
use strict;
use warnings;

# If run outside the normal test suite on an ASCII platform, you can
# just create a latin1_to_native() function that just returns its
# inputs, because that's the only function used from test.pl
require "test.pl";

# Test qr/\X/ and the \p{} regular expression constructs.  This file is
# constructed by mktables from the tables it generates, so if mktables is
# buggy, this won't necessarily catch those bugs.  Tests are generated for all
# feasible properties; a few aren't currently feasible; see
# is_code_point_usable() in mktables for details.

# Standard test packages are not used because this manipulates SIG_WARN.  It
# exits 0 if every non-skipped test succeeded; -1 if any failed.

my $Tests = 0;
my $Fails = 0;

sub Expect($$$$) {
    my $expected = shift;
    my $ord = shift;
    my $regex  = shift;
    my $warning_type = shift;   # Type of warning message, like 'deprecated'
                                # or empty if none
    my $line   = (caller)[2];
    $ord = ord(latin1_to_native(chr($ord)));

    # Convert the code point to hex form
    my $string = sprintf "\"\\x{%04X}\"", $ord;

    my @tests = "";

    # The first time through, use all warnings.  If the input should generate
    # a warning, add another time through with them turned off
    push @tests, "no warnings '$warning_type';" if $warning_type;

    foreach my $no_warnings (@tests) {

        # Store any warning messages instead of outputting them
        local $SIG{__WARN__} = $SIG{__WARN__};
        my $warning_message;
        $SIG{__WARN__} = sub { $warning_message = $_[0] };

        $Tests++;

        # A string eval is needed because of the 'no warnings'.
        # Assumes no parens in the regular expression
        my $result = eval "$no_warnings
                            my \$RegObj = qr($regex);
                            $string =~ \$RegObj ? 1 : 0";
        if (not defined $result) {
            print "not ok $Tests - couldn't compile /$regex/; line $line: $@\n";
            $Fails++;
        }
        elsif ($result ^ $expected) {
            print "not ok $Tests - expected $expected but got $result for $string =~ qr/$regex/; line $line\n";
            $Fails++;
        }
        elsif ($warning_message) {
            if (! $warning_type || ($warning_type && $no_warnings)) {
                print "not ok $Tests - for qr/$regex/ did not expect warning message '$warning_message'; line $line\n";
                $Fails++;
            }
            else {
                print "ok $Tests - expected and got a warning message for qr/$regex/; line $line\n";
            }
        }
        elsif ($warning_type && ! $no_warnings) {
            print "not ok $Tests - for qr/$regex/ expected a $warning_type warning message, but got none; line $line\n";
            $Fails++;
        }
        else {
            print "ok $Tests - got $result for $string =~ qr/$regex/; line $line\n";
        }
    }
    return;
}

sub Error($) {
    my $regex  = shift;
    $Tests++;
    if (eval { 'x' =~ qr/$regex/; 1 }) {
        $Fails++;
        my $line = (caller)[2];
        print "not ok $Tests - re compiled ok, but expected error for qr/$regex/; line $line: $@\n";
    }
    else {
        my $line = (caller)[2];
        print "ok $Tests - got and expected error for qr/$regex/; line $line\n";
    }
    return;
}

# GCBTest.txt character that separates grapheme clusters
my $breakable_utf8 = my $breakable = chr(0xF7);
utf8::upgrade($breakable_utf8);

# GCBTest.txt character that indicates that the adjoining code points are part
# of the same grapheme cluster
my $nobreak_utf8 = my $nobreak = chr(0xD7);
utf8::upgrade($nobreak_utf8);

sub Test_X($) {
    # Test qr/\X/ matches.  The input is a line from auxiliary/GCBTest.txt
    # Each such line is a sequence of code points given by their hex numbers,
    # separated by the two characters defined just before this subroutine that
    # indicate that either there can or cannot be a break between the adjacent
    # code points.  If there isn't a break, that means the sequence forms an
    # extended grapheme cluster, which means that \X should match the whole
    # thing.  If there is a break, \X should stop there.  This is all
    # converted by this routine into a match:
    #   $string =~ /(\X)/,
    # Each \X should match the next cluster; and that is what is checked.

    my $template = shift;

    my $line   = (caller)[2];

    # The line contains characters above the ASCII range, but in Latin1.  It
    # may or may not be in utf8, and if it is, it may or may not know it.  So,
    # convert these characters to 8 bits.  If knows is in utf8, simply
    # downgrade.
    if (utf8::is_utf8($template)) {
        utf8::downgrade($template);
    } else {

        # Otherwise, if it is in utf8, but doesn't know it, the next lines
        # convert the two problematic characters to their 8-bit equivalents.
        # If it isn't in utf8, they don't harm anything.
        use bytes;
        $template =~ s/$nobreak_utf8/$nobreak/g;
        $template =~ s/$breakable_utf8/$breakable/g;
    }

    # Get rid of the leading and trailing breakables
    $template =~ s/^ \s* $breakable \s* //x;
    $template =~ s/ \s* $breakable \s* $ //x;

    # And no-breaks become just a space.
    $template =~ s/ \s* $nobreak \s* / /xg;

    # Split the input into segments that are breakable between them.
    my @segments = split /\s*$breakable\s*/, $template;

    my $string = "";
    my $display_string = "";
    my @should_match;
    my @should_display;

    # Convert the code point sequence in each segment into a Perl string of
    # characters
    foreach my $segment (@segments) {
        my @code_points = split /\s+/, $segment;
        my $this_string = "";
        my $this_display = "";
        foreach my $code_point (@code_points) {
            $this_string .= latin1_to_native(chr(hex $code_point));
            $this_display .= "\\x{$code_point}";
        }

        # The next cluster should match the string in this segment.
        push @should_match, $this_string;
        push @should_display, $this_display;
        $string .= $this_string;
        $display_string .= $this_display;
    }

    # If a string can be represented in both non-ut8 and utf8, test both cases
    UPGRADE:
    for my $to_upgrade (0 .. 1) {

        if ($to_upgrade) {

            # If already in utf8, would just be a repeat
            next UPGRADE if utf8::is_utf8($string);

            utf8::upgrade($string);
        }

        # Finally, do the \X match.
        my @matches = $string =~ /(\X)/g;

        # Look through each matched cluster to verify that it matches what we
        # expect.
        my $min = (@matches < @should_match) ? @matches : @should_match;
        for my $i (0 .. $min - 1) {
            $Tests++;
            if ($matches[$i] eq $should_match[$i]) {
                print "ok $Tests - ";
                if ($i == 0) {
                    print "In \"$display_string\" =~ /(\\X)/g, \\X #1";
                } else {
                    print "And \\X #", $i + 1,
                }
                print " correctly matched $should_display[$i]; line $line\n";
            } else {
                $matches[$i] = join("", map { sprintf "\\x{%04X}", $_ }
                                                    unpack("U*", $matches[$i]));
                print "not ok $Tests - In \"$display_string\" =~ /(\\X)/g, \\X #",
                    $i + 1,
                    " should have matched $should_display[$i]",
                    " but instead matched $matches[$i]",
                    ".  Abandoning rest of line $line\n";
                next UPGRADE;
            }
        }

        # And the number of matches should equal the number of expected matches.
        $Tests++;
        if (@matches == @should_match) {
            print "ok $Tests - Nothing was left over; line $line\n";
        } else {
            print "not ok $Tests - There were ", scalar @should_match, " \\X matches expected, but got ", scalar @matches, " instead; line $line\n";
        }
    }

    return;
}

sub Finished() {
    print "1..$Tests\n";
    exit($Fails ? -1 : 0);
}

Error('\p{Script=InGreek}');    # Bug #69018
Test_X("1100 $nobreak 1161");  # Bug #70940
Expect(0, 0x2028, '\p{Print}', ""); # Bug # 71722
Expect(0, 0x2029, '\p{Print}', ""); # Bug # 71722
Expect(1, 0xFF10, '\p{XDigit}', ""); # Bug # 71726
Error('\p{ASCII_Hex_Digit:--NO/a/}');
Error('\P{ASCII_Hex_Digit:--NO/a/}');
Expect(1, 103, '\p{ASCII_Hex_Digit=no}', "");
Expect(0, 103, '\p{^ASCII_Hex_Digit=no}', "");
Expect(0, 103, '\P{ASCII_Hex_Digit=no}', "");
Expect(1, 103, '\P{^ASCII_Hex_Digit=no}', "");
Expect(0, 102, '\p{ASCII_Hex_Digit=no}', "");
Expect(1, 102, '\p{^ASCII_Hex_Digit=no}', "");
Expect(1, 102, '\P{ASCII_Hex_Digit=no}', "");
Expect(0, 102, '\P{^ASCII_Hex_Digit=no}', "");
Expect(1, 103, '\p{ASCII_Hex_Digit= NO}', "");
Expect(0, 103, '\p{^ASCII_Hex_Digit= NO}', "");
Expect(0, 103, '\P{ASCII_Hex_Digit= NO}', "");
Expect(1, 103, '\P{^ASCII_Hex_Digit= NO}', "");
Expect(0, 102, '\p{ASCII_Hex_Digit= NO}', "");
Expect(1, 102, '\p{^ASCII_Hex_Digit= NO}', "");
Expect(1, 102, '\P{ASCII_Hex_Digit= NO}', "");
Expect(0, 102, '\P{^ASCII_Hex_Digit= NO}', "");
Error('\p{AHex: :=	N}');
Error('\P{AHex: :=	N}');
Expect(1, 103, '\p{AHex: n}', "");
Expect(0, 103, '\p{^AHex: n}', "");
Expect(0, 103, '\P{AHex: n}', "");
Expect(1, 103, '\P{^AHex: n}', "");
Expect(0, 102, '\p{AHex: n}', "");
Expect(1, 102, '\p{^AHex: n}', "");
Expect(1, 102, '\P{AHex: n}', "");
Expect(0, 102, '\P{^AHex: n}', "");
Expect(1, 103, '\p{AHex=  N}', "");
Expect(0, 103, '\p{^AHex=  N}', "");
Expect(0, 103, '\P{AHex=  N}', "");
Expect(1, 103, '\P{^AHex=  N}', "");
Expect(0, 102, '\p{AHex=  N}', "");
Expect(1, 102, '\p{^AHex=  N}', "");
Expect(1, 102, '\P{AHex=  N}', "");
Expect(0, 102, '\P{^AHex=  N}', "");
Error('\p{Is_ASCII_Hex_Digit=_:=F}');
Error('\P{Is_ASCII_Hex_Digit=_:=F}');
Expect(1, 103, '\p{Is_ASCII_Hex_Digit=f}', "");
Expect(0, 103, '\p{^Is_ASCII_Hex_Digit=f}', "");
Expect(0, 103, '\P{Is_ASCII_Hex_Digit=f}', "");
Expect(1, 103, '\P{^Is_ASCII_Hex_Digit=f}', "");
Expect(0, 102, '\p{Is_ASCII_Hex_Digit=f}', "");
Expect(1, 102, '\p{^Is_ASCII_Hex_Digit=f}', "");
Expect(1, 102, '\P{Is_ASCII_Hex_Digit=f}', "");
Expect(0, 102, '\P{^Is_ASCII_Hex_Digit=f}', "");
Expect(1, 103, '\p{Is_ASCII_Hex_Digit=_-f}', "");
Expect(0, 103, '\p{^Is_ASCII_Hex_Digit=_-f}', "");
Expect(0, 103, '\P{Is_ASCII_Hex_Digit=_-f}', "");
Expect(1, 103, '\P{^Is_ASCII_Hex_Digit=_-f}', "");
Expect(0, 102, '\p{Is_ASCII_Hex_Digit=_-f}', "");
Expect(1, 102, '\p{^Is_ASCII_Hex_Digit=_-f}', "");
Expect(1, 102, '\P{Is_ASCII_Hex_Digit=_-f}', "");
Expect(0, 102, '\P{^Is_ASCII_Hex_Digit=_-f}', "");
Error('\p{Is_AHex=-/a/false}');
Error('\P{Is_AHex=-/a/false}');
Expect(1, 103, '\p{Is_AHex=false}', "");
Expect(0, 103, '\p{^Is_AHex=false}', "");
Expect(0, 103, '\P{Is_AHex=false}', "");
Expect(1, 103, '\P{^Is_AHex=false}', "");
Expect(0, 102, '\p{Is_AHex=false}', "");
Expect(1, 102, '\p{^Is_AHex=false}', "");
Expect(1, 102, '\P{Is_AHex=false}', "");
Expect(0, 102, '\P{^Is_AHex=false}', "");
Expect(1, 103, '\p{Is_AHex= False}', "");
Expect(0, 103, '\p{^Is_AHex= False}', "");
Expect(0, 103, '\P{Is_AHex= False}', "");
Expect(1, 103, '\P{^Is_AHex= False}', "");
Expect(0, 102, '\p{Is_AHex= False}', "");
Expect(1, 102, '\p{^Is_AHex= False}', "");
Expect(1, 102, '\P{Is_AHex= False}', "");
Expect(0, 102, '\P{^Is_AHex= False}', "");
Error('\p{ASCII_Hex_Digit=/a/ 	yes}');
Error('\P{ASCII_Hex_Digit=/a/ 	yes}');
Expect(1, 102, '\p{ASCII_Hex_Digit=yes}', "");
Expect(0, 102, '\p{^ASCII_Hex_Digit=yes}', "");
Expect(0, 102, '\P{ASCII_Hex_Digit=yes}', "");
Expect(1, 102, '\P{^ASCII_Hex_Digit=yes}', "");
Expect(0, 103, '\p{ASCII_Hex_Digit=yes}', "");
Expect(1, 103, '\p{^ASCII_Hex_Digit=yes}', "");
Expect(1, 103, '\P{ASCII_Hex_Digit=yes}', "");
Expect(0, 103, '\P{^ASCII_Hex_Digit=yes}', "");
Expect(1, 102, '\p{ASCII_Hex_Digit= -Yes}', "");
Expect(0, 102, '\p{^ASCII_Hex_Digit= -Yes}', "");
Expect(0, 102, '\P{ASCII_Hex_Digit= -Yes}', "");
Expect(1, 102, '\P{^ASCII_Hex_Digit= -Yes}', "");
Expect(0, 103, '\p{ASCII_Hex_Digit= -Yes}', "");
Expect(1, 103, '\p{^ASCII_Hex_Digit= -Yes}', "");
Expect(1, 103, '\P{ASCII_Hex_Digit= -Yes}', "");
Expect(0, 103, '\P{^ASCII_Hex_Digit= -Yes}', "");
Error('\p{AHex=:=	y}');
Error('\P{AHex=:=	y}');
Expect(1, 102, '\p{AHex=y}', "");
Expect(0, 102, '\p{^AHex=y}', "");
Expect(0, 102, '\P{AHex=y}', "");
Expect(1, 102, '\P{^AHex=y}', "");
Expect(0, 103, '\p{AHex=y}', "");
Expect(1, 103, '\p{^AHex=y}', "");
Expect(1, 103, '\P{AHex=y}', "");
Expect(0, 103, '\P{^AHex=y}', "");
Expect(1, 102, '\p{AHex=-Y}', "");
Expect(0, 102, '\p{^AHex=-Y}', "");
Expect(0, 102, '\P{AHex=-Y}', "");
Expect(1, 102, '\P{^AHex=-Y}', "");
Expect(0, 103, '\p{AHex=-Y}', "");
Expect(1, 103, '\p{^AHex=-Y}', "");
Expect(1, 103, '\P{AHex=-Y}', "");
Expect(0, 103, '\P{^AHex=-Y}', "");
Error('\p{Is_ASCII_Hex_Digit=/a/	-T}');
Error('\P{Is_ASCII_Hex_Digit=/a/	-T}');
Expect(1, 102, '\p{Is_ASCII_Hex_Digit=t}', "");
Expect(0, 102, '\p{^Is_ASCII_Hex_Digit=t}', "");
Expect(0, 102, '\P{Is_ASCII_Hex_Digit=t}', "");
Expect(1, 102, '\P{^Is_ASCII_Hex_Digit=t}', "");
Expect(0, 103, '\p{Is_ASCII_Hex_Digit=t}', "");
Expect(1, 103, '\p{^Is_ASCII_Hex_Digit=t}', "");
Expect(1, 103, '\P{Is_ASCII_Hex_Digit=t}', "");
Expect(0, 103, '\P{^Is_ASCII_Hex_Digit=t}', "");
Expect(1, 102, '\p{Is_ASCII_Hex_Digit=		T}', "");
Expect(0, 102, '\p{^Is_ASCII_Hex_Digit=		T}', "");
Expect(0, 102, '\P{Is_ASCII_Hex_Digit=		T}', "");
Expect(1, 102, '\P{^Is_ASCII_Hex_Digit=		T}', "");
Expect(0, 103, '\p{Is_ASCII_Hex_Digit=		T}', "");
Expect(1, 103, '\p{^Is_ASCII_Hex_Digit=		T}', "");
Expect(1, 103, '\P{Is_ASCII_Hex_Digit=		T}', "");
Expect(0, 103, '\P{^Is_ASCII_Hex_Digit=		T}', "");
Error('\p{Is_AHex=/a/__True}');
Error('\P{Is_AHex=/a/__True}');
Expect(1, 102, '\p{Is_AHex=true}', "");
Expect(0, 102, '\p{^Is_AHex=true}', "");
Expect(0, 102, '\P{Is_AHex=true}', "");
Expect(1, 102, '\P{^Is_AHex=true}', "");
Expect(0, 103, '\p{Is_AHex=true}', "");
Expect(1, 103, '\p{^Is_AHex=true}', "");
Expect(1, 103, '\P{Is_AHex=true}', "");
Expect(0, 103, '\P{^Is_AHex=true}', "");
Expect(1, 102, '\p{Is_AHex=_ TRUE}', "");
Expect(0, 102, '\p{^Is_AHex=_ TRUE}', "");
Expect(0, 102, '\P{Is_AHex=_ TRUE}', "");
Expect(1, 102, '\P{^Is_AHex=_ TRUE}', "");
Expect(0, 103, '\p{Is_AHex=_ TRUE}', "");
Expect(1, 103, '\p{^Is_AHex=_ TRUE}', "");
Expect(1, 103, '\P{Is_AHex=_ TRUE}', "");
Expect(0, 103, '\P{^Is_AHex=_ TRUE}', "");
Error('\p{Alphabetic=/a/_No}');
Error('\P{Alphabetic=/a/_No}');
Expect(1, 195102, '\p{Alphabetic=no}', "");
Expect(0, 195102, '\p{^Alphabetic=no}', "");
Expect(0, 195102, '\P{Alphabetic=no}', "");
Expect(1, 195102, '\P{^Alphabetic=no}', "");
Expect(0, 195101, '\p{Alphabetic=no}', "");
Expect(1, 195101, '\p{^Alphabetic=no}', "");
Expect(1, 195101, '\P{Alphabetic=no}', "");
Expect(0, 195101, '\P{^Alphabetic=no}', "");
Expect(1, 195102, '\p{Alphabetic= 	no}', "");
Expect(0, 195102, '\p{^Alphabetic= 	no}', "");
Expect(0, 195102, '\P{Alphabetic= 	no}', "");
Expect(1, 195102, '\P{^Alphabetic= 	no}', "");
Expect(0, 195101, '\p{Alphabetic= 	no}', "");
Expect(1, 195101, '\p{^Alphabetic= 	no}', "");
Expect(1, 195101, '\P{Alphabetic= 	no}', "");
Expect(0, 195101, '\P{^Alphabetic= 	no}', "");
Error('\p{Alpha=_ N/a/}');
Error('\P{Alpha=_ N/a/}');
Expect(1, 195102, '\p{Alpha=n}', "");
Expect(0, 195102, '\p{^Alpha=n}', "");
Expect(0, 195102, '\P{Alpha=n}', "");
Expect(1, 195102, '\P{^Alpha=n}', "");
Expect(0, 195101, '\p{Alpha=n}', "");
Expect(1, 195101, '\p{^Alpha=n}', "");
Expect(1, 195101, '\P{Alpha=n}', "");
Expect(0, 195101, '\P{^Alpha=n}', "");
Expect(1, 195102, '\p{Alpha=_N}', "");
Expect(0, 195102, '\p{^Alpha=_N}', "");
Expect(0, 195102, '\P{Alpha=_N}', "");
Expect(1, 195102, '\P{^Alpha=_N}', "");
Expect(0, 195101, '\p{Alpha=_N}', "");
Expect(1, 195101, '\p{^Alpha=_N}', "");
Expect(1, 195101, '\P{Alpha=_N}', "");
Expect(0, 195101, '\P{^Alpha=_N}', "");
Error('\p{Is_Alphabetic=:=-	F}');
Error('\P{Is_Alphabetic=:=-	F}');
Expect(1, 195102, '\p{Is_Alphabetic:   f}', "");
Expect(0, 195102, '\p{^Is_Alphabetic:   f}', "");
Expect(0, 195102, '\P{Is_Alphabetic:   f}', "");
Expect(1, 195102, '\P{^Is_Alphabetic:   f}', "");
Expect(0, 195101, '\p{Is_Alphabetic:   f}', "");
Expect(1, 195101, '\p{^Is_Alphabetic:   f}', "");
Expect(1, 195101, '\P{Is_Alphabetic:   f}', "");
Expect(0, 195101, '\P{^Is_Alphabetic:   f}', "");
Expect(1, 195102, '\p{Is_Alphabetic= _F}', "");
Expect(0, 195102, '\p{^Is_Alphabetic= _F}', "");
Expect(0, 195102, '\P{Is_Alphabetic= _F}', "");
Expect(1, 195102, '\P{^Is_Alphabetic= _F}', "");
Expect(0, 195101, '\p{Is_Alphabetic= _F}', "");
Expect(1, 195101, '\p{^Is_Alphabetic= _F}', "");
Expect(1, 195101, '\P{Is_Alphabetic= _F}', "");
Expect(0, 195101, '\P{^Is_Alphabetic= _F}', "");
Error('\p{Is_Alpha=_ FALSE/a/}');
Error('\P{Is_Alpha=_ FALSE/a/}');
Expect(1, 195102, '\p{Is_Alpha=false}', "");
Expect(0, 195102, '\p{^Is_Alpha=false}', "");
Expect(0, 195102, '\P{Is_Alpha=false}', "");
Expect(1, 195102, '\P{^Is_Alpha=false}', "");
Expect(0, 195101, '\p{Is_Alpha=false}', "");
Expect(1, 195101, '\p{^Is_Alpha=false}', "");
Expect(1, 195101, '\P{Is_Alpha=false}', "");
Expect(0, 195101, '\P{^Is_Alpha=false}', "");
Expect(1, 195102, '\p{Is_Alpha= 	False}', "");
Expect(0, 195102, '\p{^Is_Alpha= 	False}', "");
Expect(0, 195102, '\P{Is_Alpha= 	False}', "");
Expect(1, 195102, '\P{^Is_Alpha= 	False}', "");
Expect(0, 195101, '\p{Is_Alpha= 	False}', "");
Expect(1, 195101, '\p{^Is_Alpha= 	False}', "");
Expect(1, 195101, '\P{Is_Alpha= 	False}', "");
Expect(0, 195101, '\P{^Is_Alpha= 	False}', "");
Error('\p{Alphabetic=/a/ -Yes}');
Error('\P{Alphabetic=/a/ -Yes}');
Expect(1, 195101, '\p{Alphabetic=yes}', "");
Expect(0, 195101, '\p{^Alphabetic=yes}', "");
Expect(0, 195101, '\P{Alphabetic=yes}', "");
Expect(1, 195101, '\P{^Alphabetic=yes}', "");
Expect(0, 195102, '\p{Alphabetic=yes}', "");
Expect(1, 195102, '\p{^Alphabetic=yes}', "");
Expect(1, 195102, '\P{Alphabetic=yes}', "");
Expect(0, 195102, '\P{^Alphabetic=yes}', "");
Expect(1, 195101, '\p{Alphabetic=_-yes}', "");
Expect(0, 195101, '\p{^Alphabetic=_-yes}', "");
Expect(0, 195101, '\P{Alphabetic=_-yes}', "");
Expect(1, 195101, '\P{^Alphabetic=_-yes}', "");
Expect(0, 195102, '\p{Alphabetic=_-yes}', "");
Expect(1, 195102, '\p{^Alphabetic=_-yes}', "");
Expect(1, 195102, '\P{Alphabetic=_-yes}', "");
Expect(0, 195102, '\P{^Alphabetic=_-yes}', "");
Error('\p{Alpha=/a/-	Y}');
Error('\P{Alpha=/a/-	Y}');
Expect(1, 195101, '\p{Alpha=y}', "");
Expect(0, 195101, '\p{^Alpha=y}', "");
Expect(0, 195101, '\P{Alpha=y}', "");
Expect(1, 195101, '\P{^Alpha=y}', "");
Expect(0, 195102, '\p{Alpha=y}', "");
Expect(1, 195102, '\p{^Alpha=y}', "");
Expect(1, 195102, '\P{Alpha=y}', "");
Expect(0, 195102, '\P{^Alpha=y}', "");
Expect(1, 195101, '\p{Alpha=-	y}', "");
Expect(0, 195101, '\p{^Alpha=-	y}', "");
Expect(0, 195101, '\P{Alpha=-	y}', "");
Expect(1, 195101, '\P{^Alpha=-	y}', "");
Expect(0, 195102, '\p{Alpha=-	y}', "");
Expect(1, 195102, '\p{^Alpha=-	y}', "");
Expect(1, 195102, '\P{Alpha=-	y}', "");
Expect(0, 195102, '\P{^Alpha=-	y}', "");
Error('\p{Is_Alphabetic=	-T/a/}');
Error('\P{Is_Alphabetic=	-T/a/}');
Expect(1, 195101, '\p{Is_Alphabetic=t}', "");
Expect(0, 195101, '\p{^Is_Alphabetic=t}', "");
Expect(0, 195101, '\P{Is_Alphabetic=t}', "");
Expect(1, 195101, '\P{^Is_Alphabetic=t}', "");
Expect(0, 195102, '\p{Is_Alphabetic=t}', "");
Expect(1, 195102, '\p{^Is_Alphabetic=t}', "");
Expect(1, 195102, '\P{Is_Alphabetic=t}', "");
Expect(0, 195102, '\P{^Is_Alphabetic=t}', "");
Expect(1, 195101, '\p{Is_Alphabetic= T}', "");
Expect(0, 195101, '\p{^Is_Alphabetic= T}', "");
Expect(0, 195101, '\P{Is_Alphabetic= T}', "");
Expect(1, 195101, '\P{^Is_Alphabetic= T}', "");
Expect(0, 195102, '\p{Is_Alphabetic= T}', "");
Expect(1, 195102, '\p{^Is_Alphabetic= T}', "");
Expect(1, 195102, '\P{Is_Alphabetic= T}', "");
Expect(0, 195102, '\P{^Is_Alphabetic= T}', "");
Error('\p{Is_Alpha=-:=True}');
Error('\P{Is_Alpha=-:=True}');
Expect(1, 195101, '\p{Is_Alpha=true}', "");
Expect(0, 195101, '\p{^Is_Alpha=true}', "");
Expect(0, 195101, '\P{Is_Alpha=true}', "");
Expect(1, 195101, '\P{^Is_Alpha=true}', "");
Expect(0, 195102, '\p{Is_Alpha=true}', "");
Expect(1, 195102, '\p{^Is_Alpha=true}', "");
Expect(1, 195102, '\P{Is_Alpha=true}', "");
Expect(0, 195102, '\P{^Is_Alpha=true}', "");
Expect(1, 195101, '\p{Is_Alpha=_-True}', "");
Expect(0, 195101, '\p{^Is_Alpha=_-True}', "");
Expect(0, 195101, '\P{Is_Alpha=_-True}', "");
Expect(1, 195101, '\P{^Is_Alpha=_-True}', "");
Expect(0, 195102, '\p{Is_Alpha=_-True}', "");
Expect(1, 195102, '\p{^Is_Alpha=_-True}', "");
Expect(1, 195102, '\P{Is_Alpha=_-True}', "");
Expect(0, 195102, '\P{^Is_Alpha=_-True}', "");
Error('\p{Bidi_Control=	/a/No}');
Error('\P{Bidi_Control=	/a/No}');
Expect(1, 8239, '\p{Bidi_Control=no}', "");
Expect(0, 8239, '\p{^Bidi_Control=no}', "");
Expect(0, 8239, '\P{Bidi_Control=no}', "");
Expect(1, 8239, '\P{^Bidi_Control=no}', "");
Expect(0, 8238, '\p{Bidi_Control=no}', "");
Expect(1, 8238, '\p{^Bidi_Control=no}', "");
Expect(1, 8238, '\P{Bidi_Control=no}', "");
Expect(0, 8238, '\P{^Bidi_Control=no}', "");
Expect(1, 8239, '\p{Bidi_Control=-No}', "");
Expect(0, 8239, '\p{^Bidi_Control=-No}', "");
Expect(0, 8239, '\P{Bidi_Control=-No}', "");
Expect(1, 8239, '\P{^Bidi_Control=-No}', "");
Expect(0, 8238, '\p{Bidi_Control=-No}', "");
Expect(1, 8238, '\p{^Bidi_Control=-No}', "");
Expect(1, 8238, '\P{Bidi_Control=-No}', "");
Expect(0, 8238, '\P{^Bidi_Control=-No}', "");
Error('\p{Bidi_C=	 N/a/}');
Error('\P{Bidi_C=	 N/a/}');
Expect(1, 8239, '\p{Bidi_C=n}', "");
Expect(0, 8239, '\p{^Bidi_C=n}', "");
Expect(0, 8239, '\P{Bidi_C=n}', "");
Expect(1, 8239, '\P{^Bidi_C=n}', "");
Expect(0, 8238, '\p{Bidi_C=n}', "");
Expect(1, 8238, '\p{^Bidi_C=n}', "");
Expect(1, 8238, '\P{Bidi_C=n}', "");
Expect(0, 8238, '\P{^Bidi_C=n}', "");
Expect(1, 8239, '\p{Bidi_C= N}', "");
Expect(0, 8239, '\p{^Bidi_C= N}', "");
Expect(0, 8239, '\P{Bidi_C= N}', "");
Expect(1, 8239, '\P{^Bidi_C= N}', "");
Expect(0, 8238, '\p{Bidi_C= N}', "");
Expect(1, 8238, '\p{^Bidi_C= N}', "");
Expect(1, 8238, '\P{Bidi_C= N}', "");
Expect(0, 8238, '\P{^Bidi_C= N}', "");
Error('\p{Is_Bidi_Control=-	F:=}');
Error('\P{Is_Bidi_Control=-	F:=}');
Expect(1, 8239, '\p{Is_Bidi_Control=f}', "");
Expect(0, 8239, '\p{^Is_Bidi_Control=f}', "");
Expect(0, 8239, '\P{Is_Bidi_Control=f}', "");
Expect(1, 8239, '\P{^Is_Bidi_Control=f}', "");
Expect(0, 8238, '\p{Is_Bidi_Control=f}', "");
Expect(1, 8238, '\p{^Is_Bidi_Control=f}', "");
Expect(1, 8238, '\P{Is_Bidi_Control=f}', "");
Expect(0, 8238, '\P{^Is_Bidi_Control=f}', "");
Expect(1, 8239, '\p{Is_Bidi_Control=	F}', "");
Expect(0, 8239, '\p{^Is_Bidi_Control=	F}', "");
Expect(0, 8239, '\P{Is_Bidi_Control=	F}', "");
Expect(1, 8239, '\P{^Is_Bidi_Control=	F}', "");
Expect(0, 8238, '\p{Is_Bidi_Control=	F}', "");
Expect(1, 8238, '\p{^Is_Bidi_Control=	F}', "");
Expect(1, 8238, '\P{Is_Bidi_Control=	F}', "");
Expect(0, 8238, '\P{^Is_Bidi_Control=	F}', "");
Error('\p{Is_Bidi_C=/a/_-FALSE}');
Error('\P{Is_Bidi_C=/a/_-FALSE}');
Expect(1, 8239, '\p{Is_Bidi_C=false}', "");
Expect(0, 8239, '\p{^Is_Bidi_C=false}', "");
Expect(0, 8239, '\P{Is_Bidi_C=false}', "");
Expect(1, 8239, '\P{^Is_Bidi_C=false}', "");
Expect(0, 8238, '\p{Is_Bidi_C=false}', "");
Expect(1, 8238, '\p{^Is_Bidi_C=false}', "");
Expect(1, 8238, '\P{Is_Bidi_C=false}', "");
Expect(0, 8238, '\P{^Is_Bidi_C=false}', "");
Expect(1, 8239, '\p{Is_Bidi_C=  FALSE}', "");
Expect(0, 8239, '\p{^Is_Bidi_C=  FALSE}', "");
Expect(0, 8239, '\P{Is_Bidi_C=  FALSE}', "");
Expect(1, 8239, '\P{^Is_Bidi_C=  FALSE}', "");
Expect(0, 8238, '\p{Is_Bidi_C=  FALSE}', "");
Expect(1, 8238, '\p{^Is_Bidi_C=  FALSE}', "");
Expect(1, 8238, '\P{Is_Bidi_C=  FALSE}', "");
Expect(0, 8238, '\P{^Is_Bidi_C=  FALSE}', "");
Error('\p{Bidi_Control:	--yes/a/}');
Error('\P{Bidi_Control:	--yes/a/}');
Expect(1, 8238, '\p{Bidi_Control=yes}', "");
Expect(0, 8238, '\p{^Bidi_Control=yes}', "");
Expect(0, 8238, '\P{Bidi_Control=yes}', "");
Expect(1, 8238, '\P{^Bidi_Control=yes}', "");
Expect(0, 8239, '\p{Bidi_Control=yes}', "");
Expect(1, 8239, '\p{^Bidi_Control=yes}', "");
Expect(1, 8239, '\P{Bidi_Control=yes}', "");
Expect(0, 8239, '\P{^Bidi_Control=yes}', "");
Expect(1, 8238, '\p{Bidi_Control=--Yes}', "");
Expect(0, 8238, '\p{^Bidi_Control=--Yes}', "");
Expect(0, 8238, '\P{Bidi_Control=--Yes}', "");
Expect(1, 8238, '\P{^Bidi_Control=--Yes}', "");
Expect(0, 8239, '\p{Bidi_Control=--Yes}', "");
Expect(1, 8239, '\p{^Bidi_Control=--Yes}', "");
Expect(1, 8239, '\P{Bidi_Control=--Yes}', "");
Expect(0, 8239, '\P{^Bidi_Control=--Yes}', "");
Error('\p{Bidi_C=-_Y:=}');
Error('\P{Bidi_C=-_Y:=}');
Expect(1, 8238, '\p{Bidi_C=y}', "");
Expect(0, 8238, '\p{^Bidi_C=y}', "");
Expect(0, 8238, '\P{Bidi_C=y}', "");
Expect(1, 8238, '\P{^Bidi_C=y}', "");
Expect(0, 8239, '\p{Bidi_C=y}', "");
Expect(1, 8239, '\p{^Bidi_C=y}', "");
Expect(1, 8239, '\P{Bidi_C=y}', "");
Expect(0, 8239, '\P{^Bidi_C=y}', "");
Expect(1, 8238, '\p{Bidi_C=	 y}', "");
Expect(0, 8238, '\p{^Bidi_C=	 y}', "");
Expect(0, 8238, '\P{Bidi_C=	 y}', "");
Expect(1, 8238, '\P{^Bidi_C=	 y}', "");
Expect(0, 8239, '\p{Bidi_C=	 y}', "");
Expect(1, 8239, '\p{^Bidi_C=	 y}', "");
Expect(1, 8239, '\P{Bidi_C=	 y}', "");
Expect(0, 8239, '\P{^Bidi_C=	 y}', "");
Error('\p{Is_Bidi_Control=:=T}');
Error('\P{Is_Bidi_Control=:=T}');
Expect(1, 8238, '\p{Is_Bidi_Control=t}', "");
Expect(0, 8238, '\p{^Is_Bidi_Control=t}', "");
Expect(0, 8238, '\P{Is_Bidi_Control=t}', "");
Expect(1, 8238, '\P{^Is_Bidi_Control=t}', "");
Expect(0, 8239, '\p{Is_Bidi_Control=t}', "");
Expect(1, 8239, '\p{^Is_Bidi_Control=t}', "");
Expect(1, 8239, '\P{Is_Bidi_Control=t}', "");
Expect(0, 8239, '\P{^Is_Bidi_Control=t}', "");
Error('\p{Is_Bidi_C=/a/  True}');
Error('\P{Is_Bidi_C=/a/  True}');
Expect(1, 8238, '\p{Is_Bidi_C=true}', "");
Expect(0, 8238, '\p{^Is_Bidi_C=true}', "");
Expect(0, 8238, '\P{Is_Bidi_C=true}', "");
Expect(1, 8238, '\P{^Is_Bidi_C=true}', "");
Expect(0, 8239, '\p{Is_Bidi_C=true}', "");
Expect(1, 8239, '\p{^Is_Bidi_C=true}', "");
Expect(1, 8239, '\P{Is_Bidi_C=true}', "");
Expect(0, 8239, '\P{^Is_Bidi_C=true}', "");
Expect(1, 8238, '\p{Is_Bidi_C=	True}', "");
Expect(0, 8238, '\p{^Is_Bidi_C=	True}', "");
Expect(0, 8238, '\P{Is_Bidi_C=	True}', "");
Expect(1, 8238, '\P{^Is_Bidi_C=	True}', "");
Expect(0, 8239, '\p{Is_Bidi_C=	True}', "");
Expect(1, 8239, '\p{^Is_Bidi_C=	True}', "");
Expect(1, 8239, '\P{Is_Bidi_C=	True}', "");
Expect(0, 8239, '\P{^Is_Bidi_C=	True}', "");
Error('\p{Bidi_Mirrored=	No/a/}');
Error('\P{Bidi_Mirrored=	No/a/}');
Expect(1, 120772, '\p{Bidi_Mirrored=no}', "");
Expect(0, 120772, '\p{^Bidi_Mirrored=no}', "");
Expect(0, 120772, '\P{Bidi_Mirrored=no}', "");
Expect(1, 120772, '\P{^Bidi_Mirrored=no}', "");
Expect(0, 120771, '\p{Bidi_Mirrored=no}', "");
Expect(1, 120771, '\p{^Bidi_Mirrored=no}', "");
Expect(1, 120771, '\P{Bidi_Mirrored=no}', "");
Expect(0, 120771, '\P{^Bidi_Mirrored=no}', "");
Expect(1, 120772, '\p{Bidi_Mirrored=- No}', "");
Expect(0, 120772, '\p{^Bidi_Mirrored=- No}', "");
Expect(0, 120772, '\P{Bidi_Mirrored=- No}', "");
Expect(1, 120772, '\P{^Bidi_Mirrored=- No}', "");
Expect(0, 120771, '\p{Bidi_Mirrored=- No}', "");
Expect(1, 120771, '\p{^Bidi_Mirrored=- No}', "");
Expect(1, 120771, '\P{Bidi_Mirrored=- No}', "");
Expect(0, 120771, '\P{^Bidi_Mirrored=- No}', "");
Error('\p{Bidi_M=_/a/N}');
Error('\P{Bidi_M=_/a/N}');
Expect(1, 120772, '\p{Bidi_M:	n}', "");
Expect(0, 120772, '\p{^Bidi_M:	n}', "");
Expect(0, 120772, '\P{Bidi_M:	n}', "");
Expect(1, 120772, '\P{^Bidi_M:	n}', "");
Expect(0, 120771, '\p{Bidi_M:	n}', "");
Expect(1, 120771, '\p{^Bidi_M:	n}', "");
Expect(1, 120771, '\P{Bidi_M:	n}', "");
Expect(0, 120771, '\P{^Bidi_M:	n}', "");
Expect(1, 120772, '\p{Bidi_M=	-n}', "");
Expect(0, 120772, '\p{^Bidi_M=	-n}', "");
Expect(0, 120772, '\P{Bidi_M=	-n}', "");
Expect(1, 120772, '\P{^Bidi_M=	-n}', "");
Expect(0, 120771, '\p{Bidi_M=	-n}', "");
Expect(1, 120771, '\p{^Bidi_M=	-n}', "");
Expect(1, 120771, '\P{Bidi_M=	-n}', "");
Expect(0, 120771, '\P{^Bidi_M=	-n}', "");
Error('\p{Is_Bidi_Mirrored=	 F:=}');
Error('\P{Is_Bidi_Mirrored=	 F:=}');
Expect(1, 120772, '\p{Is_Bidi_Mirrored=f}', "");
Expect(0, 120772, '\p{^Is_Bidi_Mirrored=f}', "");
Expect(0, 120772, '\P{Is_Bidi_Mirrored=f}', "");
Expect(1, 120772, '\P{^Is_Bidi_Mirrored=f}', "");
Expect(0, 120771, '\p{Is_Bidi_Mirrored=f}', "");
Expect(1, 120771, '\p{^Is_Bidi_Mirrored=f}', "");
Expect(1, 120771, '\P{Is_Bidi_Mirrored=f}', "");
Expect(0, 120771, '\P{^Is_Bidi_Mirrored=f}', "");
Expect(1, 120772, '\p{Is_Bidi_Mirrored=_f}', "");
Expect(0, 120772, '\p{^Is_Bidi_Mirrored=_f}', "");
Expect(0, 120772, '\P{Is_Bidi_Mirrored=_f}', "");
Expect(1, 120772, '\P{^Is_Bidi_Mirrored=_f}', "");
Expect(0, 120771, '\p{Is_Bidi_Mirrored=_f}', "");
Expect(1, 120771, '\p{^Is_Bidi_Mirrored=_f}', "");
Expect(1, 120771, '\P{Is_Bidi_Mirrored=_f}', "");
Expect(0, 120771, '\P{^Is_Bidi_Mirrored=_f}', "");
Error('\p{Is_Bidi_M=:=_ false}');
Error('\P{Is_Bidi_M=:=_ false}');
Expect(1, 120772, '\p{Is_Bidi_M=false}', "");
Expect(0, 120772, '\p{^Is_Bidi_M=false}', "");
Expect(0, 120772, '\P{Is_Bidi_M=false}', "");
Expect(1, 120772, '\P{^Is_Bidi_M=false}', "");
Expect(0, 120771, '\p{Is_Bidi_M=false}', "");
Expect(1, 120771, '\p{^Is_Bidi_M=false}', "");
Expect(1, 120771, '\P{Is_Bidi_M=false}', "");
Expect(0, 120771, '\P{^Is_Bidi_M=false}', "");
Expect(1, 120772, '\p{Is_Bidi_M=__FALSE}', "");
Expect(0, 120772, '\p{^Is_Bidi_M=__FALSE}', "");
Expect(0, 120772, '\P{Is_Bidi_M=__FALSE}', "");
Expect(1, 120772, '\P{^Is_Bidi_M=__FALSE}', "");
Expect(0, 120771, '\p{Is_Bidi_M=__FALSE}', "");
Expect(1, 120771, '\p{^Is_Bidi_M=__FALSE}', "");
Expect(1, 120771, '\P{Is_Bidi_M=__FALSE}', "");
Expect(0, 120771, '\P{^Is_Bidi_M=__FALSE}', "");
Error('\p{Bidi_Mirrored=:=yes}');
Error('\P{Bidi_Mirrored=:=yes}');
Expect(1, 120771, '\p{Bidi_Mirrored=yes}', "");
Expect(0, 120771, '\p{^Bidi_Mirrored=yes}', "");
Expect(0, 120771, '\P{Bidi_Mirrored=yes}', "");
Expect(1, 120771, '\P{^Bidi_Mirrored=yes}', "");
Expect(0, 120772, '\p{Bidi_Mirrored=yes}', "");
Expect(1, 120772, '\p{^Bidi_Mirrored=yes}', "");
Expect(1, 120772, '\P{Bidi_Mirrored=yes}', "");
Expect(0, 120772, '\P{^Bidi_Mirrored=yes}', "");
Expect(1, 120771, '\p{Bidi_Mirrored=-_Yes}', "");
Expect(0, 120771, '\p{^Bidi_Mirrored=-_Yes}', "");
Expect(0, 120771, '\P{Bidi_Mirrored=-_Yes}', "");
Expect(1, 120771, '\P{^Bidi_Mirrored=-_Yes}', "");
Expect(0, 120772, '\p{Bidi_Mirrored=-_Yes}', "");
Expect(1, 120772, '\p{^Bidi_Mirrored=-_Yes}', "");
Expect(1, 120772, '\P{Bidi_Mirrored=-_Yes}', "");
Expect(0, 120772, '\P{^Bidi_Mirrored=-_Yes}', "");
Error('\p{Bidi_M=Y/a/}');
Error('\P{Bidi_M=Y/a/}');
Expect(1, 120771, '\p{Bidi_M=y}', "");
Expect(0, 120771, '\p{^Bidi_M=y}', "");
Expect(0, 120771, '\P{Bidi_M=y}', "");
Expect(1, 120771, '\P{^Bidi_M=y}', "");
Expect(0, 120772, '\p{Bidi_M=y}', "");
Expect(1, 120772, '\p{^Bidi_M=y}', "");
Expect(1, 120772, '\P{Bidi_M=y}', "");
Expect(0, 120772, '\P{^Bidi_M=y}', "");
Expect(1, 120771, '\p{Bidi_M= 	y}', "");
Expect(0, 120771, '\p{^Bidi_M= 	y}', "");
Expect(0, 120771, '\P{Bidi_M= 	y}', "");
Expect(1, 120771, '\P{^Bidi_M= 	y}', "");
Expect(0, 120772, '\p{Bidi_M= 	y}', "");
Expect(1, 120772, '\p{^Bidi_M= 	y}', "");
Expect(1, 120772, '\P{Bidi_M= 	y}', "");
Expect(0, 120772, '\P{^Bidi_M= 	y}', "");
Error('\p{Is_Bidi_Mirrored: 	T:=}');
Error('\P{Is_Bidi_Mirrored: 	T:=}');
Expect(1, 120771, '\p{Is_Bidi_Mirrored=t}', "");
Expect(0, 120771, '\p{^Is_Bidi_Mirrored=t}', "");
Expect(0, 120771, '\P{Is_Bidi_Mirrored=t}', "");
Expect(1, 120771, '\P{^Is_Bidi_Mirrored=t}', "");
Expect(0, 120772, '\p{Is_Bidi_Mirrored=t}', "");
Expect(1, 120772, '\p{^Is_Bidi_Mirrored=t}', "");
Expect(1, 120772, '\P{Is_Bidi_Mirrored=t}', "");
Expect(0, 120772, '\P{^Is_Bidi_Mirrored=t}', "");
Expect(1, 120771, '\p{Is_Bidi_Mirrored=  T}', "");
Expect(0, 120771, '\p{^Is_Bidi_Mirrored=  T}', "");
Expect(0, 120771, '\P{Is_Bidi_Mirrored=  T}', "");
Expect(1, 120771, '\P{^Is_Bidi_Mirrored=  T}', "");
Expect(0, 120772, '\p{Is_Bidi_Mirrored=  T}', "");
Expect(1, 120772, '\p{^Is_Bidi_Mirrored=  T}', "");
Expect(1, 120772, '\P{Is_Bidi_Mirrored=  T}', "");
Expect(0, 120772, '\P{^Is_Bidi_Mirrored=  T}', "");
Error('\p{Is_Bidi_M=/a/ true}');
Error('\P{Is_Bidi_M=/a/ true}');
Expect(1, 120771, '\p{Is_Bidi_M=true}', "");
Expect(0, 120771, '\p{^Is_Bidi_M=true}', "");
Expect(0, 120771, '\P{Is_Bidi_M=true}', "");
Expect(1, 120771, '\P{^Is_Bidi_M=true}', "");
Expect(0, 120772, '\p{Is_Bidi_M=true}', "");
Expect(1, 120772, '\p{^Is_Bidi_M=true}', "");
Expect(1, 120772, '\P{Is_Bidi_M=true}', "");
Expect(0, 120772, '\P{^Is_Bidi_M=true}', "");
Expect(1, 120771, '\p{Is_Bidi_M= -true}', "");
Expect(0, 120771, '\p{^Is_Bidi_M= -true}', "");
Expect(0, 120771, '\P{Is_Bidi_M= -true}', "");
Expect(1, 120771, '\P{^Is_Bidi_M= -true}', "");
Expect(0, 120772, '\p{Is_Bidi_M= -true}', "");
Expect(1, 120772, '\p{^Is_Bidi_M= -true}', "");
Expect(1, 120772, '\P{Is_Bidi_M= -true}', "");
Expect(0, 120772, '\P{^Is_Bidi_M= -true}', "");
Error('\p{Composition_Exclusion=	-no:=}');
Error('\P{Composition_Exclusion=	-no:=}');
Expect(1, 119233, '\p{Composition_Exclusion=no}', "");
Expect(0, 119233, '\p{^Composition_Exclusion=no}', "");
Expect(0, 119233, '\P{Composition_Exclusion=no}', "");
Expect(1, 119233, '\P{^Composition_Exclusion=no}', "");
Expect(0, 119232, '\p{Composition_Exclusion=no}', "");
Expect(1, 119232, '\p{^Composition_Exclusion=no}', "");
Expect(1, 119232, '\P{Composition_Exclusion=no}', "");
Expect(0, 119232, '\P{^Composition_Exclusion=no}', "");
Expect(1, 119233, '\p{Composition_Exclusion=-	NO}', "");
Expect(0, 119233, '\p{^Composition_Exclusion=-	NO}', "");
Expect(0, 119233, '\P{Composition_Exclusion=-	NO}', "");
Expect(1, 119233, '\P{^Composition_Exclusion=-	NO}', "");
Expect(0, 119232, '\p{Composition_Exclusion=-	NO}', "");
Expect(1, 119232, '\p{^Composition_Exclusion=-	NO}', "");
Expect(1, 119232, '\P{Composition_Exclusion=-	NO}', "");
Expect(0, 119232, '\P{^Composition_Exclusion=-	NO}', "");
Error('\p{CE=/a/	 N}');
Error('\P{CE=/a/	 N}');
Expect(1, 119233, '\p{CE=n}', "");
Expect(0, 119233, '\p{^CE=n}', "");
Expect(0, 119233, '\P{CE=n}', "");
Expect(1, 119233, '\P{^CE=n}', "");
Expect(0, 119232, '\p{CE=n}', "");
Expect(1, 119232, '\p{^CE=n}', "");
Expect(1, 119232, '\P{CE=n}', "");
Expect(0, 119232, '\P{^CE=n}', "");
Expect(1, 119233, '\p{CE=	 N}', "");
Expect(0, 119233, '\p{^CE=	 N}', "");
Expect(0, 119233, '\P{CE=	 N}', "");
Expect(1, 119233, '\P{^CE=	 N}', "");
Expect(0, 119232, '\p{CE=	 N}', "");
Expect(1, 119232, '\p{^CE=	 N}', "");
Expect(1, 119232, '\P{CE=	 N}', "");
Expect(0, 119232, '\P{^CE=	 N}', "");
Error('\p{Is_Composition_Exclusion=__F/a/}');
Error('\P{Is_Composition_Exclusion=__F/a/}');
Expect(1, 119233, '\p{Is_Composition_Exclusion=f}', "");
Expect(0, 119233, '\p{^Is_Composition_Exclusion=f}', "");
Expect(0, 119233, '\P{Is_Composition_Exclusion=f}', "");
Expect(1, 119233, '\P{^Is_Composition_Exclusion=f}', "");
Expect(0, 119232, '\p{Is_Composition_Exclusion=f}', "");
Expect(1, 119232, '\p{^Is_Composition_Exclusion=f}', "");
Expect(1, 119232, '\P{Is_Composition_Exclusion=f}', "");
Expect(0, 119232, '\P{^Is_Composition_Exclusion=f}', "");
Expect(1, 119233, '\p{Is_Composition_Exclusion= f}', "");
Expect(0, 119233, '\p{^Is_Composition_Exclusion= f}', "");
Expect(0, 119233, '\P{Is_Composition_Exclusion= f}', "");
Expect(1, 119233, '\P{^Is_Composition_Exclusion= f}', "");
Expect(0, 119232, '\p{Is_Composition_Exclusion= f}', "");
Expect(1, 119232, '\p{^Is_Composition_Exclusion= f}', "");
Expect(1, 119232, '\P{Is_Composition_Exclusion= f}', "");
Expect(0, 119232, '\P{^Is_Composition_Exclusion= f}', "");
Error('\p{Is_CE=	:=false}');
Error('\P{Is_CE=	:=false}');
Expect(1, 119233, '\p{Is_CE=false}', "");
Expect(0, 119233, '\p{^Is_CE=false}', "");
Expect(0, 119233, '\P{Is_CE=false}', "");
Expect(1, 119233, '\P{^Is_CE=false}', "");
Expect(0, 119232, '\p{Is_CE=false}', "");
Expect(1, 119232, '\p{^Is_CE=false}', "");
Expect(1, 119232, '\P{Is_CE=false}', "");
Expect(0, 119232, '\P{^Is_CE=false}', "");
Expect(1, 119233, '\p{Is_CE=False}', "");
Expect(0, 119233, '\p{^Is_CE=False}', "");
Expect(0, 119233, '\P{Is_CE=False}', "");
Expect(1, 119233, '\P{^Is_CE=False}', "");
Expect(0, 119232, '\p{Is_CE=False}', "");
Expect(1, 119232, '\p{^Is_CE=False}', "");
Expect(1, 119232, '\P{Is_CE=False}', "");
Expect(0, 119232, '\P{^Is_CE=False}', "");
Error('\p{Composition_Exclusion=yes/a/}');
Error('\P{Composition_Exclusion=yes/a/}');
Expect(1, 119232, '\p{Composition_Exclusion=yes}', "");
Expect(0, 119232, '\p{^Composition_Exclusion=yes}', "");
Expect(0, 119232, '\P{Composition_Exclusion=yes}', "");
Expect(1, 119232, '\P{^Composition_Exclusion=yes}', "");
Expect(0, 119233, '\p{Composition_Exclusion=yes}', "");
Expect(1, 119233, '\p{^Composition_Exclusion=yes}', "");
Expect(1, 119233, '\P{Composition_Exclusion=yes}', "");
Expect(0, 119233, '\P{^Composition_Exclusion=yes}', "");
Expect(1, 119232, '\p{Composition_Exclusion=-yes}', "");
Expect(0, 119232, '\p{^Composition_Exclusion=-yes}', "");
Expect(0, 119232, '\P{Composition_Exclusion=-yes}', "");
Expect(1, 119232, '\P{^Composition_Exclusion=-yes}', "");
Expect(0, 119233, '\p{Composition_Exclusion=-yes}', "");
Expect(1, 119233, '\p{^Composition_Exclusion=-yes}', "");
Expect(1, 119233, '\P{Composition_Exclusion=-yes}', "");
Expect(0, 119233, '\P{^Composition_Exclusion=-yes}', "");
Error('\p{CE:	_:=Y}');
Error('\P{CE:	_:=Y}');
Expect(1, 119232, '\p{CE=y}', "");
Expect(0, 119232, '\p{^CE=y}', "");
Expect(0, 119232, '\P{CE=y}', "");
Expect(1, 119232, '\P{^CE=y}', "");
Expect(0, 119233, '\p{CE=y}', "");
Expect(1, 119233, '\p{^CE=y}', "");
Expect(1, 119233, '\P{CE=y}', "");
Expect(0, 119233, '\P{^CE=y}', "");
Expect(1, 119232, '\p{CE= Y}', "");
Expect(0, 119232, '\p{^CE= Y}', "");
Expect(0, 119232, '\P{CE= Y}', "");
Expect(1, 119232, '\P{^CE= Y}', "");
Expect(0, 119233, '\p{CE= Y}', "");
Expect(1, 119233, '\p{^CE= Y}', "");
Expect(1, 119233, '\P{CE= Y}', "");
Expect(0, 119233, '\P{^CE= Y}', "");
Error('\p{Is_Composition_Exclusion:	 :=T}');
Error('\P{Is_Composition_Exclusion:	 :=T}');
Expect(1, 119232, '\p{Is_Composition_Exclusion=t}', "");
Expect(0, 119232, '\p{^Is_Composition_Exclusion=t}', "");
Expect(0, 119232, '\P{Is_Composition_Exclusion=t}', "");
Expect(1, 119232, '\P{^Is_Composition_Exclusion=t}', "");
Expect(0, 119233, '\p{Is_Composition_Exclusion=t}', "");
Expect(1, 119233, '\p{^Is_Composition_Exclusion=t}', "");
Expect(1, 119233, '\P{Is_Composition_Exclusion=t}', "");
Expect(0, 119233, '\P{^Is_Composition_Exclusion=t}', "");
Expect(1, 119232, '\p{Is_Composition_Exclusion=_	T}', "");
Expect(0, 119232, '\p{^Is_Composition_Exclusion=_	T}', "");
Expect(0, 119232, '\P{Is_Composition_Exclusion=_	T}', "");
Expect(1, 119232, '\P{^Is_Composition_Exclusion=_	T}', "");
Expect(0, 119233, '\p{Is_Composition_Exclusion=_	T}', "");
Expect(1, 119233, '\p{^Is_Composition_Exclusion=_	T}', "");
Expect(1, 119233, '\P{Is_Composition_Exclusion=_	T}', "");
Expect(0, 119233, '\P{^Is_Composition_Exclusion=_	T}', "");
Error('\p{Is_CE=:=True}');
Error('\P{Is_CE=:=True}');
Expect(1, 119232, '\p{Is_CE=true}', "");
Expect(0, 119232, '\p{^Is_CE=true}', "");
Expect(0, 119232, '\P{Is_CE=true}', "");
Expect(1, 119232, '\P{^Is_CE=true}', "");
Expect(0, 119233, '\p{Is_CE=true}', "");
Expect(1, 119233, '\p{^Is_CE=true}', "");
Expect(1, 119233, '\P{Is_CE=true}', "");
Expect(0, 119233, '\P{^Is_CE=true}', "");
Expect(1, 119232, '\p{Is_CE=_ TRUE}', "");
Expect(0, 119232, '\p{^Is_CE=_ TRUE}', "");
Expect(0, 119232, '\P{Is_CE=_ TRUE}', "");
Expect(1, 119232, '\P{^Is_CE=_ TRUE}', "");
Expect(0, 119233, '\p{Is_CE=_ TRUE}', "");
Expect(1, 119233, '\p{^Is_CE=_ TRUE}', "");
Expect(1, 119233, '\P{Is_CE=_ TRUE}', "");
Expect(0, 119233, '\P{^Is_CE=_ TRUE}', "");
Error('\p{Case_Ignorable=-	NO:=}');
Error('\P{Case_Ignorable=-	NO:=}');
Expect(1, 918000, '\p{Case_Ignorable: no}', "");
Expect(0, 918000, '\p{^Case_Ignorable: no}', "");
Expect(0, 918000, '\P{Case_Ignorable: no}', "");
Expect(1, 918000, '\P{^Case_Ignorable: no}', "");
Expect(0, 917999, '\p{Case_Ignorable: no}', "");
Expect(1, 917999, '\p{^Case_Ignorable: no}', "");
Expect(1, 917999, '\P{Case_Ignorable: no}', "");
Expect(0, 917999, '\P{^Case_Ignorable: no}', "");
Expect(1, 918000, '\p{Case_Ignorable=__No}', "");
Expect(0, 918000, '\p{^Case_Ignorable=__No}', "");
Expect(0, 918000, '\P{Case_Ignorable=__No}', "");
Expect(1, 918000, '\P{^Case_Ignorable=__No}', "");
Expect(0, 917999, '\p{Case_Ignorable=__No}', "");
Expect(1, 917999, '\p{^Case_Ignorable=__No}', "");
Expect(1, 917999, '\P{Case_Ignorable=__No}', "");
Expect(0, 917999, '\P{^Case_Ignorable=__No}', "");
Error('\p{CI:   -n/a/}');
Error('\P{CI:   -n/a/}');
Expect(1, 918000, '\p{CI=n}', "");
Expect(0, 918000, '\p{^CI=n}', "");
Expect(0, 918000, '\P{CI=n}', "");
Expect(1, 918000, '\P{^CI=n}', "");
Expect(0, 917999, '\p{CI=n}', "");
Expect(1, 917999, '\p{^CI=n}', "");
Expect(1, 917999, '\P{CI=n}', "");
Expect(0, 917999, '\P{^CI=n}', "");
Expect(1, 918000, '\p{CI= _N}', "");
Expect(0, 918000, '\p{^CI= _N}', "");
Expect(0, 918000, '\P{CI= _N}', "");
Expect(1, 918000, '\P{^CI= _N}', "");
Expect(0, 917999, '\p{CI= _N}', "");
Expect(1, 917999, '\p{^CI= _N}', "");
Expect(1, 917999, '\P{CI= _N}', "");
Expect(0, 917999, '\P{^CI= _N}', "");
Error('\p{Is_Case_Ignorable=/a/-	f}');
Error('\P{Is_Case_Ignorable=/a/-	f}');
Expect(1, 918000, '\p{Is_Case_Ignorable=f}', "");
Expect(0, 918000, '\p{^Is_Case_Ignorable=f}', "");
Expect(0, 918000, '\P{Is_Case_Ignorable=f}', "");
Expect(1, 918000, '\P{^Is_Case_Ignorable=f}', "");
Expect(0, 917999, '\p{Is_Case_Ignorable=f}', "");
Expect(1, 917999, '\p{^Is_Case_Ignorable=f}', "");
Expect(1, 917999, '\P{Is_Case_Ignorable=f}', "");
Expect(0, 917999, '\P{^Is_Case_Ignorable=f}', "");
Expect(1, 918000, '\p{Is_Case_Ignorable=	f}', "");
Expect(0, 918000, '\p{^Is_Case_Ignorable=	f}', "");
Expect(0, 918000, '\P{Is_Case_Ignorable=	f}', "");
Expect(1, 918000, '\P{^Is_Case_Ignorable=	f}', "");
Expect(0, 917999, '\p{Is_Case_Ignorable=	f}', "");
Expect(1, 917999, '\p{^Is_Case_Ignorable=	f}', "");
Expect(1, 917999, '\P{Is_Case_Ignorable=	f}', "");
Expect(0, 917999, '\P{^Is_Case_Ignorable=	f}', "");
Error('\p{Is_CI=/a/_	False}');
Error('\P{Is_CI=/a/_	False}');
Expect(1, 918000, '\p{Is_CI:false}', "");
Expect(0, 918000, '\p{^Is_CI:false}', "");
Expect(0, 918000, '\P{Is_CI:false}', "");
Expect(1, 918000, '\P{^Is_CI:false}', "");
Expect(0, 917999, '\p{Is_CI:false}', "");
Expect(1, 917999, '\p{^Is_CI:false}', "");
Expect(1, 917999, '\P{Is_CI:false}', "");
Expect(0, 917999, '\P{^Is_CI:false}', "");
Expect(1, 918000, '\p{Is_CI= false}', "");
Expect(0, 918000, '\p{^Is_CI= false}', "");
Expect(0, 918000, '\P{Is_CI= false}', "");
Expect(1, 918000, '\P{^Is_CI= false}', "");
Expect(0, 917999, '\p{Is_CI= false}', "");
Expect(1, 917999, '\p{^Is_CI= false}', "");
Expect(1, 917999, '\P{Is_CI= false}', "");
Expect(0, 917999, '\P{^Is_CI= false}', "");
Error('\p{Case_Ignorable=/a/yes}');
Error('\P{Case_Ignorable=/a/yes}');
Expect(1, 917999, '\p{Case_Ignorable=yes}', "");
Expect(0, 917999, '\p{^Case_Ignorable=yes}', "");
Expect(0, 917999, '\P{Case_Ignorable=yes}', "");
Expect(1, 917999, '\P{^Case_Ignorable=yes}', "");
Expect(0, 918000, '\p{Case_Ignorable=yes}', "");
Expect(1, 918000, '\p{^Case_Ignorable=yes}', "");
Expect(1, 918000, '\P{Case_Ignorable=yes}', "");
Expect(0, 918000, '\P{^Case_Ignorable=yes}', "");
Expect(1, 917999, '\p{Case_Ignorable=	-Yes}', "");
Expect(0, 917999, '\p{^Case_Ignorable=	-Yes}', "");
Expect(0, 917999, '\P{Case_Ignorable=	-Yes}', "");
Expect(1, 917999, '\P{^Case_Ignorable=	-Yes}', "");
Expect(0, 918000, '\p{Case_Ignorable=	-Yes}', "");
Expect(1, 918000, '\p{^Case_Ignorable=	-Yes}', "");
Expect(1, 918000, '\P{Case_Ignorable=	-Yes}', "");
Expect(0, 918000, '\P{^Case_Ignorable=	-Yes}', "");
Error('\p{CI= _Y:=}');
Error('\P{CI= _Y:=}');
Expect(1, 917999, '\p{CI:y}', "");
Expect(0, 917999, '\p{^CI:y}', "");
Expect(0, 917999, '\P{CI:y}', "");
Expect(1, 917999, '\P{^CI:y}', "");
Expect(0, 918000, '\p{CI:y}', "");
Expect(1, 918000, '\p{^CI:y}', "");
Expect(1, 918000, '\P{CI:y}', "");
Expect(0, 918000, '\P{^CI:y}', "");
Expect(1, 917999, '\p{CI=_y}', "");
Expect(0, 917999, '\p{^CI=_y}', "");
Expect(0, 917999, '\P{CI=_y}', "");
Expect(1, 917999, '\P{^CI=_y}', "");
Expect(0, 918000, '\p{CI=_y}', "");
Expect(1, 918000, '\p{^CI=_y}', "");
Expect(1, 918000, '\P{CI=_y}', "");
Expect(0, 918000, '\P{^CI=_y}', "");
Error('\p{Is_Case_Ignorable=_:=T}');
Error('\P{Is_Case_Ignorable=_:=T}');
Expect(1, 917999, '\p{Is_Case_Ignorable=t}', "");
Expect(0, 917999, '\p{^Is_Case_Ignorable=t}', "");
Expect(0, 917999, '\P{Is_Case_Ignorable=t}', "");
Expect(1, 917999, '\P{^Is_Case_Ignorable=t}', "");
Expect(0, 918000, '\p{Is_Case_Ignorable=t}', "");
Expect(1, 918000, '\p{^Is_Case_Ignorable=t}', "");
Expect(1, 918000, '\P{Is_Case_Ignorable=t}', "");
Expect(0, 918000, '\P{^Is_Case_Ignorable=t}', "");
Expect(1, 917999, '\p{Is_Case_Ignorable: _-T}', "");
Expect(0, 917999, '\p{^Is_Case_Ignorable: _-T}', "");
Expect(0, 917999, '\P{Is_Case_Ignorable: _-T}', "");
Expect(1, 917999, '\P{^Is_Case_Ignorable: _-T}', "");
Expect(0, 918000, '\p{Is_Case_Ignorable: _-T}', "");
Expect(1, 918000, '\p{^Is_Case_Ignorable: _-T}', "");
Expect(1, 918000, '\P{Is_Case_Ignorable: _-T}', "");
Expect(0, 918000, '\P{^Is_Case_Ignorable: _-T}', "");
Error('\p{Is_CI= -True/a/}');
Error('\P{Is_CI= -True/a/}');
Expect(1, 917999, '\p{Is_CI=true}', "");
Expect(0, 917999, '\p{^Is_CI=true}', "");
Expect(0, 917999, '\P{Is_CI=true}', "");
Expect(1, 917999, '\P{^Is_CI=true}', "");
Expect(0, 918000, '\p{Is_CI=true}', "");
Expect(1, 918000, '\p{^Is_CI=true}', "");
Expect(1, 918000, '\P{Is_CI=true}', "");
Expect(0, 918000, '\P{^Is_CI=true}', "");
Expect(1, 917999, '\p{Is_CI=	 True}', "");
Expect(0, 917999, '\p{^Is_CI=	 True}', "");
Expect(0, 917999, '\P{Is_CI=	 True}', "");
Expect(1, 917999, '\P{^Is_CI=	 True}', "");
Expect(0, 918000, '\p{Is_CI=	 True}', "");
Expect(1, 918000, '\p{^Is_CI=	 True}', "");
Expect(1, 918000, '\P{Is_CI=	 True}', "");
Expect(0, 918000, '\P{^Is_CI=	 True}', "");
Error('\p{Changes_When_Casefolded=/a/	-No}');
Error('\P{Changes_When_Casefolded=/a/	-No}');
Expect(1, 66600, '\p{Changes_When_Casefolded=no}', "");
Expect(0, 66600, '\p{^Changes_When_Casefolded=no}', "");
Expect(0, 66600, '\P{Changes_When_Casefolded=no}', "");
Expect(1, 66600, '\P{^Changes_When_Casefolded=no}', "");
Expect(0, 66599, '\p{Changes_When_Casefolded=no}', "");
Expect(1, 66599, '\p{^Changes_When_Casefolded=no}', "");
Expect(1, 66599, '\P{Changes_When_Casefolded=no}', "");
Expect(0, 66599, '\P{^Changes_When_Casefolded=no}', "");
Expect(1, 66600, '\p{Changes_When_Casefolded=_-NO}', "");
Expect(0, 66600, '\p{^Changes_When_Casefolded=_-NO}', "");
Expect(0, 66600, '\P{Changes_When_Casefolded=_-NO}', "");
Expect(1, 66600, '\P{^Changes_When_Casefolded=_-NO}', "");
Expect(0, 66599, '\p{Changes_When_Casefolded=_-NO}', "");
Expect(1, 66599, '\p{^Changes_When_Casefolded=_-NO}', "");
Expect(1, 66599, '\P{Changes_When_Casefolded=_-NO}', "");
Expect(0, 66599, '\P{^Changes_When_Casefolded=_-NO}', "");
Error('\p{CWCF=/a/	-n}');
Error('\P{CWCF=/a/	-n}');
Expect(1, 66600, '\p{CWCF:	n}', "");
Expect(0, 66600, '\p{^CWCF:	n}', "");
Expect(0, 66600, '\P{CWCF:	n}', "");
Expect(1, 66600, '\P{^CWCF:	n}', "");
Expect(0, 66599, '\p{CWCF:	n}', "");
Expect(1, 66599, '\p{^CWCF:	n}', "");
Expect(1, 66599, '\P{CWCF:	n}', "");
Expect(0, 66599, '\P{^CWCF:	n}', "");
Expect(1, 66600, '\p{CWCF: __N}', "");
Expect(0, 66600, '\p{^CWCF: __N}', "");
Expect(0, 66600, '\P{CWCF: __N}', "");
Expect(1, 66600, '\P{^CWCF: __N}', "");
Expect(0, 66599, '\p{CWCF: __N}', "");
Expect(1, 66599, '\p{^CWCF: __N}', "");
Expect(1, 66599, '\P{CWCF: __N}', "");
Expect(0, 66599, '\P{^CWCF: __N}', "");
Error('\p{Is_Changes_When_Casefolded=:=	-f}');
Error('\P{Is_Changes_When_Casefolded=:=	-f}');
Expect(1, 66600, '\p{Is_Changes_When_Casefolded=f}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Casefolded=f}', "");
Expect(0, 66600, '\P{Is_Changes_When_Casefolded=f}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Casefolded=f}', "");
Expect(0, 66599, '\p{Is_Changes_When_Casefolded=f}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Casefolded=f}', "");
Expect(1, 66599, '\P{Is_Changes_When_Casefolded=f}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Casefolded=f}', "");
Expect(1, 66600, '\p{Is_Changes_When_Casefolded:  	f}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Casefolded:  	f}', "");
Expect(0, 66600, '\P{Is_Changes_When_Casefolded:  	f}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Casefolded:  	f}', "");
Expect(0, 66599, '\p{Is_Changes_When_Casefolded:  	f}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Casefolded:  	f}', "");
Expect(1, 66599, '\P{Is_Changes_When_Casefolded:  	f}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Casefolded:  	f}', "");
Error('\p{Is_CWCF:   -false:=}');
Error('\P{Is_CWCF:   -false:=}');
Expect(1, 66600, '\p{Is_CWCF=false}', "");
Expect(0, 66600, '\p{^Is_CWCF=false}', "");
Expect(0, 66600, '\P{Is_CWCF=false}', "");
Expect(1, 66600, '\P{^Is_CWCF=false}', "");
Expect(0, 66599, '\p{Is_CWCF=false}', "");
Expect(1, 66599, '\p{^Is_CWCF=false}', "");
Expect(1, 66599, '\P{Is_CWCF=false}', "");
Expect(0, 66599, '\P{^Is_CWCF=false}', "");
Expect(1, 66600, '\p{Is_CWCF:	_-false}', "");
Expect(0, 66600, '\p{^Is_CWCF:	_-false}', "");
Expect(0, 66600, '\P{Is_CWCF:	_-false}', "");
Expect(1, 66600, '\P{^Is_CWCF:	_-false}', "");
Expect(0, 66599, '\p{Is_CWCF:	_-false}', "");
Expect(1, 66599, '\p{^Is_CWCF:	_-false}', "");
Expect(1, 66599, '\P{Is_CWCF:	_-false}', "");
Expect(0, 66599, '\P{^Is_CWCF:	_-false}', "");
Error('\p{Changes_When_Casefolded=/a/-_yes}');
Error('\P{Changes_When_Casefolded=/a/-_yes}');
Expect(1, 66599, '\p{Changes_When_Casefolded=yes}', "");
Expect(0, 66599, '\p{^Changes_When_Casefolded=yes}', "");
Expect(0, 66599, '\P{Changes_When_Casefolded=yes}', "");
Expect(1, 66599, '\P{^Changes_When_Casefolded=yes}', "");
Expect(0, 66600, '\p{Changes_When_Casefolded=yes}', "");
Expect(1, 66600, '\p{^Changes_When_Casefolded=yes}', "");
Expect(1, 66600, '\P{Changes_When_Casefolded=yes}', "");
Expect(0, 66600, '\P{^Changes_When_Casefolded=yes}', "");
Expect(1, 66599, '\p{Changes_When_Casefolded=_-yes}', "");
Expect(0, 66599, '\p{^Changes_When_Casefolded=_-yes}', "");
Expect(0, 66599, '\P{Changes_When_Casefolded=_-yes}', "");
Expect(1, 66599, '\P{^Changes_When_Casefolded=_-yes}', "");
Expect(0, 66600, '\p{Changes_When_Casefolded=_-yes}', "");
Expect(1, 66600, '\p{^Changes_When_Casefolded=_-yes}', "");
Expect(1, 66600, '\P{Changes_When_Casefolded=_-yes}', "");
Expect(0, 66600, '\P{^Changes_When_Casefolded=_-yes}', "");
Error('\p{CWCF=	Y:=}');
Error('\P{CWCF=	Y:=}');
Expect(1, 66599, '\p{CWCF=y}', "");
Expect(0, 66599, '\p{^CWCF=y}', "");
Expect(0, 66599, '\P{CWCF=y}', "");
Expect(1, 66599, '\P{^CWCF=y}', "");
Expect(0, 66600, '\p{CWCF=y}', "");
Expect(1, 66600, '\p{^CWCF=y}', "");
Expect(1, 66600, '\P{CWCF=y}', "");
Expect(0, 66600, '\P{^CWCF=y}', "");
Expect(1, 66599, '\p{CWCF=_ Y}', "");
Expect(0, 66599, '\p{^CWCF=_ Y}', "");
Expect(0, 66599, '\P{CWCF=_ Y}', "");
Expect(1, 66599, '\P{^CWCF=_ Y}', "");
Expect(0, 66600, '\p{CWCF=_ Y}', "");
Expect(1, 66600, '\p{^CWCF=_ Y}', "");
Expect(1, 66600, '\P{CWCF=_ Y}', "");
Expect(0, 66600, '\P{^CWCF=_ Y}', "");
Error('\p{Is_Changes_When_Casefolded=:=	-T}');
Error('\P{Is_Changes_When_Casefolded=:=	-T}');
Expect(1, 66599, '\p{Is_Changes_When_Casefolded=t}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Casefolded=t}', "");
Expect(0, 66599, '\P{Is_Changes_When_Casefolded=t}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Casefolded=t}', "");
Expect(0, 66600, '\p{Is_Changes_When_Casefolded=t}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Casefolded=t}', "");
Expect(1, 66600, '\P{Is_Changes_When_Casefolded=t}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Casefolded=t}', "");
Expect(1, 66599, '\p{Is_Changes_When_Casefolded=- T}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Casefolded=- T}', "");
Expect(0, 66599, '\P{Is_Changes_When_Casefolded=- T}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Casefolded=- T}', "");
Expect(0, 66600, '\p{Is_Changes_When_Casefolded=- T}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Casefolded=- T}', "");
Expect(1, 66600, '\P{Is_Changes_When_Casefolded=- T}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Casefolded=- T}', "");
Error('\p{Is_CWCF=:=True}');
Error('\P{Is_CWCF=:=True}');
Expect(1, 66599, '\p{Is_CWCF=true}', "");
Expect(0, 66599, '\p{^Is_CWCF=true}', "");
Expect(0, 66599, '\P{Is_CWCF=true}', "");
Expect(1, 66599, '\P{^Is_CWCF=true}', "");
Expect(0, 66600, '\p{Is_CWCF=true}', "");
Expect(1, 66600, '\p{^Is_CWCF=true}', "");
Expect(1, 66600, '\P{Is_CWCF=true}', "");
Expect(0, 66600, '\P{^Is_CWCF=true}', "");
Expect(1, 66599, '\p{Is_CWCF=	 True}', "");
Expect(0, 66599, '\p{^Is_CWCF=	 True}', "");
Expect(0, 66599, '\P{Is_CWCF=	 True}', "");
Expect(1, 66599, '\P{^Is_CWCF=	 True}', "");
Expect(0, 66600, '\p{Is_CWCF=	 True}', "");
Expect(1, 66600, '\p{^Is_CWCF=	 True}', "");
Expect(1, 66600, '\P{Is_CWCF=	 True}', "");
Expect(0, 66600, '\P{^Is_CWCF=	 True}', "");
Error('\p{Changes_When_Casemapped=/a/No}');
Error('\P{Changes_When_Casemapped=/a/No}');
Expect(1, 66640, '\p{Changes_When_Casemapped=no}', "");
Expect(0, 66640, '\p{^Changes_When_Casemapped=no}', "");
Expect(0, 66640, '\P{Changes_When_Casemapped=no}', "");
Expect(1, 66640, '\P{^Changes_When_Casemapped=no}', "");
Expect(0, 66639, '\p{Changes_When_Casemapped=no}', "");
Expect(1, 66639, '\p{^Changes_When_Casemapped=no}', "");
Expect(1, 66639, '\P{Changes_When_Casemapped=no}', "");
Expect(0, 66639, '\P{^Changes_When_Casemapped=no}', "");
Expect(1, 66640, '\p{Changes_When_Casemapped=--NO}', "");
Expect(0, 66640, '\p{^Changes_When_Casemapped=--NO}', "");
Expect(0, 66640, '\P{Changes_When_Casemapped=--NO}', "");
Expect(1, 66640, '\P{^Changes_When_Casemapped=--NO}', "");
Expect(0, 66639, '\p{Changes_When_Casemapped=--NO}', "");
Expect(1, 66639, '\p{^Changes_When_Casemapped=--NO}', "");
Expect(1, 66639, '\P{Changes_When_Casemapped=--NO}', "");
Expect(0, 66639, '\P{^Changes_When_Casemapped=--NO}', "");
Error('\p{CWCM=:=-N}');
Error('\P{CWCM=:=-N}');
Expect(1, 66640, '\p{CWCM=n}', "");
Expect(0, 66640, '\p{^CWCM=n}', "");
Expect(0, 66640, '\P{CWCM=n}', "");
Expect(1, 66640, '\P{^CWCM=n}', "");
Expect(0, 66639, '\p{CWCM=n}', "");
Expect(1, 66639, '\p{^CWCM=n}', "");
Expect(1, 66639, '\P{CWCM=n}', "");
Expect(0, 66639, '\P{^CWCM=n}', "");
Expect(1, 66640, '\p{CWCM=-N}', "");
Expect(0, 66640, '\p{^CWCM=-N}', "");
Expect(0, 66640, '\P{CWCM=-N}', "");
Expect(1, 66640, '\P{^CWCM=-N}', "");
Expect(0, 66639, '\p{CWCM=-N}', "");
Expect(1, 66639, '\p{^CWCM=-N}', "");
Expect(1, 66639, '\P{CWCM=-N}', "");
Expect(0, 66639, '\P{^CWCM=-N}', "");
Error('\p{Is_Changes_When_Casemapped=-f/a/}');
Error('\P{Is_Changes_When_Casemapped=-f/a/}');
Expect(1, 66640, '\p{Is_Changes_When_Casemapped=f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Casemapped=f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Casemapped=f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Casemapped=f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Casemapped=f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Casemapped=f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Casemapped=f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Casemapped=f}', "");
Expect(1, 66640, '\p{Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66640, '\P{Is_Changes_When_Casemapped=--F}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66639, '\p{Is_Changes_When_Casemapped=--F}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Casemapped=--F}', "");
Expect(1, 66639, '\P{Is_Changes_When_Casemapped=--F}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Casemapped=--F}', "");
Error('\p{Is_CWCM= :=False}');
Error('\P{Is_CWCM= :=False}');
Expect(1, 66640, '\p{Is_CWCM=false}', "");
Expect(0, 66640, '\p{^Is_CWCM=false}', "");
Expect(0, 66640, '\P{Is_CWCM=false}', "");
Expect(1, 66640, '\P{^Is_CWCM=false}', "");
Expect(0, 66639, '\p{Is_CWCM=false}', "");
Expect(1, 66639, '\p{^Is_CWCM=false}', "");
Expect(1, 66639, '\P{Is_CWCM=false}', "");
Expect(0, 66639, '\P{^Is_CWCM=false}', "");
Expect(1, 66640, '\p{Is_CWCM=--false}', "");
Expect(0, 66640, '\p{^Is_CWCM=--false}', "");
Expect(0, 66640, '\P{Is_CWCM=--false}', "");
Expect(1, 66640, '\P{^Is_CWCM=--false}', "");
Expect(0, 66639, '\p{Is_CWCM=--false}', "");
Expect(1, 66639, '\p{^Is_CWCM=--false}', "");
Expect(1, 66639, '\P{Is_CWCM=--false}', "");
Expect(0, 66639, '\P{^Is_CWCM=--false}', "");
Error('\p{Changes_When_Casemapped=/a/Yes}');
Error('\P{Changes_When_Casemapped=/a/Yes}');
Expect(1, 66639, '\p{Changes_When_Casemapped=yes}', "");
Expect(0, 66639, '\p{^Changes_When_Casemapped=yes}', "");
Expect(0, 66639, '\P{Changes_When_Casemapped=yes}', "");
Expect(1, 66639, '\P{^Changes_When_Casemapped=yes}', "");
Expect(0, 66640, '\p{Changes_When_Casemapped=yes}', "");
Expect(1, 66640, '\p{^Changes_When_Casemapped=yes}', "");
Expect(1, 66640, '\P{Changes_When_Casemapped=yes}', "");
Expect(0, 66640, '\P{^Changes_When_Casemapped=yes}', "");
Expect(1, 66639, '\p{Changes_When_Casemapped= Yes}', "");
Expect(0, 66639, '\p{^Changes_When_Casemapped= Yes}', "");
Expect(0, 66639, '\P{Changes_When_Casemapped= Yes}', "");
Expect(1, 66639, '\P{^Changes_When_Casemapped= Yes}', "");
Expect(0, 66640, '\p{Changes_When_Casemapped= Yes}', "");
Expect(1, 66640, '\p{^Changes_When_Casemapped= Yes}', "");
Expect(1, 66640, '\P{Changes_When_Casemapped= Yes}', "");
Expect(0, 66640, '\P{^Changes_When_Casemapped= Yes}', "");
Error('\p{CWCM=_	y/a/}');
Error('\P{CWCM=_	y/a/}');
Expect(1, 66639, '\p{CWCM=y}', "");
Expect(0, 66639, '\p{^CWCM=y}', "");
Expect(0, 66639, '\P{CWCM=y}', "");
Expect(1, 66639, '\P{^CWCM=y}', "");
Expect(0, 66640, '\p{CWCM=y}', "");
Expect(1, 66640, '\p{^CWCM=y}', "");
Expect(1, 66640, '\P{CWCM=y}', "");
Expect(0, 66640, '\P{^CWCM=y}', "");
Expect(1, 66639, '\p{CWCM=		Y}', "");
Expect(0, 66639, '\p{^CWCM=		Y}', "");
Expect(0, 66639, '\P{CWCM=		Y}', "");
Expect(1, 66639, '\P{^CWCM=		Y}', "");
Expect(0, 66640, '\p{CWCM=		Y}', "");
Expect(1, 66640, '\p{^CWCM=		Y}', "");
Expect(1, 66640, '\P{CWCM=		Y}', "");
Expect(0, 66640, '\P{^CWCM=		Y}', "");
Error('\p{Is_Changes_When_Casemapped=/a/T}');
Error('\P{Is_Changes_When_Casemapped=/a/T}');
Expect(1, 66639, '\p{Is_Changes_When_Casemapped=t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Casemapped=t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Casemapped=t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Casemapped=t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Casemapped=t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Casemapped=t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Casemapped=t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Casemapped=t}', "");
Expect(1, 66639, '\p{Is_Changes_When_Casemapped=_T}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Casemapped=_T}', "");
Expect(0, 66639, '\P{Is_Changes_When_Casemapped=_T}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Casemapped=_T}', "");
Expect(0, 66640, '\p{Is_Changes_When_Casemapped=_T}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Casemapped=_T}', "");
Expect(1, 66640, '\P{Is_Changes_When_Casemapped=_T}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Casemapped=_T}', "");
Error('\p{Is_CWCM=/a/ -TRUE}');
Error('\P{Is_CWCM=/a/ -TRUE}');
Expect(1, 66639, '\p{Is_CWCM=true}', "");
Expect(0, 66639, '\p{^Is_CWCM=true}', "");
Expect(0, 66639, '\P{Is_CWCM=true}', "");
Expect(1, 66639, '\P{^Is_CWCM=true}', "");
Expect(0, 66640, '\p{Is_CWCM=true}', "");
Expect(1, 66640, '\p{^Is_CWCM=true}', "");
Expect(1, 66640, '\P{Is_CWCM=true}', "");
Expect(0, 66640, '\P{^Is_CWCM=true}', "");
Expect(1, 66639, '\p{Is_CWCM=-true}', "");
Expect(0, 66639, '\p{^Is_CWCM=-true}', "");
Expect(0, 66639, '\P{Is_CWCM=-true}', "");
Expect(1, 66639, '\P{^Is_CWCM=-true}', "");
Expect(0, 66640, '\p{Is_CWCM=-true}', "");
Expect(1, 66640, '\p{^Is_CWCM=-true}', "");
Expect(1, 66640, '\P{Is_CWCM=-true}', "");
Expect(0, 66640, '\P{^Is_CWCM=-true}', "");
Error('\p{Changes_When_NFKC_Casefolded= /a/no}');
Error('\P{Changes_When_NFKC_Casefolded= /a/no}');
Expect(1, 921600, '\p{Changes_When_NFKC_Casefolded=no}', "");
Expect(0, 921600, '\p{^Changes_When_NFKC_Casefolded=no}', "");
Expect(0, 921600, '\P{Changes_When_NFKC_Casefolded=no}', "");
Expect(1, 921600, '\P{^Changes_When_NFKC_Casefolded=no}', "");
Expect(0, 921599, '\p{Changes_When_NFKC_Casefolded=no}', "");
Expect(1, 921599, '\p{^Changes_When_NFKC_Casefolded=no}', "");
Expect(1, 921599, '\P{Changes_When_NFKC_Casefolded=no}', "");
Expect(0, 921599, '\P{^Changes_When_NFKC_Casefolded=no}', "");
Expect(1, 921600, '\p{Changes_When_NFKC_Casefolded=No}', "");
Expect(0, 921600, '\p{^Changes_When_NFKC_Casefolded=No}', "");
Expect(0, 921600, '\P{Changes_When_NFKC_Casefolded=No}', "");
Expect(1, 921600, '\P{^Changes_When_NFKC_Casefolded=No}', "");
Expect(0, 921599, '\p{Changes_When_NFKC_Casefolded=No}', "");
Expect(1, 921599, '\p{^Changes_When_NFKC_Casefolded=No}', "");
Expect(1, 921599, '\P{Changes_When_NFKC_Casefolded=No}', "");
Expect(0, 921599, '\P{^Changes_When_NFKC_Casefolded=No}', "");
Error('\p{CWKCF=_N:=}');
Error('\P{CWKCF=_N:=}');
Expect(1, 921600, '\p{CWKCF=n}', "");
Expect(0, 921600, '\p{^CWKCF=n}', "");
Expect(0, 921600, '\P{CWKCF=n}', "");
Expect(1, 921600, '\P{^CWKCF=n}', "");
Expect(0, 921599, '\p{CWKCF=n}', "");
Expect(1, 921599, '\p{^CWKCF=n}', "");
Expect(1, 921599, '\P{CWKCF=n}', "");
Expect(0, 921599, '\P{^CWKCF=n}', "");
Expect(1, 921600, '\p{CWKCF=-n}', "");
Expect(0, 921600, '\p{^CWKCF=-n}', "");
Expect(0, 921600, '\P{CWKCF=-n}', "");
Expect(1, 921600, '\P{^CWKCF=-n}', "");
Expect(0, 921599, '\p{CWKCF=-n}', "");
Expect(1, 921599, '\p{^CWKCF=-n}', "");
Expect(1, 921599, '\P{CWKCF=-n}', "");
Expect(0, 921599, '\P{^CWKCF=-n}', "");
Error('\p{Is_Changes_When_NFKC_Casefolded= /a/F}');
Error('\P{Is_Changes_When_NFKC_Casefolded= /a/F}');
Expect(1, 921600, '\p{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921600, '\p{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921600, '\P{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921600, '\P{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921599, '\p{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921599, '\p{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921599, '\P{Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(0, 921599, '\P{^Is_Changes_When_NFKC_Casefolded=f}', "");
Expect(1, 921600, '\p{Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(0, 921600, '\p{^Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(0, 921600, '\P{Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(1, 921600, '\P{^Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(0, 921599, '\p{Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(1, 921599, '\p{^Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(1, 921599, '\P{Is_Changes_When_NFKC_Casefolded=	F}', "");
Expect(0, 921599, '\P{^Is_Changes_When_NFKC_Casefolded=	F}', "");
Error('\p{Is_CWKCF=/a/__FALSE}');
Error('\P{Is_CWKCF=/a/__FALSE}');
Expect(1, 921600, '\p{Is_CWKCF=false}', "");
Expect(0, 921600, '\p{^Is_CWKCF=false}', "");
Expect(0, 921600, '\P{Is_CWKCF=false}', "");
Expect(1, 921600, '\P{^Is_CWKCF=false}', "");
Expect(0, 921599, '\p{Is_CWKCF=false}', "");
Expect(1, 921599, '\p{^Is_CWKCF=false}', "");
Expect(1, 921599, '\P{Is_CWKCF=false}', "");
Expect(0, 921599, '\P{^Is_CWKCF=false}', "");
Expect(1, 921600, '\p{Is_CWKCF= -FALSE}', "");
Expect(0, 921600, '\p{^Is_CWKCF= -FALSE}', "");
Expect(0, 921600, '\P{Is_CWKCF= -FALSE}', "");
Expect(1, 921600, '\P{^Is_CWKCF= -FALSE}', "");
Expect(0, 921599, '\p{Is_CWKCF= -FALSE}', "");
Expect(1, 921599, '\p{^Is_CWKCF= -FALSE}', "");
Expect(1, 921599, '\P{Is_CWKCF= -FALSE}', "");
Expect(0, 921599, '\P{^Is_CWKCF= -FALSE}', "");
Error('\p{Changes_When_NFKC_Casefolded=/a/_ yes}');
Error('\P{Changes_When_NFKC_Casefolded=/a/_ yes}');
Expect(1, 921599, '\p{Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921599, '\p{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921599, '\P{Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921599, '\P{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921600, '\p{Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921600, '\p{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921600, '\P{Changes_When_NFKC_Casefolded=yes}', "");
Expect(0, 921600, '\P{^Changes_When_NFKC_Casefolded=yes}', "");
Expect(1, 921599, '\p{Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(0, 921599, '\p{^Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(0, 921599, '\P{Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(1, 921599, '\P{^Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(0, 921600, '\p{Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(1, 921600, '\p{^Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(1, 921600, '\P{Changes_When_NFKC_Casefolded= 	YES}', "");
Expect(0, 921600, '\P{^Changes_When_NFKC_Casefolded= 	YES}', "");
Error('\p{CWKCF=:=_-Y}');
Error('\P{CWKCF=:=_-Y}');
Expect(1, 921599, '\p{CWKCF=y}', "");
Expect(0, 921599, '\p{^CWKCF=y}', "");
Expect(0, 921599, '\P{CWKCF=y}', "");
Expect(1, 921599, '\P{^CWKCF=y}', "");
Expect(0, 921600, '\p{CWKCF=y}', "");
Expect(1, 921600, '\p{^CWKCF=y}', "");
Expect(1, 921600, '\P{CWKCF=y}', "");
Expect(0, 921600, '\P{^CWKCF=y}', "");
Expect(1, 921599, '\p{CWKCF=_y}', "");
Expect(0, 921599, '\p{^CWKCF=_y}', "");
Expect(0, 921599, '\P{CWKCF=_y}', "");
Expect(1, 921599, '\P{^CWKCF=_y}', "");
Expect(0, 921600, '\p{CWKCF=_y}', "");
Expect(1, 921600, '\p{^CWKCF=_y}', "");
Expect(1, 921600, '\P{CWKCF=_y}', "");
Expect(0, 921600, '\P{^CWKCF=_y}', "");
Error('\p{Is_Changes_When_NFKC_Casefolded=:=t}');
Error('\P{Is_Changes_When_NFKC_Casefolded=:=t}');
Expect(1, 921599, '\p{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921599, '\p{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921599, '\P{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921599, '\P{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921600, '\p{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921600, '\p{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921600, '\P{Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(0, 921600, '\P{^Is_Changes_When_NFKC_Casefolded=t}', "");
Expect(1, 921599, '\p{Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(0, 921599, '\p{^Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(0, 921599, '\P{Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(1, 921599, '\P{^Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(0, 921600, '\p{Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(1, 921600, '\p{^Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(1, 921600, '\P{Is_Changes_When_NFKC_Casefolded=_ t}', "");
Expect(0, 921600, '\P{^Is_Changes_When_NFKC_Casefolded=_ t}', "");
Error('\p{Is_CWKCF=-:=TRUE}');
Error('\P{Is_CWKCF=-:=TRUE}');
Expect(1, 921599, '\p{Is_CWKCF=true}', "");
Expect(0, 921599, '\p{^Is_CWKCF=true}', "");
Expect(0, 921599, '\P{Is_CWKCF=true}', "");
Expect(1, 921599, '\P{^Is_CWKCF=true}', "");
Expect(0, 921600, '\p{Is_CWKCF=true}', "");
Expect(1, 921600, '\p{^Is_CWKCF=true}', "");
Expect(1, 921600, '\P{Is_CWKCF=true}', "");
Expect(0, 921600, '\P{^Is_CWKCF=true}', "");
Expect(1, 921599, '\p{Is_CWKCF=-true}', "");
Expect(0, 921599, '\p{^Is_CWKCF=-true}', "");
Expect(0, 921599, '\P{Is_CWKCF=-true}', "");
Expect(1, 921599, '\P{^Is_CWKCF=-true}', "");
Expect(0, 921600, '\p{Is_CWKCF=-true}', "");
Expect(1, 921600, '\p{^Is_CWKCF=-true}', "");
Expect(1, 921600, '\P{Is_CWKCF=-true}', "");
Expect(0, 921600, '\P{^Is_CWKCF=-true}', "");
Error('\p{Changes_When_Lowercased= NO:=}');
Error('\P{Changes_When_Lowercased= NO:=}');
Expect(1, 66600, '\p{Changes_When_Lowercased=no}', "");
Expect(0, 66600, '\p{^Changes_When_Lowercased=no}', "");
Expect(0, 66600, '\P{Changes_When_Lowercased=no}', "");
Expect(1, 66600, '\P{^Changes_When_Lowercased=no}', "");
Expect(0, 66599, '\p{Changes_When_Lowercased=no}', "");
Expect(1, 66599, '\p{^Changes_When_Lowercased=no}', "");
Expect(1, 66599, '\P{Changes_When_Lowercased=no}', "");
Expect(0, 66599, '\P{^Changes_When_Lowercased=no}', "");
Expect(1, 66600, '\p{Changes_When_Lowercased=	No}', "");
Expect(0, 66600, '\p{^Changes_When_Lowercased=	No}', "");
Expect(0, 66600, '\P{Changes_When_Lowercased=	No}', "");
Expect(1, 66600, '\P{^Changes_When_Lowercased=	No}', "");
Expect(0, 66599, '\p{Changes_When_Lowercased=	No}', "");
Expect(1, 66599, '\p{^Changes_When_Lowercased=	No}', "");
Expect(1, 66599, '\P{Changes_When_Lowercased=	No}', "");
Expect(0, 66599, '\P{^Changes_When_Lowercased=	No}', "");
Error('\p{CWL=/a/ N}');
Error('\P{CWL=/a/ N}');
Expect(1, 66600, '\p{CWL=n}', "");
Expect(0, 66600, '\p{^CWL=n}', "");
Expect(0, 66600, '\P{CWL=n}', "");
Expect(1, 66600, '\P{^CWL=n}', "");
Expect(0, 66599, '\p{CWL=n}', "");
Expect(1, 66599, '\p{^CWL=n}', "");
Expect(1, 66599, '\P{CWL=n}', "");
Expect(0, 66599, '\P{^CWL=n}', "");
Expect(1, 66600, '\p{CWL:- N}', "");
Expect(0, 66600, '\p{^CWL:- N}', "");
Expect(0, 66600, '\P{CWL:- N}', "");
Expect(1, 66600, '\P{^CWL:- N}', "");
Expect(0, 66599, '\p{CWL:- N}', "");
Expect(1, 66599, '\p{^CWL:- N}', "");
Expect(1, 66599, '\P{CWL:- N}', "");
Expect(0, 66599, '\P{^CWL:- N}', "");
Error('\p{Is_Changes_When_Lowercased=/a/ 	f}');
Error('\P{Is_Changes_When_Lowercased=/a/ 	f}');
Expect(1, 66600, '\p{Is_Changes_When_Lowercased=f}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Lowercased=f}', "");
Expect(0, 66600, '\P{Is_Changes_When_Lowercased=f}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Lowercased=f}', "");
Expect(0, 66599, '\p{Is_Changes_When_Lowercased=f}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Lowercased=f}', "");
Expect(1, 66599, '\P{Is_Changes_When_Lowercased=f}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Lowercased=f}', "");
Expect(1, 66600, '\p{Is_Changes_When_Lowercased=F}', "");
Expect(0, 66600, '\p{^Is_Changes_When_Lowercased=F}', "");
Expect(0, 66600, '\P{Is_Changes_When_Lowercased=F}', "");
Expect(1, 66600, '\P{^Is_Changes_When_Lowercased=F}', "");
Expect(0, 66599, '\p{Is_Changes_When_Lowercased=F}', "");
Expect(1, 66599, '\p{^Is_Changes_When_Lowercased=F}', "");
Expect(1, 66599, '\P{Is_Changes_When_Lowercased=F}', "");
Expect(0, 66599, '\P{^Is_Changes_When_Lowercased=F}', "");
Error('\p{Is_CWL=:=	 false}');
Error('\P{Is_CWL=:=	 false}');
Expect(1, 66600, '\p{Is_CWL=false}', "");
Expect(0, 66600, '\p{^Is_CWL=false}', "");
Expect(0, 66600, '\P{Is_CWL=false}', "");
Expect(1, 66600, '\P{^Is_CWL=false}', "");
Expect(0, 66599, '\p{Is_CWL=false}', "");
Expect(1, 66599, '\p{^Is_CWL=false}', "");
Expect(1, 66599, '\P{Is_CWL=false}', "");
Expect(0, 66599, '\P{^Is_CWL=false}', "");
Expect(1, 66600, '\p{Is_CWL=-	False}', "");
Expect(0, 66600, '\p{^Is_CWL=-	False}', "");
Expect(0, 66600, '\P{Is_CWL=-	False}', "");
Expect(1, 66600, '\P{^Is_CWL=-	False}', "");
Expect(0, 66599, '\p{Is_CWL=-	False}', "");
Expect(1, 66599, '\p{^Is_CWL=-	False}', "");
Expect(1, 66599, '\P{Is_CWL=-	False}', "");
Expect(0, 66599, '\P{^Is_CWL=-	False}', "");
Error('\p{Changes_When_Lowercased=/a/yes}');
Error('\P{Changes_When_Lowercased=/a/yes}');
Expect(1, 66599, '\p{Changes_When_Lowercased=yes}', "");
Expect(0, 66599, '\p{^Changes_When_Lowercased=yes}', "");
Expect(0, 66599, '\P{Changes_When_Lowercased=yes}', "");
Expect(1, 66599, '\P{^Changes_When_Lowercased=yes}', "");
Expect(0, 66600, '\p{Changes_When_Lowercased=yes}', "");
Expect(1, 66600, '\p{^Changes_When_Lowercased=yes}', "");
Expect(1, 66600, '\P{Changes_When_Lowercased=yes}', "");
Expect(0, 66600, '\P{^Changes_When_Lowercased=yes}', "");
Expect(1, 66599, '\p{Changes_When_Lowercased=_-yes}', "");
Expect(0, 66599, '\p{^Changes_When_Lowercased=_-yes}', "");
Expect(0, 66599, '\P{Changes_When_Lowercased=_-yes}', "");
Expect(1, 66599, '\P{^Changes_When_Lowercased=_-yes}', "");
Expect(0, 66600, '\p{Changes_When_Lowercased=_-yes}', "");
Expect(1, 66600, '\p{^Changes_When_Lowercased=_-yes}', "");
Expect(1, 66600, '\P{Changes_When_Lowercased=_-yes}', "");
Expect(0, 66600, '\P{^Changes_When_Lowercased=_-yes}', "");
Error('\p{CWL:	:=_ Y}');
Error('\P{CWL:	:=_ Y}');
Expect(1, 66599, '\p{CWL:   y}', "");
Expect(0, 66599, '\p{^CWL:   y}', "");
Expect(0, 66599, '\P{CWL:   y}', "");
Expect(1, 66599, '\P{^CWL:   y}', "");
Expect(0, 66600, '\p{CWL:   y}', "");
Expect(1, 66600, '\p{^CWL:   y}', "");
Expect(1, 66600, '\P{CWL:   y}', "");
Expect(0, 66600, '\P{^CWL:   y}', "");
Expect(1, 66599, '\p{CWL=	_Y}', "");
Expect(0, 66599, '\p{^CWL=	_Y}', "");
Expect(0, 66599, '\P{CWL=	_Y}', "");
Expect(1, 66599, '\P{^CWL=	_Y}', "");
Expect(0, 66600, '\p{CWL=	_Y}', "");
Expect(1, 66600, '\p{^CWL=	_Y}', "");
Expect(1, 66600, '\P{CWL=	_Y}', "");
Expect(0, 66600, '\P{^CWL=	_Y}', "");
Error('\p{Is_Changes_When_Lowercased= :=T}');
Error('\P{Is_Changes_When_Lowercased= :=T}');
Expect(1, 66599, '\p{Is_Changes_When_Lowercased=t}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Lowercased=t}', "");
Expect(0, 66599, '\P{Is_Changes_When_Lowercased=t}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Lowercased=t}', "");
Expect(0, 66600, '\p{Is_Changes_When_Lowercased=t}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Lowercased=t}', "");
Expect(1, 66600, '\P{Is_Changes_When_Lowercased=t}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Lowercased=t}', "");
Expect(1, 66599, '\p{Is_Changes_When_Lowercased= -T}', "");
Expect(0, 66599, '\p{^Is_Changes_When_Lowercased= -T}', "");
Expect(0, 66599, '\P{Is_Changes_When_Lowercased= -T}', "");
Expect(1, 66599, '\P{^Is_Changes_When_Lowercased= -T}', "");
Expect(0, 66600, '\p{Is_Changes_When_Lowercased= -T}', "");
Expect(1, 66600, '\p{^Is_Changes_When_Lowercased= -T}', "");
Expect(1, 66600, '\P{Is_Changes_When_Lowercased= -T}', "");
Expect(0, 66600, '\P{^Is_Changes_When_Lowercased= -T}', "");
Error('\p{Is_CWL:  -True/a/}');
Error('\P{Is_CWL:  -True/a/}');
Expect(1, 66599, '\p{Is_CWL=true}', "");
Expect(0, 66599, '\p{^Is_CWL=true}', "");
Expect(0, 66599, '\P{Is_CWL=true}', "");
Expect(1, 66599, '\P{^Is_CWL=true}', "");
Expect(0, 66600, '\p{Is_CWL=true}', "");
Expect(1, 66600, '\p{^Is_CWL=true}', "");
Expect(1, 66600, '\P{Is_CWL=true}', "");
Expect(0, 66600, '\P{^Is_CWL=true}', "");
Expect(1, 66599, '\p{Is_CWL= 	True}', "");
Expect(0, 66599, '\p{^Is_CWL= 	True}', "");
Expect(0, 66599, '\P{Is_CWL= 	True}', "");
Expect(1, 66599, '\P{^Is_CWL= 	True}', "");
Expect(0, 66600, '\p{Is_CWL= 	True}', "");
Expect(1, 66600, '\p{^Is_CWL= 	True}', "");
Expect(1, 66600, '\P{Is_CWL= 	True}', "");
Expect(0, 66600, '\P{^Is_CWL= 	True}', "");
Error('\p{Changes_When_Titlecased=_	No:=}');
Error('\P{Changes_When_Titlecased=_	No:=}');
Expect(1, 66640, '\p{Changes_When_Titlecased=no}', "");
Expect(0, 66640, '\p{^Changes_When_Titlecased=no}', "");
Expect(0, 66640, '\P{Changes_When_Titlecased=no}', "");
Expect(1, 66640, '\P{^Changes_When_Titlecased=no}', "");
Expect(0, 66639, '\p{Changes_When_Titlecased=no}', "");
Expect(1, 66639, '\p{^Changes_When_Titlecased=no}', "");
Expect(1, 66639, '\P{Changes_When_Titlecased=no}', "");
Expect(0, 66639, '\P{^Changes_When_Titlecased=no}', "");
Expect(1, 66640, '\p{Changes_When_Titlecased=	_No}', "");
Expect(0, 66640, '\p{^Changes_When_Titlecased=	_No}', "");
Expect(0, 66640, '\P{Changes_When_Titlecased=	_No}', "");
Expect(1, 66640, '\P{^Changes_When_Titlecased=	_No}', "");
Expect(0, 66639, '\p{Changes_When_Titlecased=	_No}', "");
Expect(1, 66639, '\p{^Changes_When_Titlecased=	_No}', "");
Expect(1, 66639, '\P{Changes_When_Titlecased=	_No}', "");
Expect(0, 66639, '\P{^Changes_When_Titlecased=	_No}', "");
Error('\p{CWT=  N/a/}');
Error('\P{CWT=  N/a/}');
Expect(1, 66640, '\p{CWT=n}', "");
Expect(0, 66640, '\p{^CWT=n}', "");
Expect(0, 66640, '\P{CWT=n}', "");
Expect(1, 66640, '\P{^CWT=n}', "");
Expect(0, 66639, '\p{CWT=n}', "");
Expect(1, 66639, '\p{^CWT=n}', "");
Expect(1, 66639, '\P{CWT=n}', "");
Expect(0, 66639, '\P{^CWT=n}', "");
Expect(1, 66640, '\p{CWT=_-n}', "");
Expect(0, 66640, '\p{^CWT=_-n}', "");
Expect(0, 66640, '\P{CWT=_-n}', "");
Expect(1, 66640, '\P{^CWT=_-n}', "");
Expect(0, 66639, '\p{CWT=_-n}', "");
Expect(1, 66639, '\p{^CWT=_-n}', "");
Expect(1, 66639, '\P{CWT=_-n}', "");
Expect(0, 66639, '\P{^CWT=_-n}', "");
Error('\p{Is_Changes_When_Titlecased=_	f/a/}');
Error('\P{Is_Changes_When_Titlecased=_	f/a/}');
Expect(1, 66640, '\p{Is_Changes_When_Titlecased=f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Titlecased=f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Titlecased=f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Titlecased=f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Titlecased=f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Titlecased=f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Titlecased=f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Titlecased=f}', "");
Expect(1, 66640, '\p{Is_Changes_When_Titlecased=-f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Titlecased=-f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Titlecased=-f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Titlecased=-f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Titlecased=-f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Titlecased=-f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Titlecased=-f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Titlecased=-f}', "");
Error('\p{Is_CWT= FALSE/a/}');
Error('\P{Is_CWT= FALSE/a/}');
Expect(1, 66640, '\p{Is_CWT=false}', "");
Expect(0, 66640, '\p{^Is_CWT=false}', "");
Expect(0, 66640, '\P{Is_CWT=false}', "");
Expect(1, 66640, '\P{^Is_CWT=false}', "");
Expect(0, 66639, '\p{Is_CWT=false}', "");
Expect(1, 66639, '\p{^Is_CWT=false}', "");
Expect(1, 66639, '\P{Is_CWT=false}', "");
Expect(0, 66639, '\P{^Is_CWT=false}', "");
Expect(1, 66640, '\p{Is_CWT:   	False}', "");
Expect(0, 66640, '\p{^Is_CWT:   	False}', "");
Expect(0, 66640, '\P{Is_CWT:   	False}', "");
Expect(1, 66640, '\P{^Is_CWT:   	False}', "");
Expect(0, 66639, '\p{Is_CWT:   	False}', "");
Expect(1, 66639, '\p{^Is_CWT:   	False}', "");
Expect(1, 66639, '\P{Is_CWT:   	False}', "");
Expect(0, 66639, '\P{^Is_CWT:   	False}', "");
Error('\p{Changes_When_Titlecased=_Yes/a/}');
Error('\P{Changes_When_Titlecased=_Yes/a/}');
Expect(1, 66639, '\p{Changes_When_Titlecased=yes}', "");
Expect(0, 66639, '\p{^Changes_When_Titlecased=yes}', "");
Expect(0, 66639, '\P{Changes_When_Titlecased=yes}', "");
Expect(1, 66639, '\P{^Changes_When_Titlecased=yes}', "");
Expect(0, 66640, '\p{Changes_When_Titlecased=yes}', "");
Expect(1, 66640, '\p{^Changes_When_Titlecased=yes}', "");
Expect(1, 66640, '\P{Changes_When_Titlecased=yes}', "");
Expect(0, 66640, '\P{^Changes_When_Titlecased=yes}', "");
Expect(1, 66639, '\p{Changes_When_Titlecased=_Yes}', "");
Expect(0, 66639, '\p{^Changes_When_Titlecased=_Yes}', "");
Expect(0, 66639, '\P{Changes_When_Titlecased=_Yes}', "");
Expect(1, 66639, '\P{^Changes_When_Titlecased=_Yes}', "");
Expect(0, 66640, '\p{Changes_When_Titlecased=_Yes}', "");
Expect(1, 66640, '\p{^Changes_When_Titlecased=_Yes}', "");
Expect(1, 66640, '\P{Changes_When_Titlecased=_Yes}', "");
Expect(0, 66640, '\P{^Changes_When_Titlecased=_Yes}', "");
Error('\p{CWT=_/a/Y}');
Error('\P{CWT=_/a/Y}');
Expect(1, 66639, '\p{CWT=y}', "");
Expect(0, 66639, '\p{^CWT=y}', "");
Expect(0, 66639, '\P{CWT=y}', "");
Expect(1, 66639, '\P{^CWT=y}', "");
Expect(0, 66640, '\p{CWT=y}', "");
Expect(1, 66640, '\p{^CWT=y}', "");
Expect(1, 66640, '\P{CWT=y}', "");
Expect(0, 66640, '\P{^CWT=y}', "");
Expect(1, 66639, '\p{CWT= Y}', "");
Expect(0, 66639, '\p{^CWT= Y}', "");
Expect(0, 66639, '\P{CWT= Y}', "");
Expect(1, 66639, '\P{^CWT= Y}', "");
Expect(0, 66640, '\p{CWT= Y}', "");
Expect(1, 66640, '\p{^CWT= Y}', "");
Expect(1, 66640, '\P{CWT= Y}', "");
Expect(0, 66640, '\P{^CWT= Y}', "");
Error('\p{Is_Changes_When_Titlecased=_ T/a/}');
Error('\P{Is_Changes_When_Titlecased=_ T/a/}');
Expect(1, 66639, '\p{Is_Changes_When_Titlecased=t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Titlecased=t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Titlecased=t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Titlecased=t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Titlecased=t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Titlecased=t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Titlecased=t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Titlecased=t}', "");
Expect(1, 66639, '\p{Is_Changes_When_Titlecased=_-T}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Titlecased=_-T}', "");
Expect(0, 66639, '\P{Is_Changes_When_Titlecased=_-T}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Titlecased=_-T}', "");
Expect(0, 66640, '\p{Is_Changes_When_Titlecased=_-T}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Titlecased=_-T}', "");
Expect(1, 66640, '\P{Is_Changes_When_Titlecased=_-T}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Titlecased=_-T}', "");
Error('\p{Is_CWT=  True/a/}');
Error('\P{Is_CWT=  True/a/}');
Expect(1, 66639, '\p{Is_CWT=true}', "");
Expect(0, 66639, '\p{^Is_CWT=true}', "");
Expect(0, 66639, '\P{Is_CWT=true}', "");
Expect(1, 66639, '\P{^Is_CWT=true}', "");
Expect(0, 66640, '\p{Is_CWT=true}', "");
Expect(1, 66640, '\p{^Is_CWT=true}', "");
Expect(1, 66640, '\P{Is_CWT=true}', "");
Expect(0, 66640, '\P{^Is_CWT=true}', "");
Expect(1, 66639, '\p{Is_CWT= -True}', "");
Expect(0, 66639, '\p{^Is_CWT= -True}', "");
Expect(0, 66639, '\P{Is_CWT= -True}', "");
Expect(1, 66639, '\P{^Is_CWT= -True}', "");
Expect(0, 66640, '\p{Is_CWT= -True}', "");
Expect(1, 66640, '\p{^Is_CWT= -True}', "");
Expect(1, 66640, '\P{Is_CWT= -True}', "");
Expect(0, 66640, '\P{^Is_CWT= -True}', "");
Error('\p{Changes_When_Uppercased:/a/ -No}');
Error('\P{Changes_When_Uppercased:/a/ -No}');
Expect(1, 66640, '\p{Changes_When_Uppercased=no}', "");
Expect(0, 66640, '\p{^Changes_When_Uppercased=no}', "");
Expect(0, 66640, '\P{Changes_When_Uppercased=no}', "");
Expect(1, 66640, '\P{^Changes_When_Uppercased=no}', "");
Expect(0, 66639, '\p{Changes_When_Uppercased=no}', "");
Expect(1, 66639, '\p{^Changes_When_Uppercased=no}', "");
Expect(1, 66639, '\P{Changes_When_Uppercased=no}', "");
Expect(0, 66639, '\P{^Changes_When_Uppercased=no}', "");
Expect(1, 66640, '\p{Changes_When_Uppercased:    No}', "");
Expect(0, 66640, '\p{^Changes_When_Uppercased:    No}', "");
Expect(0, 66640, '\P{Changes_When_Uppercased:    No}', "");
Expect(1, 66640, '\P{^Changes_When_Uppercased:    No}', "");
Expect(0, 66639, '\p{Changes_When_Uppercased:    No}', "");
Expect(1, 66639, '\p{^Changes_When_Uppercased:    No}', "");
Expect(1, 66639, '\P{Changes_When_Uppercased:    No}', "");
Expect(0, 66639, '\P{^Changes_When_Uppercased:    No}', "");
Error('\p{CWU=_	N:=}');
Error('\P{CWU=_	N:=}');
Expect(1, 66640, '\p{CWU=n}', "");
Expect(0, 66640, '\p{^CWU=n}', "");
Expect(0, 66640, '\P{CWU=n}', "");
Expect(1, 66640, '\P{^CWU=n}', "");
Expect(0, 66639, '\p{CWU=n}', "");
Expect(1, 66639, '\p{^CWU=n}', "");
Expect(1, 66639, '\P{CWU=n}', "");
Expect(0, 66639, '\P{^CWU=n}', "");
Expect(1, 66640, '\p{CWU:   	 N}', "");
Expect(0, 66640, '\p{^CWU:   	 N}', "");
Expect(0, 66640, '\P{CWU:   	 N}', "");
Expect(1, 66640, '\P{^CWU:   	 N}', "");
Expect(0, 66639, '\p{CWU:   	 N}', "");
Expect(1, 66639, '\p{^CWU:   	 N}', "");
Expect(1, 66639, '\P{CWU:   	 N}', "");
Expect(0, 66639, '\P{^CWU:   	 N}', "");
Error('\p{Is_Changes_When_Uppercased=:=_-F}');
Error('\P{Is_Changes_When_Uppercased=:=_-F}');
Expect(1, 66640, '\p{Is_Changes_When_Uppercased=f}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Uppercased=f}', "");
Expect(0, 66640, '\P{Is_Changes_When_Uppercased=f}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Uppercased=f}', "");
Expect(0, 66639, '\p{Is_Changes_When_Uppercased=f}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Uppercased=f}', "");
Expect(1, 66639, '\P{Is_Changes_When_Uppercased=f}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Uppercased=f}', "");
Expect(1, 66640, '\p{Is_Changes_When_Uppercased=-F}', "");
Expect(0, 66640, '\p{^Is_Changes_When_Uppercased=-F}', "");
Expect(0, 66640, '\P{Is_Changes_When_Uppercased=-F}', "");
Expect(1, 66640, '\P{^Is_Changes_When_Uppercased=-F}', "");
Expect(0, 66639, '\p{Is_Changes_When_Uppercased=-F}', "");
Expect(1, 66639, '\p{^Is_Changes_When_Uppercased=-F}', "");
Expect(1, 66639, '\P{Is_Changes_When_Uppercased=-F}', "");
Expect(0, 66639, '\P{^Is_Changes_When_Uppercased=-F}', "");
Error('\p{Is_CWU=:= _false}');
Error('\P{Is_CWU=:= _false}');
Expect(1, 66640, '\p{Is_CWU=false}', "");
Expect(0, 66640, '\p{^Is_CWU=false}', "");
Expect(0, 66640, '\P{Is_CWU=false}', "");
Expect(1, 66640, '\P{^Is_CWU=false}', "");
Expect(0, 66639, '\p{Is_CWU=false}', "");
Expect(1, 66639, '\p{^Is_CWU=false}', "");
Expect(1, 66639, '\P{Is_CWU=false}', "");
Expect(0, 66639, '\P{^Is_CWU=false}', "");
Expect(1, 66640, '\p{Is_CWU=-_false}', "");
Expect(0, 66640, '\p{^Is_CWU=-_false}', "");
Expect(0, 66640, '\P{Is_CWU=-_false}', "");
Expect(1, 66640, '\P{^Is_CWU=-_false}', "");
Expect(0, 66639, '\p{Is_CWU=-_false}', "");
Expect(1, 66639, '\p{^Is_CWU=-_false}', "");
Expect(1, 66639, '\P{Is_CWU=-_false}', "");
Expect(0, 66639, '\P{^Is_CWU=-_false}', "");
Error('\p{Changes_When_Uppercased=	/a/YES}');
Error('\P{Changes_When_Uppercased=	/a/YES}');
Expect(1, 66639, '\p{Changes_When_Uppercased=yes}', "");
Expect(0, 66639, '\p{^Changes_When_Uppercased=yes}', "");
Expect(0, 66639, '\P{Changes_When_Uppercased=yes}', "");
Expect(1, 66639, '\P{^Changes_When_Uppercased=yes}', "");
Expect(0, 66640, '\p{Changes_When_Uppercased=yes}', "");
Expect(1, 66640, '\p{^Changes_When_Uppercased=yes}', "");
Expect(1, 66640, '\P{Changes_When_Uppercased=yes}', "");
Expect(0, 66640, '\P{^Changes_When_Uppercased=yes}', "");
Expect(1, 66639, '\p{Changes_When_Uppercased:   -Yes}', "");
Expect(0, 66639, '\p{^Changes_When_Uppercased:   -Yes}', "");
Expect(0, 66639, '\P{Changes_When_Uppercased:   -Yes}', "");
Expect(1, 66639, '\P{^Changes_When_Uppercased:   -Yes}', "");
Expect(0, 66640, '\p{Changes_When_Uppercased:   -Yes}', "");
Expect(1, 66640, '\p{^Changes_When_Uppercased:   -Yes}', "");
Expect(1, 66640, '\P{Changes_When_Uppercased:   -Yes}', "");
Expect(0, 66640, '\P{^Changes_When_Uppercased:   -Yes}', "");
Error('\p{CWU=	Y:=}');
Error('\P{CWU=	Y:=}');
Expect(1, 66639, '\p{CWU:	y}', "");
Expect(0, 66639, '\p{^CWU:	y}', "");
Expect(0, 66639, '\P{CWU:	y}', "");
Expect(1, 66639, '\P{^CWU:	y}', "");
Expect(0, 66640, '\p{CWU:	y}', "");
Expect(1, 66640, '\p{^CWU:	y}', "");
Expect(1, 66640, '\P{CWU:	y}', "");
Expect(0, 66640, '\P{^CWU:	y}', "");
Expect(1, 66639, '\p{CWU=-Y}', "");
Expect(0, 66639, '\p{^CWU=-Y}', "");
Expect(0, 66639, '\P{CWU=-Y}', "");
Expect(1, 66639, '\P{^CWU=-Y}', "");
Expect(0, 66640, '\p{CWU=-Y}', "");
Expect(1, 66640, '\p{^CWU=-Y}', "");
Expect(1, 66640, '\P{CWU=-Y}', "");
Expect(0, 66640, '\P{^CWU=-Y}', "");
Error('\p{Is_Changes_When_Uppercased= -T:=}');
Error('\P{Is_Changes_When_Uppercased= -T:=}');
Expect(1, 66639, '\p{Is_Changes_When_Uppercased=t}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Uppercased=t}', "");
Expect(0, 66639, '\P{Is_Changes_When_Uppercased=t}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Uppercased=t}', "");
Expect(0, 66640, '\p{Is_Changes_When_Uppercased=t}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Uppercased=t}', "");
Expect(1, 66640, '\P{Is_Changes_When_Uppercased=t}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Uppercased=t}', "");
Expect(1, 66639, '\p{Is_Changes_When_Uppercased=__T}', "");
Expect(0, 66639, '\p{^Is_Changes_When_Uppercased=__T}', "");
Expect(0, 66639, '\P{Is_Changes_When_Uppercased=__T}', "");
Expect(1, 66639, '\P{^Is_Changes_When_Uppercased=__T}', "");
Expect(0, 66640, '\p{Is_Changes_When_Uppercased=__T}', "");
Expect(1, 66640, '\p{^Is_Changes_When_Uppercased=__T}', "");
Expect(1, 66640, '\P{Is_Changes_When_Uppercased=__T}', "");
Expect(0, 66640, '\P{^Is_Changes_When_Uppercased=__T}', "");
Error('\p{Is_CWU= :=True}');
Error('\P{Is_CWU= :=True}');
Expect(1, 66639, '\p{Is_CWU=true}', "");
Expect(0, 66639, '\p{^Is_CWU=true}', "");
Expect(0, 66639, '\P{Is_CWU=true}', "");
Expect(1, 66639, '\P{^Is_CWU=true}', "");
Expect(0, 66640, '\p{Is_CWU=true}', "");
Expect(1, 66640, '\p{^Is_CWU=true}', "");
Expect(1, 66640, '\P{Is_CWU=true}', "");
Expect(0, 66640, '\P{^Is_CWU=true}', "");
Expect(1, 66639, '\p{Is_CWU= -TRUE}', "");
Expect(0, 66639, '\p{^Is_CWU= -TRUE}', "");
Expect(0, 66639, '\P{Is_CWU= -TRUE}', "");
Expect(1, 66639, '\P{^Is_CWU= -TRUE}', "");
Expect(0, 66640, '\p{Is_CWU= -TRUE}', "");
Expect(1, 66640, '\p{^Is_CWU= -TRUE}', "");
Expect(1, 66640, '\P{Is_CWU= -TRUE}', "");
Expect(0, 66640, '\P{^Is_CWU= -TRUE}', "");
Error('\p{Cased=_ No:=}');
Error('\P{Cased=_ No:=}');
Expect(1, 120780, '\p{Cased=no}', "");
Expect(0, 120780, '\p{^Cased=no}', "");
Expect(0, 120780, '\P{Cased=no}', "");
Expect(1, 120780, '\P{^Cased=no}', "");
Expect(0, 120779, '\p{Cased=no}', "");
Expect(1, 120779, '\p{^Cased=no}', "");
Expect(1, 120779, '\P{Cased=no}', "");
Expect(0, 120779, '\P{^Cased=no}', "");
Expect(1, 120780, '\p{Cased=-	No}', "");
Expect(0, 120780, '\p{^Cased=-	No}', "");
Expect(0, 120780, '\P{Cased=-	No}', "");
Expect(1, 120780, '\P{^Cased=-	No}', "");
Expect(0, 120779, '\p{Cased=-	No}', "");
Expect(1, 120779, '\p{^Cased=-	No}', "");
Expect(1, 120779, '\P{Cased=-	No}', "");
Expect(0, 120779, '\P{^Cased=-	No}', "");
Error('\p{Is_Cased=/a/N}');
Error('\P{Is_Cased=/a/N}');
Expect(1, 120780, '\p{Is_Cased: n}', "");
Expect(0, 120780, '\p{^Is_Cased: n}', "");
Expect(0, 120780, '\P{Is_Cased: n}', "");
Expect(1, 120780, '\P{^Is_Cased: n}', "");
Expect(0, 120779, '\p{Is_Cased: n}', "");
Expect(1, 120779, '\p{^Is_Cased: n}', "");
Expect(1, 120779, '\P{Is_Cased: n}', "");
Expect(0, 120779, '\P{^Is_Cased: n}', "");
Expect(1, 120780, '\p{Is_Cased=	 N}', "");
Expect(0, 120780, '\p{^Is_Cased=	 N}', "");
Expect(0, 120780, '\P{Is_Cased=	 N}', "");
Expect(1, 120780, '\P{^Is_Cased=	 N}', "");
Expect(0, 120779, '\p{Is_Cased=	 N}', "");
Expect(1, 120779, '\p{^Is_Cased=	 N}', "");
Expect(1, 120779, '\P{Is_Cased=	 N}', "");
Expect(0, 120779, '\P{^Is_Cased=	 N}', "");
Error('\p{Cased:   :=-F}');
Error('\P{Cased:   :=-F}');
Expect(1, 120780, '\p{Cased=f}', "");
Expect(0, 120780, '\p{^Cased=f}', "");
Expect(0, 120780, '\P{Cased=f}', "");
Expect(1, 120780, '\P{^Cased=f}', "");
Expect(0, 120779, '\p{Cased=f}', "");
Expect(1, 120779, '\p{^Cased=f}', "");
Expect(1, 120779, '\P{Cased=f}', "");
Expect(0, 120779, '\P{^Cased=f}', "");
Expect(1, 120780, '\p{Cased=	F}', "");
Expect(0, 120780, '\p{^Cased=	F}', "");
Expect(0, 120780, '\P{Cased=	F}', "");
Expect(1, 120780, '\P{^Cased=	F}', "");
Expect(0, 120779, '\p{Cased=	F}', "");
Expect(1, 120779, '\p{^Cased=	F}', "");
Expect(1, 120779, '\P{Cased=	F}', "");
Expect(0, 120779, '\P{^Cased=	F}', "");
Error('\p{Is_Cased=/a/-False}');
Error('\P{Is_Cased=/a/-False}');
Expect(1, 120780, '\p{Is_Cased=false}', "");
Expect(0, 120780, '\p{^Is_Cased=false}', "");
Expect(0, 120780, '\P{Is_Cased=false}', "");
Expect(1, 120780, '\P{^Is_Cased=false}', "");
Expect(0, 120779, '\p{Is_Cased=false}', "");
Expect(1, 120779, '\p{^Is_Cased=false}', "");
Expect(1, 120779, '\P{Is_Cased=false}', "");
Expect(0, 120779, '\P{^Is_Cased=false}', "");
Expect(1, 120780, '\p{Is_Cased:  -False}', "");
Expect(0, 120780, '\p{^Is_Cased:  -False}', "");
Expect(0, 120780, '\P{Is_Cased:  -False}', "");
Expect(1, 120780, '\P{^Is_Cased:  -False}', "");
Expect(0, 120779, '\p{Is_Cased:  -False}', "");
Expect(1, 120779, '\p{^Is_Cased:  -False}', "");
Expect(1, 120779, '\P{Is_Cased:  -False}', "");
Expect(0, 120779, '\P{^Is_Cased:  -False}', "");
Error('\p{Cased:   _/a/Yes}');
Error('\P{Cased:   _/a/Yes}');
Expect(1, 120779, '\p{Cased=yes}', "");
Expect(0, 120779, '\p{^Cased=yes}', "");
Expect(0, 120779, '\P{Cased=yes}', "");
Expect(1, 120779, '\P{^Cased=yes}', "");
Expect(0, 120780, '\p{Cased=yes}', "");
Expect(1, 120780, '\p{^Cased=yes}', "");
Expect(1, 120780, '\P{Cased=yes}', "");
Expect(0, 120780, '\P{^Cased=yes}', "");
Expect(1, 120779, '\p{Cased=--Yes}', "");
Expect(0, 120779, '\p{^Cased=--Yes}', "");
Expect(0, 120779, '\P{Cased=--Yes}', "");
Expect(1, 120779, '\P{^Cased=--Yes}', "");
Expect(0, 120780, '\p{Cased=--Yes}', "");
Expect(1, 120780, '\p{^Cased=--Yes}', "");
Expect(1, 120780, '\P{Cased=--Yes}', "");
Expect(0, 120780, '\P{^Cased=--Yes}', "");
Error('\p{Is_Cased=- Y:=}');
Error('\P{Is_Cased=- Y:=}');
Expect(1, 120779, '\p{Is_Cased:	y}', "");
Expect(0, 120779, '\p{^Is_Cased:	y}', "");
Expect(0, 120779, '\P{Is_Cased:	y}', "");
Expect(1, 120779, '\P{^Is_Cased:	y}', "");
Expect(0, 120780, '\p{Is_Cased:	y}', "");
Expect(1, 120780, '\p{^Is_Cased:	y}', "");
Expect(1, 120780, '\P{Is_Cased:	y}', "");
Expect(0, 120780, '\P{^Is_Cased:	y}', "");
Expect(1, 120779, '\p{Is_Cased= Y}', "");
Expect(0, 120779, '\p{^Is_Cased= Y}', "");
Expect(0, 120779, '\P{Is_Cased= Y}', "");
Expect(1, 120779, '\P{^Is_Cased= Y}', "");
Expect(0, 120780, '\p{Is_Cased= Y}', "");
Expect(1, 120780, '\p{^Is_Cased= Y}', "");
Expect(1, 120780, '\P{Is_Cased= Y}', "");
Expect(0, 120780, '\P{^Is_Cased= Y}', "");
Error('\p{Cased=:=_	T}');
Error('\P{Cased=:=_	T}');
Expect(1, 120779, '\p{Cased=t}', "");
Expect(0, 120779, '\p{^Cased=t}', "");
Expect(0, 120779, '\P{Cased=t}', "");
Expect(1, 120779, '\P{^Cased=t}', "");
Expect(0, 120780, '\p{Cased=t}', "");
Expect(1, 120780, '\p{^Cased=t}', "");
Expect(1, 120780, '\P{Cased=t}', "");
Expect(0, 120780, '\P{^Cased=t}', "");
Expect(1, 120779, '\p{Cased=__T}', "");
Expect(0, 120779, '\p{^Cased=__T}', "");
Expect(0, 120779, '\P{Cased=__T}', "");
Expect(1, 120779, '\P{^Cased=__T}', "");
Expect(0, 120780, '\p{Cased=__T}', "");
Expect(1, 120780, '\p{^Cased=__T}', "");
Expect(1, 120780, '\P{Cased=__T}', "");
Expect(0, 120780, '\P{^Cased=__T}', "");
Error('\p{Is_Cased=/a/__true}');
Error('\P{Is_Cased=/a/__true}');
Expect(1, 120779, '\p{Is_Cased:   true}', "");
Expect(0, 120779, '\p{^Is_Cased:   true}', "");
Expect(0, 120779, '\P{Is_Cased:   true}', "");
Expect(1, 120779, '\P{^Is_Cased:   true}', "");
Expect(0, 120780, '\p{Is_Cased:   true}', "");
Expect(1, 120780, '\p{^Is_Cased:   true}', "");
Expect(1, 120780, '\P{Is_Cased:   true}', "");
Expect(0, 120780, '\P{^Is_Cased:   true}', "");
Expect(1, 120779, '\p{Is_Cased=_	True}', "");
Expect(0, 120779, '\p{^Is_Cased=_	True}', "");
Expect(0, 120779, '\P{Is_Cased=_	True}', "");
Expect(1, 120779, '\P{^Is_Cased=_	True}', "");
Expect(0, 120780, '\p{Is_Cased=_	True}', "");
Expect(1, 120780, '\p{^Is_Cased=_	True}', "");
Expect(1, 120780, '\P{Is_Cased=_	True}', "");
Expect(0, 120780, '\P{^Is_Cased=_	True}', "");
Error('\p{Full_Composition_Exclusion=-No:=}');
Error('\P{Full_Composition_Exclusion=-No:=}');
Expect(1, 195102, '\p{Full_Composition_Exclusion=no}', "");
Expect(0, 195102, '\p{^Full_Composition_Exclusion=no}', "");
Expect(0, 195102, '\P{Full_Composition_Exclusion=no}', "");
Expect(1, 195102, '\P{^Full_Composition_Exclusion=no}', "");
Expect(0, 195101, '\p{Full_Composition_Exclusion=no}', "");
Expect(1, 195101, '\p{^Full_Composition_Exclusion=no}', "");
Expect(1, 195101, '\P{Full_Composition_Exclusion=no}', "");
Expect(0, 195101, '\P{^Full_Composition_Exclusion=no}', "");
Expect(1, 195102, '\p{Full_Composition_Exclusion=_no}', "");
Expect(0, 195102, '\p{^Full_Composition_Exclusion=_no}', "");
Expect(0, 195102, '\P{Full_Composition_Exclusion=_no}', "");
Expect(1, 195102, '\P{^Full_Composition_Exclusion=_no}', "");
Expect(0, 195101, '\p{Full_Composition_Exclusion=_no}', "");
Expect(1, 195101, '\p{^Full_Composition_Exclusion=_no}', "");
Expect(1, 195101, '\P{Full_Composition_Exclusion=_no}', "");
Expect(0, 195101, '\P{^Full_Composition_Exclusion=_no}', "");
Error('\p{Comp_Ex=	_n:=}');
Error('\P{Comp_Ex=	_n:=}');
Expect(1, 195102, '\p{Comp_Ex=n}', "");
Expect(0, 195102, '\p{^Comp_Ex=n}', "");
Expect(0, 195102, '\P{Comp_Ex=n}', "");
Expect(1, 195102, '\P{^Comp_Ex=n}', "");
Expect(0, 195101, '\p{Comp_Ex=n}', "");
Expect(1, 195101, '\p{^Comp_Ex=n}', "");
Expect(1, 195101, '\P{Comp_Ex=n}', "");
Expect(0, 195101, '\P{^Comp_Ex=n}', "");
Expect(1, 195102, '\p{Comp_Ex=	n}', "");
Expect(0, 195102, '\p{^Comp_Ex=	n}', "");
Expect(0, 195102, '\P{Comp_Ex=	n}', "");
Expect(1, 195102, '\P{^Comp_Ex=	n}', "");
Expect(0, 195101, '\p{Comp_Ex=	n}', "");
Expect(1, 195101, '\p{^Comp_Ex=	n}', "");
Expect(1, 195101, '\P{Comp_Ex=	n}', "");
Expect(0, 195101, '\P{^Comp_Ex=	n}', "");
Error('\p{Is_Full_Composition_Exclusion=_-f:=}');
Error('\P{Is_Full_Composition_Exclusion=_-f:=}');
Expect(1, 195102, '\p{Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195102, '\p{^Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195102, '\P{Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195102, '\P{^Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195101, '\p{Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195101, '\p{^Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195101, '\P{Is_Full_Composition_Exclusion=f}', "");
Expect(0, 195101, '\P{^Is_Full_Composition_Exclusion=f}', "");
Expect(1, 195102, '\p{Is_Full_Composition_Exclusion= _F}', "");
Expect(0, 195102, '\p{^Is_Full_Composition_Exclusion= _F}', "");
Expect(0, 195102, '\P{Is_Full_Composition_Exclusion= _F}', "");
Expect(1, 195102, '\P{^Is_Full_Composition_Exclusion= _F}', "");
Expect(0, 195101, '\p{Is_Full_Composition_Exclusion= _F}', "");
Expect(1, 195101, '\p{^Is_Full_Composition_Exclusion= _F}', "");
Expect(1, 195101, '\P{Is_Full_Composition_Exclusion= _F}', "");
Expect(0, 195101, '\P{^Is_Full_Composition_Exclusion= _F}', "");
Error('\p{Is_Comp_Ex=:= false}');
Error('\P{Is_Comp_Ex=:= false}');
Expect(1, 195102, '\p{Is_Comp_Ex=false}', "");
Expect(0, 195102, '\p{^Is_Comp_Ex=false}', "");
Expect(0, 195102, '\P{Is_Comp_Ex=false}', "");
Expect(1, 195102, '\P{^Is_Comp_Ex=false}', "");
Expect(0, 195101, '\p{Is_Comp_Ex=false}', "");
Expect(1, 195101, '\p{^Is_Comp_Ex=false}', "");
Expect(1, 195101, '\P{Is_Comp_Ex=false}', "");
Expect(0, 195101, '\P{^Is_Comp_Ex=false}', "");
Expect(1, 195102, '\p{Is_Comp_Ex=- FALSE}', "");
Expect(0, 195102, '\p{^Is_Comp_Ex=- FALSE}', "");
Expect(0, 195102, '\P{Is_Comp_Ex=- FALSE}', "");
Expect(1, 195102, '\P{^Is_Comp_Ex=- FALSE}', "");
Expect(0, 195101, '\p{Is_Comp_Ex=- FALSE}', "");
Expect(1, 195101, '\p{^Is_Comp_Ex=- FALSE}', "");
Expect(1, 195101, '\P{Is_Comp_Ex=- FALSE}', "");
Expect(0, 195101, '\P{^Is_Comp_Ex=- FALSE}', "");
Error('\p{Full_Composition_Exclusion=:=_Yes}');
Error('\P{Full_Composition_Exclusion=:=_Yes}');
Expect(1, 195101, '\p{Full_Composition_Exclusion=yes}', "");
Expect(0, 195101, '\p{^Full_Composition_Exclusion=yes}', "");
Expect(0, 195101, '\P{Full_Composition_Exclusion=yes}', "");
Expect(1, 195101, '\P{^Full_Composition_Exclusion=yes}', "");
Expect(0, 195102, '\p{Full_Composition_Exclusion=yes}', "");
Expect(1, 195102, '\p{^Full_Composition_Exclusion=yes}', "");
Expect(1, 195102, '\P{Full_Composition_Exclusion=yes}', "");
Expect(0, 195102, '\P{^Full_Composition_Exclusion=yes}', "");
Expect(1, 195101, '\p{Full_Composition_Exclusion=	Yes}', "");
Expect(0, 195101, '\p{^Full_Composition_Exclusion=	Yes}', "");
Expect(0, 195101, '\P{Full_Composition_Exclusion=	Yes}', "");
Expect(1, 195101, '\P{^Full_Composition_Exclusion=	Yes}', "");
Expect(0, 195102, '\p{Full_Composition_Exclusion=	Yes}', "");
Expect(1, 195102, '\p{^Full_Composition_Exclusion=	Yes}', "");
Expect(1, 195102, '\P{Full_Composition_Exclusion=	Yes}', "");
Expect(0, 195102, '\P{^Full_Composition_Exclusion=	Yes}', "");
Error('\p{Comp_Ex:Y/a/}');
Error('\P{Comp_Ex:Y/a/}');
Expect(1, 195101, '\p{Comp_Ex=y}', "");
Expect(0, 195101, '\p{^Comp_Ex=y}', "");
Expect(0, 195101, '\P{Comp_Ex=y}', "");
Expect(1, 195101, '\P{^Comp_Ex=y}', "");
Expect(0, 195102, '\p{Comp_Ex=y}', "");
Expect(1, 195102, '\p{^Comp_Ex=y}', "");
Expect(1, 195102, '\P{Comp_Ex=y}', "");
Expect(0, 195102, '\P{^Comp_Ex=y}', "");
Expect(1, 195101, '\p{Comp_Ex=- y}', "");
Expect(0, 195101, '\p{^Comp_Ex=- y}', "");
Expect(0, 195101, '\P{Comp_Ex=- y}', "");
Expect(1, 195101, '\P{^Comp_Ex=- y}', "");
Expect(0, 195102, '\p{Comp_Ex=- y}', "");
Expect(1, 195102, '\p{^Comp_Ex=- y}', "");
Expect(1, 195102, '\P{Comp_Ex=- y}', "");
Expect(0, 195102, '\P{^Comp_Ex=- y}', "");
Error('\p{Is_Full_Composition_Exclusion= t/a/}');
Error('\P{Is_Full_Composition_Exclusion= t/a/}');
Expect(1, 195101, '\p{Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195101, '\p{^Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195101, '\P{Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195101, '\P{^Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195102, '\p{Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195102, '\p{^Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195102, '\P{Is_Full_Composition_Exclusion=t}', "");
Expect(0, 195102, '\P{^Is_Full_Composition_Exclusion=t}', "");
Expect(1, 195101, '\p{Is_Full_Composition_Exclusion=-_T}', "");
Expect(0, 195101, '\p{^Is_Full_Composition_Exclusion=-_T}', "");
Expect(0, 195101, '\P{Is_Full_Composition_Exclusion=-_T}', "");
Expect(1, 195101, '\P{^Is_Full_Composition_Exclusion=-_T}', "");
Expect(0, 195102, '\p{Is_Full_Composition_Exclusion=-_T}', "");
Expect(1, 195102, '\p{^Is_Full_Composition_Exclusion=-_T}', "");
Expect(1, 195102, '\P{Is_Full_Composition_Exclusion=-_T}', "");
Expect(0, 195102, '\P{^Is_Full_Composition_Exclusion=-_T}', "");
Error('\p{Is_Comp_Ex:	_true:=}');
Error('\P{Is_Comp_Ex:	_true:=}');
Expect(1, 195101, '\p{Is_Comp_Ex=true}', "");
Expect(0, 195101, '\p{^Is_Comp_Ex=true}', "");
Expect(0, 195101, '\P{Is_Comp_Ex=true}', "");
Expect(1, 195101, '\P{^Is_Comp_Ex=true}', "");
Expect(0, 195102, '\p{Is_Comp_Ex=true}', "");
Expect(1, 195102, '\p{^Is_Comp_Ex=true}', "");
Expect(1, 195102, '\P{Is_Comp_Ex=true}', "");
Expect(0, 195102, '\P{^Is_Comp_Ex=true}', "");
Expect(1, 195101, '\p{Is_Comp_Ex= -True}', "");
Expect(0, 195101, '\p{^Is_Comp_Ex= -True}', "");
Expect(0, 195101, '\P{Is_Comp_Ex= -True}', "");
Expect(1, 195101, '\P{^Is_Comp_Ex= -True}', "");
Expect(0, 195102, '\p{Is_Comp_Ex= -True}', "");
Expect(1, 195102, '\p{^Is_Comp_Ex= -True}', "");
Expect(1, 195102, '\P{Is_Comp_Ex= -True}', "");
Expect(0, 195102, '\P{^Is_Comp_Ex= -True}', "");
Error('\p{Default_Ignorable_Code_Point=/a/_	No}');
Error('\P{Default_Ignorable_Code_Point=/a/_	No}');
Expect(1, 921600, '\p{Default_Ignorable_Code_Point=no}', "");
Expect(0, 921600, '\p{^Default_Ignorable_Code_Point=no}', "");
Expect(0, 921600, '\P{Default_Ignorable_Code_Point=no}', "");
Expect(1, 921600, '\P{^Default_Ignorable_Code_Point=no}', "");
Expect(0, 921599, '\p{Default_Ignorable_Code_Point=no}', "");
Expect(1, 921599, '\p{^Default_Ignorable_Code_Point=no}', "");
Expect(1, 921599, '\P{Default_Ignorable_Code_Point=no}', "");
Expect(0, 921599, '\P{^Default_Ignorable_Code_Point=no}', "");
Expect(1, 921600, '\p{Default_Ignorable_Code_Point=_	No}', "");
Expect(0, 921600, '\p{^Default_Ignorable_Code_Point=_	No}', "");
Expect(0, 921600, '\P{Default_Ignorable_Code_Point=_	No}', "");
Expect(1, 921600, '\P{^Default_Ignorable_Code_Point=_	No}', "");
Expect(0, 921599, '\p{Default_Ignorable_Code_Point=_	No}', "");
Expect(1, 921599, '\p{^Default_Ignorable_Code_Point=_	No}', "");
Expect(1, 921599, '\P{Default_Ignorable_Code_Point=_	No}', "");
Expect(0, 921599, '\P{^Default_Ignorable_Code_Point=_	No}', "");
Error('\p{DI=-:=N}');
Error('\P{DI=-:=N}');
Expect(1, 921600, '\p{DI=n}', "");
Expect(0, 921600, '\p{^DI=n}', "");
Expect(0, 921600, '\P{DI=n}', "");
Expect(1, 921600, '\P{^DI=n}', "");
Expect(0, 921599, '\p{DI=n}', "");
Expect(1, 921599, '\p{^DI=n}', "");
Expect(1, 921599, '\P{DI=n}', "");
Expect(0, 921599, '\P{^DI=n}', "");
Expect(1, 921600, '\p{DI=--N}', "");
Expect(0, 921600, '\p{^DI=--N}', "");
Expect(0, 921600, '\P{DI=--N}', "");
Expect(1, 921600, '\P{^DI=--N}', "");
Expect(0, 921599, '\p{DI=--N}', "");
Expect(1, 921599, '\p{^DI=--N}', "");
Expect(1, 921599, '\P{DI=--N}', "");
Expect(0, 921599, '\P{^DI=--N}', "");
Error('\p{Is_Default_Ignorable_Code_Point=-f/a/}');
Error('\P{Is_Default_Ignorable_Code_Point=-f/a/}');
Expect(1, 921600, '\p{Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921600, '\p{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921600, '\P{Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921600, '\P{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921599, '\p{Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921599, '\p{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921599, '\P{Is_Default_Ignorable_Code_Point=f}', "");
Expect(0, 921599, '\P{^Is_Default_Ignorable_Code_Point=f}', "");
Expect(1, 921600, '\p{Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(0, 921600, '\p{^Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(0, 921600, '\P{Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(1, 921600, '\P{^Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(0, 921599, '\p{Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(1, 921599, '\p{^Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(1, 921599, '\P{Is_Default_Ignorable_Code_Point=	_f}', "");
Expect(0, 921599, '\P{^Is_Default_Ignorable_Code_Point=	_f}', "");
Error('\p{Is_DI=/a/_ False}');
Error('\P{Is_DI=/a/_ False}');
Expect(1, 921600, '\p{Is_DI=false}', "");
Expect(0, 921600, '\p{^Is_DI=false}', "");
Expect(0, 921600, '\P{Is_DI=false}', "");
Expect(1, 921600, '\P{^Is_DI=false}', "");
Expect(0, 921599, '\p{Is_DI=false}', "");
Expect(1, 921599, '\p{^Is_DI=false}', "");
Expect(1, 921599, '\P{Is_DI=false}', "");
Expect(0, 921599, '\P{^Is_DI=false}', "");
Expect(1, 921600, '\p{Is_DI=--false}', "");
Expect(0, 921600, '\p{^Is_DI=--false}', "");
Expect(0, 921600, '\P{Is_DI=--false}', "");
Expect(1, 921600, '\P{^Is_DI=--false}', "");
Expect(0, 921599, '\p{Is_DI=--false}', "");
Expect(1, 921599, '\p{^Is_DI=--false}', "");
Expect(1, 921599, '\P{Is_DI=--false}', "");
Expect(0, 921599, '\P{^Is_DI=--false}', "");
Error('\p{Default_Ignorable_Code_Point=:=  yes}');
Error('\P{Default_Ignorable_Code_Point=:=  yes}');
Expect(1, 921599, '\p{Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921599, '\p{^Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921599, '\P{Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921599, '\P{^Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921600, '\p{Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921600, '\p{^Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921600, '\P{Default_Ignorable_Code_Point=yes}', "");
Expect(0, 921600, '\P{^Default_Ignorable_Code_Point=yes}', "");
Expect(1, 921599, '\p{Default_Ignorable_Code_Point=- yes}', "");
Expect(0, 921599, '\p{^Default_Ignorable_Code_Point=- yes}', "");
Expect(0, 921599, '\P{Default_Ignorable_Code_Point=- yes}', "");
Expect(1, 921599, '\P{^Default_Ignorable_Code_Point=- yes}', "");
Expect(0, 921600, '\p{Default_Ignorable_Code_Point=- yes}', "");
Expect(1, 921600, '\p{^Default_Ignorable_Code_Point=- yes}', "");
Expect(1, 921600, '\P{Default_Ignorable_Code_Point=- yes}', "");
Expect(0, 921600, '\P{^Default_Ignorable_Code_Point=- yes}', "");
Error('\p{DI=	_y/a/}');
Error('\P{DI=	_y/a/}');
Expect(1, 921599, '\p{DI=y}', "");
Expect(0, 921599, '\p{^DI=y}', "");
Expect(0, 921599, '\P{DI=y}', "");
Expect(1, 921599, '\P{^DI=y}', "");
Expect(0, 921600, '\p{DI=y}', "");
Expect(1, 921600, '\p{^DI=y}', "");
Expect(1, 921600, '\P{DI=y}', "");
Expect(0, 921600, '\P{^DI=y}', "");
Expect(1, 921599, '\p{DI=_-y}', "");
Expect(0, 921599, '\p{^DI=_-y}', "");
Expect(0, 921599, '\P{DI=_-y}', "");
Expect(1, 921599, '\P{^DI=_-y}', "");
Expect(0, 921600, '\p{DI=_-y}', "");
Expect(1, 921600, '\p{^DI=_-y}', "");
Expect(1, 921600, '\P{DI=_-y}', "");
Expect(0, 921600, '\P{^DI=_-y}', "");
Error('\p{Is_Default_Ignorable_Code_Point=-:=T}');
Error('\P{Is_Default_Ignorable_Code_Point=-:=T}');
Expect(1, 921599, '\p{Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921599, '\p{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921599, '\P{Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921599, '\P{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921600, '\p{Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921600, '\p{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921600, '\P{Is_Default_Ignorable_Code_Point=t}', "");
Expect(0, 921600, '\P{^Is_Default_Ignorable_Code_Point=t}', "");
Expect(1, 921599, '\p{Is_Default_Ignorable_Code_Point=- T}', "");
Expect(0, 921599, '\p{^Is_Default_Ignorable_Code_Point=- T}', "");
Expect(0, 921599, '\P{Is_Default_Ignorable_Code_Point=- T}', "");
Expect(1, 921599, '\P{^Is_Default_Ignorable_Code_Point=- T}', "");
Expect(0, 921600, '\p{Is_Default_Ignorable_Code_Point=- T}', "");
Expect(1, 921600, '\p{^Is_Default_Ignorable_Code_Point=- T}', "");
Expect(1, 921600, '\P{Is_Default_Ignorable_Code_Point=- T}', "");
Expect(0, 921600, '\P{^Is_Default_Ignorable_Code_Point=- T}', "");
Error('\p{Is_DI=:=True}');
Error('\P{Is_DI=:=True}');
Expect(1, 921599, '\p{Is_DI=true}', "");
Expect(0, 921599, '\p{^Is_DI=true}', "");
Expect(0, 921599, '\P{Is_DI=true}', "");
Expect(1, 921599, '\P{^Is_DI=true}', "");
Expect(0, 921600, '\p{Is_DI=true}', "");
Expect(1, 921600, '\p{^Is_DI=true}', "");
Expect(1, 921600, '\P{Is_DI=true}', "");
Expect(0, 921600, '\P{^Is_DI=true}', "");
Expect(1, 921599, '\p{Is_DI=	 True}', "");
Expect(0, 921599, '\p{^Is_DI=	 True}', "");
Expect(0, 921599, '\P{Is_DI=	 True}', "");
Expect(1, 921599, '\P{^Is_DI=	 True}', "");
Expect(0, 921600, '\p{Is_DI=	 True}', "");
Expect(1, 921600, '\p{^Is_DI=	 True}', "");
Expect(1, 921600, '\P{Is_DI=	 True}', "");
Expect(0, 921600, '\P{^Is_DI=	 True}', "");
Error('\p{Dash: :=-NO}');
Error('\P{Dash: :=-NO}');
Expect(1, 65294, '\p{Dash=no}', "");
Expect(0, 65294, '\p{^Dash=no}', "");
Expect(0, 65294, '\P{Dash=no}', "");
Expect(1, 65294, '\P{^Dash=no}', "");
Expect(0, 65293, '\p{Dash=no}', "");
Expect(1, 65293, '\p{^Dash=no}', "");
Expect(1, 65293, '\P{Dash=no}', "");
Expect(0, 65293, '\P{^Dash=no}', "");
Expect(1, 65294, '\p{Dash=	No}', "");
Expect(0, 65294, '\p{^Dash=	No}', "");
Expect(0, 65294, '\P{Dash=	No}', "");
Expect(1, 65294, '\P{^Dash=	No}', "");
Expect(0, 65293, '\p{Dash=	No}', "");
Expect(1, 65293, '\p{^Dash=	No}', "");
Expect(1, 65293, '\P{Dash=	No}', "");
Expect(0, 65293, '\P{^Dash=	No}', "");
Error('\p{Is_Dash=	/a/N}');
Error('\P{Is_Dash=	/a/N}');
Expect(1, 65294, '\p{Is_Dash=n}', "");
Expect(0, 65294, '\p{^Is_Dash=n}', "");
Expect(0, 65294, '\P{Is_Dash=n}', "");
Expect(1, 65294, '\P{^Is_Dash=n}', "");
Expect(0, 65293, '\p{Is_Dash=n}', "");
Expect(1, 65293, '\p{^Is_Dash=n}', "");
Expect(1, 65293, '\P{Is_Dash=n}', "");
Expect(0, 65293, '\P{^Is_Dash=n}', "");
Expect(1, 65294, '\p{Is_Dash=- n}', "");
Expect(0, 65294, '\p{^Is_Dash=- n}', "");
Expect(0, 65294, '\P{Is_Dash=- n}', "");
Expect(1, 65294, '\P{^Is_Dash=- n}', "");
Expect(0, 65293, '\p{Is_Dash=- n}', "");
Expect(1, 65293, '\p{^Is_Dash=- n}', "");
Expect(1, 65293, '\P{Is_Dash=- n}', "");
Expect(0, 65293, '\P{^Is_Dash=- n}', "");
Error('\p{Dash:   __F/a/}');
Error('\P{Dash:   __F/a/}');
Expect(1, 65294, '\p{Dash=f}', "");
Expect(0, 65294, '\p{^Dash=f}', "");
Expect(0, 65294, '\P{Dash=f}', "");
Expect(1, 65294, '\P{^Dash=f}', "");
Expect(0, 65293, '\p{Dash=f}', "");
Expect(1, 65293, '\p{^Dash=f}', "");
Expect(1, 65293, '\P{Dash=f}', "");
Expect(0, 65293, '\P{^Dash=f}', "");
Expect(1, 65294, '\p{Dash=__F}', "");
Expect(0, 65294, '\p{^Dash=__F}', "");
Expect(0, 65294, '\P{Dash=__F}', "");
Expect(1, 65294, '\P{^Dash=__F}', "");
Expect(0, 65293, '\p{Dash=__F}', "");
Expect(1, 65293, '\p{^Dash=__F}', "");
Expect(1, 65293, '\P{Dash=__F}', "");
Expect(0, 65293, '\P{^Dash=__F}', "");
Error('\p{Is_Dash: :=_ False}');
Error('\P{Is_Dash: :=_ False}');
Expect(1, 65294, '\p{Is_Dash:false}', "");
Expect(0, 65294, '\p{^Is_Dash:false}', "");
Expect(0, 65294, '\P{Is_Dash:false}', "");
Expect(1, 65294, '\P{^Is_Dash:false}', "");
Expect(0, 65293, '\p{Is_Dash:false}', "");
Expect(1, 65293, '\p{^Is_Dash:false}', "");
Expect(1, 65293, '\P{Is_Dash:false}', "");
Expect(0, 65293, '\P{^Is_Dash:false}', "");
Expect(1, 65294, '\p{Is_Dash=  False}', "");
Expect(0, 65294, '\p{^Is_Dash=  False}', "");
Expect(0, 65294, '\P{Is_Dash=  False}', "");
Expect(1, 65294, '\P{^Is_Dash=  False}', "");
Expect(0, 65293, '\p{Is_Dash=  False}', "");
Expect(1, 65293, '\p{^Is_Dash=  False}', "");
Expect(1, 65293, '\P{Is_Dash=  False}', "");
Expect(0, 65293, '\P{^Is_Dash=  False}', "");
Error('\p{Dash= :=YES}');
Error('\P{Dash= :=YES}');
Expect(1, 65293, '\p{Dash=yes}', "");
Expect(0, 65293, '\p{^Dash=yes}', "");
Expect(0, 65293, '\P{Dash=yes}', "");
Expect(1, 65293, '\P{^Dash=yes}', "");
Expect(0, 65294, '\p{Dash=yes}', "");
Expect(1, 65294, '\p{^Dash=yes}', "");
Expect(1, 65294, '\P{Dash=yes}', "");
Expect(0, 65294, '\P{^Dash=yes}', "");
Expect(1, 65293, '\p{Dash=--Yes}', "");
Expect(0, 65293, '\p{^Dash=--Yes}', "");
Expect(0, 65293, '\P{Dash=--Yes}', "");
Expect(1, 65293, '\P{^Dash=--Yes}', "");
Expect(0, 65294, '\p{Dash=--Yes}', "");
Expect(1, 65294, '\p{^Dash=--Yes}', "");
Expect(1, 65294, '\P{Dash=--Yes}', "");
Expect(0, 65294, '\P{^Dash=--Yes}', "");
Error('\p{Is_Dash: /a/	_y}');
Error('\P{Is_Dash: /a/	_y}');
Expect(1, 65293, '\p{Is_Dash=y}', "");
Expect(0, 65293, '\p{^Is_Dash=y}', "");
Expect(0, 65293, '\P{Is_Dash=y}', "");
Expect(1, 65293, '\P{^Is_Dash=y}', "");
Expect(0, 65294, '\p{Is_Dash=y}', "");
Expect(1, 65294, '\p{^Is_Dash=y}', "");
Expect(1, 65294, '\P{Is_Dash=y}', "");
Expect(0, 65294, '\P{^Is_Dash=y}', "");
Expect(1, 65293, '\p{Is_Dash=_-Y}', "");
Expect(0, 65293, '\p{^Is_Dash=_-Y}', "");
Expect(0, 65293, '\P{Is_Dash=_-Y}', "");
Expect(1, 65293, '\P{^Is_Dash=_-Y}', "");
Expect(0, 65294, '\p{Is_Dash=_-Y}', "");
Expect(1, 65294, '\p{^Is_Dash=_-Y}', "");
Expect(1, 65294, '\P{Is_Dash=_-Y}', "");
Expect(0, 65294, '\P{^Is_Dash=_-Y}', "");
Error('\p{Dash=/a/T}');
Error('\P{Dash=/a/T}');
Expect(1, 65293, '\p{Dash=t}', "");
Expect(0, 65293, '\p{^Dash=t}', "");
Expect(0, 65293, '\P{Dash=t}', "");
Expect(1, 65293, '\P{^Dash=t}', "");
Expect(0, 65294, '\p{Dash=t}', "");
Expect(1, 65294, '\p{^Dash=t}', "");
Expect(1, 65294, '\P{Dash=t}', "");
Expect(0, 65294, '\P{^Dash=t}', "");
Error('\p{Is_Dash=/a/-	True}');
Error('\P{Is_Dash=/a/-	True}');
Expect(1, 65293, '\p{Is_Dash=true}', "");
Expect(0, 65293, '\p{^Is_Dash=true}', "");
Expect(0, 65293, '\P{Is_Dash=true}', "");
Expect(1, 65293, '\P{^Is_Dash=true}', "");
Expect(0, 65294, '\p{Is_Dash=true}', "");
Expect(1, 65294, '\p{^Is_Dash=true}', "");
Expect(1, 65294, '\P{Is_Dash=true}', "");
Expect(0, 65294, '\P{^Is_Dash=true}', "");
Expect(1, 65293, '\p{Is_Dash=		true}', "");
Expect(0, 65293, '\p{^Is_Dash=		true}', "");
Expect(0, 65293, '\P{Is_Dash=		true}', "");
Expect(1, 65293, '\P{^Is_Dash=		true}', "");
Expect(0, 65294, '\p{Is_Dash=		true}', "");
Expect(1, 65294, '\p{^Is_Dash=		true}', "");
Expect(1, 65294, '\P{Is_Dash=		true}', "");
Expect(0, 65294, '\P{^Is_Dash=		true}', "");
Error('\p{Deprecated= NO:=}');
Error('\P{Deprecated= NO:=}');
Expect(1, 917632, '\p{Deprecated=no}', "");
Expect(0, 917632, '\p{^Deprecated=no}', "");
Expect(0, 917632, '\P{Deprecated=no}', "");
Expect(1, 917632, '\P{^Deprecated=no}', "");
Expect(0, 917631, '\p{Deprecated=no}', "");
Expect(1, 917631, '\p{^Deprecated=no}', "");
Expect(1, 917631, '\P{Deprecated=no}', "");
Expect(0, 917631, '\P{^Deprecated=no}', "");
Expect(1, 917632, '\p{Deprecated= NO}', "");
Expect(0, 917632, '\p{^Deprecated= NO}', "");
Expect(0, 917632, '\P{Deprecated= NO}', "");
Expect(1, 917632, '\P{^Deprecated= NO}', "");
Expect(0, 917631, '\p{Deprecated= NO}', "");
Expect(1, 917631, '\p{^Deprecated= NO}', "");
Expect(1, 917631, '\P{Deprecated= NO}', "");
Expect(0, 917631, '\P{^Deprecated= NO}', "");
Error('\p{Dep=:= -N}');
Error('\P{Dep=:= -N}');
Expect(1, 917632, '\p{Dep=n}', "");
Expect(0, 917632, '\p{^Dep=n}', "");
Expect(0, 917632, '\P{Dep=n}', "");
Expect(1, 917632, '\P{^Dep=n}', "");
Expect(0, 917631, '\p{Dep=n}', "");
Expect(1, 917631, '\p{^Dep=n}', "");
Expect(1, 917631, '\P{Dep=n}', "");
Expect(0, 917631, '\P{^Dep=n}', "");
Expect(1, 917632, '\p{Dep=	 N}', "");
Expect(0, 917632, '\p{^Dep=	 N}', "");
Expect(0, 917632, '\P{Dep=	 N}', "");
Expect(1, 917632, '\P{^Dep=	 N}', "");
Expect(0, 917631, '\p{Dep=	 N}', "");
Expect(1, 917631, '\p{^Dep=	 N}', "");
Expect(1, 917631, '\P{Dep=	 N}', "");
Expect(0, 917631, '\P{^Dep=	 N}', "");
Error('\p{Is_Deprecated: _f/a/}');
Error('\P{Is_Deprecated: _f/a/}');
Expect(1, 917632, '\p{Is_Deprecated=f}', "");
Expect(0, 917632, '\p{^Is_Deprecated=f}', "");
Expect(0, 917632, '\P{Is_Deprecated=f}', "");
Expect(1, 917632, '\P{^Is_Deprecated=f}', "");
Expect(0, 917631, '\p{Is_Deprecated=f}', "");
Expect(1, 917631, '\p{^Is_Deprecated=f}', "");
Expect(1, 917631, '\P{Is_Deprecated=f}', "");
Expect(0, 917631, '\P{^Is_Deprecated=f}', "");
Expect(1, 917632, '\p{Is_Deprecated= _F}', "");
Expect(0, 917632, '\p{^Is_Deprecated= _F}', "");
Expect(0, 917632, '\P{Is_Deprecated= _F}', "");
Expect(1, 917632, '\P{^Is_Deprecated= _F}', "");
Expect(0, 917631, '\p{Is_Deprecated= _F}', "");
Expect(1, 917631, '\p{^Is_Deprecated= _F}', "");
Expect(1, 917631, '\P{Is_Deprecated= _F}', "");
Expect(0, 917631, '\P{^Is_Deprecated= _F}', "");
Error('\p{Is_Dep=:=- False}');
Error('\P{Is_Dep=:=- False}');
Expect(1, 917632, '\p{Is_Dep=false}', "");
Expect(0, 917632, '\p{^Is_Dep=false}', "");
Expect(0, 917632, '\P{Is_Dep=false}', "");
Expect(1, 917632, '\P{^Is_Dep=false}', "");
Expect(0, 917631, '\p{Is_Dep=false}', "");
Expect(1, 917631, '\p{^Is_Dep=false}', "");
Expect(1, 917631, '\P{Is_Dep=false}', "");
Expect(0, 917631, '\P{^Is_Dep=false}', "");
Expect(1, 917632, '\p{Is_Dep:	 _false}', "");
Expect(0, 917632, '\p{^Is_Dep:	 _false}', "");
Expect(0, 917632, '\P{Is_Dep:	 _false}', "");
Expect(1, 917632, '\P{^Is_Dep:	 _false}', "");
Expect(0, 917631, '\p{Is_Dep:	 _false}', "");
Expect(1, 917631, '\p{^Is_Dep:	 _false}', "");
Expect(1, 917631, '\P{Is_Dep:	 _false}', "");
Expect(0, 917631, '\P{^Is_Dep:	 _false}', "");
Error('\p{Deprecated: /a/ -YES}');
Error('\P{Deprecated: /a/ -YES}');
Expect(1, 917631, '\p{Deprecated=yes}', "");
Expect(0, 917631, '\p{^Deprecated=yes}', "");
Expect(0, 917631, '\P{Deprecated=yes}', "");
Expect(1, 917631, '\P{^Deprecated=yes}', "");
Expect(0, 917632, '\p{Deprecated=yes}', "");
Expect(1, 917632, '\p{^Deprecated=yes}', "");
Expect(1, 917632, '\P{Deprecated=yes}', "");
Expect(0, 917632, '\P{^Deprecated=yes}', "");
Expect(1, 917631, '\p{Deprecated=-YES}', "");
Expect(0, 917631, '\p{^Deprecated=-YES}', "");
Expect(0, 917631, '\P{Deprecated=-YES}', "");
Expect(1, 917631, '\P{^Deprecated=-YES}', "");
Expect(0, 917632, '\p{Deprecated=-YES}', "");
Expect(1, 917632, '\p{^Deprecated=-YES}', "");
Expect(1, 917632, '\P{Deprecated=-YES}', "");
Expect(0, 917632, '\P{^Deprecated=-YES}', "");
Error('\p{Dep=_/a/y}');
Error('\P{Dep=_/a/y}');
Expect(1, 917631, '\p{Dep=y}', "");
Expect(0, 917631, '\p{^Dep=y}', "");
Expect(0, 917631, '\P{Dep=y}', "");
Expect(1, 917631, '\P{^Dep=y}', "");
Expect(0, 917632, '\p{Dep=y}', "");
Expect(1, 917632, '\p{^Dep=y}', "");
Expect(1, 917632, '\P{Dep=y}', "");
Expect(0, 917632, '\P{^Dep=y}', "");
Expect(1, 917631, '\p{Dep=-Y}', "");
Expect(0, 917631, '\p{^Dep=-Y}', "");
Expect(0, 917631, '\P{Dep=-Y}', "");
Expect(1, 917631, '\P{^Dep=-Y}', "");
Expect(0, 917632, '\p{Dep=-Y}', "");
Expect(1, 917632, '\p{^Dep=-Y}', "");
Expect(1, 917632, '\P{Dep=-Y}', "");
Expect(0, 917632, '\P{^Dep=-Y}', "");
Error('\p{Is_Deprecated=	T:=}');
Error('\P{Is_Deprecated=	T:=}');
Expect(1, 917631, '\p{Is_Deprecated=t}', "");
Expect(0, 917631, '\p{^Is_Deprecated=t}', "");
Expect(0, 917631, '\P{Is_Deprecated=t}', "");
Expect(1, 917631, '\P{^Is_Deprecated=t}', "");
Expect(0, 917632, '\p{Is_Deprecated=t}', "");
Expect(1, 917632, '\p{^Is_Deprecated=t}', "");
Expect(1, 917632, '\P{Is_Deprecated=t}', "");
Expect(0, 917632, '\P{^Is_Deprecated=t}', "");
Expect(1, 917631, '\p{Is_Deprecated=	T}', "");
Expect(0, 917631, '\p{^Is_Deprecated=	T}', "");
Expect(0, 917631, '\P{Is_Deprecated=	T}', "");
Expect(1, 917631, '\P{^Is_Deprecated=	T}', "");
Expect(0, 917632, '\p{Is_Deprecated=	T}', "");
Expect(1, 917632, '\p{^Is_Deprecated=	T}', "");
Expect(1, 917632, '\P{Is_Deprecated=	T}', "");
Expect(0, 917632, '\P{^Is_Deprecated=	T}', "");
Error('\p{Is_Dep=/a/-TRUE}');
Error('\P{Is_Dep=/a/-TRUE}');
Expect(1, 917631, '\p{Is_Dep:   true}', "");
Expect(0, 917631, '\p{^Is_Dep:   true}', "");
Expect(0, 917631, '\P{Is_Dep:   true}', "");
Expect(1, 917631, '\P{^Is_Dep:   true}', "");
Expect(0, 917632, '\p{Is_Dep:   true}', "");
Expect(1, 917632, '\p{^Is_Dep:   true}', "");
Expect(1, 917632, '\P{Is_Dep:   true}', "");
Expect(0, 917632, '\P{^Is_Dep:   true}', "");
Expect(1, 917631, '\p{Is_Dep=- True}', "");
Expect(0, 917631, '\p{^Is_Dep=- True}', "");
Expect(0, 917631, '\P{Is_Dep=- True}', "");
Expect(1, 917631, '\P{^Is_Dep=- True}', "");
Expect(0, 917632, '\p{Is_Dep=- True}', "");
Expect(1, 917632, '\p{^Is_Dep=- True}', "");
Expect(1, 917632, '\P{Is_Dep=- True}', "");
Expect(0, 917632, '\P{^Is_Dep=- True}', "");
Error('\p{Diacritic=:= no}');
Error('\P{Diacritic=:= no}');
Expect(1, 119214, '\p{Diacritic=no}', "");
Expect(0, 119214, '\p{^Diacritic=no}', "");
Expect(0, 119214, '\P{Diacritic=no}', "");
Expect(1, 119214, '\P{^Diacritic=no}', "");
Expect(0, 119213, '\p{Diacritic=no}', "");
Expect(1, 119213, '\p{^Diacritic=no}', "");
Expect(1, 119213, '\P{Diacritic=no}', "");
Expect(0, 119213, '\P{^Diacritic=no}', "");
Expect(1, 119214, '\p{Diacritic:	 No}', "");
Expect(0, 119214, '\p{^Diacritic:	 No}', "");
Expect(0, 119214, '\P{Diacritic:	 No}', "");
Expect(1, 119214, '\P{^Diacritic:	 No}', "");
Expect(0, 119213, '\p{Diacritic:	 No}', "");
Expect(1, 119213, '\p{^Diacritic:	 No}', "");
Expect(1, 119213, '\P{Diacritic:	 No}', "");
Expect(0, 119213, '\P{^Diacritic:	 No}', "");
Error('\p{Dia:	:= 	n}');
Error('\P{Dia:	:= 	n}');
Expect(1, 119214, '\p{Dia:   n}', "");
Expect(0, 119214, '\p{^Dia:   n}', "");
Expect(0, 119214, '\P{Dia:   n}', "");
Expect(1, 119214, '\P{^Dia:   n}', "");
Expect(0, 119213, '\p{Dia:   n}', "");
Expect(1, 119213, '\p{^Dia:   n}', "");
Expect(1, 119213, '\P{Dia:   n}', "");
Expect(0, 119213, '\P{^Dia:   n}', "");
Expect(1, 119214, '\p{Dia=	 N}', "");
Expect(0, 119214, '\p{^Dia=	 N}', "");
Expect(0, 119214, '\P{Dia=	 N}', "");
Expect(1, 119214, '\P{^Dia=	 N}', "");
Expect(0, 119213, '\p{Dia=	 N}', "");
Expect(1, 119213, '\p{^Dia=	 N}', "");
Expect(1, 119213, '\P{Dia=	 N}', "");
Expect(0, 119213, '\P{^Dia=	 N}', "");
Error('\p{Is_Diacritic:	:=F}');
Error('\P{Is_Diacritic:	:=F}');
Expect(1, 119214, '\p{Is_Diacritic=f}', "");
Expect(0, 119214, '\p{^Is_Diacritic=f}', "");
Expect(0, 119214, '\P{Is_Diacritic=f}', "");
Expect(1, 119214, '\P{^Is_Diacritic=f}', "");
Expect(0, 119213, '\p{Is_Diacritic=f}', "");
Expect(1, 119213, '\p{^Is_Diacritic=f}', "");
Expect(1, 119213, '\P{Is_Diacritic=f}', "");
Expect(0, 119213, '\P{^Is_Diacritic=f}', "");
Expect(1, 119214, '\p{Is_Diacritic=__f}', "");
Expect(0, 119214, '\p{^Is_Diacritic=__f}', "");
Expect(0, 119214, '\P{Is_Diacritic=__f}', "");
Expect(1, 119214, '\P{^Is_Diacritic=__f}', "");
Expect(0, 119213, '\p{Is_Diacritic=__f}', "");
Expect(1, 119213, '\p{^Is_Diacritic=__f}', "");
Expect(1, 119213, '\P{Is_Diacritic=__f}', "");
Expect(0, 119213, '\P{^Is_Diacritic=__f}', "");
Error('\p{Is_Dia=/a/		False}');
Error('\P{Is_Dia=/a/		False}');
Expect(1, 119214, '\p{Is_Dia=false}', "");
Expect(0, 119214, '\p{^Is_Dia=false}', "");
Expect(0, 119214, '\P{Is_Dia=false}', "");
Expect(1, 119214, '\P{^Is_Dia=false}', "");
Expect(0, 119213, '\p{Is_Dia=false}', "");
Expect(1, 119213, '\p{^Is_Dia=false}', "");
Expect(1, 119213, '\P{Is_Dia=false}', "");
Expect(0, 119213, '\P{^Is_Dia=false}', "");
Expect(1, 119214, '\p{Is_Dia=_false}', "");
Expect(0, 119214, '\p{^Is_Dia=_false}', "");
Expect(0, 119214, '\P{Is_Dia=_false}', "");
Expect(1, 119214, '\P{^Is_Dia=_false}', "");
Expect(0, 119213, '\p{Is_Dia=_false}', "");
Expect(1, 119213, '\p{^Is_Dia=_false}', "");
Expect(1, 119213, '\P{Is_Dia=_false}', "");
Expect(0, 119213, '\P{^Is_Dia=_false}', "");
Error('\p{Diacritic=-/a/YES}');
Error('\P{Diacritic=-/a/YES}');
Expect(1, 119213, '\p{Diacritic=yes}', "");
Expect(0, 119213, '\p{^Diacritic=yes}', "");
Expect(0, 119213, '\P{Diacritic=yes}', "");
Expect(1, 119213, '\P{^Diacritic=yes}', "");
Expect(0, 119214, '\p{Diacritic=yes}', "");
Expect(1, 119214, '\p{^Diacritic=yes}', "");
Expect(1, 119214, '\P{Diacritic=yes}', "");
Expect(0, 119214, '\P{^Diacritic=yes}', "");
Expect(1, 119213, '\p{Diacritic= -YES}', "");
Expect(0, 119213, '\p{^Diacritic= -YES}', "");
Expect(0, 119213, '\P{Diacritic= -YES}', "");
Expect(1, 119213, '\P{^Diacritic= -YES}', "");
Expect(0, 119214, '\p{Diacritic= -YES}', "");
Expect(1, 119214, '\p{^Diacritic= -YES}', "");
Expect(1, 119214, '\P{Diacritic= -YES}', "");
Expect(0, 119214, '\P{^Diacritic= -YES}', "");
Error('\p{Dia= y/a/}');
Error('\P{Dia= y/a/}');
Expect(1, 119213, '\p{Dia=y}', "");
Expect(0, 119213, '\p{^Dia=y}', "");
Expect(0, 119213, '\P{Dia=y}', "");
Expect(1, 119213, '\P{^Dia=y}', "");
Expect(0, 119214, '\p{Dia=y}', "");
Expect(1, 119214, '\p{^Dia=y}', "");
Expect(1, 119214, '\P{Dia=y}', "");
Expect(0, 119214, '\P{^Dia=y}', "");
Expect(1, 119213, '\p{Dia=	_Y}', "");
Expect(0, 119213, '\p{^Dia=	_Y}', "");
Expect(0, 119213, '\P{Dia=	_Y}', "");
Expect(1, 119213, '\P{^Dia=	_Y}', "");
Expect(0, 119214, '\p{Dia=	_Y}', "");
Expect(1, 119214, '\p{^Dia=	_Y}', "");
Expect(1, 119214, '\P{Dia=	_Y}', "");
Expect(0, 119214, '\P{^Dia=	_Y}', "");
Error('\p{Is_Diacritic=_T:=}');
Error('\P{Is_Diacritic=_T:=}');
Expect(1, 119213, '\p{Is_Diacritic=t}', "");
Expect(0, 119213, '\p{^Is_Diacritic=t}', "");
Expect(0, 119213, '\P{Is_Diacritic=t}', "");
Expect(1, 119213, '\P{^Is_Diacritic=t}', "");
Expect(0, 119214, '\p{Is_Diacritic=t}', "");
Expect(1, 119214, '\p{^Is_Diacritic=t}', "");
Expect(1, 119214, '\P{Is_Diacritic=t}', "");
Expect(0, 119214, '\P{^Is_Diacritic=t}', "");
Expect(1, 119213, '\p{Is_Diacritic:	-	T}', "");
Expect(0, 119213, '\p{^Is_Diacritic:	-	T}', "");
Expect(0, 119213, '\P{Is_Diacritic:	-	T}', "");
Expect(1, 119213, '\P{^Is_Diacritic:	-	T}', "");
Expect(0, 119214, '\p{Is_Diacritic:	-	T}', "");
Expect(1, 119214, '\p{^Is_Diacritic:	-	T}', "");
Expect(1, 119214, '\P{Is_Diacritic:	-	T}', "");
Expect(0, 119214, '\P{^Is_Diacritic:	-	T}', "");
Error('\p{Is_Dia=/a/TRUE}');
Error('\P{Is_Dia=/a/TRUE}');
Expect(1, 119213, '\p{Is_Dia=true}', "");
Expect(0, 119213, '\p{^Is_Dia=true}', "");
Expect(0, 119213, '\P{Is_Dia=true}', "");
Expect(1, 119213, '\P{^Is_Dia=true}', "");
Expect(0, 119214, '\p{Is_Dia=true}', "");
Expect(1, 119214, '\p{^Is_Dia=true}', "");
Expect(1, 119214, '\P{Is_Dia=true}', "");
Expect(0, 119214, '\P{^Is_Dia=true}', "");
Expect(1, 119213, '\p{Is_Dia=_ True}', "");
Expect(0, 119213, '\p{^Is_Dia=_ True}', "");
Expect(0, 119213, '\P{Is_Dia=_ True}', "");
Expect(1, 119213, '\P{^Is_Dia=_ True}', "");
Expect(0, 119214, '\p{Is_Dia=_ True}', "");
Expect(1, 119214, '\p{^Is_Dia=_ True}', "");
Expect(1, 119214, '\P{Is_Dia=_ True}', "");
Expect(0, 119214, '\P{^Is_Dia=_ True}', "");
Error('\p{Extender=	:=NO}');
Error('\P{Extender=	:=NO}');
Expect(1, 65393, '\p{Extender=no}', "");
Expect(0, 65393, '\p{^Extender=no}', "");
Expect(0, 65393, '\P{Extender=no}', "");
Expect(1, 65393, '\P{^Extender=no}', "");
Expect(0, 65392, '\p{Extender=no}', "");
Expect(1, 65392, '\p{^Extender=no}', "");
Expect(1, 65392, '\P{Extender=no}', "");
Expect(0, 65392, '\P{^Extender=no}', "");
Expect(1, 65393, '\p{Extender=_-NO}', "");
Expect(0, 65393, '\p{^Extender=_-NO}', "");
Expect(0, 65393, '\P{Extender=_-NO}', "");
Expect(1, 65393, '\P{^Extender=_-NO}', "");
Expect(0, 65392, '\p{Extender=_-NO}', "");
Expect(1, 65392, '\p{^Extender=_-NO}', "");
Expect(1, 65392, '\P{Extender=_-NO}', "");
Expect(0, 65392, '\P{^Extender=_-NO}', "");
Error('\p{Ext=:=-N}');
Error('\P{Ext=:=-N}');
Expect(1, 65393, '\p{Ext=n}', "");
Expect(0, 65393, '\p{^Ext=n}', "");
Expect(0, 65393, '\P{Ext=n}', "");
Expect(1, 65393, '\P{^Ext=n}', "");
Expect(0, 65392, '\p{Ext=n}', "");
Expect(1, 65392, '\p{^Ext=n}', "");
Expect(1, 65392, '\P{Ext=n}', "");
Expect(0, 65392, '\P{^Ext=n}', "");
Expect(1, 65393, '\p{Ext:	N}', "");
Expect(0, 65393, '\p{^Ext:	N}', "");
Expect(0, 65393, '\P{Ext:	N}', "");
Expect(1, 65393, '\P{^Ext:	N}', "");
Expect(0, 65392, '\p{Ext:	N}', "");
Expect(1, 65392, '\p{^Ext:	N}', "");
Expect(1, 65392, '\P{Ext:	N}', "");
Expect(0, 65392, '\P{^Ext:	N}', "");
Error('\p{Is_Extender=		f/a/}');
Error('\P{Is_Extender=		f/a/}');
Expect(1, 65393, '\p{Is_Extender:   f}', "");
Expect(0, 65393, '\p{^Is_Extender:   f}', "");
Expect(0, 65393, '\P{Is_Extender:   f}', "");
Expect(1, 65393, '\P{^Is_Extender:   f}', "");
Expect(0, 65392, '\p{Is_Extender:   f}', "");
Expect(1, 65392, '\p{^Is_Extender:   f}', "");
Expect(1, 65392, '\P{Is_Extender:   f}', "");
Expect(0, 65392, '\P{^Is_Extender:   f}', "");
Expect(1, 65393, '\p{Is_Extender=	F}', "");
Expect(0, 65393, '\p{^Is_Extender=	F}', "");
Expect(0, 65393, '\P{Is_Extender=	F}', "");
Expect(1, 65393, '\P{^Is_Extender=	F}', "");
Expect(0, 65392, '\p{Is_Extender=	F}', "");
Expect(1, 65392, '\p{^Is_Extender=	F}', "");
Expect(1, 65392, '\P{Is_Extender=	F}', "");
Expect(0, 65392, '\P{^Is_Extender=	F}', "");
Error('\p{Is_Ext=_	false/a/}');
Error('\P{Is_Ext=_	false/a/}');
Expect(1, 65393, '\p{Is_Ext=false}', "");
Expect(0, 65393, '\p{^Is_Ext=false}', "");
Expect(0, 65393, '\P{Is_Ext=false}', "");
Expect(1, 65393, '\P{^Is_Ext=false}', "");
Expect(0, 65392, '\p{Is_Ext=false}', "");
Expect(1, 65392, '\p{^Is_Ext=false}', "");
Expect(1, 65392, '\P{Is_Ext=false}', "");
Expect(0, 65392, '\P{^Is_Ext=false}', "");
Expect(1, 65393, '\p{Is_Ext:    False}', "");
Expect(0, 65393, '\p{^Is_Ext:    False}', "");
Expect(0, 65393, '\P{Is_Ext:    False}', "");
Expect(1, 65393, '\P{^Is_Ext:    False}', "");
Expect(0, 65392, '\p{Is_Ext:    False}', "");
Expect(1, 65392, '\p{^Is_Ext:    False}', "");
Expect(1, 65392, '\P{Is_Ext:    False}', "");
Expect(0, 65392, '\P{^Is_Ext:    False}', "");
Error('\p{Extender:	_/a/Yes}');
Error('\P{Extender:	_/a/Yes}');
Expect(1, 65392, '\p{Extender=yes}', "");
Expect(0, 65392, '\p{^Extender=yes}', "");
Expect(0, 65392, '\P{Extender=yes}', "");
Expect(1, 65392, '\P{^Extender=yes}', "");
Expect(0, 65393, '\p{Extender=yes}', "");
Expect(1, 65393, '\p{^Extender=yes}', "");
Expect(1, 65393, '\P{Extender=yes}', "");
Expect(0, 65393, '\P{^Extender=yes}', "");
Expect(1, 65392, '\p{Extender=	-Yes}', "");
Expect(0, 65392, '\p{^Extender=	-Yes}', "");
Expect(0, 65392, '\P{Extender=	-Yes}', "");
Expect(1, 65392, '\P{^Extender=	-Yes}', "");
Expect(0, 65393, '\p{Extender=	-Yes}', "");
Expect(1, 65393, '\p{^Extender=	-Yes}', "");
Expect(1, 65393, '\P{Extender=	-Yes}', "");
Expect(0, 65393, '\P{^Extender=	-Yes}', "");
Error('\p{Ext=:=		Y}');
Error('\P{Ext=:=		Y}');
Expect(1, 65392, '\p{Ext=y}', "");
Expect(0, 65392, '\p{^Ext=y}', "");
Expect(0, 65392, '\P{Ext=y}', "");
Expect(1, 65392, '\P{^Ext=y}', "");
Expect(0, 65393, '\p{Ext=y}', "");
Expect(1, 65393, '\p{^Ext=y}', "");
Expect(1, 65393, '\P{Ext=y}', "");
Expect(0, 65393, '\P{^Ext=y}', "");
Expect(1, 65392, '\p{Ext= 	Y}', "");
Expect(0, 65392, '\p{^Ext= 	Y}', "");
Expect(0, 65392, '\P{Ext= 	Y}', "");
Expect(1, 65392, '\P{^Ext= 	Y}', "");
Expect(0, 65393, '\p{Ext= 	Y}', "");
Expect(1, 65393, '\p{^Ext= 	Y}', "");
Expect(1, 65393, '\P{Ext= 	Y}', "");
Expect(0, 65393, '\P{^Ext= 	Y}', "");
Error('\p{Is_Extender=	-T:=}');
Error('\P{Is_Extender=	-T:=}');
Expect(1, 65392, '\p{Is_Extender=t}', "");
Expect(0, 65392, '\p{^Is_Extender=t}', "");
Expect(0, 65392, '\P{Is_Extender=t}', "");
Expect(1, 65392, '\P{^Is_Extender=t}', "");
Expect(0, 65393, '\p{Is_Extender=t}', "");
Expect(1, 65393, '\p{^Is_Extender=t}', "");
Expect(1, 65393, '\P{Is_Extender=t}', "");
Expect(0, 65393, '\P{^Is_Extender=t}', "");
Expect(1, 65392, '\p{Is_Extender=-_T}', "");
Expect(0, 65392, '\p{^Is_Extender=-_T}', "");
Expect(0, 65392, '\P{Is_Extender=-_T}', "");
Expect(1, 65392, '\P{^Is_Extender=-_T}', "");
Expect(0, 65393, '\p{Is_Extender=-_T}', "");
Expect(1, 65393, '\p{^Is_Extender=-_T}', "");
Expect(1, 65393, '\P{Is_Extender=-_T}', "");
Expect(0, 65393, '\P{^Is_Extender=-_T}', "");
Error('\p{Is_Ext=-:=true}');
Error('\P{Is_Ext=-:=true}');
Expect(1, 65392, '\p{Is_Ext=true}', "");
Expect(0, 65392, '\p{^Is_Ext=true}', "");
Expect(0, 65392, '\P{Is_Ext=true}', "");
Expect(1, 65392, '\P{^Is_Ext=true}', "");
Expect(0, 65393, '\p{Is_Ext=true}', "");
Expect(1, 65393, '\p{^Is_Ext=true}', "");
Expect(1, 65393, '\P{Is_Ext=true}', "");
Expect(0, 65393, '\P{^Is_Ext=true}', "");
Expect(1, 65392, '\p{Is_Ext=	-TRUE}', "");
Expect(0, 65392, '\p{^Is_Ext=	-TRUE}', "");
Expect(0, 65392, '\P{Is_Ext=	-TRUE}', "");
Expect(1, 65392, '\P{^Is_Ext=	-TRUE}', "");
Expect(0, 65393, '\p{Is_Ext=	-TRUE}', "");
Expect(1, 65393, '\p{^Is_Ext=	-TRUE}', "");
Expect(1, 65393, '\P{Is_Ext=	-TRUE}', "");
Expect(0, 65393, '\P{^Is_Ext=	-TRUE}', "");
Error('\p{Grapheme_Cluster_Break= control/a/}');
Error('\P{Grapheme_Cluster_Break= control/a/}');
Expect(1, 921599, '\p{Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\p{^Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\P{Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\P{^Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\p{Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\p{^Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\P{Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\P{^Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\p{Grapheme_Cluster_Break= -Control}', "");
Expect(0, 921599, '\p{^Grapheme_Cluster_Break= -Control}', "");
Expect(0, 921599, '\P{Grapheme_Cluster_Break= -Control}', "");
Expect(1, 921599, '\P{^Grapheme_Cluster_Break= -Control}', "");
Expect(0, 921600, '\p{Grapheme_Cluster_Break= -Control}', "");
Expect(1, 921600, '\p{^Grapheme_Cluster_Break= -Control}', "");
Expect(1, 921600, '\P{Grapheme_Cluster_Break= -Control}', "");
Expect(0, 921600, '\P{^Grapheme_Cluster_Break= -Control}', "");
Error('\p{GCB=	:=cn}');
Error('\P{GCB=	:=cn}');
Expect(1, 921599, '\p{GCB=cn}', "");
Expect(0, 921599, '\p{^GCB=cn}', "");
Expect(0, 921599, '\P{GCB=cn}', "");
Expect(1, 921599, '\P{^GCB=cn}', "");
Expect(0, 921600, '\p{GCB=cn}', "");
Expect(1, 921600, '\p{^GCB=cn}', "");
Expect(1, 921600, '\P{GCB=cn}', "");
Expect(0, 921600, '\P{^GCB=cn}', "");
Expect(1, 921599, '\p{GCB: -_cn}', "");
Expect(0, 921599, '\p{^GCB: -_cn}', "");
Expect(0, 921599, '\P{GCB: -_cn}', "");
Expect(1, 921599, '\P{^GCB: -_cn}', "");
Expect(0, 921600, '\p{GCB: -_cn}', "");
Expect(1, 921600, '\p{^GCB: -_cn}', "");
Expect(1, 921600, '\P{GCB: -_cn}', "");
Expect(0, 921600, '\P{^GCB: -_cn}', "");
Error('\p{Is_Grapheme_Cluster_Break=-control/a/}');
Error('\P{Is_Grapheme_Cluster_Break=-control/a/}');
Expect(1, 921599, '\p{Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\p{^Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921599, '\P{Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\P{^Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\p{Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\p{^Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921600, '\P{Is_Grapheme_Cluster_Break=control}', "");
Expect(0, 921600, '\P{^Is_Grapheme_Cluster_Break=control}', "");
Expect(1, 921599, '\p{Is_Grapheme_Cluster_Break= control}', "");
Expect(0, 921599, '\p{^Is_Grapheme_Cluster_Break= control}', "");
Expect(0, 921599, '\P{Is_Grapheme_Cluster_Break= control}', "");
Expect(1, 921599, '\P{^Is_Grapheme_Cluster_Break= control}', "");
Expect(0, 921600, '\p{Is_Grapheme_Cluster_Break= control}', "");
Expect(1, 921600, '\p{^Is_Grapheme_Cluster_Break= control}', "");
Expect(1, 921600, '\P{Is_Grapheme_Cluster_Break= control}', "");
Expect(0, 921600, '\P{^Is_Grapheme_Cluster_Break= control}', "");
Error('\p{Is_GCB=:=	CN}');
Error('\P{Is_GCB=:=	CN}');
Expect(1, 921599, '\p{Is_GCB=cn}', "");
Expect(0, 921599, '\p{^Is_GCB=cn}', "");
Expect(0, 921599, '\P{Is_GCB=cn}', "");
Expect(1, 921599, '\P{^Is_GCB=cn}', "");
Expect(0, 921600, '\p{Is_GCB=cn}', "");
Expect(1, 921600, '\p{^Is_GCB=cn}', "");
Expect(1, 921600, '\P{Is_GCB=cn}', "");
Expect(0, 921600, '\P{^Is_GCB=cn}', "");
Expect(1, 921599, '\p{Is_GCB=  CN}', "");
Expect(0, 921599, '\p{^Is_GCB=  CN}', "");
Expect(0, 921599, '\P{Is_GCB=  CN}', "");
Expect(1, 921599, '\P{^Is_GCB=  CN}', "");
Expect(0, 921600, '\p{Is_GCB=  CN}', "");
Expect(1, 921600, '\p{^Is_GCB=  CN}', "");
Expect(1, 921600, '\P{Is_GCB=  CN}', "");
Expect(0, 921600, '\P{^Is_GCB=  CN}', "");
Error('\p{Grapheme_Cluster_Break=:=		CR}');
Error('\P{Grapheme_Cluster_Break=:=		CR}');
Expect(1, 13, '\p{Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\p{^Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\P{Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\P{^Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\p{Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\p{^Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\P{Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\P{^Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\p{Grapheme_Cluster_Break=  CR}', "");
Expect(0, 13, '\p{^Grapheme_Cluster_Break=  CR}', "");
Expect(0, 13, '\P{Grapheme_Cluster_Break=  CR}', "");
Expect(1, 13, '\P{^Grapheme_Cluster_Break=  CR}', "");
Expect(0, 14, '\p{Grapheme_Cluster_Break=  CR}', "");
Expect(1, 14, '\p{^Grapheme_Cluster_Break=  CR}', "");
Expect(1, 14, '\P{Grapheme_Cluster_Break=  CR}', "");
Expect(0, 14, '\P{^Grapheme_Cluster_Break=  CR}', "");
Error('\p{GCB=	:=cr}');
Error('\P{GCB=	:=cr}');
Expect(1, 13, '\p{GCB=cr}', "");
Expect(0, 13, '\p{^GCB=cr}', "");
Expect(0, 13, '\P{GCB=cr}', "");
Expect(1, 13, '\P{^GCB=cr}', "");
Expect(0, 14, '\p{GCB=cr}', "");
Expect(1, 14, '\p{^GCB=cr}', "");
Expect(1, 14, '\P{GCB=cr}', "");
Expect(0, 14, '\P{^GCB=cr}', "");
Expect(1, 13, '\p{GCB=-	CR}', "");
Expect(0, 13, '\p{^GCB=-	CR}', "");
Expect(0, 13, '\P{GCB=-	CR}', "");
Expect(1, 13, '\P{^GCB=-	CR}', "");
Expect(0, 14, '\p{GCB=-	CR}', "");
Expect(1, 14, '\p{^GCB=-	CR}', "");
Expect(1, 14, '\P{GCB=-	CR}', "");
Expect(0, 14, '\P{^GCB=-	CR}', "");
Error('\p{Is_Grapheme_Cluster_Break=/a/	 CR}');
Error('\P{Is_Grapheme_Cluster_Break=/a/	 CR}');
Expect(1, 13, '\p{Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\p{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 13, '\P{Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\P{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\p{Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\p{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 14, '\P{Is_Grapheme_Cluster_Break=cr}', "");
Expect(0, 14, '\P{^Is_Grapheme_Cluster_Break=cr}', "");
Expect(1, 13, '\p{Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(0, 13, '\p{^Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(0, 13, '\P{Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(1, 13, '\P{^Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(0, 14, '\p{Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(1, 14, '\p{^Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(1, 14, '\P{Is_Grapheme_Cluster_Break=	-CR}', "");
Expect(0, 14, '\P{^Is_Grapheme_Cluster_Break=	-CR}', "");
Error('\p{Is_GCB=-:=CR}');
Error('\P{Is_GCB=-:=CR}');
Expect(1, 13, '\p{Is_GCB: cr}', "");
Expect(0, 13, '\p{^Is_GCB: cr}', "");
Expect(0, 13, '\P{Is_GCB: cr}', "");
Expect(1, 13, '\P{^Is_GCB: cr}', "");
Expect(0, 14, '\p{Is_GCB: cr}', "");
Expect(1, 14, '\p{^Is_GCB: cr}', "");
Expect(1, 14, '\P{Is_GCB: cr}', "");
Expect(0, 14, '\P{^Is_GCB: cr}', "");
Expect(1, 13, '\p{Is_GCB=- CR}', "");
Expect(0, 13, '\p{^Is_GCB=- CR}', "");
Expect(0, 13, '\P{Is_GCB=- CR}', "");
Expect(1, 13, '\P{^Is_GCB=- CR}', "");
Expect(0, 14, '\p{Is_GCB=- CR}', "");
Expect(1, 14, '\p{^Is_GCB=- CR}', "");
Expect(1, 14, '\P{Is_GCB=- CR}', "");
Expect(0, 14, '\P{^Is_GCB=- CR}', "");
Error('\p{Grapheme_Cluster_Break=	EXTEND:=}');
Error('\P{Grapheme_Cluster_Break=	EXTEND:=}');
Expect(1, 917999, '\p{Grapheme_Cluster_Break=extend}', "");
Expect(0, 917999, '\p{^Grapheme_Cluster_Break=extend}', "");
Expect(0, 917999, '\P{Grapheme_Cluster_Break=extend}', "");
Expect(1, 917999, '\P{^Grapheme_Cluster_Break=extend}', "");
Expect(0, 918000, '\p{Grapheme_Cluster_Break=extend}', "");
Expect(1, 918000, '\p{^Grapheme_Cluster_Break=extend}', "");
Expect(1, 918000, '\P{Grapheme_Cluster_Break=extend}', "");
Expect(0, 918000, '\P{^Grapheme_Cluster_Break=extend}', "");
Expect(1, 917999, '\p{Grapheme_Cluster_Break=	 extend}', "");
Expect(0, 917999, '\p{^Grapheme_Cluster_Break=	 extend}', "");
Expect(0, 917999, '\P{Grapheme_Cluster_Break=	 extend}', "");
Expect(1, 917999, '\P{^Grapheme_Cluster_Break=	 extend}', "");
Expect(0, 918000, '\p{Grapheme_Cluster_Break=	 extend}', "");
Expect(1, 918000, '\p{^Grapheme_Cluster_Break=	 extend}', "");
Expect(1, 918000, '\P{Grapheme_Cluster_Break=	 extend}', "");
Expect(0, 918000, '\P{^Grapheme_Cluster_Break=	 extend}', "");
Error('\p{GCB= /a/EX}');
Error('\P{GCB= /a/EX}');
Expect(1, 917999, '\p{GCB=ex}', "");
Expect(0, 917999, '\p{^GCB=ex}', "");
Expect(0, 917999, '\P{GCB=ex}', "");
Expect(1, 917999, '\P{^GCB=ex}', "");
Expect(0, 918000, '\p{GCB=ex}', "");
Expect(1, 918000, '\p{^GCB=ex}', "");
Expect(1, 918000, '\P{GCB=ex}', "");
Expect(0, 918000, '\P{^GCB=ex}', "");
Expect(1, 917999, '\p{GCB=  EX}', "");
Expect(0, 917999, '\p{^GCB=  EX}', "");
Expect(0, 917999, '\P{GCB=  EX}', "");
Expect(1, 917999, '\P{^GCB=  EX}', "");
Expect(0, 918000, '\p{GCB=  EX}', "");
Expect(1, 918000, '\p{^GCB=  EX}', "");
Expect(1, 918000, '\P{GCB=  EX}', "");
Expect(0, 918000, '\P{^GCB=  EX}', "");
Error('\p{Is_Grapheme_Cluster_Break=/a/ EXTEND}');
Error('\P{Is_Grapheme_Cluster_Break=/a/ EXTEND}');
Expect(1, 917999, '\p{Is_Grapheme_Cluster_Break=extend}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Cluster_Break=extend}', "");
Expect(0, 917999, '\P{Is_Grapheme_Cluster_Break=extend}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Cluster_Break=extend}', "");
Expect(0, 918000, '\p{Is_Grapheme_Cluster_Break=extend}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Cluster_Break=extend}', "");
Expect(1, 918000, '\P{Is_Grapheme_Cluster_Break=extend}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Cluster_Break=extend}', "");
Expect(1, 917999, '\p{Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(0, 917999, '\P{Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(0, 918000, '\p{Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(1, 918000, '\P{Is_Grapheme_Cluster_Break=-Extend}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Cluster_Break=-Extend}', "");
Error('\p{Is_GCB=-EX:=}');
Error('\P{Is_GCB=-EX:=}');
Expect(1, 917999, '\p{Is_GCB=ex}', "");
Expect(0, 917999, '\p{^Is_GCB=ex}', "");
Expect(0, 917999, '\P{Is_GCB=ex}', "");
Expect(1, 917999, '\P{^Is_GCB=ex}', "");
Expect(0, 918000, '\p{Is_GCB=ex}', "");
Expect(1, 918000, '\p{^Is_GCB=ex}', "");
Expect(1, 918000, '\P{Is_GCB=ex}', "");
Expect(0, 918000, '\P{^Is_GCB=ex}', "");
Expect(1, 917999, '\p{Is_GCB=	ex}', "");
Expect(0, 917999, '\p{^Is_GCB=	ex}', "");
Expect(0, 917999, '\P{Is_GCB=	ex}', "");
Expect(1, 917999, '\P{^Is_GCB=	ex}', "");
Expect(0, 918000, '\p{Is_GCB=	ex}', "");
Expect(1, 918000, '\p{^Is_GCB=	ex}', "");
Expect(1, 918000, '\P{Is_GCB=	ex}', "");
Expect(0, 918000, '\P{^Is_GCB=	ex}', "");
Error('\p{Grapheme_Cluster_Break=		L:=}');
Error('\P{Grapheme_Cluster_Break=		L:=}');
Expect(1, 43388, '\p{Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\p{^Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\P{Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\P{^Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\p{Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\p{^Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\P{Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\P{^Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\p{Grapheme_Cluster_Break=_-L}', "");
Expect(0, 43388, '\p{^Grapheme_Cluster_Break=_-L}', "");
Expect(0, 43388, '\P{Grapheme_Cluster_Break=_-L}', "");
Expect(1, 43388, '\P{^Grapheme_Cluster_Break=_-L}', "");
Expect(0, 43389, '\p{Grapheme_Cluster_Break=_-L}', "");
Expect(1, 43389, '\p{^Grapheme_Cluster_Break=_-L}', "");
Expect(1, 43389, '\P{Grapheme_Cluster_Break=_-L}', "");
Expect(0, 43389, '\P{^Grapheme_Cluster_Break=_-L}', "");
Error('\p{GCB= _L/a/}');
Error('\P{GCB= _L/a/}');
Expect(1, 43388, '\p{GCB=l}', "");
Expect(0, 43388, '\p{^GCB=l}', "");
Expect(0, 43388, '\P{GCB=l}', "");
Expect(1, 43388, '\P{^GCB=l}', "");
Expect(0, 43389, '\p{GCB=l}', "");
Expect(1, 43389, '\p{^GCB=l}', "");
Expect(1, 43389, '\P{GCB=l}', "");
Expect(0, 43389, '\P{^GCB=l}', "");
Expect(1, 43388, '\p{GCB= L}', "");
Expect(0, 43388, '\p{^GCB= L}', "");
Expect(0, 43388, '\P{GCB= L}', "");
Expect(1, 43388, '\P{^GCB= L}', "");
Expect(0, 43389, '\p{GCB= L}', "");
Expect(1, 43389, '\p{^GCB= L}', "");
Expect(1, 43389, '\P{GCB= L}', "");
Expect(0, 43389, '\P{^GCB= L}', "");
Error('\p{Is_Grapheme_Cluster_Break=:=-L}');
Error('\P{Is_Grapheme_Cluster_Break=:=-L}');
Expect(1, 43388, '\p{Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\p{^Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43388, '\P{Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\P{^Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\p{Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\p{^Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43389, '\P{Is_Grapheme_Cluster_Break=l}', "");
Expect(0, 43389, '\P{^Is_Grapheme_Cluster_Break=l}', "");
Expect(1, 43388, '\p{Is_Grapheme_Cluster_Break:	_l}', "");
Expect(0, 43388, '\p{^Is_Grapheme_Cluster_Break:	_l}', "");
Expect(0, 43388, '\P{Is_Grapheme_Cluster_Break:	_l}', "");
Expect(1, 43388, '\P{^Is_Grapheme_Cluster_Break:	_l}', "");
Expect(0, 43389, '\p{Is_Grapheme_Cluster_Break:	_l}', "");
Expect(1, 43389, '\p{^Is_Grapheme_Cluster_Break:	_l}', "");
Expect(1, 43389, '\P{Is_Grapheme_Cluster_Break:	_l}', "");
Expect(0, 43389, '\P{^Is_Grapheme_Cluster_Break:	_l}', "");
Error('\p{Is_GCB=_:=l}');
Error('\P{Is_GCB=_:=l}');
Expect(1, 43388, '\p{Is_GCB=l}', "");
Expect(0, 43388, '\p{^Is_GCB=l}', "");
Expect(0, 43388, '\P{Is_GCB=l}', "");
Expect(1, 43388, '\P{^Is_GCB=l}', "");
Expect(0, 43389, '\p{Is_GCB=l}', "");
Expect(1, 43389, '\p{^Is_GCB=l}', "");
Expect(1, 43389, '\P{Is_GCB=l}', "");
Expect(0, 43389, '\P{^Is_GCB=l}', "");
Expect(1, 43388, '\p{Is_GCB=-L}', "");
Expect(0, 43388, '\p{^Is_GCB=-L}', "");
Expect(0, 43388, '\P{Is_GCB=-L}', "");
Expect(1, 43388, '\P{^Is_GCB=-L}', "");
Expect(0, 43389, '\p{Is_GCB=-L}', "");
Expect(1, 43389, '\p{^Is_GCB=-L}', "");
Expect(1, 43389, '\P{Is_GCB=-L}', "");
Expect(0, 43389, '\P{^Is_GCB=-L}', "");
Error('\p{Grapheme_Cluster_Break= /a/LF}');
Error('\P{Grapheme_Cluster_Break= /a/LF}');
Expect(1, 10, '\p{Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\p{^Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\P{Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\P{^Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\p{Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\p{^Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\P{Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\P{^Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\p{Grapheme_Cluster_Break= -lf}', "");
Expect(0, 10, '\p{^Grapheme_Cluster_Break= -lf}', "");
Expect(0, 10, '\P{Grapheme_Cluster_Break= -lf}', "");
Expect(1, 10, '\P{^Grapheme_Cluster_Break= -lf}', "");
Expect(0, 11, '\p{Grapheme_Cluster_Break= -lf}', "");
Expect(1, 11, '\p{^Grapheme_Cluster_Break= -lf}', "");
Expect(1, 11, '\P{Grapheme_Cluster_Break= -lf}', "");
Expect(0, 11, '\P{^Grapheme_Cluster_Break= -lf}', "");
Error('\p{GCB=/a/	_LF}');
Error('\P{GCB=/a/	_LF}');
Expect(1, 10, '\p{GCB=lf}', "");
Expect(0, 10, '\p{^GCB=lf}', "");
Expect(0, 10, '\P{GCB=lf}', "");
Expect(1, 10, '\P{^GCB=lf}', "");
Expect(0, 11, '\p{GCB=lf}', "");
Expect(1, 11, '\p{^GCB=lf}', "");
Expect(1, 11, '\P{GCB=lf}', "");
Expect(0, 11, '\P{^GCB=lf}', "");
Expect(1, 10, '\p{GCB=__LF}', "");
Expect(0, 10, '\p{^GCB=__LF}', "");
Expect(0, 10, '\P{GCB=__LF}', "");
Expect(1, 10, '\P{^GCB=__LF}', "");
Expect(0, 11, '\p{GCB=__LF}', "");
Expect(1, 11, '\p{^GCB=__LF}', "");
Expect(1, 11, '\P{GCB=__LF}', "");
Expect(0, 11, '\P{^GCB=__LF}', "");
Error('\p{Is_Grapheme_Cluster_Break=	-LF/a/}');
Error('\P{Is_Grapheme_Cluster_Break=	-LF/a/}');
Expect(1, 10, '\p{Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\p{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 10, '\P{Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\P{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\p{Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\p{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 11, '\P{Is_Grapheme_Cluster_Break=lf}', "");
Expect(0, 11, '\P{^Is_Grapheme_Cluster_Break=lf}', "");
Expect(1, 10, '\p{Is_Grapheme_Cluster_Break: -LF}', "");
Expect(0, 10, '\p{^Is_Grapheme_Cluster_Break: -LF}', "");
Expect(0, 10, '\P{Is_Grapheme_Cluster_Break: -LF}', "");
Expect(1, 10, '\P{^Is_Grapheme_Cluster_Break: -LF}', "");
Expect(0, 11, '\p{Is_Grapheme_Cluster_Break: -LF}', "");
Expect(1, 11, '\p{^Is_Grapheme_Cluster_Break: -LF}', "");
Expect(1, 11, '\P{Is_Grapheme_Cluster_Break: -LF}', "");
Expect(0, 11, '\P{^Is_Grapheme_Cluster_Break: -LF}', "");
Error('\p{Is_GCB=_lf/a/}');
Error('\P{Is_GCB=_lf/a/}');
Expect(1, 10, '\p{Is_GCB:   lf}', "");
Expect(0, 10, '\p{^Is_GCB:   lf}', "");
Expect(0, 10, '\P{Is_GCB:   lf}', "");
Expect(1, 10, '\P{^Is_GCB:   lf}', "");
Expect(0, 11, '\p{Is_GCB:   lf}', "");
Expect(1, 11, '\p{^Is_GCB:   lf}', "");
Expect(1, 11, '\P{Is_GCB:   lf}', "");
Expect(0, 11, '\P{^Is_GCB:   lf}', "");
Expect(1, 10, '\p{Is_GCB=_-LF}', "");
Expect(0, 10, '\p{^Is_GCB=_-LF}', "");
Expect(0, 10, '\P{Is_GCB=_-LF}', "");
Expect(1, 10, '\P{^Is_GCB=_-LF}', "");
Expect(0, 11, '\p{Is_GCB=_-LF}', "");
Expect(1, 11, '\p{^Is_GCB=_-LF}', "");
Expect(1, 11, '\P{Is_GCB=_-LF}', "");
Expect(0, 11, '\P{^Is_GCB=_-LF}', "");
Error('\p{Grapheme_Cluster_Break=	 LV:=}');
Error('\P{Grapheme_Cluster_Break=	 LV:=}');
Expect(1, 55176, '\p{Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\p{^Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\P{Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\P{^Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\p{Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\p{^Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\P{Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\P{^Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\p{Grapheme_Cluster_Break=LV}', "");
Expect(0, 55176, '\p{^Grapheme_Cluster_Break=LV}', "");
Expect(0, 55176, '\P{Grapheme_Cluster_Break=LV}', "");
Expect(1, 55176, '\P{^Grapheme_Cluster_Break=LV}', "");
Expect(0, 55177, '\p{Grapheme_Cluster_Break=LV}', "");
Expect(1, 55177, '\p{^Grapheme_Cluster_Break=LV}', "");
Expect(1, 55177, '\P{Grapheme_Cluster_Break=LV}', "");
Expect(0, 55177, '\P{^Grapheme_Cluster_Break=LV}', "");
Error('\p{GCB= _LV/a/}');
Error('\P{GCB= _LV/a/}');
Expect(1, 55176, '\p{GCB:lv}', "");
Expect(0, 55176, '\p{^GCB:lv}', "");
Expect(0, 55176, '\P{GCB:lv}', "");
Expect(1, 55176, '\P{^GCB:lv}', "");
Expect(0, 55177, '\p{GCB:lv}', "");
Expect(1, 55177, '\p{^GCB:lv}', "");
Expect(1, 55177, '\P{GCB:lv}', "");
Expect(0, 55177, '\P{^GCB:lv}', "");
Expect(1, 55176, '\p{GCB=--LV}', "");
Expect(0, 55176, '\p{^GCB=--LV}', "");
Expect(0, 55176, '\P{GCB=--LV}', "");
Expect(1, 55176, '\P{^GCB=--LV}', "");
Expect(0, 55177, '\p{GCB=--LV}', "");
Expect(1, 55177, '\p{^GCB=--LV}', "");
Expect(1, 55177, '\P{GCB=--LV}', "");
Expect(0, 55177, '\P{^GCB=--LV}', "");
Error('\p{Is_Grapheme_Cluster_Break=/a/lv}');
Error('\P{Is_Grapheme_Cluster_Break=/a/lv}');
Expect(1, 55176, '\p{Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\p{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55176, '\P{Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\P{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\p{Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\p{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55177, '\P{Is_Grapheme_Cluster_Break=lv}', "");
Expect(0, 55177, '\P{^Is_Grapheme_Cluster_Break=lv}', "");
Expect(1, 55176, '\p{Is_Grapheme_Cluster_Break= -lv}', "");
Expect(0, 55176, '\p{^Is_Grapheme_Cluster_Break= -lv}', "");
Expect(0, 55176, '\P{Is_Grapheme_Cluster_Break= -lv}', "");
Expect(1, 55176, '\P{^Is_Grapheme_Cluster_Break= -lv}', "");
Expect(0, 55177, '\p{Is_Grapheme_Cluster_Break= -lv}', "");
Expect(1, 55177, '\p{^Is_Grapheme_Cluster_Break= -lv}', "");
Expect(1, 55177, '\P{Is_Grapheme_Cluster_Break= -lv}', "");
Expect(0, 55177, '\P{^Is_Grapheme_Cluster_Break= -lv}', "");
Error('\p{Is_GCB:	:=	-LV}');
Error('\P{Is_GCB:	:=	-LV}');
Expect(1, 55176, '\p{Is_GCB=lv}', "");
Expect(0, 55176, '\p{^Is_GCB=lv}', "");
Expect(0, 55176, '\P{Is_GCB=lv}', "");
Expect(1, 55176, '\P{^Is_GCB=lv}', "");
Expect(0, 55177, '\p{Is_GCB=lv}', "");
Expect(1, 55177, '\p{^Is_GCB=lv}', "");
Expect(1, 55177, '\P{Is_GCB=lv}', "");
Expect(0, 55177, '\P{^Is_GCB=lv}', "");
Expect(1, 55176, '\p{Is_GCB=_lv}', "");
Expect(0, 55176, '\p{^Is_GCB=_lv}', "");
Expect(0, 55176, '\P{Is_GCB=_lv}', "");
Expect(1, 55176, '\P{^Is_GCB=_lv}', "");
Expect(0, 55177, '\p{Is_GCB=_lv}', "");
Expect(1, 55177, '\p{^Is_GCB=_lv}', "");
Expect(1, 55177, '\P{Is_GCB=_lv}', "");
Expect(0, 55177, '\P{^Is_GCB=_lv}', "");
Error('\p{Grapheme_Cluster_Break=	LVT:=}');
Error('\P{Grapheme_Cluster_Break=	LVT:=}');
Expect(1, 55203, '\p{Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55203, '\p{^Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55203, '\P{Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55203, '\P{^Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55204, '\p{Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55204, '\p{^Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55204, '\P{Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55204, '\P{^Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55203, '\p{Grapheme_Cluster_Break=_ LVT}', "");
Expect(0, 55203, '\p{^Grapheme_Cluster_Break=_ LVT}', "");
Expect(0, 55203, '\P{Grapheme_Cluster_Break=_ LVT}', "");
Expect(1, 55203, '\P{^Grapheme_Cluster_Break=_ LVT}', "");
Expect(0, 55204, '\p{Grapheme_Cluster_Break=_ LVT}', "");
Expect(1, 55204, '\p{^Grapheme_Cluster_Break=_ LVT}', "");
Expect(1, 55204, '\P{Grapheme_Cluster_Break=_ LVT}', "");
Expect(0, 55204, '\P{^Grapheme_Cluster_Break=_ LVT}', "");
Error('\p{GCB=_/a/LVT}');
Error('\P{GCB=_/a/LVT}');
Expect(1, 55203, '\p{GCB=lvt}', "");
Expect(0, 55203, '\p{^GCB=lvt}', "");
Expect(0, 55203, '\P{GCB=lvt}', "");
Expect(1, 55203, '\P{^GCB=lvt}', "");
Expect(0, 55204, '\p{GCB=lvt}', "");
Expect(1, 55204, '\p{^GCB=lvt}', "");
Expect(1, 55204, '\P{GCB=lvt}', "");
Expect(0, 55204, '\P{^GCB=lvt}', "");
Expect(1, 55203, '\p{GCB=_	LVT}', "");
Expect(0, 55203, '\p{^GCB=_	LVT}', "");
Expect(0, 55203, '\P{GCB=_	LVT}', "");
Expect(1, 55203, '\P{^GCB=_	LVT}', "");
Expect(0, 55204, '\p{GCB=_	LVT}', "");
Expect(1, 55204, '\p{^GCB=_	LVT}', "");
Expect(1, 55204, '\P{GCB=_	LVT}', "");
Expect(0, 55204, '\P{^GCB=_	LVT}', "");
Error('\p{Is_Grapheme_Cluster_Break= :=LVT}');
Error('\P{Is_Grapheme_Cluster_Break= :=LVT}');
Expect(1, 55203, '\p{Is_Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55203, '\p{^Is_Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55203, '\P{Is_Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55203, '\P{^Is_Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55204, '\p{Is_Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55204, '\p{^Is_Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55204, '\P{Is_Grapheme_Cluster_Break=lvt}', "");
Expect(0, 55204, '\P{^Is_Grapheme_Cluster_Break=lvt}', "");
Expect(1, 55203, '\p{Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(0, 55203, '\p{^Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(0, 55203, '\P{Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(1, 55203, '\P{^Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(0, 55204, '\p{Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(1, 55204, '\p{^Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(1, 55204, '\P{Is_Grapheme_Cluster_Break=__LVT}', "");
Expect(0, 55204, '\P{^Is_Grapheme_Cluster_Break=__LVT}', "");
Error('\p{Is_GCB= :=LVT}');
Error('\P{Is_GCB= :=LVT}');
Expect(1, 55203, '\p{Is_GCB=lvt}', "");
Expect(0, 55203, '\p{^Is_GCB=lvt}', "");
Expect(0, 55203, '\P{Is_GCB=lvt}', "");
Expect(1, 55203, '\P{^Is_GCB=lvt}', "");
Expect(0, 55204, '\p{Is_GCB=lvt}', "");
Expect(1, 55204, '\p{^Is_GCB=lvt}', "");
Expect(1, 55204, '\P{Is_GCB=lvt}', "");
Expect(0, 55204, '\P{^Is_GCB=lvt}', "");
Expect(1, 55203, '\p{Is_GCB= LVT}', "");
Expect(0, 55203, '\p{^Is_GCB= LVT}', "");
Expect(0, 55203, '\P{Is_GCB= LVT}', "");
Expect(1, 55203, '\P{^Is_GCB= LVT}', "");
Expect(0, 55204, '\p{Is_GCB= LVT}', "");
Expect(1, 55204, '\p{^Is_GCB= LVT}', "");
Expect(1, 55204, '\P{Is_GCB= LVT}', "");
Expect(0, 55204, '\P{^Is_GCB= LVT}', "");
Error('\p{Grapheme_Cluster_Break=/a/- PREPEND}');
Error('\P{Grapheme_Cluster_Break=/a/- PREPEND}');
Expect(0, 1, '\p{Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\p{^Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\P{Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\P{^Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\p{Grapheme_Cluster_Break=_prepend}', "");
Expect(1, 1, '\p{^Grapheme_Cluster_Break=_prepend}', "");
Expect(1, 1, '\P{Grapheme_Cluster_Break=_prepend}', "");
Expect(0, 1, '\P{^Grapheme_Cluster_Break=_prepend}', "");
Error('\p{GCB=  PP/a/}');
Error('\P{GCB=  PP/a/}');
Expect(0, 1, '\p{GCB=pp}', "");
Expect(1, 1, '\p{^GCB=pp}', "");
Expect(1, 1, '\P{GCB=pp}', "");
Expect(0, 1, '\P{^GCB=pp}', "");
Expect(0, 1, '\p{GCB:	-	PP}', "");
Expect(1, 1, '\p{^GCB:	-	PP}', "");
Expect(1, 1, '\P{GCB:	-	PP}', "");
Expect(0, 1, '\P{^GCB:	-	PP}', "");
Error('\p{Is_Grapheme_Cluster_Break=:= PREPEND}');
Error('\P{Is_Grapheme_Cluster_Break=:= PREPEND}');
Expect(0, 1, '\p{Is_Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\p{^Is_Grapheme_Cluster_Break=prepend}', "");
Expect(1, 1, '\P{Is_Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\P{^Is_Grapheme_Cluster_Break=prepend}', "");
Expect(0, 1, '\p{Is_Grapheme_Cluster_Break=	 prepend}', "");
Expect(1, 1, '\p{^Is_Grapheme_Cluster_Break=	 prepend}', "");
Expect(1, 1, '\P{Is_Grapheme_Cluster_Break=	 prepend}', "");
Expect(0, 1, '\P{^Is_Grapheme_Cluster_Break=	 prepend}', "");
Error('\p{Is_GCB= PP/a/}');
Error('\P{Is_GCB= PP/a/}');
Expect(0, 1, '\p{Is_GCB=pp}', "");
Expect(1, 1, '\p{^Is_GCB=pp}', "");
Expect(1, 1, '\P{Is_GCB=pp}', "");
Expect(0, 1, '\P{^Is_GCB=pp}', "");
Expect(0, 1, '\p{Is_GCB:	-PP}', "");
Expect(1, 1, '\p{^Is_GCB:	-PP}', "");
Expect(1, 1, '\P{Is_GCB:	-PP}', "");
Expect(0, 1, '\P{^Is_GCB:	-PP}', "");
Error('\p{Grapheme_Cluster_Break=	Regional_Indicator:=}');
Error('\P{Grapheme_Cluster_Break=	Regional_Indicator:=}');
Expect(1, 127487, '\p{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(0, 127487, '\p{^Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(0, 127487, '\P{Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(1, 127487, '\P{^Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(0, 127488, '\p{Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(1, 127488, '\p{^Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(1, 127488, '\P{Grapheme_Cluster_Break:  Regional_Indicator}', "");
Expect(0, 127488, '\P{^Grapheme_Cluster_Break:  Regional_Indicator}', "");
Error('\p{GCB=/a/RI}');
Error('\P{GCB=/a/RI}');
Expect(1, 127487, '\p{GCB=ri}', "");
Expect(0, 127487, '\p{^GCB=ri}', "");
Expect(0, 127487, '\P{GCB=ri}', "");
Expect(1, 127487, '\P{^GCB=ri}', "");
Expect(0, 127488, '\p{GCB=ri}', "");
Expect(1, 127488, '\p{^GCB=ri}', "");
Expect(1, 127488, '\P{GCB=ri}', "");
Expect(0, 127488, '\P{^GCB=ri}', "");
Expect(1, 127487, '\p{GCB=-RI}', "");
Expect(0, 127487, '\p{^GCB=-RI}', "");
Expect(0, 127487, '\P{GCB=-RI}', "");
Expect(1, 127487, '\P{^GCB=-RI}', "");
Expect(0, 127488, '\p{GCB=-RI}', "");
Expect(1, 127488, '\p{^GCB=-RI}', "");
Expect(1, 127488, '\P{GCB=-RI}', "");
Expect(0, 127488, '\P{^GCB=-RI}', "");
Error('\p{Is_Grapheme_Cluster_Break=/a/__REGIONAL_Indicator}');
Error('\P{Is_Grapheme_Cluster_Break=/a/__REGIONAL_Indicator}');
Expect(1, 127487, '\p{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Is_Grapheme_Cluster_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(0, 127487, '\p{^Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(0, 127487, '\P{Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(1, 127487, '\P{^Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(0, 127488, '\p{Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(1, 127488, '\p{^Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(1, 127488, '\P{Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Expect(0, 127488, '\P{^Is_Grapheme_Cluster_Break=	_REGIONAL_INDICATOR}', "");
Error('\p{Is_GCB:	-:=RI}');
Error('\P{Is_GCB:	-:=RI}');
Expect(1, 127487, '\p{Is_GCB=ri}', "");
Expect(0, 127487, '\p{^Is_GCB=ri}', "");
Expect(0, 127487, '\P{Is_GCB=ri}', "");
Expect(1, 127487, '\P{^Is_GCB=ri}', "");
Expect(0, 127488, '\p{Is_GCB=ri}', "");
Expect(1, 127488, '\p{^Is_GCB=ri}', "");
Expect(1, 127488, '\P{Is_GCB=ri}', "");
Expect(0, 127488, '\P{^Is_GCB=ri}', "");
Expect(1, 127487, '\p{Is_GCB= _ri}', "");
Expect(0, 127487, '\p{^Is_GCB= _ri}', "");
Expect(0, 127487, '\P{Is_GCB= _ri}', "");
Expect(1, 127487, '\P{^Is_GCB= _ri}', "");
Expect(0, 127488, '\p{Is_GCB= _ri}', "");
Expect(1, 127488, '\p{^Is_GCB= _ri}', "");
Expect(1, 127488, '\P{Is_GCB= _ri}', "");
Expect(0, 127488, '\P{^Is_GCB= _ri}', "");
Error('\p{Grapheme_Cluster_Break= spacingmark/a/}');
Error('\P{Grapheme_Cluster_Break= spacingmark/a/}');
Expect(1, 119149, '\p{Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\p{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\P{Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\P{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\p{Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\p{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\P{Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\P{^Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\p{Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(0, 119149, '\p{^Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(0, 119149, '\P{Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(1, 119149, '\P{^Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(0, 119150, '\p{Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(1, 119150, '\p{^Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(1, 119150, '\P{Grapheme_Cluster_Break= -SpacingMark}', "");
Expect(0, 119150, '\P{^Grapheme_Cluster_Break= -SpacingMark}', "");
Error('\p{GCB:   -/a/SM}');
Error('\P{GCB:   -/a/SM}');
Expect(1, 119149, '\p{GCB=sm}', "");
Expect(0, 119149, '\p{^GCB=sm}', "");
Expect(0, 119149, '\P{GCB=sm}', "");
Expect(1, 119149, '\P{^GCB=sm}', "");
Expect(0, 119150, '\p{GCB=sm}', "");
Expect(1, 119150, '\p{^GCB=sm}', "");
Expect(1, 119150, '\P{GCB=sm}', "");
Expect(0, 119150, '\P{^GCB=sm}', "");
Error('\p{Is_Grapheme_Cluster_Break:/a/	 SpacingMark}');
Error('\P{Is_Grapheme_Cluster_Break:/a/	 SpacingMark}');
Expect(1, 119149, '\p{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\p{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119149, '\P{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\P{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\p{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\p{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119150, '\P{Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(0, 119150, '\P{^Is_Grapheme_Cluster_Break=spacingmark}', "");
Expect(1, 119149, '\p{Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(0, 119149, '\p{^Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(0, 119149, '\P{Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(1, 119149, '\P{^Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(0, 119150, '\p{Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(1, 119150, '\p{^Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(1, 119150, '\P{Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Expect(0, 119150, '\P{^Is_Grapheme_Cluster_Break: -SpacingMark}', "");
Error('\p{Is_GCB=:=SM}');
Error('\P{Is_GCB=:=SM}');
Expect(1, 119149, '\p{Is_GCB=sm}', "");
Expect(0, 119149, '\p{^Is_GCB=sm}', "");
Expect(0, 119149, '\P{Is_GCB=sm}', "");
Expect(1, 119149, '\P{^Is_GCB=sm}', "");
Expect(0, 119150, '\p{Is_GCB=sm}', "");
Expect(1, 119150, '\p{^Is_GCB=sm}', "");
Expect(1, 119150, '\P{Is_GCB=sm}', "");
Expect(0, 119150, '\P{^Is_GCB=sm}', "");
Error('\p{Grapheme_Cluster_Break:	_/a/T}');
Error('\P{Grapheme_Cluster_Break:	_/a/T}');
Expect(1, 55291, '\p{Grapheme_Cluster_Break:   t}', "");
Expect(0, 55291, '\p{^Grapheme_Cluster_Break:   t}', "");
Expect(0, 55291, '\P{Grapheme_Cluster_Break:   t}', "");
Expect(1, 55291, '\P{^Grapheme_Cluster_Break:   t}', "");
Expect(0, 55292, '\p{Grapheme_Cluster_Break:   t}', "");
Expect(1, 55292, '\p{^Grapheme_Cluster_Break:   t}', "");
Expect(1, 55292, '\P{Grapheme_Cluster_Break:   t}', "");
Expect(0, 55292, '\P{^Grapheme_Cluster_Break:   t}', "");
Expect(1, 55291, '\p{Grapheme_Cluster_Break=_T}', "");
Expect(0, 55291, '\p{^Grapheme_Cluster_Break=_T}', "");
Expect(0, 55291, '\P{Grapheme_Cluster_Break=_T}', "");
Expect(1, 55291, '\P{^Grapheme_Cluster_Break=_T}', "");
Expect(0, 55292, '\p{Grapheme_Cluster_Break=_T}', "");
Expect(1, 55292, '\p{^Grapheme_Cluster_Break=_T}', "");
Expect(1, 55292, '\P{Grapheme_Cluster_Break=_T}', "");
Expect(0, 55292, '\P{^Grapheme_Cluster_Break=_T}', "");
Error('\p{GCB=_/a/T}');
Error('\P{GCB=_/a/T}');
Expect(1, 55291, '\p{GCB=t}', "");
Expect(0, 55291, '\p{^GCB=t}', "");
Expect(0, 55291, '\P{GCB=t}', "");
Expect(1, 55291, '\P{^GCB=t}', "");
Expect(0, 55292, '\p{GCB=t}', "");
Expect(1, 55292, '\p{^GCB=t}', "");
Expect(1, 55292, '\P{GCB=t}', "");
Expect(0, 55292, '\P{^GCB=t}', "");
Expect(1, 55291, '\p{GCB=_T}', "");
Expect(0, 55291, '\p{^GCB=_T}', "");
Expect(0, 55291, '\P{GCB=_T}', "");
Expect(1, 55291, '\P{^GCB=_T}', "");
Expect(0, 55292, '\p{GCB=_T}', "");
Expect(1, 55292, '\p{^GCB=_T}', "");
Expect(1, 55292, '\P{GCB=_T}', "");
Expect(0, 55292, '\P{^GCB=_T}', "");
Error('\p{Is_Grapheme_Cluster_Break=/a/_	t}');
Error('\P{Is_Grapheme_Cluster_Break=/a/_	t}');
Expect(1, 55291, '\p{Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55291, '\p{^Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55291, '\P{Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55291, '\P{^Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55292, '\p{Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55292, '\p{^Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55292, '\P{Is_Grapheme_Cluster_Break=t}', "");
Expect(0, 55292, '\P{^Is_Grapheme_Cluster_Break=t}', "");
Expect(1, 55291, '\p{Is_Grapheme_Cluster_Break= t}', "");
Expect(0, 55291, '\p{^Is_Grapheme_Cluster_Break= t}', "");
Expect(0, 55291, '\P{Is_Grapheme_Cluster_Break= t}', "");
Expect(1, 55291, '\P{^Is_Grapheme_Cluster_Break= t}', "");
Expect(0, 55292, '\p{Is_Grapheme_Cluster_Break= t}', "");
Expect(1, 55292, '\p{^Is_Grapheme_Cluster_Break= t}', "");
Expect(1, 55292, '\P{Is_Grapheme_Cluster_Break= t}', "");
Expect(0, 55292, '\P{^Is_Grapheme_Cluster_Break= t}', "");
Error('\p{Is_GCB=__T:=}');
Error('\P{Is_GCB=__T:=}');
Expect(1, 55291, '\p{Is_GCB=t}', "");
Expect(0, 55291, '\p{^Is_GCB=t}', "");
Expect(0, 55291, '\P{Is_GCB=t}', "");
Expect(1, 55291, '\P{^Is_GCB=t}', "");
Expect(0, 55292, '\p{Is_GCB=t}', "");
Expect(1, 55292, '\p{^Is_GCB=t}', "");
Expect(1, 55292, '\P{Is_GCB=t}', "");
Expect(0, 55292, '\P{^Is_GCB=t}', "");
Expect(1, 55291, '\p{Is_GCB:   	T}', "");
Expect(0, 55291, '\p{^Is_GCB:   	T}', "");
Expect(0, 55291, '\P{Is_GCB:   	T}', "");
Expect(1, 55291, '\P{^Is_GCB:   	T}', "");
Expect(0, 55292, '\p{Is_GCB:   	T}', "");
Expect(1, 55292, '\p{^Is_GCB:   	T}', "");
Expect(1, 55292, '\P{Is_GCB:   	T}', "");
Expect(0, 55292, '\P{^Is_GCB:   	T}', "");
Error('\p{Grapheme_Cluster_Break=/a/V}');
Error('\P{Grapheme_Cluster_Break=/a/V}');
Expect(1, 55238, '\p{Grapheme_Cluster_Break=v}', "");
Expect(0, 55238, '\p{^Grapheme_Cluster_Break=v}', "");
Expect(0, 55238, '\P{Grapheme_Cluster_Break=v}', "");
Expect(1, 55238, '\P{^Grapheme_Cluster_Break=v}', "");
Expect(0, 55239, '\p{Grapheme_Cluster_Break=v}', "");
Expect(1, 55239, '\p{^Grapheme_Cluster_Break=v}', "");
Expect(1, 55239, '\P{Grapheme_Cluster_Break=v}', "");
Expect(0, 55239, '\P{^Grapheme_Cluster_Break=v}', "");
Expect(1, 55238, '\p{Grapheme_Cluster_Break= -V}', "");
Expect(0, 55238, '\p{^Grapheme_Cluster_Break= -V}', "");
Expect(0, 55238, '\P{Grapheme_Cluster_Break= -V}', "");
Expect(1, 55238, '\P{^Grapheme_Cluster_Break= -V}', "");
Expect(0, 55239, '\p{Grapheme_Cluster_Break= -V}', "");
Expect(1, 55239, '\p{^Grapheme_Cluster_Break= -V}', "");
Expect(1, 55239, '\P{Grapheme_Cluster_Break= -V}', "");
Expect(0, 55239, '\P{^Grapheme_Cluster_Break= -V}', "");
Error('\p{GCB=		V:=}');
Error('\P{GCB=		V:=}');
Expect(1, 55238, '\p{GCB=v}', "");
Expect(0, 55238, '\p{^GCB=v}', "");
Expect(0, 55238, '\P{GCB=v}', "");
Expect(1, 55238, '\P{^GCB=v}', "");
Expect(0, 55239, '\p{GCB=v}', "");
Expect(1, 55239, '\p{^GCB=v}', "");
Expect(1, 55239, '\P{GCB=v}', "");
Expect(0, 55239, '\P{^GCB=v}', "");
Expect(1, 55238, '\p{GCB=_	V}', "");
Expect(0, 55238, '\p{^GCB=_	V}', "");
Expect(0, 55238, '\P{GCB=_	V}', "");
Expect(1, 55238, '\P{^GCB=_	V}', "");
Expect(0, 55239, '\p{GCB=_	V}', "");
Expect(1, 55239, '\p{^GCB=_	V}', "");
Expect(1, 55239, '\P{GCB=_	V}', "");
Expect(0, 55239, '\P{^GCB=_	V}', "");
Error('\p{Is_Grapheme_Cluster_Break=	-v:=}');
Error('\P{Is_Grapheme_Cluster_Break=	-v:=}');
Expect(1, 55238, '\p{Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55238, '\p{^Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55238, '\P{Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55238, '\P{^Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55239, '\p{Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55239, '\p{^Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55239, '\P{Is_Grapheme_Cluster_Break=v}', "");
Expect(0, 55239, '\P{^Is_Grapheme_Cluster_Break=v}', "");
Expect(1, 55238, '\p{Is_Grapheme_Cluster_Break=V}', "");
Expect(0, 55238, '\p{^Is_Grapheme_Cluster_Break=V}', "");
Expect(0, 55238, '\P{Is_Grapheme_Cluster_Break=V}', "");
Expect(1, 55238, '\P{^Is_Grapheme_Cluster_Break=V}', "");
Expect(0, 55239, '\p{Is_Grapheme_Cluster_Break=V}', "");
Expect(1, 55239, '\p{^Is_Grapheme_Cluster_Break=V}', "");
Expect(1, 55239, '\P{Is_Grapheme_Cluster_Break=V}', "");
Expect(0, 55239, '\P{^Is_Grapheme_Cluster_Break=V}', "");
Error('\p{Is_GCB::=-V}');
Error('\P{Is_GCB::=-V}');
Expect(1, 55238, '\p{Is_GCB=v}', "");
Expect(0, 55238, '\p{^Is_GCB=v}', "");
Expect(0, 55238, '\P{Is_GCB=v}', "");
Expect(1, 55238, '\P{^Is_GCB=v}', "");
Expect(0, 55239, '\p{Is_GCB=v}', "");
Expect(1, 55239, '\p{^Is_GCB=v}', "");
Expect(1, 55239, '\P{Is_GCB=v}', "");
Expect(0, 55239, '\P{^Is_GCB=v}', "");
Expect(1, 55238, '\p{Is_GCB=	-V}', "");
Expect(0, 55238, '\p{^Is_GCB=	-V}', "");
Expect(0, 55238, '\P{Is_GCB=	-V}', "");
Expect(1, 55238, '\P{^Is_GCB=	-V}', "");
Expect(0, 55239, '\p{Is_GCB=	-V}', "");
Expect(1, 55239, '\p{^Is_GCB=	-V}', "");
Expect(1, 55239, '\P{Is_GCB=	-V}', "");
Expect(0, 55239, '\P{^Is_GCB=	-V}', "");
Error('\p{Grapheme_Cluster_Break=_/a/Other}');
Error('\P{Grapheme_Cluster_Break=_/a/Other}');
Expect(1, 921600, '\p{Grapheme_Cluster_Break=other}', "");
Expect(0, 921600, '\p{^Grapheme_Cluster_Break=other}', "");
Expect(0, 921600, '\P{Grapheme_Cluster_Break=other}', "");
Expect(1, 921600, '\P{^Grapheme_Cluster_Break=other}', "");
Expect(0, 921599, '\p{Grapheme_Cluster_Break=other}', "");
Expect(1, 921599, '\p{^Grapheme_Cluster_Break=other}', "");
Expect(1, 921599, '\P{Grapheme_Cluster_Break=other}', "");
Expect(0, 921599, '\P{^Grapheme_Cluster_Break=other}', "");
Expect(1, 921600, '\p{Grapheme_Cluster_Break= -other}', "");
Expect(0, 921600, '\p{^Grapheme_Cluster_Break= -other}', "");
Expect(0, 921600, '\P{Grapheme_Cluster_Break= -other}', "");
Expect(1, 921600, '\P{^Grapheme_Cluster_Break= -other}', "");
Expect(0, 921599, '\p{Grapheme_Cluster_Break= -other}', "");
Expect(1, 921599, '\p{^Grapheme_Cluster_Break= -other}', "");
Expect(1, 921599, '\P{Grapheme_Cluster_Break= -other}', "");
Expect(0, 921599, '\P{^Grapheme_Cluster_Break= -other}', "");
Error('\p{GCB=/a/-XX}');
Error('\P{GCB=/a/-XX}');
Expect(1, 921600, '\p{GCB=xx}', "");
Expect(0, 921600, '\p{^GCB=xx}', "");
Expect(0, 921600, '\P{GCB=xx}', "");
Expect(1, 921600, '\P{^GCB=xx}', "");
Expect(0, 921599, '\p{GCB=xx}', "");
Expect(1, 921599, '\p{^GCB=xx}', "");
Expect(1, 921599, '\P{GCB=xx}', "");
Expect(0, 921599, '\P{^GCB=xx}', "");
Expect(1, 921600, '\p{GCB=_XX}', "");
Expect(0, 921600, '\p{^GCB=_XX}', "");
Expect(0, 921600, '\P{GCB=_XX}', "");
Expect(1, 921600, '\P{^GCB=_XX}', "");
Expect(0, 921599, '\p{GCB=_XX}', "");
Expect(1, 921599, '\p{^GCB=_XX}', "");
Expect(1, 921599, '\P{GCB=_XX}', "");
Expect(0, 921599, '\P{^GCB=_XX}', "");
Error('\p{Is_Grapheme_Cluster_Break= 	Other:=}');
Error('\P{Is_Grapheme_Cluster_Break= 	Other:=}');
Expect(1, 921600, '\p{Is_Grapheme_Cluster_Break: other}', "");
Expect(0, 921600, '\p{^Is_Grapheme_Cluster_Break: other}', "");
Expect(0, 921600, '\P{Is_Grapheme_Cluster_Break: other}', "");
Expect(1, 921600, '\P{^Is_Grapheme_Cluster_Break: other}', "");
Expect(0, 921599, '\p{Is_Grapheme_Cluster_Break: other}', "");
Expect(1, 921599, '\p{^Is_Grapheme_Cluster_Break: other}', "");
Expect(1, 921599, '\P{Is_Grapheme_Cluster_Break: other}', "");
Expect(0, 921599, '\P{^Is_Grapheme_Cluster_Break: other}', "");
Expect(1, 921600, '\p{Is_Grapheme_Cluster_Break= -other}', "");
Expect(0, 921600, '\p{^Is_Grapheme_Cluster_Break= -other}', "");
Expect(0, 921600, '\P{Is_Grapheme_Cluster_Break= -other}', "");
Expect(1, 921600, '\P{^Is_Grapheme_Cluster_Break= -other}', "");
Expect(0, 921599, '\p{Is_Grapheme_Cluster_Break= -other}', "");
Expect(1, 921599, '\p{^Is_Grapheme_Cluster_Break= -other}', "");
Expect(1, 921599, '\P{Is_Grapheme_Cluster_Break= -other}', "");
Expect(0, 921599, '\P{^Is_Grapheme_Cluster_Break= -other}', "");
Error('\p{Is_GCB=:=-XX}');
Error('\P{Is_GCB=:=-XX}');
Expect(1, 921600, '\p{Is_GCB=xx}', "");
Expect(0, 921600, '\p{^Is_GCB=xx}', "");
Expect(0, 921600, '\P{Is_GCB=xx}', "");
Expect(1, 921600, '\P{^Is_GCB=xx}', "");
Expect(0, 921599, '\p{Is_GCB=xx}', "");
Expect(1, 921599, '\p{^Is_GCB=xx}', "");
Expect(1, 921599, '\P{Is_GCB=xx}', "");
Expect(0, 921599, '\P{^Is_GCB=xx}', "");
Expect(1, 921600, '\p{Is_GCB:  XX}', "");
Expect(0, 921600, '\p{^Is_GCB:  XX}', "");
Expect(0, 921600, '\P{Is_GCB:  XX}', "");
Expect(1, 921600, '\P{^Is_GCB:  XX}', "");
Expect(0, 921599, '\p{Is_GCB:  XX}', "");
Expect(1, 921599, '\p{^Is_GCB:  XX}', "");
Expect(1, 921599, '\P{Is_GCB:  XX}', "");
Expect(0, 921599, '\P{^Is_GCB:  XX}', "");
Error('\p{Grapheme_Base::= -No}');
Error('\P{Grapheme_Base::= -No}');
Expect(1, 195102, '\p{Grapheme_Base=no}', "");
Expect(0, 195102, '\p{^Grapheme_Base=no}', "");
Expect(0, 195102, '\P{Grapheme_Base=no}', "");
Expect(1, 195102, '\P{^Grapheme_Base=no}', "");
Expect(0, 195101, '\p{Grapheme_Base=no}', "");
Expect(1, 195101, '\p{^Grapheme_Base=no}', "");
Expect(1, 195101, '\P{Grapheme_Base=no}', "");
Expect(0, 195101, '\P{^Grapheme_Base=no}', "");
Expect(1, 195102, '\p{Grapheme_Base= -No}', "");
Expect(0, 195102, '\p{^Grapheme_Base= -No}', "");
Expect(0, 195102, '\P{Grapheme_Base= -No}', "");
Expect(1, 195102, '\P{^Grapheme_Base= -No}', "");
Expect(0, 195101, '\p{Grapheme_Base= -No}', "");
Expect(1, 195101, '\p{^Grapheme_Base= -No}', "");
Expect(1, 195101, '\P{Grapheme_Base= -No}', "");
Expect(0, 195101, '\P{^Grapheme_Base= -No}', "");
Error('\p{Gr_Base= /a/N}');
Error('\P{Gr_Base= /a/N}');
Expect(1, 195102, '\p{Gr_Base=n}', "");
Expect(0, 195102, '\p{^Gr_Base=n}', "");
Expect(0, 195102, '\P{Gr_Base=n}', "");
Expect(1, 195102, '\P{^Gr_Base=n}', "");
Expect(0, 195101, '\p{Gr_Base=n}', "");
Expect(1, 195101, '\p{^Gr_Base=n}', "");
Expect(1, 195101, '\P{Gr_Base=n}', "");
Expect(0, 195101, '\P{^Gr_Base=n}', "");
Expect(1, 195102, '\p{Gr_Base=--N}', "");
Expect(0, 195102, '\p{^Gr_Base=--N}', "");
Expect(0, 195102, '\P{Gr_Base=--N}', "");
Expect(1, 195102, '\P{^Gr_Base=--N}', "");
Expect(0, 195101, '\p{Gr_Base=--N}', "");
Expect(1, 195101, '\p{^Gr_Base=--N}', "");
Expect(1, 195101, '\P{Gr_Base=--N}', "");
Expect(0, 195101, '\P{^Gr_Base=--N}', "");
Error('\p{Is_Grapheme_Base= 	F/a/}');
Error('\P{Is_Grapheme_Base= 	F/a/}');
Expect(1, 195102, '\p{Is_Grapheme_Base=f}', "");
Expect(0, 195102, '\p{^Is_Grapheme_Base=f}', "");
Expect(0, 195102, '\P{Is_Grapheme_Base=f}', "");
Expect(1, 195102, '\P{^Is_Grapheme_Base=f}', "");
Expect(0, 195101, '\p{Is_Grapheme_Base=f}', "");
Expect(1, 195101, '\p{^Is_Grapheme_Base=f}', "");
Expect(1, 195101, '\P{Is_Grapheme_Base=f}', "");
Expect(0, 195101, '\P{^Is_Grapheme_Base=f}', "");
Expect(1, 195102, '\p{Is_Grapheme_Base=F}', "");
Expect(0, 195102, '\p{^Is_Grapheme_Base=F}', "");
Expect(0, 195102, '\P{Is_Grapheme_Base=F}', "");
Expect(1, 195102, '\P{^Is_Grapheme_Base=F}', "");
Expect(0, 195101, '\p{Is_Grapheme_Base=F}', "");
Expect(1, 195101, '\p{^Is_Grapheme_Base=F}', "");
Expect(1, 195101, '\P{Is_Grapheme_Base=F}', "");
Expect(0, 195101, '\P{^Is_Grapheme_Base=F}', "");
Error('\p{Is_Gr_Base:   /a/false}');
Error('\P{Is_Gr_Base:   /a/false}');
Expect(1, 195102, '\p{Is_Gr_Base=false}', "");
Expect(0, 195102, '\p{^Is_Gr_Base=false}', "");
Expect(0, 195102, '\P{Is_Gr_Base=false}', "");
Expect(1, 195102, '\P{^Is_Gr_Base=false}', "");
Expect(0, 195101, '\p{Is_Gr_Base=false}', "");
Expect(1, 195101, '\p{^Is_Gr_Base=false}', "");
Expect(1, 195101, '\P{Is_Gr_Base=false}', "");
Expect(0, 195101, '\P{^Is_Gr_Base=false}', "");
Expect(1, 195102, '\p{Is_Gr_Base:   _false}', "");
Expect(0, 195102, '\p{^Is_Gr_Base:   _false}', "");
Expect(0, 195102, '\P{Is_Gr_Base:   _false}', "");
Expect(1, 195102, '\P{^Is_Gr_Base:   _false}', "");
Expect(0, 195101, '\p{Is_Gr_Base:   _false}', "");
Expect(1, 195101, '\p{^Is_Gr_Base:   _false}', "");
Expect(1, 195101, '\P{Is_Gr_Base:   _false}', "");
Expect(0, 195101, '\P{^Is_Gr_Base:   _false}', "");
Error('\p{Grapheme_Base=-	yes/a/}');
Error('\P{Grapheme_Base=-	yes/a/}');
Expect(1, 195101, '\p{Grapheme_Base:yes}', "");
Expect(0, 195101, '\p{^Grapheme_Base:yes}', "");
Expect(0, 195101, '\P{Grapheme_Base:yes}', "");
Expect(1, 195101, '\P{^Grapheme_Base:yes}', "");
Expect(0, 195102, '\p{Grapheme_Base:yes}', "");
Expect(1, 195102, '\p{^Grapheme_Base:yes}', "");
Expect(1, 195102, '\P{Grapheme_Base:yes}', "");
Expect(0, 195102, '\P{^Grapheme_Base:yes}', "");
Expect(1, 195101, '\p{Grapheme_Base=-_Yes}', "");
Expect(0, 195101, '\p{^Grapheme_Base=-_Yes}', "");
Expect(0, 195101, '\P{Grapheme_Base=-_Yes}', "");
Expect(1, 195101, '\P{^Grapheme_Base=-_Yes}', "");
Expect(0, 195102, '\p{Grapheme_Base=-_Yes}', "");
Expect(1, 195102, '\p{^Grapheme_Base=-_Yes}', "");
Expect(1, 195102, '\P{Grapheme_Base=-_Yes}', "");
Expect(0, 195102, '\P{^Grapheme_Base=-_Yes}', "");
Error('\p{Gr_Base=/a/  Y}');
Error('\P{Gr_Base=/a/  Y}');
Expect(1, 195101, '\p{Gr_Base=y}', "");
Expect(0, 195101, '\p{^Gr_Base=y}', "");
Expect(0, 195101, '\P{Gr_Base=y}', "");
Expect(1, 195101, '\P{^Gr_Base=y}', "");
Expect(0, 195102, '\p{Gr_Base=y}', "");
Expect(1, 195102, '\p{^Gr_Base=y}', "");
Expect(1, 195102, '\P{Gr_Base=y}', "");
Expect(0, 195102, '\P{^Gr_Base=y}', "");
Expect(1, 195101, '\p{Gr_Base=  Y}', "");
Expect(0, 195101, '\p{^Gr_Base=  Y}', "");
Expect(0, 195101, '\P{Gr_Base=  Y}', "");
Expect(1, 195101, '\P{^Gr_Base=  Y}', "");
Expect(0, 195102, '\p{Gr_Base=  Y}', "");
Expect(1, 195102, '\p{^Gr_Base=  Y}', "");
Expect(1, 195102, '\P{Gr_Base=  Y}', "");
Expect(0, 195102, '\P{^Gr_Base=  Y}', "");
Error('\p{Is_Grapheme_Base=-/a/T}');
Error('\P{Is_Grapheme_Base=-/a/T}');
Expect(1, 195101, '\p{Is_Grapheme_Base=t}', "");
Expect(0, 195101, '\p{^Is_Grapheme_Base=t}', "");
Expect(0, 195101, '\P{Is_Grapheme_Base=t}', "");
Expect(1, 195101, '\P{^Is_Grapheme_Base=t}', "");
Expect(0, 195102, '\p{Is_Grapheme_Base=t}', "");
Expect(1, 195102, '\p{^Is_Grapheme_Base=t}', "");
Expect(1, 195102, '\P{Is_Grapheme_Base=t}', "");
Expect(0, 195102, '\P{^Is_Grapheme_Base=t}', "");
Expect(1, 195101, '\p{Is_Grapheme_Base=__T}', "");
Expect(0, 195101, '\p{^Is_Grapheme_Base=__T}', "");
Expect(0, 195101, '\P{Is_Grapheme_Base=__T}', "");
Expect(1, 195101, '\P{^Is_Grapheme_Base=__T}', "");
Expect(0, 195102, '\p{Is_Grapheme_Base=__T}', "");
Expect(1, 195102, '\p{^Is_Grapheme_Base=__T}', "");
Expect(1, 195102, '\P{Is_Grapheme_Base=__T}', "");
Expect(0, 195102, '\P{^Is_Grapheme_Base=__T}', "");
Error('\p{Is_Gr_Base=-/a/TRUE}');
Error('\P{Is_Gr_Base=-/a/TRUE}');
Expect(1, 195101, '\p{Is_Gr_Base=true}', "");
Expect(0, 195101, '\p{^Is_Gr_Base=true}', "");
Expect(0, 195101, '\P{Is_Gr_Base=true}', "");
Expect(1, 195101, '\P{^Is_Gr_Base=true}', "");
Expect(0, 195102, '\p{Is_Gr_Base=true}', "");
Expect(1, 195102, '\p{^Is_Gr_Base=true}', "");
Expect(1, 195102, '\P{Is_Gr_Base=true}', "");
Expect(0, 195102, '\P{^Is_Gr_Base=true}', "");
Expect(1, 195101, '\p{Is_Gr_Base=--TRUE}', "");
Expect(0, 195101, '\p{^Is_Gr_Base=--TRUE}', "");
Expect(0, 195101, '\P{Is_Gr_Base=--TRUE}', "");
Expect(1, 195101, '\P{^Is_Gr_Base=--TRUE}', "");
Expect(0, 195102, '\p{Is_Gr_Base=--TRUE}', "");
Expect(1, 195102, '\p{^Is_Gr_Base=--TRUE}', "");
Expect(1, 195102, '\P{Is_Gr_Base=--TRUE}', "");
Expect(0, 195102, '\P{^Is_Gr_Base=--TRUE}', "");
Error('\p{Grapheme_Extend=:=_No}');
Error('\P{Grapheme_Extend=:=_No}');
Expect(1, 918000, '\p{Grapheme_Extend=no}', "");
Expect(0, 918000, '\p{^Grapheme_Extend=no}', "");
Expect(0, 918000, '\P{Grapheme_Extend=no}', "");
Expect(1, 918000, '\P{^Grapheme_Extend=no}', "");
Expect(0, 917999, '\p{Grapheme_Extend=no}', "");
Expect(1, 917999, '\p{^Grapheme_Extend=no}', "");
Expect(1, 917999, '\P{Grapheme_Extend=no}', "");
Expect(0, 917999, '\P{^Grapheme_Extend=no}', "");
Expect(1, 918000, '\p{Grapheme_Extend=-no}', "");
Expect(0, 918000, '\p{^Grapheme_Extend=-no}', "");
Expect(0, 918000, '\P{Grapheme_Extend=-no}', "");
Expect(1, 918000, '\P{^Grapheme_Extend=-no}', "");
Expect(0, 917999, '\p{Grapheme_Extend=-no}', "");
Expect(1, 917999, '\p{^Grapheme_Extend=-no}', "");
Expect(1, 917999, '\P{Grapheme_Extend=-no}', "");
Expect(0, 917999, '\P{^Grapheme_Extend=-no}', "");
Error('\p{Gr_Ext=:=N}');
Error('\P{Gr_Ext=:=N}');
Expect(1, 918000, '\p{Gr_Ext=n}', "");
Expect(0, 918000, '\p{^Gr_Ext=n}', "");
Expect(0, 918000, '\P{Gr_Ext=n}', "");
Expect(1, 918000, '\P{^Gr_Ext=n}', "");
Expect(0, 917999, '\p{Gr_Ext=n}', "");
Expect(1, 917999, '\p{^Gr_Ext=n}', "");
Expect(1, 917999, '\P{Gr_Ext=n}', "");
Expect(0, 917999, '\P{^Gr_Ext=n}', "");
Expect(1, 918000, '\p{Gr_Ext= _n}', "");
Expect(0, 918000, '\p{^Gr_Ext= _n}', "");
Expect(0, 918000, '\P{Gr_Ext= _n}', "");
Expect(1, 918000, '\P{^Gr_Ext= _n}', "");
Expect(0, 917999, '\p{Gr_Ext= _n}', "");
Expect(1, 917999, '\p{^Gr_Ext= _n}', "");
Expect(1, 917999, '\P{Gr_Ext= _n}', "");
Expect(0, 917999, '\P{^Gr_Ext= _n}', "");
Error('\p{Is_Grapheme_Extend= -F/a/}');
Error('\P{Is_Grapheme_Extend= -F/a/}');
Expect(1, 918000, '\p{Is_Grapheme_Extend=f}', "");
Expect(0, 918000, '\p{^Is_Grapheme_Extend=f}', "");
Expect(0, 918000, '\P{Is_Grapheme_Extend=f}', "");
Expect(1, 918000, '\P{^Is_Grapheme_Extend=f}', "");
Expect(0, 917999, '\p{Is_Grapheme_Extend=f}', "");
Expect(1, 917999, '\p{^Is_Grapheme_Extend=f}', "");
Expect(1, 917999, '\P{Is_Grapheme_Extend=f}', "");
Expect(0, 917999, '\P{^Is_Grapheme_Extend=f}', "");
Expect(1, 918000, '\p{Is_Grapheme_Extend:    _F}', "");
Expect(0, 918000, '\p{^Is_Grapheme_Extend:    _F}', "");
Expect(0, 918000, '\P{Is_Grapheme_Extend:    _F}', "");
Expect(1, 918000, '\P{^Is_Grapheme_Extend:    _F}', "");
Expect(0, 917999, '\p{Is_Grapheme_Extend:    _F}', "");
Expect(1, 917999, '\p{^Is_Grapheme_Extend:    _F}', "");
Expect(1, 917999, '\P{Is_Grapheme_Extend:    _F}', "");
Expect(0, 917999, '\P{^Is_Grapheme_Extend:    _F}', "");
Error('\p{Is_Gr_Ext:			False/a/}');
Error('\P{Is_Gr_Ext:			False/a/}');
Expect(1, 918000, '\p{Is_Gr_Ext=false}', "");
Expect(0, 918000, '\p{^Is_Gr_Ext=false}', "");
Expect(0, 918000, '\P{Is_Gr_Ext=false}', "");
Expect(1, 918000, '\P{^Is_Gr_Ext=false}', "");
Expect(0, 917999, '\p{Is_Gr_Ext=false}', "");
Expect(1, 917999, '\p{^Is_Gr_Ext=false}', "");
Expect(1, 917999, '\P{Is_Gr_Ext=false}', "");
Expect(0, 917999, '\P{^Is_Gr_Ext=false}', "");
Expect(1, 918000, '\p{Is_Gr_Ext=		FALSE}', "");
Expect(0, 918000, '\p{^Is_Gr_Ext=		FALSE}', "");
Expect(0, 918000, '\P{Is_Gr_Ext=		FALSE}', "");
Expect(1, 918000, '\P{^Is_Gr_Ext=		FALSE}', "");
Expect(0, 917999, '\p{Is_Gr_Ext=		FALSE}', "");
Expect(1, 917999, '\p{^Is_Gr_Ext=		FALSE}', "");
Expect(1, 917999, '\P{Is_Gr_Ext=		FALSE}', "");
Expect(0, 917999, '\P{^Is_Gr_Ext=		FALSE}', "");
Error('\p{Grapheme_Extend=-:=YES}');
Error('\P{Grapheme_Extend=-:=YES}');
Expect(1, 917999, '\p{Grapheme_Extend=yes}', "");
Expect(0, 917999, '\p{^Grapheme_Extend=yes}', "");
Expect(0, 917999, '\P{Grapheme_Extend=yes}', "");
Expect(1, 917999, '\P{^Grapheme_Extend=yes}', "");
Expect(0, 918000, '\p{Grapheme_Extend=yes}', "");
Expect(1, 918000, '\p{^Grapheme_Extend=yes}', "");
Expect(1, 918000, '\P{Grapheme_Extend=yes}', "");
Expect(0, 918000, '\P{^Grapheme_Extend=yes}', "");
Expect(1, 917999, '\p{Grapheme_Extend=	Yes}', "");
Expect(0, 917999, '\p{^Grapheme_Extend=	Yes}', "");
Expect(0, 917999, '\P{Grapheme_Extend=	Yes}', "");
Expect(1, 917999, '\P{^Grapheme_Extend=	Yes}', "");
Expect(0, 918000, '\p{Grapheme_Extend=	Yes}', "");
Expect(1, 918000, '\p{^Grapheme_Extend=	Yes}', "");
Expect(1, 918000, '\P{Grapheme_Extend=	Yes}', "");
Expect(0, 918000, '\P{^Grapheme_Extend=	Yes}', "");
Error('\p{Gr_Ext=/a/--y}');
Error('\P{Gr_Ext=/a/--y}');
Expect(1, 917999, '\p{Gr_Ext=y}', "");
Expect(0, 917999, '\p{^Gr_Ext=y}', "");
Expect(0, 917999, '\P{Gr_Ext=y}', "");
Expect(1, 917999, '\P{^Gr_Ext=y}', "");
Expect(0, 918000, '\p{Gr_Ext=y}', "");
Expect(1, 918000, '\p{^Gr_Ext=y}', "");
Expect(1, 918000, '\P{Gr_Ext=y}', "");
Expect(0, 918000, '\P{^Gr_Ext=y}', "");
Expect(1, 917999, '\p{Gr_Ext=--Y}', "");
Expect(0, 917999, '\p{^Gr_Ext=--Y}', "");
Expect(0, 917999, '\P{Gr_Ext=--Y}', "");
Expect(1, 917999, '\P{^Gr_Ext=--Y}', "");
Expect(0, 918000, '\p{Gr_Ext=--Y}', "");
Expect(1, 918000, '\p{^Gr_Ext=--Y}', "");
Expect(1, 918000, '\P{Gr_Ext=--Y}', "");
Expect(0, 918000, '\P{^Gr_Ext=--Y}', "");
Error('\p{Is_Grapheme_Extend=:= _T}');
Error('\P{Is_Grapheme_Extend=:= _T}');
Expect(1, 917999, '\p{Is_Grapheme_Extend:   t}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Extend:   t}', "");
Expect(0, 917999, '\P{Is_Grapheme_Extend:   t}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Extend:   t}', "");
Expect(0, 918000, '\p{Is_Grapheme_Extend:   t}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Extend:   t}', "");
Expect(1, 918000, '\P{Is_Grapheme_Extend:   t}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Extend:   t}', "");
Expect(1, 917999, '\p{Is_Grapheme_Extend:  -T}', "");
Expect(0, 917999, '\p{^Is_Grapheme_Extend:  -T}', "");
Expect(0, 917999, '\P{Is_Grapheme_Extend:  -T}', "");
Expect(1, 917999, '\P{^Is_Grapheme_Extend:  -T}', "");
Expect(0, 918000, '\p{Is_Grapheme_Extend:  -T}', "");
Expect(1, 918000, '\p{^Is_Grapheme_Extend:  -T}', "");
Expect(1, 918000, '\P{Is_Grapheme_Extend:  -T}', "");
Expect(0, 918000, '\P{^Is_Grapheme_Extend:  -T}', "");
Error('\p{Is_Gr_Ext=-/a/True}');
Error('\P{Is_Gr_Ext=-/a/True}');
Expect(1, 917999, '\p{Is_Gr_Ext:	true}', "");
Expect(0, 917999, '\p{^Is_Gr_Ext:	true}', "");
Expect(0, 917999, '\P{Is_Gr_Ext:	true}', "");
Expect(1, 917999, '\P{^Is_Gr_Ext:	true}', "");
Expect(0, 918000, '\p{Is_Gr_Ext:	true}', "");
Expect(1, 918000, '\p{^Is_Gr_Ext:	true}', "");
Expect(1, 918000, '\P{Is_Gr_Ext:	true}', "");
Expect(0, 918000, '\P{^Is_Gr_Ext:	true}', "");
Expect(1, 917999, '\p{Is_Gr_Ext= True}', "");
Expect(0, 917999, '\p{^Is_Gr_Ext= True}', "");
Expect(0, 917999, '\P{Is_Gr_Ext= True}', "");
Expect(1, 917999, '\P{^Is_Gr_Ext= True}', "");
Expect(0, 918000, '\p{Is_Gr_Ext= True}', "");
Expect(1, 918000, '\p{^Is_Gr_Ext= True}', "");
Expect(1, 918000, '\P{Is_Gr_Ext= True}', "");
Expect(0, 918000, '\P{^Is_Gr_Ext= True}', "");
Error('\p{Grapheme_Link=No}');
Error('\P{Grapheme_Link=No}');
Error('\p{Gr_Link=N}');
Error('\P{Gr_Link=N}');
Error('\p{Is_Grapheme_Link:   F}');
Error('\P{Is_Grapheme_Link:   F}');
Error('\p{Is_Gr_Link=False}');
Error('\P{Is_Gr_Link=False}');
Error('\p{Grapheme_Link=Yes}');
Error('\P{Grapheme_Link=Yes}');
Error('\p{Gr_Link=Y}');
Error('\P{Gr_Link=Y}');
Error('\p{Is_Grapheme_Link=T}');
Error('\P{Is_Grapheme_Link=T}');
Error('\p{Is_Gr_Link=True}');
Error('\P{Is_Gr_Link=True}');
Error('\p{Hex_Digit=:=no}');
Error('\P{Hex_Digit=:=no}');
Expect(1, 65351, '\p{Hex_Digit=no}', "");
Expect(0, 65351, '\p{^Hex_Digit=no}', "");
Expect(0, 65351, '\P{Hex_Digit=no}', "");
Expect(1, 65351, '\P{^Hex_Digit=no}', "");
Expect(0, 65350, '\p{Hex_Digit=no}', "");
Expect(1, 65350, '\p{^Hex_Digit=no}', "");
Expect(1, 65350, '\P{Hex_Digit=no}', "");
Expect(0, 65350, '\P{^Hex_Digit=no}', "");
Expect(1, 65351, '\p{Hex_Digit:    _No}', "");
Expect(0, 65351, '\p{^Hex_Digit:    _No}', "");
Expect(0, 65351, '\P{Hex_Digit:    _No}', "");
Expect(1, 65351, '\P{^Hex_Digit:    _No}', "");
Expect(0, 65350, '\p{Hex_Digit:    _No}', "");
Expect(1, 65350, '\p{^Hex_Digit:    _No}', "");
Expect(1, 65350, '\P{Hex_Digit:    _No}', "");
Expect(0, 65350, '\P{^Hex_Digit:    _No}', "");
Error('\p{Hex=:=_	N}');
Error('\P{Hex=:=_	N}');
Expect(1, 65351, '\p{Hex=n}', "");
Expect(0, 65351, '\p{^Hex=n}', "");
Expect(0, 65351, '\P{Hex=n}', "");
Expect(1, 65351, '\P{^Hex=n}', "");
Expect(0, 65350, '\p{Hex=n}', "");
Expect(1, 65350, '\p{^Hex=n}', "");
Expect(1, 65350, '\P{Hex=n}', "");
Expect(0, 65350, '\P{^Hex=n}', "");
Expect(1, 65351, '\p{Hex=_ n}', "");
Expect(0, 65351, '\p{^Hex=_ n}', "");
Expect(0, 65351, '\P{Hex=_ n}', "");
Expect(1, 65351, '\P{^Hex=_ n}', "");
Expect(0, 65350, '\p{Hex=_ n}', "");
Expect(1, 65350, '\p{^Hex=_ n}', "");
Expect(1, 65350, '\P{Hex=_ n}', "");
Expect(0, 65350, '\P{^Hex=_ n}', "");
Error('\p{Is_Hex_Digit:	:=f}');
Error('\P{Is_Hex_Digit:	:=f}');
Expect(1, 65351, '\p{Is_Hex_Digit=f}', "");
Expect(0, 65351, '\p{^Is_Hex_Digit=f}', "");
Expect(0, 65351, '\P{Is_Hex_Digit=f}', "");
Expect(1, 65351, '\P{^Is_Hex_Digit=f}', "");
Expect(0, 65350, '\p{Is_Hex_Digit=f}', "");
Expect(1, 65350, '\p{^Is_Hex_Digit=f}', "");
Expect(1, 65350, '\P{Is_Hex_Digit=f}', "");
Expect(0, 65350, '\P{^Is_Hex_Digit=f}', "");
Expect(1, 65351, '\p{Is_Hex_Digit=__f}', "");
Expect(0, 65351, '\p{^Is_Hex_Digit=__f}', "");
Expect(0, 65351, '\P{Is_Hex_Digit=__f}', "");
Expect(1, 65351, '\P{^Is_Hex_Digit=__f}', "");
Expect(0, 65350, '\p{Is_Hex_Digit=__f}', "");
Expect(1, 65350, '\p{^Is_Hex_Digit=__f}', "");
Expect(1, 65350, '\P{Is_Hex_Digit=__f}', "");
Expect(0, 65350, '\P{^Is_Hex_Digit=__f}', "");
Error('\p{Is_Hex=	:=false}');
Error('\P{Is_Hex=	:=false}');
Expect(1, 65351, '\p{Is_Hex=false}', "");
Expect(0, 65351, '\p{^Is_Hex=false}', "");
Expect(0, 65351, '\P{Is_Hex=false}', "");
Expect(1, 65351, '\P{^Is_Hex=false}', "");
Expect(0, 65350, '\p{Is_Hex=false}', "");
Expect(1, 65350, '\p{^Is_Hex=false}', "");
Expect(1, 65350, '\P{Is_Hex=false}', "");
Expect(0, 65350, '\P{^Is_Hex=false}', "");
Expect(1, 65351, '\p{Is_Hex=	_FALSE}', "");
Expect(0, 65351, '\p{^Is_Hex=	_FALSE}', "");
Expect(0, 65351, '\P{Is_Hex=	_FALSE}', "");
Expect(1, 65351, '\P{^Is_Hex=	_FALSE}', "");
Expect(0, 65350, '\p{Is_Hex=	_FALSE}', "");
Expect(1, 65350, '\p{^Is_Hex=	_FALSE}', "");
Expect(1, 65350, '\P{Is_Hex=	_FALSE}', "");
Expect(0, 65350, '\P{^Is_Hex=	_FALSE}', "");
Error('\p{Hex_Digit:	/a/-Yes}');
Error('\P{Hex_Digit:	/a/-Yes}');
Expect(1, 65350, '\p{Hex_Digit=yes}', "");
Expect(0, 65350, '\p{^Hex_Digit=yes}', "");
Expect(0, 65350, '\P{Hex_Digit=yes}', "");
Expect(1, 65350, '\P{^Hex_Digit=yes}', "");
Expect(0, 65351, '\p{Hex_Digit=yes}', "");
Expect(1, 65351, '\p{^Hex_Digit=yes}', "");
Expect(1, 65351, '\P{Hex_Digit=yes}', "");
Expect(0, 65351, '\P{^Hex_Digit=yes}', "");
Expect(1, 65350, '\p{Hex_Digit=	Yes}', "");
Expect(0, 65350, '\p{^Hex_Digit=	Yes}', "");
Expect(0, 65350, '\P{Hex_Digit=	Yes}', "");
Expect(1, 65350, '\P{^Hex_Digit=	Yes}', "");
Expect(0, 65351, '\p{Hex_Digit=	Yes}', "");
Expect(1, 65351, '\p{^Hex_Digit=	Yes}', "");
Expect(1, 65351, '\P{Hex_Digit=	Yes}', "");
Expect(0, 65351, '\P{^Hex_Digit=	Yes}', "");
Error('\p{Hex:  -Y:=}');
Error('\P{Hex:  -Y:=}');
Expect(1, 65350, '\p{Hex=y}', "");
Expect(0, 65350, '\p{^Hex=y}', "");
Expect(0, 65350, '\P{Hex=y}', "");
Expect(1, 65350, '\P{^Hex=y}', "");
Expect(0, 65351, '\p{Hex=y}', "");
Expect(1, 65351, '\p{^Hex=y}', "");
Expect(1, 65351, '\P{Hex=y}', "");
Expect(0, 65351, '\P{^Hex=y}', "");
Expect(1, 65350, '\p{Hex=	 y}', "");
Expect(0, 65350, '\p{^Hex=	 y}', "");
Expect(0, 65350, '\P{Hex=	 y}', "");
Expect(1, 65350, '\P{^Hex=	 y}', "");
Expect(0, 65351, '\p{Hex=	 y}', "");
Expect(1, 65351, '\p{^Hex=	 y}', "");
Expect(1, 65351, '\P{Hex=	 y}', "");
Expect(0, 65351, '\P{^Hex=	 y}', "");
Error('\p{Is_Hex_Digit:    /a/T}');
Error('\P{Is_Hex_Digit:    /a/T}');
Expect(1, 65350, '\p{Is_Hex_Digit=t}', "");
Expect(0, 65350, '\p{^Is_Hex_Digit=t}', "");
Expect(0, 65350, '\P{Is_Hex_Digit=t}', "");
Expect(1, 65350, '\P{^Is_Hex_Digit=t}', "");
Expect(0, 65351, '\p{Is_Hex_Digit=t}', "");
Expect(1, 65351, '\p{^Is_Hex_Digit=t}', "");
Expect(1, 65351, '\P{Is_Hex_Digit=t}', "");
Expect(0, 65351, '\P{^Is_Hex_Digit=t}', "");
Expect(1, 65350, '\p{Is_Hex_Digit= _T}', "");
Expect(0, 65350, '\p{^Is_Hex_Digit= _T}', "");
Expect(0, 65350, '\P{Is_Hex_Digit= _T}', "");
Expect(1, 65350, '\P{^Is_Hex_Digit= _T}', "");
Expect(0, 65351, '\p{Is_Hex_Digit= _T}', "");
Expect(1, 65351, '\p{^Is_Hex_Digit= _T}', "");
Expect(1, 65351, '\P{Is_Hex_Digit= _T}', "");
Expect(0, 65351, '\P{^Is_Hex_Digit= _T}', "");
Error('\p{Is_Hex=/a/True}');
Error('\P{Is_Hex=/a/True}');
Expect(1, 65350, '\p{Is_Hex=true}', "");
Expect(0, 65350, '\p{^Is_Hex=true}', "");
Expect(0, 65350, '\P{Is_Hex=true}', "");
Expect(1, 65350, '\P{^Is_Hex=true}', "");
Expect(0, 65351, '\p{Is_Hex=true}', "");
Expect(1, 65351, '\p{^Is_Hex=true}', "");
Expect(1, 65351, '\P{Is_Hex=true}', "");
Expect(0, 65351, '\P{^Is_Hex=true}', "");
Expect(1, 65350, '\p{Is_Hex=	True}', "");
Expect(0, 65350, '\p{^Is_Hex=	True}', "");
Expect(0, 65350, '\P{Is_Hex=	True}', "");
Expect(1, 65350, '\P{^Is_Hex=	True}', "");
Expect(0, 65351, '\p{Is_Hex=	True}', "");
Expect(1, 65351, '\p{^Is_Hex=	True}', "");
Expect(1, 65351, '\P{Is_Hex=	True}', "");
Expect(0, 65351, '\P{^Is_Hex=	True}', "");
Error('\p{Hyphen=_:=no}');
Error('\P{Hyphen=_:=no}');
Expect(1, 65382, '\p{Hyphen=no}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen=no}', 'deprecated');
Expect(0, 65382, '\P{Hyphen=no}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen=no}', 'deprecated');
Expect(0, 65381, '\p{Hyphen=no}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen=no}', 'deprecated');
Expect(1, 65381, '\P{Hyphen=no}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen=no}', 'deprecated');
Expect(1, 65382, '\p{Hyphen= _No}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen= _No}', 'deprecated');
Expect(0, 65382, '\P{Hyphen= _No}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen= _No}', 'deprecated');
Expect(0, 65381, '\p{Hyphen= _No}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen= _No}', 'deprecated');
Expect(1, 65381, '\P{Hyphen= _No}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen= _No}', 'deprecated');
Error('\p{Is_Hyphen=:=	N}');
Error('\P{Is_Hyphen=:=	N}');
Expect(1, 65382, '\p{Is_Hyphen=n}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=n}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=n}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=n}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=n}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=n}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=n}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=n}', 'deprecated');
Expect(1, 65382, '\p{Is_Hyphen=--n}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=--n}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=--n}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=--n}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=--n}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=--n}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=--n}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=--n}', 'deprecated');
Error('\p{Hyphen=-:=F}');
Error('\P{Hyphen=-:=F}');
Expect(1, 65382, '\p{Hyphen:f}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen:f}', 'deprecated');
Expect(0, 65382, '\P{Hyphen:f}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen:f}', 'deprecated');
Expect(0, 65381, '\p{Hyphen:f}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen:f}', 'deprecated');
Expect(1, 65381, '\P{Hyphen:f}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen:f}', 'deprecated');
Expect(1, 65382, '\p{Hyphen=	F}', 'deprecated');
Expect(0, 65382, '\p{^Hyphen=	F}', 'deprecated');
Expect(0, 65382, '\P{Hyphen=	F}', 'deprecated');
Expect(1, 65382, '\P{^Hyphen=	F}', 'deprecated');
Expect(0, 65381, '\p{Hyphen=	F}', 'deprecated');
Expect(1, 65381, '\p{^Hyphen=	F}', 'deprecated');
Expect(1, 65381, '\P{Hyphen=	F}', 'deprecated');
Expect(0, 65381, '\P{^Hyphen=	F}', 'deprecated');
Error('\p{Is_Hyphen= /a/False}');
Error('\P{Is_Hyphen= /a/False}');
Expect(1, 65382, '\p{Is_Hyphen=false}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen=false}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen=false}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen=false}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen=false}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen=false}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen=false}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen=false}', 'deprecated');
Expect(1, 65382, '\p{Is_Hyphen:-False}', 'deprecated');
Expect(0, 65382, '\p{^Is_Hyphen:-False}', 'deprecated');
Expect(0, 65382, '\P{Is_Hyphen:-False}', 'deprecated');
Expect(1, 65382, '\P{^Is_Hyphen:-False}', 'deprecated');
Expect(0, 65381, '\p{Is_Hyphen:-False}', 'deprecated');
Expect(1, 65381, '\p{^Is_Hyphen:-False}', 'deprecated');
Expect(1, 65381, '\P{Is_Hyphen:-False}', 'deprecated');
Expect(0, 65381, '\P{^Is_Hyphen:-False}', 'deprecated');
Error('\p{Hyphen=	_Yes/a/}');
Error('\P{Hyphen=	_Yes/a/}');
Expect(1, 65381, '\p{Hyphen=yes}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen=yes}', 'deprecated');
Expect(0, 65381, '\P{Hyphen=yes}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen=yes}', 'deprecated');
Expect(0, 65382, '\p{Hyphen=yes}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen=yes}', 'deprecated');
Expect(1, 65382, '\P{Hyphen=yes}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen=yes}', 'deprecated');
Expect(1, 65381, '\p{Hyphen= 	YES}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen= 	YES}', 'deprecated');
Expect(0, 65381, '\P{Hyphen= 	YES}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen= 	YES}', 'deprecated');
Expect(0, 65382, '\p{Hyphen= 	YES}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen= 	YES}', 'deprecated');
Expect(1, 65382, '\P{Hyphen= 	YES}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen= 	YES}', 'deprecated');
Error('\p{Is_Hyphen=/a/--Y}');
Error('\P{Is_Hyphen=/a/--Y}');
Expect(1, 65381, '\p{Is_Hyphen=y}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=y}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=y}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=y}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=y}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=y}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=y}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=y}', 'deprecated');
Expect(1, 65381, '\p{Is_Hyphen=_	y}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=_	y}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=_	y}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=_	y}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=_	y}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=_	y}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=_	y}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=_	y}', 'deprecated');
Error('\p{Hyphen=	-t:=}');
Error('\P{Hyphen=	-t:=}');
Expect(1, 65381, '\p{Hyphen=t}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen=t}', 'deprecated');
Expect(0, 65381, '\P{Hyphen=t}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen=t}', 'deprecated');
Expect(0, 65382, '\p{Hyphen=t}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen=t}', 'deprecated');
Expect(1, 65382, '\P{Hyphen=t}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen=t}', 'deprecated');
Expect(1, 65381, '\p{Hyphen= T}', 'deprecated');
Expect(0, 65381, '\p{^Hyphen= T}', 'deprecated');
Expect(0, 65381, '\P{Hyphen= T}', 'deprecated');
Expect(1, 65381, '\P{^Hyphen= T}', 'deprecated');
Expect(0, 65382, '\p{Hyphen= T}', 'deprecated');
Expect(1, 65382, '\p{^Hyphen= T}', 'deprecated');
Expect(1, 65382, '\P{Hyphen= T}', 'deprecated');
Expect(0, 65382, '\P{^Hyphen= T}', 'deprecated');
Error('\p{Is_Hyphen=:=  True}');
Error('\P{Is_Hyphen=:=  True}');
Expect(1, 65381, '\p{Is_Hyphen=true}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=true}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=true}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=true}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=true}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=true}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=true}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=true}', 'deprecated');
Expect(1, 65381, '\p{Is_Hyphen=-TRUE}', 'deprecated');
Expect(0, 65381, '\p{^Is_Hyphen=-TRUE}', 'deprecated');
Expect(0, 65381, '\P{Is_Hyphen=-TRUE}', 'deprecated');
Expect(1, 65381, '\P{^Is_Hyphen=-TRUE}', 'deprecated');
Expect(0, 65382, '\p{Is_Hyphen=-TRUE}', 'deprecated');
Expect(1, 65382, '\p{^Is_Hyphen=-TRUE}', 'deprecated');
Expect(1, 65382, '\P{Is_Hyphen=-TRUE}', 'deprecated');
Expect(0, 65382, '\P{^Is_Hyphen=-TRUE}', 'deprecated');
Error('\p{ID_Continue=/a/  No}');
Error('\P{ID_Continue=/a/  No}');
Expect(1, 918000, '\p{ID_Continue=no}', "");
Expect(0, 918000, '\p{^ID_Continue=no}', "");
Expect(0, 918000, '\P{ID_Continue=no}', "");
Expect(1, 918000, '\P{^ID_Continue=no}', "");
Expect(0, 917999, '\p{ID_Continue=no}', "");
Expect(1, 917999, '\p{^ID_Continue=no}', "");
Expect(1, 917999, '\P{ID_Continue=no}', "");
Expect(0, 917999, '\P{^ID_Continue=no}', "");
Expect(1, 918000, '\p{ID_Continue=-No}', "");
Expect(0, 918000, '\p{^ID_Continue=-No}', "");
Expect(0, 918000, '\P{ID_Continue=-No}', "");
Expect(1, 918000, '\P{^ID_Continue=-No}', "");
Expect(0, 917999, '\p{ID_Continue=-No}', "");
Expect(1, 917999, '\p{^ID_Continue=-No}', "");
Expect(1, 917999, '\P{ID_Continue=-No}', "");
Expect(0, 917999, '\P{^ID_Continue=-No}', "");
Error('\p{IDC: 	 N/a/}');
Error('\P{IDC: 	 N/a/}');
Expect(1, 918000, '\p{IDC=n}', "");
Expect(0, 918000, '\p{^IDC=n}', "");
Expect(0, 918000, '\P{IDC=n}', "");
Expect(1, 918000, '\P{^IDC=n}', "");
Expect(0, 917999, '\p{IDC=n}', "");
Expect(1, 917999, '\p{^IDC=n}', "");
Expect(1, 917999, '\P{IDC=n}', "");
Expect(0, 917999, '\P{^IDC=n}', "");
Expect(1, 918000, '\p{IDC= -n}', "");
Expect(0, 918000, '\p{^IDC= -n}', "");
Expect(0, 918000, '\P{IDC= -n}', "");
Expect(1, 918000, '\P{^IDC= -n}', "");
Expect(0, 917999, '\p{IDC= -n}', "");
Expect(1, 917999, '\p{^IDC= -n}', "");
Expect(1, 917999, '\P{IDC= -n}', "");
Expect(0, 917999, '\P{^IDC= -n}', "");
Error('\p{Is_ID_Continue=	:=F}');
Error('\P{Is_ID_Continue=	:=F}');
Expect(1, 918000, '\p{Is_ID_Continue=f}', "");
Expect(0, 918000, '\p{^Is_ID_Continue=f}', "");
Expect(0, 918000, '\P{Is_ID_Continue=f}', "");
Expect(1, 918000, '\P{^Is_ID_Continue=f}', "");
Expect(0, 917999, '\p{Is_ID_Continue=f}', "");
Expect(1, 917999, '\p{^Is_ID_Continue=f}', "");
Expect(1, 917999, '\P{Is_ID_Continue=f}', "");
Expect(0, 917999, '\P{^Is_ID_Continue=f}', "");
Expect(1, 918000, '\p{Is_ID_Continue=	_f}', "");
Expect(0, 918000, '\p{^Is_ID_Continue=	_f}', "");
Expect(0, 918000, '\P{Is_ID_Continue=	_f}', "");
Expect(1, 918000, '\P{^Is_ID_Continue=	_f}', "");
Expect(0, 917999, '\p{Is_ID_Continue=	_f}', "");
Expect(1, 917999, '\p{^Is_ID_Continue=	_f}', "");
Expect(1, 917999, '\P{Is_ID_Continue=	_f}', "");
Expect(0, 917999, '\P{^Is_ID_Continue=	_f}', "");
Error('\p{Is_IDC=:=	-False}');
Error('\P{Is_IDC=:=	-False}');
Expect(1, 918000, '\p{Is_IDC:   false}', "");
Expect(0, 918000, '\p{^Is_IDC:   false}', "");
Expect(0, 918000, '\P{Is_IDC:   false}', "");
Expect(1, 918000, '\P{^Is_IDC:   false}', "");
Expect(0, 917999, '\p{Is_IDC:   false}', "");
Expect(1, 917999, '\p{^Is_IDC:   false}', "");
Expect(1, 917999, '\P{Is_IDC:   false}', "");
Expect(0, 917999, '\P{^Is_IDC:   false}', "");
Expect(1, 918000, '\p{Is_IDC=FALSE}', "");
Expect(0, 918000, '\p{^Is_IDC=FALSE}', "");
Expect(0, 918000, '\P{Is_IDC=FALSE}', "");
Expect(1, 918000, '\P{^Is_IDC=FALSE}', "");
Expect(0, 917999, '\p{Is_IDC=FALSE}', "");
Expect(1, 917999, '\p{^Is_IDC=FALSE}', "");
Expect(1, 917999, '\P{Is_IDC=FALSE}', "");
Expect(0, 917999, '\P{^Is_IDC=FALSE}', "");
Error('\p{ID_Continue=--Yes:=}');
Error('\P{ID_Continue=--Yes:=}');
Expect(1, 917999, '\p{ID_Continue=yes}', "");
Expect(0, 917999, '\p{^ID_Continue=yes}', "");
Expect(0, 917999, '\P{ID_Continue=yes}', "");
Expect(1, 917999, '\P{^ID_Continue=yes}', "");
Expect(0, 918000, '\p{ID_Continue=yes}', "");
Expect(1, 918000, '\p{^ID_Continue=yes}', "");
Expect(1, 918000, '\P{ID_Continue=yes}', "");
Expect(0, 918000, '\P{^ID_Continue=yes}', "");
Expect(1, 917999, '\p{ID_Continue=_yes}', "");
Expect(0, 917999, '\p{^ID_Continue=_yes}', "");
Expect(0, 917999, '\P{ID_Continue=_yes}', "");
Expect(1, 917999, '\P{^ID_Continue=_yes}', "");
Expect(0, 918000, '\p{ID_Continue=_yes}', "");
Expect(1, 918000, '\p{^ID_Continue=_yes}', "");
Expect(1, 918000, '\P{ID_Continue=_yes}', "");
Expect(0, 918000, '\P{^ID_Continue=_yes}', "");
Error('\p{IDC:	:= 	Y}');
Error('\P{IDC:	:= 	Y}');
Expect(1, 917999, '\p{IDC:	y}', "");
Expect(0, 917999, '\p{^IDC:	y}', "");
Expect(0, 917999, '\P{IDC:	y}', "");
Expect(1, 917999, '\P{^IDC:	y}', "");
Expect(0, 918000, '\p{IDC:	y}', "");
Expect(1, 918000, '\p{^IDC:	y}', "");
Expect(1, 918000, '\P{IDC:	y}', "");
Expect(0, 918000, '\P{^IDC:	y}', "");
Expect(1, 917999, '\p{IDC=  Y}', "");
Expect(0, 917999, '\p{^IDC=  Y}', "");
Expect(0, 917999, '\P{IDC=  Y}', "");
Expect(1, 917999, '\P{^IDC=  Y}', "");
Expect(0, 918000, '\p{IDC=  Y}', "");
Expect(1, 918000, '\p{^IDC=  Y}', "");
Expect(1, 918000, '\P{IDC=  Y}', "");
Expect(0, 918000, '\P{^IDC=  Y}', "");
Error('\p{Is_ID_Continue=:= T}');
Error('\P{Is_ID_Continue=:= T}');
Expect(1, 917999, '\p{Is_ID_Continue=t}', "");
Expect(0, 917999, '\p{^Is_ID_Continue=t}', "");
Expect(0, 917999, '\P{Is_ID_Continue=t}', "");
Expect(1, 917999, '\P{^Is_ID_Continue=t}', "");
Expect(0, 918000, '\p{Is_ID_Continue=t}', "");
Expect(1, 918000, '\p{^Is_ID_Continue=t}', "");
Expect(1, 918000, '\P{Is_ID_Continue=t}', "");
Expect(0, 918000, '\P{^Is_ID_Continue=t}', "");
Expect(1, 917999, '\p{Is_ID_Continue= _t}', "");
Expect(0, 917999, '\p{^Is_ID_Continue= _t}', "");
Expect(0, 917999, '\P{Is_ID_Continue= _t}', "");
Expect(1, 917999, '\P{^Is_ID_Continue= _t}', "");
Expect(0, 918000, '\p{Is_ID_Continue= _t}', "");
Expect(1, 918000, '\p{^Is_ID_Continue= _t}', "");
Expect(1, 918000, '\P{Is_ID_Continue= _t}', "");
Expect(0, 918000, '\P{^Is_ID_Continue= _t}', "");
Error('\p{Is_IDC=_TRUE/a/}');
Error('\P{Is_IDC=_TRUE/a/}');
Expect(1, 917999, '\p{Is_IDC=true}', "");
Expect(0, 917999, '\p{^Is_IDC=true}', "");
Expect(0, 917999, '\P{Is_IDC=true}', "");
Expect(1, 917999, '\P{^Is_IDC=true}', "");
Expect(0, 918000, '\p{Is_IDC=true}', "");
Expect(1, 918000, '\p{^Is_IDC=true}', "");
Expect(1, 918000, '\P{Is_IDC=true}', "");
Expect(0, 918000, '\P{^Is_IDC=true}', "");
Expect(1, 917999, '\p{Is_IDC=--true}', "");
Expect(0, 917999, '\p{^Is_IDC=--true}', "");
Expect(0, 917999, '\P{Is_IDC=--true}', "");
Expect(1, 917999, '\P{^Is_IDC=--true}', "");
Expect(0, 918000, '\p{Is_IDC=--true}', "");
Expect(1, 918000, '\p{^Is_IDC=--true}', "");
Expect(1, 918000, '\P{Is_IDC=--true}', "");
Expect(0, 918000, '\P{^Is_IDC=--true}', "");
Error('\p{ID_Start=:=-NO}');
Error('\P{ID_Start=:=-NO}');
Expect(1, 195102, '\p{ID_Start=no}', "");
Expect(0, 195102, '\p{^ID_Start=no}', "");
Expect(0, 195102, '\P{ID_Start=no}', "");
Expect(1, 195102, '\P{^ID_Start=no}', "");
Expect(0, 195101, '\p{ID_Start=no}', "");
Expect(1, 195101, '\p{^ID_Start=no}', "");
Expect(1, 195101, '\P{ID_Start=no}', "");
Expect(0, 195101, '\P{^ID_Start=no}', "");
Expect(1, 195102, '\p{ID_Start= _NO}', "");
Expect(0, 195102, '\p{^ID_Start= _NO}', "");
Expect(0, 195102, '\P{ID_Start= _NO}', "");
Expect(1, 195102, '\P{^ID_Start= _NO}', "");
Expect(0, 195101, '\p{ID_Start= _NO}', "");
Expect(1, 195101, '\p{^ID_Start= _NO}', "");
Expect(1, 195101, '\P{ID_Start= _NO}', "");
Expect(0, 195101, '\P{^ID_Start= _NO}', "");
Error('\p{IDS=:=_n}');
Error('\P{IDS=:=_n}');
Expect(1, 195102, '\p{IDS=n}', "");
Expect(0, 195102, '\p{^IDS=n}', "");
Expect(0, 195102, '\P{IDS=n}', "");
Expect(1, 195102, '\P{^IDS=n}', "");
Expect(0, 195101, '\p{IDS=n}', "");
Expect(1, 195101, '\p{^IDS=n}', "");
Expect(1, 195101, '\P{IDS=n}', "");
Expect(0, 195101, '\P{^IDS=n}', "");
Expect(1, 195102, '\p{IDS=__N}', "");
Expect(0, 195102, '\p{^IDS=__N}', "");
Expect(0, 195102, '\P{IDS=__N}', "");
Expect(1, 195102, '\P{^IDS=__N}', "");
Expect(0, 195101, '\p{IDS=__N}', "");
Expect(1, 195101, '\p{^IDS=__N}', "");
Expect(1, 195101, '\P{IDS=__N}', "");
Expect(0, 195101, '\P{^IDS=__N}', "");
Error('\p{Is_ID_Start=/a/_	F}');
Error('\P{Is_ID_Start=/a/_	F}');
Expect(1, 195102, '\p{Is_ID_Start=f}', "");
Expect(0, 195102, '\p{^Is_ID_Start=f}', "");
Expect(0, 195102, '\P{Is_ID_Start=f}', "");
Expect(1, 195102, '\P{^Is_ID_Start=f}', "");
Expect(0, 195101, '\p{Is_ID_Start=f}', "");
Expect(1, 195101, '\p{^Is_ID_Start=f}', "");
Expect(1, 195101, '\P{Is_ID_Start=f}', "");
Expect(0, 195101, '\P{^Is_ID_Start=f}', "");
Expect(1, 195102, '\p{Is_ID_Start=--F}', "");
Expect(0, 195102, '\p{^Is_ID_Start=--F}', "");
Expect(0, 195102, '\P{Is_ID_Start=--F}', "");
Expect(1, 195102, '\P{^Is_ID_Start=--F}', "");
Expect(0, 195101, '\p{Is_ID_Start=--F}', "");
Expect(1, 195101, '\p{^Is_ID_Start=--F}', "");
Expect(1, 195101, '\P{Is_ID_Start=--F}', "");
Expect(0, 195101, '\P{^Is_ID_Start=--F}', "");
Error('\p{Is_IDS=/a/ -FALSE}');
Error('\P{Is_IDS=/a/ -FALSE}');
Expect(1, 195102, '\p{Is_IDS=false}', "");
Expect(0, 195102, '\p{^Is_IDS=false}', "");
Expect(0, 195102, '\P{Is_IDS=false}', "");
Expect(1, 195102, '\P{^Is_IDS=false}', "");
Expect(0, 195101, '\p{Is_IDS=false}', "");
Expect(1, 195101, '\p{^Is_IDS=false}', "");
Expect(1, 195101, '\P{Is_IDS=false}', "");
Expect(0, 195101, '\P{^Is_IDS=false}', "");
Expect(1, 195102, '\p{Is_IDS=	 False}', "");
Expect(0, 195102, '\p{^Is_IDS=	 False}', "");
Expect(0, 195102, '\P{Is_IDS=	 False}', "");
Expect(1, 195102, '\P{^Is_IDS=	 False}', "");
Expect(0, 195101, '\p{Is_IDS=	 False}', "");
Expect(1, 195101, '\p{^Is_IDS=	 False}', "");
Expect(1, 195101, '\P{Is_IDS=	 False}', "");
Expect(0, 195101, '\P{^Is_IDS=	 False}', "");
Error('\p{ID_Start: :=	 YES}');
Error('\P{ID_Start: :=	 YES}');
Expect(1, 195101, '\p{ID_Start=yes}', "");
Expect(0, 195101, '\p{^ID_Start=yes}', "");
Expect(0, 195101, '\P{ID_Start=yes}', "");
Expect(1, 195101, '\P{^ID_Start=yes}', "");
Expect(0, 195102, '\p{ID_Start=yes}', "");
Expect(1, 195102, '\p{^ID_Start=yes}', "");
Expect(1, 195102, '\P{ID_Start=yes}', "");
Expect(0, 195102, '\P{^ID_Start=yes}', "");
Expect(1, 195101, '\p{ID_Start= yes}', "");
Expect(0, 195101, '\p{^ID_Start= yes}', "");
Expect(0, 195101, '\P{ID_Start= yes}', "");
Expect(1, 195101, '\P{^ID_Start= yes}', "");
Expect(0, 195102, '\p{ID_Start= yes}', "");
Expect(1, 195102, '\p{^ID_Start= yes}', "");
Expect(1, 195102, '\P{ID_Start= yes}', "");
Expect(0, 195102, '\P{^ID_Start= yes}', "");
Error('\p{IDS=/a/- Y}');
Error('\P{IDS=/a/- Y}');
Expect(1, 195101, '\p{IDS=y}', "");
Expect(0, 195101, '\p{^IDS=y}', "");
Expect(0, 195101, '\P{IDS=y}', "");
Expect(1, 195101, '\P{^IDS=y}', "");
Expect(0, 195102, '\p{IDS=y}', "");
Expect(1, 195102, '\p{^IDS=y}', "");
Expect(1, 195102, '\P{IDS=y}', "");
Expect(0, 195102, '\P{^IDS=y}', "");
Expect(1, 195101, '\p{IDS= Y}', "");
Expect(0, 195101, '\p{^IDS= Y}', "");
Expect(0, 195101, '\P{IDS= Y}', "");
Expect(1, 195101, '\P{^IDS= Y}', "");
Expect(0, 195102, '\p{IDS= Y}', "");
Expect(1, 195102, '\p{^IDS= Y}', "");
Expect(1, 195102, '\P{IDS= Y}', "");
Expect(0, 195102, '\P{^IDS= Y}', "");
Error('\p{Is_ID_Start= t:=}');
Error('\P{Is_ID_Start= t:=}');
Expect(1, 195101, '\p{Is_ID_Start: t}', "");
Expect(0, 195101, '\p{^Is_ID_Start: t}', "");
Expect(0, 195101, '\P{Is_ID_Start: t}', "");
Expect(1, 195101, '\P{^Is_ID_Start: t}', "");
Expect(0, 195102, '\p{Is_ID_Start: t}', "");
Expect(1, 195102, '\p{^Is_ID_Start: t}', "");
Expect(1, 195102, '\P{Is_ID_Start: t}', "");
Expect(0, 195102, '\P{^Is_ID_Start: t}', "");
Expect(1, 195101, '\p{Is_ID_Start=_T}', "");
Expect(0, 195101, '\p{^Is_ID_Start=_T}', "");
Expect(0, 195101, '\P{Is_ID_Start=_T}', "");
Expect(1, 195101, '\P{^Is_ID_Start=_T}', "");
Expect(0, 195102, '\p{Is_ID_Start=_T}', "");
Expect(1, 195102, '\p{^Is_ID_Start=_T}', "");
Expect(1, 195102, '\P{Is_ID_Start=_T}', "");
Expect(0, 195102, '\P{^Is_ID_Start=_T}', "");
Error('\p{Is_IDS=/a/	TRUE}');
Error('\P{Is_IDS=/a/	TRUE}');
Expect(1, 195101, '\p{Is_IDS=true}', "");
Expect(0, 195101, '\p{^Is_IDS=true}', "");
Expect(0, 195101, '\P{Is_IDS=true}', "");
Expect(1, 195101, '\P{^Is_IDS=true}', "");
Expect(0, 195102, '\p{Is_IDS=true}', "");
Expect(1, 195102, '\p{^Is_IDS=true}', "");
Expect(1, 195102, '\P{Is_IDS=true}', "");
Expect(0, 195102, '\P{^Is_IDS=true}', "");
Expect(1, 195101, '\p{Is_IDS= 	True}', "");
Expect(0, 195101, '\p{^Is_IDS= 	True}', "");
Expect(0, 195101, '\P{Is_IDS= 	True}', "");
Expect(1, 195101, '\P{^Is_IDS= 	True}', "");
Expect(0, 195102, '\p{Is_IDS= 	True}', "");
Expect(1, 195102, '\p{^Is_IDS= 	True}', "");
Expect(1, 195102, '\P{Is_IDS= 	True}', "");
Expect(0, 195102, '\P{^Is_IDS= 	True}', "");
Error('\p{IDS_Binary_Operator= :=No}');
Error('\P{IDS_Binary_Operator= :=No}');
Expect(1, 12284, '\p{IDS_Binary_Operator=no}', "");
Expect(0, 12284, '\p{^IDS_Binary_Operator=no}', "");
Expect(0, 12284, '\P{IDS_Binary_Operator=no}', "");
Expect(1, 12284, '\P{^IDS_Binary_Operator=no}', "");
Expect(0, 12283, '\p{IDS_Binary_Operator=no}', "");
Expect(1, 12283, '\p{^IDS_Binary_Operator=no}', "");
Expect(1, 12283, '\P{IDS_Binary_Operator=no}', "");
Expect(0, 12283, '\P{^IDS_Binary_Operator=no}', "");
Expect(1, 12284, '\p{IDS_Binary_Operator=		No}', "");
Expect(0, 12284, '\p{^IDS_Binary_Operator=		No}', "");
Expect(0, 12284, '\P{IDS_Binary_Operator=		No}', "");
Expect(1, 12284, '\P{^IDS_Binary_Operator=		No}', "");
Expect(0, 12283, '\p{IDS_Binary_Operator=		No}', "");
Expect(1, 12283, '\p{^IDS_Binary_Operator=		No}', "");
Expect(1, 12283, '\P{IDS_Binary_Operator=		No}', "");
Expect(0, 12283, '\P{^IDS_Binary_Operator=		No}', "");
Error('\p{IDSB= :=n}');
Error('\P{IDSB= :=n}');
Expect(1, 12284, '\p{IDSB=n}', "");
Expect(0, 12284, '\p{^IDSB=n}', "");
Expect(0, 12284, '\P{IDSB=n}', "");
Expect(1, 12284, '\P{^IDSB=n}', "");
Expect(0, 12283, '\p{IDSB=n}', "");
Expect(1, 12283, '\p{^IDSB=n}', "");
Expect(1, 12283, '\P{IDSB=n}', "");
Expect(0, 12283, '\P{^IDSB=n}', "");
Expect(1, 12284, '\p{IDSB=-_N}', "");
Expect(0, 12284, '\p{^IDSB=-_N}', "");
Expect(0, 12284, '\P{IDSB=-_N}', "");
Expect(1, 12284, '\P{^IDSB=-_N}', "");
Expect(0, 12283, '\p{IDSB=-_N}', "");
Expect(1, 12283, '\p{^IDSB=-_N}', "");
Expect(1, 12283, '\P{IDSB=-_N}', "");
Expect(0, 12283, '\P{^IDSB=-_N}', "");
Error('\p{Is_IDS_Binary_Operator=:=_F}');
Error('\P{Is_IDS_Binary_Operator=:=_F}');
Expect(1, 12284, '\p{Is_IDS_Binary_Operator=f}', "");
Expect(0, 12284, '\p{^Is_IDS_Binary_Operator=f}', "");
Expect(0, 12284, '\P{Is_IDS_Binary_Operator=f}', "");
Expect(1, 12284, '\P{^Is_IDS_Binary_Operator=f}', "");
Expect(0, 12283, '\p{Is_IDS_Binary_Operator=f}', "");
Expect(1, 12283, '\p{^Is_IDS_Binary_Operator=f}', "");
Expect(1, 12283, '\P{Is_IDS_Binary_Operator=f}', "");
Expect(0, 12283, '\P{^Is_IDS_Binary_Operator=f}', "");
Expect(1, 12284, '\p{Is_IDS_Binary_Operator= -F}', "");
Expect(0, 12284, '\p{^Is_IDS_Binary_Operator= -F}', "");
Expect(0, 12284, '\P{Is_IDS_Binary_Operator= -F}', "");
Expect(1, 12284, '\P{^Is_IDS_Binary_Operator= -F}', "");
Expect(0, 12283, '\p{Is_IDS_Binary_Operator= -F}', "");
Expect(1, 12283, '\p{^Is_IDS_Binary_Operator= -F}', "");
Expect(1, 12283, '\P{Is_IDS_Binary_Operator= -F}', "");
Expect(0, 12283, '\P{^Is_IDS_Binary_Operator= -F}', "");
Error('\p{Is_IDSB=	 false:=}');
Error('\P{Is_IDSB=	 false:=}');
Expect(1, 12284, '\p{Is_IDSB=false}', "");
Expect(0, 12284, '\p{^Is_IDSB=false}', "");
Expect(0, 12284, '\P{Is_IDSB=false}', "");
Expect(1, 12284, '\P{^Is_IDSB=false}', "");
Expect(0, 12283, '\p{Is_IDSB=false}', "");
Expect(1, 12283, '\p{^Is_IDSB=false}', "");
Expect(1, 12283, '\P{Is_IDSB=false}', "");
Expect(0, 12283, '\P{^Is_IDSB=false}', "");
Expect(1, 12284, '\p{Is_IDSB=_	FALSE}', "");
Expect(0, 12284, '\p{^Is_IDSB=_	FALSE}', "");
Expect(0, 12284, '\P{Is_IDSB=_	FALSE}', "");
Expect(1, 12284, '\P{^Is_IDSB=_	FALSE}', "");
Expect(0, 12283, '\p{Is_IDSB=_	FALSE}', "");
Expect(1, 12283, '\p{^Is_IDSB=_	FALSE}', "");
Expect(1, 12283, '\P{Is_IDSB=_	FALSE}', "");
Expect(0, 12283, '\P{^Is_IDSB=_	FALSE}', "");
Error('\p{IDS_Binary_Operator=	:=Yes}');
Error('\P{IDS_Binary_Operator=	:=Yes}');
Expect(1, 12283, '\p{IDS_Binary_Operator:yes}', "");
Expect(0, 12283, '\p{^IDS_Binary_Operator:yes}', "");
Expect(0, 12283, '\P{IDS_Binary_Operator:yes}', "");
Expect(1, 12283, '\P{^IDS_Binary_Operator:yes}', "");
Expect(0, 12284, '\p{IDS_Binary_Operator:yes}', "");
Expect(1, 12284, '\p{^IDS_Binary_Operator:yes}', "");
Expect(1, 12284, '\P{IDS_Binary_Operator:yes}', "");
Expect(0, 12284, '\P{^IDS_Binary_Operator:yes}', "");
Expect(1, 12283, '\p{IDS_Binary_Operator=	_Yes}', "");
Expect(0, 12283, '\p{^IDS_Binary_Operator=	_Yes}', "");
Expect(0, 12283, '\P{IDS_Binary_Operator=	_Yes}', "");
Expect(1, 12283, '\P{^IDS_Binary_Operator=	_Yes}', "");
Expect(0, 12284, '\p{IDS_Binary_Operator=	_Yes}', "");
Expect(1, 12284, '\p{^IDS_Binary_Operator=	_Yes}', "");
Expect(1, 12284, '\P{IDS_Binary_Operator=	_Yes}', "");
Expect(0, 12284, '\P{^IDS_Binary_Operator=	_Yes}', "");
Error('\p{IDSB=/a/-Y}');
Error('\P{IDSB=/a/-Y}');
Expect(1, 12283, '\p{IDSB=y}', "");
Expect(0, 12283, '\p{^IDSB=y}', "");
Expect(0, 12283, '\P{IDSB=y}', "");
Expect(1, 12283, '\P{^IDSB=y}', "");
Expect(0, 12284, '\p{IDSB=y}', "");
Expect(1, 12284, '\p{^IDSB=y}', "");
Expect(1, 12284, '\P{IDSB=y}', "");
Expect(0, 12284, '\P{^IDSB=y}', "");
Expect(1, 12283, '\p{IDSB=	-y}', "");
Expect(0, 12283, '\p{^IDSB=	-y}', "");
Expect(0, 12283, '\P{IDSB=	-y}', "");
Expect(1, 12283, '\P{^IDSB=	-y}', "");
Expect(0, 12284, '\p{IDSB=	-y}', "");
Expect(1, 12284, '\p{^IDSB=	-y}', "");
Expect(1, 12284, '\P{IDSB=	-y}', "");
Expect(0, 12284, '\P{^IDSB=	-y}', "");
Error('\p{Is_IDS_Binary_Operator=/a/-	T}');
Error('\P{Is_IDS_Binary_Operator=/a/-	T}');
Expect(1, 12283, '\p{Is_IDS_Binary_Operator=t}', "");
Expect(0, 12283, '\p{^Is_IDS_Binary_Operator=t}', "");
Expect(0, 12283, '\P{Is_IDS_Binary_Operator=t}', "");
Expect(1, 12283, '\P{^Is_IDS_Binary_Operator=t}', "");
Expect(0, 12284, '\p{Is_IDS_Binary_Operator=t}', "");
Expect(1, 12284, '\p{^Is_IDS_Binary_Operator=t}', "");
Expect(1, 12284, '\P{Is_IDS_Binary_Operator=t}', "");
Expect(0, 12284, '\P{^Is_IDS_Binary_Operator=t}', "");
Expect(1, 12283, '\p{Is_IDS_Binary_Operator=_-T}', "");
Expect(0, 12283, '\p{^Is_IDS_Binary_Operator=_-T}', "");
Expect(0, 12283, '\P{Is_IDS_Binary_Operator=_-T}', "");
Expect(1, 12283, '\P{^Is_IDS_Binary_Operator=_-T}', "");
Expect(0, 12284, '\p{Is_IDS_Binary_Operator=_-T}', "");
Expect(1, 12284, '\p{^Is_IDS_Binary_Operator=_-T}', "");
Expect(1, 12284, '\P{Is_IDS_Binary_Operator=_-T}', "");
Expect(0, 12284, '\P{^Is_IDS_Binary_Operator=_-T}', "");
Error('\p{Is_IDSB=:= true}');
Error('\P{Is_IDSB=:= true}');
Expect(1, 12283, '\p{Is_IDSB=true}', "");
Expect(0, 12283, '\p{^Is_IDSB=true}', "");
Expect(0, 12283, '\P{Is_IDSB=true}', "");
Expect(1, 12283, '\P{^Is_IDSB=true}', "");
Expect(0, 12284, '\p{Is_IDSB=true}', "");
Expect(1, 12284, '\p{^Is_IDSB=true}', "");
Expect(1, 12284, '\P{Is_IDSB=true}', "");
Expect(0, 12284, '\P{^Is_IDSB=true}', "");
Expect(1, 12283, '\p{Is_IDSB: _ True}', "");
Expect(0, 12283, '\p{^Is_IDSB: _ True}', "");
Expect(0, 12283, '\P{Is_IDSB: _ True}', "");
Expect(1, 12283, '\P{^Is_IDSB: _ True}', "");
Expect(0, 12284, '\p{Is_IDSB: _ True}', "");
Expect(1, 12284, '\p{^Is_IDSB: _ True}', "");
Expect(1, 12284, '\P{Is_IDSB: _ True}', "");
Expect(0, 12284, '\P{^Is_IDSB: _ True}', "");
Error('\p{IDS_Trinary_Operator:	 /a/NO}');
Error('\P{IDS_Trinary_Operator:	 /a/NO}');
Expect(1, 12276, '\p{IDS_Trinary_Operator=no}', "");
Expect(0, 12276, '\p{^IDS_Trinary_Operator=no}', "");
Expect(0, 12276, '\P{IDS_Trinary_Operator=no}', "");
Expect(1, 12276, '\P{^IDS_Trinary_Operator=no}', "");
Expect(0, 12275, '\p{IDS_Trinary_Operator=no}', "");
Expect(1, 12275, '\p{^IDS_Trinary_Operator=no}', "");
Expect(1, 12275, '\P{IDS_Trinary_Operator=no}', "");
Expect(0, 12275, '\P{^IDS_Trinary_Operator=no}', "");
Expect(1, 12276, '\p{IDS_Trinary_Operator=NO}', "");
Expect(0, 12276, '\p{^IDS_Trinary_Operator=NO}', "");
Expect(0, 12276, '\P{IDS_Trinary_Operator=NO}', "");
Expect(1, 12276, '\P{^IDS_Trinary_Operator=NO}', "");
Expect(0, 12275, '\p{IDS_Trinary_Operator=NO}', "");
Expect(1, 12275, '\p{^IDS_Trinary_Operator=NO}', "");
Expect(1, 12275, '\P{IDS_Trinary_Operator=NO}', "");
Expect(0, 12275, '\P{^IDS_Trinary_Operator=NO}', "");
Error('\p{IDST=_N/a/}');
Error('\P{IDST=_N/a/}');
Expect(1, 12276, '\p{IDST=n}', "");
Expect(0, 12276, '\p{^IDST=n}', "");
Expect(0, 12276, '\P{IDST=n}', "");
Expect(1, 12276, '\P{^IDST=n}', "");
Expect(0, 12275, '\p{IDST=n}', "");
Expect(1, 12275, '\p{^IDST=n}', "");
Expect(1, 12275, '\P{IDST=n}', "");
Expect(0, 12275, '\P{^IDST=n}', "");
Expect(1, 12276, '\p{IDST=- N}', "");
Expect(0, 12276, '\p{^IDST=- N}', "");
Expect(0, 12276, '\P{IDST=- N}', "");
Expect(1, 12276, '\P{^IDST=- N}', "");
Expect(0, 12275, '\p{IDST=- N}', "");
Expect(1, 12275, '\p{^IDST=- N}', "");
Expect(1, 12275, '\P{IDST=- N}', "");
Expect(0, 12275, '\P{^IDST=- N}', "");
Error('\p{Is_IDS_Trinary_Operator= 	F/a/}');
Error('\P{Is_IDS_Trinary_Operator= 	F/a/}');
Expect(1, 12276, '\p{Is_IDS_Trinary_Operator:f}', "");
Expect(0, 12276, '\p{^Is_IDS_Trinary_Operator:f}', "");
Expect(0, 12276, '\P{Is_IDS_Trinary_Operator:f}', "");
Expect(1, 12276, '\P{^Is_IDS_Trinary_Operator:f}', "");
Expect(0, 12275, '\p{Is_IDS_Trinary_Operator:f}', "");
Expect(1, 12275, '\p{^Is_IDS_Trinary_Operator:f}', "");
Expect(1, 12275, '\P{Is_IDS_Trinary_Operator:f}', "");
Expect(0, 12275, '\P{^Is_IDS_Trinary_Operator:f}', "");
Expect(1, 12276, '\p{Is_IDS_Trinary_Operator=		F}', "");
Expect(0, 12276, '\p{^Is_IDS_Trinary_Operator=		F}', "");
Expect(0, 12276, '\P{Is_IDS_Trinary_Operator=		F}', "");
Expect(1, 12276, '\P{^Is_IDS_Trinary_Operator=		F}', "");
Expect(0, 12275, '\p{Is_IDS_Trinary_Operator=		F}', "");
Expect(1, 12275, '\p{^Is_IDS_Trinary_Operator=		F}', "");
Expect(1, 12275, '\P{Is_IDS_Trinary_Operator=		F}', "");
Expect(0, 12275, '\P{^Is_IDS_Trinary_Operator=		F}', "");
Error('\p{Is_IDST= False/a/}');
Error('\P{Is_IDST= False/a/}');
Expect(1, 12276, '\p{Is_IDST=false}', "");
Expect(0, 12276, '\p{^Is_IDST=false}', "");
Expect(0, 12276, '\P{Is_IDST=false}', "");
Expect(1, 12276, '\P{^Is_IDST=false}', "");
Expect(0, 12275, '\p{Is_IDST=false}', "");
Expect(1, 12275, '\p{^Is_IDST=false}', "");
Expect(1, 12275, '\P{Is_IDST=false}', "");
Expect(0, 12275, '\P{^Is_IDST=false}', "");
Expect(1, 12276, '\p{Is_IDST=_False}', "");
Expect(0, 12276, '\p{^Is_IDST=_False}', "");
Expect(0, 12276, '\P{Is_IDST=_False}', "");
Expect(1, 12276, '\P{^Is_IDST=_False}', "");
Expect(0, 12275, '\p{Is_IDST=_False}', "");
Expect(1, 12275, '\p{^Is_IDST=_False}', "");
Expect(1, 12275, '\P{Is_IDST=_False}', "");
Expect(0, 12275, '\P{^Is_IDST=_False}', "");
Error('\p{IDS_Trinary_Operator:   	Yes:=}');
Error('\P{IDS_Trinary_Operator:   	Yes:=}');
Expect(1, 12275, '\p{IDS_Trinary_Operator=yes}', "");
Expect(0, 12275, '\p{^IDS_Trinary_Operator=yes}', "");
Expect(0, 12275, '\P{IDS_Trinary_Operator=yes}', "");
Expect(1, 12275, '\P{^IDS_Trinary_Operator=yes}', "");
Expect(0, 12276, '\p{IDS_Trinary_Operator=yes}', "");
Expect(1, 12276, '\p{^IDS_Trinary_Operator=yes}', "");
Expect(1, 12276, '\P{IDS_Trinary_Operator=yes}', "");
Expect(0, 12276, '\P{^IDS_Trinary_Operator=yes}', "");
Expect(1, 12275, '\p{IDS_Trinary_Operator= yes}', "");
Expect(0, 12275, '\p{^IDS_Trinary_Operator= yes}', "");
Expect(0, 12275, '\P{IDS_Trinary_Operator= yes}', "");
Expect(1, 12275, '\P{^IDS_Trinary_Operator= yes}', "");
Expect(0, 12276, '\p{IDS_Trinary_Operator= yes}', "");
Expect(1, 12276, '\p{^IDS_Trinary_Operator= yes}', "");
Expect(1, 12276, '\P{IDS_Trinary_Operator= yes}', "");
Expect(0, 12276, '\P{^IDS_Trinary_Operator= yes}', "");
Error('\p{IDST:	:= 	y}');
Error('\P{IDST:	:= 	y}');
Expect(1, 12275, '\p{IDST=y}', "");
Expect(0, 12275, '\p{^IDST=y}', "");
Expect(0, 12275, '\P{IDST=y}', "");
Expect(1, 12275, '\P{^IDST=y}', "");
Expect(0, 12276, '\p{IDST=y}', "");
Expect(1, 12276, '\p{^IDST=y}', "");
Expect(1, 12276, '\P{IDST=y}', "");
Expect(0, 12276, '\P{^IDST=y}', "");
Expect(1, 12275, '\p{IDST=_Y}', "");
Expect(0, 12275, '\p{^IDST=_Y}', "");
Expect(0, 12275, '\P{IDST=_Y}', "");
Expect(1, 12275, '\P{^IDST=_Y}', "");
Expect(0, 12276, '\p{IDST=_Y}', "");
Expect(1, 12276, '\p{^IDST=_Y}', "");
Expect(1, 12276, '\P{IDST=_Y}', "");
Expect(0, 12276, '\P{^IDST=_Y}', "");
Error('\p{Is_IDS_Trinary_Operator=/a/	 T}');
Error('\P{Is_IDS_Trinary_Operator=/a/	 T}');
Expect(1, 12275, '\p{Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12275, '\p{^Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12275, '\P{Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12275, '\P{^Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12276, '\p{Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12276, '\p{^Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12276, '\P{Is_IDS_Trinary_Operator=t}', "");
Expect(0, 12276, '\P{^Is_IDS_Trinary_Operator=t}', "");
Expect(1, 12275, '\p{Is_IDS_Trinary_Operator=		T}', "");
Expect(0, 12275, '\p{^Is_IDS_Trinary_Operator=		T}', "");
Expect(0, 12275, '\P{Is_IDS_Trinary_Operator=		T}', "");
Expect(1, 12275, '\P{^Is_IDS_Trinary_Operator=		T}', "");
Expect(0, 12276, '\p{Is_IDS_Trinary_Operator=		T}', "");
Expect(1, 12276, '\p{^Is_IDS_Trinary_Operator=		T}', "");
Expect(1, 12276, '\P{Is_IDS_Trinary_Operator=		T}', "");
Expect(0, 12276, '\P{^Is_IDS_Trinary_Operator=		T}', "");
Error('\p{Is_IDST=-:=True}');
Error('\P{Is_IDST=-:=True}');
Expect(1, 12275, '\p{Is_IDST=true}', "");
Expect(0, 12275, '\p{^Is_IDST=true}', "");
Expect(0, 12275, '\P{Is_IDST=true}', "");
Expect(1, 12275, '\P{^Is_IDST=true}', "");
Expect(0, 12276, '\p{Is_IDST=true}', "");
Expect(1, 12276, '\p{^Is_IDST=true}', "");
Expect(1, 12276, '\P{Is_IDST=true}', "");
Expect(0, 12276, '\P{^Is_IDST=true}', "");
Expect(1, 12275, '\p{Is_IDST=-true}', "");
Expect(0, 12275, '\p{^Is_IDST=-true}', "");
Expect(0, 12275, '\P{Is_IDST=-true}', "");
Expect(1, 12275, '\P{^Is_IDST=-true}', "");
Expect(0, 12276, '\p{Is_IDST=-true}', "");
Expect(1, 12276, '\p{^Is_IDST=-true}', "");
Expect(1, 12276, '\P{Is_IDST=-true}', "");
Expect(0, 12276, '\P{^Is_IDST=-true}', "");
Error('\p{Ideographic=_:=no}');
Error('\P{Ideographic=_:=no}');
Expect(1, 195102, '\p{Ideographic=no}', "");
Expect(0, 195102, '\p{^Ideographic=no}', "");
Expect(0, 195102, '\P{Ideographic=no}', "");
Expect(1, 195102, '\P{^Ideographic=no}', "");
Expect(0, 195101, '\p{Ideographic=no}', "");
Expect(1, 195101, '\p{^Ideographic=no}', "");
Expect(1, 195101, '\P{Ideographic=no}', "");
Expect(0, 195101, '\P{^Ideographic=no}', "");
Expect(1, 195102, '\p{Ideographic:	  No}', "");
Expect(0, 195102, '\p{^Ideographic:	  No}', "");
Expect(0, 195102, '\P{Ideographic:	  No}', "");
Expect(1, 195102, '\P{^Ideographic:	  No}', "");
Expect(0, 195101, '\p{Ideographic:	  No}', "");
Expect(1, 195101, '\p{^Ideographic:	  No}', "");
Expect(1, 195101, '\P{Ideographic:	  No}', "");
Expect(0, 195101, '\P{^Ideographic:	  No}', "");
Error('\p{Ideo=- N/a/}');
Error('\P{Ideo=- N/a/}');
Expect(1, 195102, '\p{Ideo=n}', "");
Expect(0, 195102, '\p{^Ideo=n}', "");
Expect(0, 195102, '\P{Ideo=n}', "");
Expect(1, 195102, '\P{^Ideo=n}', "");
Expect(0, 195101, '\p{Ideo=n}', "");
Expect(1, 195101, '\p{^Ideo=n}', "");
Expect(1, 195101, '\P{Ideo=n}', "");
Expect(0, 195101, '\P{^Ideo=n}', "");
Expect(1, 195102, '\p{Ideo=__N}', "");
Expect(0, 195102, '\p{^Ideo=__N}', "");
Expect(0, 195102, '\P{Ideo=__N}', "");
Expect(1, 195102, '\P{^Ideo=__N}', "");
Expect(0, 195101, '\p{Ideo=__N}', "");
Expect(1, 195101, '\p{^Ideo=__N}', "");
Expect(1, 195101, '\P{Ideo=__N}', "");
Expect(0, 195101, '\P{^Ideo=__N}', "");
Error('\p{Is_Ideographic=	 f/a/}');
Error('\P{Is_Ideographic=	 f/a/}');
Expect(1, 195102, '\p{Is_Ideographic=f}', "");
Expect(0, 195102, '\p{^Is_Ideographic=f}', "");
Expect(0, 195102, '\P{Is_Ideographic=f}', "");
Expect(1, 195102, '\P{^Is_Ideographic=f}', "");
Expect(0, 195101, '\p{Is_Ideographic=f}', "");
Expect(1, 195101, '\p{^Is_Ideographic=f}', "");
Expect(1, 195101, '\P{Is_Ideographic=f}', "");
Expect(0, 195101, '\P{^Is_Ideographic=f}', "");
Expect(1, 195102, '\p{Is_Ideographic=-F}', "");
Expect(0, 195102, '\p{^Is_Ideographic=-F}', "");
Expect(0, 195102, '\P{Is_Ideographic=-F}', "");
Expect(1, 195102, '\P{^Is_Ideographic=-F}', "");
Expect(0, 195101, '\p{Is_Ideographic=-F}', "");
Expect(1, 195101, '\p{^Is_Ideographic=-F}', "");
Expect(1, 195101, '\P{Is_Ideographic=-F}', "");
Expect(0, 195101, '\P{^Is_Ideographic=-F}', "");
Error('\p{Is_Ideo=:=-	False}');
Error('\P{Is_Ideo=:=-	False}');
Expect(1, 195102, '\p{Is_Ideo:	false}', "");
Expect(0, 195102, '\p{^Is_Ideo:	false}', "");
Expect(0, 195102, '\P{Is_Ideo:	false}', "");
Expect(1, 195102, '\P{^Is_Ideo:	false}', "");
Expect(0, 195101, '\p{Is_Ideo:	false}', "");
Expect(1, 195101, '\p{^Is_Ideo:	false}', "");
Expect(1, 195101, '\P{Is_Ideo:	false}', "");
Expect(0, 195101, '\P{^Is_Ideo:	false}', "");
Expect(1, 195102, '\p{Is_Ideo:	__False}', "");
Expect(0, 195102, '\p{^Is_Ideo:	__False}', "");
Expect(0, 195102, '\P{Is_Ideo:	__False}', "");
Expect(1, 195102, '\P{^Is_Ideo:	__False}', "");
Expect(0, 195101, '\p{Is_Ideo:	__False}', "");
Expect(1, 195101, '\p{^Is_Ideo:	__False}', "");
Expect(1, 195101, '\P{Is_Ideo:	__False}', "");
Expect(0, 195101, '\P{^Is_Ideo:	__False}', "");
Error('\p{Ideographic=/a/	Yes}');
Error('\P{Ideographic=/a/	Yes}');
Expect(1, 195101, '\p{Ideographic=yes}', "");
Expect(0, 195101, '\p{^Ideographic=yes}', "");
Expect(0, 195101, '\P{Ideographic=yes}', "");
Expect(1, 195101, '\P{^Ideographic=yes}', "");
Expect(0, 195102, '\p{Ideographic=yes}', "");
Expect(1, 195102, '\p{^Ideographic=yes}', "");
Expect(1, 195102, '\P{Ideographic=yes}', "");
Expect(0, 195102, '\P{^Ideographic=yes}', "");
Expect(1, 195101, '\p{Ideographic=_-Yes}', "");
Expect(0, 195101, '\p{^Ideographic=_-Yes}', "");
Expect(0, 195101, '\P{Ideographic=_-Yes}', "");
Expect(1, 195101, '\P{^Ideographic=_-Yes}', "");
Expect(0, 195102, '\p{Ideographic=_-Yes}', "");
Expect(1, 195102, '\p{^Ideographic=_-Yes}', "");
Expect(1, 195102, '\P{Ideographic=_-Yes}', "");
Expect(0, 195102, '\P{^Ideographic=_-Yes}', "");
Error('\p{Ideo=	-Y:=}');
Error('\P{Ideo=	-Y:=}');
Expect(1, 195101, '\p{Ideo=y}', "");
Expect(0, 195101, '\p{^Ideo=y}', "");
Expect(0, 195101, '\P{Ideo=y}', "");
Expect(1, 195101, '\P{^Ideo=y}', "");
Expect(0, 195102, '\p{Ideo=y}', "");
Expect(1, 195102, '\p{^Ideo=y}', "");
Expect(1, 195102, '\P{Ideo=y}', "");
Expect(0, 195102, '\P{^Ideo=y}', "");
Expect(1, 195101, '\p{Ideo=-_Y}', "");
Expect(0, 195101, '\p{^Ideo=-_Y}', "");
Expect(0, 195101, '\P{Ideo=-_Y}', "");
Expect(1, 195101, '\P{^Ideo=-_Y}', "");
Expect(0, 195102, '\p{Ideo=-_Y}', "");
Expect(1, 195102, '\p{^Ideo=-_Y}', "");
Expect(1, 195102, '\P{Ideo=-_Y}', "");
Expect(0, 195102, '\P{^Ideo=-_Y}', "");
Error('\p{Is_Ideographic=:=_-T}');
Error('\P{Is_Ideographic=:=_-T}');
Expect(1, 195101, '\p{Is_Ideographic=t}', "");
Expect(0, 195101, '\p{^Is_Ideographic=t}', "");
Expect(0, 195101, '\P{Is_Ideographic=t}', "");
Expect(1, 195101, '\P{^Is_Ideographic=t}', "");
Expect(0, 195102, '\p{Is_Ideographic=t}', "");
Expect(1, 195102, '\p{^Is_Ideographic=t}', "");
Expect(1, 195102, '\P{Is_Ideographic=t}', "");
Expect(0, 195102, '\P{^Is_Ideographic=t}', "");
Expect(1, 195101, '\p{Is_Ideographic= t}', "");
Expect(0, 195101, '\p{^Is_Ideographic= t}', "");
Expect(0, 195101, '\P{Is_Ideographic= t}', "");
Expect(1, 195101, '\P{^Is_Ideographic= t}', "");
Expect(0, 195102, '\p{Is_Ideographic= t}', "");
Expect(1, 195102, '\p{^Is_Ideographic= t}', "");
Expect(1, 195102, '\P{Is_Ideographic= t}', "");
Expect(0, 195102, '\P{^Is_Ideographic= t}', "");
Error('\p{Is_Ideo=:=__true}');
Error('\P{Is_Ideo=:=__true}');
Expect(1, 195101, '\p{Is_Ideo:   true}', "");
Expect(0, 195101, '\p{^Is_Ideo:   true}', "");
Expect(0, 195101, '\P{Is_Ideo:   true}', "");
Expect(1, 195101, '\P{^Is_Ideo:   true}', "");
Expect(0, 195102, '\p{Is_Ideo:   true}', "");
Expect(1, 195102, '\p{^Is_Ideo:   true}', "");
Expect(1, 195102, '\P{Is_Ideo:   true}', "");
Expect(0, 195102, '\P{^Is_Ideo:   true}', "");
Expect(1, 195101, '\p{Is_Ideo=__True}', "");
Expect(0, 195101, '\p{^Is_Ideo=__True}', "");
Expect(0, 195101, '\P{Is_Ideo=__True}', "");
Expect(1, 195101, '\P{^Is_Ideo=__True}', "");
Expect(0, 195102, '\p{Is_Ideo=__True}', "");
Expect(1, 195102, '\p{^Is_Ideo=__True}', "");
Expect(1, 195102, '\P{Is_Ideo=__True}', "");
Expect(0, 195102, '\P{^Is_Ideo=__True}', "");
Error('\p{Present_In=_001.1:=}');
Error('\P{Present_In=_001.1:=}');
Expect(1, 65533, '\p{Present_In=+00_00_1.1}', "");
Expect(0, 65533, '\p{^Present_In=+00_00_1.1}', "");
Expect(0, 65533, '\P{Present_In=+00_00_1.1}', "");
Expect(1, 65533, '\P{^Present_In=+00_00_1.1}', "");
Expect(0, 65536, '\p{Present_In=+00_00_1.1}', "");
Expect(1, 65536, '\p{^Present_In=+00_00_1.1}', "");
Expect(1, 65536, '\P{Present_In=+00_00_1.1}', "");
Expect(0, 65536, '\P{^Present_In=+00_00_1.1}', "");
Error('\p{In=:=_	+000001.1}');
Error('\P{In=:=_	+000001.1}');
Expect(1, 65533, '\p{In:	0_0_0_0_01.1}', "");
Expect(0, 65533, '\p{^In:	0_0_0_0_01.1}', "");
Expect(0, 65533, '\P{In:	0_0_0_0_01.1}', "");
Expect(1, 65533, '\P{^In:	0_0_0_0_01.1}', "");
Expect(0, 65536, '\p{In:	0_0_0_0_01.1}', "");
Expect(1, 65536, '\p{^In:	0_0_0_0_01.1}', "");
Expect(1, 65536, '\P{In:	0_0_0_0_01.1}', "");
Expect(0, 65536, '\P{^In:	0_0_0_0_01.1}', "");
Error('\p{Is_Present_In= 	001.1:=}');
Error('\P{Is_Present_In= 	001.1:=}');
Expect(1, 65533, '\p{Is_Present_In=001.1}', "");
Expect(0, 65533, '\p{^Is_Present_In=001.1}', "");
Expect(0, 65533, '\P{Is_Present_In=001.1}', "");
Expect(1, 65533, '\P{^Is_Present_In=001.1}', "");
Expect(0, 65536, '\p{Is_Present_In=001.1}', "");
Expect(1, 65536, '\p{^Is_Present_In=001.1}', "");
Expect(1, 65536, '\P{Is_Present_In=001.1}', "");
Expect(0, 65536, '\P{^Is_Present_In=001.1}', "");
Error('\p{Is_In=-0001.1/a/}');
Error('\P{Is_In=-0001.1/a/}');
Expect(1, 65533, '\p{Is_In=0_1.1}', "");
Expect(0, 65533, '\p{^Is_In=0_1.1}', "");
Expect(0, 65533, '\P{Is_In=0_1.1}', "");
Expect(1, 65533, '\P{^Is_In=0_1.1}', "");
Expect(0, 65536, '\p{Is_In=0_1.1}', "");
Expect(1, 65536, '\p{^Is_In=0_1.1}', "");
Expect(1, 65536, '\P{Is_In=0_1.1}', "");
Expect(0, 65536, '\P{^Is_In=0_1.1}', "");
Error('\p{Present_In=-/a/00002.0}');
Error('\P{Present_In=-/a/00002.0}');
Expect(1, 983040, '\p{Present_In=2.0}', "");
Expect(0, 983040, '\p{^Present_In=2.0}', "");
Expect(0, 983040, '\P{Present_In=2.0}', "");
Expect(1, 983040, '\P{^Present_In=2.0}', "");
Expect(0, 983037, '\p{Present_In=2.0}', "");
Expect(1, 983037, '\p{^Present_In=2.0}', "");
Expect(1, 983037, '\P{Present_In=2.0}', "");
Expect(0, 983037, '\P{^Present_In=2.0}', "");
Error('\p{In=	:=2.0}');
Error('\P{In=	:=2.0}');
Expect(1, 983040, '\p{In=00000_2.0}', "");
Expect(0, 983040, '\p{^In=00000_2.0}', "");
Expect(0, 983040, '\P{In=00000_2.0}', "");
Expect(1, 983040, '\P{^In=00000_2.0}', "");
Expect(0, 983037, '\p{In=00000_2.0}', "");
Expect(1, 983037, '\p{^In=00000_2.0}', "");
Expect(1, 983037, '\P{In=00000_2.0}', "");
Expect(0, 983037, '\P{^In=00000_2.0}', "");
Error('\p{Is_Present_In=_	0_2.0:=}');
Error('\P{Is_Present_In=_	0_2.0:=}');
Expect(1, 983040, '\p{Is_Present_In:   00000002.0}', "");
Expect(0, 983040, '\p{^Is_Present_In:   00000002.0}', "");
Expect(0, 983040, '\P{Is_Present_In:   00000002.0}', "");
Expect(1, 983040, '\P{^Is_Present_In:   00000002.0}', "");
Expect(0, 983037, '\p{Is_Present_In:   00000002.0}', "");
Expect(1, 983037, '\p{^Is_Present_In:   00000002.0}', "");
Expect(1, 983037, '\P{Is_Present_In:   00000002.0}', "");
Expect(0, 983037, '\P{^Is_Present_In:   00000002.0}', "");
Error('\p{Is_In=	/a/002.0}');
Error('\P{Is_In=	/a/002.0}');
Expect(1, 983040, '\p{Is_In=0_0_0_0_0_02.0}', "");
Expect(0, 983040, '\p{^Is_In=0_0_0_0_0_02.0}', "");
Expect(0, 983040, '\P{Is_In=0_0_0_0_0_02.0}', "");
Expect(1, 983040, '\P{^Is_In=0_0_0_0_0_02.0}', "");
Expect(0, 983037, '\p{Is_In=0_0_0_0_0_02.0}', "");
Expect(1, 983037, '\p{^Is_In=0_0_0_0_0_02.0}', "");
Expect(1, 983037, '\P{Is_In=0_0_0_0_0_02.0}', "");
Expect(0, 983037, '\P{^Is_In=0_0_0_0_0_02.0}', "");
Error('\p{Present_In=/a/	-000000002.1}');
Error('\P{Present_In=/a/	-000000002.1}');
Expect(1, 983040, '\p{Present_In=0000000_2.1}', "");
Expect(0, 983040, '\p{^Present_In=0000000_2.1}', "");
Expect(0, 983040, '\P{Present_In=0000000_2.1}', "");
Expect(1, 983040, '\P{^Present_In=0000000_2.1}', "");
Expect(0, 983037, '\p{Present_In=0000000_2.1}', "");
Expect(1, 983037, '\p{^Present_In=0000000_2.1}', "");
Expect(1, 983037, '\P{Present_In=0000000_2.1}', "");
Expect(0, 983037, '\P{^Present_In=0000000_2.1}', "");
Error('\p{In=/a/0_0_0_0_0_02.1}');
Error('\P{In=/a/0_0_0_0_0_02.1}');
Expect(1, 983040, '\p{In=+000_000_000_2.1}', "");
Expect(0, 983040, '\p{^In=+000_000_000_2.1}', "");
Expect(0, 983040, '\P{In=+000_000_000_2.1}', "");
Expect(1, 983040, '\P{^In=+000_000_000_2.1}', "");
Expect(0, 983037, '\p{In=+000_000_000_2.1}', "");
Expect(1, 983037, '\p{^In=+000_000_000_2.1}', "");
Expect(1, 983037, '\P{In=+000_000_000_2.1}', "");
Expect(0, 983037, '\P{^In=+000_000_000_2.1}', "");
Error('\p{Is_Present_In:	-2.1/a/}');
Error('\P{Is_Present_In:	-2.1/a/}');
Expect(1, 983040, '\p{Is_Present_In:   +0000_0000_2.1}', "");
Expect(0, 983040, '\p{^Is_Present_In:   +0000_0000_2.1}', "");
Expect(0, 983040, '\P{Is_Present_In:   +0000_0000_2.1}', "");
Expect(1, 983040, '\P{^Is_Present_In:   +0000_0000_2.1}', "");
Expect(0, 983037, '\p{Is_Present_In:   +0000_0000_2.1}', "");
Expect(1, 983037, '\p{^Is_Present_In:   +0000_0000_2.1}', "");
Expect(1, 983037, '\P{Is_Present_In:   +0000_0000_2.1}', "");
Expect(0, 983037, '\P{^Is_Present_In:   +0000_0000_2.1}', "");
Error('\p{Is_In= :=+000000002.1}');
Error('\P{Is_In= :=+000000002.1}');
Expect(1, 983040, '\p{Is_In=0_0_0_0_02.1}', "");
Expect(0, 983040, '\p{^Is_In=0_0_0_0_02.1}', "");
Expect(0, 983040, '\P{Is_In=0_0_0_0_02.1}', "");
Expect(1, 983040, '\P{^Is_In=0_0_0_0_02.1}', "");
Expect(0, 983037, '\p{Is_In=0_0_0_0_02.1}', "");
Expect(1, 983037, '\p{^Is_In=0_0_0_0_02.1}', "");
Expect(1, 983037, '\P{Is_In=0_0_0_0_02.1}', "");
Expect(0, 983037, '\P{^Is_In=0_0_0_0_02.1}', "");
Error('\p{Present_In=:=--0003.0}');
Error('\P{Present_In=:=--0003.0}');
Expect(1, 983040, '\p{Present_In=+00000003.0}', "");
Expect(0, 983040, '\p{^Present_In=+00000003.0}', "");
Expect(0, 983040, '\P{Present_In=+00000003.0}', "");
Expect(1, 983040, '\P{^Present_In=+00000003.0}', "");
Expect(0, 983037, '\p{Present_In=+00000003.0}', "");
Expect(1, 983037, '\p{^Present_In=+00000003.0}', "");
Expect(1, 983037, '\P{Present_In=+00000003.0}', "");
Expect(0, 983037, '\P{^Present_In=+00000003.0}', "");
Error('\p{In=/a/_0_3.0}');
Error('\P{In=/a/_0_3.0}');
Expect(1, 983040, '\p{In=+00_3.0}', "");
Expect(0, 983040, '\p{^In=+00_3.0}', "");
Expect(0, 983040, '\P{In=+00_3.0}', "");
Expect(1, 983040, '\P{^In=+00_3.0}', "");
Expect(0, 983037, '\p{In=+00_3.0}', "");
Expect(1, 983037, '\p{^In=+00_3.0}', "");
Expect(1, 983037, '\P{In=+00_3.0}', "");
Expect(0, 983037, '\P{^In=+00_3.0}', "");
Error('\p{Is_Present_In=:=000_000_3.0}');
Error('\P{Is_Present_In=:=000_000_3.0}');
Expect(1, 983040, '\p{Is_Present_In=+00003.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=+00003.0}', "");
Expect(0, 983040, '\P{Is_Present_In=+00003.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=+00003.0}', "");
Expect(0, 983037, '\p{Is_Present_In=+00003.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=+00003.0}', "");
Expect(1, 983037, '\P{Is_Present_In=+00003.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=+00003.0}', "");
Error('\p{Is_In=:= 0_0_0_03.0}');
Error('\P{Is_In=:= 0_0_0_03.0}');
Expect(1, 983040, '\p{Is_In=+000003.0}', "");
Expect(0, 983040, '\p{^Is_In=+000003.0}', "");
Expect(0, 983040, '\P{Is_In=+000003.0}', "");
Expect(1, 983040, '\P{^Is_In=+000003.0}', "");
Expect(0, 983037, '\p{Is_In=+000003.0}', "");
Expect(1, 983037, '\p{^Is_In=+000003.0}', "");
Expect(1, 983037, '\P{Is_In=+000003.0}', "");
Expect(0, 983037, '\P{^Is_In=+000003.0}', "");
Error('\p{Present_In= :=3.1}');
Error('\P{Present_In= :=3.1}');
Expect(1, 983040, '\p{Present_In=0_0_0_0_003.1}', "");
Expect(0, 983040, '\p{^Present_In=0_0_0_0_003.1}', "");
Expect(0, 983040, '\P{Present_In=0_0_0_0_003.1}', "");
Expect(1, 983040, '\P{^Present_In=0_0_0_0_003.1}', "");
Expect(0, 983037, '\p{Present_In=0_0_0_0_003.1}', "");
Expect(1, 983037, '\p{^Present_In=0_0_0_0_003.1}', "");
Expect(1, 983037, '\P{Present_In=0_0_0_0_003.1}', "");
Expect(0, 983037, '\P{^Present_In=0_0_0_0_003.1}', "");
Error('\p{In= :=3.1}');
Error('\P{In= :=3.1}');
Expect(1, 983040, '\p{In=00000003.1}', "");
Expect(0, 983040, '\p{^In=00000003.1}', "");
Expect(0, 983040, '\P{In=00000003.1}', "");
Expect(1, 983040, '\P{^In=00000003.1}', "");
Expect(0, 983037, '\p{In=00000003.1}', "");
Expect(1, 983037, '\p{^In=00000003.1}', "");
Expect(1, 983037, '\P{In=00000003.1}', "");
Expect(0, 983037, '\P{^In=00000003.1}', "");
Error('\p{Is_Present_In=		+00_00_3.1/a/}');
Error('\P{Is_Present_In=		+00_00_3.1/a/}');
Expect(1, 983040, '\p{Is_Present_In=00_00_00_00_03.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=00_00_00_00_03.1}', "");
Expect(0, 983040, '\P{Is_Present_In=00_00_00_00_03.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=00_00_00_00_03.1}', "");
Expect(0, 983037, '\p{Is_Present_In=00_00_00_00_03.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=00_00_00_00_03.1}', "");
Expect(1, 983037, '\P{Is_Present_In=00_00_00_00_03.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=00_00_00_00_03.1}', "");
Error('\p{Is_In=:= 	0_0_0_003.1}');
Error('\P{Is_In=:= 	0_0_0_003.1}');
Expect(1, 983040, '\p{Is_In=+0_0_0_0_003.1}', "");
Expect(0, 983040, '\p{^Is_In=+0_0_0_0_003.1}', "");
Expect(0, 983040, '\P{Is_In=+0_0_0_0_003.1}', "");
Expect(1, 983040, '\P{^Is_In=+0_0_0_0_003.1}', "");
Expect(0, 983037, '\p{Is_In=+0_0_0_0_003.1}', "");
Expect(1, 983037, '\p{^Is_In=+0_0_0_0_003.1}', "");
Expect(1, 983037, '\P{Is_In=+0_0_0_0_003.1}', "");
Expect(0, 983037, '\P{^Is_In=+0_0_0_0_003.1}', "");
Error('\p{Present_In=__00_00_3.2:=}');
Error('\P{Present_In=__00_00_3.2:=}');
Expect(1, 983040, '\p{Present_In=00_3.2}', "");
Expect(0, 983040, '\p{^Present_In=00_3.2}', "");
Expect(0, 983040, '\P{Present_In=00_3.2}', "");
Expect(1, 983040, '\P{^Present_In=00_3.2}', "");
Expect(0, 983037, '\p{Present_In=00_3.2}', "");
Expect(1, 983037, '\p{^Present_In=00_3.2}', "");
Expect(1, 983037, '\P{Present_In=00_3.2}', "");
Expect(0, 983037, '\P{^Present_In=00_3.2}', "");
Error('\p{In= +3.2/a/}');
Error('\P{In= +3.2/a/}');
Expect(1, 983040, '\p{In=0_0_0_0_0_0_0003.2}', "");
Expect(0, 983040, '\p{^In=0_0_0_0_0_0_0003.2}', "");
Expect(0, 983040, '\P{In=0_0_0_0_0_0_0003.2}', "");
Expect(1, 983040, '\P{^In=0_0_0_0_0_0_0003.2}', "");
Expect(0, 983037, '\p{In=0_0_0_0_0_0_0003.2}', "");
Expect(1, 983037, '\p{^In=0_0_0_0_0_0_0003.2}', "");
Expect(1, 983037, '\P{In=0_0_0_0_0_0_0003.2}', "");
Expect(0, 983037, '\P{^In=0_0_0_0_0_0_0003.2}', "");
Error('\p{Is_Present_In: -0_0_03.2:=}');
Error('\P{Is_Present_In: -0_0_03.2:=}');
Expect(1, 983040, '\p{Is_Present_In=00003.2}', "");
Expect(0, 983040, '\p{^Is_Present_In=00003.2}', "");
Expect(0, 983040, '\P{Is_Present_In=00003.2}', "");
Expect(1, 983040, '\P{^Is_Present_In=00003.2}', "");
Expect(0, 983037, '\p{Is_Present_In=00003.2}', "");
Expect(1, 983037, '\p{^Is_Present_In=00003.2}', "");
Expect(1, 983037, '\P{Is_Present_In=00003.2}', "");
Expect(0, 983037, '\P{^Is_Present_In=00003.2}', "");
Error('\p{Is_In=:=_-0_0_03.2}');
Error('\P{Is_In=:=_-0_0_03.2}');
Expect(1, 983040, '\p{Is_In=+000_3.2}', "");
Expect(0, 983040, '\p{^Is_In=+000_3.2}', "");
Expect(0, 983040, '\P{Is_In=+000_3.2}', "");
Expect(1, 983040, '\P{^Is_In=+000_3.2}', "");
Expect(0, 983037, '\p{Is_In=+000_3.2}', "");
Expect(1, 983037, '\p{^Is_In=+000_3.2}', "");
Expect(1, 983037, '\P{Is_In=+000_3.2}', "");
Expect(0, 983037, '\P{^Is_In=+000_3.2}', "");
Error('\p{Present_In=_-0000000004.0:=}');
Error('\P{Present_In=_-0000000004.0:=}');
Expect(1, 983040, '\p{Present_In=+00_4.0}', "");
Expect(0, 983040, '\p{^Present_In=+00_4.0}', "");
Expect(0, 983040, '\P{Present_In=+00_4.0}', "");
Expect(1, 983040, '\P{^Present_In=+00_4.0}', "");
Expect(0, 983037, '\p{Present_In=+00_4.0}', "");
Expect(1, 983037, '\p{^Present_In=+00_4.0}', "");
Expect(1, 983037, '\P{Present_In=+00_4.0}', "");
Expect(0, 983037, '\P{^Present_In=+00_4.0}', "");
Error('\p{In=	/a/+000_4.0}');
Error('\P{In=	/a/+000_4.0}');
Expect(1, 983040, '\p{In=4.0}', "");
Expect(0, 983040, '\p{^In=4.0}', "");
Expect(0, 983040, '\P{In=4.0}', "");
Expect(1, 983040, '\P{^In=4.0}', "");
Expect(0, 983037, '\p{In=4.0}', "");
Expect(1, 983037, '\p{^In=4.0}', "");
Expect(1, 983037, '\P{In=4.0}', "");
Expect(0, 983037, '\P{^In=4.0}', "");
Error('\p{Is_Present_In:   	:=0000004.0}');
Error('\P{Is_Present_In:   	:=0000004.0}');
Expect(1, 983040, '\p{Is_Present_In=0000004.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=0000004.0}', "");
Expect(0, 983040, '\P{Is_Present_In=0000004.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=0000004.0}', "");
Expect(0, 983037, '\p{Is_Present_In=0000004.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=0000004.0}', "");
Expect(1, 983037, '\P{Is_Present_In=0000004.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=0000004.0}', "");
Error('\p{Is_In=-:=00_4.0}');
Error('\P{Is_In=-:=00_4.0}');
Expect(1, 983040, '\p{Is_In=0000_0000_4.0}', "");
Expect(0, 983040, '\p{^Is_In=0000_0000_4.0}', "");
Expect(0, 983040, '\P{Is_In=0000_0000_4.0}', "");
Expect(1, 983040, '\P{^Is_In=0000_0000_4.0}', "");
Expect(0, 983037, '\p{Is_In=0000_0000_4.0}', "");
Expect(1, 983037, '\p{^Is_In=0000_0000_4.0}', "");
Expect(1, 983037, '\P{Is_In=0000_0000_4.0}', "");
Expect(0, 983037, '\P{^Is_In=0000_0000_4.0}', "");
Error('\p{Present_In=/a/		004.1}');
Error('\P{Present_In=/a/		004.1}');
Expect(1, 983040, '\p{Present_In=+00_4.1}', "");
Expect(0, 983040, '\p{^Present_In=+00_4.1}', "");
Expect(0, 983040, '\P{Present_In=+00_4.1}', "");
Expect(1, 983040, '\P{^Present_In=+00_4.1}', "");
Expect(0, 983037, '\p{Present_In=+00_4.1}', "");
Expect(1, 983037, '\p{^Present_In=+00_4.1}', "");
Expect(1, 983037, '\P{Present_In=+00_4.1}', "");
Expect(0, 983037, '\P{^Present_In=+00_4.1}', "");
Error('\p{In:    -0000000_4.1/a/}');
Error('\P{In:    -0000000_4.1/a/}');
Expect(1, 983040, '\p{In=000_4.1}', "");
Expect(0, 983040, '\p{^In=000_4.1}', "");
Expect(0, 983040, '\P{In=000_4.1}', "");
Expect(1, 983040, '\P{^In=000_4.1}', "");
Expect(0, 983037, '\p{In=000_4.1}', "");
Expect(1, 983037, '\p{^In=000_4.1}', "");
Expect(1, 983037, '\P{In=000_4.1}', "");
Expect(0, 983037, '\P{^In=000_4.1}', "");
Error('\p{Is_Present_In= :=+4.1}');
Error('\P{Is_Present_In= :=+4.1}');
Expect(1, 983040, '\p{Is_Present_In=0_0_0_0_0004.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=0_0_0_0_0004.1}', "");
Expect(0, 983040, '\P{Is_Present_In=0_0_0_0_0004.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=0_0_0_0_0004.1}', "");
Expect(0, 983037, '\p{Is_Present_In=0_0_0_0_0004.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=0_0_0_0_0004.1}', "");
Expect(1, 983037, '\P{Is_Present_In=0_0_0_0_0004.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=0_0_0_0_0004.1}', "");
Error('\p{Is_In=:=_ 0_0_0_0_0_0_0_04.1}');
Error('\P{Is_In=:=_ 0_0_0_0_0_0_0_04.1}');
Expect(1, 983040, '\p{Is_In=0004.1}', "");
Expect(0, 983040, '\p{^Is_In=0004.1}', "");
Expect(0, 983040, '\P{Is_In=0004.1}', "");
Expect(1, 983040, '\P{^Is_In=0004.1}', "");
Expect(0, 983037, '\p{Is_In=0004.1}', "");
Expect(1, 983037, '\p{^Is_In=0004.1}', "");
Expect(1, 983037, '\P{Is_In=0004.1}', "");
Expect(0, 983037, '\P{^Is_In=0004.1}', "");
Error('\p{Present_In=_/a/0_0_0_005.0}');
Error('\P{Present_In=_/a/0_0_0_005.0}');
Expect(1, 983040, '\p{Present_In=+5.0}', "");
Expect(0, 983040, '\p{^Present_In=+5.0}', "");
Expect(0, 983040, '\P{Present_In=+5.0}', "");
Expect(1, 983040, '\P{^Present_In=+5.0}', "");
Expect(0, 983037, '\p{Present_In=+5.0}', "");
Expect(1, 983037, '\p{^Present_In=+5.0}', "");
Expect(1, 983037, '\P{Present_In=+5.0}', "");
Expect(0, 983037, '\P{^Present_In=+5.0}', "");
Error('\p{In=_/a/005.0}');
Error('\P{In=_/a/005.0}');
Expect(1, 983040, '\p{In=0_0_0_0_0005.0}', "");
Expect(0, 983040, '\p{^In=0_0_0_0_0005.0}', "");
Expect(0, 983040, '\P{In=0_0_0_0_0005.0}', "");
Expect(1, 983040, '\P{^In=0_0_0_0_0005.0}', "");
Expect(0, 983037, '\p{In=0_0_0_0_0005.0}', "");
Expect(1, 983037, '\p{^In=0_0_0_0_0005.0}', "");
Expect(1, 983037, '\P{In=0_0_0_0_0005.0}', "");
Expect(0, 983037, '\P{^In=0_0_0_0_0005.0}', "");
Error('\p{Is_Present_In=-:=000_000_5.0}');
Error('\P{Is_Present_In=-:=000_000_5.0}');
Expect(1, 983040, '\p{Is_Present_In=00000_5.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=00000_5.0}', "");
Expect(0, 983040, '\P{Is_Present_In=00000_5.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=00000_5.0}', "");
Expect(0, 983037, '\p{Is_Present_In=00000_5.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=00000_5.0}', "");
Expect(1, 983037, '\P{Is_Present_In=00000_5.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=00000_5.0}', "");
Error('\p{Is_In=_00000005.0/a/}');
Error('\P{Is_In=_00000005.0/a/}');
Expect(1, 983040, '\p{Is_In=00_00_5.0}', "");
Expect(0, 983040, '\p{^Is_In=00_00_5.0}', "");
Expect(0, 983040, '\P{Is_In=00_00_5.0}', "");
Expect(1, 983040, '\P{^Is_In=00_00_5.0}', "");
Expect(0, 983037, '\p{Is_In=00_00_5.0}', "");
Expect(1, 983037, '\p{^Is_In=00_00_5.0}', "");
Expect(1, 983037, '\P{Is_In=00_00_5.0}', "");
Expect(0, 983037, '\P{^Is_In=00_00_5.0}', "");
Error('\p{Present_In:   :=+5.1}');
Error('\P{Present_In:   :=+5.1}');
Expect(1, 983040, '\p{Present_In=0_0_0_05.1}', "");
Expect(0, 983040, '\p{^Present_In=0_0_0_05.1}', "");
Expect(0, 983040, '\P{Present_In=0_0_0_05.1}', "");
Expect(1, 983040, '\P{^Present_In=0_0_0_05.1}', "");
Expect(0, 983037, '\p{Present_In=0_0_0_05.1}', "");
Expect(1, 983037, '\p{^Present_In=0_0_0_05.1}', "");
Expect(1, 983037, '\P{Present_In=0_0_0_05.1}', "");
Expect(0, 983037, '\P{^Present_In=0_0_0_05.1}', "");
Error('\p{In=/a/ 05.1}');
Error('\P{In=/a/ 05.1}');
Expect(1, 983040, '\p{In=0000000_5.1}', "");
Expect(0, 983040, '\p{^In=0000000_5.1}', "");
Expect(0, 983040, '\P{In=0000000_5.1}', "");
Expect(1, 983040, '\P{^In=0000000_5.1}', "");
Expect(0, 983037, '\p{In=0000000_5.1}', "");
Expect(1, 983037, '\p{^In=0000000_5.1}', "");
Expect(1, 983037, '\P{In=0000000_5.1}', "");
Expect(0, 983037, '\P{^In=0000000_5.1}', "");
Error('\p{Is_Present_In=/a/_-0000_0000_05.1}');
Error('\P{Is_Present_In=/a/_-0000_0000_05.1}');
Expect(1, 983040, '\p{Is_Present_In=000_000_05.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=000_000_05.1}', "");
Expect(0, 983040, '\P{Is_Present_In=000_000_05.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=000_000_05.1}', "");
Expect(0, 983037, '\p{Is_Present_In=000_000_05.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=000_000_05.1}', "");
Expect(1, 983037, '\P{Is_Present_In=000_000_05.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=000_000_05.1}', "");
Error('\p{Is_In= :=000_000_5.1}');
Error('\P{Is_In= :=000_000_5.1}');
Expect(1, 983040, '\p{Is_In=+00_5.1}', "");
Expect(0, 983040, '\p{^Is_In=+00_5.1}', "");
Expect(0, 983040, '\P{Is_In=+00_5.1}', "");
Expect(1, 983040, '\P{^Is_In=+00_5.1}', "");
Expect(0, 983037, '\p{Is_In=+00_5.1}', "");
Expect(1, 983037, '\p{^Is_In=+00_5.1}', "");
Expect(1, 983037, '\P{Is_In=+00_5.1}', "");
Expect(0, 983037, '\P{^Is_In=+00_5.1}', "");
Error('\p{Present_In=--+000000005.2:=}');
Error('\P{Present_In=--+000000005.2:=}');
Expect(1, 983040, '\p{Present_In=0_0_0_05.2}', "");
Expect(0, 983040, '\p{^Present_In=0_0_0_05.2}', "");
Expect(0, 983040, '\P{Present_In=0_0_0_05.2}', "");
Expect(1, 983040, '\P{^Present_In=0_0_0_05.2}', "");
Expect(0, 983037, '\p{Present_In=0_0_0_05.2}', "");
Expect(1, 983037, '\p{^Present_In=0_0_0_05.2}', "");
Expect(1, 983037, '\P{Present_In=0_0_0_05.2}', "");
Expect(0, 983037, '\P{^Present_In=0_0_0_05.2}', "");
Error('\p{In: /a/0005.2}');
Error('\P{In: /a/0005.2}');
Expect(1, 983040, '\p{In=+00_5.2}', "");
Expect(0, 983040, '\p{^In=+00_5.2}', "");
Expect(0, 983040, '\P{In=+00_5.2}', "");
Expect(1, 983040, '\P{^In=+00_5.2}', "");
Expect(0, 983037, '\p{In=+00_5.2}', "");
Expect(1, 983037, '\p{^In=+00_5.2}', "");
Expect(1, 983037, '\P{In=+00_5.2}', "");
Expect(0, 983037, '\P{^In=+00_5.2}', "");
Error('\p{Is_Present_In=/a/ 00_00_00_005.2}');
Error('\P{Is_Present_In=/a/ 00_00_00_005.2}');
Expect(1, 983040, '\p{Is_Present_In=005.2}', "");
Expect(0, 983040, '\p{^Is_Present_In=005.2}', "");
Expect(0, 983040, '\P{Is_Present_In=005.2}', "");
Expect(1, 983040, '\P{^Is_Present_In=005.2}', "");
Expect(0, 983037, '\p{Is_Present_In=005.2}', "");
Expect(1, 983037, '\p{^Is_Present_In=005.2}', "");
Expect(1, 983037, '\P{Is_Present_In=005.2}', "");
Expect(0, 983037, '\P{^Is_Present_In=005.2}', "");
Error('\p{Is_In=/a/00_00_00_005.2}');
Error('\P{Is_In=/a/00_00_00_005.2}');
Expect(1, 983040, '\p{Is_In=0000_5.2}', "");
Expect(0, 983040, '\p{^Is_In=0000_5.2}', "");
Expect(0, 983040, '\P{Is_In=0000_5.2}', "");
Expect(1, 983040, '\P{^Is_In=0000_5.2}', "");
Expect(0, 983037, '\p{Is_In=0000_5.2}', "");
Expect(1, 983037, '\p{^Is_In=0000_5.2}', "");
Expect(1, 983037, '\P{Is_In=0000_5.2}', "");
Expect(0, 983037, '\P{^Is_In=0000_5.2}', "");
Error('\p{Present_In=-/a/0006.0}');
Error('\P{Present_In=-/a/0006.0}');
Expect(1, 983040, '\p{Present_In=+6.0}', "");
Expect(0, 983040, '\p{^Present_In=+6.0}', "");
Expect(0, 983040, '\P{Present_In=+6.0}', "");
Expect(1, 983040, '\P{^Present_In=+6.0}', "");
Expect(0, 983037, '\p{Present_In=+6.0}', "");
Expect(1, 983037, '\p{^Present_In=+6.0}', "");
Expect(1, 983037, '\P{Present_In=+6.0}', "");
Expect(0, 983037, '\P{^Present_In=+6.0}', "");
Error('\p{In=-/a/+0000000006.0}');
Error('\P{In=-/a/+0000000006.0}');
Expect(1, 983040, '\p{In=0000000006.0}', "");
Expect(0, 983040, '\p{^In=0000000006.0}', "");
Expect(0, 983040, '\P{In=0000000006.0}', "");
Expect(1, 983040, '\P{^In=0000000006.0}', "");
Expect(0, 983037, '\p{In=0000000006.0}', "");
Expect(1, 983037, '\p{^In=0000000006.0}', "");
Expect(1, 983037, '\P{In=0000000006.0}', "");
Expect(0, 983037, '\P{^In=0000000006.0}', "");
Error('\p{Is_Present_In=_	0_0_0_006.0/a/}');
Error('\P{Is_Present_In=_	0_0_0_006.0/a/}');
Expect(1, 983040, '\p{Is_Present_In=+0_6.0}', "");
Expect(0, 983040, '\p{^Is_Present_In=+0_6.0}', "");
Expect(0, 983040, '\P{Is_Present_In=+0_6.0}', "");
Expect(1, 983040, '\P{^Is_Present_In=+0_6.0}', "");
Expect(0, 983037, '\p{Is_Present_In=+0_6.0}', "");
Expect(1, 983037, '\p{^Is_Present_In=+0_6.0}', "");
Expect(1, 983037, '\P{Is_Present_In=+0_6.0}', "");
Expect(0, 983037, '\P{^Is_Present_In=+0_6.0}', "");
Error('\p{Is_In=_/a/0_0_0_0_0_0_06.0}');
Error('\P{Is_In=_/a/0_0_0_0_0_0_06.0}');
Expect(1, 983040, '\p{Is_In=00_00_6.0}', "");
Expect(0, 983040, '\p{^Is_In=00_00_6.0}', "");
Expect(0, 983040, '\P{Is_In=00_00_6.0}', "");
Expect(1, 983040, '\P{^Is_In=00_00_6.0}', "");
Expect(0, 983037, '\p{Is_In=00_00_6.0}', "");
Expect(1, 983037, '\p{^Is_In=00_00_6.0}', "");
Expect(1, 983037, '\P{Is_In=00_00_6.0}', "");
Expect(0, 983037, '\P{^Is_In=00_00_6.0}', "");
Error('\p{Present_In=/a/ 0000006.1}');
Error('\P{Present_In=/a/ 0000006.1}');
Expect(1, 983040, '\p{Present_In=+00_6.1}', "");
Expect(0, 983040, '\p{^Present_In=+00_6.1}', "");
Expect(0, 983040, '\P{Present_In=+00_6.1}', "");
Expect(1, 983040, '\P{^Present_In=+00_6.1}', "");
Expect(0, 983037, '\p{Present_In=+00_6.1}', "");
Expect(1, 983037, '\p{^Present_In=+00_6.1}', "");
Expect(1, 983037, '\P{Present_In=+00_6.1}', "");
Expect(0, 983037, '\P{^Present_In=+00_6.1}', "");
Error('\p{In=/a/__0000000006.1}');
Error('\P{In=/a/__0000000006.1}');
Expect(1, 983040, '\p{In:   00000006.1}', "");
Expect(0, 983040, '\p{^In:   00000006.1}', "");
Expect(0, 983040, '\P{In:   00000006.1}', "");
Expect(1, 983040, '\P{^In:   00000006.1}', "");
Expect(0, 983037, '\p{In:   00000006.1}', "");
Expect(1, 983037, '\p{^In:   00000006.1}', "");
Expect(1, 983037, '\P{In:   00000006.1}', "");
Expect(0, 983037, '\P{^In:   00000006.1}', "");
Error('\p{Is_Present_In:/a/-0000006.1}');
Error('\P{Is_Present_In:/a/-0000006.1}');
Expect(1, 983040, '\p{Is_Present_In=+0_0_0_0_06.1}', "");
Expect(0, 983040, '\p{^Is_Present_In=+0_0_0_0_06.1}', "");
Expect(0, 983040, '\P{Is_Present_In=+0_0_0_0_06.1}', "");
Expect(1, 983040, '\P{^Is_Present_In=+0_0_0_0_06.1}', "");
Expect(0, 983037, '\p{Is_Present_In=+0_0_0_0_06.1}', "");
Expect(1, 983037, '\p{^Is_Present_In=+0_0_0_0_06.1}', "");
Expect(1, 983037, '\P{Is_Present_In=+0_0_0_0_06.1}', "");
Expect(0, 983037, '\P{^Is_Present_In=+0_0_0_0_06.1}', "");
Error('\p{Is_In=	:=00000_6.1}');
Error('\P{Is_In=	:=00000_6.1}');
Expect(1, 983040, '\p{Is_In=+0006.1}', "");
Expect(0, 983040, '\p{^Is_In=+0006.1}', "");
Expect(0, 983040, '\P{Is_In=+0006.1}', "");
Expect(1, 983040, '\P{^Is_In=+0006.1}', "");
Expect(0, 983037, '\p{Is_In=+0006.1}', "");
Expect(1, 983037, '\p{^Is_In=+0006.1}', "");
Expect(1, 983037, '\P{Is_In=+0006.1}', "");
Expect(0, 983037, '\P{^Is_In=+0006.1}', "");
Error('\p{Present_In= -0_0_06.2:=}');
Error('\P{Present_In= -0_0_06.2:=}');
Expect(1, 983040, '\p{Present_In=0000_0000_06.2}', "");
Expect(0, 983040, '\p{^Present_In=0000_0000_06.2}', "");
Expect(0, 983040, '\P{Present_In=0000_0000_06.2}', "");
Expect(1, 983040, '\P{^Present_In=0000_0000_06.2}', "");
Expect(0, 983037, '\p{Present_In=0000_0000_06.2}', "");
Expect(1, 983037, '\p{^Present_In=0000_0000_06.2}', "");
Expect(1, 983037, '\P{Present_In=0000_0000_06.2}', "");
Expect(0, 983037, '\P{^Present_In=0000_0000_06.2}', "");
Error('\p{In=-00_00_00_6.2:=}');
Error('\P{In=-00_00_00_6.2:=}');
Expect(1, 983040, '\p{In=+000000006.2}', "");
Expect(0, 983040, '\p{^In=+000000006.2}', "");
Expect(0, 983040, '\P{In=+000000006.2}', "");
Expect(1, 983040, '\P{^In=+000000006.2}', "");
Expect(0, 983037, '\p{In=+000000006.2}', "");
Expect(1, 983037, '\p{^In=+000000006.2}', "");
Expect(1, 983037, '\P{In=+000000006.2}', "");
Expect(0, 983037, '\P{^In=+000000006.2}', "");
Error('\p{Is_Present_In: /a/00_6.2}');
Error('\P{Is_Present_In: /a/00_6.2}');
Expect(1, 983040, '\p{Is_Present_In=00_00_00_006.2}', "");
Expect(0, 983040, '\p{^Is_Present_In=00_00_00_006.2}', "");
Expect(0, 983040, '\P{Is_Present_In=00_00_00_006.2}', "");
Expect(1, 983040, '\P{^Is_Present_In=00_00_00_006.2}', "");
Expect(0, 983037, '\p{Is_Present_In=00_00_00_006.2}', "");
Expect(1, 983037, '\p{^Is_Present_In=00_00_00_006.2}', "");
Expect(1, 983037, '\P{Is_Present_In=00_00_00_006.2}', "");
Expect(0, 983037, '\P{^Is_Present_In=00_00_00_006.2}', "");
Error('\p{Is_In=0_0_0_0_0_006.2/a/}');
Error('\P{Is_In=0_0_0_0_0_006.2/a/}');
Expect(1, 983040, '\p{Is_In=00006.2}', "");
Expect(0, 983040, '\p{^Is_In=00006.2}', "");
Expect(0, 983040, '\P{Is_In=00006.2}', "");
Expect(1, 983040, '\P{^Is_In=00006.2}', "");
Expect(0, 983037, '\p{Is_In=00006.2}', "");
Expect(1, 983037, '\p{^Is_In=00006.2}', "");
Expect(1, 983037, '\P{Is_In=00006.2}', "");
Expect(0, 983037, '\P{^Is_In=00006.2}', "");
Error('\p{Present_In: /a/	_UNASSIGNED}');
Error('\P{Present_In: /a/	_UNASSIGNED}');
Expect(1, 983037, '\p{Present_In=unassigned}', "");
Expect(0, 983037, '\p{^Present_In=unassigned}', "");
Expect(0, 983037, '\P{Present_In=unassigned}', "");
Expect(1, 983037, '\P{^Present_In=unassigned}', "");
Expect(0, 983040, '\p{Present_In=unassigned}', "");
Expect(1, 983040, '\p{^Present_In=unassigned}', "");
Expect(1, 983040, '\P{Present_In=unassigned}', "");
Expect(0, 983040, '\P{^Present_In=unassigned}', "");
Expect(1, 983037, '\p{Present_In=_Unassigned}', "");
Expect(0, 983037, '\p{^Present_In=_Unassigned}', "");
Expect(0, 983037, '\P{Present_In=_Unassigned}', "");
Expect(1, 983037, '\P{^Present_In=_Unassigned}', "");
Expect(0, 983040, '\p{Present_In=_Unassigned}', "");
Expect(1, 983040, '\p{^Present_In=_Unassigned}', "");
Expect(1, 983040, '\P{Present_In=_Unassigned}', "");
Expect(0, 983040, '\P{^Present_In=_Unassigned}', "");
Error('\p{In=-:=Unassigned}');
Error('\P{In=-:=Unassigned}');
Expect(1, 983037, '\p{In:   unassigned}', "");
Expect(0, 983037, '\p{^In:   unassigned}', "");
Expect(0, 983037, '\P{In:   unassigned}', "");
Expect(1, 983037, '\P{^In:   unassigned}', "");
Expect(0, 983040, '\p{In:   unassigned}', "");
Expect(1, 983040, '\p{^In:   unassigned}', "");
Expect(1, 983040, '\P{In:   unassigned}', "");
Expect(0, 983040, '\P{^In:   unassigned}', "");
Expect(1, 983037, '\p{In=--unassigned}', "");
Expect(0, 983037, '\p{^In=--unassigned}', "");
Expect(0, 983037, '\P{In=--unassigned}', "");
Expect(1, 983037, '\P{^In=--unassigned}', "");
Expect(0, 983040, '\p{In=--unassigned}', "");
Expect(1, 983040, '\p{^In=--unassigned}', "");
Expect(1, 983040, '\P{In=--unassigned}', "");
Expect(0, 983040, '\P{^In=--unassigned}', "");
Error('\p{Is_Present_In:   	unassigned/a/}');
Error('\P{Is_Present_In:   	unassigned/a/}');
Expect(1, 983037, '\p{Is_Present_In=unassigned}', "");
Expect(0, 983037, '\p{^Is_Present_In=unassigned}', "");
Expect(0, 983037, '\P{Is_Present_In=unassigned}', "");
Expect(1, 983037, '\P{^Is_Present_In=unassigned}', "");
Expect(0, 983040, '\p{Is_Present_In=unassigned}', "");
Expect(1, 983040, '\p{^Is_Present_In=unassigned}', "");
Expect(1, 983040, '\P{Is_Present_In=unassigned}', "");
Expect(0, 983040, '\P{^Is_Present_In=unassigned}', "");
Expect(1, 983037, '\p{Is_Present_In=-	Unassigned}', "");
Expect(0, 983037, '\p{^Is_Present_In=-	Unassigned}', "");
Expect(0, 983037, '\P{Is_Present_In=-	Unassigned}', "");
Expect(1, 983037, '\P{^Is_Present_In=-	Unassigned}', "");
Expect(0, 983040, '\p{Is_Present_In=-	Unassigned}', "");
Expect(1, 983040, '\p{^Is_Present_In=-	Unassigned}', "");
Expect(1, 983040, '\P{Is_Present_In=-	Unassigned}', "");
Expect(0, 983040, '\P{^Is_Present_In=-	Unassigned}', "");
Error('\p{Is_In=	UNASSIGNED/a/}');
Error('\P{Is_In=	UNASSIGNED/a/}');
Expect(1, 983037, '\p{Is_In=unassigned}', "");
Expect(0, 983037, '\p{^Is_In=unassigned}', "");
Expect(0, 983037, '\P{Is_In=unassigned}', "");
Expect(1, 983037, '\P{^Is_In=unassigned}', "");
Expect(0, 983040, '\p{Is_In=unassigned}', "");
Expect(1, 983040, '\p{^Is_In=unassigned}', "");
Expect(1, 983040, '\P{Is_In=unassigned}', "");
Expect(0, 983040, '\P{^Is_In=unassigned}', "");
Expect(1, 983037, '\p{Is_In=	Unassigned}', "");
Expect(0, 983037, '\p{^Is_In=	Unassigned}', "");
Expect(0, 983037, '\P{Is_In=	Unassigned}', "");
Expect(1, 983037, '\P{^Is_In=	Unassigned}', "");
Expect(0, 983040, '\p{Is_In=	Unassigned}', "");
Expect(1, 983040, '\p{^Is_In=	Unassigned}', "");
Expect(1, 983040, '\P{Is_In=	Unassigned}', "");
Expect(0, 983040, '\P{^Is_In=	Unassigned}', "");
Error('\p{Indic_Matra_Category:Bottom}');
Error('\P{Indic_Matra_Category:Bottom}');
Error('\p{InMC=Bottom}');
Error('\P{InMC=Bottom}');
Error('\p{Is_Indic_Matra_Category=Bottom}');
Error('\P{Is_Indic_Matra_Category=Bottom}');
Error('\p{Is_InMC=Bottom}');
Error('\P{Is_InMC=Bottom}');
Error('\p{Indic_Matra_Category=Bottom_And_Right}');
Error('\P{Indic_Matra_Category=Bottom_And_Right}');
Error('\p{InMC=Bottom_And_Right}');
Error('\P{InMC=Bottom_And_Right}');
Error('\p{Is_Indic_Matra_Category=Bottom_And_Right}');
Error('\P{Is_Indic_Matra_Category=Bottom_And_Right}');
Error('\p{Is_InMC=Bottom_And_Right}');
Error('\P{Is_InMC=Bottom_And_Right}');
Error('\p{Indic_Matra_Category:Invisible}');
Error('\P{Indic_Matra_Category:Invisible}');
Error('\p{InMC=Invisible}');
Error('\P{InMC=Invisible}');
Error('\p{Is_Indic_Matra_Category=Invisible}');
Error('\P{Is_Indic_Matra_Category=Invisible}');
Error('\p{Is_InMC=Invisible}');
Error('\P{Is_InMC=Invisible}');
Error('\p{Indic_Matra_Category=Left}');
Error('\P{Indic_Matra_Category=Left}');
Error('\p{InMC=Left}');
Error('\P{InMC=Left}');
Error('\p{Is_Indic_Matra_Category=Left}');
Error('\P{Is_Indic_Matra_Category=Left}');
Error('\p{Is_InMC=Left}');
Error('\P{Is_InMC=Left}');
Error('\p{Indic_Matra_Category=Left_And_Right}');
Error('\P{Indic_Matra_Category=Left_And_Right}');
Error('\p{InMC=Left_And_Right}');
Error('\P{InMC=Left_And_Right}');
Error('\p{Is_Indic_Matra_Category:   Left_And_Right}');
Error('\P{Is_Indic_Matra_Category:   Left_And_Right}');
Error('\p{Is_InMC=Left_And_Right}');
Error('\P{Is_InMC=Left_And_Right}');
Error('\p{Indic_Matra_Category=NA}');
Error('\P{Indic_Matra_Category=NA}');
Error('\p{InMC=NA}');
Error('\P{InMC=NA}');
Error('\p{Is_Indic_Matra_Category=NA}');
Error('\P{Is_Indic_Matra_Category=NA}');
Error('\p{Is_InMC=NA}');
Error('\P{Is_InMC=NA}');
Error('\p{Indic_Matra_Category=Overstruck}');
Error('\P{Indic_Matra_Category=Overstruck}');
Error('\p{InMC=Overstruck}');
Error('\P{InMC=Overstruck}');
Error('\p{Is_Indic_Matra_Category=Overstruck}');
Error('\P{Is_Indic_Matra_Category=Overstruck}');
Error('\p{Is_InMC=Overstruck}');
Error('\P{Is_InMC=Overstruck}');
Error('\p{Indic_Matra_Category=Right}');
Error('\P{Indic_Matra_Category=Right}');
Error('\p{InMC=Right}');
Error('\P{InMC=Right}');
Error('\p{Is_Indic_Matra_Category=Right}');
Error('\P{Is_Indic_Matra_Category=Right}');
Error('\p{Is_InMC=Right}');
Error('\P{Is_InMC=Right}');
Error('\p{Indic_Matra_Category=Top}');
Error('\P{Indic_Matra_Category=Top}');
Error('\p{InMC=Top}');
Error('\P{InMC=Top}');
Error('\p{Is_Indic_Matra_Category=Top}');
Error('\P{Is_Indic_Matra_Category=Top}');
Error('\p{Is_InMC:   Top}');
Error('\P{Is_InMC:   Top}');
Error('\p{Indic_Matra_Category=Top_And_Bottom}');
Error('\P{Indic_Matra_Category=Top_And_Bottom}');
Error('\p{InMC=Top_And_Bottom}');
Error('\P{InMC=Top_And_Bottom}');
Error('\p{Is_Indic_Matra_Category=Top_And_Bottom}');
Error('\P{Is_Indic_Matra_Category=Top_And_Bottom}');
Error('\p{Is_InMC=Top_And_Bottom}');
Error('\P{Is_InMC=Top_And_Bottom}');
Error('\p{Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\P{Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\p{InMC=Top_And_Bottom_And_Right}');
Error('\P{InMC=Top_And_Bottom_And_Right}');
Error('\p{Is_Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\P{Is_Indic_Matra_Category=Top_And_Bottom_And_Right}');
Error('\p{Is_InMC=Top_And_Bottom_And_Right}');
Error('\P{Is_InMC=Top_And_Bottom_And_Right}');
Error('\p{Indic_Matra_Category=Top_And_Left}');
Error('\P{Indic_Matra_Category=Top_And_Left}');
Error('\p{InMC=Top_And_Left}');
Error('\P{InMC=Top_And_Left}');
Error('\p{Is_Indic_Matra_Category=Top_And_Left}');
Error('\P{Is_Indic_Matra_Category=Top_And_Left}');
Error('\p{Is_InMC=Top_And_Left}');
Error('\P{Is_InMC=Top_And_Left}');
Error('\p{Indic_Matra_Category:   Top_And_Left_And_Right}');
Error('\P{Indic_Matra_Category:   Top_And_Left_And_Right}');
Error('\p{InMC=Top_And_Left_And_Right}');
Error('\P{InMC=Top_And_Left_And_Right}');
Error('\p{Is_Indic_Matra_Category=Top_And_Left_And_Right}');
Error('\P{Is_Indic_Matra_Category=Top_And_Left_And_Right}');
Error('\p{Is_InMC:   Top_And_Left_And_Right}');
Error('\P{Is_InMC:   Top_And_Left_And_Right}');
Error('\p{Indic_Matra_Category=Top_And_Right}');
Error('\P{Indic_Matra_Category=Top_And_Right}');
Error('\p{InMC=Top_And_Right}');
Error('\P{InMC=Top_And_Right}');
Error('\p{Is_Indic_Matra_Category=Top_And_Right}');
Error('\P{Is_Indic_Matra_Category=Top_And_Right}');
Error('\p{Is_InMC=Top_And_Right}');
Error('\P{Is_InMC=Top_And_Right}');
Error('\p{Indic_Matra_Category=Visual_Order_Left}');
Error('\P{Indic_Matra_Category=Visual_Order_Left}');
Error('\p{InMC=Visual_Order_Left}');
Error('\P{InMC=Visual_Order_Left}');
Error('\p{Is_Indic_Matra_Category=Visual_Order_Left}');
Error('\P{Is_Indic_Matra_Category=Visual_Order_Left}');
Error('\p{Is_InMC=Visual_Order_Left}');
Error('\P{Is_InMC=Visual_Order_Left}');
Error('\p{Indic_Syllabic_Category=Avagraha}');
Error('\P{Indic_Syllabic_Category=Avagraha}');
Error('\p{InSC:Avagraha}');
Error('\P{InSC:Avagraha}');
Error('\p{Is_Indic_Syllabic_Category=Avagraha}');
Error('\P{Is_Indic_Syllabic_Category=Avagraha}');
Error('\p{Is_InSC=Avagraha}');
Error('\P{Is_InSC=Avagraha}');
Error('\p{Indic_Syllabic_Category=Bindu}');
Error('\P{Indic_Syllabic_Category=Bindu}');
Error('\p{InSC=Bindu}');
Error('\P{InSC=Bindu}');
Error('\p{Is_Indic_Syllabic_Category:   Bindu}');
Error('\P{Is_Indic_Syllabic_Category:   Bindu}');
Error('\p{Is_InSC=Bindu}');
Error('\P{Is_InSC=Bindu}');
Error('\p{Indic_Syllabic_Category=Consonant}');
Error('\P{Indic_Syllabic_Category=Consonant}');
Error('\p{InSC=Consonant}');
Error('\P{InSC=Consonant}');
Error('\p{Is_Indic_Syllabic_Category=Consonant}');
Error('\P{Is_Indic_Syllabic_Category=Consonant}');
Error('\p{Is_InSC=Consonant}');
Error('\P{Is_InSC=Consonant}');
Error('\p{Indic_Syllabic_Category=Consonant_Dead}');
Error('\P{Indic_Syllabic_Category=Consonant_Dead}');
Error('\p{InSC=Consonant_Dead}');
Error('\P{InSC=Consonant_Dead}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Dead}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Dead}');
Error('\p{Is_InSC=Consonant_Dead}');
Error('\P{Is_InSC=Consonant_Dead}');
Error('\p{Indic_Syllabic_Category=Consonant_Final}');
Error('\P{Indic_Syllabic_Category=Consonant_Final}');
Error('\p{InSC=Consonant_Final}');
Error('\P{InSC=Consonant_Final}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Final}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Final}');
Error('\p{Is_InSC=Consonant_Final}');
Error('\P{Is_InSC=Consonant_Final}');
Error('\p{Indic_Syllabic_Category: Consonant_Head_Letter}');
Error('\P{Indic_Syllabic_Category: Consonant_Head_Letter}');
Error('\p{InSC=Consonant_Head_Letter}');
Error('\P{InSC=Consonant_Head_Letter}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Head_Letter}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Head_Letter}');
Error('\p{Is_InSC=Consonant_Head_Letter}');
Error('\P{Is_InSC=Consonant_Head_Letter}');
Error('\p{Indic_Syllabic_Category=Consonant_Medial}');
Error('\P{Indic_Syllabic_Category=Consonant_Medial}');
Error('\p{InSC=Consonant_Medial}');
Error('\P{InSC=Consonant_Medial}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Medial}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Medial}');
Error('\p{Is_InSC:   Consonant_Medial}');
Error('\P{Is_InSC:   Consonant_Medial}');
Error('\p{Indic_Syllabic_Category=Consonant_Placeholder}');
Error('\P{Indic_Syllabic_Category=Consonant_Placeholder}');
Error('\p{InSC: Consonant_Placeholder}');
Error('\P{InSC: Consonant_Placeholder}');
Error('\p{Is_Indic_Syllabic_Category:	Consonant_Placeholder}');
Error('\P{Is_Indic_Syllabic_Category:	Consonant_Placeholder}');
Error('\p{Is_InSC=Consonant_Placeholder}');
Error('\P{Is_InSC=Consonant_Placeholder}');
Error('\p{Indic_Syllabic_Category=Consonant_Repha}');
Error('\P{Indic_Syllabic_Category=Consonant_Repha}');
Error('\p{InSC=Consonant_Repha}');
Error('\P{InSC=Consonant_Repha}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Repha}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Repha}');
Error('\p{Is_InSC=Consonant_Repha}');
Error('\P{Is_InSC=Consonant_Repha}');
Error('\p{Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\P{Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\p{InSC=Consonant_Subjoined}');
Error('\P{InSC=Consonant_Subjoined}');
Error('\p{Is_Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\P{Is_Indic_Syllabic_Category=Consonant_Subjoined}');
Error('\p{Is_InSC=Consonant_Subjoined}');
Error('\P{Is_InSC=Consonant_Subjoined}');
Error('\p{Indic_Syllabic_Category=Modifying_Letter}');
Error('\P{Indic_Syllabic_Category=Modifying_Letter}');
Error('\p{InSC=Modifying_Letter}');
Error('\P{InSC=Modifying_Letter}');
Error('\p{Is_Indic_Syllabic_Category=Modifying_Letter}');
Error('\P{Is_Indic_Syllabic_Category=Modifying_Letter}');
Error('\p{Is_InSC:   Modifying_Letter}');
Error('\P{Is_InSC:   Modifying_Letter}');
Error('\p{Indic_Syllabic_Category=Nukta}');
Error('\P{Indic_Syllabic_Category=Nukta}');
Error('\p{InSC=Nukta}');
Error('\P{InSC=Nukta}');
Error('\p{Is_Indic_Syllabic_Category=Nukta}');
Error('\P{Is_Indic_Syllabic_Category=Nukta}');
Error('\p{Is_InSC=Nukta}');
Error('\P{Is_InSC=Nukta}');
Error('\p{Indic_Syllabic_Category=Other}');
Error('\P{Indic_Syllabic_Category=Other}');
Error('\p{InSC=Other}');
Error('\P{InSC=Other}');
Error('\p{Is_Indic_Syllabic_Category=Other}');
Error('\P{Is_Indic_Syllabic_Category=Other}');
Error('\p{Is_InSC=Other}');
Error('\P{Is_InSC=Other}');
Error('\p{Indic_Syllabic_Category:   Register_Shifter}');
Error('\P{Indic_Syllabic_Category:   Register_Shifter}');
Error('\p{InSC=Register_Shifter}');
Error('\P{InSC=Register_Shifter}');
Error('\p{Is_Indic_Syllabic_Category=Register_Shifter}');
Error('\P{Is_Indic_Syllabic_Category=Register_Shifter}');
Error('\p{Is_InSC:Register_Shifter}');
Error('\P{Is_InSC:Register_Shifter}');
Error('\p{Indic_Syllabic_Category=Tone_Letter}');
Error('\P{Indic_Syllabic_Category=Tone_Letter}');
Error('\p{InSC=Tone_Letter}');
Error('\P{InSC=Tone_Letter}');
Error('\p{Is_Indic_Syllabic_Category=Tone_Letter}');
Error('\P{Is_Indic_Syllabic_Category=Tone_Letter}');
Error('\p{Is_InSC:   Tone_Letter}');
Error('\P{Is_InSC:   Tone_Letter}');
Error('\p{Indic_Syllabic_Category:   Tone_Mark}');
Error('\P{Indic_Syllabic_Category:   Tone_Mark}');
Error('\p{InSC=Tone_Mark}');
Error('\P{InSC=Tone_Mark}');
Error('\p{Is_Indic_Syllabic_Category=Tone_Mark}');
Error('\P{Is_Indic_Syllabic_Category=Tone_Mark}');
Error('\p{Is_InSC=Tone_Mark}');
Error('\P{Is_InSC=Tone_Mark}');
Error('\p{Indic_Syllabic_Category=Virama}');
Error('\P{Indic_Syllabic_Category=Virama}');
Error('\p{InSC=Virama}');
Error('\P{InSC=Virama}');
Error('\p{Is_Indic_Syllabic_Category=Virama}');
Error('\P{Is_Indic_Syllabic_Category=Virama}');
Error('\p{Is_InSC=Virama}');
Error('\P{Is_InSC=Virama}');
Error('\p{Indic_Syllabic_Category=Visarga}');
Error('\P{Indic_Syllabic_Category=Visarga}');
Error('\p{InSC=Visarga}');
Error('\P{InSC=Visarga}');
Error('\p{Is_Indic_Syllabic_Category=Visarga}');
Error('\P{Is_Indic_Syllabic_Category=Visarga}');
Error('\p{Is_InSC=Visarga}');
Error('\P{Is_InSC=Visarga}');
Error('\p{Indic_Syllabic_Category=Vowel}');
Error('\P{Indic_Syllabic_Category=Vowel}');
Error('\p{InSC: Vowel}');
Error('\P{InSC: Vowel}');
Error('\p{Is_Indic_Syllabic_Category=Vowel}');
Error('\P{Is_Indic_Syllabic_Category=Vowel}');
Error('\p{Is_InSC=Vowel}');
Error('\P{Is_InSC=Vowel}');
Error('\p{Indic_Syllabic_Category=Vowel_Dependent}');
Error('\P{Indic_Syllabic_Category=Vowel_Dependent}');
Error('\p{InSC=Vowel_Dependent}');
Error('\P{InSC=Vowel_Dependent}');
Error('\p{Is_Indic_Syllabic_Category=Vowel_Dependent}');
Error('\P{Is_Indic_Syllabic_Category=Vowel_Dependent}');
Error('\p{Is_InSC=Vowel_Dependent}');
Error('\P{Is_InSC=Vowel_Dependent}');
Error('\p{Indic_Syllabic_Category=Vowel_Independent}');
Error('\P{Indic_Syllabic_Category=Vowel_Independent}');
Error('\p{InSC:Vowel_Independent}');
Error('\P{InSC:Vowel_Independent}');
Error('\p{Is_Indic_Syllabic_Category=Vowel_Independent}');
Error('\P{Is_Indic_Syllabic_Category=Vowel_Independent}');
Error('\p{Is_InSC=Vowel_Independent}');
Error('\P{Is_InSC=Vowel_Independent}');
Error('\p{Jamo_Short_Name=A}');
Error('\P{Jamo_Short_Name=A}');
Error('\p{JSN=A}');
Error('\P{JSN=A}');
Error('\p{Is_Jamo_Short_Name=A}');
Error('\P{Is_Jamo_Short_Name=A}');
Error('\p{Is_JSN=A}');
Error('\P{Is_JSN=A}');
Error('\p{Jamo_Short_Name=AE}');
Error('\P{Jamo_Short_Name=AE}');
Error('\p{JSN=AE}');
Error('\P{JSN=AE}');
Error('\p{Is_Jamo_Short_Name=AE}');
Error('\P{Is_Jamo_Short_Name=AE}');
Error('\p{Is_JSN=AE}');
Error('\P{Is_JSN=AE}');
Error('\p{Jamo_Short_Name=B}');
Error('\P{Jamo_Short_Name=B}');
Error('\p{JSN=B}');
Error('\P{JSN=B}');
Error('\p{Is_Jamo_Short_Name=B}');
Error('\P{Is_Jamo_Short_Name=B}');
Error('\p{Is_JSN=B}');
Error('\P{Is_JSN=B}');
Error('\p{Jamo_Short_Name=BB}');
Error('\P{Jamo_Short_Name=BB}');
Error('\p{JSN=BB}');
Error('\P{JSN=BB}');
Error('\p{Is_Jamo_Short_Name=BB}');
Error('\P{Is_Jamo_Short_Name=BB}');
Error('\p{Is_JSN=BB}');
Error('\P{Is_JSN=BB}');
Error('\p{Jamo_Short_Name=BS}');
Error('\P{Jamo_Short_Name=BS}');
Error('\p{JSN=BS}');
Error('\P{JSN=BS}');
Error('\p{Is_Jamo_Short_Name=BS}');
Error('\P{Is_Jamo_Short_Name=BS}');
Error('\p{Is_JSN=BS}');
Error('\P{Is_JSN=BS}');
Error('\p{Jamo_Short_Name=C}');
Error('\P{Jamo_Short_Name=C}');
Error('\p{JSN=C}');
Error('\P{JSN=C}');
Error('\p{Is_Jamo_Short_Name=C}');
Error('\P{Is_Jamo_Short_Name=C}');
Error('\p{Is_JSN=C}');
Error('\P{Is_JSN=C}');
Error('\p{Jamo_Short_Name=D}');
Error('\P{Jamo_Short_Name=D}');
Error('\p{JSN:   D}');
Error('\P{JSN:   D}');
Error('\p{Is_Jamo_Short_Name=D}');
Error('\P{Is_Jamo_Short_Name=D}');
Error('\p{Is_JSN=D}');
Error('\P{Is_JSN=D}');
Error('\p{Jamo_Short_Name:DD}');
Error('\P{Jamo_Short_Name:DD}');
Error('\p{JSN=DD}');
Error('\P{JSN=DD}');
Error('\p{Is_Jamo_Short_Name=DD}');
Error('\P{Is_Jamo_Short_Name=DD}');
Error('\p{Is_JSN=DD}');
Error('\P{Is_JSN=DD}');
Error('\p{Jamo_Short_Name=E}');
Error('\P{Jamo_Short_Name=E}');
Error('\p{JSN=E}');
Error('\P{JSN=E}');
Error('\p{Is_Jamo_Short_Name=E}');
Error('\P{Is_Jamo_Short_Name=E}');
Error('\p{Is_JSN=E}');
Error('\P{Is_JSN=E}');
Error('\p{Jamo_Short_Name:   EO}');
Error('\P{Jamo_Short_Name:   EO}');
Error('\p{JSN=EO}');
Error('\P{JSN=EO}');
Error('\p{Is_Jamo_Short_Name=EO}');
Error('\P{Is_Jamo_Short_Name=EO}');
Error('\p{Is_JSN=EO}');
Error('\P{Is_JSN=EO}');
Error('\p{Jamo_Short_Name=EU}');
Error('\P{Jamo_Short_Name=EU}');
Error('\p{JSN=EU}');
Error('\P{JSN=EU}');
Error('\p{Is_Jamo_Short_Name=EU}');
Error('\P{Is_Jamo_Short_Name=EU}');
Error('\p{Is_JSN=EU}');
Error('\P{Is_JSN=EU}');
Error('\p{Jamo_Short_Name=G}');
Error('\P{Jamo_Short_Name=G}');
Error('\p{JSN=G}');
Error('\P{JSN=G}');
Error('\p{Is_Jamo_Short_Name=G}');
Error('\P{Is_Jamo_Short_Name=G}');
Error('\p{Is_JSN=G}');
Error('\P{Is_JSN=G}');
Error('\p{Jamo_Short_Name=GG}');
Error('\P{Jamo_Short_Name=GG}');
Error('\p{JSN=GG}');
Error('\P{JSN=GG}');
Error('\p{Is_Jamo_Short_Name=GG}');
Error('\P{Is_Jamo_Short_Name=GG}');
Error('\p{Is_JSN:GG}');
Error('\P{Is_JSN:GG}');
Error('\p{Jamo_Short_Name=GS}');
Error('\P{Jamo_Short_Name=GS}');
Error('\p{JSN=GS}');
Error('\P{JSN=GS}');
Error('\p{Is_Jamo_Short_Name=GS}');
Error('\P{Is_Jamo_Short_Name=GS}');
Error('\p{Is_JSN=GS}');
Error('\P{Is_JSN=GS}');
Error('\p{Jamo_Short_Name:	H}');
Error('\P{Jamo_Short_Name:	H}');
Error('\p{JSN=H}');
Error('\P{JSN=H}');
Error('\p{Is_Jamo_Short_Name=H}');
Error('\P{Is_Jamo_Short_Name=H}');
Error('\p{Is_JSN:H}');
Error('\P{Is_JSN:H}');
Error('\p{Jamo_Short_Name=I}');
Error('\P{Jamo_Short_Name=I}');
Error('\p{JSN: I}');
Error('\P{JSN: I}');
Error('\p{Is_Jamo_Short_Name=I}');
Error('\P{Is_Jamo_Short_Name=I}');
Error('\p{Is_JSN=I}');
Error('\P{Is_JSN=I}');
Error('\p{Jamo_Short_Name=J}');
Error('\P{Jamo_Short_Name=J}');
Error('\p{JSN=J}');
Error('\P{JSN=J}');
Error('\p{Is_Jamo_Short_Name=J}');
Error('\P{Is_Jamo_Short_Name=J}');
Error('\p{Is_JSN=J}');
Error('\P{Is_JSN=J}');
Error('\p{Jamo_Short_Name=JJ}');
Error('\P{Jamo_Short_Name=JJ}');
Error('\p{JSN=JJ}');
Error('\P{JSN=JJ}');
Error('\p{Is_Jamo_Short_Name=JJ}');
Error('\P{Is_Jamo_Short_Name=JJ}');
Error('\p{Is_JSN:	JJ}');
Error('\P{Is_JSN:	JJ}');
Error('\p{Jamo_Short_Name=K}');
Error('\P{Jamo_Short_Name=K}');
Error('\p{JSN=K}');
Error('\P{JSN=K}');
Error('\p{Is_Jamo_Short_Name=K}');
Error('\P{Is_Jamo_Short_Name=K}');
Error('\p{Is_JSN=K}');
Error('\P{Is_JSN=K}');
Error('\p{Jamo_Short_Name=L}');
Error('\P{Jamo_Short_Name=L}');
Error('\p{JSN=L}');
Error('\P{JSN=L}');
Error('\p{Is_Jamo_Short_Name=L}');
Error('\P{Is_Jamo_Short_Name=L}');
Error('\p{Is_JSN=L}');
Error('\P{Is_JSN=L}');
Error('\p{Jamo_Short_Name=LB}');
Error('\P{Jamo_Short_Name=LB}');
Error('\p{JSN=LB}');
Error('\P{JSN=LB}');
Error('\p{Is_Jamo_Short_Name:   LB}');
Error('\P{Is_Jamo_Short_Name:   LB}');
Error('\p{Is_JSN=LB}');
Error('\P{Is_JSN=LB}');
Error('\p{Jamo_Short_Name=LG}');
Error('\P{Jamo_Short_Name=LG}');
Error('\p{JSN=LG}');
Error('\P{JSN=LG}');
Error('\p{Is_Jamo_Short_Name=LG}');
Error('\P{Is_Jamo_Short_Name=LG}');
Error('\p{Is_JSN=LG}');
Error('\P{Is_JSN=LG}');
Error('\p{Jamo_Short_Name=LH}');
Error('\P{Jamo_Short_Name=LH}');
Error('\p{JSN=LH}');
Error('\P{JSN=LH}');
Error('\p{Is_Jamo_Short_Name=LH}');
Error('\P{Is_Jamo_Short_Name=LH}');
Error('\p{Is_JSN=LH}');
Error('\P{Is_JSN=LH}');
Error('\p{Jamo_Short_Name:LM}');
Error('\P{Jamo_Short_Name:LM}');
Error('\p{JSN=LM}');
Error('\P{JSN=LM}');
Error('\p{Is_Jamo_Short_Name:	LM}');
Error('\P{Is_Jamo_Short_Name:	LM}');
Error('\p{Is_JSN=LM}');
Error('\P{Is_JSN=LM}');
Error('\p{Jamo_Short_Name:	LP}');
Error('\P{Jamo_Short_Name:	LP}');
Error('\p{JSN=LP}');
Error('\P{JSN=LP}');
Error('\p{Is_Jamo_Short_Name=LP}');
Error('\P{Is_Jamo_Short_Name=LP}');
Error('\p{Is_JSN=LP}');
Error('\P{Is_JSN=LP}');
Error('\p{Jamo_Short_Name=LS}');
Error('\P{Jamo_Short_Name=LS}');
Error('\p{JSN=LS}');
Error('\P{JSN=LS}');
Error('\p{Is_Jamo_Short_Name=LS}');
Error('\P{Is_Jamo_Short_Name=LS}');
Error('\p{Is_JSN=LS}');
Error('\P{Is_JSN=LS}');
Error('\p{Jamo_Short_Name:	LT}');
Error('\P{Jamo_Short_Name:	LT}');
Error('\p{JSN=LT}');
Error('\P{JSN=LT}');
Error('\p{Is_Jamo_Short_Name=LT}');
Error('\P{Is_Jamo_Short_Name=LT}');
Error('\p{Is_JSN=LT}');
Error('\P{Is_JSN=LT}');
Error('\p{Jamo_Short_Name:M}');
Error('\P{Jamo_Short_Name:M}');
Error('\p{JSN=M}');
Error('\P{JSN=M}');
Error('\p{Is_Jamo_Short_Name=M}');
Error('\P{Is_Jamo_Short_Name=M}');
Error('\p{Is_JSN=M}');
Error('\P{Is_JSN=M}');
Error('\p{Jamo_Short_Name=N}');
Error('\P{Jamo_Short_Name=N}');
Error('\p{JSN=N}');
Error('\P{JSN=N}');
Error('\p{Is_Jamo_Short_Name:	N}');
Error('\P{Is_Jamo_Short_Name:	N}');
Error('\p{Is_JSN=N}');
Error('\P{Is_JSN=N}');
Error('\p{Jamo_Short_Name=NG}');
Error('\P{Jamo_Short_Name=NG}');
Error('\p{JSN=NG}');
Error('\P{JSN=NG}');
Error('\p{Is_Jamo_Short_Name=NG}');
Error('\P{Is_Jamo_Short_Name=NG}');
Error('\p{Is_JSN=NG}');
Error('\P{Is_JSN=NG}');
Error('\p{Jamo_Short_Name:   NH}');
Error('\P{Jamo_Short_Name:   NH}');
Error('\p{JSN=NH}');
Error('\P{JSN=NH}');
Error('\p{Is_Jamo_Short_Name=NH}');
Error('\P{Is_Jamo_Short_Name=NH}');
Error('\p{Is_JSN=NH}');
Error('\P{Is_JSN=NH}');
Error('\p{Jamo_Short_Name=NJ}');
Error('\P{Jamo_Short_Name=NJ}');
Error('\p{JSN=NJ}');
Error('\P{JSN=NJ}');
Error('\p{Is_Jamo_Short_Name=NJ}');
Error('\P{Is_Jamo_Short_Name=NJ}');
Error('\p{Is_JSN=NJ}');
Error('\P{Is_JSN=NJ}');
Error('\p{Jamo_Short_Name:   O}');
Error('\P{Jamo_Short_Name:   O}');
Error('\p{JSN=O}');
Error('\P{JSN=O}');
Error('\p{Is_Jamo_Short_Name=O}');
Error('\P{Is_Jamo_Short_Name=O}');
Error('\p{Is_JSN=O}');
Error('\P{Is_JSN=O}');
Error('\p{Jamo_Short_Name=OE}');
Error('\P{Jamo_Short_Name=OE}');
Error('\p{JSN=OE}');
Error('\P{JSN=OE}');
Error('\p{Is_Jamo_Short_Name=OE}');
Error('\P{Is_Jamo_Short_Name=OE}');
Error('\p{Is_JSN=OE}');
Error('\P{Is_JSN=OE}');
Error('\p{Jamo_Short_Name=P}');
Error('\P{Jamo_Short_Name=P}');
Error('\p{JSN=P}');
Error('\P{JSN=P}');
Error('\p{Is_Jamo_Short_Name=P}');
Error('\P{Is_Jamo_Short_Name=P}');
Error('\p{Is_JSN=P}');
Error('\P{Is_JSN=P}');
Error('\p{Jamo_Short_Name=R}');
Error('\P{Jamo_Short_Name=R}');
Error('\p{JSN=R}');
Error('\P{JSN=R}');
Error('\p{Is_Jamo_Short_Name=R}');
Error('\P{Is_Jamo_Short_Name=R}');
Error('\p{Is_JSN=R}');
Error('\P{Is_JSN=R}');
Error('\p{Jamo_Short_Name=S}');
Error('\P{Jamo_Short_Name=S}');
Error('\p{JSN=S}');
Error('\P{JSN=S}');
Error('\p{Is_Jamo_Short_Name=S}');
Error('\P{Is_Jamo_Short_Name=S}');
Error('\p{Is_JSN=S}');
Error('\P{Is_JSN=S}');
Error('\p{Jamo_Short_Name=SS}');
Error('\P{Jamo_Short_Name=SS}');
Error('\p{JSN=SS}');
Error('\P{JSN=SS}');
Error('\p{Is_Jamo_Short_Name:   SS}');
Error('\P{Is_Jamo_Short_Name:   SS}');
Error('\p{Is_JSN=SS}');
Error('\P{Is_JSN=SS}');
Error('\p{Jamo_Short_Name=T}');
Error('\P{Jamo_Short_Name=T}');
Error('\p{JSN=T}');
Error('\P{JSN=T}');
Error('\p{Is_Jamo_Short_Name:	T}');
Error('\P{Is_Jamo_Short_Name:	T}');
Error('\p{Is_JSN=T}');
Error('\P{Is_JSN=T}');
Error('\p{Jamo_Short_Name=U}');
Error('\P{Jamo_Short_Name=U}');
Error('\p{JSN=U}');
Error('\P{JSN=U}');
Error('\p{Is_Jamo_Short_Name=U}');
Error('\P{Is_Jamo_Short_Name=U}');
Error('\p{Is_JSN=U}');
Error('\P{Is_JSN=U}');
Error('\p{Jamo_Short_Name=WA}');
Error('\P{Jamo_Short_Name=WA}');
Error('\p{JSN=WA}');
Error('\P{JSN=WA}');
Error('\p{Is_Jamo_Short_Name=WA}');
Error('\P{Is_Jamo_Short_Name=WA}');
Error('\p{Is_JSN=WA}');
Error('\P{Is_JSN=WA}');
Error('\p{Jamo_Short_Name=WAE}');
Error('\P{Jamo_Short_Name=WAE}');
Error('\p{JSN=WAE}');
Error('\P{JSN=WAE}');
Error('\p{Is_Jamo_Short_Name=WAE}');
Error('\P{Is_Jamo_Short_Name=WAE}');
Error('\p{Is_JSN=WAE}');
Error('\P{Is_JSN=WAE}');
Error('\p{Jamo_Short_Name=WE}');
Error('\P{Jamo_Short_Name=WE}');
Error('\p{JSN=WE}');
Error('\P{JSN=WE}');
Error('\p{Is_Jamo_Short_Name=WE}');
Error('\P{Is_Jamo_Short_Name=WE}');
Error('\p{Is_JSN=WE}');
Error('\P{Is_JSN=WE}');
Error('\p{Jamo_Short_Name=WEO}');
Error('\P{Jamo_Short_Name=WEO}');
Error('\p{JSN=WEO}');
Error('\P{JSN=WEO}');
Error('\p{Is_Jamo_Short_Name=WEO}');
Error('\P{Is_Jamo_Short_Name=WEO}');
Error('\p{Is_JSN:	WEO}');
Error('\P{Is_JSN:	WEO}');
Error('\p{Jamo_Short_Name=WI}');
Error('\P{Jamo_Short_Name=WI}');
Error('\p{JSN=WI}');
Error('\P{JSN=WI}');
Error('\p{Is_Jamo_Short_Name=WI}');
Error('\P{Is_Jamo_Short_Name=WI}');
Error('\p{Is_JSN=WI}');
Error('\P{Is_JSN=WI}');
Error('\p{Jamo_Short_Name=YA}');
Error('\P{Jamo_Short_Name=YA}');
Error('\p{JSN=YA}');
Error('\P{JSN=YA}');
Error('\p{Is_Jamo_Short_Name=YA}');
Error('\P{Is_Jamo_Short_Name=YA}');
Error('\p{Is_JSN=YA}');
Error('\P{Is_JSN=YA}');
Error('\p{Jamo_Short_Name=YAE}');
Error('\P{Jamo_Short_Name=YAE}');
Error('\p{JSN:   YAE}');
Error('\P{JSN:   YAE}');
Error('\p{Is_Jamo_Short_Name:   YAE}');
Error('\P{Is_Jamo_Short_Name:   YAE}');
Error('\p{Is_JSN=YAE}');
Error('\P{Is_JSN=YAE}');
Error('\p{Jamo_Short_Name=YE}');
Error('\P{Jamo_Short_Name=YE}');
Error('\p{JSN=YE}');
Error('\P{JSN=YE}');
Error('\p{Is_Jamo_Short_Name=YE}');
Error('\P{Is_Jamo_Short_Name=YE}');
Error('\p{Is_JSN=YE}');
Error('\P{Is_JSN=YE}');
Error('\p{Jamo_Short_Name:YEO}');
Error('\P{Jamo_Short_Name:YEO}');
Error('\p{JSN=YEO}');
Error('\P{JSN=YEO}');
Error('\p{Is_Jamo_Short_Name=YEO}');
Error('\P{Is_Jamo_Short_Name=YEO}');
Error('\p{Is_JSN:   YEO}');
Error('\P{Is_JSN:   YEO}');
Error('\p{Jamo_Short_Name=YI}');
Error('\P{Jamo_Short_Name=YI}');
Error('\p{JSN=YI}');
Error('\P{JSN=YI}');
Error('\p{Is_Jamo_Short_Name=YI}');
Error('\P{Is_Jamo_Short_Name=YI}');
Error('\p{Is_JSN=YI}');
Error('\P{Is_JSN=YI}');
Error('\p{Jamo_Short_Name=YO}');
Error('\P{Jamo_Short_Name=YO}');
Error('\p{JSN:	YO}');
Error('\P{JSN:	YO}');
Error('\p{Is_Jamo_Short_Name=YO}');
Error('\P{Is_Jamo_Short_Name=YO}');
Error('\p{Is_JSN=YO}');
Error('\P{Is_JSN=YO}');
Error('\p{Jamo_Short_Name=YU}');
Error('\P{Jamo_Short_Name=YU}');
Error('\p{JSN=YU}');
Error('\P{JSN=YU}');
Error('\p{Is_Jamo_Short_Name=YU}');
Error('\P{Is_Jamo_Short_Name=YU}');
Error('\p{Is_JSN=YU}');
Error('\P{Is_JSN=YU}');
Error('\p{Join_Control= /a/No}');
Error('\P{Join_Control= /a/No}');
Expect(1, 8206, '\p{Join_Control: no}', "");
Expect(0, 8206, '\p{^Join_Control: no}', "");
Expect(0, 8206, '\P{Join_Control: no}', "");
Expect(1, 8206, '\P{^Join_Control: no}', "");
Expect(0, 8205, '\p{Join_Control: no}', "");
Expect(1, 8205, '\p{^Join_Control: no}', "");
Expect(1, 8205, '\P{Join_Control: no}', "");
Expect(0, 8205, '\P{^Join_Control: no}', "");
Expect(1, 8206, '\p{Join_Control=		No}', "");
Expect(0, 8206, '\p{^Join_Control=		No}', "");
Expect(0, 8206, '\P{Join_Control=		No}', "");
Expect(1, 8206, '\P{^Join_Control=		No}', "");
Expect(0, 8205, '\p{Join_Control=		No}', "");
Expect(1, 8205, '\p{^Join_Control=		No}', "");
Expect(1, 8205, '\P{Join_Control=		No}', "");
Expect(0, 8205, '\P{^Join_Control=		No}', "");
Error('\p{Join_C:_/a/N}');
Error('\P{Join_C:_/a/N}');
Expect(1, 8206, '\p{Join_C=n}', "");
Expect(0, 8206, '\p{^Join_C=n}', "");
Expect(0, 8206, '\P{Join_C=n}', "");
Expect(1, 8206, '\P{^Join_C=n}', "");
Expect(0, 8205, '\p{Join_C=n}', "");
Expect(1, 8205, '\p{^Join_C=n}', "");
Expect(1, 8205, '\P{Join_C=n}', "");
Expect(0, 8205, '\P{^Join_C=n}', "");
Expect(1, 8206, '\p{Join_C=__N}', "");
Expect(0, 8206, '\p{^Join_C=__N}', "");
Expect(0, 8206, '\P{Join_C=__N}', "");
Expect(1, 8206, '\P{^Join_C=__N}', "");
Expect(0, 8205, '\p{Join_C=__N}', "");
Expect(1, 8205, '\p{^Join_C=__N}', "");
Expect(1, 8205, '\P{Join_C=__N}', "");
Expect(0, 8205, '\P{^Join_C=__N}', "");
Error('\p{Is_Join_Control=:=- F}');
Error('\P{Is_Join_Control=:=- F}');
Expect(1, 8206, '\p{Is_Join_Control:	f}', "");
Expect(0, 8206, '\p{^Is_Join_Control:	f}', "");
Expect(0, 8206, '\P{Is_Join_Control:	f}', "");
Expect(1, 8206, '\P{^Is_Join_Control:	f}', "");
Expect(0, 8205, '\p{Is_Join_Control:	f}', "");
Expect(1, 8205, '\p{^Is_Join_Control:	f}', "");
Expect(1, 8205, '\P{Is_Join_Control:	f}', "");
Expect(0, 8205, '\P{^Is_Join_Control:	f}', "");
Expect(1, 8206, '\p{Is_Join_Control=-_F}', "");
Expect(0, 8206, '\p{^Is_Join_Control=-_F}', "");
Expect(0, 8206, '\P{Is_Join_Control=-_F}', "");
Expect(1, 8206, '\P{^Is_Join_Control=-_F}', "");
Expect(0, 8205, '\p{Is_Join_Control=-_F}', "");
Expect(1, 8205, '\p{^Is_Join_Control=-_F}', "");
Expect(1, 8205, '\P{Is_Join_Control=-_F}', "");
Expect(0, 8205, '\P{^Is_Join_Control=-_F}', "");
Error('\p{Is_Join_C=-false:=}');
Error('\P{Is_Join_C=-false:=}');
Expect(1, 8206, '\p{Is_Join_C=false}', "");
Expect(0, 8206, '\p{^Is_Join_C=false}', "");
Expect(0, 8206, '\P{Is_Join_C=false}', "");
Expect(1, 8206, '\P{^Is_Join_C=false}', "");
Expect(0, 8205, '\p{Is_Join_C=false}', "");
Expect(1, 8205, '\p{^Is_Join_C=false}', "");
Expect(1, 8205, '\P{Is_Join_C=false}', "");
Expect(0, 8205, '\P{^Is_Join_C=false}', "");
Expect(1, 8206, '\p{Is_Join_C=-FALSE}', "");
Expect(0, 8206, '\p{^Is_Join_C=-FALSE}', "");
Expect(0, 8206, '\P{Is_Join_C=-FALSE}', "");
Expect(1, 8206, '\P{^Is_Join_C=-FALSE}', "");
Expect(0, 8205, '\p{Is_Join_C=-FALSE}', "");
Expect(1, 8205, '\p{^Is_Join_C=-FALSE}', "");
Expect(1, 8205, '\P{Is_Join_C=-FALSE}', "");
Expect(0, 8205, '\P{^Is_Join_C=-FALSE}', "");
Error('\p{Join_Control=/a/Yes}');
Error('\P{Join_Control=/a/Yes}');
Expect(1, 8205, '\p{Join_Control=yes}', "");
Expect(0, 8205, '\p{^Join_Control=yes}', "");
Expect(0, 8205, '\P{Join_Control=yes}', "");
Expect(1, 8205, '\P{^Join_Control=yes}', "");
Expect(0, 8206, '\p{Join_Control=yes}', "");
Expect(1, 8206, '\p{^Join_Control=yes}', "");
Expect(1, 8206, '\P{Join_Control=yes}', "");
Expect(0, 8206, '\P{^Join_Control=yes}', "");
Expect(1, 8205, '\p{Join_Control=__yes}', "");
Expect(0, 8205, '\p{^Join_Control=__yes}', "");
Expect(0, 8205, '\P{Join_Control=__yes}', "");
Expect(1, 8205, '\P{^Join_Control=__yes}', "");
Expect(0, 8206, '\p{Join_Control=__yes}', "");
Expect(1, 8206, '\p{^Join_Control=__yes}', "");
Expect(1, 8206, '\P{Join_Control=__yes}', "");
Expect(0, 8206, '\P{^Join_Control=__yes}', "");
Error('\p{Join_C=:=__Y}');
Error('\P{Join_C=:=__Y}');
Expect(1, 8205, '\p{Join_C:   y}', "");
Expect(0, 8205, '\p{^Join_C:   y}', "");
Expect(0, 8205, '\P{Join_C:   y}', "");
Expect(1, 8205, '\P{^Join_C:   y}', "");
Expect(0, 8206, '\p{Join_C:   y}', "");
Expect(1, 8206, '\p{^Join_C:   y}', "");
Expect(1, 8206, '\P{Join_C:   y}', "");
Expect(0, 8206, '\P{^Join_C:   y}', "");
Expect(1, 8205, '\p{Join_C=-Y}', "");
Expect(0, 8205, '\p{^Join_C=-Y}', "");
Expect(0, 8205, '\P{Join_C=-Y}', "");
Expect(1, 8205, '\P{^Join_C=-Y}', "");
Expect(0, 8206, '\p{Join_C=-Y}', "");
Expect(1, 8206, '\p{^Join_C=-Y}', "");
Expect(1, 8206, '\P{Join_C=-Y}', "");
Expect(0, 8206, '\P{^Join_C=-Y}', "");
Error('\p{Is_Join_Control=- T/a/}');
Error('\P{Is_Join_Control=- T/a/}');
Expect(1, 8205, '\p{Is_Join_Control=t}', "");
Expect(0, 8205, '\p{^Is_Join_Control=t}', "");
Expect(0, 8205, '\P{Is_Join_Control=t}', "");
Expect(1, 8205, '\P{^Is_Join_Control=t}', "");
Expect(0, 8206, '\p{Is_Join_Control=t}', "");
Expect(1, 8206, '\p{^Is_Join_Control=t}', "");
Expect(1, 8206, '\P{Is_Join_Control=t}', "");
Expect(0, 8206, '\P{^Is_Join_Control=t}', "");
Expect(1, 8205, '\p{Is_Join_Control= -T}', "");
Expect(0, 8205, '\p{^Is_Join_Control= -T}', "");
Expect(0, 8205, '\P{Is_Join_Control= -T}', "");
Expect(1, 8205, '\P{^Is_Join_Control= -T}', "");
Expect(0, 8206, '\p{Is_Join_Control= -T}', "");
Expect(1, 8206, '\p{^Is_Join_Control= -T}', "");
Expect(1, 8206, '\P{Is_Join_Control= -T}', "");
Expect(0, 8206, '\P{^Is_Join_Control= -T}', "");
Error('\p{Is_Join_C=-/a/True}');
Error('\P{Is_Join_C=-/a/True}');
Expect(1, 8205, '\p{Is_Join_C=true}', "");
Expect(0, 8205, '\p{^Is_Join_C=true}', "");
Expect(0, 8205, '\P{Is_Join_C=true}', "");
Expect(1, 8205, '\P{^Is_Join_C=true}', "");
Expect(0, 8206, '\p{Is_Join_C=true}', "");
Expect(1, 8206, '\p{^Is_Join_C=true}', "");
Expect(1, 8206, '\P{Is_Join_C=true}', "");
Expect(0, 8206, '\P{^Is_Join_C=true}', "");
Expect(1, 8205, '\p{Is_Join_C=	true}', "");
Expect(0, 8205, '\p{^Is_Join_C=	true}', "");
Expect(0, 8205, '\P{Is_Join_C=	true}', "");
Expect(1, 8205, '\P{^Is_Join_C=	true}', "");
Expect(0, 8206, '\p{Is_Join_C=	true}', "");
Expect(1, 8206, '\p{^Is_Join_C=	true}', "");
Expect(1, 8206, '\P{Is_Join_C=	true}', "");
Expect(0, 8206, '\P{^Is_Join_C=	true}', "");
Error('\p{Logical_Order_Exception=-No/a/}');
Error('\P{Logical_Order_Exception=-No/a/}');
Expect(1, 43709, '\p{Logical_Order_Exception=no}', "");
Expect(0, 43709, '\p{^Logical_Order_Exception=no}', "");
Expect(0, 43709, '\P{Logical_Order_Exception=no}', "");
Expect(1, 43709, '\P{^Logical_Order_Exception=no}', "");
Expect(0, 43708, '\p{Logical_Order_Exception=no}', "");
Expect(1, 43708, '\p{^Logical_Order_Exception=no}', "");
Expect(1, 43708, '\P{Logical_Order_Exception=no}', "");
Expect(0, 43708, '\P{^Logical_Order_Exception=no}', "");
Expect(1, 43709, '\p{Logical_Order_Exception= 	no}', "");
Expect(0, 43709, '\p{^Logical_Order_Exception= 	no}', "");
Expect(0, 43709, '\P{Logical_Order_Exception= 	no}', "");
Expect(1, 43709, '\P{^Logical_Order_Exception= 	no}', "");
Expect(0, 43708, '\p{Logical_Order_Exception= 	no}', "");
Expect(1, 43708, '\p{^Logical_Order_Exception= 	no}', "");
Expect(1, 43708, '\P{Logical_Order_Exception= 	no}', "");
Expect(0, 43708, '\P{^Logical_Order_Exception= 	no}', "");
Error('\p{LOE=/a/		N}');
Error('\P{LOE=/a/		N}');
Expect(1, 43709, '\p{LOE=n}', "");
Expect(0, 43709, '\p{^LOE=n}', "");
Expect(0, 43709, '\P{LOE=n}', "");
Expect(1, 43709, '\P{^LOE=n}', "");
Expect(0, 43708, '\p{LOE=n}', "");
Expect(1, 43708, '\p{^LOE=n}', "");
Expect(1, 43708, '\P{LOE=n}', "");
Expect(0, 43708, '\P{^LOE=n}', "");
Expect(1, 43709, '\p{LOE=__n}', "");
Expect(0, 43709, '\p{^LOE=__n}', "");
Expect(0, 43709, '\P{LOE=__n}', "");
Expect(1, 43709, '\P{^LOE=__n}', "");
Expect(0, 43708, '\p{LOE=__n}', "");
Expect(1, 43708, '\p{^LOE=__n}', "");
Expect(1, 43708, '\P{LOE=__n}', "");
Expect(0, 43708, '\P{^LOE=__n}', "");
Error('\p{Is_Logical_Order_Exception=_/a/F}');
Error('\P{Is_Logical_Order_Exception=_/a/F}');
Expect(1, 43709, '\p{Is_Logical_Order_Exception=f}', "");
Expect(0, 43709, '\p{^Is_Logical_Order_Exception=f}', "");
Expect(0, 43709, '\P{Is_Logical_Order_Exception=f}', "");
Expect(1, 43709, '\P{^Is_Logical_Order_Exception=f}', "");
Expect(0, 43708, '\p{Is_Logical_Order_Exception=f}', "");
Expect(1, 43708, '\p{^Is_Logical_Order_Exception=f}', "");
Expect(1, 43708, '\P{Is_Logical_Order_Exception=f}', "");
Expect(0, 43708, '\P{^Is_Logical_Order_Exception=f}', "");
Expect(1, 43709, '\p{Is_Logical_Order_Exception= -F}', "");
Expect(0, 43709, '\p{^Is_Logical_Order_Exception= -F}', "");
Expect(0, 43709, '\P{Is_Logical_Order_Exception= -F}', "");
Expect(1, 43709, '\P{^Is_Logical_Order_Exception= -F}', "");
Expect(0, 43708, '\p{Is_Logical_Order_Exception= -F}', "");
Expect(1, 43708, '\p{^Is_Logical_Order_Exception= -F}', "");
Expect(1, 43708, '\P{Is_Logical_Order_Exception= -F}', "");
Expect(0, 43708, '\P{^Is_Logical_Order_Exception= -F}', "");
Error('\p{Is_LOE=/a/ False}');
Error('\P{Is_LOE=/a/ False}');
Expect(1, 43709, '\p{Is_LOE=false}', "");
Expect(0, 43709, '\p{^Is_LOE=false}', "");
Expect(0, 43709, '\P{Is_LOE=false}', "");
Expect(1, 43709, '\P{^Is_LOE=false}', "");
Expect(0, 43708, '\p{Is_LOE=false}', "");
Expect(1, 43708, '\p{^Is_LOE=false}', "");
Expect(1, 43708, '\P{Is_LOE=false}', "");
Expect(0, 43708, '\P{^Is_LOE=false}', "");
Expect(1, 43709, '\p{Is_LOE=-False}', "");
Expect(0, 43709, '\p{^Is_LOE=-False}', "");
Expect(0, 43709, '\P{Is_LOE=-False}', "");
Expect(1, 43709, '\P{^Is_LOE=-False}', "");
Expect(0, 43708, '\p{Is_LOE=-False}', "");
Expect(1, 43708, '\p{^Is_LOE=-False}', "");
Expect(1, 43708, '\P{Is_LOE=-False}', "");
Expect(0, 43708, '\P{^Is_LOE=-False}', "");
Error('\p{Logical_Order_Exception:	:=- yes}');
Error('\P{Logical_Order_Exception:	:=- yes}');
Expect(1, 43708, '\p{Logical_Order_Exception=yes}', "");
Expect(0, 43708, '\p{^Logical_Order_Exception=yes}', "");
Expect(0, 43708, '\P{Logical_Order_Exception=yes}', "");
Expect(1, 43708, '\P{^Logical_Order_Exception=yes}', "");
Expect(0, 43709, '\p{Logical_Order_Exception=yes}', "");
Expect(1, 43709, '\p{^Logical_Order_Exception=yes}', "");
Expect(1, 43709, '\P{Logical_Order_Exception=yes}', "");
Expect(0, 43709, '\P{^Logical_Order_Exception=yes}', "");
Expect(1, 43708, '\p{Logical_Order_Exception=_Yes}', "");
Expect(0, 43708, '\p{^Logical_Order_Exception=_Yes}', "");
Expect(0, 43708, '\P{Logical_Order_Exception=_Yes}', "");
Expect(1, 43708, '\P{^Logical_Order_Exception=_Yes}', "");
Expect(0, 43709, '\p{Logical_Order_Exception=_Yes}', "");
Expect(1, 43709, '\p{^Logical_Order_Exception=_Yes}', "");
Expect(1, 43709, '\P{Logical_Order_Exception=_Yes}', "");
Expect(0, 43709, '\P{^Logical_Order_Exception=_Yes}', "");
Error('\p{LOE=/a/	-Y}');
Error('\P{LOE=/a/	-Y}');
Expect(1, 43708, '\p{LOE=y}', "");
Expect(0, 43708, '\p{^LOE=y}', "");
Expect(0, 43708, '\P{LOE=y}', "");
Expect(1, 43708, '\P{^LOE=y}', "");
Expect(0, 43709, '\p{LOE=y}', "");
Expect(1, 43709, '\p{^LOE=y}', "");
Expect(1, 43709, '\P{LOE=y}', "");
Expect(0, 43709, '\P{^LOE=y}', "");
Expect(1, 43708, '\p{LOE=  Y}', "");
Expect(0, 43708, '\p{^LOE=  Y}', "");
Expect(0, 43708, '\P{LOE=  Y}', "");
Expect(1, 43708, '\P{^LOE=  Y}', "");
Expect(0, 43709, '\p{LOE=  Y}', "");
Expect(1, 43709, '\p{^LOE=  Y}', "");
Expect(1, 43709, '\P{LOE=  Y}', "");
Expect(0, 43709, '\P{^LOE=  Y}', "");
Error('\p{Is_Logical_Order_Exception=:=_T}');
Error('\P{Is_Logical_Order_Exception=:=_T}');
Expect(1, 43708, '\p{Is_Logical_Order_Exception=t}', "");
Expect(0, 43708, '\p{^Is_Logical_Order_Exception=t}', "");
Expect(0, 43708, '\P{Is_Logical_Order_Exception=t}', "");
Expect(1, 43708, '\P{^Is_Logical_Order_Exception=t}', "");
Expect(0, 43709, '\p{Is_Logical_Order_Exception=t}', "");
Expect(1, 43709, '\p{^Is_Logical_Order_Exception=t}', "");
Expect(1, 43709, '\P{Is_Logical_Order_Exception=t}', "");
Expect(0, 43709, '\P{^Is_Logical_Order_Exception=t}', "");
Expect(1, 43708, '\p{Is_Logical_Order_Exception=-t}', "");
Expect(0, 43708, '\p{^Is_Logical_Order_Exception=-t}', "");
Expect(0, 43708, '\P{Is_Logical_Order_Exception=-t}', "");
Expect(1, 43708, '\P{^Is_Logical_Order_Exception=-t}', "");
Expect(0, 43709, '\p{Is_Logical_Order_Exception=-t}', "");
Expect(1, 43709, '\p{^Is_Logical_Order_Exception=-t}', "");
Expect(1, 43709, '\P{Is_Logical_Order_Exception=-t}', "");
Expect(0, 43709, '\P{^Is_Logical_Order_Exception=-t}', "");
Error('\p{Is_LOE=  TRUE:=}');
Error('\P{Is_LOE=  TRUE:=}');
Expect(1, 43708, '\p{Is_LOE=true}', "");
Expect(0, 43708, '\p{^Is_LOE=true}', "");
Expect(0, 43708, '\P{Is_LOE=true}', "");
Expect(1, 43708, '\P{^Is_LOE=true}', "");
Expect(0, 43709, '\p{Is_LOE=true}', "");
Expect(1, 43709, '\p{^Is_LOE=true}', "");
Expect(1, 43709, '\P{Is_LOE=true}', "");
Expect(0, 43709, '\P{^Is_LOE=true}', "");
Expect(1, 43708, '\p{Is_LOE=_	TRUE}', "");
Expect(0, 43708, '\p{^Is_LOE=_	TRUE}', "");
Expect(0, 43708, '\P{Is_LOE=_	TRUE}', "");
Expect(1, 43708, '\P{^Is_LOE=_	TRUE}', "");
Expect(0, 43709, '\p{Is_LOE=_	TRUE}', "");
Expect(1, 43709, '\p{^Is_LOE=_	TRUE}', "");
Expect(1, 43709, '\P{Is_LOE=_	TRUE}', "");
Expect(0, 43709, '\P{^Is_LOE=_	TRUE}', "");
Error('\p{Lowercase=  No/a/}');
Error('\P{Lowercase=  No/a/}');
Expect(1, 120780, '\p{Lowercase=no}', "");
Expect(0, 120780, '\p{^Lowercase=no}', "");
Expect(0, 120780, '\P{Lowercase=no}', "");
Expect(1, 120780, '\P{^Lowercase=no}', "");
Expect(0, 120779, '\p{Lowercase=no}', "");
Expect(1, 120779, '\p{^Lowercase=no}', "");
Expect(1, 120779, '\P{Lowercase=no}', "");
Expect(0, 120779, '\P{^Lowercase=no}', "");
Expect(1, 120780, '\p{Lowercase= No}', "");
Expect(0, 120780, '\p{^Lowercase= No}', "");
Expect(0, 120780, '\P{Lowercase= No}', "");
Expect(1, 120780, '\P{^Lowercase= No}', "");
Expect(0, 120779, '\p{Lowercase= No}', "");
Expect(1, 120779, '\p{^Lowercase= No}', "");
Expect(1, 120779, '\P{Lowercase= No}', "");
Expect(0, 120779, '\P{^Lowercase= No}', "");
Error('\p{Lower=/a/ 	N}');
Error('\P{Lower=/a/ 	N}');
Expect(1, 120780, '\p{Lower=n}', "");
Expect(0, 120780, '\p{^Lower=n}', "");
Expect(0, 120780, '\P{Lower=n}', "");
Expect(1, 120780, '\P{^Lower=n}', "");
Expect(0, 120779, '\p{Lower=n}', "");
Expect(1, 120779, '\p{^Lower=n}', "");
Expect(1, 120779, '\P{Lower=n}', "");
Expect(0, 120779, '\P{^Lower=n}', "");
Expect(1, 120780, '\p{Lower= N}', "");
Expect(0, 120780, '\p{^Lower= N}', "");
Expect(0, 120780, '\P{Lower= N}', "");
Expect(1, 120780, '\P{^Lower= N}', "");
Expect(0, 120779, '\p{Lower= N}', "");
Expect(1, 120779, '\p{^Lower= N}', "");
Expect(1, 120779, '\P{Lower= N}', "");
Expect(0, 120779, '\P{^Lower= N}', "");
Error('\p{Is_Lowercase=_f:=}');
Error('\P{Is_Lowercase=_f:=}');
Expect(1, 120780, '\p{Is_Lowercase=f}', "");
Expect(0, 120780, '\p{^Is_Lowercase=f}', "");
Expect(0, 120780, '\P{Is_Lowercase=f}', "");
Expect(1, 120780, '\P{^Is_Lowercase=f}', "");
Expect(0, 120779, '\p{Is_Lowercase=f}', "");
Expect(1, 120779, '\p{^Is_Lowercase=f}', "");
Expect(1, 120779, '\P{Is_Lowercase=f}', "");
Expect(0, 120779, '\P{^Is_Lowercase=f}', "");
Expect(1, 120780, '\p{Is_Lowercase=	_F}', "");
Expect(0, 120780, '\p{^Is_Lowercase=	_F}', "");
Expect(0, 120780, '\P{Is_Lowercase=	_F}', "");
Expect(1, 120780, '\P{^Is_Lowercase=	_F}', "");
Expect(0, 120779, '\p{Is_Lowercase=	_F}', "");
Expect(1, 120779, '\p{^Is_Lowercase=	_F}', "");
Expect(1, 120779, '\P{Is_Lowercase=	_F}', "");
Expect(0, 120779, '\P{^Is_Lowercase=	_F}', "");
Error('\p{Is_Lower=	False/a/}');
Error('\P{Is_Lower=	False/a/}');
Expect(1, 120780, '\p{Is_Lower:false}', "");
Expect(0, 120780, '\p{^Is_Lower:false}', "");
Expect(0, 120780, '\P{Is_Lower:false}', "");
Expect(1, 120780, '\P{^Is_Lower:false}', "");
Expect(0, 120779, '\p{Is_Lower:false}', "");
Expect(1, 120779, '\p{^Is_Lower:false}', "");
Expect(1, 120779, '\P{Is_Lower:false}', "");
Expect(0, 120779, '\P{^Is_Lower:false}', "");
Expect(1, 120780, '\p{Is_Lower:-_False}', "");
Expect(0, 120780, '\p{^Is_Lower:-_False}', "");
Expect(0, 120780, '\P{Is_Lower:-_False}', "");
Expect(1, 120780, '\P{^Is_Lower:-_False}', "");
Expect(0, 120779, '\p{Is_Lower:-_False}', "");
Expect(1, 120779, '\p{^Is_Lower:-_False}', "");
Expect(1, 120779, '\P{Is_Lower:-_False}', "");
Expect(0, 120779, '\P{^Is_Lower:-_False}', "");
Error('\p{Lowercase=_ yes/a/}');
Error('\P{Lowercase=_ yes/a/}');
Expect(1, 120779, '\p{Lowercase=yes}', "");
Expect(0, 120779, '\p{^Lowercase=yes}', "");
Expect(0, 120779, '\P{Lowercase=yes}', "");
Expect(1, 120779, '\P{^Lowercase=yes}', "");
Expect(0, 120780, '\p{Lowercase=yes}', "");
Expect(1, 120780, '\p{^Lowercase=yes}', "");
Expect(1, 120780, '\P{Lowercase=yes}', "");
Expect(0, 120780, '\P{^Lowercase=yes}', "");
Expect(1, 120779, '\p{Lowercase=	 Yes}', "");
Expect(0, 120779, '\p{^Lowercase=	 Yes}', "");
Expect(0, 120779, '\P{Lowercase=	 Yes}', "");
Expect(1, 120779, '\P{^Lowercase=	 Yes}', "");
Expect(0, 120780, '\p{Lowercase=	 Yes}', "");
Expect(1, 120780, '\p{^Lowercase=	 Yes}', "");
Expect(1, 120780, '\P{Lowercase=	 Yes}', "");
Expect(0, 120780, '\P{^Lowercase=	 Yes}', "");
Error('\p{Lower=__y/a/}');
Error('\P{Lower=__y/a/}');
Expect(1, 120779, '\p{Lower=y}', "");
Expect(0, 120779, '\p{^Lower=y}', "");
Expect(0, 120779, '\P{Lower=y}', "");
Expect(1, 120779, '\P{^Lower=y}', "");
Expect(0, 120780, '\p{Lower=y}', "");
Expect(1, 120780, '\p{^Lower=y}', "");
Expect(1, 120780, '\P{Lower=y}', "");
Expect(0, 120780, '\P{^Lower=y}', "");
Expect(1, 120779, '\p{Lower=-	Y}', "");
Expect(0, 120779, '\p{^Lower=-	Y}', "");
Expect(0, 120779, '\P{Lower=-	Y}', "");
Expect(1, 120779, '\P{^Lower=-	Y}', "");
Expect(0, 120780, '\p{Lower=-	Y}', "");
Expect(1, 120780, '\p{^Lower=-	Y}', "");
Expect(1, 120780, '\P{Lower=-	Y}', "");
Expect(0, 120780, '\P{^Lower=-	Y}', "");
Error('\p{Is_Lowercase=__T:=}');
Error('\P{Is_Lowercase=__T:=}');
Expect(1, 120779, '\p{Is_Lowercase=t}', "");
Expect(0, 120779, '\p{^Is_Lowercase=t}', "");
Expect(0, 120779, '\P{Is_Lowercase=t}', "");
Expect(1, 120779, '\P{^Is_Lowercase=t}', "");
Expect(0, 120780, '\p{Is_Lowercase=t}', "");
Expect(1, 120780, '\p{^Is_Lowercase=t}', "");
Expect(1, 120780, '\P{Is_Lowercase=t}', "");
Expect(0, 120780, '\P{^Is_Lowercase=t}', "");
Expect(1, 120779, '\p{Is_Lowercase:   		T}', "");
Expect(0, 120779, '\p{^Is_Lowercase:   		T}', "");
Expect(0, 120779, '\P{Is_Lowercase:   		T}', "");
Expect(1, 120779, '\P{^Is_Lowercase:   		T}', "");
Expect(0, 120780, '\p{Is_Lowercase:   		T}', "");
Expect(1, 120780, '\p{^Is_Lowercase:   		T}', "");
Expect(1, 120780, '\P{Is_Lowercase:   		T}', "");
Expect(0, 120780, '\P{^Is_Lowercase:   		T}', "");
Error('\p{Is_Lower=_True/a/}');
Error('\P{Is_Lower=_True/a/}');
Expect(1, 120779, '\p{Is_Lower=true}', "");
Expect(0, 120779, '\p{^Is_Lower=true}', "");
Expect(0, 120779, '\P{Is_Lower=true}', "");
Expect(1, 120779, '\P{^Is_Lower=true}', "");
Expect(0, 120780, '\p{Is_Lower=true}', "");
Expect(1, 120780, '\p{^Is_Lower=true}', "");
Expect(1, 120780, '\P{Is_Lower=true}', "");
Expect(0, 120780, '\P{^Is_Lower=true}', "");
Expect(1, 120779, '\p{Is_Lower= -True}', "");
Expect(0, 120779, '\p{^Is_Lower= -True}', "");
Expect(0, 120779, '\P{Is_Lower= -True}', "");
Expect(1, 120779, '\P{^Is_Lower= -True}', "");
Expect(0, 120780, '\p{Is_Lower= -True}', "");
Expect(1, 120780, '\p{^Is_Lower= -True}', "");
Expect(1, 120780, '\P{Is_Lower= -True}', "");
Expect(0, 120780, '\P{^Is_Lower= -True}', "");
Error('\p{Math=:=--no}');
Error('\P{Math=:=--no}');
Expect(1, 126706, '\p{Math=no}', "");
Expect(0, 126706, '\p{^Math=no}', "");
Expect(0, 126706, '\P{Math=no}', "");
Expect(1, 126706, '\P{^Math=no}', "");
Expect(0, 126705, '\p{Math=no}', "");
Expect(1, 126705, '\p{^Math=no}', "");
Expect(1, 126705, '\P{Math=no}', "");
Expect(0, 126705, '\P{^Math=no}', "");
Expect(1, 126706, '\p{Math= NO}', "");
Expect(0, 126706, '\p{^Math= NO}', "");
Expect(0, 126706, '\P{Math= NO}', "");
Expect(1, 126706, '\P{^Math= NO}', "");
Expect(0, 126705, '\p{Math= NO}', "");
Expect(1, 126705, '\p{^Math= NO}', "");
Expect(1, 126705, '\P{Math= NO}', "");
Expect(0, 126705, '\P{^Math= NO}', "");
Error('\p{Is_Math= :=N}');
Error('\P{Is_Math= :=N}');
Expect(1, 126706, '\p{Is_Math=n}', "");
Expect(0, 126706, '\p{^Is_Math=n}', "");
Expect(0, 126706, '\P{Is_Math=n}', "");
Expect(1, 126706, '\P{^Is_Math=n}', "");
Expect(0, 126705, '\p{Is_Math=n}', "");
Expect(1, 126705, '\p{^Is_Math=n}', "");
Expect(1, 126705, '\P{Is_Math=n}', "");
Expect(0, 126705, '\P{^Is_Math=n}', "");
Expect(1, 126706, '\p{Is_Math=	 N}', "");
Expect(0, 126706, '\p{^Is_Math=	 N}', "");
Expect(0, 126706, '\P{Is_Math=	 N}', "");
Expect(1, 126706, '\P{^Is_Math=	 N}', "");
Expect(0, 126705, '\p{Is_Math=	 N}', "");
Expect(1, 126705, '\p{^Is_Math=	 N}', "");
Expect(1, 126705, '\P{Is_Math=	 N}', "");
Expect(0, 126705, '\P{^Is_Math=	 N}', "");
Error('\p{Math:	/a/-_F}');
Error('\P{Math:	/a/-_F}');
Expect(1, 126706, '\p{Math=f}', "");
Expect(0, 126706, '\p{^Math=f}', "");
Expect(0, 126706, '\P{Math=f}', "");
Expect(1, 126706, '\P{^Math=f}', "");
Expect(0, 126705, '\p{Math=f}', "");
Expect(1, 126705, '\p{^Math=f}', "");
Expect(1, 126705, '\P{Math=f}', "");
Expect(0, 126705, '\P{^Math=f}', "");
Expect(1, 126706, '\p{Math=-F}', "");
Expect(0, 126706, '\p{^Math=-F}', "");
Expect(0, 126706, '\P{Math=-F}', "");
Expect(1, 126706, '\P{^Math=-F}', "");
Expect(0, 126705, '\p{Math=-F}', "");
Expect(1, 126705, '\p{^Math=-F}', "");
Expect(1, 126705, '\P{Math=-F}', "");
Expect(0, 126705, '\P{^Math=-F}', "");
Error('\p{Is_Math= _FALSE/a/}');
Error('\P{Is_Math= _FALSE/a/}');
Expect(1, 126706, '\p{Is_Math=false}', "");
Expect(0, 126706, '\p{^Is_Math=false}', "");
Expect(0, 126706, '\P{Is_Math=false}', "");
Expect(1, 126706, '\P{^Is_Math=false}', "");
Expect(0, 126705, '\p{Is_Math=false}', "");
Expect(1, 126705, '\p{^Is_Math=false}', "");
Expect(1, 126705, '\P{Is_Math=false}', "");
Expect(0, 126705, '\P{^Is_Math=false}', "");
Expect(1, 126706, '\p{Is_Math=	-False}', "");
Expect(0, 126706, '\p{^Is_Math=	-False}', "");
Expect(0, 126706, '\P{Is_Math=	-False}', "");
Expect(1, 126706, '\P{^Is_Math=	-False}', "");
Expect(0, 126705, '\p{Is_Math=	-False}', "");
Expect(1, 126705, '\p{^Is_Math=	-False}', "");
Expect(1, 126705, '\P{Is_Math=	-False}', "");
Expect(0, 126705, '\P{^Is_Math=	-False}', "");
Error('\p{Math:	:= 	Yes}');
Error('\P{Math:	:= 	Yes}');
Expect(1, 126705, '\p{Math=yes}', "");
Expect(0, 126705, '\p{^Math=yes}', "");
Expect(0, 126705, '\P{Math=yes}', "");
Expect(1, 126705, '\P{^Math=yes}', "");
Expect(0, 126706, '\p{Math=yes}', "");
Expect(1, 126706, '\p{^Math=yes}', "");
Expect(1, 126706, '\P{Math=yes}', "");
Expect(0, 126706, '\P{^Math=yes}', "");
Expect(1, 126705, '\p{Math:			yes}', "");
Expect(0, 126705, '\p{^Math:			yes}', "");
Expect(0, 126705, '\P{Math:			yes}', "");
Expect(1, 126705, '\P{^Math:			yes}', "");
Expect(0, 126706, '\p{Math:			yes}', "");
Expect(1, 126706, '\p{^Math:			yes}', "");
Expect(1, 126706, '\P{Math:			yes}', "");
Expect(0, 126706, '\P{^Math:			yes}', "");
Error('\p{Is_Math=_Y:=}');
Error('\P{Is_Math=_Y:=}');
Expect(1, 126705, '\p{Is_Math=y}', "");
Expect(0, 126705, '\p{^Is_Math=y}', "");
Expect(0, 126705, '\P{Is_Math=y}', "");
Expect(1, 126705, '\P{^Is_Math=y}', "");
Expect(0, 126706, '\p{Is_Math=y}', "");
Expect(1, 126706, '\p{^Is_Math=y}', "");
Expect(1, 126706, '\P{Is_Math=y}', "");
Expect(0, 126706, '\P{^Is_Math=y}', "");
Expect(1, 126705, '\p{Is_Math= 	y}', "");
Expect(0, 126705, '\p{^Is_Math= 	y}', "");
Expect(0, 126705, '\P{Is_Math= 	y}', "");
Expect(1, 126705, '\P{^Is_Math= 	y}', "");
Expect(0, 126706, '\p{Is_Math= 	y}', "");
Expect(1, 126706, '\p{^Is_Math= 	y}', "");
Expect(1, 126706, '\P{Is_Math= 	y}', "");
Expect(0, 126706, '\P{^Is_Math= 	y}', "");
Error('\p{Math=-T:=}');
Error('\P{Math=-T:=}');
Expect(1, 126705, '\p{Math=t}', "");
Expect(0, 126705, '\p{^Math=t}', "");
Expect(0, 126705, '\P{Math=t}', "");
Expect(1, 126705, '\P{^Math=t}', "");
Expect(0, 126706, '\p{Math=t}', "");
Expect(1, 126706, '\p{^Math=t}', "");
Expect(1, 126706, '\P{Math=t}', "");
Expect(0, 126706, '\P{^Math=t}', "");
Expect(1, 126705, '\p{Math=-	t}', "");
Expect(0, 126705, '\p{^Math=-	t}', "");
Expect(0, 126705, '\P{Math=-	t}', "");
Expect(1, 126705, '\P{^Math=-	t}', "");
Expect(0, 126706, '\p{Math=-	t}', "");
Expect(1, 126706, '\p{^Math=-	t}', "");
Expect(1, 126706, '\P{Math=-	t}', "");
Expect(0, 126706, '\P{^Math=-	t}', "");
Error('\p{Is_Math=/a/ _True}');
Error('\P{Is_Math=/a/ _True}');
Expect(1, 126705, '\p{Is_Math=true}', "");
Expect(0, 126705, '\p{^Is_Math=true}', "");
Expect(0, 126705, '\P{Is_Math=true}', "");
Expect(1, 126705, '\P{^Is_Math=true}', "");
Expect(0, 126706, '\p{Is_Math=true}', "");
Expect(1, 126706, '\p{^Is_Math=true}', "");
Expect(1, 126706, '\P{Is_Math=true}', "");
Expect(0, 126706, '\P{^Is_Math=true}', "");
Expect(1, 126705, '\p{Is_Math=TRUE}', "");
Expect(0, 126705, '\p{^Is_Math=TRUE}', "");
Expect(0, 126705, '\P{Is_Math=TRUE}', "");
Expect(1, 126705, '\P{^Is_Math=TRUE}', "");
Expect(0, 126706, '\p{Is_Math=TRUE}', "");
Expect(1, 126706, '\p{^Is_Math=TRUE}', "");
Expect(1, 126706, '\P{Is_Math=TRUE}', "");
Expect(0, 126706, '\P{^Is_Math=TRUE}', "");
Error('\p{Noncharacter_Code_Point:   _:=No}');
Error('\P{Noncharacter_Code_Point:   _:=No}');
Expect(1, 1114109, '\p{Noncharacter_Code_Point=no}', "");
Expect(0, 1114109, '\p{^Noncharacter_Code_Point=no}', "");
Expect(0, 1114109, '\P{Noncharacter_Code_Point=no}', "");
Expect(1, 1114109, '\P{^Noncharacter_Code_Point=no}', "");
Expect(0, 1114111, '\p{Noncharacter_Code_Point=no}', "");
Expect(1, 1114111, '\p{^Noncharacter_Code_Point=no}', "");
Expect(1, 1114111, '\P{Noncharacter_Code_Point=no}', "");
Expect(0, 1114111, '\P{^Noncharacter_Code_Point=no}', "");
Expect(1, 1114109, '\p{Noncharacter_Code_Point=		no}', "");
Expect(0, 1114109, '\p{^Noncharacter_Code_Point=		no}', "");
Expect(0, 1114109, '\P{Noncharacter_Code_Point=		no}', "");
Expect(1, 1114109, '\P{^Noncharacter_Code_Point=		no}', "");
Expect(0, 1114111, '\p{Noncharacter_Code_Point=		no}', "");
Expect(1, 1114111, '\p{^Noncharacter_Code_Point=		no}', "");
Expect(1, 1114111, '\P{Noncharacter_Code_Point=		no}', "");
Expect(0, 1114111, '\P{^Noncharacter_Code_Point=		no}', "");
Error('\p{NChar= -N/a/}');
Error('\P{NChar= -N/a/}');
Expect(1, 1114109, '\p{NChar=n}', "");
Expect(0, 1114109, '\p{^NChar=n}', "");
Expect(0, 1114109, '\P{NChar=n}', "");
Expect(1, 1114109, '\P{^NChar=n}', "");
Expect(0, 1114111, '\p{NChar=n}', "");
Expect(1, 1114111, '\p{^NChar=n}', "");
Expect(1, 1114111, '\P{NChar=n}', "");
Expect(0, 1114111, '\P{^NChar=n}', "");
Expect(1, 1114109, '\p{NChar=_N}', "");
Expect(0, 1114109, '\p{^NChar=_N}', "");
Expect(0, 1114109, '\P{NChar=_N}', "");
Expect(1, 1114109, '\P{^NChar=_N}', "");
Expect(0, 1114111, '\p{NChar=_N}', "");
Expect(1, 1114111, '\p{^NChar=_N}', "");
Expect(1, 1114111, '\P{NChar=_N}', "");
Expect(0, 1114111, '\P{^NChar=_N}', "");
Error('\p{Is_Noncharacter_Code_Point:   /a/  F}');
Error('\P{Is_Noncharacter_Code_Point:   /a/  F}');
Expect(1, 1114109, '\p{Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114109, '\p{^Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114109, '\P{Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114109, '\P{^Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114111, '\p{Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114111, '\p{^Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114111, '\P{Is_Noncharacter_Code_Point=f}', "");
Expect(0, 1114111, '\P{^Is_Noncharacter_Code_Point=f}', "");
Expect(1, 1114109, '\p{Is_Noncharacter_Code_Point=	-f}', "");
Expect(0, 1114109, '\p{^Is_Noncharacter_Code_Point=	-f}', "");
Expect(0, 1114109, '\P{Is_Noncharacter_Code_Point=	-f}', "");
Expect(1, 1114109, '\P{^Is_Noncharacter_Code_Point=	-f}', "");
Expect(0, 1114111, '\p{Is_Noncharacter_Code_Point=	-f}', "");
Expect(1, 1114111, '\p{^Is_Noncharacter_Code_Point=	-f}', "");
Expect(1, 1114111, '\P{Is_Noncharacter_Code_Point=	-f}', "");
Expect(0, 1114111, '\P{^Is_Noncharacter_Code_Point=	-f}', "");
Error('\p{Is_NChar::=		False}');
Error('\P{Is_NChar::=		False}');
Expect(1, 1114109, '\p{Is_NChar=false}', "");
Expect(0, 1114109, '\p{^Is_NChar=false}', "");
Expect(0, 1114109, '\P{Is_NChar=false}', "");
Expect(1, 1114109, '\P{^Is_NChar=false}', "");
Expect(0, 1114111, '\p{Is_NChar=false}', "");
Expect(1, 1114111, '\p{^Is_NChar=false}', "");
Expect(1, 1114111, '\P{Is_NChar=false}', "");
Expect(0, 1114111, '\P{^Is_NChar=false}', "");
Expect(1, 1114109, '\p{Is_NChar:--False}', "");
Expect(0, 1114109, '\p{^Is_NChar:--False}', "");
Expect(0, 1114109, '\P{Is_NChar:--False}', "");
Expect(1, 1114109, '\P{^Is_NChar:--False}', "");
Expect(0, 1114111, '\p{Is_NChar:--False}', "");
Expect(1, 1114111, '\p{^Is_NChar:--False}', "");
Expect(1, 1114111, '\P{Is_NChar:--False}', "");
Expect(0, 1114111, '\P{^Is_NChar:--False}', "");
Error('\p{Noncharacter_Code_Point=_/a/Yes}');
Error('\P{Noncharacter_Code_Point=_/a/Yes}');
Expect(1, 1114111, '\p{Noncharacter_Code_Point=yes}', "");
Expect(0, 1114111, '\p{^Noncharacter_Code_Point=yes}', "");
Expect(0, 1114111, '\P{Noncharacter_Code_Point=yes}', "");
Expect(1, 1114111, '\P{^Noncharacter_Code_Point=yes}', "");
Expect(0, 1114109, '\p{Noncharacter_Code_Point=yes}', "");
Expect(1, 1114109, '\p{^Noncharacter_Code_Point=yes}', "");
Expect(1, 1114109, '\P{Noncharacter_Code_Point=yes}', "");
Expect(0, 1114109, '\P{^Noncharacter_Code_Point=yes}', "");
Expect(1, 1114111, '\p{Noncharacter_Code_Point=	Yes}', "");
Expect(0, 1114111, '\p{^Noncharacter_Code_Point=	Yes}', "");
Expect(0, 1114111, '\P{Noncharacter_Code_Point=	Yes}', "");
Expect(1, 1114111, '\P{^Noncharacter_Code_Point=	Yes}', "");
Expect(0, 1114109, '\p{Noncharacter_Code_Point=	Yes}', "");
Expect(1, 1114109, '\p{^Noncharacter_Code_Point=	Yes}', "");
Expect(1, 1114109, '\P{Noncharacter_Code_Point=	Yes}', "");
Expect(0, 1114109, '\P{^Noncharacter_Code_Point=	Yes}', "");
Error('\p{NChar= :=Y}');
Error('\P{NChar= :=Y}');
Expect(1, 1114111, '\p{NChar=y}', "");
Expect(0, 1114111, '\p{^NChar=y}', "");
Expect(0, 1114111, '\P{NChar=y}', "");
Expect(1, 1114111, '\P{^NChar=y}', "");
Expect(0, 1114109, '\p{NChar=y}', "");
Expect(1, 1114109, '\p{^NChar=y}', "");
Expect(1, 1114109, '\P{NChar=y}', "");
Expect(0, 1114109, '\P{^NChar=y}', "");
Expect(1, 1114111, '\p{NChar:	-_Y}', "");
Expect(0, 1114111, '\p{^NChar:	-_Y}', "");
Expect(0, 1114111, '\P{NChar:	-_Y}', "");
Expect(1, 1114111, '\P{^NChar:	-_Y}', "");
Expect(0, 1114109, '\p{NChar:	-_Y}', "");
Expect(1, 1114109, '\p{^NChar:	-_Y}', "");
Expect(1, 1114109, '\P{NChar:	-_Y}', "");
Expect(0, 1114109, '\P{^NChar:	-_Y}', "");
Error('\p{Is_Noncharacter_Code_Point=-/a/T}');
Error('\P{Is_Noncharacter_Code_Point=-/a/T}');
Expect(1, 1114111, '\p{Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114111, '\p{^Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114111, '\P{Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114111, '\P{^Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114109, '\p{Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114109, '\p{^Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114109, '\P{Is_Noncharacter_Code_Point=t}', "");
Expect(0, 1114109, '\P{^Is_Noncharacter_Code_Point=t}', "");
Expect(1, 1114111, '\p{Is_Noncharacter_Code_Point=	-T}', "");
Expect(0, 1114111, '\p{^Is_Noncharacter_Code_Point=	-T}', "");
Expect(0, 1114111, '\P{Is_Noncharacter_Code_Point=	-T}', "");
Expect(1, 1114111, '\P{^Is_Noncharacter_Code_Point=	-T}', "");
Expect(0, 1114109, '\p{Is_Noncharacter_Code_Point=	-T}', "");
Expect(1, 1114109, '\p{^Is_Noncharacter_Code_Point=	-T}', "");
Expect(1, 1114109, '\P{Is_Noncharacter_Code_Point=	-T}', "");
Expect(0, 1114109, '\P{^Is_Noncharacter_Code_Point=	-T}', "");
Error('\p{Is_NChar=-true:=}');
Error('\P{Is_NChar=-true:=}');
Expect(1, 1114111, '\p{Is_NChar=true}', "");
Expect(0, 1114111, '\p{^Is_NChar=true}', "");
Expect(0, 1114111, '\P{Is_NChar=true}', "");
Expect(1, 1114111, '\P{^Is_NChar=true}', "");
Expect(0, 1114109, '\p{Is_NChar=true}', "");
Expect(1, 1114109, '\p{^Is_NChar=true}', "");
Expect(1, 1114109, '\P{Is_NChar=true}', "");
Expect(0, 1114109, '\P{^Is_NChar=true}', "");
Expect(1, 1114111, '\p{Is_NChar=	-TRUE}', "");
Expect(0, 1114111, '\p{^Is_NChar=	-TRUE}', "");
Expect(0, 1114111, '\P{Is_NChar=	-TRUE}', "");
Expect(1, 1114111, '\P{^Is_NChar=	-TRUE}', "");
Expect(0, 1114109, '\p{Is_NChar=	-TRUE}', "");
Expect(1, 1114109, '\p{^Is_NChar=	-TRUE}', "");
Expect(1, 1114109, '\P{Is_NChar=	-TRUE}', "");
Expect(0, 1114109, '\P{^Is_NChar=	-TRUE}', "");
Error('\p{NFC_Quick_Check=:= _MAYBE}');
Error('\P{NFC_Quick_Check=:= _MAYBE}');
Expect(1, 69927, '\p{NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\p{NFC_Quick_Check=__maybe}', "");
Expect(0, 69927, '\p{^NFC_Quick_Check=__maybe}', "");
Expect(0, 69927, '\P{NFC_Quick_Check=__maybe}', "");
Expect(1, 69927, '\P{^NFC_Quick_Check=__maybe}', "");
Expect(0, 69928, '\p{NFC_Quick_Check=__maybe}', "");
Expect(1, 69928, '\p{^NFC_Quick_Check=__maybe}', "");
Expect(1, 69928, '\P{NFC_Quick_Check=__maybe}', "");
Expect(0, 69928, '\P{^NFC_Quick_Check=__maybe}', "");
Error('\p{NFC_QC=:=-m}');
Error('\P{NFC_QC=:=-m}');
Expect(1, 69927, '\p{NFC_QC=m}', "");
Expect(0, 69927, '\p{^NFC_QC=m}', "");
Expect(0, 69927, '\P{NFC_QC=m}', "");
Expect(1, 69927, '\P{^NFC_QC=m}', "");
Expect(0, 69928, '\p{NFC_QC=m}', "");
Expect(1, 69928, '\p{^NFC_QC=m}', "");
Expect(1, 69928, '\P{NFC_QC=m}', "");
Expect(0, 69928, '\P{^NFC_QC=m}', "");
Expect(1, 69927, '\p{NFC_QC=_ M}', "");
Expect(0, 69927, '\p{^NFC_QC=_ M}', "");
Expect(0, 69927, '\P{NFC_QC=_ M}', "");
Expect(1, 69927, '\P{^NFC_QC=_ M}', "");
Expect(0, 69928, '\p{NFC_QC=_ M}', "");
Expect(1, 69928, '\p{^NFC_QC=_ M}', "");
Expect(1, 69928, '\P{NFC_QC=_ M}', "");
Expect(0, 69928, '\P{^NFC_QC=_ M}', "");
Error('\p{Is_NFC_Quick_Check=		Maybe/a/}');
Error('\P{Is_NFC_Quick_Check=		Maybe/a/}');
Expect(1, 69927, '\p{Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^Is_NFC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{Is_NFC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^Is_NFC_Quick_Check=maybe}', "");
Error('\p{Is_NFC_QC=:= -M}');
Error('\P{Is_NFC_QC=:= -M}');
Expect(1, 69927, '\p{Is_NFC_QC=m}', "");
Expect(0, 69927, '\p{^Is_NFC_QC=m}', "");
Expect(0, 69927, '\P{Is_NFC_QC=m}', "");
Expect(1, 69927, '\P{^Is_NFC_QC=m}', "");
Expect(0, 69928, '\p{Is_NFC_QC=m}', "");
Expect(1, 69928, '\p{^Is_NFC_QC=m}', "");
Expect(1, 69928, '\P{Is_NFC_QC=m}', "");
Expect(0, 69928, '\P{^Is_NFC_QC=m}', "");
Expect(1, 69927, '\p{Is_NFC_QC=_ m}', "");
Expect(0, 69927, '\p{^Is_NFC_QC=_ m}', "");
Expect(0, 69927, '\P{Is_NFC_QC=_ m}', "");
Expect(1, 69927, '\P{^Is_NFC_QC=_ m}', "");
Expect(0, 69928, '\p{Is_NFC_QC=_ m}', "");
Expect(1, 69928, '\p{^Is_NFC_QC=_ m}', "");
Expect(1, 69928, '\P{Is_NFC_QC=_ m}', "");
Expect(0, 69928, '\P{^Is_NFC_QC=_ m}', "");
Error('\p{NFC_Quick_Check=_:=No}');
Error('\P{NFC_Quick_Check=_:=No}');
Expect(1, 195101, '\p{NFC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFC_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFC_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFC_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFC_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFC_Quick_Check=_no}', "");
Expect(0, 195101, '\p{^NFC_Quick_Check=_no}', "");
Expect(0, 195101, '\P{NFC_Quick_Check=_no}', "");
Expect(1, 195101, '\P{^NFC_Quick_Check=_no}', "");
Expect(0, 195102, '\p{NFC_Quick_Check=_no}', "");
Expect(1, 195102, '\p{^NFC_Quick_Check=_no}', "");
Expect(1, 195102, '\P{NFC_Quick_Check=_no}', "");
Expect(0, 195102, '\P{^NFC_Quick_Check=_no}', "");
Error('\p{NFC_QC=__N:=}');
Error('\P{NFC_QC=__N:=}');
Expect(1, 195101, '\p{NFC_QC=n}', "");
Expect(0, 195101, '\p{^NFC_QC=n}', "");
Expect(0, 195101, '\P{NFC_QC=n}', "");
Expect(1, 195101, '\P{^NFC_QC=n}', "");
Expect(0, 195102, '\p{NFC_QC=n}', "");
Expect(1, 195102, '\p{^NFC_QC=n}', "");
Expect(1, 195102, '\P{NFC_QC=n}', "");
Expect(0, 195102, '\P{^NFC_QC=n}', "");
Expect(1, 195101, '\p{NFC_QC=__N}', "");
Expect(0, 195101, '\p{^NFC_QC=__N}', "");
Expect(0, 195101, '\P{NFC_QC=__N}', "");
Expect(1, 195101, '\P{^NFC_QC=__N}', "");
Expect(0, 195102, '\p{NFC_QC=__N}', "");
Expect(1, 195102, '\p{^NFC_QC=__N}', "");
Expect(1, 195102, '\P{NFC_QC=__N}', "");
Expect(0, 195102, '\P{^NFC_QC=__N}', "");
Error('\p{Is_NFC_Quick_Check=_/a/no}');
Error('\P{Is_NFC_Quick_Check=_/a/no}');
Expect(1, 195101, '\p{Is_NFC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFC_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFC_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFC_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFC_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFC_Quick_Check:_-No}', "");
Expect(0, 195101, '\p{^Is_NFC_Quick_Check:_-No}', "");
Expect(0, 195101, '\P{Is_NFC_Quick_Check:_-No}', "");
Expect(1, 195101, '\P{^Is_NFC_Quick_Check:_-No}', "");
Expect(0, 195102, '\p{Is_NFC_Quick_Check:_-No}', "");
Expect(1, 195102, '\p{^Is_NFC_Quick_Check:_-No}', "");
Expect(1, 195102, '\P{Is_NFC_Quick_Check:_-No}', "");
Expect(0, 195102, '\P{^Is_NFC_Quick_Check:_-No}', "");
Error('\p{Is_NFC_QC=:=_ N}');
Error('\P{Is_NFC_QC=:=_ N}');
Expect(1, 195101, '\p{Is_NFC_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFC_QC=n}', "");
Expect(0, 195101, '\P{Is_NFC_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFC_QC=n}', "");
Expect(0, 195102, '\p{Is_NFC_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFC_QC=n}', "");
Expect(1, 195102, '\P{Is_NFC_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFC_QC=n}', "");
Expect(1, 195101, '\p{Is_NFC_QC= -n}', "");
Expect(0, 195101, '\p{^Is_NFC_QC= -n}', "");
Expect(0, 195101, '\P{Is_NFC_QC= -n}', "");
Expect(1, 195101, '\P{^Is_NFC_QC= -n}', "");
Expect(0, 195102, '\p{Is_NFC_QC= -n}', "");
Expect(1, 195102, '\p{^Is_NFC_QC= -n}', "");
Expect(1, 195102, '\P{Is_NFC_QC= -n}', "");
Expect(0, 195102, '\P{^Is_NFC_QC= -n}', "");
Error('\p{NFC_Quick_Check=-Yes/a/}');
Error('\P{NFC_Quick_Check=-Yes/a/}');
Expect(1, 195102, '\p{NFC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^NFC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{NFC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^NFC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{NFC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^NFC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{NFC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^NFC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{NFC_Quick_Check= -yes}', "");
Expect(0, 195102, '\p{^NFC_Quick_Check= -yes}', "");
Expect(0, 195102, '\P{NFC_Quick_Check= -yes}', "");
Expect(1, 195102, '\P{^NFC_Quick_Check= -yes}', "");
Expect(0, 195101, '\p{NFC_Quick_Check= -yes}', "");
Expect(1, 195101, '\p{^NFC_Quick_Check= -yes}', "");
Expect(1, 195101, '\P{NFC_Quick_Check= -yes}', "");
Expect(0, 195101, '\P{^NFC_Quick_Check= -yes}', "");
Error('\p{NFC_QC=-	Y/a/}');
Error('\P{NFC_QC=-	Y/a/}');
Expect(1, 195102, '\p{NFC_QC=y}', "");
Expect(0, 195102, '\p{^NFC_QC=y}', "");
Expect(0, 195102, '\P{NFC_QC=y}', "");
Expect(1, 195102, '\P{^NFC_QC=y}', "");
Expect(0, 195101, '\p{NFC_QC=y}', "");
Expect(1, 195101, '\p{^NFC_QC=y}', "");
Expect(1, 195101, '\P{NFC_QC=y}', "");
Expect(0, 195101, '\P{^NFC_QC=y}', "");
Expect(1, 195102, '\p{NFC_QC=_y}', "");
Expect(0, 195102, '\p{^NFC_QC=_y}', "");
Expect(0, 195102, '\P{NFC_QC=_y}', "");
Expect(1, 195102, '\P{^NFC_QC=_y}', "");
Expect(0, 195101, '\p{NFC_QC=_y}', "");
Expect(1, 195101, '\p{^NFC_QC=_y}', "");
Expect(1, 195101, '\P{NFC_QC=_y}', "");
Expect(0, 195101, '\P{^NFC_QC=_y}', "");
Error('\p{Is_NFC_Quick_Check=/a/ _YES}');
Error('\P{Is_NFC_Quick_Check=/a/ _YES}');
Expect(1, 195102, '\p{Is_NFC_Quick_Check: yes}', "");
Expect(0, 195102, '\p{^Is_NFC_Quick_Check: yes}', "");
Expect(0, 195102, '\P{Is_NFC_Quick_Check: yes}', "");
Expect(1, 195102, '\P{^Is_NFC_Quick_Check: yes}', "");
Expect(0, 195101, '\p{Is_NFC_Quick_Check: yes}', "");
Expect(1, 195101, '\p{^Is_NFC_Quick_Check: yes}', "");
Expect(1, 195101, '\P{Is_NFC_Quick_Check: yes}', "");
Expect(0, 195101, '\P{^Is_NFC_Quick_Check: yes}', "");
Expect(1, 195102, '\p{Is_NFC_Quick_Check=--YES}', "");
Expect(0, 195102, '\p{^Is_NFC_Quick_Check=--YES}', "");
Expect(0, 195102, '\P{Is_NFC_Quick_Check=--YES}', "");
Expect(1, 195102, '\P{^Is_NFC_Quick_Check=--YES}', "");
Expect(0, 195101, '\p{Is_NFC_Quick_Check=--YES}', "");
Expect(1, 195101, '\p{^Is_NFC_Quick_Check=--YES}', "");
Expect(1, 195101, '\P{Is_NFC_Quick_Check=--YES}', "");
Expect(0, 195101, '\P{^Is_NFC_Quick_Check=--YES}', "");
Error('\p{Is_NFC_QC=_Y/a/}');
Error('\P{Is_NFC_QC=_Y/a/}');
Expect(1, 195102, '\p{Is_NFC_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFC_QC=y}', "");
Expect(0, 195102, '\P{Is_NFC_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFC_QC=y}', "");
Expect(0, 195101, '\p{Is_NFC_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFC_QC=y}', "");
Expect(1, 195101, '\P{Is_NFC_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFC_QC=y}', "");
Expect(1, 195102, '\p{Is_NFC_QC=	Y}', "");
Expect(0, 195102, '\p{^Is_NFC_QC=	Y}', "");
Expect(0, 195102, '\P{Is_NFC_QC=	Y}', "");
Expect(1, 195102, '\P{^Is_NFC_QC=	Y}', "");
Expect(0, 195101, '\p{Is_NFC_QC=	Y}', "");
Expect(1, 195101, '\p{^Is_NFC_QC=	Y}', "");
Expect(1, 195101, '\P{Is_NFC_QC=	Y}', "");
Expect(0, 195101, '\P{^Is_NFC_QC=	Y}', "");
Error('\p{NFD_Quick_Check=No/a/}');
Error('\P{NFD_Quick_Check=No/a/}');
Expect(1, 195101, '\p{NFD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFD_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFD_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFD_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFD_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFD_Quick_Check=		No}', "");
Expect(0, 195101, '\p{^NFD_Quick_Check=		No}', "");
Expect(0, 195101, '\P{NFD_Quick_Check=		No}', "");
Expect(1, 195101, '\P{^NFD_Quick_Check=		No}', "");
Expect(0, 195102, '\p{NFD_Quick_Check=		No}', "");
Expect(1, 195102, '\p{^NFD_Quick_Check=		No}', "");
Expect(1, 195102, '\P{NFD_Quick_Check=		No}', "");
Expect(0, 195102, '\P{^NFD_Quick_Check=		No}', "");
Error('\p{NFD_QC=-:=n}');
Error('\P{NFD_QC=-:=n}');
Expect(1, 195101, '\p{NFD_QC:n}', "");
Expect(0, 195101, '\p{^NFD_QC:n}', "");
Expect(0, 195101, '\P{NFD_QC:n}', "");
Expect(1, 195101, '\P{^NFD_QC:n}', "");
Expect(0, 195102, '\p{NFD_QC:n}', "");
Expect(1, 195102, '\p{^NFD_QC:n}', "");
Expect(1, 195102, '\P{NFD_QC:n}', "");
Expect(0, 195102, '\P{^NFD_QC:n}', "");
Expect(1, 195101, '\p{NFD_QC=	 N}', "");
Expect(0, 195101, '\p{^NFD_QC=	 N}', "");
Expect(0, 195101, '\P{NFD_QC=	 N}', "");
Expect(1, 195101, '\P{^NFD_QC=	 N}', "");
Expect(0, 195102, '\p{NFD_QC=	 N}', "");
Expect(1, 195102, '\p{^NFD_QC=	 N}', "");
Expect(1, 195102, '\P{NFD_QC=	 N}', "");
Expect(0, 195102, '\P{^NFD_QC=	 N}', "");
Error('\p{Is_NFD_Quick_Check=	 No/a/}');
Error('\P{Is_NFD_Quick_Check=	 No/a/}');
Expect(1, 195101, '\p{Is_NFD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFD_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFD_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFD_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFD_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFD_Quick_Check=	no}', "");
Expect(0, 195101, '\p{^Is_NFD_Quick_Check=	no}', "");
Expect(0, 195101, '\P{Is_NFD_Quick_Check=	no}', "");
Expect(1, 195101, '\P{^Is_NFD_Quick_Check=	no}', "");
Expect(0, 195102, '\p{Is_NFD_Quick_Check=	no}', "");
Expect(1, 195102, '\p{^Is_NFD_Quick_Check=	no}', "");
Expect(1, 195102, '\P{Is_NFD_Quick_Check=	no}', "");
Expect(0, 195102, '\P{^Is_NFD_Quick_Check=	no}', "");
Error('\p{Is_NFD_QC=	-N:=}');
Error('\P{Is_NFD_QC=	-N:=}');
Expect(1, 195101, '\p{Is_NFD_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFD_QC=n}', "");
Expect(0, 195101, '\P{Is_NFD_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFD_QC=n}', "");
Expect(0, 195102, '\p{Is_NFD_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFD_QC=n}', "");
Expect(1, 195102, '\P{Is_NFD_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFD_QC=n}', "");
Expect(1, 195101, '\p{Is_NFD_QC=-_N}', "");
Expect(0, 195101, '\p{^Is_NFD_QC=-_N}', "");
Expect(0, 195101, '\P{Is_NFD_QC=-_N}', "");
Expect(1, 195101, '\P{^Is_NFD_QC=-_N}', "");
Expect(0, 195102, '\p{Is_NFD_QC=-_N}', "");
Expect(1, 195102, '\p{^Is_NFD_QC=-_N}', "");
Expect(1, 195102, '\P{Is_NFD_QC=-_N}', "");
Expect(0, 195102, '\P{^Is_NFD_QC=-_N}', "");
Error('\p{NFD_Quick_Check=-Yes:=}');
Error('\P{NFD_Quick_Check=-Yes:=}');
Expect(1, 195102, '\p{NFD_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^NFD_Quick_Check=yes}', "");
Expect(0, 195102, '\P{NFD_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^NFD_Quick_Check=yes}', "");
Expect(0, 195101, '\p{NFD_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^NFD_Quick_Check=yes}', "");
Expect(1, 195101, '\P{NFD_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^NFD_Quick_Check=yes}', "");
Expect(1, 195102, '\p{NFD_Quick_Check:-	Yes}', "");
Expect(0, 195102, '\p{^NFD_Quick_Check:-	Yes}', "");
Expect(0, 195102, '\P{NFD_Quick_Check:-	Yes}', "");
Expect(1, 195102, '\P{^NFD_Quick_Check:-	Yes}', "");
Expect(0, 195101, '\p{NFD_Quick_Check:-	Yes}', "");
Expect(1, 195101, '\p{^NFD_Quick_Check:-	Yes}', "");
Expect(1, 195101, '\P{NFD_Quick_Check:-	Yes}', "");
Expect(0, 195101, '\P{^NFD_Quick_Check:-	Yes}', "");
Error('\p{NFD_QC=/a/ -y}');
Error('\P{NFD_QC=/a/ -y}');
Expect(1, 195102, '\p{NFD_QC=y}', "");
Expect(0, 195102, '\p{^NFD_QC=y}', "");
Expect(0, 195102, '\P{NFD_QC=y}', "");
Expect(1, 195102, '\P{^NFD_QC=y}', "");
Expect(0, 195101, '\p{NFD_QC=y}', "");
Expect(1, 195101, '\p{^NFD_QC=y}', "");
Expect(1, 195101, '\P{NFD_QC=y}', "");
Expect(0, 195101, '\P{^NFD_QC=y}', "");
Expect(1, 195102, '\p{NFD_QC=_-Y}', "");
Expect(0, 195102, '\p{^NFD_QC=_-Y}', "");
Expect(0, 195102, '\P{NFD_QC=_-Y}', "");
Expect(1, 195102, '\P{^NFD_QC=_-Y}', "");
Expect(0, 195101, '\p{NFD_QC=_-Y}', "");
Expect(1, 195101, '\p{^NFD_QC=_-Y}', "");
Expect(1, 195101, '\P{NFD_QC=_-Y}', "");
Expect(0, 195101, '\P{^NFD_QC=_-Y}', "");
Error('\p{Is_NFD_Quick_Check=	_YES:=}');
Error('\P{Is_NFD_Quick_Check=	_YES:=}');
Expect(1, 195102, '\p{Is_NFD_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFD_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFD_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFD_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFD_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFD_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFD_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFD_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFD_Quick_Check:--yes}', "");
Expect(0, 195102, '\p{^Is_NFD_Quick_Check:--yes}', "");
Expect(0, 195102, '\P{Is_NFD_Quick_Check:--yes}', "");
Expect(1, 195102, '\P{^Is_NFD_Quick_Check:--yes}', "");
Expect(0, 195101, '\p{Is_NFD_Quick_Check:--yes}', "");
Expect(1, 195101, '\p{^Is_NFD_Quick_Check:--yes}', "");
Expect(1, 195101, '\P{Is_NFD_Quick_Check:--yes}', "");
Expect(0, 195101, '\P{^Is_NFD_Quick_Check:--yes}', "");
Error('\p{Is_NFD_QC=:=__Y}');
Error('\P{Is_NFD_QC=:=__Y}');
Expect(1, 195102, '\p{Is_NFD_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFD_QC=y}', "");
Expect(0, 195102, '\P{Is_NFD_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFD_QC=y}', "");
Expect(0, 195101, '\p{Is_NFD_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFD_QC=y}', "");
Expect(1, 195101, '\P{Is_NFD_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFD_QC=y}', "");
Expect(1, 195102, '\p{Is_NFD_QC=	-Y}', "");
Expect(0, 195102, '\p{^Is_NFD_QC=	-Y}', "");
Expect(0, 195102, '\P{Is_NFD_QC=	-Y}', "");
Expect(1, 195102, '\P{^Is_NFD_QC=	-Y}', "");
Expect(0, 195101, '\p{Is_NFD_QC=	-Y}', "");
Expect(1, 195101, '\p{^Is_NFD_QC=	-Y}', "");
Expect(1, 195101, '\P{Is_NFD_QC=	-Y}', "");
Expect(0, 195101, '\P{^Is_NFD_QC=	-Y}', "");
Error('\p{NFKC_Quick_Check=-/a/maybe}');
Error('\P{NFKC_Quick_Check=-/a/maybe}');
Expect(1, 69927, '\p{NFKC_Quick_Check:maybe}', "");
Expect(0, 69927, '\p{^NFKC_Quick_Check:maybe}', "");
Expect(0, 69927, '\P{NFKC_Quick_Check:maybe}', "");
Expect(1, 69927, '\P{^NFKC_Quick_Check:maybe}', "");
Expect(0, 69928, '\p{NFKC_Quick_Check:maybe}', "");
Expect(1, 69928, '\p{^NFKC_Quick_Check:maybe}', "");
Expect(1, 69928, '\P{NFKC_Quick_Check:maybe}', "");
Expect(0, 69928, '\P{^NFKC_Quick_Check:maybe}', "");
Expect(1, 69927, '\p{NFKC_Quick_Check=-_Maybe}', "");
Expect(0, 69927, '\p{^NFKC_Quick_Check=-_Maybe}', "");
Expect(0, 69927, '\P{NFKC_Quick_Check=-_Maybe}', "");
Expect(1, 69927, '\P{^NFKC_Quick_Check=-_Maybe}', "");
Expect(0, 69928, '\p{NFKC_Quick_Check=-_Maybe}', "");
Expect(1, 69928, '\p{^NFKC_Quick_Check=-_Maybe}', "");
Expect(1, 69928, '\P{NFKC_Quick_Check=-_Maybe}', "");
Expect(0, 69928, '\P{^NFKC_Quick_Check=-_Maybe}', "");
Error('\p{NFKC_QC=-M/a/}');
Error('\P{NFKC_QC=-M/a/}');
Expect(1, 69927, '\p{NFKC_QC=m}', "");
Expect(0, 69927, '\p{^NFKC_QC=m}', "");
Expect(0, 69927, '\P{NFKC_QC=m}', "");
Expect(1, 69927, '\P{^NFKC_QC=m}', "");
Expect(0, 69928, '\p{NFKC_QC=m}', "");
Expect(1, 69928, '\p{^NFKC_QC=m}', "");
Expect(1, 69928, '\P{NFKC_QC=m}', "");
Expect(0, 69928, '\P{^NFKC_QC=m}', "");
Expect(1, 69927, '\p{NFKC_QC=_m}', "");
Expect(0, 69927, '\p{^NFKC_QC=_m}', "");
Expect(0, 69927, '\P{NFKC_QC=_m}', "");
Expect(1, 69927, '\P{^NFKC_QC=_m}', "");
Expect(0, 69928, '\p{NFKC_QC=_m}', "");
Expect(1, 69928, '\p{^NFKC_QC=_m}', "");
Expect(1, 69928, '\P{NFKC_QC=_m}', "");
Expect(0, 69928, '\P{^NFKC_QC=_m}', "");
Error('\p{Is_NFKC_Quick_Check=-:=maybe}');
Error('\P{Is_NFKC_Quick_Check=-:=maybe}');
Expect(1, 69927, '\p{Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69927, '\p{^Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69927, '\P{Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69927, '\P{^Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69928, '\p{Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69928, '\p{^Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69928, '\P{Is_NFKC_Quick_Check=maybe}', "");
Expect(0, 69928, '\P{^Is_NFKC_Quick_Check=maybe}', "");
Expect(1, 69927, '\p{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69927, '\p{^Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69927, '\P{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(1, 69927, '\P{^Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69928, '\p{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(1, 69928, '\p{^Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(1, 69928, '\P{Is_NFKC_Quick_Check=	_Maybe}', "");
Expect(0, 69928, '\P{^Is_NFKC_Quick_Check=	_Maybe}', "");
Error('\p{Is_NFKC_QC:		 M:=}');
Error('\P{Is_NFKC_QC:		 M:=}');
Expect(1, 69927, '\p{Is_NFKC_QC=m}', "");
Expect(0, 69927, '\p{^Is_NFKC_QC=m}', "");
Expect(0, 69927, '\P{Is_NFKC_QC=m}', "");
Expect(1, 69927, '\P{^Is_NFKC_QC=m}', "");
Expect(0, 69928, '\p{Is_NFKC_QC=m}', "");
Expect(1, 69928, '\p{^Is_NFKC_QC=m}', "");
Expect(1, 69928, '\P{Is_NFKC_QC=m}', "");
Expect(0, 69928, '\P{^Is_NFKC_QC=m}', "");
Expect(1, 69927, '\p{Is_NFKC_QC=	_m}', "");
Expect(0, 69927, '\p{^Is_NFKC_QC=	_m}', "");
Expect(0, 69927, '\P{Is_NFKC_QC=	_m}', "");
Expect(1, 69927, '\P{^Is_NFKC_QC=	_m}', "");
Expect(0, 69928, '\p{Is_NFKC_QC=	_m}', "");
Expect(1, 69928, '\p{^Is_NFKC_QC=	_m}', "");
Expect(1, 69928, '\P{Is_NFKC_QC=	_m}', "");
Expect(0, 69928, '\P{^Is_NFKC_QC=	_m}', "");
Error('\p{NFKC_Quick_Check=	No/a/}');
Error('\P{NFKC_Quick_Check=	No/a/}');
Expect(1, 195101, '\p{NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFKC_Quick_Check=- no}', "");
Expect(0, 195101, '\p{^NFKC_Quick_Check=- no}', "");
Expect(0, 195101, '\P{NFKC_Quick_Check=- no}', "");
Expect(1, 195101, '\P{^NFKC_Quick_Check=- no}', "");
Expect(0, 195102, '\p{NFKC_Quick_Check=- no}', "");
Expect(1, 195102, '\p{^NFKC_Quick_Check=- no}', "");
Expect(1, 195102, '\P{NFKC_Quick_Check=- no}', "");
Expect(0, 195102, '\P{^NFKC_Quick_Check=- no}', "");
Error('\p{NFKC_QC=/a/		N}');
Error('\P{NFKC_QC=/a/		N}');
Expect(1, 195101, '\p{NFKC_QC=n}', "");
Expect(0, 195101, '\p{^NFKC_QC=n}', "");
Expect(0, 195101, '\P{NFKC_QC=n}', "");
Expect(1, 195101, '\P{^NFKC_QC=n}', "");
Expect(0, 195102, '\p{NFKC_QC=n}', "");
Expect(1, 195102, '\p{^NFKC_QC=n}', "");
Expect(1, 195102, '\P{NFKC_QC=n}', "");
Expect(0, 195102, '\P{^NFKC_QC=n}', "");
Expect(1, 195101, '\p{NFKC_QC= N}', "");
Expect(0, 195101, '\p{^NFKC_QC= N}', "");
Expect(0, 195101, '\P{NFKC_QC= N}', "");
Expect(1, 195101, '\P{^NFKC_QC= N}', "");
Expect(0, 195102, '\p{NFKC_QC= N}', "");
Expect(1, 195102, '\p{^NFKC_QC= N}', "");
Expect(1, 195102, '\P{NFKC_QC= N}', "");
Expect(0, 195102, '\P{^NFKC_QC= N}', "");
Error('\p{Is_NFKC_Quick_Check: _No/a/}');
Error('\P{Is_NFKC_Quick_Check: _No/a/}');
Expect(1, 195101, '\p{Is_NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFKC_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFKC_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFKC_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFKC_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFKC_Quick_Check=-	No}', "");
Expect(0, 195101, '\p{^Is_NFKC_Quick_Check=-	No}', "");
Expect(0, 195101, '\P{Is_NFKC_Quick_Check=-	No}', "");
Expect(1, 195101, '\P{^Is_NFKC_Quick_Check=-	No}', "");
Expect(0, 195102, '\p{Is_NFKC_Quick_Check=-	No}', "");
Expect(1, 195102, '\p{^Is_NFKC_Quick_Check=-	No}', "");
Expect(1, 195102, '\P{Is_NFKC_Quick_Check=-	No}', "");
Expect(0, 195102, '\P{^Is_NFKC_Quick_Check=-	No}', "");
Error('\p{Is_NFKC_QC=-:=n}');
Error('\P{Is_NFKC_QC=-:=n}');
Expect(1, 195101, '\p{Is_NFKC_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFKC_QC=n}', "");
Expect(0, 195101, '\P{Is_NFKC_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFKC_QC=n}', "");
Expect(0, 195102, '\p{Is_NFKC_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFKC_QC=n}', "");
Expect(1, 195102, '\P{Is_NFKC_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFKC_QC=n}', "");
Expect(1, 195101, '\p{Is_NFKC_QC= N}', "");
Expect(0, 195101, '\p{^Is_NFKC_QC= N}', "");
Expect(0, 195101, '\P{Is_NFKC_QC= N}', "");
Expect(1, 195101, '\P{^Is_NFKC_QC= N}', "");
Expect(0, 195102, '\p{Is_NFKC_QC= N}', "");
Expect(1, 195102, '\p{^Is_NFKC_QC= N}', "");
Expect(1, 195102, '\P{Is_NFKC_QC= N}', "");
Expect(0, 195102, '\P{^Is_NFKC_QC= N}', "");
Error('\p{NFKC_Quick_Check=	-yes/a/}');
Error('\P{NFKC_Quick_Check=	-yes/a/}');
Expect(1, 195102, '\p{NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{NFKC_Quick_Check= _yes}', "");
Expect(0, 195102, '\p{^NFKC_Quick_Check= _yes}', "");
Expect(0, 195102, '\P{NFKC_Quick_Check= _yes}', "");
Expect(1, 195102, '\P{^NFKC_Quick_Check= _yes}', "");
Expect(0, 195101, '\p{NFKC_Quick_Check= _yes}', "");
Expect(1, 195101, '\p{^NFKC_Quick_Check= _yes}', "");
Expect(1, 195101, '\P{NFKC_Quick_Check= _yes}', "");
Expect(0, 195101, '\P{^NFKC_Quick_Check= _yes}', "");
Error('\p{NFKC_QC=:=  Y}');
Error('\P{NFKC_QC=:=  Y}');
Expect(1, 195102, '\p{NFKC_QC=y}', "");
Expect(0, 195102, '\p{^NFKC_QC=y}', "");
Expect(0, 195102, '\P{NFKC_QC=y}', "");
Expect(1, 195102, '\P{^NFKC_QC=y}', "");
Expect(0, 195101, '\p{NFKC_QC=y}', "");
Expect(1, 195101, '\p{^NFKC_QC=y}', "");
Expect(1, 195101, '\P{NFKC_QC=y}', "");
Expect(0, 195101, '\P{^NFKC_QC=y}', "");
Expect(1, 195102, '\p{NFKC_QC=--Y}', "");
Expect(0, 195102, '\p{^NFKC_QC=--Y}', "");
Expect(0, 195102, '\P{NFKC_QC=--Y}', "");
Expect(1, 195102, '\P{^NFKC_QC=--Y}', "");
Expect(0, 195101, '\p{NFKC_QC=--Y}', "");
Expect(1, 195101, '\p{^NFKC_QC=--Y}', "");
Expect(1, 195101, '\P{NFKC_QC=--Y}', "");
Expect(0, 195101, '\P{^NFKC_QC=--Y}', "");
Error('\p{Is_NFKC_Quick_Check=/a/	yes}');
Error('\P{Is_NFKC_Quick_Check=/a/	yes}');
Expect(1, 195102, '\p{Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFKC_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFKC_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFKC_Quick_Check=--YES}', "");
Expect(0, 195102, '\p{^Is_NFKC_Quick_Check=--YES}', "");
Expect(0, 195102, '\P{Is_NFKC_Quick_Check=--YES}', "");
Expect(1, 195102, '\P{^Is_NFKC_Quick_Check=--YES}', "");
Expect(0, 195101, '\p{Is_NFKC_Quick_Check=--YES}', "");
Expect(1, 195101, '\p{^Is_NFKC_Quick_Check=--YES}', "");
Expect(1, 195101, '\P{Is_NFKC_Quick_Check=--YES}', "");
Expect(0, 195101, '\P{^Is_NFKC_Quick_Check=--YES}', "");
Error('\p{Is_NFKC_QC=	/a/y}');
Error('\P{Is_NFKC_QC=	/a/y}');
Expect(1, 195102, '\p{Is_NFKC_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFKC_QC=y}', "");
Expect(0, 195102, '\P{Is_NFKC_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFKC_QC=y}', "");
Expect(0, 195101, '\p{Is_NFKC_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFKC_QC=y}', "");
Expect(1, 195101, '\P{Is_NFKC_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFKC_QC=y}', "");
Expect(1, 195102, '\p{Is_NFKC_QC=  Y}', "");
Expect(0, 195102, '\p{^Is_NFKC_QC=  Y}', "");
Expect(0, 195102, '\P{Is_NFKC_QC=  Y}', "");
Expect(1, 195102, '\P{^Is_NFKC_QC=  Y}', "");
Expect(0, 195101, '\p{Is_NFKC_QC=  Y}', "");
Expect(1, 195101, '\p{^Is_NFKC_QC=  Y}', "");
Expect(1, 195101, '\P{Is_NFKC_QC=  Y}', "");
Expect(0, 195101, '\P{^Is_NFKC_QC=  Y}', "");
Error('\p{NFKD_Quick_Check=:=NO}');
Error('\P{NFKD_Quick_Check=:=NO}');
Expect(1, 195101, '\p{NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\P{NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\p{NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\P{NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\p{NFKD_Quick_Check=--No}', "");
Expect(0, 195101, '\p{^NFKD_Quick_Check=--No}', "");
Expect(0, 195101, '\P{NFKD_Quick_Check=--No}', "");
Expect(1, 195101, '\P{^NFKD_Quick_Check=--No}', "");
Expect(0, 195102, '\p{NFKD_Quick_Check=--No}', "");
Expect(1, 195102, '\p{^NFKD_Quick_Check=--No}', "");
Expect(1, 195102, '\P{NFKD_Quick_Check=--No}', "");
Expect(0, 195102, '\P{^NFKD_Quick_Check=--No}', "");
Error('\p{NFKD_QC=	N/a/}');
Error('\P{NFKD_QC=	N/a/}');
Expect(1, 195101, '\p{NFKD_QC=n}', "");
Expect(0, 195101, '\p{^NFKD_QC=n}', "");
Expect(0, 195101, '\P{NFKD_QC=n}', "");
Expect(1, 195101, '\P{^NFKD_QC=n}', "");
Expect(0, 195102, '\p{NFKD_QC=n}', "");
Expect(1, 195102, '\p{^NFKD_QC=n}', "");
Expect(1, 195102, '\P{NFKD_QC=n}', "");
Expect(0, 195102, '\P{^NFKD_QC=n}', "");
Expect(1, 195101, '\p{NFKD_QC=_-n}', "");
Expect(0, 195101, '\p{^NFKD_QC=_-n}', "");
Expect(0, 195101, '\P{NFKD_QC=_-n}', "");
Expect(1, 195101, '\P{^NFKD_QC=_-n}', "");
Expect(0, 195102, '\p{NFKD_QC=_-n}', "");
Expect(1, 195102, '\p{^NFKD_QC=_-n}', "");
Expect(1, 195102, '\P{NFKD_QC=_-n}', "");
Expect(0, 195102, '\P{^NFKD_QC=_-n}', "");
Error('\p{Is_NFKD_Quick_Check= 	no:=}');
Error('\P{Is_NFKD_Quick_Check= 	no:=}');
Expect(1, 195101, '\p{Is_NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\p{^Is_NFKD_Quick_Check=no}', "");
Expect(0, 195101, '\P{Is_NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\P{^Is_NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\p{Is_NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\p{^Is_NFKD_Quick_Check=no}', "");
Expect(1, 195102, '\P{Is_NFKD_Quick_Check=no}', "");
Expect(0, 195102, '\P{^Is_NFKD_Quick_Check=no}', "");
Expect(1, 195101, '\p{Is_NFKD_Quick_Check=-no}', "");
Expect(0, 195101, '\p{^Is_NFKD_Quick_Check=-no}', "");
Expect(0, 195101, '\P{Is_NFKD_Quick_Check=-no}', "");
Expect(1, 195101, '\P{^Is_NFKD_Quick_Check=-no}', "");
Expect(0, 195102, '\p{Is_NFKD_Quick_Check=-no}', "");
Expect(1, 195102, '\p{^Is_NFKD_Quick_Check=-no}', "");
Expect(1, 195102, '\P{Is_NFKD_Quick_Check=-no}', "");
Expect(0, 195102, '\P{^Is_NFKD_Quick_Check=-no}', "");
Error('\p{Is_NFKD_QC=	 N:=}');
Error('\P{Is_NFKD_QC=	 N:=}');
Expect(1, 195101, '\p{Is_NFKD_QC=n}', "");
Expect(0, 195101, '\p{^Is_NFKD_QC=n}', "");
Expect(0, 195101, '\P{Is_NFKD_QC=n}', "");
Expect(1, 195101, '\P{^Is_NFKD_QC=n}', "");
Expect(0, 195102, '\p{Is_NFKD_QC=n}', "");
Expect(1, 195102, '\p{^Is_NFKD_QC=n}', "");
Expect(1, 195102, '\P{Is_NFKD_QC=n}', "");
Expect(0, 195102, '\P{^Is_NFKD_QC=n}', "");
Expect(1, 195101, '\p{Is_NFKD_QC=-	n}', "");
Expect(0, 195101, '\p{^Is_NFKD_QC=-	n}', "");
Expect(0, 195101, '\P{Is_NFKD_QC=-	n}', "");
Expect(1, 195101, '\P{^Is_NFKD_QC=-	n}', "");
Expect(0, 195102, '\p{Is_NFKD_QC=-	n}', "");
Expect(1, 195102, '\p{^Is_NFKD_QC=-	n}', "");
Expect(1, 195102, '\P{Is_NFKD_QC=-	n}', "");
Expect(0, 195102, '\P{^Is_NFKD_QC=-	n}', "");
Error('\p{NFKD_Quick_Check:-:=Yes}');
Error('\P{NFKD_Quick_Check:-:=Yes}');
Expect(1, 195102, '\p{NFKD_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^NFKD_Quick_Check=yes}', "");
Expect(0, 195102, '\P{NFKD_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^NFKD_Quick_Check=yes}', "");
Expect(0, 195101, '\p{NFKD_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^NFKD_Quick_Check=yes}', "");
Expect(1, 195101, '\P{NFKD_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^NFKD_Quick_Check=yes}', "");
Expect(1, 195102, '\p{NFKD_Quick_Check=_-YES}', "");
Expect(0, 195102, '\p{^NFKD_Quick_Check=_-YES}', "");
Expect(0, 195102, '\P{NFKD_Quick_Check=_-YES}', "");
Expect(1, 195102, '\P{^NFKD_Quick_Check=_-YES}', "");
Expect(0, 195101, '\p{NFKD_Quick_Check=_-YES}', "");
Expect(1, 195101, '\p{^NFKD_Quick_Check=_-YES}', "");
Expect(1, 195101, '\P{NFKD_Quick_Check=_-YES}', "");
Expect(0, 195101, '\P{^NFKD_Quick_Check=_-YES}', "");
Error('\p{NFKD_QC=/a/-	Y}');
Error('\P{NFKD_QC=/a/-	Y}');
Expect(1, 195102, '\p{NFKD_QC=y}', "");
Expect(0, 195102, '\p{^NFKD_QC=y}', "");
Expect(0, 195102, '\P{NFKD_QC=y}', "");
Expect(1, 195102, '\P{^NFKD_QC=y}', "");
Expect(0, 195101, '\p{NFKD_QC=y}', "");
Expect(1, 195101, '\p{^NFKD_QC=y}', "");
Expect(1, 195101, '\P{NFKD_QC=y}', "");
Expect(0, 195101, '\P{^NFKD_QC=y}', "");
Expect(1, 195102, '\p{NFKD_QC= _Y}', "");
Expect(0, 195102, '\p{^NFKD_QC= _Y}', "");
Expect(0, 195102, '\P{NFKD_QC= _Y}', "");
Expect(1, 195102, '\P{^NFKD_QC= _Y}', "");
Expect(0, 195101, '\p{NFKD_QC= _Y}', "");
Expect(1, 195101, '\p{^NFKD_QC= _Y}', "");
Expect(1, 195101, '\P{NFKD_QC= _Y}', "");
Expect(0, 195101, '\P{^NFKD_QC= _Y}', "");
Error('\p{Is_NFKD_Quick_Check=_:=Yes}');
Error('\P{Is_NFKD_Quick_Check=_:=Yes}');
Expect(1, 195102, '\p{Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195102, '\p{^Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195102, '\P{Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195102, '\P{^Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195101, '\p{Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195101, '\p{^Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195101, '\P{Is_NFKD_Quick_Check=yes}', "");
Expect(0, 195101, '\P{^Is_NFKD_Quick_Check=yes}', "");
Expect(1, 195102, '\p{Is_NFKD_Quick_Check=_YES}', "");
Expect(0, 195102, '\p{^Is_NFKD_Quick_Check=_YES}', "");
Expect(0, 195102, '\P{Is_NFKD_Quick_Check=_YES}', "");
Expect(1, 195102, '\P{^Is_NFKD_Quick_Check=_YES}', "");
Expect(0, 195101, '\p{Is_NFKD_Quick_Check=_YES}', "");
Expect(1, 195101, '\p{^Is_NFKD_Quick_Check=_YES}', "");
Expect(1, 195101, '\P{Is_NFKD_Quick_Check=_YES}', "");
Expect(0, 195101, '\P{^Is_NFKD_Quick_Check=_YES}', "");
Error('\p{Is_NFKD_QC=	Y:=}');
Error('\P{Is_NFKD_QC=	Y:=}');
Expect(1, 195102, '\p{Is_NFKD_QC=y}', "");
Expect(0, 195102, '\p{^Is_NFKD_QC=y}', "");
Expect(0, 195102, '\P{Is_NFKD_QC=y}', "");
Expect(1, 195102, '\P{^Is_NFKD_QC=y}', "");
Expect(0, 195101, '\p{Is_NFKD_QC=y}', "");
Expect(1, 195101, '\p{^Is_NFKD_QC=y}', "");
Expect(1, 195101, '\P{Is_NFKD_QC=y}', "");
Expect(0, 195101, '\P{^Is_NFKD_QC=y}', "");
Expect(1, 195102, '\p{Is_NFKD_QC=  Y}', "");
Expect(0, 195102, '\p{^Is_NFKD_QC=  Y}', "");
Expect(0, 195102, '\P{Is_NFKD_QC=  Y}', "");
Expect(1, 195102, '\P{^Is_NFKD_QC=  Y}', "");
Expect(0, 195101, '\p{Is_NFKD_QC=  Y}', "");
Expect(1, 195101, '\p{^Is_NFKD_QC=  Y}', "");
Expect(1, 195101, '\P{Is_NFKD_QC=  Y}', "");
Expect(0, 195101, '\P{^Is_NFKD_QC=  Y}', "");
Error('\p{Other_Alphabetic=No}');
Error('\P{Other_Alphabetic=No}');
Error('\p{OAlpha:	N}');
Error('\P{OAlpha:	N}');
Error('\p{Is_Other_Alphabetic=F}');
Error('\P{Is_Other_Alphabetic=F}');
Error('\p{Is_OAlpha=False}');
Error('\P{Is_OAlpha=False}');
Error('\p{Other_Alphabetic=Yes}');
Error('\P{Other_Alphabetic=Yes}');
Error('\p{OAlpha=Y}');
Error('\P{OAlpha=Y}');
Error('\p{Is_Other_Alphabetic=T}');
Error('\P{Is_Other_Alphabetic=T}');
Error('\p{Is_OAlpha=True}');
Error('\P{Is_OAlpha=True}');
Error('\p{Other_Default_Ignorable_Code_Point=No}');
Error('\P{Other_Default_Ignorable_Code_Point=No}');
Error('\p{ODI=N}');
Error('\P{ODI=N}');
Error('\p{Is_Other_Default_Ignorable_Code_Point=F}');
Error('\P{Is_Other_Default_Ignorable_Code_Point=F}');
Error('\p{Is_ODI:	False}');
Error('\P{Is_ODI:	False}');
Error('\p{Other_Default_Ignorable_Code_Point=Yes}');
Error('\P{Other_Default_Ignorable_Code_Point=Yes}');
Error('\p{ODI=Y}');
Error('\P{ODI=Y}');
Error('\p{Is_Other_Default_Ignorable_Code_Point=T}');
Error('\P{Is_Other_Default_Ignorable_Code_Point=T}');
Error('\p{Is_ODI=True}');
Error('\P{Is_ODI=True}');
Error('\p{Other_Grapheme_Extend=No}');
Error('\P{Other_Grapheme_Extend=No}');
Error('\p{OGr_Ext=N}');
Error('\P{OGr_Ext=N}');
Error('\p{Is_Other_Grapheme_Extend:F}');
Error('\P{Is_Other_Grapheme_Extend:F}');
Error('\p{Is_OGr_Ext=False}');
Error('\P{Is_OGr_Ext=False}');
Error('\p{Other_Grapheme_Extend=Yes}');
Error('\P{Other_Grapheme_Extend=Yes}');
Error('\p{OGr_Ext=Y}');
Error('\P{OGr_Ext=Y}');
Error('\p{Is_Other_Grapheme_Extend=T}');
Error('\P{Is_Other_Grapheme_Extend=T}');
Error('\p{Is_OGr_Ext=True}');
Error('\P{Is_OGr_Ext=True}');
Error('\p{Other_ID_Continue=No}');
Error('\P{Other_ID_Continue=No}');
Error('\p{OIDC=N}');
Error('\P{OIDC=N}');
Error('\p{Is_Other_ID_Continue: F}');
Error('\P{Is_Other_ID_Continue: F}');
Error('\p{Is_OIDC=False}');
Error('\P{Is_OIDC=False}');
Error('\p{Other_ID_Continue=Yes}');
Error('\P{Other_ID_Continue=Yes}');
Error('\p{OIDC=Y}');
Error('\P{OIDC=Y}');
Error('\p{Is_Other_ID_Continue=T}');
Error('\P{Is_Other_ID_Continue=T}');
Error('\p{Is_OIDC=True}');
Error('\P{Is_OIDC=True}');
Error('\p{Other_ID_Start:   No}');
Error('\P{Other_ID_Start:   No}');
Error('\p{OIDS=N}');
Error('\P{OIDS=N}');
Error('\p{Is_Other_ID_Start=F}');
Error('\P{Is_Other_ID_Start=F}');
Error('\p{Is_OIDS=False}');
Error('\P{Is_OIDS=False}');
Error('\p{Other_ID_Start=Yes}');
Error('\P{Other_ID_Start=Yes}');
Error('\p{OIDS=Y}');
Error('\P{OIDS=Y}');
Error('\p{Is_Other_ID_Start:	T}');
Error('\P{Is_Other_ID_Start:	T}');
Error('\p{Is_OIDS=True}');
Error('\P{Is_OIDS=True}');
Error('\p{Other_Lowercase:   No}');
Error('\P{Other_Lowercase:   No}');
Error('\p{OLower=N}');
Error('\P{OLower=N}');
Error('\p{Is_Other_Lowercase=F}');
Error('\P{Is_Other_Lowercase=F}');
Error('\p{Is_OLower:False}');
Error('\P{Is_OLower:False}');
Error('\p{Other_Lowercase=Yes}');
Error('\P{Other_Lowercase=Yes}');
Error('\p{OLower=Y}');
Error('\P{OLower=Y}');
Error('\p{Is_Other_Lowercase=T}');
Error('\P{Is_Other_Lowercase=T}');
Error('\p{Is_OLower=True}');
Error('\P{Is_OLower=True}');
Error('\p{Other_Math=No}');
Error('\P{Other_Math=No}');
Error('\p{OMath=N}');
Error('\P{OMath=N}');
Error('\p{Is_Other_Math=F}');
Error('\P{Is_Other_Math=F}');
Error('\p{Is_OMath=False}');
Error('\P{Is_OMath=False}');
Error('\p{Other_Math=Yes}');
Error('\P{Other_Math=Yes}');
Error('\p{OMath=Y}');
Error('\P{OMath=Y}');
Error('\p{Is_Other_Math:T}');
Error('\P{Is_Other_Math:T}');
Error('\p{Is_OMath=True}');
Error('\P{Is_OMath=True}');
Error('\p{Other_Uppercase=No}');
Error('\P{Other_Uppercase=No}');
Error('\p{OUpper=N}');
Error('\P{OUpper=N}');
Error('\p{Is_Other_Uppercase=F}');
Error('\P{Is_Other_Uppercase=F}');
Error('\p{Is_OUpper=False}');
Error('\P{Is_OUpper=False}');
Error('\p{Other_Uppercase=Yes}');
Error('\P{Other_Uppercase=Yes}');
Error('\p{OUpper=Y}');
Error('\P{OUpper=Y}');
Error('\p{Is_Other_Uppercase=T}');
Error('\P{Is_Other_Uppercase=T}');
Error('\p{Is_OUpper=True}');
Error('\P{Is_OUpper=True}');
Error('\p{Pattern_Syntax= /a/No}');
Error('\P{Pattern_Syntax= /a/No}');
Expect(1, 65095, '\p{Pattern_Syntax: no}', "");
Expect(0, 65095, '\p{^Pattern_Syntax: no}', "");
Expect(0, 65095, '\P{Pattern_Syntax: no}', "");
Expect(1, 65095, '\P{^Pattern_Syntax: no}', "");
Expect(0, 65094, '\p{Pattern_Syntax: no}', "");
Expect(1, 65094, '\p{^Pattern_Syntax: no}', "");
Expect(1, 65094, '\P{Pattern_Syntax: no}', "");
Expect(0, 65094, '\P{^Pattern_Syntax: no}', "");
Expect(1, 65095, '\p{Pattern_Syntax=__No}', "");
Expect(0, 65095, '\p{^Pattern_Syntax=__No}', "");
Expect(0, 65095, '\P{Pattern_Syntax=__No}', "");
Expect(1, 65095, '\P{^Pattern_Syntax=__No}', "");
Expect(0, 65094, '\p{Pattern_Syntax=__No}', "");
Expect(1, 65094, '\p{^Pattern_Syntax=__No}', "");
Expect(1, 65094, '\P{Pattern_Syntax=__No}', "");
Expect(0, 65094, '\P{^Pattern_Syntax=__No}', "");
Error('\p{Pat_Syn=/a/N}');
Error('\P{Pat_Syn=/a/N}');
Expect(1, 65095, '\p{Pat_Syn:	n}', "");
Expect(0, 65095, '\p{^Pat_Syn:	n}', "");
Expect(0, 65095, '\P{Pat_Syn:	n}', "");
Expect(1, 65095, '\P{^Pat_Syn:	n}', "");
Expect(0, 65094, '\p{Pat_Syn:	n}', "");
Expect(1, 65094, '\p{^Pat_Syn:	n}', "");
Expect(1, 65094, '\P{Pat_Syn:	n}', "");
Expect(0, 65094, '\P{^Pat_Syn:	n}', "");
Expect(1, 65095, '\p{Pat_Syn=	-n}', "");
Expect(0, 65095, '\p{^Pat_Syn=	-n}', "");
Expect(0, 65095, '\P{Pat_Syn=	-n}', "");
Expect(1, 65095, '\P{^Pat_Syn=	-n}', "");
Expect(0, 65094, '\p{Pat_Syn=	-n}', "");
Expect(1, 65094, '\p{^Pat_Syn=	-n}', "");
Expect(1, 65094, '\P{Pat_Syn=	-n}', "");
Expect(0, 65094, '\P{^Pat_Syn=	-n}', "");
Error('\p{Is_Pattern_Syntax=_-F:=}');
Error('\P{Is_Pattern_Syntax=_-F:=}');
Expect(1, 65095, '\p{Is_Pattern_Syntax=f}', "");
Expect(0, 65095, '\p{^Is_Pattern_Syntax=f}', "");
Expect(0, 65095, '\P{Is_Pattern_Syntax=f}', "");
Expect(1, 65095, '\P{^Is_Pattern_Syntax=f}', "");
Expect(0, 65094, '\p{Is_Pattern_Syntax=f}', "");
Expect(1, 65094, '\p{^Is_Pattern_Syntax=f}', "");
Expect(1, 65094, '\P{Is_Pattern_Syntax=f}', "");
Expect(0, 65094, '\P{^Is_Pattern_Syntax=f}', "");
Expect(1, 65095, '\p{Is_Pattern_Syntax=	f}', "");
Expect(0, 65095, '\p{^Is_Pattern_Syntax=	f}', "");
Expect(0, 65095, '\P{Is_Pattern_Syntax=	f}', "");
Expect(1, 65095, '\P{^Is_Pattern_Syntax=	f}', "");
Expect(0, 65094, '\p{Is_Pattern_Syntax=	f}', "");
Expect(1, 65094, '\p{^Is_Pattern_Syntax=	f}', "");
Expect(1, 65094, '\P{Is_Pattern_Syntax=	f}', "");
Expect(0, 65094, '\P{^Is_Pattern_Syntax=	f}', "");
Error('\p{Is_Pat_Syn= :=False}');
Error('\P{Is_Pat_Syn= :=False}');
Expect(1, 65095, '\p{Is_Pat_Syn=false}', "");
Expect(0, 65095, '\p{^Is_Pat_Syn=false}', "");
Expect(0, 65095, '\P{Is_Pat_Syn=false}', "");
Expect(1, 65095, '\P{^Is_Pat_Syn=false}', "");
Expect(0, 65094, '\p{Is_Pat_Syn=false}', "");
Expect(1, 65094, '\p{^Is_Pat_Syn=false}', "");
Expect(1, 65094, '\P{Is_Pat_Syn=false}', "");
Expect(0, 65094, '\P{^Is_Pat_Syn=false}', "");
Expect(1, 65095, '\p{Is_Pat_Syn:   _	false}', "");
Expect(0, 65095, '\p{^Is_Pat_Syn:   _	false}', "");
Expect(0, 65095, '\P{Is_Pat_Syn:   _	false}', "");
Expect(1, 65095, '\P{^Is_Pat_Syn:   _	false}', "");
Expect(0, 65094, '\p{Is_Pat_Syn:   _	false}', "");
Expect(1, 65094, '\p{^Is_Pat_Syn:   _	false}', "");
Expect(1, 65094, '\P{Is_Pat_Syn:   _	false}', "");
Expect(0, 65094, '\P{^Is_Pat_Syn:   _	false}', "");
Error('\p{Pattern_Syntax=/a/	 YES}');
Error('\P{Pattern_Syntax=/a/	 YES}');
Expect(1, 65094, '\p{Pattern_Syntax=yes}', "");
Expect(0, 65094, '\p{^Pattern_Syntax=yes}', "");
Expect(0, 65094, '\P{Pattern_Syntax=yes}', "");
Expect(1, 65094, '\P{^Pattern_Syntax=yes}', "");
Expect(0, 65095, '\p{Pattern_Syntax=yes}', "");
Expect(1, 65095, '\p{^Pattern_Syntax=yes}', "");
Expect(1, 65095, '\P{Pattern_Syntax=yes}', "");
Expect(0, 65095, '\P{^Pattern_Syntax=yes}', "");
Expect(1, 65094, '\p{Pattern_Syntax:	 YES}', "");
Expect(0, 65094, '\p{^Pattern_Syntax:	 YES}', "");
Expect(0, 65094, '\P{Pattern_Syntax:	 YES}', "");
Expect(1, 65094, '\P{^Pattern_Syntax:	 YES}', "");
Expect(0, 65095, '\p{Pattern_Syntax:	 YES}', "");
Expect(1, 65095, '\p{^Pattern_Syntax:	 YES}', "");
Expect(1, 65095, '\P{Pattern_Syntax:	 YES}', "");
Expect(0, 65095, '\P{^Pattern_Syntax:	 YES}', "");
Error('\p{Pat_Syn:  _y:=}');
Error('\P{Pat_Syn:  _y:=}');
Expect(1, 65094, '\p{Pat_Syn=y}', "");
Expect(0, 65094, '\p{^Pat_Syn=y}', "");
Expect(0, 65094, '\P{Pat_Syn=y}', "");
Expect(1, 65094, '\P{^Pat_Syn=y}', "");
Expect(0, 65095, '\p{Pat_Syn=y}', "");
Expect(1, 65095, '\p{^Pat_Syn=y}', "");
Expect(1, 65095, '\P{Pat_Syn=y}', "");
Expect(0, 65095, '\P{^Pat_Syn=y}', "");
Expect(1, 65094, '\p{Pat_Syn=_y}', "");
Expect(0, 65094, '\p{^Pat_Syn=_y}', "");
Expect(0, 65094, '\P{Pat_Syn=_y}', "");
Expect(1, 65094, '\P{^Pat_Syn=_y}', "");
Expect(0, 65095, '\p{Pat_Syn=_y}', "");
Expect(1, 65095, '\p{^Pat_Syn=_y}', "");
Expect(1, 65095, '\P{Pat_Syn=_y}', "");
Expect(0, 65095, '\P{^Pat_Syn=_y}', "");
Error('\p{Is_Pattern_Syntax=/a/_ T}');
Error('\P{Is_Pattern_Syntax=/a/_ T}');
Expect(1, 65094, '\p{Is_Pattern_Syntax=t}', "");
Expect(0, 65094, '\p{^Is_Pattern_Syntax=t}', "");
Expect(0, 65094, '\P{Is_Pattern_Syntax=t}', "");
Expect(1, 65094, '\P{^Is_Pattern_Syntax=t}', "");
Expect(0, 65095, '\p{Is_Pattern_Syntax=t}', "");
Expect(1, 65095, '\p{^Is_Pattern_Syntax=t}', "");
Expect(1, 65095, '\P{Is_Pattern_Syntax=t}', "");
Expect(0, 65095, '\P{^Is_Pattern_Syntax=t}', "");
Expect(1, 65094, '\p{Is_Pattern_Syntax=-_t}', "");
Expect(0, 65094, '\p{^Is_Pattern_Syntax=-_t}', "");
Expect(0, 65094, '\P{Is_Pattern_Syntax=-_t}', "");
Expect(1, 65094, '\P{^Is_Pattern_Syntax=-_t}', "");
Expect(0, 65095, '\p{Is_Pattern_Syntax=-_t}', "");
Expect(1, 65095, '\p{^Is_Pattern_Syntax=-_t}', "");
Expect(1, 65095, '\P{Is_Pattern_Syntax=-_t}', "");
Expect(0, 65095, '\P{^Is_Pattern_Syntax=-_t}', "");
Error('\p{Is_Pat_Syn= 	True:=}');
Error('\P{Is_Pat_Syn= 	True:=}');
Expect(1, 65094, '\p{Is_Pat_Syn=true}', "");
Expect(0, 65094, '\p{^Is_Pat_Syn=true}', "");
Expect(0, 65094, '\P{Is_Pat_Syn=true}', "");
Expect(1, 65094, '\P{^Is_Pat_Syn=true}', "");
Expect(0, 65095, '\p{Is_Pat_Syn=true}', "");
Expect(1, 65095, '\p{^Is_Pat_Syn=true}', "");
Expect(1, 65095, '\P{Is_Pat_Syn=true}', "");
Expect(0, 65095, '\P{^Is_Pat_Syn=true}', "");
Expect(1, 65094, '\p{Is_Pat_Syn= 	true}', "");
Expect(0, 65094, '\p{^Is_Pat_Syn= 	true}', "");
Expect(0, 65094, '\P{Is_Pat_Syn= 	true}', "");
Expect(1, 65094, '\P{^Is_Pat_Syn= 	true}', "");
Expect(0, 65095, '\p{Is_Pat_Syn= 	true}', "");
Expect(1, 65095, '\p{^Is_Pat_Syn= 	true}', "");
Expect(1, 65095, '\P{Is_Pat_Syn= 	true}', "");
Expect(0, 65095, '\P{^Is_Pat_Syn= 	true}', "");
Error('\p{Pattern_White_Space=/a/		no}');
Error('\P{Pattern_White_Space=/a/		no}');
Expect(1, 8234, '\p{Pattern_White_Space=no}', "");
Expect(0, 8234, '\p{^Pattern_White_Space=no}', "");
Expect(0, 8234, '\P{Pattern_White_Space=no}', "");
Expect(1, 8234, '\P{^Pattern_White_Space=no}', "");
Expect(0, 8233, '\p{Pattern_White_Space=no}', "");
Expect(1, 8233, '\p{^Pattern_White_Space=no}', "");
Expect(1, 8233, '\P{Pattern_White_Space=no}', "");
Expect(0, 8233, '\P{^Pattern_White_Space=no}', "");
Expect(1, 8234, '\p{Pattern_White_Space=-No}', "");
Expect(0, 8234, '\p{^Pattern_White_Space=-No}', "");
Expect(0, 8234, '\P{Pattern_White_Space=-No}', "");
Expect(1, 8234, '\P{^Pattern_White_Space=-No}', "");
Expect(0, 8233, '\p{Pattern_White_Space=-No}', "");
Expect(1, 8233, '\p{^Pattern_White_Space=-No}', "");
Expect(1, 8233, '\P{Pattern_White_Space=-No}', "");
Expect(0, 8233, '\P{^Pattern_White_Space=-No}', "");
Error('\p{Pat_WS=		N/a/}');
Error('\P{Pat_WS=		N/a/}');
Expect(1, 8234, '\p{Pat_WS:n}', "");
Expect(0, 8234, '\p{^Pat_WS:n}', "");
Expect(0, 8234, '\P{Pat_WS:n}', "");
Expect(1, 8234, '\P{^Pat_WS:n}', "");
Expect(0, 8233, '\p{Pat_WS:n}', "");
Expect(1, 8233, '\p{^Pat_WS:n}', "");
Expect(1, 8233, '\P{Pat_WS:n}', "");
Expect(0, 8233, '\P{^Pat_WS:n}', "");
Expect(1, 8234, '\p{Pat_WS=	N}', "");
Expect(0, 8234, '\p{^Pat_WS=	N}', "");
Expect(0, 8234, '\P{Pat_WS=	N}', "");
Expect(1, 8234, '\P{^Pat_WS=	N}', "");
Expect(0, 8233, '\p{Pat_WS=	N}', "");
Expect(1, 8233, '\p{^Pat_WS=	N}', "");
Expect(1, 8233, '\P{Pat_WS=	N}', "");
Expect(0, 8233, '\P{^Pat_WS=	N}', "");
Error('\p{Is_Pattern_White_Space= -f/a/}');
Error('\P{Is_Pattern_White_Space= -f/a/}');
Expect(1, 8234, '\p{Is_Pattern_White_Space=f}', "");
Expect(0, 8234, '\p{^Is_Pattern_White_Space=f}', "");
Expect(0, 8234, '\P{Is_Pattern_White_Space=f}', "");
Expect(1, 8234, '\P{^Is_Pattern_White_Space=f}', "");
Expect(0, 8233, '\p{Is_Pattern_White_Space=f}', "");
Expect(1, 8233, '\p{^Is_Pattern_White_Space=f}', "");
Expect(1, 8233, '\P{Is_Pattern_White_Space=f}', "");
Expect(0, 8233, '\P{^Is_Pattern_White_Space=f}', "");
Expect(1, 8234, '\p{Is_Pattern_White_Space=-f}', "");
Expect(0, 8234, '\p{^Is_Pattern_White_Space=-f}', "");
Expect(0, 8234, '\P{Is_Pattern_White_Space=-f}', "");
Expect(1, 8234, '\P{^Is_Pattern_White_Space=-f}', "");
Expect(0, 8233, '\p{Is_Pattern_White_Space=-f}', "");
Expect(1, 8233, '\p{^Is_Pattern_White_Space=-f}', "");
Expect(1, 8233, '\P{Is_Pattern_White_Space=-f}', "");
Expect(0, 8233, '\P{^Is_Pattern_White_Space=-f}', "");
Error('\p{Is_Pat_WS= _false/a/}');
Error('\P{Is_Pat_WS= _false/a/}');
Expect(1, 8234, '\p{Is_Pat_WS=false}', "");
Expect(0, 8234, '\p{^Is_Pat_WS=false}', "");
Expect(0, 8234, '\P{Is_Pat_WS=false}', "");
Expect(1, 8234, '\P{^Is_Pat_WS=false}', "");
Expect(0, 8233, '\p{Is_Pat_WS=false}', "");
Expect(1, 8233, '\p{^Is_Pat_WS=false}', "");
Expect(1, 8233, '\P{Is_Pat_WS=false}', "");
Expect(0, 8233, '\P{^Is_Pat_WS=false}', "");
Expect(1, 8234, '\p{Is_Pat_WS:   - false}', "");
Expect(0, 8234, '\p{^Is_Pat_WS:   - false}', "");
Expect(0, 8234, '\P{Is_Pat_WS:   - false}', "");
Expect(1, 8234, '\P{^Is_Pat_WS:   - false}', "");
Expect(0, 8233, '\p{Is_Pat_WS:   - false}', "");
Expect(1, 8233, '\p{^Is_Pat_WS:   - false}', "");
Expect(1, 8233, '\P{Is_Pat_WS:   - false}', "");
Expect(0, 8233, '\P{^Is_Pat_WS:   - false}', "");
Error('\p{Pattern_White_Space=:= _yes}');
Error('\P{Pattern_White_Space=:= _yes}');
Expect(1, 8233, '\p{Pattern_White_Space=yes}', "");
Expect(0, 8233, '\p{^Pattern_White_Space=yes}', "");
Expect(0, 8233, '\P{Pattern_White_Space=yes}', "");
Expect(1, 8233, '\P{^Pattern_White_Space=yes}', "");
Expect(0, 8234, '\p{Pattern_White_Space=yes}', "");
Expect(1, 8234, '\p{^Pattern_White_Space=yes}', "");
Expect(1, 8234, '\P{Pattern_White_Space=yes}', "");
Expect(0, 8234, '\P{^Pattern_White_Space=yes}', "");
Expect(1, 8233, '\p{Pattern_White_Space=__Yes}', "");
Expect(0, 8233, '\p{^Pattern_White_Space=__Yes}', "");
Expect(0, 8233, '\P{Pattern_White_Space=__Yes}', "");
Expect(1, 8233, '\P{^Pattern_White_Space=__Yes}', "");
Expect(0, 8234, '\p{Pattern_White_Space=__Yes}', "");
Expect(1, 8234, '\p{^Pattern_White_Space=__Yes}', "");
Expect(1, 8234, '\P{Pattern_White_Space=__Yes}', "");
Expect(0, 8234, '\P{^Pattern_White_Space=__Yes}', "");
Error('\p{Pat_WS: :=_Y}');
Error('\P{Pat_WS: :=_Y}');
Expect(1, 8233, '\p{Pat_WS=y}', "");
Expect(0, 8233, '\p{^Pat_WS=y}', "");
Expect(0, 8233, '\P{Pat_WS=y}', "");
Expect(1, 8233, '\P{^Pat_WS=y}', "");
Expect(0, 8234, '\p{Pat_WS=y}', "");
Expect(1, 8234, '\p{^Pat_WS=y}', "");
Expect(1, 8234, '\P{Pat_WS=y}', "");
Expect(0, 8234, '\P{^Pat_WS=y}', "");
Expect(1, 8233, '\p{Pat_WS=	Y}', "");
Expect(0, 8233, '\p{^Pat_WS=	Y}', "");
Expect(0, 8233, '\P{Pat_WS=	Y}', "");
Expect(1, 8233, '\P{^Pat_WS=	Y}', "");
Expect(0, 8234, '\p{Pat_WS=	Y}', "");
Expect(1, 8234, '\p{^Pat_WS=	Y}', "");
Expect(1, 8234, '\P{Pat_WS=	Y}', "");
Expect(0, 8234, '\P{^Pat_WS=	Y}', "");
Error('\p{Is_Pattern_White_Space: -:=T}');
Error('\P{Is_Pattern_White_Space: -:=T}');
Expect(1, 8233, '\p{Is_Pattern_White_Space=t}', "");
Expect(0, 8233, '\p{^Is_Pattern_White_Space=t}', "");
Expect(0, 8233, '\P{Is_Pattern_White_Space=t}', "");
Expect(1, 8233, '\P{^Is_Pattern_White_Space=t}', "");
Expect(0, 8234, '\p{Is_Pattern_White_Space=t}', "");
Expect(1, 8234, '\p{^Is_Pattern_White_Space=t}', "");
Expect(1, 8234, '\P{Is_Pattern_White_Space=t}', "");
Expect(0, 8234, '\P{^Is_Pattern_White_Space=t}', "");
Expect(1, 8233, '\p{Is_Pattern_White_Space=-T}', "");
Expect(0, 8233, '\p{^Is_Pattern_White_Space=-T}', "");
Expect(0, 8233, '\P{Is_Pattern_White_Space=-T}', "");
Expect(1, 8233, '\P{^Is_Pattern_White_Space=-T}', "");
Expect(0, 8234, '\p{Is_Pattern_White_Space=-T}', "");
Expect(1, 8234, '\p{^Is_Pattern_White_Space=-T}', "");
Expect(1, 8234, '\P{Is_Pattern_White_Space=-T}', "");
Expect(0, 8234, '\P{^Is_Pattern_White_Space=-T}', "");
Error('\p{Is_Pat_WS=_True:=}');
Error('\P{Is_Pat_WS=_True:=}');
Expect(1, 8233, '\p{Is_Pat_WS=true}', "");
Expect(0, 8233, '\p{^Is_Pat_WS=true}', "");
Expect(0, 8233, '\P{Is_Pat_WS=true}', "");
Expect(1, 8233, '\P{^Is_Pat_WS=true}', "");
Expect(0, 8234, '\p{Is_Pat_WS=true}', "");
Expect(1, 8234, '\p{^Is_Pat_WS=true}', "");
Expect(1, 8234, '\P{Is_Pat_WS=true}', "");
Expect(0, 8234, '\P{^Is_Pat_WS=true}', "");
Expect(1, 8233, '\p{Is_Pat_WS= -true}', "");
Expect(0, 8233, '\p{^Is_Pat_WS= -true}', "");
Expect(0, 8233, '\P{Is_Pat_WS= -true}', "");
Expect(1, 8233, '\P{^Is_Pat_WS= -true}', "");
Expect(0, 8234, '\p{Is_Pat_WS= -true}', "");
Expect(1, 8234, '\p{^Is_Pat_WS= -true}', "");
Expect(1, 8234, '\P{Is_Pat_WS= -true}', "");
Expect(0, 8234, '\P{^Is_Pat_WS= -true}', "");
Error('\p{Quotation_Mark=_NO:=}');
Error('\P{Quotation_Mark=_NO:=}');
Expect(1, 65380, '\p{Quotation_Mark=no}', "");
Expect(0, 65380, '\p{^Quotation_Mark=no}', "");
Expect(0, 65380, '\P{Quotation_Mark=no}', "");
Expect(1, 65380, '\P{^Quotation_Mark=no}', "");
Expect(0, 65379, '\p{Quotation_Mark=no}', "");
Expect(1, 65379, '\p{^Quotation_Mark=no}', "");
Expect(1, 65379, '\P{Quotation_Mark=no}', "");
Expect(0, 65379, '\P{^Quotation_Mark=no}', "");
Expect(1, 65380, '\p{Quotation_Mark= 	NO}', "");
Expect(0, 65380, '\p{^Quotation_Mark= 	NO}', "");
Expect(0, 65380, '\P{Quotation_Mark= 	NO}', "");
Expect(1, 65380, '\P{^Quotation_Mark= 	NO}', "");
Expect(0, 65379, '\p{Quotation_Mark= 	NO}', "");
Expect(1, 65379, '\p{^Quotation_Mark= 	NO}', "");
Expect(1, 65379, '\P{Quotation_Mark= 	NO}', "");
Expect(0, 65379, '\P{^Quotation_Mark= 	NO}', "");
Error('\p{QMark:	-N/a/}');
Error('\P{QMark:	-N/a/}');
Expect(1, 65380, '\p{QMark:	n}', "");
Expect(0, 65380, '\p{^QMark:	n}', "");
Expect(0, 65380, '\P{QMark:	n}', "");
Expect(1, 65380, '\P{^QMark:	n}', "");
Expect(0, 65379, '\p{QMark:	n}', "");
Expect(1, 65379, '\p{^QMark:	n}', "");
Expect(1, 65379, '\P{QMark:	n}', "");
Expect(0, 65379, '\P{^QMark:	n}', "");
Expect(1, 65380, '\p{QMark=N}', "");
Expect(0, 65380, '\p{^QMark=N}', "");
Expect(0, 65380, '\P{QMark=N}', "");
Expect(1, 65380, '\P{^QMark=N}', "");
Expect(0, 65379, '\p{QMark=N}', "");
Expect(1, 65379, '\p{^QMark=N}', "");
Expect(1, 65379, '\P{QMark=N}', "");
Expect(0, 65379, '\P{^QMark=N}', "");
Error('\p{Is_Quotation_Mark=-:=F}');
Error('\P{Is_Quotation_Mark=-:=F}');
Expect(1, 65380, '\p{Is_Quotation_Mark=f}', "");
Expect(0, 65380, '\p{^Is_Quotation_Mark=f}', "");
Expect(0, 65380, '\P{Is_Quotation_Mark=f}', "");
Expect(1, 65380, '\P{^Is_Quotation_Mark=f}', "");
Expect(0, 65379, '\p{Is_Quotation_Mark=f}', "");
Expect(1, 65379, '\p{^Is_Quotation_Mark=f}', "");
Expect(1, 65379, '\P{Is_Quotation_Mark=f}', "");
Expect(0, 65379, '\P{^Is_Quotation_Mark=f}', "");
Expect(1, 65380, '\p{Is_Quotation_Mark: _F}', "");
Expect(0, 65380, '\p{^Is_Quotation_Mark: _F}', "");
Expect(0, 65380, '\P{Is_Quotation_Mark: _F}', "");
Expect(1, 65380, '\P{^Is_Quotation_Mark: _F}', "");
Expect(0, 65379, '\p{Is_Quotation_Mark: _F}', "");
Expect(1, 65379, '\p{^Is_Quotation_Mark: _F}', "");
Expect(1, 65379, '\P{Is_Quotation_Mark: _F}', "");
Expect(0, 65379, '\P{^Is_Quotation_Mark: _F}', "");
Error('\p{Is_QMark=:=false}');
Error('\P{Is_QMark=:=false}');
Expect(1, 65380, '\p{Is_QMark:	false}', "");
Expect(0, 65380, '\p{^Is_QMark:	false}', "");
Expect(0, 65380, '\P{Is_QMark:	false}', "");
Expect(1, 65380, '\P{^Is_QMark:	false}', "");
Expect(0, 65379, '\p{Is_QMark:	false}', "");
Expect(1, 65379, '\p{^Is_QMark:	false}', "");
Expect(1, 65379, '\P{Is_QMark:	false}', "");
Expect(0, 65379, '\P{^Is_QMark:	false}', "");
Expect(1, 65380, '\p{Is_QMark: 		False}', "");
Expect(0, 65380, '\p{^Is_QMark: 		False}', "");
Expect(0, 65380, '\P{Is_QMark: 		False}', "");
Expect(1, 65380, '\P{^Is_QMark: 		False}', "");
Expect(0, 65379, '\p{Is_QMark: 		False}', "");
Expect(1, 65379, '\p{^Is_QMark: 		False}', "");
Expect(1, 65379, '\P{Is_QMark: 		False}', "");
Expect(0, 65379, '\P{^Is_QMark: 		False}', "");
Error('\p{Quotation_Mark=	YES:=}');
Error('\P{Quotation_Mark=	YES:=}');
Expect(1, 65379, '\p{Quotation_Mark: yes}', "");
Expect(0, 65379, '\p{^Quotation_Mark: yes}', "");
Expect(0, 65379, '\P{Quotation_Mark: yes}', "");
Expect(1, 65379, '\P{^Quotation_Mark: yes}', "");
Expect(0, 65380, '\p{Quotation_Mark: yes}', "");
Expect(1, 65380, '\p{^Quotation_Mark: yes}', "");
Expect(1, 65380, '\P{Quotation_Mark: yes}', "");
Expect(0, 65380, '\P{^Quotation_Mark: yes}', "");
Expect(1, 65379, '\p{Quotation_Mark=		Yes}', "");
Expect(0, 65379, '\p{^Quotation_Mark=		Yes}', "");
Expect(0, 65379, '\P{Quotation_Mark=		Yes}', "");
Expect(1, 65379, '\P{^Quotation_Mark=		Yes}', "");
Expect(0, 65380, '\p{Quotation_Mark=		Yes}', "");
Expect(1, 65380, '\p{^Quotation_Mark=		Yes}', "");
Expect(1, 65380, '\P{Quotation_Mark=		Yes}', "");
Expect(0, 65380, '\P{^Quotation_Mark=		Yes}', "");
Error('\p{QMark=/a/- Y}');
Error('\P{QMark=/a/- Y}');
Expect(1, 65379, '\p{QMark=y}', "");
Expect(0, 65379, '\p{^QMark=y}', "");
Expect(0, 65379, '\P{QMark=y}', "");
Expect(1, 65379, '\P{^QMark=y}', "");
Expect(0, 65380, '\p{QMark=y}', "");
Expect(1, 65380, '\p{^QMark=y}', "");
Expect(1, 65380, '\P{QMark=y}', "");
Expect(0, 65380, '\P{^QMark=y}', "");
Error('\p{Is_Quotation_Mark=:=-_T}');
Error('\P{Is_Quotation_Mark=:=-_T}');
Expect(1, 65379, '\p{Is_Quotation_Mark=t}', "");
Expect(0, 65379, '\p{^Is_Quotation_Mark=t}', "");
Expect(0, 65379, '\P{Is_Quotation_Mark=t}', "");
Expect(1, 65379, '\P{^Is_Quotation_Mark=t}', "");
Expect(0, 65380, '\p{Is_Quotation_Mark=t}', "");
Expect(1, 65380, '\p{^Is_Quotation_Mark=t}', "");
Expect(1, 65380, '\P{Is_Quotation_Mark=t}', "");
Expect(0, 65380, '\P{^Is_Quotation_Mark=t}', "");
Expect(1, 65379, '\p{Is_Quotation_Mark= _T}', "");
Expect(0, 65379, '\p{^Is_Quotation_Mark= _T}', "");
Expect(0, 65379, '\P{Is_Quotation_Mark= _T}', "");
Expect(1, 65379, '\P{^Is_Quotation_Mark= _T}', "");
Expect(0, 65380, '\p{Is_Quotation_Mark= _T}', "");
Expect(1, 65380, '\p{^Is_Quotation_Mark= _T}', "");
Expect(1, 65380, '\P{Is_Quotation_Mark= _T}', "");
Expect(0, 65380, '\P{^Is_Quotation_Mark= _T}', "");
Error('\p{Is_QMark= _True:=}');
Error('\P{Is_QMark= _True:=}');
Expect(1, 65379, '\p{Is_QMark=true}', "");
Expect(0, 65379, '\p{^Is_QMark=true}', "");
Expect(0, 65379, '\P{Is_QMark=true}', "");
Expect(1, 65379, '\P{^Is_QMark=true}', "");
Expect(0, 65380, '\p{Is_QMark=true}', "");
Expect(1, 65380, '\p{^Is_QMark=true}', "");
Expect(1, 65380, '\P{Is_QMark=true}', "");
Expect(0, 65380, '\P{^Is_QMark=true}', "");
Expect(1, 65379, '\p{Is_QMark=_-True}', "");
Expect(0, 65379, '\p{^Is_QMark=_-True}', "");
Expect(0, 65379, '\P{Is_QMark=_-True}', "");
Expect(1, 65379, '\P{^Is_QMark=_-True}', "");
Expect(0, 65380, '\p{Is_QMark=_-True}', "");
Expect(1, 65380, '\p{^Is_QMark=_-True}', "");
Expect(1, 65380, '\P{Is_QMark=_-True}', "");
Expect(0, 65380, '\P{^Is_QMark=_-True}', "");
Error('\p{Radical=	No:=}');
Error('\P{Radical=	No:=}');
Expect(1, 12246, '\p{Radical=no}', "");
Expect(0, 12246, '\p{^Radical=no}', "");
Expect(0, 12246, '\P{Radical=no}', "");
Expect(1, 12246, '\P{^Radical=no}', "");
Expect(0, 12245, '\p{Radical=no}', "");
Expect(1, 12245, '\p{^Radical=no}', "");
Expect(1, 12245, '\P{Radical=no}', "");
Expect(0, 12245, '\P{^Radical=no}', "");
Expect(1, 12246, '\p{Radical:   No}', "");
Expect(0, 12246, '\p{^Radical:   No}', "");
Expect(0, 12246, '\P{Radical:   No}', "");
Expect(1, 12246, '\P{^Radical:   No}', "");
Expect(0, 12245, '\p{Radical:   No}', "");
Expect(1, 12245, '\p{^Radical:   No}', "");
Expect(1, 12245, '\P{Radical:   No}', "");
Expect(0, 12245, '\P{^Radical:   No}', "");
Error('\p{Is_Radical= :=N}');
Error('\P{Is_Radical= :=N}');
Expect(1, 12246, '\p{Is_Radical=n}', "");
Expect(0, 12246, '\p{^Is_Radical=n}', "");
Expect(0, 12246, '\P{Is_Radical=n}', "");
Expect(1, 12246, '\P{^Is_Radical=n}', "");
Expect(0, 12245, '\p{Is_Radical=n}', "");
Expect(1, 12245, '\p{^Is_Radical=n}', "");
Expect(1, 12245, '\P{Is_Radical=n}', "");
Expect(0, 12245, '\P{^Is_Radical=n}', "");
Expect(1, 12246, '\p{Is_Radical= 	N}', "");
Expect(0, 12246, '\p{^Is_Radical= 	N}', "");
Expect(0, 12246, '\P{Is_Radical= 	N}', "");
Expect(1, 12246, '\P{^Is_Radical= 	N}', "");
Expect(0, 12245, '\p{Is_Radical= 	N}', "");
Expect(1, 12245, '\p{^Is_Radical= 	N}', "");
Expect(1, 12245, '\P{Is_Radical= 	N}', "");
Expect(0, 12245, '\P{^Is_Radical= 	N}', "");
Error('\p{Radical= -f/a/}');
Error('\P{Radical= -f/a/}');
Expect(1, 12246, '\p{Radical=f}', "");
Expect(0, 12246, '\p{^Radical=f}', "");
Expect(0, 12246, '\P{Radical=f}', "");
Expect(1, 12246, '\P{^Radical=f}', "");
Expect(0, 12245, '\p{Radical=f}', "");
Expect(1, 12245, '\p{^Radical=f}', "");
Expect(1, 12245, '\P{Radical=f}', "");
Expect(0, 12245, '\P{^Radical=f}', "");
Expect(1, 12246, '\p{Radical=__F}', "");
Expect(0, 12246, '\p{^Radical=__F}', "");
Expect(0, 12246, '\P{Radical=__F}', "");
Expect(1, 12246, '\P{^Radical=__F}', "");
Expect(0, 12245, '\p{Radical=__F}', "");
Expect(1, 12245, '\p{^Radical=__F}', "");
Expect(1, 12245, '\P{Radical=__F}', "");
Expect(0, 12245, '\P{^Radical=__F}', "");
Error('\p{Is_Radical=-_FALSE:=}');
Error('\P{Is_Radical=-_FALSE:=}');
Expect(1, 12246, '\p{Is_Radical=false}', "");
Expect(0, 12246, '\p{^Is_Radical=false}', "");
Expect(0, 12246, '\P{Is_Radical=false}', "");
Expect(1, 12246, '\P{^Is_Radical=false}', "");
Expect(0, 12245, '\p{Is_Radical=false}', "");
Expect(1, 12245, '\p{^Is_Radical=false}', "");
Expect(1, 12245, '\P{Is_Radical=false}', "");
Expect(0, 12245, '\P{^Is_Radical=false}', "");
Expect(1, 12246, '\p{Is_Radical=		False}', "");
Expect(0, 12246, '\p{^Is_Radical=		False}', "");
Expect(0, 12246, '\P{Is_Radical=		False}', "");
Expect(1, 12246, '\P{^Is_Radical=		False}', "");
Expect(0, 12245, '\p{Is_Radical=		False}', "");
Expect(1, 12245, '\p{^Is_Radical=		False}', "");
Expect(1, 12245, '\P{Is_Radical=		False}', "");
Expect(0, 12245, '\P{^Is_Radical=		False}', "");
Error('\p{Radical=	-yes:=}');
Error('\P{Radical=	-yes:=}');
Expect(1, 12245, '\p{Radical:yes}', "");
Expect(0, 12245, '\p{^Radical:yes}', "");
Expect(0, 12245, '\P{Radical:yes}', "");
Expect(1, 12245, '\P{^Radical:yes}', "");
Expect(0, 12246, '\p{Radical:yes}', "");
Expect(1, 12246, '\p{^Radical:yes}', "");
Expect(1, 12246, '\P{Radical:yes}', "");
Expect(0, 12246, '\P{^Radical:yes}', "");
Expect(1, 12245, '\p{Radical=	yes}', "");
Expect(0, 12245, '\p{^Radical=	yes}', "");
Expect(0, 12245, '\P{Radical=	yes}', "");
Expect(1, 12245, '\P{^Radical=	yes}', "");
Expect(0, 12246, '\p{Radical=	yes}', "");
Expect(1, 12246, '\p{^Radical=	yes}', "");
Expect(1, 12246, '\P{Radical=	yes}', "");
Expect(0, 12246, '\P{^Radical=	yes}', "");
Error('\p{Is_Radical=/a/-	Y}');
Error('\P{Is_Radical=/a/-	Y}');
Expect(1, 12245, '\p{Is_Radical=y}', "");
Expect(0, 12245, '\p{^Is_Radical=y}', "");
Expect(0, 12245, '\P{Is_Radical=y}', "");
Expect(1, 12245, '\P{^Is_Radical=y}', "");
Expect(0, 12246, '\p{Is_Radical=y}', "");
Expect(1, 12246, '\p{^Is_Radical=y}', "");
Expect(1, 12246, '\P{Is_Radical=y}', "");
Expect(0, 12246, '\P{^Is_Radical=y}', "");
Expect(1, 12245, '\p{Is_Radical=-y}', "");
Expect(0, 12245, '\p{^Is_Radical=-y}', "");
Expect(0, 12245, '\P{Is_Radical=-y}', "");
Expect(1, 12245, '\P{^Is_Radical=-y}', "");
Expect(0, 12246, '\p{Is_Radical=-y}', "");
Expect(1, 12246, '\p{^Is_Radical=-y}', "");
Expect(1, 12246, '\P{Is_Radical=-y}', "");
Expect(0, 12246, '\P{^Is_Radical=-y}', "");
Error('\p{Radical=-_T:=}');
Error('\P{Radical=-_T:=}');
Expect(1, 12245, '\p{Radical=t}', "");
Expect(0, 12245, '\p{^Radical=t}', "");
Expect(0, 12245, '\P{Radical=t}', "");
Expect(1, 12245, '\P{^Radical=t}', "");
Expect(0, 12246, '\p{Radical=t}', "");
Expect(1, 12246, '\p{^Radical=t}', "");
Expect(1, 12246, '\P{Radical=t}', "");
Expect(0, 12246, '\P{^Radical=t}', "");
Expect(1, 12245, '\p{Radical:-_T}', "");
Expect(0, 12245, '\p{^Radical:-_T}', "");
Expect(0, 12245, '\P{Radical:-_T}', "");
Expect(1, 12245, '\P{^Radical:-_T}', "");
Expect(0, 12246, '\p{Radical:-_T}', "");
Expect(1, 12246, '\p{^Radical:-_T}', "");
Expect(1, 12246, '\P{Radical:-_T}', "");
Expect(0, 12246, '\P{^Radical:-_T}', "");
Error('\p{Is_Radical=/a/-TRUE}');
Error('\P{Is_Radical=/a/-TRUE}');
Expect(1, 12245, '\p{Is_Radical=true}', "");
Expect(0, 12245, '\p{^Is_Radical=true}', "");
Expect(0, 12245, '\P{Is_Radical=true}', "");
Expect(1, 12245, '\P{^Is_Radical=true}', "");
Expect(0, 12246, '\p{Is_Radical=true}', "");
Expect(1, 12246, '\p{^Is_Radical=true}', "");
Expect(1, 12246, '\P{Is_Radical=true}', "");
Expect(0, 12246, '\P{^Is_Radical=true}', "");
Expect(1, 12245, '\p{Is_Radical=	true}', "");
Expect(0, 12245, '\p{^Is_Radical=	true}', "");
Expect(0, 12245, '\P{Is_Radical=	true}', "");
Expect(1, 12245, '\P{^Is_Radical=	true}', "");
Expect(0, 12246, '\p{Is_Radical=	true}', "");
Expect(1, 12246, '\p{^Is_Radical=	true}', "");
Expect(1, 12246, '\P{Is_Radical=	true}', "");
Expect(0, 12246, '\P{^Is_Radical=	true}', "");
Error('\p{Sentence_Break= /a/aterm}');
Error('\P{Sentence_Break= /a/aterm}');
Expect(1, 65294, '\p{Sentence_Break=aterm}', "");
Expect(0, 65294, '\p{^Sentence_Break=aterm}', "");
Expect(0, 65294, '\P{Sentence_Break=aterm}', "");
Expect(1, 65294, '\P{^Sentence_Break=aterm}', "");
Expect(0, 65295, '\p{Sentence_Break=aterm}', "");
Expect(1, 65295, '\p{^Sentence_Break=aterm}', "");
Expect(1, 65295, '\P{Sentence_Break=aterm}', "");
Expect(0, 65295, '\P{^Sentence_Break=aterm}', "");
Expect(1, 65294, '\p{Sentence_Break=-ATERM}', "");
Expect(0, 65294, '\p{^Sentence_Break=-ATERM}', "");
Expect(0, 65294, '\P{Sentence_Break=-ATERM}', "");
Expect(1, 65294, '\P{^Sentence_Break=-ATERM}', "");
Expect(0, 65295, '\p{Sentence_Break=-ATERM}', "");
Expect(1, 65295, '\p{^Sentence_Break=-ATERM}', "");
Expect(1, 65295, '\P{Sentence_Break=-ATERM}', "");
Expect(0, 65295, '\P{^Sentence_Break=-ATERM}', "");
Error('\p{SB: -	AT/a/}');
Error('\P{SB: -	AT/a/}');
Expect(1, 65294, '\p{SB=at}', "");
Expect(0, 65294, '\p{^SB=at}', "");
Expect(0, 65294, '\P{SB=at}', "");
Expect(1, 65294, '\P{^SB=at}', "");
Expect(0, 65295, '\p{SB=at}', "");
Expect(1, 65295, '\p{^SB=at}', "");
Expect(1, 65295, '\P{SB=at}', "");
Expect(0, 65295, '\P{^SB=at}', "");
Expect(1, 65294, '\p{SB= -at}', "");
Expect(0, 65294, '\p{^SB= -at}', "");
Expect(0, 65294, '\P{SB= -at}', "");
Expect(1, 65294, '\P{^SB= -at}', "");
Expect(0, 65295, '\p{SB= -at}', "");
Expect(1, 65295, '\p{^SB= -at}', "");
Expect(1, 65295, '\P{SB= -at}', "");
Expect(0, 65295, '\P{^SB= -at}', "");
Error('\p{Is_Sentence_Break=:=-	ATerm}');
Error('\P{Is_Sentence_Break=:=-	ATerm}');
Expect(1, 65294, '\p{Is_Sentence_Break=aterm}', "");
Expect(0, 65294, '\p{^Is_Sentence_Break=aterm}', "");
Expect(0, 65294, '\P{Is_Sentence_Break=aterm}', "");
Expect(1, 65294, '\P{^Is_Sentence_Break=aterm}', "");
Expect(0, 65295, '\p{Is_Sentence_Break=aterm}', "");
Expect(1, 65295, '\p{^Is_Sentence_Break=aterm}', "");
Expect(1, 65295, '\P{Is_Sentence_Break=aterm}', "");
Expect(0, 65295, '\P{^Is_Sentence_Break=aterm}', "");
Expect(1, 65294, '\p{Is_Sentence_Break=  aterm}', "");
Expect(0, 65294, '\p{^Is_Sentence_Break=  aterm}', "");
Expect(0, 65294, '\P{Is_Sentence_Break=  aterm}', "");
Expect(1, 65294, '\P{^Is_Sentence_Break=  aterm}', "");
Expect(0, 65295, '\p{Is_Sentence_Break=  aterm}', "");
Expect(1, 65295, '\p{^Is_Sentence_Break=  aterm}', "");
Expect(1, 65295, '\P{Is_Sentence_Break=  aterm}', "");
Expect(0, 65295, '\P{^Is_Sentence_Break=  aterm}', "");
Error('\p{Is_SB=	:=AT}');
Error('\P{Is_SB=	:=AT}');
Expect(1, 65294, '\p{Is_SB=at}', "");
Expect(0, 65294, '\p{^Is_SB=at}', "");
Expect(0, 65294, '\P{Is_SB=at}', "");
Expect(1, 65294, '\P{^Is_SB=at}', "");
Expect(0, 65295, '\p{Is_SB=at}', "");
Expect(1, 65295, '\p{^Is_SB=at}', "");
Expect(1, 65295, '\P{Is_SB=at}', "");
Expect(0, 65295, '\P{^Is_SB=at}', "");
Expect(1, 65294, '\p{Is_SB= -AT}', "");
Expect(0, 65294, '\p{^Is_SB= -AT}', "");
Expect(0, 65294, '\P{Is_SB= -AT}', "");
Expect(1, 65294, '\P{^Is_SB= -AT}', "");
Expect(0, 65295, '\p{Is_SB= -AT}', "");
Expect(1, 65295, '\p{^Is_SB= -AT}', "");
Expect(1, 65295, '\P{Is_SB= -AT}', "");
Expect(0, 65295, '\P{^Is_SB= -AT}', "");
Error('\p{Sentence_Break:/a/--Close}');
Error('\P{Sentence_Break:/a/--Close}');
Expect(1, 65379, '\p{Sentence_Break=close}', "");
Expect(0, 65379, '\p{^Sentence_Break=close}', "");
Expect(0, 65379, '\P{Sentence_Break=close}', "");
Expect(1, 65379, '\P{^Sentence_Break=close}', "");
Expect(0, 65380, '\p{Sentence_Break=close}', "");
Expect(1, 65380, '\p{^Sentence_Break=close}', "");
Expect(1, 65380, '\P{Sentence_Break=close}', "");
Expect(0, 65380, '\P{^Sentence_Break=close}', "");
Expect(1, 65379, '\p{Sentence_Break=Close}', "");
Expect(0, 65379, '\p{^Sentence_Break=Close}', "");
Expect(0, 65379, '\P{Sentence_Break=Close}', "");
Expect(1, 65379, '\P{^Sentence_Break=Close}', "");
Expect(0, 65380, '\p{Sentence_Break=Close}', "");
Expect(1, 65380, '\p{^Sentence_Break=Close}', "");
Expect(1, 65380, '\P{Sentence_Break=Close}', "");
Expect(0, 65380, '\P{^Sentence_Break=Close}', "");
Error('\p{SB=:= _CL}');
Error('\P{SB=:= _CL}');
Expect(1, 65379, '\p{SB=cl}', "");
Expect(0, 65379, '\p{^SB=cl}', "");
Expect(0, 65379, '\P{SB=cl}', "");
Expect(1, 65379, '\P{^SB=cl}', "");
Expect(0, 65380, '\p{SB=cl}', "");
Expect(1, 65380, '\p{^SB=cl}', "");
Expect(1, 65380, '\P{SB=cl}', "");
Expect(0, 65380, '\P{^SB=cl}', "");
Expect(1, 65379, '\p{SB=	_CL}', "");
Expect(0, 65379, '\p{^SB=	_CL}', "");
Expect(0, 65379, '\P{SB=	_CL}', "");
Expect(1, 65379, '\P{^SB=	_CL}', "");
Expect(0, 65380, '\p{SB=	_CL}', "");
Expect(1, 65380, '\p{^SB=	_CL}', "");
Expect(1, 65380, '\P{SB=	_CL}', "");
Expect(0, 65380, '\P{^SB=	_CL}', "");
Error('\p{Is_Sentence_Break=:=	 CLOSE}');
Error('\P{Is_Sentence_Break=:=	 CLOSE}');
Expect(1, 65379, '\p{Is_Sentence_Break:	close}', "");
Expect(0, 65379, '\p{^Is_Sentence_Break:	close}', "");
Expect(0, 65379, '\P{Is_Sentence_Break:	close}', "");
Expect(1, 65379, '\P{^Is_Sentence_Break:	close}', "");
Expect(0, 65380, '\p{Is_Sentence_Break:	close}', "");
Expect(1, 65380, '\p{^Is_Sentence_Break:	close}', "");
Expect(1, 65380, '\P{Is_Sentence_Break:	close}', "");
Expect(0, 65380, '\P{^Is_Sentence_Break:	close}', "");
Expect(1, 65379, '\p{Is_Sentence_Break=_Close}', "");
Expect(0, 65379, '\p{^Is_Sentence_Break=_Close}', "");
Expect(0, 65379, '\P{Is_Sentence_Break=_Close}', "");
Expect(1, 65379, '\P{^Is_Sentence_Break=_Close}', "");
Expect(0, 65380, '\p{Is_Sentence_Break=_Close}', "");
Expect(1, 65380, '\p{^Is_Sentence_Break=_Close}', "");
Expect(1, 65380, '\P{Is_Sentence_Break=_Close}', "");
Expect(0, 65380, '\P{^Is_Sentence_Break=_Close}', "");
Error('\p{Is_SB=-:=cl}');
Error('\P{Is_SB=-:=cl}');
Expect(1, 65379, '\p{Is_SB=cl}', "");
Expect(0, 65379, '\p{^Is_SB=cl}', "");
Expect(0, 65379, '\P{Is_SB=cl}', "");
Expect(1, 65379, '\P{^Is_SB=cl}', "");
Expect(0, 65380, '\p{Is_SB=cl}', "");
Expect(1, 65380, '\p{^Is_SB=cl}', "");
Expect(1, 65380, '\P{Is_SB=cl}', "");
Expect(0, 65380, '\P{^Is_SB=cl}', "");
Expect(1, 65379, '\p{Is_SB=  cl}', "");
Expect(0, 65379, '\p{^Is_SB=  cl}', "");
Expect(0, 65379, '\P{Is_SB=  cl}', "");
Expect(1, 65379, '\P{^Is_SB=  cl}', "");
Expect(0, 65380, '\p{Is_SB=  cl}', "");
Expect(1, 65380, '\p{^Is_SB=  cl}', "");
Expect(1, 65380, '\P{Is_SB=  cl}', "");
Expect(0, 65380, '\P{^Is_SB=  cl}', "");
Error('\p{Sentence_Break=	:=CR}');
Error('\P{Sentence_Break=	:=CR}');
Expect(1, 13, '\p{Sentence_Break=cr}', "");
Expect(0, 13, '\p{^Sentence_Break=cr}', "");
Expect(0, 13, '\P{Sentence_Break=cr}', "");
Expect(1, 13, '\P{^Sentence_Break=cr}', "");
Expect(0, 14, '\p{Sentence_Break=cr}', "");
Expect(1, 14, '\p{^Sentence_Break=cr}', "");
Expect(1, 14, '\P{Sentence_Break=cr}', "");
Expect(0, 14, '\P{^Sentence_Break=cr}', "");
Expect(1, 13, '\p{Sentence_Break=-CR}', "");
Expect(0, 13, '\p{^Sentence_Break=-CR}', "");
Expect(0, 13, '\P{Sentence_Break=-CR}', "");
Expect(1, 13, '\P{^Sentence_Break=-CR}', "");
Expect(0, 14, '\p{Sentence_Break=-CR}', "");
Expect(1, 14, '\p{^Sentence_Break=-CR}', "");
Expect(1, 14, '\P{Sentence_Break=-CR}', "");
Expect(0, 14, '\P{^Sentence_Break=-CR}', "");
Error('\p{SB: 	/a/CR}');
Error('\P{SB: 	/a/CR}');
Expect(1, 13, '\p{SB=cr}', "");
Expect(0, 13, '\p{^SB=cr}', "");
Expect(0, 13, '\P{SB=cr}', "");
Expect(1, 13, '\P{^SB=cr}', "");
Expect(0, 14, '\p{SB=cr}', "");
Expect(1, 14, '\p{^SB=cr}', "");
Expect(1, 14, '\P{SB=cr}', "");
Expect(0, 14, '\P{^SB=cr}', "");
Expect(1, 13, '\p{SB:	_ cr}', "");
Expect(0, 13, '\p{^SB:	_ cr}', "");
Expect(0, 13, '\P{SB:	_ cr}', "");
Expect(1, 13, '\P{^SB:	_ cr}', "");
Expect(0, 14, '\p{SB:	_ cr}', "");
Expect(1, 14, '\p{^SB:	_ cr}', "");
Expect(1, 14, '\P{SB:	_ cr}', "");
Expect(0, 14, '\P{^SB:	_ cr}', "");
Error('\p{Is_Sentence_Break=		CR:=}');
Error('\P{Is_Sentence_Break=		CR:=}');
Expect(1, 13, '\p{Is_Sentence_Break=cr}', "");
Expect(0, 13, '\p{^Is_Sentence_Break=cr}', "");
Expect(0, 13, '\P{Is_Sentence_Break=cr}', "");
Expect(1, 13, '\P{^Is_Sentence_Break=cr}', "");
Expect(0, 14, '\p{Is_Sentence_Break=cr}', "");
Expect(1, 14, '\p{^Is_Sentence_Break=cr}', "");
Expect(1, 14, '\P{Is_Sentence_Break=cr}', "");
Expect(0, 14, '\P{^Is_Sentence_Break=cr}', "");
Expect(1, 13, '\p{Is_Sentence_Break=--CR}', "");
Expect(0, 13, '\p{^Is_Sentence_Break=--CR}', "");
Expect(0, 13, '\P{Is_Sentence_Break=--CR}', "");
Expect(1, 13, '\P{^Is_Sentence_Break=--CR}', "");
Expect(0, 14, '\p{Is_Sentence_Break=--CR}', "");
Expect(1, 14, '\p{^Is_Sentence_Break=--CR}', "");
Expect(1, 14, '\P{Is_Sentence_Break=--CR}', "");
Expect(0, 14, '\P{^Is_Sentence_Break=--CR}', "");
Error('\p{Is_SB=/a/ 	CR}');
Error('\P{Is_SB=/a/ 	CR}');
Expect(1, 13, '\p{Is_SB=cr}', "");
Expect(0, 13, '\p{^Is_SB=cr}', "");
Expect(0, 13, '\P{Is_SB=cr}', "");
Expect(1, 13, '\P{^Is_SB=cr}', "");
Expect(0, 14, '\p{Is_SB=cr}', "");
Expect(1, 14, '\p{^Is_SB=cr}', "");
Expect(1, 14, '\P{Is_SB=cr}', "");
Expect(0, 14, '\P{^Is_SB=cr}', "");
Expect(1, 13, '\p{Is_SB= 	CR}', "");
Expect(0, 13, '\p{^Is_SB= 	CR}', "");
Expect(0, 13, '\P{Is_SB= 	CR}', "");
Expect(1, 13, '\P{^Is_SB= 	CR}', "");
Expect(0, 14, '\p{Is_SB= 	CR}', "");
Expect(1, 14, '\p{^Is_SB= 	CR}', "");
Expect(1, 14, '\P{Is_SB= 	CR}', "");
Expect(0, 14, '\P{^Is_SB= 	CR}', "");
Error('\p{Sentence_Break=	 extend/a/}');
Error('\P{Sentence_Break=	 extend/a/}');
Expect(1, 917999, '\p{Sentence_Break=extend}', "");
Expect(0, 917999, '\p{^Sentence_Break=extend}', "");
Expect(0, 917999, '\P{Sentence_Break=extend}', "");
Expect(1, 917999, '\P{^Sentence_Break=extend}', "");
Expect(0, 918000, '\p{Sentence_Break=extend}', "");
Expect(1, 918000, '\p{^Sentence_Break=extend}', "");
Expect(1, 918000, '\P{Sentence_Break=extend}', "");
Expect(0, 918000, '\P{^Sentence_Break=extend}', "");
Expect(1, 917999, '\p{Sentence_Break=-EXTEND}', "");
Expect(0, 917999, '\p{^Sentence_Break=-EXTEND}', "");
Expect(0, 917999, '\P{Sentence_Break=-EXTEND}', "");
Expect(1, 917999, '\P{^Sentence_Break=-EXTEND}', "");
Expect(0, 918000, '\p{Sentence_Break=-EXTEND}', "");
Expect(1, 918000, '\p{^Sentence_Break=-EXTEND}', "");
Expect(1, 918000, '\P{Sentence_Break=-EXTEND}', "");
Expect(0, 918000, '\P{^Sentence_Break=-EXTEND}', "");
Error('\p{SB=-EX/a/}');
Error('\P{SB=-EX/a/}');
Expect(1, 917999, '\p{SB=ex}', "");
Expect(0, 917999, '\p{^SB=ex}', "");
Expect(0, 917999, '\P{SB=ex}', "");
Expect(1, 917999, '\P{^SB=ex}', "");
Expect(0, 918000, '\p{SB=ex}', "");
Expect(1, 918000, '\p{^SB=ex}', "");
Expect(1, 918000, '\P{SB=ex}', "");
Expect(0, 918000, '\P{^SB=ex}', "");
Expect(1, 917999, '\p{SB=EX}', "");
Expect(0, 917999, '\p{^SB=EX}', "");
Expect(0, 917999, '\P{SB=EX}', "");
Expect(1, 917999, '\P{^SB=EX}', "");
Expect(0, 918000, '\p{SB=EX}', "");
Expect(1, 918000, '\p{^SB=EX}', "");
Expect(1, 918000, '\P{SB=EX}', "");
Expect(0, 918000, '\P{^SB=EX}', "");
Error('\p{Is_Sentence_Break=	Extend/a/}');
Error('\P{Is_Sentence_Break=	Extend/a/}');
Expect(1, 917999, '\p{Is_Sentence_Break=extend}', "");
Expect(0, 917999, '\p{^Is_Sentence_Break=extend}', "");
Expect(0, 917999, '\P{Is_Sentence_Break=extend}', "");
Expect(1, 917999, '\P{^Is_Sentence_Break=extend}', "");
Expect(0, 918000, '\p{Is_Sentence_Break=extend}', "");
Expect(1, 918000, '\p{^Is_Sentence_Break=extend}', "");
Expect(1, 918000, '\P{Is_Sentence_Break=extend}', "");
Expect(0, 918000, '\P{^Is_Sentence_Break=extend}', "");
Expect(1, 917999, '\p{Is_Sentence_Break=--EXTEND}', "");
Expect(0, 917999, '\p{^Is_Sentence_Break=--EXTEND}', "");
Expect(0, 917999, '\P{Is_Sentence_Break=--EXTEND}', "");
Expect(1, 917999, '\P{^Is_Sentence_Break=--EXTEND}', "");
Expect(0, 918000, '\p{Is_Sentence_Break=--EXTEND}', "");
Expect(1, 918000, '\p{^Is_Sentence_Break=--EXTEND}', "");
Expect(1, 918000, '\P{Is_Sentence_Break=--EXTEND}', "");
Expect(0, 918000, '\P{^Is_Sentence_Break=--EXTEND}', "");
Error('\p{Is_SB=-_EX:=}');
Error('\P{Is_SB=-_EX:=}');
Expect(1, 917999, '\p{Is_SB=ex}', "");
Expect(0, 917999, '\p{^Is_SB=ex}', "");
Expect(0, 917999, '\P{Is_SB=ex}', "");
Expect(1, 917999, '\P{^Is_SB=ex}', "");
Expect(0, 918000, '\p{Is_SB=ex}', "");
Expect(1, 918000, '\p{^Is_SB=ex}', "");
Expect(1, 918000, '\P{Is_SB=ex}', "");
Expect(0, 918000, '\P{^Is_SB=ex}', "");
Expect(1, 917999, '\p{Is_SB=	_EX}', "");
Expect(0, 917999, '\p{^Is_SB=	_EX}', "");
Expect(0, 917999, '\P{Is_SB=	_EX}', "");
Expect(1, 917999, '\P{^Is_SB=	_EX}', "");
Expect(0, 918000, '\p{Is_SB=	_EX}', "");
Expect(1, 918000, '\p{^Is_SB=	_EX}', "");
Expect(1, 918000, '\P{Is_SB=	_EX}', "");
Expect(0, 918000, '\P{^Is_SB=	_EX}', "");
Error('\p{Sentence_Break=	Format:=}');
Error('\P{Sentence_Break=	Format:=}');
Expect(1, 917631, '\p{Sentence_Break=format}', "");
Expect(0, 917631, '\p{^Sentence_Break=format}', "");
Expect(0, 917631, '\P{Sentence_Break=format}', "");
Expect(1, 917631, '\P{^Sentence_Break=format}', "");
Expect(0, 917632, '\p{Sentence_Break=format}', "");
Expect(1, 917632, '\p{^Sentence_Break=format}', "");
Expect(1, 917632, '\P{Sentence_Break=format}', "");
Expect(0, 917632, '\P{^Sentence_Break=format}', "");
Expect(1, 917631, '\p{Sentence_Break:   	Format}', "");
Expect(0, 917631, '\p{^Sentence_Break:   	Format}', "");
Expect(0, 917631, '\P{Sentence_Break:   	Format}', "");
Expect(1, 917631, '\P{^Sentence_Break:   	Format}', "");
Expect(0, 917632, '\p{Sentence_Break:   	Format}', "");
Expect(1, 917632, '\p{^Sentence_Break:   	Format}', "");
Expect(1, 917632, '\P{Sentence_Break:   	Format}', "");
Expect(0, 917632, '\P{^Sentence_Break:   	Format}', "");
Error('\p{SB=--fo/a/}');
Error('\P{SB=--fo/a/}');
Expect(1, 917631, '\p{SB=fo}', "");
Expect(0, 917631, '\p{^SB=fo}', "");
Expect(0, 917631, '\P{SB=fo}', "");
Expect(1, 917631, '\P{^SB=fo}', "");
Expect(0, 917632, '\p{SB=fo}', "");
Expect(1, 917632, '\p{^SB=fo}', "");
Expect(1, 917632, '\P{SB=fo}', "");
Expect(0, 917632, '\P{^SB=fo}', "");
Expect(1, 917631, '\p{SB=--FO}', "");
Expect(0, 917631, '\p{^SB=--FO}', "");
Expect(0, 917631, '\P{SB=--FO}', "");
Expect(1, 917631, '\P{^SB=--FO}', "");
Expect(0, 917632, '\p{SB=--FO}', "");
Expect(1, 917632, '\p{^SB=--FO}', "");
Expect(1, 917632, '\P{SB=--FO}', "");
Expect(0, 917632, '\P{^SB=--FO}', "");
Error('\p{Is_Sentence_Break=- Format:=}');
Error('\P{Is_Sentence_Break=- Format:=}');
Expect(1, 917631, '\p{Is_Sentence_Break=format}', "");
Expect(0, 917631, '\p{^Is_Sentence_Break=format}', "");
Expect(0, 917631, '\P{Is_Sentence_Break=format}', "");
Expect(1, 917631, '\P{^Is_Sentence_Break=format}', "");
Expect(0, 917632, '\p{Is_Sentence_Break=format}', "");
Expect(1, 917632, '\p{^Is_Sentence_Break=format}', "");
Expect(1, 917632, '\P{Is_Sentence_Break=format}', "");
Expect(0, 917632, '\P{^Is_Sentence_Break=format}', "");
Expect(1, 917631, '\p{Is_Sentence_Break=-	FORMAT}', "");
Expect(0, 917631, '\p{^Is_Sentence_Break=-	FORMAT}', "");
Expect(0, 917631, '\P{Is_Sentence_Break=-	FORMAT}', "");
Expect(1, 917631, '\P{^Is_Sentence_Break=-	FORMAT}', "");
Expect(0, 917632, '\p{Is_Sentence_Break=-	FORMAT}', "");
Expect(1, 917632, '\p{^Is_Sentence_Break=-	FORMAT}', "");
Expect(1, 917632, '\P{Is_Sentence_Break=-	FORMAT}', "");
Expect(0, 917632, '\P{^Is_Sentence_Break=-	FORMAT}', "");
Error('\p{Is_SB= FO:=}');
Error('\P{Is_SB= FO:=}');
Expect(1, 917631, '\p{Is_SB:	fo}', "");
Expect(0, 917631, '\p{^Is_SB:	fo}', "");
Expect(0, 917631, '\P{Is_SB:	fo}', "");
Expect(1, 917631, '\P{^Is_SB:	fo}', "");
Expect(0, 917632, '\p{Is_SB:	fo}', "");
Expect(1, 917632, '\p{^Is_SB:	fo}', "");
Expect(1, 917632, '\P{Is_SB:	fo}', "");
Expect(0, 917632, '\P{^Is_SB:	fo}', "");
Expect(1, 917631, '\p{Is_SB=__fo}', "");
Expect(0, 917631, '\p{^Is_SB=__fo}', "");
Expect(0, 917631, '\P{Is_SB=__fo}', "");
Expect(1, 917631, '\P{^Is_SB=__fo}', "");
Expect(0, 917632, '\p{Is_SB=__fo}', "");
Expect(1, 917632, '\p{^Is_SB=__fo}', "");
Expect(1, 917632, '\P{Is_SB=__fo}', "");
Expect(0, 917632, '\P{^Is_SB=__fo}', "");
Error('\p{Sentence_Break=/a/_ OLETTER}');
Error('\P{Sentence_Break=/a/_ OLETTER}');
Expect(1, 195101, '\p{Sentence_Break=oletter}', "");
Expect(0, 195101, '\p{^Sentence_Break=oletter}', "");
Expect(0, 195101, '\P{Sentence_Break=oletter}', "");
Expect(1, 195101, '\P{^Sentence_Break=oletter}', "");
Expect(0, 195102, '\p{Sentence_Break=oletter}', "");
Expect(1, 195102, '\p{^Sentence_Break=oletter}', "");
Expect(1, 195102, '\P{Sentence_Break=oletter}', "");
Expect(0, 195102, '\P{^Sentence_Break=oletter}', "");
Expect(1, 195101, '\p{Sentence_Break= oletter}', "");
Expect(0, 195101, '\p{^Sentence_Break= oletter}', "");
Expect(0, 195101, '\P{Sentence_Break= oletter}', "");
Expect(1, 195101, '\P{^Sentence_Break= oletter}', "");
Expect(0, 195102, '\p{Sentence_Break= oletter}', "");
Expect(1, 195102, '\p{^Sentence_Break= oletter}', "");
Expect(1, 195102, '\P{Sentence_Break= oletter}', "");
Expect(0, 195102, '\P{^Sentence_Break= oletter}', "");
Error('\p{SB=/a/	-LE}');
Error('\P{SB=/a/	-LE}');
Expect(1, 195101, '\p{SB=le}', "");
Expect(0, 195101, '\p{^SB=le}', "");
Expect(0, 195101, '\P{SB=le}', "");
Expect(1, 195101, '\P{^SB=le}', "");
Expect(0, 195102, '\p{SB=le}', "");
Expect(1, 195102, '\p{^SB=le}', "");
Expect(1, 195102, '\P{SB=le}', "");
Expect(0, 195102, '\P{^SB=le}', "");
Expect(1, 195101, '\p{SB=	 LE}', "");
Expect(0, 195101, '\p{^SB=	 LE}', "");
Expect(0, 195101, '\P{SB=	 LE}', "");
Expect(1, 195101, '\P{^SB=	 LE}', "");
Expect(0, 195102, '\p{SB=	 LE}', "");
Expect(1, 195102, '\p{^SB=	 LE}', "");
Expect(1, 195102, '\P{SB=	 LE}', "");
Expect(0, 195102, '\P{^SB=	 LE}', "");
Error('\p{Is_Sentence_Break=_/a/oletter}');
Error('\P{Is_Sentence_Break=_/a/oletter}');
Expect(1, 195101, '\p{Is_Sentence_Break=oletter}', "");
Expect(0, 195101, '\p{^Is_Sentence_Break=oletter}', "");
Expect(0, 195101, '\P{Is_Sentence_Break=oletter}', "");
Expect(1, 195101, '\P{^Is_Sentence_Break=oletter}', "");
Expect(0, 195102, '\p{Is_Sentence_Break=oletter}', "");
Expect(1, 195102, '\p{^Is_Sentence_Break=oletter}', "");
Expect(1, 195102, '\P{Is_Sentence_Break=oletter}', "");
Expect(0, 195102, '\P{^Is_Sentence_Break=oletter}', "");
Expect(1, 195101, '\p{Is_Sentence_Break=	-oletter}', "");
Expect(0, 195101, '\p{^Is_Sentence_Break=	-oletter}', "");
Expect(0, 195101, '\P{Is_Sentence_Break=	-oletter}', "");
Expect(1, 195101, '\P{^Is_Sentence_Break=	-oletter}', "");
Expect(0, 195102, '\p{Is_Sentence_Break=	-oletter}', "");
Expect(1, 195102, '\p{^Is_Sentence_Break=	-oletter}', "");
Expect(1, 195102, '\P{Is_Sentence_Break=	-oletter}', "");
Expect(0, 195102, '\P{^Is_Sentence_Break=	-oletter}', "");
Error('\p{Is_SB= /a/LE}');
Error('\P{Is_SB= /a/LE}');
Expect(1, 195101, '\p{Is_SB=le}', "");
Expect(0, 195101, '\p{^Is_SB=le}', "");
Expect(0, 195101, '\P{Is_SB=le}', "");
Expect(1, 195101, '\P{^Is_SB=le}', "");
Expect(0, 195102, '\p{Is_SB=le}', "");
Expect(1, 195102, '\p{^Is_SB=le}', "");
Expect(1, 195102, '\P{Is_SB=le}', "");
Expect(0, 195102, '\P{^Is_SB=le}', "");
Expect(1, 195101, '\p{Is_SB=_-le}', "");
Expect(0, 195101, '\p{^Is_SB=_-le}', "");
Expect(0, 195101, '\P{Is_SB=_-le}', "");
Expect(1, 195101, '\P{^Is_SB=_-le}', "");
Expect(0, 195102, '\p{Is_SB=_-le}', "");
Expect(1, 195102, '\p{^Is_SB=_-le}', "");
Expect(1, 195102, '\P{Is_SB=_-le}', "");
Expect(0, 195102, '\P{^Is_SB=_-le}', "");
Error('\p{Sentence_Break:   _/a/LF}');
Error('\P{Sentence_Break:   _/a/LF}');
Expect(1, 10, '\p{Sentence_Break=lf}', "");
Expect(0, 10, '\p{^Sentence_Break=lf}', "");
Expect(0, 10, '\P{Sentence_Break=lf}', "");
Expect(1, 10, '\P{^Sentence_Break=lf}', "");
Expect(0, 11, '\p{Sentence_Break=lf}', "");
Expect(1, 11, '\p{^Sentence_Break=lf}', "");
Expect(1, 11, '\P{Sentence_Break=lf}', "");
Expect(0, 11, '\P{^Sentence_Break=lf}', "");
Expect(1, 10, '\p{Sentence_Break=_LF}', "");
Expect(0, 10, '\p{^Sentence_Break=_LF}', "");
Expect(0, 10, '\P{Sentence_Break=_LF}', "");
Expect(1, 10, '\P{^Sentence_Break=_LF}', "");
Expect(0, 11, '\p{Sentence_Break=_LF}', "");
Expect(1, 11, '\p{^Sentence_Break=_LF}', "");
Expect(1, 11, '\P{Sentence_Break=_LF}', "");
Expect(0, 11, '\P{^Sentence_Break=_LF}', "");
Error('\p{SB=:= _LF}');
Error('\P{SB=:= _LF}');
Expect(1, 10, '\p{SB=lf}', "");
Expect(0, 10, '\p{^SB=lf}', "");
Expect(0, 10, '\P{SB=lf}', "");
Expect(1, 10, '\P{^SB=lf}', "");
Expect(0, 11, '\p{SB=lf}', "");
Expect(1, 11, '\p{^SB=lf}', "");
Expect(1, 11, '\P{SB=lf}', "");
Expect(0, 11, '\P{^SB=lf}', "");
Expect(1, 10, '\p{SB=_LF}', "");
Expect(0, 10, '\p{^SB=_LF}', "");
Expect(0, 10, '\P{SB=_LF}', "");
Expect(1, 10, '\P{^SB=_LF}', "");
Expect(0, 11, '\p{SB=_LF}', "");
Expect(1, 11, '\p{^SB=_LF}', "");
Expect(1, 11, '\P{SB=_LF}', "");
Expect(0, 11, '\P{^SB=_LF}', "");
Error('\p{Is_Sentence_Break=:=lf}');
Error('\P{Is_Sentence_Break=:=lf}');
Expect(1, 10, '\p{Is_Sentence_Break=lf}', "");
Expect(0, 10, '\p{^Is_Sentence_Break=lf}', "");
Expect(0, 10, '\P{Is_Sentence_Break=lf}', "");
Expect(1, 10, '\P{^Is_Sentence_Break=lf}', "");
Expect(0, 11, '\p{Is_Sentence_Break=lf}', "");
Expect(1, 11, '\p{^Is_Sentence_Break=lf}', "");
Expect(1, 11, '\P{Is_Sentence_Break=lf}', "");
Expect(0, 11, '\P{^Is_Sentence_Break=lf}', "");
Expect(1, 10, '\p{Is_Sentence_Break=- LF}', "");
Expect(0, 10, '\p{^Is_Sentence_Break=- LF}', "");
Expect(0, 10, '\P{Is_Sentence_Break=- LF}', "");
Expect(1, 10, '\P{^Is_Sentence_Break=- LF}', "");
Expect(0, 11, '\p{Is_Sentence_Break=- LF}', "");
Expect(1, 11, '\p{^Is_Sentence_Break=- LF}', "");
Expect(1, 11, '\P{Is_Sentence_Break=- LF}', "");
Expect(0, 11, '\P{^Is_Sentence_Break=- LF}', "");
Error('\p{Is_SB=-/a/lf}');
Error('\P{Is_SB=-/a/lf}');
Expect(1, 10, '\p{Is_SB=lf}', "");
Expect(0, 10, '\p{^Is_SB=lf}', "");
Expect(0, 10, '\P{Is_SB=lf}', "");
Expect(1, 10, '\P{^Is_SB=lf}', "");
Expect(0, 11, '\p{Is_SB=lf}', "");
Expect(1, 11, '\p{^Is_SB=lf}', "");
Expect(1, 11, '\P{Is_SB=lf}', "");
Expect(0, 11, '\P{^Is_SB=lf}', "");
Expect(1, 10, '\p{Is_SB=-_LF}', "");
Expect(0, 10, '\p{^Is_SB=-_LF}', "");
Expect(0, 10, '\P{Is_SB=-_LF}', "");
Expect(1, 10, '\P{^Is_SB=-_LF}', "");
Expect(0, 11, '\p{Is_SB=-_LF}', "");
Expect(1, 11, '\p{^Is_SB=-_LF}', "");
Expect(1, 11, '\P{Is_SB=-_LF}', "");
Expect(0, 11, '\P{^Is_SB=-_LF}', "");
Error('\p{Sentence_Break=	:=LOWER}');
Error('\P{Sentence_Break=	:=LOWER}');
Expect(1, 120779, '\p{Sentence_Break=lower}', "");
Expect(0, 120779, '\p{^Sentence_Break=lower}', "");
Expect(0, 120779, '\P{Sentence_Break=lower}', "");
Expect(1, 120779, '\P{^Sentence_Break=lower}', "");
Expect(0, 120780, '\p{Sentence_Break=lower}', "");
Expect(1, 120780, '\p{^Sentence_Break=lower}', "");
Expect(1, 120780, '\P{Sentence_Break=lower}', "");
Expect(0, 120780, '\P{^Sentence_Break=lower}', "");
Expect(1, 120779, '\p{Sentence_Break=-lower}', "");
Expect(0, 120779, '\p{^Sentence_Break=-lower}', "");
Expect(0, 120779, '\P{Sentence_Break=-lower}', "");
Expect(1, 120779, '\P{^Sentence_Break=-lower}', "");
Expect(0, 120780, '\p{Sentence_Break=-lower}', "");
Expect(1, 120780, '\p{^Sentence_Break=-lower}', "");
Expect(1, 120780, '\P{Sentence_Break=-lower}', "");
Expect(0, 120780, '\P{^Sentence_Break=-lower}', "");
Error('\p{SB=_:=LO}');
Error('\P{SB=_:=LO}');
Expect(1, 120779, '\p{SB=lo}', "");
Expect(0, 120779, '\p{^SB=lo}', "");
Expect(0, 120779, '\P{SB=lo}', "");
Expect(1, 120779, '\P{^SB=lo}', "");
Expect(0, 120780, '\p{SB=lo}', "");
Expect(1, 120780, '\p{^SB=lo}', "");
Expect(1, 120780, '\P{SB=lo}', "");
Expect(0, 120780, '\P{^SB=lo}', "");
Expect(1, 120779, '\p{SB=_-LO}', "");
Expect(0, 120779, '\p{^SB=_-LO}', "");
Expect(0, 120779, '\P{SB=_-LO}', "");
Expect(1, 120779, '\P{^SB=_-LO}', "");
Expect(0, 120780, '\p{SB=_-LO}', "");
Expect(1, 120780, '\p{^SB=_-LO}', "");
Expect(1, 120780, '\P{SB=_-LO}', "");
Expect(0, 120780, '\P{^SB=_-LO}', "");
Error('\p{Is_Sentence_Break=:=LOWER}');
Error('\P{Is_Sentence_Break=:=LOWER}');
Expect(1, 120779, '\p{Is_Sentence_Break=lower}', "");
Expect(0, 120779, '\p{^Is_Sentence_Break=lower}', "");
Expect(0, 120779, '\P{Is_Sentence_Break=lower}', "");
Expect(1, 120779, '\P{^Is_Sentence_Break=lower}', "");
Expect(0, 120780, '\p{Is_Sentence_Break=lower}', "");
Expect(1, 120780, '\p{^Is_Sentence_Break=lower}', "");
Expect(1, 120780, '\P{Is_Sentence_Break=lower}', "");
Expect(0, 120780, '\P{^Is_Sentence_Break=lower}', "");
Expect(1, 120779, '\p{Is_Sentence_Break=__lower}', "");
Expect(0, 120779, '\p{^Is_Sentence_Break=__lower}', "");
Expect(0, 120779, '\P{Is_Sentence_Break=__lower}', "");
Expect(1, 120779, '\P{^Is_Sentence_Break=__lower}', "");
Expect(0, 120780, '\p{Is_Sentence_Break=__lower}', "");
Expect(1, 120780, '\p{^Is_Sentence_Break=__lower}', "");
Expect(1, 120780, '\P{Is_Sentence_Break=__lower}', "");
Expect(0, 120780, '\P{^Is_Sentence_Break=__lower}', "");
Error('\p{Is_SB:   	LO/a/}');
Error('\P{Is_SB:   	LO/a/}');
Expect(1, 120779, '\p{Is_SB=lo}', "");
Expect(0, 120779, '\p{^Is_SB=lo}', "");
Expect(0, 120779, '\P{Is_SB=lo}', "");
Expect(1, 120779, '\P{^Is_SB=lo}', "");
Expect(0, 120780, '\p{Is_SB=lo}', "");
Expect(1, 120780, '\p{^Is_SB=lo}', "");
Expect(1, 120780, '\P{Is_SB=lo}', "");
Expect(0, 120780, '\P{^Is_SB=lo}', "");
Expect(1, 120779, '\p{Is_SB=_-LO}', "");
Expect(0, 120779, '\p{^Is_SB=_-LO}', "");
Expect(0, 120779, '\P{Is_SB=_-LO}', "");
Expect(1, 120779, '\P{^Is_SB=_-LO}', "");
Expect(0, 120780, '\p{Is_SB=_-LO}', "");
Expect(1, 120780, '\p{^Is_SB=_-LO}', "");
Expect(1, 120780, '\P{Is_SB=_-LO}', "");
Expect(0, 120780, '\P{^Is_SB=_-LO}', "");
Error('\p{Sentence_Break=	:=NUMERIC}');
Error('\P{Sentence_Break=	:=NUMERIC}');
Expect(1, 120831, '\p{Sentence_Break=numeric}', "");
Expect(0, 120831, '\p{^Sentence_Break=numeric}', "");
Expect(0, 120831, '\P{Sentence_Break=numeric}', "");
Expect(1, 120831, '\P{^Sentence_Break=numeric}', "");
Expect(0, 120832, '\p{Sentence_Break=numeric}', "");
Expect(1, 120832, '\p{^Sentence_Break=numeric}', "");
Expect(1, 120832, '\P{Sentence_Break=numeric}', "");
Expect(0, 120832, '\P{^Sentence_Break=numeric}', "");
Expect(1, 120831, '\p{Sentence_Break= Numeric}', "");
Expect(0, 120831, '\p{^Sentence_Break= Numeric}', "");
Expect(0, 120831, '\P{Sentence_Break= Numeric}', "");
Expect(1, 120831, '\P{^Sentence_Break= Numeric}', "");
Expect(0, 120832, '\p{Sentence_Break= Numeric}', "");
Expect(1, 120832, '\p{^Sentence_Break= Numeric}', "");
Expect(1, 120832, '\P{Sentence_Break= Numeric}', "");
Expect(0, 120832, '\P{^Sentence_Break= Numeric}', "");
Error('\p{SB=/a/		nu}');
Error('\P{SB=/a/		nu}');
Expect(1, 120831, '\p{SB=nu}', "");
Expect(0, 120831, '\p{^SB=nu}', "");
Expect(0, 120831, '\P{SB=nu}', "");
Expect(1, 120831, '\P{^SB=nu}', "");
Expect(0, 120832, '\p{SB=nu}', "");
Expect(1, 120832, '\p{^SB=nu}', "");
Expect(1, 120832, '\P{SB=nu}', "");
Expect(0, 120832, '\P{^SB=nu}', "");
Expect(1, 120831, '\p{SB=_NU}', "");
Expect(0, 120831, '\p{^SB=_NU}', "");
Expect(0, 120831, '\P{SB=_NU}', "");
Expect(1, 120831, '\P{^SB=_NU}', "");
Expect(0, 120832, '\p{SB=_NU}', "");
Expect(1, 120832, '\p{^SB=_NU}', "");
Expect(1, 120832, '\P{SB=_NU}', "");
Expect(0, 120832, '\P{^SB=_NU}', "");
Error('\p{Is_Sentence_Break=--Numeric:=}');
Error('\P{Is_Sentence_Break=--Numeric:=}');
Expect(1, 120831, '\p{Is_Sentence_Break=numeric}', "");
Expect(0, 120831, '\p{^Is_Sentence_Break=numeric}', "");
Expect(0, 120831, '\P{Is_Sentence_Break=numeric}', "");
Expect(1, 120831, '\P{^Is_Sentence_Break=numeric}', "");
Expect(0, 120832, '\p{Is_Sentence_Break=numeric}', "");
Expect(1, 120832, '\p{^Is_Sentence_Break=numeric}', "");
Expect(1, 120832, '\P{Is_Sentence_Break=numeric}', "");
Expect(0, 120832, '\P{^Is_Sentence_Break=numeric}', "");
Expect(1, 120831, '\p{Is_Sentence_Break=		Numeric}', "");
Expect(0, 120831, '\p{^Is_Sentence_Break=		Numeric}', "");
Expect(0, 120831, '\P{Is_Sentence_Break=		Numeric}', "");
Expect(1, 120831, '\P{^Is_Sentence_Break=		Numeric}', "");
Expect(0, 120832, '\p{Is_Sentence_Break=		Numeric}', "");
Expect(1, 120832, '\p{^Is_Sentence_Break=		Numeric}', "");
Expect(1, 120832, '\P{Is_Sentence_Break=		Numeric}', "");
Expect(0, 120832, '\P{^Is_Sentence_Break=		Numeric}', "");
Error('\p{Is_SB=-	nu/a/}');
Error('\P{Is_SB=-	nu/a/}');
Expect(1, 120831, '\p{Is_SB=nu}', "");
Expect(0, 120831, '\p{^Is_SB=nu}', "");
Expect(0, 120831, '\P{Is_SB=nu}', "");
Expect(1, 120831, '\P{^Is_SB=nu}', "");
Expect(0, 120832, '\p{Is_SB=nu}', "");
Expect(1, 120832, '\p{^Is_SB=nu}', "");
Expect(1, 120832, '\P{Is_SB=nu}', "");
Expect(0, 120832, '\P{^Is_SB=nu}', "");
Expect(1, 120831, '\p{Is_SB= NU}', "");
Expect(0, 120831, '\p{^Is_SB= NU}', "");
Expect(0, 120831, '\P{Is_SB= NU}', "");
Expect(1, 120831, '\P{^Is_SB= NU}', "");
Expect(0, 120832, '\p{Is_SB= NU}', "");
Expect(1, 120832, '\p{^Is_SB= NU}', "");
Expect(1, 120832, '\P{Is_SB= NU}', "");
Expect(0, 120832, '\P{^Is_SB= NU}', "");
Error('\p{Sentence_Break=_/a/SContinue}');
Error('\P{Sentence_Break=_/a/SContinue}');
Expect(1, 65380, '\p{Sentence_Break=scontinue}', "");
Expect(0, 65380, '\p{^Sentence_Break=scontinue}', "");
Expect(0, 65380, '\P{Sentence_Break=scontinue}', "");
Expect(1, 65380, '\P{^Sentence_Break=scontinue}', "");
Expect(0, 65381, '\p{Sentence_Break=scontinue}', "");
Expect(1, 65381, '\p{^Sentence_Break=scontinue}', "");
Expect(1, 65381, '\P{Sentence_Break=scontinue}', "");
Expect(0, 65381, '\P{^Sentence_Break=scontinue}', "");
Expect(1, 65380, '\p{Sentence_Break=-SContinue}', "");
Expect(0, 65380, '\p{^Sentence_Break=-SContinue}', "");
Expect(0, 65380, '\P{Sentence_Break=-SContinue}', "");
Expect(1, 65380, '\P{^Sentence_Break=-SContinue}', "");
Expect(0, 65381, '\p{Sentence_Break=-SContinue}', "");
Expect(1, 65381, '\p{^Sentence_Break=-SContinue}', "");
Expect(1, 65381, '\P{Sentence_Break=-SContinue}', "");
Expect(0, 65381, '\P{^Sentence_Break=-SContinue}', "");
Error('\p{SB=-/a/SC}');
Error('\P{SB=-/a/SC}');
Expect(1, 65380, '\p{SB=sc}', "");
Expect(0, 65380, '\p{^SB=sc}', "");
Expect(0, 65380, '\P{SB=sc}', "");
Expect(1, 65380, '\P{^SB=sc}', "");
Expect(0, 65381, '\p{SB=sc}', "");
Expect(1, 65381, '\p{^SB=sc}', "");
Expect(1, 65381, '\P{SB=sc}', "");
Expect(0, 65381, '\P{^SB=sc}', "");
Expect(1, 65380, '\p{SB=  SC}', "");
Expect(0, 65380, '\p{^SB=  SC}', "");
Expect(0, 65380, '\P{SB=  SC}', "");
Expect(1, 65380, '\P{^SB=  SC}', "");
Expect(0, 65381, '\p{SB=  SC}', "");
Expect(1, 65381, '\p{^SB=  SC}', "");
Expect(1, 65381, '\P{SB=  SC}', "");
Expect(0, 65381, '\P{^SB=  SC}', "");
Error('\p{Is_Sentence_Break=- SCONTINUE:=}');
Error('\P{Is_Sentence_Break=- SCONTINUE:=}');
Expect(1, 65380, '\p{Is_Sentence_Break=scontinue}', "");
Expect(0, 65380, '\p{^Is_Sentence_Break=scontinue}', "");
Expect(0, 65380, '\P{Is_Sentence_Break=scontinue}', "");
Expect(1, 65380, '\P{^Is_Sentence_Break=scontinue}', "");
Expect(0, 65381, '\p{Is_Sentence_Break=scontinue}', "");
Expect(1, 65381, '\p{^Is_Sentence_Break=scontinue}', "");
Expect(1, 65381, '\P{Is_Sentence_Break=scontinue}', "");
Expect(0, 65381, '\P{^Is_Sentence_Break=scontinue}', "");
Expect(1, 65380, '\p{Is_Sentence_Break:		scontinue}', "");
Expect(0, 65380, '\p{^Is_Sentence_Break:		scontinue}', "");
Expect(0, 65380, '\P{Is_Sentence_Break:		scontinue}', "");
Expect(1, 65380, '\P{^Is_Sentence_Break:		scontinue}', "");
Expect(0, 65381, '\p{Is_Sentence_Break:		scontinue}', "");
Expect(1, 65381, '\p{^Is_Sentence_Break:		scontinue}', "");
Expect(1, 65381, '\P{Is_Sentence_Break:		scontinue}', "");
Expect(0, 65381, '\P{^Is_Sentence_Break:		scontinue}', "");
Error('\p{Is_SB=	SC/a/}');
Error('\P{Is_SB=	SC/a/}');
Expect(1, 65380, '\p{Is_SB:   sc}', "");
Expect(0, 65380, '\p{^Is_SB:   sc}', "");
Expect(0, 65380, '\P{Is_SB:   sc}', "");
Expect(1, 65380, '\P{^Is_SB:   sc}', "");
Expect(0, 65381, '\p{Is_SB:   sc}', "");
Expect(1, 65381, '\p{^Is_SB:   sc}', "");
Expect(1, 65381, '\P{Is_SB:   sc}', "");
Expect(0, 65381, '\P{^Is_SB:   sc}', "");
Expect(1, 65380, '\p{Is_SB= _SC}', "");
Expect(0, 65380, '\p{^Is_SB= _SC}', "");
Expect(0, 65380, '\P{Is_SB= _SC}', "");
Expect(1, 65380, '\P{^Is_SB= _SC}', "");
Expect(0, 65381, '\p{Is_SB= _SC}', "");
Expect(1, 65381, '\p{^Is_SB= _SC}', "");
Expect(1, 65381, '\P{Is_SB= _SC}', "");
Expect(0, 65381, '\P{^Is_SB= _SC}', "");
Error('\p{Sentence_Break=-/a/Sep}');
Error('\P{Sentence_Break=-/a/Sep}');
Expect(1, 8233, '\p{Sentence_Break=sep}', "");
Expect(0, 8233, '\p{^Sentence_Break=sep}', "");
Expect(0, 8233, '\P{Sentence_Break=sep}', "");
Expect(1, 8233, '\P{^Sentence_Break=sep}', "");
Expect(0, 8234, '\p{Sentence_Break=sep}', "");
Expect(1, 8234, '\p{^Sentence_Break=sep}', "");
Expect(1, 8234, '\P{Sentence_Break=sep}', "");
Expect(0, 8234, '\P{^Sentence_Break=sep}', "");
Expect(1, 8233, '\p{Sentence_Break=	 Sep}', "");
Expect(0, 8233, '\p{^Sentence_Break=	 Sep}', "");
Expect(0, 8233, '\P{Sentence_Break=	 Sep}', "");
Expect(1, 8233, '\P{^Sentence_Break=	 Sep}', "");
Expect(0, 8234, '\p{Sentence_Break=	 Sep}', "");
Expect(1, 8234, '\p{^Sentence_Break=	 Sep}', "");
Expect(1, 8234, '\P{Sentence_Break=	 Sep}', "");
Expect(0, 8234, '\P{^Sentence_Break=	 Sep}', "");
Error('\p{SB=_:=se}');
Error('\P{SB=_:=se}');
Expect(1, 8233, '\p{SB=se}', "");
Expect(0, 8233, '\p{^SB=se}', "");
Expect(0, 8233, '\P{SB=se}', "");
Expect(1, 8233, '\P{^SB=se}', "");
Expect(0, 8234, '\p{SB=se}', "");
Expect(1, 8234, '\p{^SB=se}', "");
Expect(1, 8234, '\P{SB=se}', "");
Expect(0, 8234, '\P{^SB=se}', "");
Expect(1, 8233, '\p{SB=	SE}', "");
Expect(0, 8233, '\p{^SB=	SE}', "");
Expect(0, 8233, '\P{SB=	SE}', "");
Expect(1, 8233, '\P{^SB=	SE}', "");
Expect(0, 8234, '\p{SB=	SE}', "");
Expect(1, 8234, '\p{^SB=	SE}', "");
Expect(1, 8234, '\P{SB=	SE}', "");
Expect(0, 8234, '\P{^SB=	SE}', "");
Error('\p{Is_Sentence_Break=_/a/Sep}');
Error('\P{Is_Sentence_Break=_/a/Sep}');
Expect(1, 8233, '\p{Is_Sentence_Break=sep}', "");
Expect(0, 8233, '\p{^Is_Sentence_Break=sep}', "");
Expect(0, 8233, '\P{Is_Sentence_Break=sep}', "");
Expect(1, 8233, '\P{^Is_Sentence_Break=sep}', "");
Expect(0, 8234, '\p{Is_Sentence_Break=sep}', "");
Expect(1, 8234, '\p{^Is_Sentence_Break=sep}', "");
Expect(1, 8234, '\P{Is_Sentence_Break=sep}', "");
Expect(0, 8234, '\P{^Is_Sentence_Break=sep}', "");
Expect(1, 8233, '\p{Is_Sentence_Break=	 Sep}', "");
Expect(0, 8233, '\p{^Is_Sentence_Break=	 Sep}', "");
Expect(0, 8233, '\P{Is_Sentence_Break=	 Sep}', "");
Expect(1, 8233, '\P{^Is_Sentence_Break=	 Sep}', "");
Expect(0, 8234, '\p{Is_Sentence_Break=	 Sep}', "");
Expect(1, 8234, '\p{^Is_Sentence_Break=	 Sep}', "");
Expect(1, 8234, '\P{Is_Sentence_Break=	 Sep}', "");
Expect(0, 8234, '\P{^Is_Sentence_Break=	 Sep}', "");
Error('\p{Is_SB=__se/a/}');
Error('\P{Is_SB=__se/a/}');
Expect(1, 8233, '\p{Is_SB=se}', "");
Expect(0, 8233, '\p{^Is_SB=se}', "");
Expect(0, 8233, '\P{Is_SB=se}', "");
Expect(1, 8233, '\P{^Is_SB=se}', "");
Expect(0, 8234, '\p{Is_SB=se}', "");
Expect(1, 8234, '\p{^Is_SB=se}', "");
Expect(1, 8234, '\P{Is_SB=se}', "");
Expect(0, 8234, '\P{^Is_SB=se}', "");
Expect(1, 8233, '\p{Is_SB=_-se}', "");
Expect(0, 8233, '\p{^Is_SB=_-se}', "");
Expect(0, 8233, '\P{Is_SB=_-se}', "");
Expect(1, 8233, '\P{^Is_SB=_-se}', "");
Expect(0, 8234, '\p{Is_SB=_-se}', "");
Expect(1, 8234, '\p{^Is_SB=_-se}', "");
Expect(1, 8234, '\P{Is_SB=_-se}', "");
Expect(0, 8234, '\P{^Is_SB=_-se}', "");
Error('\p{Sentence_Break: _	Sp:=}');
Error('\P{Sentence_Break: _	Sp:=}');
Expect(1, 12288, '\p{Sentence_Break=sp}', "");
Expect(0, 12288, '\p{^Sentence_Break=sp}', "");
Expect(0, 12288, '\P{Sentence_Break=sp}', "");
Expect(1, 12288, '\P{^Sentence_Break=sp}', "");
Expect(0, 12289, '\p{Sentence_Break=sp}', "");
Expect(1, 12289, '\p{^Sentence_Break=sp}', "");
Expect(1, 12289, '\P{Sentence_Break=sp}', "");
Expect(0, 12289, '\P{^Sentence_Break=sp}', "");
Expect(1, 12288, '\p{Sentence_Break=	SP}', "");
Expect(0, 12288, '\p{^Sentence_Break=	SP}', "");
Expect(0, 12288, '\P{Sentence_Break=	SP}', "");
Expect(1, 12288, '\P{^Sentence_Break=	SP}', "");
Expect(0, 12289, '\p{Sentence_Break=	SP}', "");
Expect(1, 12289, '\p{^Sentence_Break=	SP}', "");
Expect(1, 12289, '\P{Sentence_Break=	SP}', "");
Expect(0, 12289, '\P{^Sentence_Break=	SP}', "");
Error('\p{SB:   :=-sp}');
Error('\P{SB:   :=-sp}');
Expect(1, 12288, '\p{SB: sp}', "");
Expect(0, 12288, '\p{^SB: sp}', "");
Expect(0, 12288, '\P{SB: sp}', "");
Expect(1, 12288, '\P{^SB: sp}', "");
Expect(0, 12289, '\p{SB: sp}', "");
Expect(1, 12289, '\p{^SB: sp}', "");
Expect(1, 12289, '\P{SB: sp}', "");
Expect(0, 12289, '\P{^SB: sp}', "");
Expect(1, 12288, '\p{SB=	-Sp}', "");
Expect(0, 12288, '\p{^SB=	-Sp}', "");
Expect(0, 12288, '\P{SB=	-Sp}', "");
Expect(1, 12288, '\P{^SB=	-Sp}', "");
Expect(0, 12289, '\p{SB=	-Sp}', "");
Expect(1, 12289, '\p{^SB=	-Sp}', "");
Expect(1, 12289, '\P{SB=	-Sp}', "");
Expect(0, 12289, '\P{^SB=	-Sp}', "");
Error('\p{Is_Sentence_Break= SP:=}');
Error('\P{Is_Sentence_Break= SP:=}');
Expect(1, 12288, '\p{Is_Sentence_Break=sp}', "");
Expect(0, 12288, '\p{^Is_Sentence_Break=sp}', "");
Expect(0, 12288, '\P{Is_Sentence_Break=sp}', "");
Expect(1, 12288, '\P{^Is_Sentence_Break=sp}', "");
Expect(0, 12289, '\p{Is_Sentence_Break=sp}', "");
Expect(1, 12289, '\p{^Is_Sentence_Break=sp}', "");
Expect(1, 12289, '\P{Is_Sentence_Break=sp}', "");
Expect(0, 12289, '\P{^Is_Sentence_Break=sp}', "");
Expect(1, 12288, '\p{Is_Sentence_Break=	-Sp}', "");
Expect(0, 12288, '\p{^Is_Sentence_Break=	-Sp}', "");
Expect(0, 12288, '\P{Is_Sentence_Break=	-Sp}', "");
Expect(1, 12288, '\P{^Is_Sentence_Break=	-Sp}', "");
Expect(0, 12289, '\p{Is_Sentence_Break=	-Sp}', "");
Expect(1, 12289, '\p{^Is_Sentence_Break=	-Sp}', "");
Expect(1, 12289, '\P{Is_Sentence_Break=	-Sp}', "");
Expect(0, 12289, '\P{^Is_Sentence_Break=	-Sp}', "");
Error('\p{Is_SB=:=__SP}');
Error('\P{Is_SB=:=__SP}');
Expect(1, 12288, '\p{Is_SB=sp}', "");
Expect(0, 12288, '\p{^Is_SB=sp}', "");
Expect(0, 12288, '\P{Is_SB=sp}', "");
Expect(1, 12288, '\P{^Is_SB=sp}', "");
Expect(0, 12289, '\p{Is_SB=sp}', "");
Expect(1, 12289, '\p{^Is_SB=sp}', "");
Expect(1, 12289, '\P{Is_SB=sp}', "");
Expect(0, 12289, '\P{^Is_SB=sp}', "");
Expect(1, 12288, '\p{Is_SB=-	Sp}', "");
Expect(0, 12288, '\p{^Is_SB=-	Sp}', "");
Expect(0, 12288, '\P{Is_SB=-	Sp}', "");
Expect(1, 12288, '\P{^Is_SB=-	Sp}', "");
Expect(0, 12289, '\p{Is_SB=-	Sp}', "");
Expect(1, 12289, '\p{^Is_SB=-	Sp}', "");
Expect(1, 12289, '\P{Is_SB=-	Sp}', "");
Expect(0, 12289, '\P{^Is_SB=-	Sp}', "");
Error('\p{Sentence_Break=/a/__STERM}');
Error('\P{Sentence_Break=/a/__STERM}');
Expect(1, 70086, '\p{Sentence_Break=sterm}', "");
Expect(0, 70086, '\p{^Sentence_Break=sterm}', "");
Expect(0, 70086, '\P{Sentence_Break=sterm}', "");
Expect(1, 70086, '\P{^Sentence_Break=sterm}', "");
Expect(0, 70087, '\p{Sentence_Break=sterm}', "");
Expect(1, 70087, '\p{^Sentence_Break=sterm}', "");
Expect(1, 70087, '\P{Sentence_Break=sterm}', "");
Expect(0, 70087, '\P{^Sentence_Break=sterm}', "");
Expect(1, 70086, '\p{Sentence_Break= _sterm}', "");
Expect(0, 70086, '\p{^Sentence_Break= _sterm}', "");
Expect(0, 70086, '\P{Sentence_Break= _sterm}', "");
Expect(1, 70086, '\P{^Sentence_Break= _sterm}', "");
Expect(0, 70087, '\p{Sentence_Break= _sterm}', "");
Expect(1, 70087, '\p{^Sentence_Break= _sterm}', "");
Expect(1, 70087, '\P{Sentence_Break= _sterm}', "");
Expect(0, 70087, '\P{^Sentence_Break= _sterm}', "");
Error('\p{SB=/a/st}');
Error('\P{SB=/a/st}');
Expect(1, 70086, '\p{SB: st}', "");
Expect(0, 70086, '\p{^SB: st}', "");
Expect(0, 70086, '\P{SB: st}', "");
Expect(1, 70086, '\P{^SB: st}', "");
Expect(0, 70087, '\p{SB: st}', "");
Expect(1, 70087, '\p{^SB: st}', "");
Expect(1, 70087, '\P{SB: st}', "");
Expect(0, 70087, '\P{^SB: st}', "");
Expect(1, 70086, '\p{SB:	-_ST}', "");
Expect(0, 70086, '\p{^SB:	-_ST}', "");
Expect(0, 70086, '\P{SB:	-_ST}', "");
Expect(1, 70086, '\P{^SB:	-_ST}', "");
Expect(0, 70087, '\p{SB:	-_ST}', "");
Expect(1, 70087, '\p{^SB:	-_ST}', "");
Expect(1, 70087, '\P{SB:	-_ST}', "");
Expect(0, 70087, '\P{^SB:	-_ST}', "");
Error('\p{Is_Sentence_Break=:=-STerm}');
Error('\P{Is_Sentence_Break=:=-STerm}');
Expect(1, 70086, '\p{Is_Sentence_Break=sterm}', "");
Expect(0, 70086, '\p{^Is_Sentence_Break=sterm}', "");
Expect(0, 70086, '\P{Is_Sentence_Break=sterm}', "");
Expect(1, 70086, '\P{^Is_Sentence_Break=sterm}', "");
Expect(0, 70087, '\p{Is_Sentence_Break=sterm}', "");
Expect(1, 70087, '\p{^Is_Sentence_Break=sterm}', "");
Expect(1, 70087, '\P{Is_Sentence_Break=sterm}', "");
Expect(0, 70087, '\P{^Is_Sentence_Break=sterm}', "");
Expect(1, 70086, '\p{Is_Sentence_Break=__sterm}', "");
Expect(0, 70086, '\p{^Is_Sentence_Break=__sterm}', "");
Expect(0, 70086, '\P{Is_Sentence_Break=__sterm}', "");
Expect(1, 70086, '\P{^Is_Sentence_Break=__sterm}', "");
Expect(0, 70087, '\p{Is_Sentence_Break=__sterm}', "");
Expect(1, 70087, '\p{^Is_Sentence_Break=__sterm}', "");
Expect(1, 70087, '\P{Is_Sentence_Break=__sterm}', "");
Expect(0, 70087, '\P{^Is_Sentence_Break=__sterm}', "");
Error('\p{Is_SB:	:=	_ST}');
Error('\P{Is_SB:	:=	_ST}');
Expect(1, 70086, '\p{Is_SB=st}', "");
Expect(0, 70086, '\p{^Is_SB=st}', "");
Expect(0, 70086, '\P{Is_SB=st}', "");
Expect(1, 70086, '\P{^Is_SB=st}', "");
Expect(0, 70087, '\p{Is_SB=st}', "");
Expect(1, 70087, '\p{^Is_SB=st}', "");
Expect(1, 70087, '\P{Is_SB=st}', "");
Expect(0, 70087, '\P{^Is_SB=st}', "");
Expect(1, 70086, '\p{Is_SB=--st}', "");
Expect(0, 70086, '\p{^Is_SB=--st}', "");
Expect(0, 70086, '\P{Is_SB=--st}', "");
Expect(1, 70086, '\P{^Is_SB=--st}', "");
Expect(0, 70087, '\p{Is_SB=--st}', "");
Expect(1, 70087, '\p{^Is_SB=--st}', "");
Expect(1, 70087, '\P{Is_SB=--st}', "");
Expect(0, 70087, '\P{^Is_SB=--st}', "");
Error('\p{Sentence_Break=/a/_ UPPER}');
Error('\P{Sentence_Break=/a/_ UPPER}');
Expect(1, 120778, '\p{Sentence_Break=upper}', "");
Expect(0, 120778, '\p{^Sentence_Break=upper}', "");
Expect(0, 120778, '\P{Sentence_Break=upper}', "");
Expect(1, 120778, '\P{^Sentence_Break=upper}', "");
Expect(0, 120779, '\p{Sentence_Break=upper}', "");
Expect(1, 120779, '\p{^Sentence_Break=upper}', "");
Expect(1, 120779, '\P{Sentence_Break=upper}', "");
Expect(0, 120779, '\P{^Sentence_Break=upper}', "");
Expect(1, 120778, '\p{Sentence_Break=- UPPER}', "");
Expect(0, 120778, '\p{^Sentence_Break=- UPPER}', "");
Expect(0, 120778, '\P{Sentence_Break=- UPPER}', "");
Expect(1, 120778, '\P{^Sentence_Break=- UPPER}', "");
Expect(0, 120779, '\p{Sentence_Break=- UPPER}', "");
Expect(1, 120779, '\p{^Sentence_Break=- UPPER}', "");
Expect(1, 120779, '\P{Sentence_Break=- UPPER}', "");
Expect(0, 120779, '\P{^Sentence_Break=- UPPER}', "");
Error('\p{SB=:=_	up}');
Error('\P{SB=:=_	up}');
Expect(1, 120778, '\p{SB=up}', "");
Expect(0, 120778, '\p{^SB=up}', "");
Expect(0, 120778, '\P{SB=up}', "");
Expect(1, 120778, '\P{^SB=up}', "");
Expect(0, 120779, '\p{SB=up}', "");
Expect(1, 120779, '\p{^SB=up}', "");
Expect(1, 120779, '\P{SB=up}', "");
Expect(0, 120779, '\P{^SB=up}', "");
Expect(1, 120778, '\p{SB=-	UP}', "");
Expect(0, 120778, '\p{^SB=-	UP}', "");
Expect(0, 120778, '\P{SB=-	UP}', "");
Expect(1, 120778, '\P{^SB=-	UP}', "");
Expect(0, 120779, '\p{SB=-	UP}', "");
Expect(1, 120779, '\p{^SB=-	UP}', "");
Expect(1, 120779, '\P{SB=-	UP}', "");
Expect(0, 120779, '\P{^SB=-	UP}', "");
Error('\p{Is_Sentence_Break:	Upper:=}');
Error('\P{Is_Sentence_Break:	Upper:=}');
Expect(1, 120778, '\p{Is_Sentence_Break=upper}', "");
Expect(0, 120778, '\p{^Is_Sentence_Break=upper}', "");
Expect(0, 120778, '\P{Is_Sentence_Break=upper}', "");
Expect(1, 120778, '\P{^Is_Sentence_Break=upper}', "");
Expect(0, 120779, '\p{Is_Sentence_Break=upper}', "");
Expect(1, 120779, '\p{^Is_Sentence_Break=upper}', "");
Expect(1, 120779, '\P{Is_Sentence_Break=upper}', "");
Expect(0, 120779, '\P{^Is_Sentence_Break=upper}', "");
Expect(1, 120778, '\p{Is_Sentence_Break=	Upper}', "");
Expect(0, 120778, '\p{^Is_Sentence_Break=	Upper}', "");
Expect(0, 120778, '\P{Is_Sentence_Break=	Upper}', "");
Expect(1, 120778, '\P{^Is_Sentence_Break=	Upper}', "");
Expect(0, 120779, '\p{Is_Sentence_Break=	Upper}', "");
Expect(1, 120779, '\p{^Is_Sentence_Break=	Upper}', "");
Expect(1, 120779, '\P{Is_Sentence_Break=	Upper}', "");
Expect(0, 120779, '\P{^Is_Sentence_Break=	Upper}', "");
Error('\p{Is_SB= /a/UP}');
Error('\P{Is_SB= /a/UP}');
Expect(1, 120778, '\p{Is_SB=up}', "");
Expect(0, 120778, '\p{^Is_SB=up}', "");
Expect(0, 120778, '\P{Is_SB=up}', "");
Expect(1, 120778, '\P{^Is_SB=up}', "");
Expect(0, 120779, '\p{Is_SB=up}', "");
Expect(1, 120779, '\p{^Is_SB=up}', "");
Expect(1, 120779, '\P{Is_SB=up}', "");
Expect(0, 120779, '\P{^Is_SB=up}', "");
Expect(1, 120778, '\p{Is_SB= up}', "");
Expect(0, 120778, '\p{^Is_SB= up}', "");
Expect(0, 120778, '\P{Is_SB= up}', "");
Expect(1, 120778, '\P{^Is_SB= up}', "");
Expect(0, 120779, '\p{Is_SB= up}', "");
Expect(1, 120779, '\p{^Is_SB= up}', "");
Expect(1, 120779, '\P{Is_SB= up}', "");
Expect(0, 120779, '\P{^Is_SB= up}', "");
Error('\p{Sentence_Break=/a/--other}');
Error('\P{Sentence_Break=/a/--other}');
Expect(1, 918000, '\p{Sentence_Break=other}', "");
Expect(0, 918000, '\p{^Sentence_Break=other}', "");
Expect(0, 918000, '\P{Sentence_Break=other}', "");
Expect(1, 918000, '\P{^Sentence_Break=other}', "");
Expect(0, 917999, '\p{Sentence_Break=other}', "");
Expect(1, 917999, '\p{^Sentence_Break=other}', "");
Expect(1, 917999, '\P{Sentence_Break=other}', "");
Expect(0, 917999, '\P{^Sentence_Break=other}', "");
Expect(1, 918000, '\p{Sentence_Break=-Other}', "");
Expect(0, 918000, '\p{^Sentence_Break=-Other}', "");
Expect(0, 918000, '\P{Sentence_Break=-Other}', "");
Expect(1, 918000, '\P{^Sentence_Break=-Other}', "");
Expect(0, 917999, '\p{Sentence_Break=-Other}', "");
Expect(1, 917999, '\p{^Sentence_Break=-Other}', "");
Expect(1, 917999, '\P{Sentence_Break=-Other}', "");
Expect(0, 917999, '\P{^Sentence_Break=-Other}', "");
Error('\p{SB= _XX/a/}');
Error('\P{SB= _XX/a/}');
Expect(1, 918000, '\p{SB=xx}', "");
Expect(0, 918000, '\p{^SB=xx}', "");
Expect(0, 918000, '\P{SB=xx}', "");
Expect(1, 918000, '\P{^SB=xx}', "");
Expect(0, 917999, '\p{SB=xx}', "");
Expect(1, 917999, '\p{^SB=xx}', "");
Expect(1, 917999, '\P{SB=xx}', "");
Expect(0, 917999, '\P{^SB=xx}', "");
Expect(1, 918000, '\p{SB=  xx}', "");
Expect(0, 918000, '\p{^SB=  xx}', "");
Expect(0, 918000, '\P{SB=  xx}', "");
Expect(1, 918000, '\P{^SB=  xx}', "");
Expect(0, 917999, '\p{SB=  xx}', "");
Expect(1, 917999, '\p{^SB=  xx}', "");
Expect(1, 917999, '\P{SB=  xx}', "");
Expect(0, 917999, '\P{^SB=  xx}', "");
Error('\p{Is_Sentence_Break:	:= -OTHER}');
Error('\P{Is_Sentence_Break:	:= -OTHER}');
Expect(1, 918000, '\p{Is_Sentence_Break=other}', "");
Expect(0, 918000, '\p{^Is_Sentence_Break=other}', "");
Expect(0, 918000, '\P{Is_Sentence_Break=other}', "");
Expect(1, 918000, '\P{^Is_Sentence_Break=other}', "");
Expect(0, 917999, '\p{Is_Sentence_Break=other}', "");
Expect(1, 917999, '\p{^Is_Sentence_Break=other}', "");
Expect(1, 917999, '\P{Is_Sentence_Break=other}', "");
Expect(0, 917999, '\P{^Is_Sentence_Break=other}', "");
Expect(1, 918000, '\p{Is_Sentence_Break=	Other}', "");
Expect(0, 918000, '\p{^Is_Sentence_Break=	Other}', "");
Expect(0, 918000, '\P{Is_Sentence_Break=	Other}', "");
Expect(1, 918000, '\P{^Is_Sentence_Break=	Other}', "");
Expect(0, 917999, '\p{Is_Sentence_Break=	Other}', "");
Expect(1, 917999, '\p{^Is_Sentence_Break=	Other}', "");
Expect(1, 917999, '\P{Is_Sentence_Break=	Other}', "");
Expect(0, 917999, '\P{^Is_Sentence_Break=	Other}', "");
Error('\p{Is_SB=	XX:=}');
Error('\P{Is_SB=	XX:=}');
Expect(1, 918000, '\p{Is_SB=xx}', "");
Expect(0, 918000, '\p{^Is_SB=xx}', "");
Expect(0, 918000, '\P{Is_SB=xx}', "");
Expect(1, 918000, '\P{^Is_SB=xx}', "");
Expect(0, 917999, '\p{Is_SB=xx}', "");
Expect(1, 917999, '\p{^Is_SB=xx}', "");
Expect(1, 917999, '\P{Is_SB=xx}', "");
Expect(0, 917999, '\P{^Is_SB=xx}', "");
Expect(1, 918000, '\p{Is_SB=_ XX}', "");
Expect(0, 918000, '\p{^Is_SB=_ XX}', "");
Expect(0, 918000, '\P{Is_SB=_ XX}', "");
Expect(1, 918000, '\P{^Is_SB=_ XX}', "");
Expect(0, 917999, '\p{Is_SB=_ XX}', "");
Expect(1, 917999, '\p{^Is_SB=_ XX}', "");
Expect(1, 917999, '\P{Is_SB=_ XX}', "");
Expect(0, 917999, '\P{^Is_SB=_ XX}', "");
Error('\p{Soft_Dotted:   :=_	no}');
Error('\P{Soft_Dotted:   :=_	no}');
Expect(1, 120468, '\p{Soft_Dotted=no}', "");
Expect(0, 120468, '\p{^Soft_Dotted=no}', "");
Expect(0, 120468, '\P{Soft_Dotted=no}', "");
Expect(1, 120468, '\P{^Soft_Dotted=no}', "");
Expect(0, 120467, '\p{Soft_Dotted=no}', "");
Expect(1, 120467, '\p{^Soft_Dotted=no}', "");
Expect(1, 120467, '\P{Soft_Dotted=no}', "");
Expect(0, 120467, '\P{^Soft_Dotted=no}', "");
Expect(1, 120468, '\p{Soft_Dotted=_ NO}', "");
Expect(0, 120468, '\p{^Soft_Dotted=_ NO}', "");
Expect(0, 120468, '\P{Soft_Dotted=_ NO}', "");
Expect(1, 120468, '\P{^Soft_Dotted=_ NO}', "");
Expect(0, 120467, '\p{Soft_Dotted=_ NO}', "");
Expect(1, 120467, '\p{^Soft_Dotted=_ NO}', "");
Expect(1, 120467, '\P{Soft_Dotted=_ NO}', "");
Expect(0, 120467, '\P{^Soft_Dotted=_ NO}', "");
Error('\p{SD=N:=}');
Error('\P{SD=N:=}');
Expect(1, 120468, '\p{SD=n}', "");
Expect(0, 120468, '\p{^SD=n}', "");
Expect(0, 120468, '\P{SD=n}', "");
Expect(1, 120468, '\P{^SD=n}', "");
Expect(0, 120467, '\p{SD=n}', "");
Expect(1, 120467, '\p{^SD=n}', "");
Expect(1, 120467, '\P{SD=n}', "");
Expect(0, 120467, '\P{^SD=n}', "");
Expect(1, 120468, '\p{SD:	 _N}', "");
Expect(0, 120468, '\p{^SD:	 _N}', "");
Expect(0, 120468, '\P{SD:	 _N}', "");
Expect(1, 120468, '\P{^SD:	 _N}', "");
Expect(0, 120467, '\p{SD:	 _N}', "");
Expect(1, 120467, '\p{^SD:	 _N}', "");
Expect(1, 120467, '\P{SD:	 _N}', "");
Expect(0, 120467, '\P{^SD:	 _N}', "");
Error('\p{Is_Soft_Dotted=_	f:=}');
Error('\P{Is_Soft_Dotted=_	f:=}');
Expect(1, 120468, '\p{Is_Soft_Dotted=f}', "");
Expect(0, 120468, '\p{^Is_Soft_Dotted=f}', "");
Expect(0, 120468, '\P{Is_Soft_Dotted=f}', "");
Expect(1, 120468, '\P{^Is_Soft_Dotted=f}', "");
Expect(0, 120467, '\p{Is_Soft_Dotted=f}', "");
Expect(1, 120467, '\p{^Is_Soft_Dotted=f}', "");
Expect(1, 120467, '\P{Is_Soft_Dotted=f}', "");
Expect(0, 120467, '\P{^Is_Soft_Dotted=f}', "");
Expect(1, 120468, '\p{Is_Soft_Dotted=-F}', "");
Expect(0, 120468, '\p{^Is_Soft_Dotted=-F}', "");
Expect(0, 120468, '\P{Is_Soft_Dotted=-F}', "");
Expect(1, 120468, '\P{^Is_Soft_Dotted=-F}', "");
Expect(0, 120467, '\p{Is_Soft_Dotted=-F}', "");
Expect(1, 120467, '\p{^Is_Soft_Dotted=-F}', "");
Expect(1, 120467, '\P{Is_Soft_Dotted=-F}', "");
Expect(0, 120467, '\P{^Is_Soft_Dotted=-F}', "");
Error('\p{Is_SD=	false/a/}');
Error('\P{Is_SD=	false/a/}');
Expect(1, 120468, '\p{Is_SD=false}', "");
Expect(0, 120468, '\p{^Is_SD=false}', "");
Expect(0, 120468, '\P{Is_SD=false}', "");
Expect(1, 120468, '\P{^Is_SD=false}', "");
Expect(0, 120467, '\p{Is_SD=false}', "");
Expect(1, 120467, '\p{^Is_SD=false}', "");
Expect(1, 120467, '\P{Is_SD=false}', "");
Expect(0, 120467, '\P{^Is_SD=false}', "");
Expect(1, 120468, '\p{Is_SD=_FALSE}', "");
Expect(0, 120468, '\p{^Is_SD=_FALSE}', "");
Expect(0, 120468, '\P{Is_SD=_FALSE}', "");
Expect(1, 120468, '\P{^Is_SD=_FALSE}', "");
Expect(0, 120467, '\p{Is_SD=_FALSE}', "");
Expect(1, 120467, '\p{^Is_SD=_FALSE}', "");
Expect(1, 120467, '\P{Is_SD=_FALSE}', "");
Expect(0, 120467, '\P{^Is_SD=_FALSE}', "");
Error('\p{Soft_Dotted=_YES:=}');
Error('\P{Soft_Dotted=_YES:=}');
Expect(1, 120467, '\p{Soft_Dotted=yes}', "");
Expect(0, 120467, '\p{^Soft_Dotted=yes}', "");
Expect(0, 120467, '\P{Soft_Dotted=yes}', "");
Expect(1, 120467, '\P{^Soft_Dotted=yes}', "");
Expect(0, 120468, '\p{Soft_Dotted=yes}', "");
Expect(1, 120468, '\p{^Soft_Dotted=yes}', "");
Expect(1, 120468, '\P{Soft_Dotted=yes}', "");
Expect(0, 120468, '\P{^Soft_Dotted=yes}', "");
Expect(1, 120467, '\p{Soft_Dotted=_Yes}', "");
Expect(0, 120467, '\p{^Soft_Dotted=_Yes}', "");
Expect(0, 120467, '\P{Soft_Dotted=_Yes}', "");
Expect(1, 120467, '\P{^Soft_Dotted=_Yes}', "");
Expect(0, 120468, '\p{Soft_Dotted=_Yes}', "");
Expect(1, 120468, '\p{^Soft_Dotted=_Yes}', "");
Expect(1, 120468, '\P{Soft_Dotted=_Yes}', "");
Expect(0, 120468, '\P{^Soft_Dotted=_Yes}', "");
Error('\p{SD=:= _Y}');
Error('\P{SD=:= _Y}');
Expect(1, 120467, '\p{SD=y}', "");
Expect(0, 120467, '\p{^SD=y}', "");
Expect(0, 120467, '\P{SD=y}', "");
Expect(1, 120467, '\P{^SD=y}', "");
Expect(0, 120468, '\p{SD=y}', "");
Expect(1, 120468, '\p{^SD=y}', "");
Expect(1, 120468, '\P{SD=y}', "");
Expect(0, 120468, '\P{^SD=y}', "");
Expect(1, 120467, '\p{SD= Y}', "");
Expect(0, 120467, '\p{^SD= Y}', "");
Expect(0, 120467, '\P{SD= Y}', "");
Expect(1, 120467, '\P{^SD= Y}', "");
Expect(0, 120468, '\p{SD= Y}', "");
Expect(1, 120468, '\p{^SD= Y}', "");
Expect(1, 120468, '\P{SD= Y}', "");
Expect(0, 120468, '\P{^SD= Y}', "");
Error('\p{Is_Soft_Dotted= -T/a/}');
Error('\P{Is_Soft_Dotted= -T/a/}');
Expect(1, 120467, '\p{Is_Soft_Dotted=t}', "");
Expect(0, 120467, '\p{^Is_Soft_Dotted=t}', "");
Expect(0, 120467, '\P{Is_Soft_Dotted=t}', "");
Expect(1, 120467, '\P{^Is_Soft_Dotted=t}', "");
Expect(0, 120468, '\p{Is_Soft_Dotted=t}', "");
Expect(1, 120468, '\p{^Is_Soft_Dotted=t}', "");
Expect(1, 120468, '\P{Is_Soft_Dotted=t}', "");
Expect(0, 120468, '\P{^Is_Soft_Dotted=t}', "");
Expect(1, 120467, '\p{Is_Soft_Dotted=--T}', "");
Expect(0, 120467, '\p{^Is_Soft_Dotted=--T}', "");
Expect(0, 120467, '\P{Is_Soft_Dotted=--T}', "");
Expect(1, 120467, '\P{^Is_Soft_Dotted=--T}', "");
Expect(0, 120468, '\p{Is_Soft_Dotted=--T}', "");
Expect(1, 120468, '\p{^Is_Soft_Dotted=--T}', "");
Expect(1, 120468, '\P{Is_Soft_Dotted=--T}', "");
Expect(0, 120468, '\P{^Is_Soft_Dotted=--T}', "");
Error('\p{Is_SD= -true/a/}');
Error('\P{Is_SD= -true/a/}');
Expect(1, 120467, '\p{Is_SD=true}', "");
Expect(0, 120467, '\p{^Is_SD=true}', "");
Expect(0, 120467, '\P{Is_SD=true}', "");
Expect(1, 120467, '\P{^Is_SD=true}', "");
Expect(0, 120468, '\p{Is_SD=true}', "");
Expect(1, 120468, '\p{^Is_SD=true}', "");
Expect(1, 120468, '\P{Is_SD=true}', "");
Expect(0, 120468, '\P{^Is_SD=true}', "");
Expect(1, 120467, '\p{Is_SD=	true}', "");
Expect(0, 120467, '\p{^Is_SD=	true}', "");
Expect(0, 120467, '\P{Is_SD=	true}', "");
Expect(1, 120467, '\P{^Is_SD=	true}', "");
Expect(0, 120468, '\p{Is_SD=	true}', "");
Expect(1, 120468, '\p{^Is_SD=	true}', "");
Expect(1, 120468, '\P{Is_SD=	true}', "");
Expect(0, 120468, '\P{^Is_SD=	true}', "");
Error('\p{STerm= :=no}');
Error('\P{STerm= :=no}');
Expect(1, 70087, '\p{STerm=no}', "");
Expect(0, 70087, '\p{^STerm=no}', "");
Expect(0, 70087, '\P{STerm=no}', "");
Expect(1, 70087, '\P{^STerm=no}', "");
Expect(0, 70086, '\p{STerm=no}', "");
Expect(1, 70086, '\p{^STerm=no}', "");
Expect(1, 70086, '\P{STerm=no}', "");
Expect(0, 70086, '\P{^STerm=no}', "");
Expect(1, 70087, '\p{STerm=_ no}', "");
Expect(0, 70087, '\p{^STerm=_ no}', "");
Expect(0, 70087, '\P{STerm=_ no}', "");
Expect(1, 70087, '\P{^STerm=_ no}', "");
Expect(0, 70086, '\p{STerm=_ no}', "");
Expect(1, 70086, '\p{^STerm=_ no}', "");
Expect(1, 70086, '\P{STerm=_ no}', "");
Expect(0, 70086, '\P{^STerm=_ no}', "");
Error('\p{Is_STerm=_/a/N}');
Error('\P{Is_STerm=_/a/N}');
Expect(1, 70087, '\p{Is_STerm=n}', "");
Expect(0, 70087, '\p{^Is_STerm=n}', "");
Expect(0, 70087, '\P{Is_STerm=n}', "");
Expect(1, 70087, '\P{^Is_STerm=n}', "");
Expect(0, 70086, '\p{Is_STerm=n}', "");
Expect(1, 70086, '\p{^Is_STerm=n}', "");
Expect(1, 70086, '\P{Is_STerm=n}', "");
Expect(0, 70086, '\P{^Is_STerm=n}', "");
Expect(1, 70087, '\p{Is_STerm=  N}', "");
Expect(0, 70087, '\p{^Is_STerm=  N}', "");
Expect(0, 70087, '\P{Is_STerm=  N}', "");
Expect(1, 70087, '\P{^Is_STerm=  N}', "");
Expect(0, 70086, '\p{Is_STerm=  N}', "");
Expect(1, 70086, '\p{^Is_STerm=  N}', "");
Expect(1, 70086, '\P{Is_STerm=  N}', "");
Expect(0, 70086, '\P{^Is_STerm=  N}', "");
Error('\p{STerm=/a/-F}');
Error('\P{STerm=/a/-F}');
Expect(1, 70087, '\p{STerm=f}', "");
Expect(0, 70087, '\p{^STerm=f}', "");
Expect(0, 70087, '\P{STerm=f}', "");
Expect(1, 70087, '\P{^STerm=f}', "");
Expect(0, 70086, '\p{STerm=f}', "");
Expect(1, 70086, '\p{^STerm=f}', "");
Expect(1, 70086, '\P{STerm=f}', "");
Expect(0, 70086, '\P{^STerm=f}', "");
Expect(1, 70087, '\p{STerm=F}', "");
Expect(0, 70087, '\p{^STerm=F}', "");
Expect(0, 70087, '\P{STerm=F}', "");
Expect(1, 70087, '\P{^STerm=F}', "");
Expect(0, 70086, '\p{STerm=F}', "");
Expect(1, 70086, '\p{^STerm=F}', "");
Expect(1, 70086, '\P{STerm=F}', "");
Expect(0, 70086, '\P{^STerm=F}', "");
Error('\p{Is_STerm: /a/- false}');
Error('\P{Is_STerm: /a/- false}');
Expect(1, 70087, '\p{Is_STerm=false}', "");
Expect(0, 70087, '\p{^Is_STerm=false}', "");
Expect(0, 70087, '\P{Is_STerm=false}', "");
Expect(1, 70087, '\P{^Is_STerm=false}', "");
Expect(0, 70086, '\p{Is_STerm=false}', "");
Expect(1, 70086, '\p{^Is_STerm=false}', "");
Expect(1, 70086, '\P{Is_STerm=false}', "");
Expect(0, 70086, '\P{^Is_STerm=false}', "");
Expect(1, 70087, '\p{Is_STerm=-False}', "");
Expect(0, 70087, '\p{^Is_STerm=-False}', "");
Expect(0, 70087, '\P{Is_STerm=-False}', "");
Expect(1, 70087, '\P{^Is_STerm=-False}', "");
Expect(0, 70086, '\p{Is_STerm=-False}', "");
Expect(1, 70086, '\p{^Is_STerm=-False}', "");
Expect(1, 70086, '\P{Is_STerm=-False}', "");
Expect(0, 70086, '\P{^Is_STerm=-False}', "");
Error('\p{STerm:	:=Yes}');
Error('\P{STerm:	:=Yes}');
Expect(1, 70086, '\p{STerm=yes}', "");
Expect(0, 70086, '\p{^STerm=yes}', "");
Expect(0, 70086, '\P{STerm=yes}', "");
Expect(1, 70086, '\P{^STerm=yes}', "");
Expect(0, 70087, '\p{STerm=yes}', "");
Expect(1, 70087, '\p{^STerm=yes}', "");
Expect(1, 70087, '\P{STerm=yes}', "");
Expect(0, 70087, '\P{^STerm=yes}', "");
Expect(1, 70086, '\p{STerm=-	YES}', "");
Expect(0, 70086, '\p{^STerm=-	YES}', "");
Expect(0, 70086, '\P{STerm=-	YES}', "");
Expect(1, 70086, '\P{^STerm=-	YES}', "");
Expect(0, 70087, '\p{STerm=-	YES}', "");
Expect(1, 70087, '\p{^STerm=-	YES}', "");
Expect(1, 70087, '\P{STerm=-	YES}', "");
Expect(0, 70087, '\P{^STerm=-	YES}', "");
Error('\p{Is_STerm=:=_Y}');
Error('\P{Is_STerm=:=_Y}');
Expect(1, 70086, '\p{Is_STerm=y}', "");
Expect(0, 70086, '\p{^Is_STerm=y}', "");
Expect(0, 70086, '\P{Is_STerm=y}', "");
Expect(1, 70086, '\P{^Is_STerm=y}', "");
Expect(0, 70087, '\p{Is_STerm=y}', "");
Expect(1, 70087, '\p{^Is_STerm=y}', "");
Expect(1, 70087, '\P{Is_STerm=y}', "");
Expect(0, 70087, '\P{^Is_STerm=y}', "");
Expect(1, 70086, '\p{Is_STerm=-_Y}', "");
Expect(0, 70086, '\p{^Is_STerm=-_Y}', "");
Expect(0, 70086, '\P{Is_STerm=-_Y}', "");
Expect(1, 70086, '\P{^Is_STerm=-_Y}', "");
Expect(0, 70087, '\p{Is_STerm=-_Y}', "");
Expect(1, 70087, '\p{^Is_STerm=-_Y}', "");
Expect(1, 70087, '\P{Is_STerm=-_Y}', "");
Expect(0, 70087, '\P{^Is_STerm=-_Y}', "");
Error('\p{STerm: :=-	T}');
Error('\P{STerm: :=-	T}');
Expect(1, 70086, '\p{STerm=t}', "");
Expect(0, 70086, '\p{^STerm=t}', "");
Expect(0, 70086, '\P{STerm=t}', "");
Expect(1, 70086, '\P{^STerm=t}', "");
Expect(0, 70087, '\p{STerm=t}', "");
Expect(1, 70087, '\p{^STerm=t}', "");
Expect(1, 70087, '\P{STerm=t}', "");
Expect(0, 70087, '\P{^STerm=t}', "");
Expect(1, 70086, '\p{STerm=_	t}', "");
Expect(0, 70086, '\p{^STerm=_	t}', "");
Expect(0, 70086, '\P{STerm=_	t}', "");
Expect(1, 70086, '\P{^STerm=_	t}', "");
Expect(0, 70087, '\p{STerm=_	t}', "");
Expect(1, 70087, '\p{^STerm=_	t}', "");
Expect(1, 70087, '\P{STerm=_	t}', "");
Expect(0, 70087, '\P{^STerm=_	t}', "");
Error('\p{Is_STerm=/a/	_True}');
Error('\P{Is_STerm=/a/	_True}');
Expect(1, 70086, '\p{Is_STerm=true}', "");
Expect(0, 70086, '\p{^Is_STerm=true}', "");
Expect(0, 70086, '\P{Is_STerm=true}', "");
Expect(1, 70086, '\P{^Is_STerm=true}', "");
Expect(0, 70087, '\p{Is_STerm=true}', "");
Expect(1, 70087, '\p{^Is_STerm=true}', "");
Expect(1, 70087, '\P{Is_STerm=true}', "");
Expect(0, 70087, '\P{^Is_STerm=true}', "");
Expect(1, 70086, '\p{Is_STerm=_ True}', "");
Expect(0, 70086, '\p{^Is_STerm=_ True}', "");
Expect(0, 70086, '\P{Is_STerm=_ True}', "");
Expect(1, 70086, '\P{^Is_STerm=_ True}', "");
Expect(0, 70087, '\p{Is_STerm=_ True}', "");
Expect(1, 70087, '\p{^Is_STerm=_ True}', "");
Expect(1, 70087, '\P{Is_STerm=_ True}', "");
Expect(0, 70087, '\P{^Is_STerm=_ True}', "");
Error('\p{Terminal_Punctuation=/a/-No}');
Error('\P{Terminal_Punctuation=/a/-No}');
Expect(1, 74868, '\p{Terminal_Punctuation=no}', "");
Expect(0, 74868, '\p{^Terminal_Punctuation=no}', "");
Expect(0, 74868, '\P{Terminal_Punctuation=no}', "");
Expect(1, 74868, '\P{^Terminal_Punctuation=no}', "");
Expect(0, 74867, '\p{Terminal_Punctuation=no}', "");
Expect(1, 74867, '\p{^Terminal_Punctuation=no}', "");
Expect(1, 74867, '\P{Terminal_Punctuation=no}', "");
Expect(0, 74867, '\P{^Terminal_Punctuation=no}', "");
Expect(1, 74868, '\p{Terminal_Punctuation=_NO}', "");
Expect(0, 74868, '\p{^Terminal_Punctuation=_NO}', "");
Expect(0, 74868, '\P{Terminal_Punctuation=_NO}', "");
Expect(1, 74868, '\P{^Terminal_Punctuation=_NO}', "");
Expect(0, 74867, '\p{Terminal_Punctuation=_NO}', "");
Expect(1, 74867, '\p{^Terminal_Punctuation=_NO}', "");
Expect(1, 74867, '\P{Terminal_Punctuation=_NO}', "");
Expect(0, 74867, '\P{^Terminal_Punctuation=_NO}', "");
Error('\p{Term=/a/  n}');
Error('\P{Term=/a/  n}');
Expect(1, 74868, '\p{Term=n}', "");
Expect(0, 74868, '\p{^Term=n}', "");
Expect(0, 74868, '\P{Term=n}', "");
Expect(1, 74868, '\P{^Term=n}', "");
Expect(0, 74867, '\p{Term=n}', "");
Expect(1, 74867, '\p{^Term=n}', "");
Expect(1, 74867, '\P{Term=n}', "");
Expect(0, 74867, '\P{^Term=n}', "");
Expect(1, 74868, '\p{Term= n}', "");
Expect(0, 74868, '\p{^Term= n}', "");
Expect(0, 74868, '\P{Term= n}', "");
Expect(1, 74868, '\P{^Term= n}', "");
Expect(0, 74867, '\p{Term= n}', "");
Expect(1, 74867, '\p{^Term= n}', "");
Expect(1, 74867, '\P{Term= n}', "");
Expect(0, 74867, '\P{^Term= n}', "");
Error('\p{Is_Terminal_Punctuation:   -f:=}');
Error('\P{Is_Terminal_Punctuation:   -f:=}');
Expect(1, 74868, '\p{Is_Terminal_Punctuation=f}', "");
Expect(0, 74868, '\p{^Is_Terminal_Punctuation=f}', "");
Expect(0, 74868, '\P{Is_Terminal_Punctuation=f}', "");
Expect(1, 74868, '\P{^Is_Terminal_Punctuation=f}', "");
Expect(0, 74867, '\p{Is_Terminal_Punctuation=f}', "");
Expect(1, 74867, '\p{^Is_Terminal_Punctuation=f}', "");
Expect(1, 74867, '\P{Is_Terminal_Punctuation=f}', "");
Expect(0, 74867, '\P{^Is_Terminal_Punctuation=f}', "");
Expect(1, 74868, '\p{Is_Terminal_Punctuation: _F}', "");
Expect(0, 74868, '\p{^Is_Terminal_Punctuation: _F}', "");
Expect(0, 74868, '\P{Is_Terminal_Punctuation: _F}', "");
Expect(1, 74868, '\P{^Is_Terminal_Punctuation: _F}', "");
Expect(0, 74867, '\p{Is_Terminal_Punctuation: _F}', "");
Expect(1, 74867, '\p{^Is_Terminal_Punctuation: _F}', "");
Expect(1, 74867, '\P{Is_Terminal_Punctuation: _F}', "");
Expect(0, 74867, '\P{^Is_Terminal_Punctuation: _F}', "");
Error('\p{Is_Term=:=FALSE}');
Error('\P{Is_Term=:=FALSE}');
Expect(1, 74868, '\p{Is_Term=false}', "");
Expect(0, 74868, '\p{^Is_Term=false}', "");
Expect(0, 74868, '\P{Is_Term=false}', "");
Expect(1, 74868, '\P{^Is_Term=false}', "");
Expect(0, 74867, '\p{Is_Term=false}', "");
Expect(1, 74867, '\p{^Is_Term=false}', "");
Expect(1, 74867, '\P{Is_Term=false}', "");
Expect(0, 74867, '\P{^Is_Term=false}', "");
Expect(1, 74868, '\p{Is_Term= False}', "");
Expect(0, 74868, '\p{^Is_Term= False}', "");
Expect(0, 74868, '\P{Is_Term= False}', "");
Expect(1, 74868, '\P{^Is_Term= False}', "");
Expect(0, 74867, '\p{Is_Term= False}', "");
Expect(1, 74867, '\p{^Is_Term= False}', "");
Expect(1, 74867, '\P{Is_Term= False}', "");
Expect(0, 74867, '\P{^Is_Term= False}', "");
Error('\p{Terminal_Punctuation=:=--YES}');
Error('\P{Terminal_Punctuation=:=--YES}');
Expect(1, 74867, '\p{Terminal_Punctuation=yes}', "");
Expect(0, 74867, '\p{^Terminal_Punctuation=yes}', "");
Expect(0, 74867, '\P{Terminal_Punctuation=yes}', "");
Expect(1, 74867, '\P{^Terminal_Punctuation=yes}', "");
Expect(0, 74868, '\p{Terminal_Punctuation=yes}', "");
Expect(1, 74868, '\p{^Terminal_Punctuation=yes}', "");
Expect(1, 74868, '\P{Terminal_Punctuation=yes}', "");
Expect(0, 74868, '\P{^Terminal_Punctuation=yes}', "");
Expect(1, 74867, '\p{Terminal_Punctuation= Yes}', "");
Expect(0, 74867, '\p{^Terminal_Punctuation= Yes}', "");
Expect(0, 74867, '\P{Terminal_Punctuation= Yes}', "");
Expect(1, 74867, '\P{^Terminal_Punctuation= Yes}', "");
Expect(0, 74868, '\p{Terminal_Punctuation= Yes}', "");
Expect(1, 74868, '\p{^Terminal_Punctuation= Yes}', "");
Expect(1, 74868, '\P{Terminal_Punctuation= Yes}', "");
Expect(0, 74868, '\P{^Terminal_Punctuation= Yes}', "");
Error('\p{Term=		Y/a/}');
Error('\P{Term=		Y/a/}');
Expect(1, 74867, '\p{Term:   y}', "");
Expect(0, 74867, '\p{^Term:   y}', "");
Expect(0, 74867, '\P{Term:   y}', "");
Expect(1, 74867, '\P{^Term:   y}', "");
Expect(0, 74868, '\p{Term:   y}', "");
Expect(1, 74868, '\p{^Term:   y}', "");
Expect(1, 74868, '\P{Term:   y}', "");
Expect(0, 74868, '\P{^Term:   y}', "");
Expect(1, 74867, '\p{Term=	Y}', "");
Expect(0, 74867, '\p{^Term=	Y}', "");
Expect(0, 74867, '\P{Term=	Y}', "");
Expect(1, 74867, '\P{^Term=	Y}', "");
Expect(0, 74868, '\p{Term=	Y}', "");
Expect(1, 74868, '\p{^Term=	Y}', "");
Expect(1, 74868, '\P{Term=	Y}', "");
Expect(0, 74868, '\P{^Term=	Y}', "");
Error('\p{Is_Terminal_Punctuation=-_T:=}');
Error('\P{Is_Terminal_Punctuation=-_T:=}');
Expect(1, 74867, '\p{Is_Terminal_Punctuation=t}', "");
Expect(0, 74867, '\p{^Is_Terminal_Punctuation=t}', "");
Expect(0, 74867, '\P{Is_Terminal_Punctuation=t}', "");
Expect(1, 74867, '\P{^Is_Terminal_Punctuation=t}', "");
Expect(0, 74868, '\p{Is_Terminal_Punctuation=t}', "");
Expect(1, 74868, '\p{^Is_Terminal_Punctuation=t}', "");
Expect(1, 74868, '\P{Is_Terminal_Punctuation=t}', "");
Expect(0, 74868, '\P{^Is_Terminal_Punctuation=t}', "");
Expect(1, 74867, '\p{Is_Terminal_Punctuation=		T}', "");
Expect(0, 74867, '\p{^Is_Terminal_Punctuation=		T}', "");
Expect(0, 74867, '\P{Is_Terminal_Punctuation=		T}', "");
Expect(1, 74867, '\P{^Is_Terminal_Punctuation=		T}', "");
Expect(0, 74868, '\p{Is_Terminal_Punctuation=		T}', "");
Expect(1, 74868, '\p{^Is_Terminal_Punctuation=		T}', "");
Expect(1, 74868, '\P{Is_Terminal_Punctuation=		T}', "");
Expect(0, 74868, '\P{^Is_Terminal_Punctuation=		T}', "");
Error('\p{Is_Term:   /a/ True}');
Error('\P{Is_Term:   /a/ True}');
Expect(1, 74867, '\p{Is_Term:	true}', "");
Expect(0, 74867, '\p{^Is_Term:	true}', "");
Expect(0, 74867, '\P{Is_Term:	true}', "");
Expect(1, 74867, '\P{^Is_Term:	true}', "");
Expect(0, 74868, '\p{Is_Term:	true}', "");
Expect(1, 74868, '\p{^Is_Term:	true}', "");
Expect(1, 74868, '\P{Is_Term:	true}', "");
Expect(0, 74868, '\P{^Is_Term:	true}', "");
Expect(1, 74867, '\p{Is_Term:	__true}', "");
Expect(0, 74867, '\p{^Is_Term:	__true}', "");
Expect(0, 74867, '\P{Is_Term:	__true}', "");
Expect(1, 74867, '\P{^Is_Term:	__true}', "");
Expect(0, 74868, '\p{Is_Term:	__true}', "");
Expect(1, 74868, '\p{^Is_Term:	__true}', "");
Expect(1, 74868, '\P{Is_Term:	__true}', "");
Expect(0, 74868, '\P{^Is_Term:	__true}', "");
Error('\p{Unified_Ideograph=/a/- NO}');
Error('\P{Unified_Ideograph=/a/- NO}');
Expect(1, 178206, '\p{Unified_Ideograph=no}', "");
Expect(0, 178206, '\p{^Unified_Ideograph=no}', "");
Expect(0, 178206, '\P{Unified_Ideograph=no}', "");
Expect(1, 178206, '\P{^Unified_Ideograph=no}', "");
Expect(0, 178205, '\p{Unified_Ideograph=no}', "");
Expect(1, 178205, '\p{^Unified_Ideograph=no}', "");
Expect(1, 178205, '\P{Unified_Ideograph=no}', "");
Expect(0, 178205, '\P{^Unified_Ideograph=no}', "");
Expect(1, 178206, '\p{Unified_Ideograph=-	No}', "");
Expect(0, 178206, '\p{^Unified_Ideograph=-	No}', "");
Expect(0, 178206, '\P{Unified_Ideograph=-	No}', "");
Expect(1, 178206, '\P{^Unified_Ideograph=-	No}', "");
Expect(0, 178205, '\p{Unified_Ideograph=-	No}', "");
Expect(1, 178205, '\p{^Unified_Ideograph=-	No}', "");
Expect(1, 178205, '\P{Unified_Ideograph=-	No}', "");
Expect(0, 178205, '\P{^Unified_Ideograph=-	No}', "");
Error('\p{UIdeo= _n/a/}');
Error('\P{UIdeo= _n/a/}');
Expect(1, 178206, '\p{UIdeo=n}', "");
Expect(0, 178206, '\p{^UIdeo=n}', "");
Expect(0, 178206, '\P{UIdeo=n}', "");
Expect(1, 178206, '\P{^UIdeo=n}', "");
Expect(0, 178205, '\p{UIdeo=n}', "");
Expect(1, 178205, '\p{^UIdeo=n}', "");
Expect(1, 178205, '\P{UIdeo=n}', "");
Expect(0, 178205, '\P{^UIdeo=n}', "");
Expect(1, 178206, '\p{UIdeo=-_N}', "");
Expect(0, 178206, '\p{^UIdeo=-_N}', "");
Expect(0, 178206, '\P{UIdeo=-_N}', "");
Expect(1, 178206, '\P{^UIdeo=-_N}', "");
Expect(0, 178205, '\p{UIdeo=-_N}', "");
Expect(1, 178205, '\p{^UIdeo=-_N}', "");
Expect(1, 178205, '\P{UIdeo=-_N}', "");
Expect(0, 178205, '\P{^UIdeo=-_N}', "");
Error('\p{Is_Unified_Ideograph=:= 	F}');
Error('\P{Is_Unified_Ideograph=:= 	F}');
Expect(1, 178206, '\p{Is_Unified_Ideograph=f}', "");
Expect(0, 178206, '\p{^Is_Unified_Ideograph=f}', "");
Expect(0, 178206, '\P{Is_Unified_Ideograph=f}', "");
Expect(1, 178206, '\P{^Is_Unified_Ideograph=f}', "");
Expect(0, 178205, '\p{Is_Unified_Ideograph=f}', "");
Expect(1, 178205, '\p{^Is_Unified_Ideograph=f}', "");
Expect(1, 178205, '\P{Is_Unified_Ideograph=f}', "");
Expect(0, 178205, '\P{^Is_Unified_Ideograph=f}', "");
Expect(1, 178206, '\p{Is_Unified_Ideograph=_	F}', "");
Expect(0, 178206, '\p{^Is_Unified_Ideograph=_	F}', "");
Expect(0, 178206, '\P{Is_Unified_Ideograph=_	F}', "");
Expect(1, 178206, '\P{^Is_Unified_Ideograph=_	F}', "");
Expect(0, 178205, '\p{Is_Unified_Ideograph=_	F}', "");
Expect(1, 178205, '\p{^Is_Unified_Ideograph=_	F}', "");
Expect(1, 178205, '\P{Is_Unified_Ideograph=_	F}', "");
Expect(0, 178205, '\P{^Is_Unified_Ideograph=_	F}', "");
Error('\p{Is_UIdeo=_/a/FALSE}');
Error('\P{Is_UIdeo=_/a/FALSE}');
Expect(1, 178206, '\p{Is_UIdeo=false}', "");
Expect(0, 178206, '\p{^Is_UIdeo=false}', "");
Expect(0, 178206, '\P{Is_UIdeo=false}', "");
Expect(1, 178206, '\P{^Is_UIdeo=false}', "");
Expect(0, 178205, '\p{Is_UIdeo=false}', "");
Expect(1, 178205, '\p{^Is_UIdeo=false}', "");
Expect(1, 178205, '\P{Is_UIdeo=false}', "");
Expect(0, 178205, '\P{^Is_UIdeo=false}', "");
Expect(1, 178206, '\p{Is_UIdeo=_-FALSE}', "");
Expect(0, 178206, '\p{^Is_UIdeo=_-FALSE}', "");
Expect(0, 178206, '\P{Is_UIdeo=_-FALSE}', "");
Expect(1, 178206, '\P{^Is_UIdeo=_-FALSE}', "");
Expect(0, 178205, '\p{Is_UIdeo=_-FALSE}', "");
Expect(1, 178205, '\p{^Is_UIdeo=_-FALSE}', "");
Expect(1, 178205, '\P{Is_UIdeo=_-FALSE}', "");
Expect(0, 178205, '\P{^Is_UIdeo=_-FALSE}', "");
Error('\p{Unified_Ideograph=Yes/a/}');
Error('\P{Unified_Ideograph=Yes/a/}');
Expect(1, 178205, '\p{Unified_Ideograph=yes}', "");
Expect(0, 178205, '\p{^Unified_Ideograph=yes}', "");
Expect(0, 178205, '\P{Unified_Ideograph=yes}', "");
Expect(1, 178205, '\P{^Unified_Ideograph=yes}', "");
Expect(0, 178206, '\p{Unified_Ideograph=yes}', "");
Expect(1, 178206, '\p{^Unified_Ideograph=yes}', "");
Expect(1, 178206, '\P{Unified_Ideograph=yes}', "");
Expect(0, 178206, '\P{^Unified_Ideograph=yes}', "");
Expect(1, 178205, '\p{Unified_Ideograph=__YES}', "");
Expect(0, 178205, '\p{^Unified_Ideograph=__YES}', "");
Expect(0, 178205, '\P{Unified_Ideograph=__YES}', "");
Expect(1, 178205, '\P{^Unified_Ideograph=__YES}', "");
Expect(0, 178206, '\p{Unified_Ideograph=__YES}', "");
Expect(1, 178206, '\p{^Unified_Ideograph=__YES}', "");
Expect(1, 178206, '\P{Unified_Ideograph=__YES}', "");
Expect(0, 178206, '\P{^Unified_Ideograph=__YES}', "");
Error('\p{UIdeo:   /a/_	Y}');
Error('\P{UIdeo:   /a/_	Y}');
Expect(1, 178205, '\p{UIdeo=y}', "");
Expect(0, 178205, '\p{^UIdeo=y}', "");
Expect(0, 178205, '\P{UIdeo=y}', "");
Expect(1, 178205, '\P{^UIdeo=y}', "");
Expect(0, 178206, '\p{UIdeo=y}', "");
Expect(1, 178206, '\p{^UIdeo=y}', "");
Expect(1, 178206, '\P{UIdeo=y}', "");
Expect(0, 178206, '\P{^UIdeo=y}', "");
Expect(1, 178205, '\p{UIdeo=-Y}', "");
Expect(0, 178205, '\p{^UIdeo=-Y}', "");
Expect(0, 178205, '\P{UIdeo=-Y}', "");
Expect(1, 178205, '\P{^UIdeo=-Y}', "");
Expect(0, 178206, '\p{UIdeo=-Y}', "");
Expect(1, 178206, '\p{^UIdeo=-Y}', "");
Expect(1, 178206, '\P{UIdeo=-Y}', "");
Expect(0, 178206, '\P{^UIdeo=-Y}', "");
Error('\p{Is_Unified_Ideograph= /a/T}');
Error('\P{Is_Unified_Ideograph= /a/T}');
Expect(1, 178205, '\p{Is_Unified_Ideograph=t}', "");
Expect(0, 178205, '\p{^Is_Unified_Ideograph=t}', "");
Expect(0, 178205, '\P{Is_Unified_Ideograph=t}', "");
Expect(1, 178205, '\P{^Is_Unified_Ideograph=t}', "");
Expect(0, 178206, '\p{Is_Unified_Ideograph=t}', "");
Expect(1, 178206, '\p{^Is_Unified_Ideograph=t}', "");
Expect(1, 178206, '\P{Is_Unified_Ideograph=t}', "");
Expect(0, 178206, '\P{^Is_Unified_Ideograph=t}', "");
Expect(1, 178205, '\p{Is_Unified_Ideograph= t}', "");
Expect(0, 178205, '\p{^Is_Unified_Ideograph= t}', "");
Expect(0, 178205, '\P{Is_Unified_Ideograph= t}', "");
Expect(1, 178205, '\P{^Is_Unified_Ideograph= t}', "");
Expect(0, 178206, '\p{Is_Unified_Ideograph= t}', "");
Expect(1, 178206, '\p{^Is_Unified_Ideograph= t}', "");
Expect(1, 178206, '\P{Is_Unified_Ideograph= t}', "");
Expect(0, 178206, '\P{^Is_Unified_Ideograph= t}', "");
Error('\p{Is_UIdeo=TRUE:=}');
Error('\P{Is_UIdeo=TRUE:=}');
Expect(1, 178205, '\p{Is_UIdeo=true}', "");
Expect(0, 178205, '\p{^Is_UIdeo=true}', "");
Expect(0, 178205, '\P{Is_UIdeo=true}', "");
Expect(1, 178205, '\P{^Is_UIdeo=true}', "");
Expect(0, 178206, '\p{Is_UIdeo=true}', "");
Expect(1, 178206, '\p{^Is_UIdeo=true}', "");
Expect(1, 178206, '\P{Is_UIdeo=true}', "");
Expect(0, 178206, '\P{^Is_UIdeo=true}', "");
Expect(1, 178205, '\p{Is_UIdeo=True}', "");
Expect(0, 178205, '\p{^Is_UIdeo=True}', "");
Expect(0, 178205, '\P{Is_UIdeo=True}', "");
Expect(1, 178205, '\P{^Is_UIdeo=True}', "");
Expect(0, 178206, '\p{Is_UIdeo=True}', "");
Expect(1, 178206, '\p{^Is_UIdeo=True}', "");
Expect(1, 178206, '\P{Is_UIdeo=True}', "");
Expect(0, 178206, '\P{^Is_UIdeo=True}', "");
Error('\p{Uppercase=/a/		NO}');
Error('\P{Uppercase=/a/		NO}');
Expect(1, 120779, '\p{Uppercase=no}', "");
Expect(0, 120779, '\p{^Uppercase=no}', "");
Expect(0, 120779, '\P{Uppercase=no}', "");
Expect(1, 120779, '\P{^Uppercase=no}', "");
Expect(0, 120778, '\p{Uppercase=no}', "");
Expect(1, 120778, '\p{^Uppercase=no}', "");
Expect(1, 120778, '\P{Uppercase=no}', "");
Expect(0, 120778, '\P{^Uppercase=no}', "");
Expect(1, 120779, '\p{Uppercase=_ NO}', "");
Expect(0, 120779, '\p{^Uppercase=_ NO}', "");
Expect(0, 120779, '\P{Uppercase=_ NO}', "");
Expect(1, 120779, '\P{^Uppercase=_ NO}', "");
Expect(0, 120778, '\p{Uppercase=_ NO}', "");
Expect(1, 120778, '\p{^Uppercase=_ NO}', "");
Expect(1, 120778, '\P{Uppercase=_ NO}', "");
Expect(0, 120778, '\P{^Uppercase=_ NO}', "");
Error('\p{Upper=:=N}');
Error('\P{Upper=:=N}');
Expect(1, 120779, '\p{Upper=n}', "");
Expect(0, 120779, '\p{^Upper=n}', "");
Expect(0, 120779, '\P{Upper=n}', "");
Expect(1, 120779, '\P{^Upper=n}', "");
Expect(0, 120778, '\p{Upper=n}', "");
Expect(1, 120778, '\p{^Upper=n}', "");
Expect(1, 120778, '\P{Upper=n}', "");
Expect(0, 120778, '\P{^Upper=n}', "");
Expect(1, 120779, '\p{Upper=--N}', "");
Expect(0, 120779, '\p{^Upper=--N}', "");
Expect(0, 120779, '\P{Upper=--N}', "");
Expect(1, 120779, '\P{^Upper=--N}', "");
Expect(0, 120778, '\p{Upper=--N}', "");
Expect(1, 120778, '\p{^Upper=--N}', "");
Expect(1, 120778, '\P{Upper=--N}', "");
Expect(0, 120778, '\P{^Upper=--N}', "");
Error('\p{Is_Uppercase:		:=f}');
Error('\P{Is_Uppercase:		:=f}');
Expect(1, 120779, '\p{Is_Uppercase=f}', "");
Expect(0, 120779, '\p{^Is_Uppercase=f}', "");
Expect(0, 120779, '\P{Is_Uppercase=f}', "");
Expect(1, 120779, '\P{^Is_Uppercase=f}', "");
Expect(0, 120778, '\p{Is_Uppercase=f}', "");
Expect(1, 120778, '\p{^Is_Uppercase=f}', "");
Expect(1, 120778, '\P{Is_Uppercase=f}', "");
Expect(0, 120778, '\P{^Is_Uppercase=f}', "");
Expect(1, 120779, '\p{Is_Uppercase=_	f}', "");
Expect(0, 120779, '\p{^Is_Uppercase=_	f}', "");
Expect(0, 120779, '\P{Is_Uppercase=_	f}', "");
Expect(1, 120779, '\P{^Is_Uppercase=_	f}', "");
Expect(0, 120778, '\p{Is_Uppercase=_	f}', "");
Expect(1, 120778, '\p{^Is_Uppercase=_	f}', "");
Expect(1, 120778, '\P{Is_Uppercase=_	f}', "");
Expect(0, 120778, '\P{^Is_Uppercase=_	f}', "");
Error('\p{Is_Upper=/a/_false}');
Error('\P{Is_Upper=/a/_false}');
Expect(1, 120779, '\p{Is_Upper=false}', "");
Expect(0, 120779, '\p{^Is_Upper=false}', "");
Expect(0, 120779, '\P{Is_Upper=false}', "");
Expect(1, 120779, '\P{^Is_Upper=false}', "");
Expect(0, 120778, '\p{Is_Upper=false}', "");
Expect(1, 120778, '\p{^Is_Upper=false}', "");
Expect(1, 120778, '\P{Is_Upper=false}', "");
Expect(0, 120778, '\P{^Is_Upper=false}', "");
Expect(1, 120779, '\p{Is_Upper=  False}', "");
Expect(0, 120779, '\p{^Is_Upper=  False}', "");
Expect(0, 120779, '\P{Is_Upper=  False}', "");
Expect(1, 120779, '\P{^Is_Upper=  False}', "");
Expect(0, 120778, '\p{Is_Upper=  False}', "");
Expect(1, 120778, '\p{^Is_Upper=  False}', "");
Expect(1, 120778, '\P{Is_Upper=  False}', "");
Expect(0, 120778, '\P{^Is_Upper=  False}', "");
Error('\p{Uppercase:/a/-YES}');
Error('\P{Uppercase:/a/-YES}');
Expect(1, 120778, '\p{Uppercase=yes}', "");
Expect(0, 120778, '\p{^Uppercase=yes}', "");
Expect(0, 120778, '\P{Uppercase=yes}', "");
Expect(1, 120778, '\P{^Uppercase=yes}', "");
Expect(0, 120779, '\p{Uppercase=yes}', "");
Expect(1, 120779, '\p{^Uppercase=yes}', "");
Expect(1, 120779, '\P{Uppercase=yes}', "");
Expect(0, 120779, '\P{^Uppercase=yes}', "");
Expect(1, 120778, '\p{Uppercase=__Yes}', "");
Expect(0, 120778, '\p{^Uppercase=__Yes}', "");
Expect(0, 120778, '\P{Uppercase=__Yes}', "");
Expect(1, 120778, '\P{^Uppercase=__Yes}', "");
Expect(0, 120779, '\p{Uppercase=__Yes}', "");
Expect(1, 120779, '\p{^Uppercase=__Yes}', "");
Expect(1, 120779, '\P{Uppercase=__Yes}', "");
Expect(0, 120779, '\P{^Uppercase=__Yes}', "");
Error('\p{Upper=/a/-Y}');
Error('\P{Upper=/a/-Y}');
Expect(1, 120778, '\p{Upper=y}', "");
Expect(0, 120778, '\p{^Upper=y}', "");
Expect(0, 120778, '\P{Upper=y}', "");
Expect(1, 120778, '\P{^Upper=y}', "");
Expect(0, 120779, '\p{Upper=y}', "");
Expect(1, 120779, '\p{^Upper=y}', "");
Expect(1, 120779, '\P{Upper=y}', "");
Expect(0, 120779, '\P{^Upper=y}', "");
Expect(1, 120778, '\p{Upper=- Y}', "");
Expect(0, 120778, '\p{^Upper=- Y}', "");
Expect(0, 120778, '\P{Upper=- Y}', "");
Expect(1, 120778, '\P{^Upper=- Y}', "");
Expect(0, 120779, '\p{Upper=- Y}', "");
Expect(1, 120779, '\p{^Upper=- Y}', "");
Expect(1, 120779, '\P{Upper=- Y}', "");
Expect(0, 120779, '\P{^Upper=- Y}', "");
Error('\p{Is_Uppercase=-:=T}');
Error('\P{Is_Uppercase=-:=T}');
Expect(1, 120778, '\p{Is_Uppercase=t}', "");
Expect(0, 120778, '\p{^Is_Uppercase=t}', "");
Expect(0, 120778, '\P{Is_Uppercase=t}', "");
Expect(1, 120778, '\P{^Is_Uppercase=t}', "");
Expect(0, 120779, '\p{Is_Uppercase=t}', "");
Expect(1, 120779, '\p{^Is_Uppercase=t}', "");
Expect(1, 120779, '\P{Is_Uppercase=t}', "");
Expect(0, 120779, '\P{^Is_Uppercase=t}', "");
Expect(1, 120778, '\p{Is_Uppercase=  T}', "");
Expect(0, 120778, '\p{^Is_Uppercase=  T}', "");
Expect(0, 120778, '\P{Is_Uppercase=  T}', "");
Expect(1, 120778, '\P{^Is_Uppercase=  T}', "");
Expect(0, 120779, '\p{Is_Uppercase=  T}', "");
Expect(1, 120779, '\p{^Is_Uppercase=  T}', "");
Expect(1, 120779, '\P{Is_Uppercase=  T}', "");
Expect(0, 120779, '\P{^Is_Uppercase=  T}', "");
Error('\p{Is_Upper=:=	 True}');
Error('\P{Is_Upper=:=	 True}');
Expect(1, 120778, '\p{Is_Upper=true}', "");
Expect(0, 120778, '\p{^Is_Upper=true}', "");
Expect(0, 120778, '\P{Is_Upper=true}', "");
Expect(1, 120778, '\P{^Is_Upper=true}', "");
Expect(0, 120779, '\p{Is_Upper=true}', "");
Expect(1, 120779, '\p{^Is_Upper=true}', "");
Expect(1, 120779, '\P{Is_Upper=true}', "");
Expect(0, 120779, '\P{^Is_Upper=true}', "");
Expect(1, 120778, '\p{Is_Upper=-	True}', "");
Expect(0, 120778, '\p{^Is_Upper=-	True}', "");
Expect(0, 120778, '\P{Is_Upper=-	True}', "");
Expect(1, 120778, '\P{^Is_Upper=-	True}', "");
Expect(0, 120779, '\p{Is_Upper=-	True}', "");
Expect(1, 120779, '\p{^Is_Upper=-	True}', "");
Expect(1, 120779, '\P{Is_Upper=-	True}', "");
Expect(0, 120779, '\P{^Is_Upper=-	True}', "");
Error('\p{Variation_Selector: /a/-_NO}');
Error('\P{Variation_Selector: /a/-_NO}');
Expect(1, 918000, '\p{Variation_Selector:	no}', "");
Expect(0, 918000, '\p{^Variation_Selector:	no}', "");
Expect(0, 918000, '\P{Variation_Selector:	no}', "");
Expect(1, 918000, '\P{^Variation_Selector:	no}', "");
Expect(0, 917999, '\p{Variation_Selector:	no}', "");
Expect(1, 917999, '\p{^Variation_Selector:	no}', "");
Expect(1, 917999, '\P{Variation_Selector:	no}', "");
Expect(0, 917999, '\P{^Variation_Selector:	no}', "");
Expect(1, 918000, '\p{Variation_Selector: _	No}', "");
Expect(0, 918000, '\p{^Variation_Selector: _	No}', "");
Expect(0, 918000, '\P{Variation_Selector: _	No}', "");
Expect(1, 918000, '\P{^Variation_Selector: _	No}', "");
Expect(0, 917999, '\p{Variation_Selector: _	No}', "");
Expect(1, 917999, '\p{^Variation_Selector: _	No}', "");
Expect(1, 917999, '\P{Variation_Selector: _	No}', "");
Expect(0, 917999, '\P{^Variation_Selector: _	No}', "");
Error('\p{VS=N/a/}');
Error('\P{VS=N/a/}');
Expect(1, 918000, '\p{VS=n}', "");
Expect(0, 918000, '\p{^VS=n}', "");
Expect(0, 918000, '\P{VS=n}', "");
Expect(1, 918000, '\P{^VS=n}', "");
Expect(0, 917999, '\p{VS=n}', "");
Expect(1, 917999, '\p{^VS=n}', "");
Expect(1, 917999, '\P{VS=n}', "");
Expect(0, 917999, '\P{^VS=n}', "");
Expect(1, 918000, '\p{VS=-n}', "");
Expect(0, 918000, '\p{^VS=-n}', "");
Expect(0, 918000, '\P{VS=-n}', "");
Expect(1, 918000, '\P{^VS=-n}', "");
Expect(0, 917999, '\p{VS=-n}', "");
Expect(1, 917999, '\p{^VS=-n}', "");
Expect(1, 917999, '\P{VS=-n}', "");
Expect(0, 917999, '\P{^VS=-n}', "");
Error('\p{Is_Variation_Selector=-_f/a/}');
Error('\P{Is_Variation_Selector=-_f/a/}');
Expect(1, 918000, '\p{Is_Variation_Selector=f}', "");
Expect(0, 918000, '\p{^Is_Variation_Selector=f}', "");
Expect(0, 918000, '\P{Is_Variation_Selector=f}', "");
Expect(1, 918000, '\P{^Is_Variation_Selector=f}', "");
Expect(0, 917999, '\p{Is_Variation_Selector=f}', "");
Expect(1, 917999, '\p{^Is_Variation_Selector=f}', "");
Expect(1, 917999, '\P{Is_Variation_Selector=f}', "");
Expect(0, 917999, '\P{^Is_Variation_Selector=f}', "");
Expect(1, 918000, '\p{Is_Variation_Selector=	_F}', "");
Expect(0, 918000, '\p{^Is_Variation_Selector=	_F}', "");
Expect(0, 918000, '\P{Is_Variation_Selector=	_F}', "");
Expect(1, 918000, '\P{^Is_Variation_Selector=	_F}', "");
Expect(0, 917999, '\p{Is_Variation_Selector=	_F}', "");
Expect(1, 917999, '\p{^Is_Variation_Selector=	_F}', "");
Expect(1, 917999, '\P{Is_Variation_Selector=	_F}', "");
Expect(0, 917999, '\P{^Is_Variation_Selector=	_F}', "");
Error('\p{Is_VS= :=False}');
Error('\P{Is_VS= :=False}');
Expect(1, 918000, '\p{Is_VS=false}', "");
Expect(0, 918000, '\p{^Is_VS=false}', "");
Expect(0, 918000, '\P{Is_VS=false}', "");
Expect(1, 918000, '\P{^Is_VS=false}', "");
Expect(0, 917999, '\p{Is_VS=false}', "");
Expect(1, 917999, '\p{^Is_VS=false}', "");
Expect(1, 917999, '\P{Is_VS=false}', "");
Expect(0, 917999, '\P{^Is_VS=false}', "");
Expect(1, 918000, '\p{Is_VS=--False}', "");
Expect(0, 918000, '\p{^Is_VS=--False}', "");
Expect(0, 918000, '\P{Is_VS=--False}', "");
Expect(1, 918000, '\P{^Is_VS=--False}', "");
Expect(0, 917999, '\p{Is_VS=--False}', "");
Expect(1, 917999, '\p{^Is_VS=--False}', "");
Expect(1, 917999, '\P{Is_VS=--False}', "");
Expect(0, 917999, '\P{^Is_VS=--False}', "");
Error('\p{Variation_Selector=yes:=}');
Error('\P{Variation_Selector=yes:=}');
Expect(1, 917999, '\p{Variation_Selector=yes}', "");
Expect(0, 917999, '\p{^Variation_Selector=yes}', "");
Expect(0, 917999, '\P{Variation_Selector=yes}', "");
Expect(1, 917999, '\P{^Variation_Selector=yes}', "");
Expect(0, 918000, '\p{Variation_Selector=yes}', "");
Expect(1, 918000, '\p{^Variation_Selector=yes}', "");
Expect(1, 918000, '\P{Variation_Selector=yes}', "");
Expect(0, 918000, '\P{^Variation_Selector=yes}', "");
Expect(1, 917999, '\p{Variation_Selector= YES}', "");
Expect(0, 917999, '\p{^Variation_Selector= YES}', "");
Expect(0, 917999, '\P{Variation_Selector= YES}', "");
Expect(1, 917999, '\P{^Variation_Selector= YES}', "");
Expect(0, 918000, '\p{Variation_Selector= YES}', "");
Expect(1, 918000, '\p{^Variation_Selector= YES}', "");
Expect(1, 918000, '\P{Variation_Selector= YES}', "");
Expect(0, 918000, '\P{^Variation_Selector= YES}', "");
Error('\p{VS=:=Y}');
Error('\P{VS=:=Y}');
Expect(1, 917999, '\p{VS:   y}', "");
Expect(0, 917999, '\p{^VS:   y}', "");
Expect(0, 917999, '\P{VS:   y}', "");
Expect(1, 917999, '\P{^VS:   y}', "");
Expect(0, 918000, '\p{VS:   y}', "");
Expect(1, 918000, '\p{^VS:   y}', "");
Expect(1, 918000, '\P{VS:   y}', "");
Expect(0, 918000, '\P{^VS:   y}', "");
Expect(1, 917999, '\p{VS=  Y}', "");
Expect(0, 917999, '\p{^VS=  Y}', "");
Expect(0, 917999, '\P{VS=  Y}', "");
Expect(1, 917999, '\P{^VS=  Y}', "");
Expect(0, 918000, '\p{VS=  Y}', "");
Expect(1, 918000, '\p{^VS=  Y}', "");
Expect(1, 918000, '\P{VS=  Y}', "");
Expect(0, 918000, '\P{^VS=  Y}', "");
Error('\p{Is_Variation_Selector=/a/ T}');
Error('\P{Is_Variation_Selector=/a/ T}');
Expect(1, 917999, '\p{Is_Variation_Selector=t}', "");
Expect(0, 917999, '\p{^Is_Variation_Selector=t}', "");
Expect(0, 917999, '\P{Is_Variation_Selector=t}', "");
Expect(1, 917999, '\P{^Is_Variation_Selector=t}', "");
Expect(0, 918000, '\p{Is_Variation_Selector=t}', "");
Expect(1, 918000, '\p{^Is_Variation_Selector=t}', "");
Expect(1, 918000, '\P{Is_Variation_Selector=t}', "");
Expect(0, 918000, '\P{^Is_Variation_Selector=t}', "");
Expect(1, 917999, '\p{Is_Variation_Selector=	T}', "");
Expect(0, 917999, '\p{^Is_Variation_Selector=	T}', "");
Expect(0, 917999, '\P{Is_Variation_Selector=	T}', "");
Expect(1, 917999, '\P{^Is_Variation_Selector=	T}', "");
Expect(0, 918000, '\p{Is_Variation_Selector=	T}', "");
Expect(1, 918000, '\p{^Is_Variation_Selector=	T}', "");
Expect(1, 918000, '\P{Is_Variation_Selector=	T}', "");
Expect(0, 918000, '\P{^Is_Variation_Selector=	T}', "");
Error('\p{Is_VS=_/a/True}');
Error('\P{Is_VS=_/a/True}');
Expect(1, 917999, '\p{Is_VS=true}', "");
Expect(0, 917999, '\p{^Is_VS=true}', "");
Expect(0, 917999, '\P{Is_VS=true}', "");
Expect(1, 917999, '\P{^Is_VS=true}', "");
Expect(0, 918000, '\p{Is_VS=true}', "");
Expect(1, 918000, '\p{^Is_VS=true}', "");
Expect(1, 918000, '\P{Is_VS=true}', "");
Expect(0, 918000, '\P{^Is_VS=true}', "");
Expect(1, 917999, '\p{Is_VS=--True}', "");
Expect(0, 917999, '\p{^Is_VS=--True}', "");
Expect(0, 917999, '\P{Is_VS=--True}', "");
Expect(1, 917999, '\P{^Is_VS=--True}', "");
Expect(0, 918000, '\p{Is_VS=--True}', "");
Expect(1, 918000, '\p{^Is_VS=--True}', "");
Expect(1, 918000, '\P{Is_VS=--True}', "");
Expect(0, 918000, '\P{^Is_VS=--True}', "");
Error('\p{Word_Break=:=CR}');
Error('\P{Word_Break=:=CR}');
Expect(1, 13, '\p{Word_Break=cr}', "");
Expect(0, 13, '\p{^Word_Break=cr}', "");
Expect(0, 13, '\P{Word_Break=cr}', "");
Expect(1, 13, '\P{^Word_Break=cr}', "");
Expect(0, 14, '\p{Word_Break=cr}', "");
Expect(1, 14, '\p{^Word_Break=cr}', "");
Expect(1, 14, '\P{Word_Break=cr}', "");
Expect(0, 14, '\P{^Word_Break=cr}', "");
Expect(1, 13, '\p{Word_Break= _cr}', "");
Expect(0, 13, '\p{^Word_Break= _cr}', "");
Expect(0, 13, '\P{Word_Break= _cr}', "");
Expect(1, 13, '\P{^Word_Break= _cr}', "");
Expect(0, 14, '\p{Word_Break= _cr}', "");
Expect(1, 14, '\p{^Word_Break= _cr}', "");
Expect(1, 14, '\P{Word_Break= _cr}', "");
Expect(0, 14, '\P{^Word_Break= _cr}', "");
Error('\p{WB:	/a/ CR}');
Error('\P{WB:	/a/ CR}');
Expect(1, 13, '\p{WB=cr}', "");
Expect(0, 13, '\p{^WB=cr}', "");
Expect(0, 13, '\P{WB=cr}', "");
Expect(1, 13, '\P{^WB=cr}', "");
Expect(0, 14, '\p{WB=cr}', "");
Expect(1, 14, '\p{^WB=cr}', "");
Expect(1, 14, '\P{WB=cr}', "");
Expect(0, 14, '\P{^WB=cr}', "");
Expect(1, 13, '\p{WB= CR}', "");
Expect(0, 13, '\p{^WB= CR}', "");
Expect(0, 13, '\P{WB= CR}', "");
Expect(1, 13, '\P{^WB= CR}', "");
Expect(0, 14, '\p{WB= CR}', "");
Expect(1, 14, '\p{^WB= CR}', "");
Expect(1, 14, '\P{WB= CR}', "");
Expect(0, 14, '\P{^WB= CR}', "");
Error('\p{Is_Word_Break=:= CR}');
Error('\P{Is_Word_Break=:= CR}');
Expect(1, 13, '\p{Is_Word_Break=cr}', "");
Expect(0, 13, '\p{^Is_Word_Break=cr}', "");
Expect(0, 13, '\P{Is_Word_Break=cr}', "");
Expect(1, 13, '\P{^Is_Word_Break=cr}', "");
Expect(0, 14, '\p{Is_Word_Break=cr}', "");
Expect(1, 14, '\p{^Is_Word_Break=cr}', "");
Expect(1, 14, '\P{Is_Word_Break=cr}', "");
Expect(0, 14, '\P{^Is_Word_Break=cr}', "");
Expect(1, 13, '\p{Is_Word_Break= cr}', "");
Expect(0, 13, '\p{^Is_Word_Break= cr}', "");
Expect(0, 13, '\P{Is_Word_Break= cr}', "");
Expect(1, 13, '\P{^Is_Word_Break= cr}', "");
Expect(0, 14, '\p{Is_Word_Break= cr}', "");
Expect(1, 14, '\p{^Is_Word_Break= cr}', "");
Expect(1, 14, '\P{Is_Word_Break= cr}', "");
Expect(0, 14, '\P{^Is_Word_Break= cr}', "");
Error('\p{Is_WB:	/a/CR}');
Error('\P{Is_WB:	/a/CR}');
Expect(1, 13, '\p{Is_WB=cr}', "");
Expect(0, 13, '\p{^Is_WB=cr}', "");
Expect(0, 13, '\P{Is_WB=cr}', "");
Expect(1, 13, '\P{^Is_WB=cr}', "");
Expect(0, 14, '\p{Is_WB=cr}', "");
Expect(1, 14, '\p{^Is_WB=cr}', "");
Expect(1, 14, '\P{Is_WB=cr}', "");
Expect(0, 14, '\P{^Is_WB=cr}', "");
Expect(1, 13, '\p{Is_WB=  CR}', "");
Expect(0, 13, '\p{^Is_WB=  CR}', "");
Expect(0, 13, '\P{Is_WB=  CR}', "");
Expect(1, 13, '\P{^Is_WB=  CR}', "");
Expect(0, 14, '\p{Is_WB=  CR}', "");
Expect(1, 14, '\p{^Is_WB=  CR}', "");
Expect(1, 14, '\P{Is_WB=  CR}', "");
Expect(0, 14, '\P{^Is_WB=  CR}', "");
Error('\p{Word_Break=/a/_	ExtendNumLet}');
Error('\P{Word_Break=/a/_	ExtendNumLet}');
Expect(1, 65343, '\p{Word_Break=extendnumlet}', "");
Expect(0, 65343, '\p{^Word_Break=extendnumlet}', "");
Expect(0, 65343, '\P{Word_Break=extendnumlet}', "");
Expect(1, 65343, '\P{^Word_Break=extendnumlet}', "");
Expect(0, 65344, '\p{Word_Break=extendnumlet}', "");
Expect(1, 65344, '\p{^Word_Break=extendnumlet}', "");
Expect(1, 65344, '\P{Word_Break=extendnumlet}', "");
Expect(0, 65344, '\P{^Word_Break=extendnumlet}', "");
Expect(1, 65343, '\p{Word_Break=-	extendnumlet}', "");
Expect(0, 65343, '\p{^Word_Break=-	extendnumlet}', "");
Expect(0, 65343, '\P{Word_Break=-	extendnumlet}', "");
Expect(1, 65343, '\P{^Word_Break=-	extendnumlet}', "");
Expect(0, 65344, '\p{Word_Break=-	extendnumlet}', "");
Expect(1, 65344, '\p{^Word_Break=-	extendnumlet}', "");
Expect(1, 65344, '\P{Word_Break=-	extendnumlet}', "");
Expect(0, 65344, '\P{^Word_Break=-	extendnumlet}', "");
Error('\p{WB=:=EX}');
Error('\P{WB=:=EX}');
Expect(1, 65343, '\p{WB=ex}', "");
Expect(0, 65343, '\p{^WB=ex}', "");
Expect(0, 65343, '\P{WB=ex}', "");
Expect(1, 65343, '\P{^WB=ex}', "");
Expect(0, 65344, '\p{WB=ex}', "");
Expect(1, 65344, '\p{^WB=ex}', "");
Expect(1, 65344, '\P{WB=ex}', "");
Expect(0, 65344, '\P{^WB=ex}', "");
Expect(1, 65343, '\p{WB=-	EX}', "");
Expect(0, 65343, '\p{^WB=-	EX}', "");
Expect(0, 65343, '\P{WB=-	EX}', "");
Expect(1, 65343, '\P{^WB=-	EX}', "");
Expect(0, 65344, '\p{WB=-	EX}', "");
Expect(1, 65344, '\p{^WB=-	EX}', "");
Expect(1, 65344, '\P{WB=-	EX}', "");
Expect(0, 65344, '\P{^WB=-	EX}', "");
Error('\p{Is_Word_Break:	/a/		ExtendNumLet}');
Error('\P{Is_Word_Break:	/a/		ExtendNumLet}');
Expect(1, 65343, '\p{Is_Word_Break=extendnumlet}', "");
Expect(0, 65343, '\p{^Is_Word_Break=extendnumlet}', "");
Expect(0, 65343, '\P{Is_Word_Break=extendnumlet}', "");
Expect(1, 65343, '\P{^Is_Word_Break=extendnumlet}', "");
Expect(0, 65344, '\p{Is_Word_Break=extendnumlet}', "");
Expect(1, 65344, '\p{^Is_Word_Break=extendnumlet}', "");
Expect(1, 65344, '\P{Is_Word_Break=extendnumlet}', "");
Expect(0, 65344, '\P{^Is_Word_Break=extendnumlet}', "");
Expect(1, 65343, '\p{Is_Word_Break= 	ExtendNumLet}', "");
Expect(0, 65343, '\p{^Is_Word_Break= 	ExtendNumLet}', "");
Expect(0, 65343, '\P{Is_Word_Break= 	ExtendNumLet}', "");
Expect(1, 65343, '\P{^Is_Word_Break= 	ExtendNumLet}', "");
Expect(0, 65344, '\p{Is_Word_Break= 	ExtendNumLet}', "");
Expect(1, 65344, '\p{^Is_Word_Break= 	ExtendNumLet}', "");
Expect(1, 65344, '\P{Is_Word_Break= 	ExtendNumLet}', "");
Expect(0, 65344, '\P{^Is_Word_Break= 	ExtendNumLet}', "");
Error('\p{Is_WB=:=- ex}');
Error('\P{Is_WB=:=- ex}');
Expect(1, 65343, '\p{Is_WB=ex}', "");
Expect(0, 65343, '\p{^Is_WB=ex}', "");
Expect(0, 65343, '\P{Is_WB=ex}', "");
Expect(1, 65343, '\P{^Is_WB=ex}', "");
Expect(0, 65344, '\p{Is_WB=ex}', "");
Expect(1, 65344, '\p{^Is_WB=ex}', "");
Expect(1, 65344, '\P{Is_WB=ex}', "");
Expect(0, 65344, '\P{^Is_WB=ex}', "");
Expect(1, 65343, '\p{Is_WB=- EX}', "");
Expect(0, 65343, '\p{^Is_WB=- EX}', "");
Expect(0, 65343, '\P{Is_WB=- EX}', "");
Expect(1, 65343, '\P{^Is_WB=- EX}', "");
Expect(0, 65344, '\p{Is_WB=- EX}', "");
Expect(1, 65344, '\p{^Is_WB=- EX}', "");
Expect(1, 65344, '\P{Is_WB=- EX}', "");
Expect(0, 65344, '\P{^Is_WB=- EX}', "");
Error('\p{Word_Break=:= _Extend}');
Error('\P{Word_Break=:= _Extend}');
Expect(1, 917999, '\p{Word_Break=extend}', "");
Expect(0, 917999, '\p{^Word_Break=extend}', "");
Expect(0, 917999, '\P{Word_Break=extend}', "");
Expect(1, 917999, '\P{^Word_Break=extend}', "");
Expect(0, 918000, '\p{Word_Break=extend}', "");
Expect(1, 918000, '\p{^Word_Break=extend}', "");
Expect(1, 918000, '\P{Word_Break=extend}', "");
Expect(0, 918000, '\P{^Word_Break=extend}', "");
Expect(1, 917999, '\p{Word_Break=_extend}', "");
Expect(0, 917999, '\p{^Word_Break=_extend}', "");
Expect(0, 917999, '\P{Word_Break=_extend}', "");
Expect(1, 917999, '\P{^Word_Break=_extend}', "");
Expect(0, 918000, '\p{Word_Break=_extend}', "");
Expect(1, 918000, '\p{^Word_Break=_extend}', "");
Expect(1, 918000, '\P{Word_Break=_extend}', "");
Expect(0, 918000, '\P{^Word_Break=_extend}', "");
Error('\p{WB=	 Extend:=}');
Error('\P{WB=	 Extend:=}');
Expect(1, 917999, '\p{WB:	extend}', "");
Expect(0, 917999, '\p{^WB:	extend}', "");
Expect(0, 917999, '\P{WB:	extend}', "");
Expect(1, 917999, '\P{^WB:	extend}', "");
Expect(0, 918000, '\p{WB:	extend}', "");
Expect(1, 918000, '\p{^WB:	extend}', "");
Expect(1, 918000, '\P{WB:	extend}', "");
Expect(0, 918000, '\P{^WB:	extend}', "");
Expect(1, 917999, '\p{WB=- extend}', "");
Expect(0, 917999, '\p{^WB=- extend}', "");
Expect(0, 917999, '\P{WB=- extend}', "");
Expect(1, 917999, '\P{^WB=- extend}', "");
Expect(0, 918000, '\p{WB=- extend}', "");
Expect(1, 918000, '\p{^WB=- extend}', "");
Expect(1, 918000, '\P{WB=- extend}', "");
Expect(0, 918000, '\P{^WB=- extend}', "");
Error('\p{Is_Word_Break=	/a/extend}');
Error('\P{Is_Word_Break=	/a/extend}');
Expect(1, 917999, '\p{Is_Word_Break=extend}', "");
Expect(0, 917999, '\p{^Is_Word_Break=extend}', "");
Expect(0, 917999, '\P{Is_Word_Break=extend}', "");
Expect(1, 917999, '\P{^Is_Word_Break=extend}', "");
Expect(0, 918000, '\p{Is_Word_Break=extend}', "");
Expect(1, 918000, '\p{^Is_Word_Break=extend}', "");
Expect(1, 918000, '\P{Is_Word_Break=extend}', "");
Expect(0, 918000, '\P{^Is_Word_Break=extend}', "");
Expect(1, 917999, '\p{Is_Word_Break= Extend}', "");
Expect(0, 917999, '\p{^Is_Word_Break= Extend}', "");
Expect(0, 917999, '\P{Is_Word_Break= Extend}', "");
Expect(1, 917999, '\P{^Is_Word_Break= Extend}', "");
Expect(0, 918000, '\p{Is_Word_Break= Extend}', "");
Expect(1, 918000, '\p{^Is_Word_Break= Extend}', "");
Expect(1, 918000, '\P{Is_Word_Break= Extend}', "");
Expect(0, 918000, '\P{^Is_Word_Break= Extend}', "");
Error('\p{Is_WB= -Extend/a/}');
Error('\P{Is_WB= -Extend/a/}');
Expect(1, 917999, '\p{Is_WB=extend}', "");
Expect(0, 917999, '\p{^Is_WB=extend}', "");
Expect(0, 917999, '\P{Is_WB=extend}', "");
Expect(1, 917999, '\P{^Is_WB=extend}', "");
Expect(0, 918000, '\p{Is_WB=extend}', "");
Expect(1, 918000, '\p{^Is_WB=extend}', "");
Expect(1, 918000, '\P{Is_WB=extend}', "");
Expect(0, 918000, '\P{^Is_WB=extend}', "");
Expect(1, 917999, '\p{Is_WB=	Extend}', "");
Expect(0, 917999, '\p{^Is_WB=	Extend}', "");
Expect(0, 917999, '\P{Is_WB=	Extend}', "");
Expect(1, 917999, '\P{^Is_WB=	Extend}', "");
Expect(0, 918000, '\p{Is_WB=	Extend}', "");
Expect(1, 918000, '\p{^Is_WB=	Extend}', "");
Expect(1, 918000, '\P{Is_WB=	Extend}', "");
Expect(0, 918000, '\P{^Is_WB=	Extend}', "");
Error('\p{Word_Break=/a/ format}');
Error('\P{Word_Break=/a/ format}');
Expect(1, 917631, '\p{Word_Break=format}', "");
Expect(0, 917631, '\p{^Word_Break=format}', "");
Expect(0, 917631, '\P{Word_Break=format}', "");
Expect(1, 917631, '\P{^Word_Break=format}', "");
Expect(0, 917632, '\p{Word_Break=format}', "");
Expect(1, 917632, '\p{^Word_Break=format}', "");
Expect(1, 917632, '\P{Word_Break=format}', "");
Expect(0, 917632, '\P{^Word_Break=format}', "");
Expect(1, 917631, '\p{Word_Break=	Format}', "");
Expect(0, 917631, '\p{^Word_Break=	Format}', "");
Expect(0, 917631, '\P{Word_Break=	Format}', "");
Expect(1, 917631, '\P{^Word_Break=	Format}', "");
Expect(0, 917632, '\p{Word_Break=	Format}', "");
Expect(1, 917632, '\p{^Word_Break=	Format}', "");
Expect(1, 917632, '\P{Word_Break=	Format}', "");
Expect(0, 917632, '\P{^Word_Break=	Format}', "");
Error('\p{WB=/a/ 	fo}');
Error('\P{WB=/a/ 	fo}');
Expect(1, 917631, '\p{WB=fo}', "");
Expect(0, 917631, '\p{^WB=fo}', "");
Expect(0, 917631, '\P{WB=fo}', "");
Expect(1, 917631, '\P{^WB=fo}', "");
Expect(0, 917632, '\p{WB=fo}', "");
Expect(1, 917632, '\p{^WB=fo}', "");
Expect(1, 917632, '\P{WB=fo}', "");
Expect(0, 917632, '\P{^WB=fo}', "");
Expect(1, 917631, '\p{WB= 	FO}', "");
Expect(0, 917631, '\p{^WB= 	FO}', "");
Expect(0, 917631, '\P{WB= 	FO}', "");
Expect(1, 917631, '\P{^WB= 	FO}', "");
Expect(0, 917632, '\p{WB= 	FO}', "");
Expect(1, 917632, '\p{^WB= 	FO}', "");
Expect(1, 917632, '\P{WB= 	FO}', "");
Expect(0, 917632, '\P{^WB= 	FO}', "");
Error('\p{Is_Word_Break=/a/ 	format}');
Error('\P{Is_Word_Break=/a/ 	format}');
Expect(1, 917631, '\p{Is_Word_Break=format}', "");
Expect(0, 917631, '\p{^Is_Word_Break=format}', "");
Expect(0, 917631, '\P{Is_Word_Break=format}', "");
Expect(1, 917631, '\P{^Is_Word_Break=format}', "");
Expect(0, 917632, '\p{Is_Word_Break=format}', "");
Expect(1, 917632, '\p{^Is_Word_Break=format}', "");
Expect(1, 917632, '\P{Is_Word_Break=format}', "");
Expect(0, 917632, '\P{^Is_Word_Break=format}', "");
Expect(1, 917631, '\p{Is_Word_Break=-_Format}', "");
Expect(0, 917631, '\p{^Is_Word_Break=-_Format}', "");
Expect(0, 917631, '\P{Is_Word_Break=-_Format}', "");
Expect(1, 917631, '\P{^Is_Word_Break=-_Format}', "");
Expect(0, 917632, '\p{Is_Word_Break=-_Format}', "");
Expect(1, 917632, '\p{^Is_Word_Break=-_Format}', "");
Expect(1, 917632, '\P{Is_Word_Break=-_Format}', "");
Expect(0, 917632, '\P{^Is_Word_Break=-_Format}', "");
Error('\p{Is_WB=:=-	fo}');
Error('\P{Is_WB=:=-	fo}');
Expect(1, 917631, '\p{Is_WB=fo}', "");
Expect(0, 917631, '\p{^Is_WB=fo}', "");
Expect(0, 917631, '\P{Is_WB=fo}', "");
Expect(1, 917631, '\P{^Is_WB=fo}', "");
Expect(0, 917632, '\p{Is_WB=fo}', "");
Expect(1, 917632, '\p{^Is_WB=fo}', "");
Expect(1, 917632, '\P{Is_WB=fo}', "");
Expect(0, 917632, '\P{^Is_WB=fo}', "");
Expect(1, 917631, '\p{Is_WB: 	 FO}', "");
Expect(0, 917631, '\p{^Is_WB: 	 FO}', "");
Expect(0, 917631, '\P{Is_WB: 	 FO}', "");
Expect(1, 917631, '\P{^Is_WB: 	 FO}', "");
Expect(0, 917632, '\p{Is_WB: 	 FO}', "");
Expect(1, 917632, '\p{^Is_WB: 	 FO}', "");
Expect(1, 917632, '\P{Is_WB: 	 FO}', "");
Expect(0, 917632, '\P{^Is_WB: 	 FO}', "");
Error('\p{Word_Break= _katakana:=}');
Error('\P{Word_Break= _katakana:=}');
Expect(1, 110592, '\p{Word_Break=katakana}', "");
Expect(0, 110592, '\p{^Word_Break=katakana}', "");
Expect(0, 110592, '\P{Word_Break=katakana}', "");
Expect(1, 110592, '\P{^Word_Break=katakana}', "");
Expect(0, 110593, '\p{Word_Break=katakana}', "");
Expect(1, 110593, '\p{^Word_Break=katakana}', "");
Expect(1, 110593, '\P{Word_Break=katakana}', "");
Expect(0, 110593, '\P{^Word_Break=katakana}', "");
Expect(1, 110592, '\p{Word_Break=_katakana}', "");
Expect(0, 110592, '\p{^Word_Break=_katakana}', "");
Expect(0, 110592, '\P{Word_Break=_katakana}', "");
Expect(1, 110592, '\P{^Word_Break=_katakana}', "");
Expect(0, 110593, '\p{Word_Break=_katakana}', "");
Expect(1, 110593, '\p{^Word_Break=_katakana}', "");
Expect(1, 110593, '\P{Word_Break=_katakana}', "");
Expect(0, 110593, '\P{^Word_Break=_katakana}', "");
Error('\p{WB=/a/ ka}');
Error('\P{WB=/a/ ka}');
Expect(1, 110592, '\p{WB=ka}', "");
Expect(0, 110592, '\p{^WB=ka}', "");
Expect(0, 110592, '\P{WB=ka}', "");
Expect(1, 110592, '\P{^WB=ka}', "");
Expect(0, 110593, '\p{WB=ka}', "");
Expect(1, 110593, '\p{^WB=ka}', "");
Expect(1, 110593, '\P{WB=ka}', "");
Expect(0, 110593, '\P{^WB=ka}', "");
Expect(1, 110592, '\p{WB:    	KA}', "");
Expect(0, 110592, '\p{^WB:    	KA}', "");
Expect(0, 110592, '\P{WB:    	KA}', "");
Expect(1, 110592, '\P{^WB:    	KA}', "");
Expect(0, 110593, '\p{WB:    	KA}', "");
Expect(1, 110593, '\p{^WB:    	KA}', "");
Expect(1, 110593, '\P{WB:    	KA}', "");
Expect(0, 110593, '\P{^WB:    	KA}', "");
Error('\p{Is_Word_Break=/a/KATAKANA}');
Error('\P{Is_Word_Break=/a/KATAKANA}');
Expect(1, 110592, '\p{Is_Word_Break=katakana}', "");
Expect(0, 110592, '\p{^Is_Word_Break=katakana}', "");
Expect(0, 110592, '\P{Is_Word_Break=katakana}', "");
Expect(1, 110592, '\P{^Is_Word_Break=katakana}', "");
Expect(0, 110593, '\p{Is_Word_Break=katakana}', "");
Expect(1, 110593, '\p{^Is_Word_Break=katakana}', "");
Expect(1, 110593, '\P{Is_Word_Break=katakana}', "");
Expect(0, 110593, '\P{^Is_Word_Break=katakana}', "");
Expect(1, 110592, '\p{Is_Word_Break= Katakana}', "");
Expect(0, 110592, '\p{^Is_Word_Break= Katakana}', "");
Expect(0, 110592, '\P{Is_Word_Break= Katakana}', "");
Expect(1, 110592, '\P{^Is_Word_Break= Katakana}', "");
Expect(0, 110593, '\p{Is_Word_Break= Katakana}', "");
Expect(1, 110593, '\p{^Is_Word_Break= Katakana}', "");
Expect(1, 110593, '\P{Is_Word_Break= Katakana}', "");
Expect(0, 110593, '\P{^Is_Word_Break= Katakana}', "");
Error('\p{Is_WB=/a/-	KA}');
Error('\P{Is_WB=/a/-	KA}');
Expect(1, 110592, '\p{Is_WB: ka}', "");
Expect(0, 110592, '\p{^Is_WB: ka}', "");
Expect(0, 110592, '\P{Is_WB: ka}', "");
Expect(1, 110592, '\P{^Is_WB: ka}', "");
Expect(0, 110593, '\p{Is_WB: ka}', "");
Expect(1, 110593, '\p{^Is_WB: ka}', "");
Expect(1, 110593, '\P{Is_WB: ka}', "");
Expect(0, 110593, '\P{^Is_WB: ka}', "");
Expect(1, 110592, '\p{Is_WB:    KA}', "");
Expect(0, 110592, '\p{^Is_WB:    KA}', "");
Expect(0, 110592, '\P{Is_WB:    KA}', "");
Expect(1, 110592, '\P{^Is_WB:    KA}', "");
Expect(0, 110593, '\p{Is_WB:    KA}', "");
Expect(1, 110593, '\p{^Is_WB:    KA}', "");
Expect(1, 110593, '\P{Is_WB:    KA}', "");
Expect(0, 110593, '\P{^Is_WB:    KA}', "");
Error('\p{Word_Break:	_/a/ALetter}');
Error('\P{Word_Break:	_/a/ALetter}');
Expect(1, 126651, '\p{Word_Break=aletter}', "");
Expect(0, 126651, '\p{^Word_Break=aletter}', "");
Expect(0, 126651, '\P{Word_Break=aletter}', "");
Expect(1, 126651, '\P{^Word_Break=aletter}', "");
Expect(0, 126652, '\p{Word_Break=aletter}', "");
Expect(1, 126652, '\p{^Word_Break=aletter}', "");
Expect(1, 126652, '\P{Word_Break=aletter}', "");
Expect(0, 126652, '\P{^Word_Break=aletter}', "");
Expect(1, 126651, '\p{Word_Break=	_ALetter}', "");
Expect(0, 126651, '\p{^Word_Break=	_ALetter}', "");
Expect(0, 126651, '\P{Word_Break=	_ALetter}', "");
Expect(1, 126651, '\P{^Word_Break=	_ALetter}', "");
Expect(0, 126652, '\p{Word_Break=	_ALetter}', "");
Expect(1, 126652, '\p{^Word_Break=	_ALetter}', "");
Expect(1, 126652, '\P{Word_Break=	_ALetter}', "");
Expect(0, 126652, '\P{^Word_Break=	_ALetter}', "");
Error('\p{WB=/a/LE}');
Error('\P{WB=/a/LE}');
Expect(1, 126651, '\p{WB=le}', "");
Expect(0, 126651, '\p{^WB=le}', "");
Expect(0, 126651, '\P{WB=le}', "");
Expect(1, 126651, '\P{^WB=le}', "");
Expect(0, 126652, '\p{WB=le}', "");
Expect(1, 126652, '\p{^WB=le}', "");
Expect(1, 126652, '\P{WB=le}', "");
Expect(0, 126652, '\P{^WB=le}', "");
Expect(1, 126651, '\p{WB=-	LE}', "");
Expect(0, 126651, '\p{^WB=-	LE}', "");
Expect(0, 126651, '\P{WB=-	LE}', "");
Expect(1, 126651, '\P{^WB=-	LE}', "");
Expect(0, 126652, '\p{WB=-	LE}', "");
Expect(1, 126652, '\p{^WB=-	LE}', "");
Expect(1, 126652, '\P{WB=-	LE}', "");
Expect(0, 126652, '\P{^WB=-	LE}', "");
Error('\p{Is_Word_Break=--ALetter:=}');
Error('\P{Is_Word_Break=--ALetter:=}');
Expect(1, 126651, '\p{Is_Word_Break=aletter}', "");
Expect(0, 126651, '\p{^Is_Word_Break=aletter}', "");
Expect(0, 126651, '\P{Is_Word_Break=aletter}', "");
Expect(1, 126651, '\P{^Is_Word_Break=aletter}', "");
Expect(0, 126652, '\p{Is_Word_Break=aletter}', "");
Expect(1, 126652, '\p{^Is_Word_Break=aletter}', "");
Expect(1, 126652, '\P{Is_Word_Break=aletter}', "");
Expect(0, 126652, '\P{^Is_Word_Break=aletter}', "");
Expect(1, 126651, '\p{Is_Word_Break=_ALetter}', "");
Expect(0, 126651, '\p{^Is_Word_Break=_ALetter}', "");
Expect(0, 126651, '\P{Is_Word_Break=_ALetter}', "");
Expect(1, 126651, '\P{^Is_Word_Break=_ALetter}', "");
Expect(0, 126652, '\p{Is_Word_Break=_ALetter}', "");
Expect(1, 126652, '\p{^Is_Word_Break=_ALetter}', "");
Expect(1, 126652, '\P{Is_Word_Break=_ALetter}', "");
Expect(0, 126652, '\P{^Is_Word_Break=_ALetter}', "");
Error('\p{Is_WB=	le:=}');
Error('\P{Is_WB=	le:=}');
Expect(1, 126651, '\p{Is_WB=le}', "");
Expect(0, 126651, '\p{^Is_WB=le}', "");
Expect(0, 126651, '\P{Is_WB=le}', "");
Expect(1, 126651, '\P{^Is_WB=le}', "");
Expect(0, 126652, '\p{Is_WB=le}', "");
Expect(1, 126652, '\p{^Is_WB=le}', "");
Expect(1, 126652, '\P{Is_WB=le}', "");
Expect(0, 126652, '\P{^Is_WB=le}', "");
Expect(1, 126651, '\p{Is_WB=LE}', "");
Expect(0, 126651, '\p{^Is_WB=LE}', "");
Expect(0, 126651, '\P{Is_WB=LE}', "");
Expect(1, 126651, '\P{^Is_WB=LE}', "");
Expect(0, 126652, '\p{Is_WB=LE}', "");
Expect(1, 126652, '\p{^Is_WB=LE}', "");
Expect(1, 126652, '\P{Is_WB=LE}', "");
Expect(0, 126652, '\P{^Is_WB=LE}', "");
Error('\p{Word_Break=/a/__LF}');
Error('\P{Word_Break=/a/__LF}');
Expect(1, 10, '\p{Word_Break=lf}', "");
Expect(0, 10, '\p{^Word_Break=lf}', "");
Expect(0, 10, '\P{Word_Break=lf}', "");
Expect(1, 10, '\P{^Word_Break=lf}', "");
Expect(0, 11, '\p{Word_Break=lf}', "");
Expect(1, 11, '\p{^Word_Break=lf}', "");
Expect(1, 11, '\P{Word_Break=lf}', "");
Expect(0, 11, '\P{^Word_Break=lf}', "");
Expect(1, 10, '\p{Word_Break= -lf}', "");
Expect(0, 10, '\p{^Word_Break= -lf}', "");
Expect(0, 10, '\P{Word_Break= -lf}', "");
Expect(1, 10, '\P{^Word_Break= -lf}', "");
Expect(0, 11, '\p{Word_Break= -lf}', "");
Expect(1, 11, '\p{^Word_Break= -lf}', "");
Expect(1, 11, '\P{Word_Break= -lf}', "");
Expect(0, 11, '\P{^Word_Break= -lf}', "");
Error('\p{WB=_-lf:=}');
Error('\P{WB=_-lf:=}');
Expect(1, 10, '\p{WB=lf}', "");
Expect(0, 10, '\p{^WB=lf}', "");
Expect(0, 10, '\P{WB=lf}', "");
Expect(1, 10, '\P{^WB=lf}', "");
Expect(0, 11, '\p{WB=lf}', "");
Expect(1, 11, '\p{^WB=lf}', "");
Expect(1, 11, '\P{WB=lf}', "");
Expect(0, 11, '\P{^WB=lf}', "");
Expect(1, 10, '\p{WB= 	LF}', "");
Expect(0, 10, '\p{^WB= 	LF}', "");
Expect(0, 10, '\P{WB= 	LF}', "");
Expect(1, 10, '\P{^WB= 	LF}', "");
Expect(0, 11, '\p{WB= 	LF}', "");
Expect(1, 11, '\p{^WB= 	LF}', "");
Expect(1, 11, '\P{WB= 	LF}', "");
Expect(0, 11, '\P{^WB= 	LF}', "");
Error('\p{Is_Word_Break=/a/lf}');
Error('\P{Is_Word_Break=/a/lf}');
Expect(1, 10, '\p{Is_Word_Break:	lf}', "");
Expect(0, 10, '\p{^Is_Word_Break:	lf}', "");
Expect(0, 10, '\P{Is_Word_Break:	lf}', "");
Expect(1, 10, '\P{^Is_Word_Break:	lf}', "");
Expect(0, 11, '\p{Is_Word_Break:	lf}', "");
Expect(1, 11, '\p{^Is_Word_Break:	lf}', "");
Expect(1, 11, '\P{Is_Word_Break:	lf}', "");
Expect(0, 11, '\P{^Is_Word_Break:	lf}', "");
Expect(1, 10, '\p{Is_Word_Break=-	LF}', "");
Expect(0, 10, '\p{^Is_Word_Break=-	LF}', "");
Expect(0, 10, '\P{Is_Word_Break=-	LF}', "");
Expect(1, 10, '\P{^Is_Word_Break=-	LF}', "");
Expect(0, 11, '\p{Is_Word_Break=-	LF}', "");
Expect(1, 11, '\p{^Is_Word_Break=-	LF}', "");
Expect(1, 11, '\P{Is_Word_Break=-	LF}', "");
Expect(0, 11, '\P{^Is_Word_Break=-	LF}', "");
Error('\p{Is_WB=:=LF}');
Error('\P{Is_WB=:=LF}');
Expect(1, 10, '\p{Is_WB=lf}', "");
Expect(0, 10, '\p{^Is_WB=lf}', "");
Expect(0, 10, '\P{Is_WB=lf}', "");
Expect(1, 10, '\P{^Is_WB=lf}', "");
Expect(0, 11, '\p{Is_WB=lf}', "");
Expect(1, 11, '\p{^Is_WB=lf}', "");
Expect(1, 11, '\P{Is_WB=lf}', "");
Expect(0, 11, '\P{^Is_WB=lf}', "");
Expect(1, 10, '\p{Is_WB=	LF}', "");
Expect(0, 10, '\p{^Is_WB=	LF}', "");
Expect(0, 10, '\P{Is_WB=	LF}', "");
Expect(1, 10, '\P{^Is_WB=	LF}', "");
Expect(0, 11, '\p{Is_WB=	LF}', "");
Expect(1, 11, '\p{^Is_WB=	LF}', "");
Expect(1, 11, '\P{Is_WB=	LF}', "");
Expect(0, 11, '\P{^Is_WB=	LF}', "");
Error('\p{Word_Break=--MIDNUMLET:=}');
Error('\P{Word_Break=--MIDNUMLET:=}');
Expect(1, 65294, '\p{Word_Break=midnumlet}', "");
Expect(0, 65294, '\p{^Word_Break=midnumlet}', "");
Expect(0, 65294, '\P{Word_Break=midnumlet}', "");
Expect(1, 65294, '\P{^Word_Break=midnumlet}', "");
Expect(0, 65295, '\p{Word_Break=midnumlet}', "");
Expect(1, 65295, '\p{^Word_Break=midnumlet}', "");
Expect(1, 65295, '\P{Word_Break=midnumlet}', "");
Expect(0, 65295, '\P{^Word_Break=midnumlet}', "");
Expect(1, 65294, '\p{Word_Break=	MIDNUMLET}', "");
Expect(0, 65294, '\p{^Word_Break=	MIDNUMLET}', "");
Expect(0, 65294, '\P{Word_Break=	MIDNUMLET}', "");
Expect(1, 65294, '\P{^Word_Break=	MIDNUMLET}', "");
Expect(0, 65295, '\p{Word_Break=	MIDNUMLET}', "");
Expect(1, 65295, '\p{^Word_Break=	MIDNUMLET}', "");
Expect(1, 65295, '\P{Word_Break=	MIDNUMLET}', "");
Expect(0, 65295, '\P{^Word_Break=	MIDNUMLET}', "");
Error('\p{WB=_	MB:=}');
Error('\P{WB=_	MB:=}');
Expect(1, 65294, '\p{WB:mb}', "");
Expect(0, 65294, '\p{^WB:mb}', "");
Expect(0, 65294, '\P{WB:mb}', "");
Expect(1, 65294, '\P{^WB:mb}', "");
Expect(0, 65295, '\p{WB:mb}', "");
Expect(1, 65295, '\p{^WB:mb}', "");
Expect(1, 65295, '\P{WB:mb}', "");
Expect(0, 65295, '\P{^WB:mb}', "");
Expect(1, 65294, '\p{WB= -mb}', "");
Expect(0, 65294, '\p{^WB= -mb}', "");
Expect(0, 65294, '\P{WB= -mb}', "");
Expect(1, 65294, '\P{^WB= -mb}', "");
Expect(0, 65295, '\p{WB= -mb}', "");
Expect(1, 65295, '\p{^WB= -mb}', "");
Expect(1, 65295, '\P{WB= -mb}', "");
Expect(0, 65295, '\P{^WB= -mb}', "");
Error('\p{Is_Word_Break=_/a/MidNumLet}');
Error('\P{Is_Word_Break=_/a/MidNumLet}');
Expect(1, 65294, '\p{Is_Word_Break=midnumlet}', "");
Expect(0, 65294, '\p{^Is_Word_Break=midnumlet}', "");
Expect(0, 65294, '\P{Is_Word_Break=midnumlet}', "");
Expect(1, 65294, '\P{^Is_Word_Break=midnumlet}', "");
Expect(0, 65295, '\p{Is_Word_Break=midnumlet}', "");
Expect(1, 65295, '\p{^Is_Word_Break=midnumlet}', "");
Expect(1, 65295, '\P{Is_Word_Break=midnumlet}', "");
Expect(0, 65295, '\P{^Is_Word_Break=midnumlet}', "");
Expect(1, 65294, '\p{Is_Word_Break= midnumlet}', "");
Expect(0, 65294, '\p{^Is_Word_Break= midnumlet}', "");
Expect(0, 65294, '\P{Is_Word_Break= midnumlet}', "");
Expect(1, 65294, '\P{^Is_Word_Break= midnumlet}', "");
Expect(0, 65295, '\p{Is_Word_Break= midnumlet}', "");
Expect(1, 65295, '\p{^Is_Word_Break= midnumlet}', "");
Expect(1, 65295, '\P{Is_Word_Break= midnumlet}', "");
Expect(0, 65295, '\P{^Is_Word_Break= midnumlet}', "");
Error('\p{Is_WB=:=- MB}');
Error('\P{Is_WB=:=- MB}');
Expect(1, 65294, '\p{Is_WB:	mb}', "");
Expect(0, 65294, '\p{^Is_WB:	mb}', "");
Expect(0, 65294, '\P{Is_WB:	mb}', "");
Expect(1, 65294, '\P{^Is_WB:	mb}', "");
Expect(0, 65295, '\p{Is_WB:	mb}', "");
Expect(1, 65295, '\p{^Is_WB:	mb}', "");
Expect(1, 65295, '\P{Is_WB:	mb}', "");
Expect(0, 65295, '\P{^Is_WB:	mb}', "");
Expect(1, 65294, '\p{Is_WB=_-mb}', "");
Expect(0, 65294, '\p{^Is_WB=_-mb}', "");
Expect(0, 65294, '\P{Is_WB=_-mb}', "");
Expect(1, 65294, '\P{^Is_WB=_-mb}', "");
Expect(0, 65295, '\p{Is_WB=_-mb}', "");
Expect(1, 65295, '\p{^Is_WB=_-mb}', "");
Expect(1, 65295, '\P{Is_WB=_-mb}', "");
Expect(0, 65295, '\P{^Is_WB=_-mb}', "");
Error('\p{Word_Break=-:=midletter}');
Error('\P{Word_Break=-:=midletter}');
Expect(1, 65306, '\p{Word_Break:midletter}', "");
Expect(0, 65306, '\p{^Word_Break:midletter}', "");
Expect(0, 65306, '\P{Word_Break:midletter}', "");
Expect(1, 65306, '\P{^Word_Break:midletter}', "");
Expect(0, 65307, '\p{Word_Break:midletter}', "");
Expect(1, 65307, '\p{^Word_Break:midletter}', "");
Expect(1, 65307, '\P{Word_Break:midletter}', "");
Expect(0, 65307, '\P{^Word_Break:midletter}', "");
Expect(1, 65306, '\p{Word_Break=		MIDLETTER}', "");
Expect(0, 65306, '\p{^Word_Break=		MIDLETTER}', "");
Expect(0, 65306, '\P{Word_Break=		MIDLETTER}', "");
Expect(1, 65306, '\P{^Word_Break=		MIDLETTER}', "");
Expect(0, 65307, '\p{Word_Break=		MIDLETTER}', "");
Expect(1, 65307, '\p{^Word_Break=		MIDLETTER}', "");
Expect(1, 65307, '\P{Word_Break=		MIDLETTER}', "");
Expect(0, 65307, '\P{^Word_Break=		MIDLETTER}', "");
Error('\p{WB:   /a/_ML}');
Error('\P{WB:   /a/_ML}');
Expect(1, 65306, '\p{WB=ml}', "");
Expect(0, 65306, '\p{^WB=ml}', "");
Expect(0, 65306, '\P{WB=ml}', "");
Expect(1, 65306, '\P{^WB=ml}', "");
Expect(0, 65307, '\p{WB=ml}', "");
Expect(1, 65307, '\p{^WB=ml}', "");
Expect(1, 65307, '\P{WB=ml}', "");
Expect(0, 65307, '\P{^WB=ml}', "");
Expect(1, 65306, '\p{WB= ML}', "");
Expect(0, 65306, '\p{^WB= ML}', "");
Expect(0, 65306, '\P{WB= ML}', "");
Expect(1, 65306, '\P{^WB= ML}', "");
Expect(0, 65307, '\p{WB= ML}', "");
Expect(1, 65307, '\p{^WB= ML}', "");
Expect(1, 65307, '\P{WB= ML}', "");
Expect(0, 65307, '\P{^WB= ML}', "");
Error('\p{Is_Word_Break=-	MidLetter:=}');
Error('\P{Is_Word_Break=-	MidLetter:=}');
Expect(1, 65306, '\p{Is_Word_Break=midletter}', "");
Expect(0, 65306, '\p{^Is_Word_Break=midletter}', "");
Expect(0, 65306, '\P{Is_Word_Break=midletter}', "");
Expect(1, 65306, '\P{^Is_Word_Break=midletter}', "");
Expect(0, 65307, '\p{Is_Word_Break=midletter}', "");
Expect(1, 65307, '\p{^Is_Word_Break=midletter}', "");
Expect(1, 65307, '\P{Is_Word_Break=midletter}', "");
Expect(0, 65307, '\P{^Is_Word_Break=midletter}', "");
Expect(1, 65306, '\p{Is_Word_Break=_	MidLetter}', "");
Expect(0, 65306, '\p{^Is_Word_Break=_	MidLetter}', "");
Expect(0, 65306, '\P{Is_Word_Break=_	MidLetter}', "");
Expect(1, 65306, '\P{^Is_Word_Break=_	MidLetter}', "");
Expect(0, 65307, '\p{Is_Word_Break=_	MidLetter}', "");
Expect(1, 65307, '\p{^Is_Word_Break=_	MidLetter}', "");
Expect(1, 65307, '\P{Is_Word_Break=_	MidLetter}', "");
Expect(0, 65307, '\P{^Is_Word_Break=_	MidLetter}', "");
Error('\p{Is_WB=	_ML:=}');
Error('\P{Is_WB=	_ML:=}');
Expect(1, 65306, '\p{Is_WB=ml}', "");
Expect(0, 65306, '\p{^Is_WB=ml}', "");
Expect(0, 65306, '\P{Is_WB=ml}', "");
Expect(1, 65306, '\P{^Is_WB=ml}', "");
Expect(0, 65307, '\p{Is_WB=ml}', "");
Expect(1, 65307, '\p{^Is_WB=ml}', "");
Expect(1, 65307, '\P{Is_WB=ml}', "");
Expect(0, 65307, '\P{^Is_WB=ml}', "");
Expect(1, 65306, '\p{Is_WB= _ml}', "");
Expect(0, 65306, '\p{^Is_WB= _ml}', "");
Expect(0, 65306, '\P{Is_WB= _ml}', "");
Expect(1, 65306, '\P{^Is_WB= _ml}', "");
Expect(0, 65307, '\p{Is_WB= _ml}', "");
Expect(1, 65307, '\p{^Is_WB= _ml}', "");
Expect(1, 65307, '\P{Is_WB= _ml}', "");
Expect(0, 65307, '\P{^Is_WB= _ml}', "");
Error('\p{Word_Break= /a/MidNum}');
Error('\P{Word_Break= /a/MidNum}');
Expect(1, 65307, '\p{Word_Break:   midnum}', "");
Expect(0, 65307, '\p{^Word_Break:   midnum}', "");
Expect(0, 65307, '\P{Word_Break:   midnum}', "");
Expect(1, 65307, '\P{^Word_Break:   midnum}', "");
Expect(0, 65308, '\p{Word_Break:   midnum}', "");
Expect(1, 65308, '\p{^Word_Break:   midnum}', "");
Expect(1, 65308, '\P{Word_Break:   midnum}', "");
Expect(0, 65308, '\P{^Word_Break:   midnum}', "");
Expect(1, 65307, '\p{Word_Break=	-MIDNUM}', "");
Expect(0, 65307, '\p{^Word_Break=	-MIDNUM}', "");
Expect(0, 65307, '\P{Word_Break=	-MIDNUM}', "");
Expect(1, 65307, '\P{^Word_Break=	-MIDNUM}', "");
Expect(0, 65308, '\p{Word_Break=	-MIDNUM}', "");
Expect(1, 65308, '\p{^Word_Break=	-MIDNUM}', "");
Expect(1, 65308, '\P{Word_Break=	-MIDNUM}', "");
Expect(0, 65308, '\P{^Word_Break=	-MIDNUM}', "");
Error('\p{WB=	MN/a/}');
Error('\P{WB=	MN/a/}');
Expect(1, 65307, '\p{WB=mn}', "");
Expect(0, 65307, '\p{^WB=mn}', "");
Expect(0, 65307, '\P{WB=mn}', "");
Expect(1, 65307, '\P{^WB=mn}', "");
Expect(0, 65308, '\p{WB=mn}', "");
Expect(1, 65308, '\p{^WB=mn}', "");
Expect(1, 65308, '\P{WB=mn}', "");
Expect(0, 65308, '\P{^WB=mn}', "");
Expect(1, 65307, '\p{WB=- MN}', "");
Expect(0, 65307, '\p{^WB=- MN}', "");
Expect(0, 65307, '\P{WB=- MN}', "");
Expect(1, 65307, '\P{^WB=- MN}', "");
Expect(0, 65308, '\p{WB=- MN}', "");
Expect(1, 65308, '\p{^WB=- MN}', "");
Expect(1, 65308, '\P{WB=- MN}', "");
Expect(0, 65308, '\P{^WB=- MN}', "");
Error('\p{Is_Word_Break=_MidNum:=}');
Error('\P{Is_Word_Break=_MidNum:=}');
Expect(1, 65307, '\p{Is_Word_Break=midnum}', "");
Expect(0, 65307, '\p{^Is_Word_Break=midnum}', "");
Expect(0, 65307, '\P{Is_Word_Break=midnum}', "");
Expect(1, 65307, '\P{^Is_Word_Break=midnum}', "");
Expect(0, 65308, '\p{Is_Word_Break=midnum}', "");
Expect(1, 65308, '\p{^Is_Word_Break=midnum}', "");
Expect(1, 65308, '\P{Is_Word_Break=midnum}', "");
Expect(0, 65308, '\P{^Is_Word_Break=midnum}', "");
Expect(1, 65307, '\p{Is_Word_Break=_MidNum}', "");
Expect(0, 65307, '\p{^Is_Word_Break=_MidNum}', "");
Expect(0, 65307, '\P{Is_Word_Break=_MidNum}', "");
Expect(1, 65307, '\P{^Is_Word_Break=_MidNum}', "");
Expect(0, 65308, '\p{Is_Word_Break=_MidNum}', "");
Expect(1, 65308, '\p{^Is_Word_Break=_MidNum}', "");
Expect(1, 65308, '\P{Is_Word_Break=_MidNum}', "");
Expect(0, 65308, '\P{^Is_Word_Break=_MidNum}', "");
Error('\p{Is_WB:   /a/mn}');
Error('\P{Is_WB:   /a/mn}');
Expect(1, 65307, '\p{Is_WB=mn}', "");
Expect(0, 65307, '\p{^Is_WB=mn}', "");
Expect(0, 65307, '\P{Is_WB=mn}', "");
Expect(1, 65307, '\P{^Is_WB=mn}', "");
Expect(0, 65308, '\p{Is_WB=mn}', "");
Expect(1, 65308, '\p{^Is_WB=mn}', "");
Expect(1, 65308, '\P{Is_WB=mn}', "");
Expect(0, 65308, '\P{^Is_WB=mn}', "");
Expect(1, 65307, '\p{Is_WB= _mn}', "");
Expect(0, 65307, '\p{^Is_WB= _mn}', "");
Expect(0, 65307, '\P{Is_WB= _mn}', "");
Expect(1, 65307, '\P{^Is_WB= _mn}', "");
Expect(0, 65308, '\p{Is_WB= _mn}', "");
Expect(1, 65308, '\p{^Is_WB= _mn}', "");
Expect(1, 65308, '\P{Is_WB= _mn}', "");
Expect(0, 65308, '\P{^Is_WB= _mn}', "");
Error('\p{Word_Break:	/a/	NEWLINE}');
Error('\P{Word_Break:	/a/	NEWLINE}');
Expect(1, 8233, '\p{Word_Break:	newline}', "");
Expect(0, 8233, '\p{^Word_Break:	newline}', "");
Expect(0, 8233, '\P{Word_Break:	newline}', "");
Expect(1, 8233, '\P{^Word_Break:	newline}', "");
Expect(0, 8234, '\p{Word_Break:	newline}', "");
Expect(1, 8234, '\p{^Word_Break:	newline}', "");
Expect(1, 8234, '\P{Word_Break:	newline}', "");
Expect(0, 8234, '\P{^Word_Break:	newline}', "");
Expect(1, 8233, '\p{Word_Break=_	Newline}', "");
Expect(0, 8233, '\p{^Word_Break=_	Newline}', "");
Expect(0, 8233, '\P{Word_Break=_	Newline}', "");
Expect(1, 8233, '\P{^Word_Break=_	Newline}', "");
Expect(0, 8234, '\p{Word_Break=_	Newline}', "");
Expect(1, 8234, '\p{^Word_Break=_	Newline}', "");
Expect(1, 8234, '\P{Word_Break=_	Newline}', "");
Expect(0, 8234, '\P{^Word_Break=_	Newline}', "");
Error('\p{WB: /a/ NL}');
Error('\P{WB: /a/ NL}');
Expect(1, 8233, '\p{WB=nl}', "");
Expect(0, 8233, '\p{^WB=nl}', "");
Expect(0, 8233, '\P{WB=nl}', "");
Expect(1, 8233, '\P{^WB=nl}', "");
Expect(0, 8234, '\p{WB=nl}', "");
Expect(1, 8234, '\p{^WB=nl}', "");
Expect(1, 8234, '\P{WB=nl}', "");
Expect(0, 8234, '\P{^WB=nl}', "");
Expect(1, 8233, '\p{WB:   	 NL}', "");
Expect(0, 8233, '\p{^WB:   	 NL}', "");
Expect(0, 8233, '\P{WB:   	 NL}', "");
Expect(1, 8233, '\P{^WB:   	 NL}', "");
Expect(0, 8234, '\p{WB:   	 NL}', "");
Expect(1, 8234, '\p{^WB:   	 NL}', "");
Expect(1, 8234, '\P{WB:   	 NL}', "");
Expect(0, 8234, '\P{^WB:   	 NL}', "");
Error('\p{Is_Word_Break=_/a/NEWLINE}');
Error('\P{Is_Word_Break=_/a/NEWLINE}');
Expect(1, 8233, '\p{Is_Word_Break=newline}', "");
Expect(0, 8233, '\p{^Is_Word_Break=newline}', "");
Expect(0, 8233, '\P{Is_Word_Break=newline}', "");
Expect(1, 8233, '\P{^Is_Word_Break=newline}', "");
Expect(0, 8234, '\p{Is_Word_Break=newline}', "");
Expect(1, 8234, '\p{^Is_Word_Break=newline}', "");
Expect(1, 8234, '\P{Is_Word_Break=newline}', "");
Expect(0, 8234, '\P{^Is_Word_Break=newline}', "");
Expect(1, 8233, '\p{Is_Word_Break= newline}', "");
Expect(0, 8233, '\p{^Is_Word_Break= newline}', "");
Expect(0, 8233, '\P{Is_Word_Break= newline}', "");
Expect(1, 8233, '\P{^Is_Word_Break= newline}', "");
Expect(0, 8234, '\p{Is_Word_Break= newline}', "");
Expect(1, 8234, '\p{^Is_Word_Break= newline}', "");
Expect(1, 8234, '\P{Is_Word_Break= newline}', "");
Expect(0, 8234, '\P{^Is_Word_Break= newline}', "");
Error('\p{Is_WB=	NL/a/}');
Error('\P{Is_WB=	NL/a/}');
Expect(1, 8233, '\p{Is_WB=nl}', "");
Expect(0, 8233, '\p{^Is_WB=nl}', "");
Expect(0, 8233, '\P{Is_WB=nl}', "");
Expect(1, 8233, '\P{^Is_WB=nl}', "");
Expect(0, 8234, '\p{Is_WB=nl}', "");
Expect(1, 8234, '\p{^Is_WB=nl}', "");
Expect(1, 8234, '\P{Is_WB=nl}', "");
Expect(0, 8234, '\P{^Is_WB=nl}', "");
Expect(1, 8233, '\p{Is_WB=_nl}', "");
Expect(0, 8233, '\p{^Is_WB=_nl}', "");
Expect(0, 8233, '\P{Is_WB=_nl}', "");
Expect(1, 8233, '\P{^Is_WB=_nl}', "");
Expect(0, 8234, '\p{Is_WB=_nl}', "");
Expect(1, 8234, '\p{^Is_WB=_nl}', "");
Expect(1, 8234, '\P{Is_WB=_nl}', "");
Expect(0, 8234, '\P{^Is_WB=_nl}', "");
Error('\p{Word_Break=_	NUMERIC/a/}');
Error('\P{Word_Break=_	NUMERIC/a/}');
Expect(1, 120831, '\p{Word_Break=numeric}', "");
Expect(0, 120831, '\p{^Word_Break=numeric}', "");
Expect(0, 120831, '\P{Word_Break=numeric}', "");
Expect(1, 120831, '\P{^Word_Break=numeric}', "");
Expect(0, 120832, '\p{Word_Break=numeric}', "");
Expect(1, 120832, '\p{^Word_Break=numeric}', "");
Expect(1, 120832, '\P{Word_Break=numeric}', "");
Expect(0, 120832, '\P{^Word_Break=numeric}', "");
Expect(1, 120831, '\p{Word_Break=_NUMERIC}', "");
Expect(0, 120831, '\p{^Word_Break=_NUMERIC}', "");
Expect(0, 120831, '\P{Word_Break=_NUMERIC}', "");
Expect(1, 120831, '\P{^Word_Break=_NUMERIC}', "");
Expect(0, 120832, '\p{Word_Break=_NUMERIC}', "");
Expect(1, 120832, '\p{^Word_Break=_NUMERIC}', "");
Expect(1, 120832, '\P{Word_Break=_NUMERIC}', "");
Expect(0, 120832, '\P{^Word_Break=_NUMERIC}', "");
Error('\p{WB=/a/-_NU}');
Error('\P{WB=/a/-_NU}');
Expect(1, 120831, '\p{WB:	nu}', "");
Expect(0, 120831, '\p{^WB:	nu}', "");
Expect(0, 120831, '\P{WB:	nu}', "");
Expect(1, 120831, '\P{^WB:	nu}', "");
Expect(0, 120832, '\p{WB:	nu}', "");
Expect(1, 120832, '\p{^WB:	nu}', "");
Expect(1, 120832, '\P{WB:	nu}', "");
Expect(0, 120832, '\P{^WB:	nu}', "");
Expect(1, 120831, '\p{WB=	NU}', "");
Expect(0, 120831, '\p{^WB=	NU}', "");
Expect(0, 120831, '\P{WB=	NU}', "");
Expect(1, 120831, '\P{^WB=	NU}', "");
Expect(0, 120832, '\p{WB=	NU}', "");
Expect(1, 120832, '\p{^WB=	NU}', "");
Expect(1, 120832, '\P{WB=	NU}', "");
Expect(0, 120832, '\P{^WB=	NU}', "");
Error('\p{Is_Word_Break=:=		Numeric}');
Error('\P{Is_Word_Break=:=		Numeric}');
Expect(1, 120831, '\p{Is_Word_Break:	numeric}', "");
Expect(0, 120831, '\p{^Is_Word_Break:	numeric}', "");
Expect(0, 120831, '\P{Is_Word_Break:	numeric}', "");
Expect(1, 120831, '\P{^Is_Word_Break:	numeric}', "");
Expect(0, 120832, '\p{Is_Word_Break:	numeric}', "");
Expect(1, 120832, '\p{^Is_Word_Break:	numeric}', "");
Expect(1, 120832, '\P{Is_Word_Break:	numeric}', "");
Expect(0, 120832, '\P{^Is_Word_Break:	numeric}', "");
Expect(1, 120831, '\p{Is_Word_Break=_-Numeric}', "");
Expect(0, 120831, '\p{^Is_Word_Break=_-Numeric}', "");
Expect(0, 120831, '\P{Is_Word_Break=_-Numeric}', "");
Expect(1, 120831, '\P{^Is_Word_Break=_-Numeric}', "");
Expect(0, 120832, '\p{Is_Word_Break=_-Numeric}', "");
Expect(1, 120832, '\p{^Is_Word_Break=_-Numeric}', "");
Expect(1, 120832, '\P{Is_Word_Break=_-Numeric}', "");
Expect(0, 120832, '\P{^Is_Word_Break=_-Numeric}', "");
Error('\p{Is_WB:/a/_	NU}');
Error('\P{Is_WB:/a/_	NU}');
Expect(1, 120831, '\p{Is_WB=nu}', "");
Expect(0, 120831, '\p{^Is_WB=nu}', "");
Expect(0, 120831, '\P{Is_WB=nu}', "");
Expect(1, 120831, '\P{^Is_WB=nu}', "");
Expect(0, 120832, '\p{Is_WB=nu}', "");
Expect(1, 120832, '\p{^Is_WB=nu}', "");
Expect(1, 120832, '\P{Is_WB=nu}', "");
Expect(0, 120832, '\P{^Is_WB=nu}', "");
Expect(1, 120831, '\p{Is_WB=-_NU}', "");
Expect(0, 120831, '\p{^Is_WB=-_NU}', "");
Expect(0, 120831, '\P{Is_WB=-_NU}', "");
Expect(1, 120831, '\P{^Is_WB=-_NU}', "");
Expect(0, 120832, '\p{Is_WB=-_NU}', "");
Expect(1, 120832, '\p{^Is_WB=-_NU}', "");
Expect(1, 120832, '\P{Is_WB=-_NU}', "");
Expect(0, 120832, '\P{^Is_WB=-_NU}', "");
Error('\p{Word_Break=	_REGIONAL_Indicator:=}');
Error('\P{Word_Break=	_REGIONAL_Indicator:=}');
Expect(1, 127487, '\p{Word_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Word_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Word_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Word_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Word_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Word_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Word_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Word_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Word_Break=-Regional_indicator}', "");
Expect(0, 127487, '\p{^Word_Break=-Regional_indicator}', "");
Expect(0, 127487, '\P{Word_Break=-Regional_indicator}', "");
Expect(1, 127487, '\P{^Word_Break=-Regional_indicator}', "");
Expect(0, 127488, '\p{Word_Break=-Regional_indicator}', "");
Expect(1, 127488, '\p{^Word_Break=-Regional_indicator}', "");
Expect(1, 127488, '\P{Word_Break=-Regional_indicator}', "");
Expect(0, 127488, '\P{^Word_Break=-Regional_indicator}', "");
Error('\p{WB=_ri:=}');
Error('\P{WB=_ri:=}');
Expect(1, 127487, '\p{WB=ri}', "");
Expect(0, 127487, '\p{^WB=ri}', "");
Expect(0, 127487, '\P{WB=ri}', "");
Expect(1, 127487, '\P{^WB=ri}', "");
Expect(0, 127488, '\p{WB=ri}', "");
Expect(1, 127488, '\p{^WB=ri}', "");
Expect(1, 127488, '\P{WB=ri}', "");
Expect(0, 127488, '\P{^WB=ri}', "");
Expect(1, 127487, '\p{WB:	_ RI}', "");
Expect(0, 127487, '\p{^WB:	_ RI}', "");
Expect(0, 127487, '\P{WB:	_ RI}', "");
Expect(1, 127487, '\P{^WB:	_ RI}', "");
Expect(0, 127488, '\p{WB:	_ RI}', "");
Expect(1, 127488, '\p{^WB:	_ RI}', "");
Expect(1, 127488, '\P{WB:	_ RI}', "");
Expect(0, 127488, '\P{^WB:	_ RI}', "");
Error('\p{Is_Word_Break=_REGIONAL_indicator/a/}');
Error('\P{Is_Word_Break=_REGIONAL_indicator/a/}');
Expect(1, 127487, '\p{Is_Word_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Is_Word_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Is_Word_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Is_Word_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Is_Word_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Is_Word_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Is_Word_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Is_Word_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Is_Word_Break=	Regional_Indicator}', "");
Expect(0, 127487, '\p{^Is_Word_Break=	Regional_Indicator}', "");
Expect(0, 127487, '\P{Is_Word_Break=	Regional_Indicator}', "");
Expect(1, 127487, '\P{^Is_Word_Break=	Regional_Indicator}', "");
Expect(0, 127488, '\p{Is_Word_Break=	Regional_Indicator}', "");
Expect(1, 127488, '\p{^Is_Word_Break=	Regional_Indicator}', "");
Expect(1, 127488, '\P{Is_Word_Break=	Regional_Indicator}', "");
Expect(0, 127488, '\P{^Is_Word_Break=	Regional_Indicator}', "");
Error('\p{Is_WB=_	ri/a/}');
Error('\P{Is_WB=_	ri/a/}');
Expect(1, 127487, '\p{Is_WB:ri}', "");
Expect(0, 127487, '\p{^Is_WB:ri}', "");
Expect(0, 127487, '\P{Is_WB:ri}', "");
Expect(1, 127487, '\P{^Is_WB:ri}', "");
Expect(0, 127488, '\p{Is_WB:ri}', "");
Expect(1, 127488, '\p{^Is_WB:ri}', "");
Expect(1, 127488, '\P{Is_WB:ri}', "");
Expect(0, 127488, '\P{^Is_WB:ri}', "");
Expect(1, 127487, '\p{Is_WB=_-RI}', "");
Expect(0, 127487, '\p{^Is_WB=_-RI}', "");
Expect(0, 127487, '\P{Is_WB=_-RI}', "");
Expect(1, 127487, '\P{^Is_WB=_-RI}', "");
Expect(0, 127488, '\p{Is_WB=_-RI}', "");
Expect(1, 127488, '\p{^Is_WB=_-RI}', "");
Expect(1, 127488, '\P{Is_WB=_-RI}', "");
Expect(0, 127488, '\P{^Is_WB=_-RI}', "");
Error('\p{Word_Break=:=Other}');
Error('\P{Word_Break=:=Other}');
Expect(1, 918000, '\p{Word_Break=other}', "");
Expect(0, 918000, '\p{^Word_Break=other}', "");
Expect(0, 918000, '\P{Word_Break=other}', "");
Expect(1, 918000, '\P{^Word_Break=other}', "");
Expect(0, 917999, '\p{Word_Break=other}', "");
Expect(1, 917999, '\p{^Word_Break=other}', "");
Expect(1, 917999, '\P{Word_Break=other}', "");
Expect(0, 917999, '\P{^Word_Break=other}', "");
Expect(1, 918000, '\p{Word_Break=_	Other}', "");
Expect(0, 918000, '\p{^Word_Break=_	Other}', "");
Expect(0, 918000, '\P{Word_Break=_	Other}', "");
Expect(1, 918000, '\P{^Word_Break=_	Other}', "");
Expect(0, 917999, '\p{Word_Break=_	Other}', "");
Expect(1, 917999, '\p{^Word_Break=_	Other}', "");
Expect(1, 917999, '\P{Word_Break=_	Other}', "");
Expect(0, 917999, '\P{^Word_Break=_	Other}', "");
Error('\p{WB= :=XX}');
Error('\P{WB= :=XX}');
Expect(1, 918000, '\p{WB=xx}', "");
Expect(0, 918000, '\p{^WB=xx}', "");
Expect(0, 918000, '\P{WB=xx}', "");
Expect(1, 918000, '\P{^WB=xx}', "");
Expect(0, 917999, '\p{WB=xx}', "");
Expect(1, 917999, '\p{^WB=xx}', "");
Expect(1, 917999, '\P{WB=xx}', "");
Expect(0, 917999, '\P{^WB=xx}', "");
Expect(1, 918000, '\p{WB:	 XX}', "");
Expect(0, 918000, '\p{^WB:	 XX}', "");
Expect(0, 918000, '\P{WB:	 XX}', "");
Expect(1, 918000, '\P{^WB:	 XX}', "");
Expect(0, 917999, '\p{WB:	 XX}', "");
Expect(1, 917999, '\p{^WB:	 XX}', "");
Expect(1, 917999, '\P{WB:	 XX}', "");
Expect(0, 917999, '\P{^WB:	 XX}', "");
Error('\p{Is_Word_Break:   /a/-_Other}');
Error('\P{Is_Word_Break:   /a/-_Other}');
Expect(1, 918000, '\p{Is_Word_Break=other}', "");
Expect(0, 918000, '\p{^Is_Word_Break=other}', "");
Expect(0, 918000, '\P{Is_Word_Break=other}', "");
Expect(1, 918000, '\P{^Is_Word_Break=other}', "");
Expect(0, 917999, '\p{Is_Word_Break=other}', "");
Expect(1, 917999, '\p{^Is_Word_Break=other}', "");
Expect(1, 917999, '\P{Is_Word_Break=other}', "");
Expect(0, 917999, '\P{^Is_Word_Break=other}', "");
Expect(1, 918000, '\p{Is_Word_Break=--Other}', "");
Expect(0, 918000, '\p{^Is_Word_Break=--Other}', "");
Expect(0, 918000, '\P{Is_Word_Break=--Other}', "");
Expect(1, 918000, '\P{^Is_Word_Break=--Other}', "");
Expect(0, 917999, '\p{Is_Word_Break=--Other}', "");
Expect(1, 917999, '\p{^Is_Word_Break=--Other}', "");
Expect(1, 917999, '\P{Is_Word_Break=--Other}', "");
Expect(0, 917999, '\P{^Is_Word_Break=--Other}', "");
Error('\p{Is_WB=XX/a/}');
Error('\P{Is_WB=XX/a/}');
Expect(1, 918000, '\p{Is_WB=xx}', "");
Expect(0, 918000, '\p{^Is_WB=xx}', "");
Expect(0, 918000, '\P{Is_WB=xx}', "");
Expect(1, 918000, '\P{^Is_WB=xx}', "");
Expect(0, 917999, '\p{Is_WB=xx}', "");
Expect(1, 917999, '\p{^Is_WB=xx}', "");
Expect(1, 917999, '\P{Is_WB=xx}', "");
Expect(0, 917999, '\P{^Is_WB=xx}', "");
Expect(1, 918000, '\p{Is_WB=	_XX}', "");
Expect(0, 918000, '\p{^Is_WB=	_XX}', "");
Expect(0, 918000, '\P{Is_WB=	_XX}', "");
Expect(1, 918000, '\P{^Is_WB=	_XX}', "");
Expect(0, 917999, '\p{Is_WB=	_XX}', "");
Expect(1, 917999, '\p{^Is_WB=	_XX}', "");
Expect(1, 917999, '\P{Is_WB=	_XX}', "");
Expect(0, 917999, '\P{^Is_WB=	_XX}', "");
Error('\p{White_Space=_NO/a/}');
Error('\P{White_Space=_NO/a/}');
Expect(1, 12289, '\p{White_Space=no}', "");
Expect(0, 12289, '\p{^White_Space=no}', "");
Expect(0, 12289, '\P{White_Space=no}', "");
Expect(1, 12289, '\P{^White_Space=no}', "");
Expect(0, 12288, '\p{White_Space=no}', "");
Expect(1, 12288, '\p{^White_Space=no}', "");
Expect(1, 12288, '\P{White_Space=no}', "");
Expect(0, 12288, '\P{^White_Space=no}', "");
Expect(1, 12289, '\p{White_Space:    	NO}', "");
Expect(0, 12289, '\p{^White_Space:    	NO}', "");
Expect(0, 12289, '\P{White_Space:    	NO}', "");
Expect(1, 12289, '\P{^White_Space:    	NO}', "");
Expect(0, 12288, '\p{White_Space:    	NO}', "");
Expect(1, 12288, '\p{^White_Space:    	NO}', "");
Expect(1, 12288, '\P{White_Space:    	NO}', "");
Expect(0, 12288, '\P{^White_Space:    	NO}', "");
Error('\p{WSpace=_	N:=}');
Error('\P{WSpace=_	N:=}');
Expect(1, 12289, '\p{WSpace=n}', "");
Expect(0, 12289, '\p{^WSpace=n}', "");
Expect(0, 12289, '\P{WSpace=n}', "");
Expect(1, 12289, '\P{^WSpace=n}', "");
Expect(0, 12288, '\p{WSpace=n}', "");
Expect(1, 12288, '\p{^WSpace=n}', "");
Expect(1, 12288, '\P{WSpace=n}', "");
Expect(0, 12288, '\P{^WSpace=n}', "");
Expect(1, 12289, '\p{WSpace:	 N}', "");
Expect(0, 12289, '\p{^WSpace:	 N}', "");
Expect(0, 12289, '\P{WSpace:	 N}', "");
Expect(1, 12289, '\P{^WSpace:	 N}', "");
Expect(0, 12288, '\p{WSpace:	 N}', "");
Expect(1, 12288, '\p{^WSpace:	 N}', "");
Expect(1, 12288, '\P{WSpace:	 N}', "");
Expect(0, 12288, '\P{^WSpace:	 N}', "");
Error('\p{Space=F/a/}');
Error('\P{Space=F/a/}');
Expect(1, 12289, '\p{Space=f}', "");
Expect(0, 12289, '\p{^Space=f}', "");
Expect(0, 12289, '\P{Space=f}', "");
Expect(1, 12289, '\P{^Space=f}', "");
Expect(0, 12288, '\p{Space=f}', "");
Expect(1, 12288, '\p{^Space=f}', "");
Expect(1, 12288, '\P{Space=f}', "");
Expect(0, 12288, '\P{^Space=f}', "");
Expect(1, 12289, '\p{Space=	 F}', "");
Expect(0, 12289, '\p{^Space=	 F}', "");
Expect(0, 12289, '\P{Space=	 F}', "");
Expect(1, 12289, '\P{^Space=	 F}', "");
Expect(0, 12288, '\p{Space=	 F}', "");
Expect(1, 12288, '\p{^Space=	 F}', "");
Expect(1, 12288, '\P{Space=	 F}', "");
Expect(0, 12288, '\P{^Space=	 F}', "");
Error('\p{Is_White_Space=:=- false}');
Error('\P{Is_White_Space=:=- false}');
Expect(1, 12289, '\p{Is_White_Space=false}', "");
Expect(0, 12289, '\p{^Is_White_Space=false}', "");
Expect(0, 12289, '\P{Is_White_Space=false}', "");
Expect(1, 12289, '\P{^Is_White_Space=false}', "");
Expect(0, 12288, '\p{Is_White_Space=false}', "");
Expect(1, 12288, '\p{^Is_White_Space=false}', "");
Expect(1, 12288, '\P{Is_White_Space=false}', "");
Expect(0, 12288, '\P{^Is_White_Space=false}', "");
Expect(1, 12289, '\p{Is_White_Space=_ False}', "");
Expect(0, 12289, '\p{^Is_White_Space=_ False}', "");
Expect(0, 12289, '\P{Is_White_Space=_ False}', "");
Expect(1, 12289, '\P{^Is_White_Space=_ False}', "");
Expect(0, 12288, '\p{Is_White_Space=_ False}', "");
Expect(1, 12288, '\p{^Is_White_Space=_ False}', "");
Expect(1, 12288, '\P{Is_White_Space=_ False}', "");
Expect(0, 12288, '\P{^Is_White_Space=_ False}', "");
Error('\p{Is_WSpace=	:=no}');
Error('\P{Is_WSpace=	:=no}');
Expect(1, 12289, '\p{Is_WSpace=no}', "");
Expect(0, 12289, '\p{^Is_WSpace=no}', "");
Expect(0, 12289, '\P{Is_WSpace=no}', "");
Expect(1, 12289, '\P{^Is_WSpace=no}', "");
Expect(0, 12288, '\p{Is_WSpace=no}', "");
Expect(1, 12288, '\p{^Is_WSpace=no}', "");
Expect(1, 12288, '\P{Is_WSpace=no}', "");
Expect(0, 12288, '\P{^Is_WSpace=no}', "");
Expect(1, 12289, '\p{Is_WSpace=__No}', "");
Expect(0, 12289, '\p{^Is_WSpace=__No}', "");
Expect(0, 12289, '\P{Is_WSpace=__No}', "");
Expect(1, 12289, '\P{^Is_WSpace=__No}', "");
Expect(0, 12288, '\p{Is_WSpace=__No}', "");
Expect(1, 12288, '\p{^Is_WSpace=__No}', "");
Expect(1, 12288, '\P{Is_WSpace=__No}', "");
Expect(0, 12288, '\P{^Is_WSpace=__No}', "");
Error('\p{Is_Space=/a/		N}');
Error('\P{Is_Space=/a/		N}');
Expect(1, 12289, '\p{Is_Space=n}', "");
Expect(0, 12289, '\p{^Is_Space=n}', "");
Expect(0, 12289, '\P{Is_Space=n}', "");
Expect(1, 12289, '\P{^Is_Space=n}', "");
Expect(0, 12288, '\p{Is_Space=n}', "");
Expect(1, 12288, '\p{^Is_Space=n}', "");
Expect(1, 12288, '\P{Is_Space=n}', "");
Expect(0, 12288, '\P{^Is_Space=n}', "");
Expect(1, 12289, '\p{Is_Space=	_N}', "");
Expect(0, 12289, '\p{^Is_Space=	_N}', "");
Expect(0, 12289, '\P{Is_Space=	_N}', "");
Expect(1, 12289, '\P{^Is_Space=	_N}', "");
Expect(0, 12288, '\p{Is_Space=	_N}', "");
Expect(1, 12288, '\p{^Is_Space=	_N}', "");
Expect(1, 12288, '\P{Is_Space=	_N}', "");
Expect(0, 12288, '\P{^Is_Space=	_N}', "");
Error('\p{White_Space=:= YES}');
Error('\P{White_Space=:= YES}');
Expect(1, 12288, '\p{White_Space=yes}', "");
Expect(0, 12288, '\p{^White_Space=yes}', "");
Expect(0, 12288, '\P{White_Space=yes}', "");
Expect(1, 12288, '\P{^White_Space=yes}', "");
Expect(0, 12289, '\p{White_Space=yes}', "");
Expect(1, 12289, '\p{^White_Space=yes}', "");
Expect(1, 12289, '\P{White_Space=yes}', "");
Expect(0, 12289, '\P{^White_Space=yes}', "");
Expect(1, 12288, '\p{White_Space=-	YES}', "");
Expect(0, 12288, '\p{^White_Space=-	YES}', "");
Expect(0, 12288, '\P{White_Space=-	YES}', "");
Expect(1, 12288, '\P{^White_Space=-	YES}', "");
Expect(0, 12289, '\p{White_Space=-	YES}', "");
Expect(1, 12289, '\p{^White_Space=-	YES}', "");
Expect(1, 12289, '\P{White_Space=-	YES}', "");
Expect(0, 12289, '\P{^White_Space=-	YES}', "");
Error('\p{WSpace=-y/a/}');
Error('\P{WSpace=-y/a/}');
Expect(1, 12288, '\p{WSpace=y}', "");
Expect(0, 12288, '\p{^WSpace=y}', "");
Expect(0, 12288, '\P{WSpace=y}', "");
Expect(1, 12288, '\P{^WSpace=y}', "");
Expect(0, 12289, '\p{WSpace=y}', "");
Expect(1, 12289, '\p{^WSpace=y}', "");
Expect(1, 12289, '\P{WSpace=y}', "");
Expect(0, 12289, '\P{^WSpace=y}', "");
Expect(1, 12288, '\p{WSpace=- y}', "");
Expect(0, 12288, '\p{^WSpace=- y}', "");
Expect(0, 12288, '\P{WSpace=- y}', "");
Expect(1, 12288, '\P{^WSpace=- y}', "");
Expect(0, 12289, '\p{WSpace=- y}', "");
Expect(1, 12289, '\p{^WSpace=- y}', "");
Expect(1, 12289, '\P{WSpace=- y}', "");
Expect(0, 12289, '\P{^WSpace=- y}', "");
Error('\p{Space=:=--T}');
Error('\P{Space=:=--T}');
Expect(1, 12288, '\p{Space=t}', "");
Expect(0, 12288, '\p{^Space=t}', "");
Expect(0, 12288, '\P{Space=t}', "");
Expect(1, 12288, '\P{^Space=t}', "");
Expect(0, 12289, '\p{Space=t}', "");
Expect(1, 12289, '\p{^Space=t}', "");
Expect(1, 12289, '\P{Space=t}', "");
Expect(0, 12289, '\P{^Space=t}', "");
Expect(1, 12288, '\p{Space=	T}', "");
Expect(0, 12288, '\p{^Space=	T}', "");
Expect(0, 12288, '\P{Space=	T}', "");
Expect(1, 12288, '\P{^Space=	T}', "");
Expect(0, 12289, '\p{Space=	T}', "");
Expect(1, 12289, '\p{^Space=	T}', "");
Expect(1, 12289, '\P{Space=	T}', "");
Expect(0, 12289, '\P{^Space=	T}', "");
Error('\p{Is_White_Space=	/a/true}');
Error('\P{Is_White_Space=	/a/true}');
Expect(1, 12288, '\p{Is_White_Space=true}', "");
Expect(0, 12288, '\p{^Is_White_Space=true}', "");
Expect(0, 12288, '\P{Is_White_Space=true}', "");
Expect(1, 12288, '\P{^Is_White_Space=true}', "");
Expect(0, 12289, '\p{Is_White_Space=true}', "");
Expect(1, 12289, '\p{^Is_White_Space=true}', "");
Expect(1, 12289, '\P{Is_White_Space=true}', "");
Expect(0, 12289, '\P{^Is_White_Space=true}', "");
Expect(1, 12288, '\p{Is_White_Space=- TRUE}', "");
Expect(0, 12288, '\p{^Is_White_Space=- TRUE}', "");
Expect(0, 12288, '\P{Is_White_Space=- TRUE}', "");
Expect(1, 12288, '\P{^Is_White_Space=- TRUE}', "");
Expect(0, 12289, '\p{Is_White_Space=- TRUE}', "");
Expect(1, 12289, '\p{^Is_White_Space=- TRUE}', "");
Expect(1, 12289, '\P{Is_White_Space=- TRUE}', "");
Expect(0, 12289, '\P{^Is_White_Space=- TRUE}', "");
Error('\p{Is_WSpace=  YES:=}');
Error('\P{Is_WSpace=  YES:=}');
Expect(1, 12288, '\p{Is_WSpace=yes}', "");
Expect(0, 12288, '\p{^Is_WSpace=yes}', "");
Expect(0, 12288, '\P{Is_WSpace=yes}', "");
Expect(1, 12288, '\P{^Is_WSpace=yes}', "");
Expect(0, 12289, '\p{Is_WSpace=yes}', "");
Expect(1, 12289, '\p{^Is_WSpace=yes}', "");
Expect(1, 12289, '\P{Is_WSpace=yes}', "");
Expect(0, 12289, '\P{^Is_WSpace=yes}', "");
Expect(1, 12288, '\p{Is_WSpace=	_Yes}', "");
Expect(0, 12288, '\p{^Is_WSpace=	_Yes}', "");
Expect(0, 12288, '\P{Is_WSpace=	_Yes}', "");
Expect(1, 12288, '\P{^Is_WSpace=	_Yes}', "");
Expect(0, 12289, '\p{Is_WSpace=	_Yes}', "");
Expect(1, 12289, '\p{^Is_WSpace=	_Yes}', "");
Expect(1, 12289, '\P{Is_WSpace=	_Yes}', "");
Expect(0, 12289, '\P{^Is_WSpace=	_Yes}', "");
Error('\p{Is_Space=_Y/a/}');
Error('\P{Is_Space=_Y/a/}');
Expect(1, 12288, '\p{Is_Space=y}', "");
Expect(0, 12288, '\p{^Is_Space=y}', "");
Expect(0, 12288, '\P{Is_Space=y}', "");
Expect(1, 12288, '\P{^Is_Space=y}', "");
Expect(0, 12289, '\p{Is_Space=y}', "");
Expect(1, 12289, '\p{^Is_Space=y}', "");
Expect(1, 12289, '\P{Is_Space=y}', "");
Expect(0, 12289, '\P{^Is_Space=y}', "");
Expect(1, 12288, '\p{Is_Space=	-Y}', "");
Expect(0, 12288, '\p{^Is_Space=	-Y}', "");
Expect(0, 12288, '\P{Is_Space=	-Y}', "");
Expect(1, 12288, '\P{^Is_Space=	-Y}', "");
Expect(0, 12289, '\p{Is_Space=	-Y}', "");
Expect(1, 12289, '\p{^Is_Space=	-Y}', "");
Expect(1, 12289, '\P{Is_Space=	-Y}', "");
Expect(0, 12289, '\P{^Is_Space=	-Y}', "");
Error('\p{XID_Continue=:=-No}');
Error('\P{XID_Continue=:=-No}');
Expect(1, 918000, '\p{XID_Continue=no}', "");
Expect(0, 918000, '\p{^XID_Continue=no}', "");
Expect(0, 918000, '\P{XID_Continue=no}', "");
Expect(1, 918000, '\P{^XID_Continue=no}', "");
Expect(0, 917999, '\p{XID_Continue=no}', "");
Expect(1, 917999, '\p{^XID_Continue=no}', "");
Expect(1, 917999, '\P{XID_Continue=no}', "");
Expect(0, 917999, '\P{^XID_Continue=no}', "");
Expect(1, 918000, '\p{XID_Continue=-no}', "");
Expect(0, 918000, '\p{^XID_Continue=-no}', "");
Expect(0, 918000, '\P{XID_Continue=-no}', "");
Expect(1, 918000, '\P{^XID_Continue=-no}', "");
Expect(0, 917999, '\p{XID_Continue=-no}', "");
Expect(1, 917999, '\p{^XID_Continue=-no}', "");
Expect(1, 917999, '\P{XID_Continue=-no}', "");
Expect(0, 917999, '\P{^XID_Continue=-no}', "");
Error('\p{XIDC= N:=}');
Error('\P{XIDC= N:=}');
Expect(1, 918000, '\p{XIDC=n}', "");
Expect(0, 918000, '\p{^XIDC=n}', "");
Expect(0, 918000, '\P{XIDC=n}', "");
Expect(1, 918000, '\P{^XIDC=n}', "");
Expect(0, 917999, '\p{XIDC=n}', "");
Expect(1, 917999, '\p{^XIDC=n}', "");
Expect(1, 917999, '\P{XIDC=n}', "");
Expect(0, 917999, '\P{^XIDC=n}', "");
Expect(1, 918000, '\p{XIDC= n}', "");
Expect(0, 918000, '\p{^XIDC= n}', "");
Expect(0, 918000, '\P{XIDC= n}', "");
Expect(1, 918000, '\P{^XIDC= n}', "");
Expect(0, 917999, '\p{XIDC= n}', "");
Expect(1, 917999, '\p{^XIDC= n}', "");
Expect(1, 917999, '\P{XIDC= n}', "");
Expect(0, 917999, '\P{^XIDC= n}', "");
Error('\p{Is_XID_Continue=	 F:=}');
Error('\P{Is_XID_Continue=	 F:=}');
Expect(1, 918000, '\p{Is_XID_Continue=f}', "");
Expect(0, 918000, '\p{^Is_XID_Continue=f}', "");
Expect(0, 918000, '\P{Is_XID_Continue=f}', "");
Expect(1, 918000, '\P{^Is_XID_Continue=f}', "");
Expect(0, 917999, '\p{Is_XID_Continue=f}', "");
Expect(1, 917999, '\p{^Is_XID_Continue=f}', "");
Expect(1, 917999, '\P{Is_XID_Continue=f}', "");
Expect(0, 917999, '\P{^Is_XID_Continue=f}', "");
Expect(1, 918000, '\p{Is_XID_Continue=-_F}', "");
Expect(0, 918000, '\p{^Is_XID_Continue=-_F}', "");
Expect(0, 918000, '\P{Is_XID_Continue=-_F}', "");
Expect(1, 918000, '\P{^Is_XID_Continue=-_F}', "");
Expect(0, 917999, '\p{Is_XID_Continue=-_F}', "");
Expect(1, 917999, '\p{^Is_XID_Continue=-_F}', "");
Expect(1, 917999, '\P{Is_XID_Continue=-_F}', "");
Expect(0, 917999, '\P{^Is_XID_Continue=-_F}', "");
Error('\p{Is_XIDC=_False:=}');
Error('\P{Is_XIDC=_False:=}');
Expect(1, 918000, '\p{Is_XIDC=false}', "");
Expect(0, 918000, '\p{^Is_XIDC=false}', "");
Expect(0, 918000, '\P{Is_XIDC=false}', "");
Expect(1, 918000, '\P{^Is_XIDC=false}', "");
Expect(0, 917999, '\p{Is_XIDC=false}', "");
Expect(1, 917999, '\p{^Is_XIDC=false}', "");
Expect(1, 917999, '\P{Is_XIDC=false}', "");
Expect(0, 917999, '\P{^Is_XIDC=false}', "");
Expect(1, 918000, '\p{Is_XIDC= False}', "");
Expect(0, 918000, '\p{^Is_XIDC= False}', "");
Expect(0, 918000, '\P{Is_XIDC= False}', "");
Expect(1, 918000, '\P{^Is_XIDC= False}', "");
Expect(0, 917999, '\p{Is_XIDC= False}', "");
Expect(1, 917999, '\p{^Is_XIDC= False}', "");
Expect(1, 917999, '\P{Is_XIDC= False}', "");
Expect(0, 917999, '\P{^Is_XIDC= False}', "");
Error('\p{XID_Continue=/a/ _yes}');
Error('\P{XID_Continue=/a/ _yes}');
Expect(1, 917999, '\p{XID_Continue=yes}', "");
Expect(0, 917999, '\p{^XID_Continue=yes}', "");
Expect(0, 917999, '\P{XID_Continue=yes}', "");
Expect(1, 917999, '\P{^XID_Continue=yes}', "");
Expect(0, 918000, '\p{XID_Continue=yes}', "");
Expect(1, 918000, '\p{^XID_Continue=yes}', "");
Expect(1, 918000, '\P{XID_Continue=yes}', "");
Expect(0, 918000, '\P{^XID_Continue=yes}', "");
Expect(1, 917999, '\p{XID_Continue=	 Yes}', "");
Expect(0, 917999, '\p{^XID_Continue=	 Yes}', "");
Expect(0, 917999, '\P{XID_Continue=	 Yes}', "");
Expect(1, 917999, '\P{^XID_Continue=	 Yes}', "");
Expect(0, 918000, '\p{XID_Continue=	 Yes}', "");
Expect(1, 918000, '\p{^XID_Continue=	 Yes}', "");
Expect(1, 918000, '\P{XID_Continue=	 Yes}', "");
Expect(0, 918000, '\P{^XID_Continue=	 Yes}', "");
Error('\p{XIDC= 	y/a/}');
Error('\P{XIDC= 	y/a/}');
Expect(1, 917999, '\p{XIDC=y}', "");
Expect(0, 917999, '\p{^XIDC=y}', "");
Expect(0, 917999, '\P{XIDC=y}', "");
Expect(1, 917999, '\P{^XIDC=y}', "");
Expect(0, 918000, '\p{XIDC=y}', "");
Expect(1, 918000, '\p{^XIDC=y}', "");
Expect(1, 918000, '\P{XIDC=y}', "");
Expect(0, 918000, '\P{^XIDC=y}', "");
Expect(1, 917999, '\p{XIDC=	-y}', "");
Expect(0, 917999, '\p{^XIDC=	-y}', "");
Expect(0, 917999, '\P{XIDC=	-y}', "");
Expect(1, 917999, '\P{^XIDC=	-y}', "");
Expect(0, 918000, '\p{XIDC=	-y}', "");
Expect(1, 918000, '\p{^XIDC=	-y}', "");
Expect(1, 918000, '\P{XIDC=	-y}', "");
Expect(0, 918000, '\P{^XIDC=	-y}', "");
Error('\p{Is_XID_Continue=_T/a/}');
Error('\P{Is_XID_Continue=_T/a/}');
Expect(1, 917999, '\p{Is_XID_Continue=t}', "");
Expect(0, 917999, '\p{^Is_XID_Continue=t}', "");
Expect(0, 917999, '\P{Is_XID_Continue=t}', "");
Expect(1, 917999, '\P{^Is_XID_Continue=t}', "");
Expect(0, 918000, '\p{Is_XID_Continue=t}', "");
Expect(1, 918000, '\p{^Is_XID_Continue=t}', "");
Expect(1, 918000, '\P{Is_XID_Continue=t}', "");
Expect(0, 918000, '\P{^Is_XID_Continue=t}', "");
Expect(1, 917999, '\p{Is_XID_Continue=		T}', "");
Expect(0, 917999, '\p{^Is_XID_Continue=		T}', "");
Expect(0, 917999, '\P{Is_XID_Continue=		T}', "");
Expect(1, 917999, '\P{^Is_XID_Continue=		T}', "");
Expect(0, 918000, '\p{Is_XID_Continue=		T}', "");
Expect(1, 918000, '\p{^Is_XID_Continue=		T}', "");
Expect(1, 918000, '\P{Is_XID_Continue=		T}', "");
Expect(0, 918000, '\P{^Is_XID_Continue=		T}', "");
Error('\p{Is_XIDC=/a/_	TRUE}');
Error('\P{Is_XIDC=/a/_	TRUE}');
Expect(1, 917999, '\p{Is_XIDC=true}', "");
Expect(0, 917999, '\p{^Is_XIDC=true}', "");
Expect(0, 917999, '\P{Is_XIDC=true}', "");
Expect(1, 917999, '\P{^Is_XIDC=true}', "");
Expect(0, 918000, '\p{Is_XIDC=true}', "");
Expect(1, 918000, '\p{^Is_XIDC=true}', "");
Expect(1, 918000, '\P{Is_XIDC=true}', "");
Expect(0, 918000, '\P{^Is_XIDC=true}', "");
Expect(1, 917999, '\p{Is_XIDC=_-True}', "");
Expect(0, 917999, '\p{^Is_XIDC=_-True}', "");
Expect(0, 917999, '\P{Is_XIDC=_-True}', "");
Expect(1, 917999, '\P{^Is_XIDC=_-True}', "");
Expect(0, 918000, '\p{Is_XIDC=_-True}', "");
Expect(1, 918000, '\p{^Is_XIDC=_-True}', "");
Expect(1, 918000, '\P{Is_XIDC=_-True}', "");
Expect(0, 918000, '\P{^Is_XIDC=_-True}', "");
Error('\p{XID_Start=-No/a/}');
Error('\P{XID_Start=-No/a/}');
Expect(1, 195102, '\p{XID_Start=no}', "");
Expect(0, 195102, '\p{^XID_Start=no}', "");
Expect(0, 195102, '\P{XID_Start=no}', "");
Expect(1, 195102, '\P{^XID_Start=no}', "");
Expect(0, 195101, '\p{XID_Start=no}', "");
Expect(1, 195101, '\p{^XID_Start=no}', "");
Expect(1, 195101, '\P{XID_Start=no}', "");
Expect(0, 195101, '\P{^XID_Start=no}', "");
Expect(1, 195102, '\p{XID_Start=	no}', "");
Expect(0, 195102, '\p{^XID_Start=	no}', "");
Expect(0, 195102, '\P{XID_Start=	no}', "");
Expect(1, 195102, '\P{^XID_Start=	no}', "");
Expect(0, 195101, '\p{XID_Start=	no}', "");
Expect(1, 195101, '\p{^XID_Start=	no}', "");
Expect(1, 195101, '\P{XID_Start=	no}', "");
Expect(0, 195101, '\P{^XID_Start=	no}', "");
Error('\p{XIDS=:=		n}');
Error('\P{XIDS=:=		n}');
Expect(1, 195102, '\p{XIDS:	n}', "");
Expect(0, 195102, '\p{^XIDS:	n}', "");
Expect(0, 195102, '\P{XIDS:	n}', "");
Expect(1, 195102, '\P{^XIDS:	n}', "");
Expect(0, 195101, '\p{XIDS:	n}', "");
Expect(1, 195101, '\p{^XIDS:	n}', "");
Expect(1, 195101, '\P{XIDS:	n}', "");
Expect(0, 195101, '\P{^XIDS:	n}', "");
Expect(1, 195102, '\p{XIDS=__N}', "");
Expect(0, 195102, '\p{^XIDS=__N}', "");
Expect(0, 195102, '\P{XIDS=__N}', "");
Expect(1, 195102, '\P{^XIDS=__N}', "");
Expect(0, 195101, '\p{XIDS=__N}', "");
Expect(1, 195101, '\p{^XIDS=__N}', "");
Expect(1, 195101, '\P{XIDS=__N}', "");
Expect(0, 195101, '\P{^XIDS=__N}', "");
Error('\p{Is_XID_Start=/a/	F}');
Error('\P{Is_XID_Start=/a/	F}');
Expect(1, 195102, '\p{Is_XID_Start=f}', "");
Expect(0, 195102, '\p{^Is_XID_Start=f}', "");
Expect(0, 195102, '\P{Is_XID_Start=f}', "");
Expect(1, 195102, '\P{^Is_XID_Start=f}', "");
Expect(0, 195101, '\p{Is_XID_Start=f}', "");
Expect(1, 195101, '\p{^Is_XID_Start=f}', "");
Expect(1, 195101, '\P{Is_XID_Start=f}', "");
Expect(0, 195101, '\P{^Is_XID_Start=f}', "");
Expect(1, 195102, '\p{Is_XID_Start=	 f}', "");
Expect(0, 195102, '\p{^Is_XID_Start=	 f}', "");
Expect(0, 195102, '\P{Is_XID_Start=	 f}', "");
Expect(1, 195102, '\P{^Is_XID_Start=	 f}', "");
Expect(0, 195101, '\p{Is_XID_Start=	 f}', "");
Expect(1, 195101, '\p{^Is_XID_Start=	 f}', "");
Expect(1, 195101, '\P{Is_XID_Start=	 f}', "");
Expect(0, 195101, '\P{^Is_XID_Start=	 f}', "");
Error('\p{Is_XIDS:_False/a/}');
Error('\P{Is_XIDS:_False/a/}');
Expect(1, 195102, '\p{Is_XIDS:   false}', "");
Expect(0, 195102, '\p{^Is_XIDS:   false}', "");
Expect(0, 195102, '\P{Is_XIDS:   false}', "");
Expect(1, 195102, '\P{^Is_XIDS:   false}', "");
Expect(0, 195101, '\p{Is_XIDS:   false}', "");
Expect(1, 195101, '\p{^Is_XIDS:   false}', "");
Expect(1, 195101, '\P{Is_XIDS:   false}', "");
Expect(0, 195101, '\P{^Is_XIDS:   false}', "");
Expect(1, 195102, '\p{Is_XIDS= FALSE}', "");
Expect(0, 195102, '\p{^Is_XIDS= FALSE}', "");
Expect(0, 195102, '\P{Is_XIDS= FALSE}', "");
Expect(1, 195102, '\P{^Is_XIDS= FALSE}', "");
Expect(0, 195101, '\p{Is_XIDS= FALSE}', "");
Expect(1, 195101, '\p{^Is_XIDS= FALSE}', "");
Expect(1, 195101, '\P{Is_XIDS= FALSE}', "");
Expect(0, 195101, '\P{^Is_XIDS= FALSE}', "");
Error('\p{XID_Start=:=_ Yes}');
Error('\P{XID_Start=:=_ Yes}');
Expect(1, 195101, '\p{XID_Start=yes}', "");
Expect(0, 195101, '\p{^XID_Start=yes}', "");
Expect(0, 195101, '\P{XID_Start=yes}', "");
Expect(1, 195101, '\P{^XID_Start=yes}', "");
Expect(0, 195102, '\p{XID_Start=yes}', "");
Expect(1, 195102, '\p{^XID_Start=yes}', "");
Expect(1, 195102, '\P{XID_Start=yes}', "");
Expect(0, 195102, '\P{^XID_Start=yes}', "");
Expect(1, 195101, '\p{XID_Start= Yes}', "");
Expect(0, 195101, '\p{^XID_Start= Yes}', "");
Expect(0, 195101, '\P{XID_Start= Yes}', "");
Expect(1, 195101, '\P{^XID_Start= Yes}', "");
Expect(0, 195102, '\p{XID_Start= Yes}', "");
Expect(1, 195102, '\p{^XID_Start= Yes}', "");
Expect(1, 195102, '\P{XID_Start= Yes}', "");
Expect(0, 195102, '\P{^XID_Start= Yes}', "");
Error('\p{XIDS:	/a/ Y}');
Error('\P{XIDS:	/a/ Y}');
Expect(1, 195101, '\p{XIDS=y}', "");
Expect(0, 195101, '\p{^XIDS=y}', "");
Expect(0, 195101, '\P{XIDS=y}', "");
Expect(1, 195101, '\P{^XIDS=y}', "");
Expect(0, 195102, '\p{XIDS=y}', "");
Expect(1, 195102, '\p{^XIDS=y}', "");
Expect(1, 195102, '\P{XIDS=y}', "");
Expect(0, 195102, '\P{^XIDS=y}', "");
Expect(1, 195101, '\p{XIDS=	y}', "");
Expect(0, 195101, '\p{^XIDS=	y}', "");
Expect(0, 195101, '\P{XIDS=	y}', "");
Expect(1, 195101, '\P{^XIDS=	y}', "");
Expect(0, 195102, '\p{XIDS=	y}', "");
Expect(1, 195102, '\p{^XIDS=	y}', "");
Expect(1, 195102, '\P{XIDS=	y}', "");
Expect(0, 195102, '\P{^XIDS=	y}', "");
Error('\p{Is_XID_Start=- t:=}');
Error('\P{Is_XID_Start=- t:=}');
Expect(1, 195101, '\p{Is_XID_Start:   t}', "");
Expect(0, 195101, '\p{^Is_XID_Start:   t}', "");
Expect(0, 195101, '\P{Is_XID_Start:   t}', "");
Expect(1, 195101, '\P{^Is_XID_Start:   t}', "");
Expect(0, 195102, '\p{Is_XID_Start:   t}', "");
Expect(1, 195102, '\p{^Is_XID_Start:   t}', "");
Expect(1, 195102, '\P{Is_XID_Start:   t}', "");
Expect(0, 195102, '\P{^Is_XID_Start:   t}', "");
Expect(1, 195101, '\p{Is_XID_Start:	 T}', "");
Expect(0, 195101, '\p{^Is_XID_Start:	 T}', "");
Expect(0, 195101, '\P{Is_XID_Start:	 T}', "");
Expect(1, 195101, '\P{^Is_XID_Start:	 T}', "");
Expect(0, 195102, '\p{Is_XID_Start:	 T}', "");
Expect(1, 195102, '\p{^Is_XID_Start:	 T}', "");
Expect(1, 195102, '\P{Is_XID_Start:	 T}', "");
Expect(0, 195102, '\P{^Is_XID_Start:	 T}', "");
Error('\p{Is_XIDS=:=--True}');
Error('\P{Is_XIDS=:=--True}');
Expect(1, 195101, '\p{Is_XIDS=true}', "");
Expect(0, 195101, '\p{^Is_XIDS=true}', "");
Expect(0, 195101, '\P{Is_XIDS=true}', "");
Expect(1, 195101, '\P{^Is_XIDS=true}', "");
Expect(0, 195102, '\p{Is_XIDS=true}', "");
Expect(1, 195102, '\p{^Is_XIDS=true}', "");
Expect(1, 195102, '\P{Is_XIDS=true}', "");
Expect(0, 195102, '\P{^Is_XIDS=true}', "");
Expect(1, 195101, '\p{Is_XIDS=_	TRUE}', "");
Expect(0, 195101, '\p{^Is_XIDS=_	TRUE}', "");
Expect(0, 195101, '\P{Is_XIDS=_	TRUE}', "");
Expect(1, 195101, '\P{^Is_XIDS=_	TRUE}', "");
Expect(0, 195102, '\p{Is_XIDS=_	TRUE}', "");
Expect(1, 195102, '\p{^Is_XIDS=_	TRUE}', "");
Expect(1, 195102, '\P{Is_XIDS=_	TRUE}', "");
Expect(0, 195102, '\P{^Is_XIDS=_	TRUE}', "");
Error('\p{Expands_On_NFC=No}');
Error('\P{Expands_On_NFC=No}');
Error('\p{XO_NFC=N}');
Error('\P{XO_NFC=N}');
Error('\p{Is_Expands_On_NFC=F}');
Error('\P{Is_Expands_On_NFC=F}');
Error('\p{Is_XO_NFC: False}');
Error('\P{Is_XO_NFC: False}');
Error('\p{Expands_On_NFC=Yes}');
Error('\P{Expands_On_NFC=Yes}');
Error('\p{XO_NFC=Y}');
Error('\P{XO_NFC=Y}');
Error('\p{Is_Expands_On_NFC=T}');
Error('\P{Is_Expands_On_NFC=T}');
Error('\p{Is_XO_NFC:True}');
Error('\P{Is_XO_NFC:True}');
Error('\p{Expands_On_NFD=No}');
Error('\P{Expands_On_NFD=No}');
Error('\p{XO_NFD:N}');
Error('\P{XO_NFD:N}');
Error('\p{Is_Expands_On_NFD: F}');
Error('\P{Is_Expands_On_NFD: F}');
Error('\p{Is_XO_NFD=False}');
Error('\P{Is_XO_NFD=False}');
Error('\p{Expands_On_NFD=Yes}');
Error('\P{Expands_On_NFD=Yes}');
Error('\p{XO_NFD=Y}');
Error('\P{XO_NFD=Y}');
Error('\p{Is_Expands_On_NFD=T}');
Error('\P{Is_Expands_On_NFD=T}');
Error('\p{Is_XO_NFD=True}');
Error('\P{Is_XO_NFD=True}');
Error('\p{Expands_On_NFKC=No}');
Error('\P{Expands_On_NFKC=No}');
Error('\p{XO_NFKC:	N}');
Error('\P{XO_NFKC:	N}');
Error('\p{Is_Expands_On_NFKC=F}');
Error('\P{Is_Expands_On_NFKC=F}');
Error('\p{Is_XO_NFKC=False}');
Error('\P{Is_XO_NFKC=False}');
Error('\p{Expands_On_NFKC: Yes}');
Error('\P{Expands_On_NFKC: Yes}');
Error('\p{XO_NFKC=Y}');
Error('\P{XO_NFKC=Y}');
Error('\p{Is_Expands_On_NFKC=T}');
Error('\P{Is_Expands_On_NFKC=T}');
Error('\p{Is_XO_NFKC=True}');
Error('\P{Is_XO_NFKC=True}');
Error('\p{Expands_On_NFKD=No}');
Error('\P{Expands_On_NFKD=No}');
Error('\p{XO_NFKD=N}');
Error('\P{XO_NFKD=N}');
Error('\p{Is_Expands_On_NFKD=F}');
Error('\P{Is_Expands_On_NFKD=F}');
Error('\p{Is_XO_NFKD=False}');
Error('\P{Is_XO_NFKD=False}');
Error('\p{Expands_On_NFKD=Yes}');
Error('\P{Expands_On_NFKD=Yes}');
Error('\p{XO_NFKD=Y}');
Error('\P{XO_NFKD=Y}');
Error('\p{Is_Expands_On_NFKD=T}');
Error('\P{Is_Expands_On_NFKD=T}');
Error('\p{Is_XO_NFKD=True}');
Error('\P{Is_XO_NFKD=True}');
Error('\p{Age:   -_V1_1:=}');
Error('\P{Age:   -_V1_1:=}');
Expect(1, 65533, '\p{Age=v11}', "");
Expect(0, 65533, '\p{^Age=v11}', "");
Expect(0, 65533, '\P{Age=v11}', "");
Expect(1, 65533, '\P{^Age=v11}', "");
Expect(0, 65536, '\p{Age=v11}', "");
Expect(1, 65536, '\p{^Age=v11}', "");
Expect(1, 65536, '\P{Age=v11}', "");
Expect(0, 65536, '\P{^Age=v11}', "");
Expect(1, 65533, '\p{Age:	-v1_1}', "");
Expect(0, 65533, '\p{^Age:	-v1_1}', "");
Expect(0, 65533, '\P{Age:	-v1_1}', "");
Expect(1, 65533, '\P{^Age:	-v1_1}', "");
Expect(0, 65536, '\p{Age:	-v1_1}', "");
Expect(1, 65536, '\p{^Age:	-v1_1}', "");
Expect(1, 65536, '\P{Age:	-v1_1}', "");
Expect(0, 65536, '\P{^Age:	-v1_1}', "");
Error('\p{Is_Age=:=+0000000001.1}');
Error('\P{Is_Age=:=+0000000001.1}');
Expect(1, 65533, '\p{Is_Age=0_0_0_0_0_01.1}', "");
Expect(0, 65533, '\p{^Is_Age=0_0_0_0_0_01.1}', "");
Expect(0, 65533, '\P{Is_Age=0_0_0_0_0_01.1}', "");
Expect(1, 65533, '\P{^Is_Age=0_0_0_0_0_01.1}', "");
Expect(0, 65536, '\p{Is_Age=0_0_0_0_0_01.1}', "");
Expect(1, 65536, '\p{^Is_Age=0_0_0_0_0_01.1}', "");
Expect(1, 65536, '\P{Is_Age=0_0_0_0_0_01.1}', "");
Expect(0, 65536, '\P{^Is_Age=0_0_0_0_0_01.1}', "");
Error('\p{Age=:=V2_0}');
Error('\P{Age=:=V2_0}');
Expect(1, 983040, '\p{Age:   v20}', "");
Expect(0, 983040, '\p{^Age:   v20}', "");
Expect(0, 983040, '\P{Age:   v20}', "");
Expect(1, 983040, '\P{^Age:   v20}', "");
Expect(0, 983037, '\p{Age:   v20}', "");
Expect(1, 983037, '\p{^Age:   v20}', "");
Expect(1, 983037, '\P{Age:   v20}', "");
Expect(0, 983037, '\P{^Age:   v20}', "");
Expect(1, 983040, '\p{Age=-	V2_0}', "");
Expect(0, 983040, '\p{^Age=-	V2_0}', "");
Expect(0, 983040, '\P{Age=-	V2_0}', "");
Expect(1, 983040, '\P{^Age=-	V2_0}', "");
Expect(0, 983037, '\p{Age=-	V2_0}', "");
Expect(1, 983037, '\p{^Age=-	V2_0}', "");
Expect(1, 983037, '\P{Age=-	V2_0}', "");
Expect(0, 983037, '\P{^Age=-	V2_0}', "");
Error('\p{Is_Age: 	00_2.0/a/}');
Error('\P{Is_Age: 	00_2.0/a/}');
Expect(1, 983040, '\p{Is_Age=000000002.0}', "");
Expect(0, 983040, '\p{^Is_Age=000000002.0}', "");
Expect(0, 983040, '\P{Is_Age=000000002.0}', "");
Expect(1, 983040, '\P{^Is_Age=000000002.0}', "");
Expect(0, 983037, '\p{Is_Age=000000002.0}', "");
Expect(1, 983037, '\p{^Is_Age=000000002.0}', "");
Expect(1, 983037, '\P{Is_Age=000000002.0}', "");
Expect(0, 983037, '\P{^Is_Age=000000002.0}', "");
Error('\p{Age=/a/		V2_1}');
Error('\P{Age=/a/		V2_1}');
Expect(1, 65532, '\p{Age=v21}', "");
Expect(0, 65532, '\p{^Age=v21}', "");
Expect(0, 65532, '\P{Age=v21}', "");
Expect(1, 65532, '\P{^Age=v21}', "");
Expect(0, 65533, '\p{Age=v21}', "");
Expect(1, 65533, '\p{^Age=v21}', "");
Expect(1, 65533, '\P{Age=v21}', "");
Expect(0, 65533, '\P{^Age=v21}', "");
Expect(1, 65532, '\p{Age= v2_1}', "");
Expect(0, 65532, '\p{^Age= v2_1}', "");
Expect(0, 65532, '\P{Age= v2_1}', "");
Expect(1, 65532, '\P{^Age= v2_1}', "");
Expect(0, 65533, '\p{Age= v2_1}', "");
Expect(1, 65533, '\p{^Age= v2_1}', "");
Expect(1, 65533, '\P{Age= v2_1}', "");
Expect(0, 65533, '\P{^Age= v2_1}', "");
Error('\p{Is_Age=/a/ 2.1}');
Error('\P{Is_Age=/a/ 2.1}');
Expect(1, 65532, '\p{Is_Age=00000000_2.1}', "");
Expect(0, 65532, '\p{^Is_Age=00000000_2.1}', "");
Expect(0, 65532, '\P{Is_Age=00000000_2.1}', "");
Expect(1, 65532, '\P{^Is_Age=00000000_2.1}', "");
Expect(0, 65533, '\p{Is_Age=00000000_2.1}', "");
Expect(1, 65533, '\p{^Is_Age=00000000_2.1}', "");
Expect(1, 65533, '\P{Is_Age=00000000_2.1}', "");
Expect(0, 65533, '\P{^Is_Age=00000000_2.1}', "");
Error('\p{Age=__V3_0:=}');
Error('\P{Age=__V3_0:=}');
Expect(1, 65531, '\p{Age=v30}', "");
Expect(0, 65531, '\p{^Age=v30}', "");
Expect(0, 65531, '\P{Age=v30}', "");
Expect(1, 65531, '\P{^Age=v30}', "");
Expect(0, 65532, '\p{Age=v30}', "");
Expect(1, 65532, '\p{^Age=v30}', "");
Expect(1, 65532, '\P{Age=v30}', "");
Expect(0, 65532, '\P{^Age=v30}', "");
Expect(1, 65531, '\p{Age: 		v3_0}', "");
Expect(0, 65531, '\p{^Age: 		v3_0}', "");
Expect(0, 65531, '\P{Age: 		v3_0}', "");
Expect(1, 65531, '\P{^Age: 		v3_0}', "");
Expect(0, 65532, '\p{Age: 		v3_0}', "");
Expect(1, 65532, '\p{^Age: 		v3_0}', "");
Expect(1, 65532, '\P{Age: 		v3_0}', "");
Expect(0, 65532, '\P{^Age: 		v3_0}', "");
Error('\p{Is_Age=_/a/00_3.0}');
Error('\P{Is_Age=_/a/00_3.0}');
Expect(1, 65531, '\p{Is_Age=0000000003.0}', "");
Expect(0, 65531, '\p{^Is_Age=0000000003.0}', "");
Expect(0, 65531, '\P{Is_Age=0000000003.0}', "");
Expect(1, 65531, '\P{^Is_Age=0000000003.0}', "");
Expect(0, 65532, '\p{Is_Age=0000000003.0}', "");
Expect(1, 65532, '\p{^Is_Age=0000000003.0}', "");
Expect(1, 65532, '\P{Is_Age=0000000003.0}', "");
Expect(0, 65532, '\P{^Is_Age=0000000003.0}', "");
Error('\p{Age=:=	V3_1}');
Error('\P{Age=:=	V3_1}');
Expect(1, 917631, '\p{Age=v31}', "");
Expect(0, 917631, '\p{^Age=v31}', "");
Expect(0, 917631, '\P{Age=v31}', "");
Expect(1, 917631, '\P{^Age=v31}', "");
Expect(0, 917632, '\p{Age=v31}', "");
Expect(1, 917632, '\p{^Age=v31}', "");
Expect(1, 917632, '\P{Age=v31}', "");
Expect(0, 917632, '\P{^Age=v31}', "");
Expect(1, 917631, '\p{Age=	-V3_1}', "");
Expect(0, 917631, '\p{^Age=	-V3_1}', "");
Expect(0, 917631, '\P{Age=	-V3_1}', "");
Expect(1, 917631, '\P{^Age=	-V3_1}', "");
Expect(0, 917632, '\p{Age=	-V3_1}', "");
Expect(1, 917632, '\p{^Age=	-V3_1}', "");
Expect(1, 917632, '\P{Age=	-V3_1}', "");
Expect(0, 917632, '\P{^Age=	-V3_1}', "");
Error('\p{Is_Age=/a/	 0000_3.1}');
Error('\P{Is_Age=/a/	 0000_3.1}');
Expect(1, 917631, '\p{Is_Age=+000000003.1}', "");
Expect(0, 917631, '\p{^Is_Age=+000000003.1}', "");
Expect(0, 917631, '\P{Is_Age=+000000003.1}', "");
Expect(1, 917631, '\P{^Is_Age=+000000003.1}', "");
Expect(0, 917632, '\p{Is_Age=+000000003.1}', "");
Expect(1, 917632, '\p{^Is_Age=+000000003.1}', "");
Expect(1, 917632, '\P{Is_Age=+000000003.1}', "");
Expect(0, 917632, '\P{^Is_Age=+000000003.1}', "");
Error('\p{Age= :=V3_2}');
Error('\P{Age= :=V3_2}');
Expect(1, 65376, '\p{Age=v32}', "");
Expect(0, 65376, '\p{^Age=v32}', "");
Expect(0, 65376, '\P{Age=v32}', "");
Expect(1, 65376, '\P{^Age=v32}', "");
Expect(0, 65377, '\p{Age=v32}', "");
Expect(1, 65377, '\p{^Age=v32}', "");
Expect(1, 65377, '\P{Age=v32}', "");
Expect(0, 65377, '\P{^Age=v32}', "");
Expect(1, 65376, '\p{Age= 	V3_2}', "");
Expect(0, 65376, '\p{^Age= 	V3_2}', "");
Expect(0, 65376, '\P{Age= 	V3_2}', "");
Expect(1, 65376, '\P{^Age= 	V3_2}', "");
Expect(0, 65377, '\p{Age= 	V3_2}', "");
Expect(1, 65377, '\p{^Age= 	V3_2}', "");
Expect(1, 65377, '\P{Age= 	V3_2}', "");
Expect(0, 65377, '\P{^Age= 	V3_2}', "");
Error('\p{Is_Age:   	:=+000_3.2}');
Error('\P{Is_Age:   	:=+000_3.2}');
Expect(1, 65376, '\p{Is_Age=3.2}', "");
Expect(0, 65376, '\p{^Is_Age=3.2}', "");
Expect(0, 65376, '\P{Is_Age=3.2}', "");
Expect(1, 65376, '\P{^Is_Age=3.2}', "");
Expect(0, 65377, '\p{Is_Age=3.2}', "");
Expect(1, 65377, '\p{^Is_Age=3.2}', "");
Expect(1, 65377, '\P{Is_Age=3.2}', "");
Expect(0, 65377, '\P{^Is_Age=3.2}', "");
Error('\p{Age=	V4_0/a/}');
Error('\P{Age=	V4_0/a/}');
Expect(1, 917999, '\p{Age=v40}', "");
Expect(0, 917999, '\p{^Age=v40}', "");
Expect(0, 917999, '\P{Age=v40}', "");
Expect(1, 917999, '\P{^Age=v40}', "");
Expect(0, 918000, '\p{Age=v40}', "");
Expect(1, 918000, '\p{^Age=v40}', "");
Expect(1, 918000, '\P{Age=v40}', "");
Expect(0, 918000, '\P{^Age=v40}', "");
Expect(1, 917999, '\p{Age=	V4_0}', "");
Expect(0, 917999, '\p{^Age=	V4_0}', "");
Expect(0, 917999, '\P{Age=	V4_0}', "");
Expect(1, 917999, '\P{^Age=	V4_0}', "");
Expect(0, 918000, '\p{Age=	V4_0}', "");
Expect(1, 918000, '\p{^Age=	V4_0}', "");
Expect(1, 918000, '\P{Age=	V4_0}', "");
Expect(0, 918000, '\P{^Age=	V4_0}', "");
Error('\p{Is_Age=-/a/000004.0}');
Error('\P{Is_Age=-/a/000004.0}');
Expect(1, 917999, '\p{Is_Age: 000000_4.0}', "");
Expect(0, 917999, '\p{^Is_Age: 000000_4.0}', "");
Expect(0, 917999, '\P{Is_Age: 000000_4.0}', "");
Expect(1, 917999, '\P{^Is_Age: 000000_4.0}', "");
Expect(0, 918000, '\p{Is_Age: 000000_4.0}', "");
Expect(1, 918000, '\p{^Is_Age: 000000_4.0}', "");
Expect(1, 918000, '\P{Is_Age: 000000_4.0}', "");
Expect(0, 918000, '\P{^Is_Age: 000000_4.0}', "");
Error('\p{Age=/a/_ V4_1}');
Error('\P{Age=/a/_ V4_1}');
Expect(1, 120485, '\p{Age: v41}', "");
Expect(0, 120485, '\p{^Age: v41}', "");
Expect(0, 120485, '\P{Age: v41}', "");
Expect(1, 120485, '\P{^Age: v41}', "");
Expect(0, 120486, '\p{Age: v41}', "");
Expect(1, 120486, '\p{^Age: v41}', "");
Expect(1, 120486, '\P{Age: v41}', "");
Expect(0, 120486, '\P{^Age: v41}', "");
Expect(1, 120485, '\p{Age:-V4_1}', "");
Expect(0, 120485, '\p{^Age:-V4_1}', "");
Expect(0, 120485, '\P{Age:-V4_1}', "");
Expect(1, 120485, '\P{^Age:-V4_1}', "");
Expect(0, 120486, '\p{Age:-V4_1}', "");
Expect(1, 120486, '\p{^Age:-V4_1}', "");
Expect(1, 120486, '\P{Age:-V4_1}', "");
Expect(0, 120486, '\P{^Age:-V4_1}', "");
Error('\p{Is_Age: /a/ 0004.1}');
Error('\P{Is_Age: /a/ 0004.1}');
Expect(1, 120485, '\p{Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(0, 120485, '\p{^Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(0, 120485, '\P{Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(1, 120485, '\P{^Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(0, 120486, '\p{Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(1, 120486, '\p{^Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(1, 120486, '\P{Is_Age=+0_0_0_0_0_0004.1}', "");
Expect(0, 120486, '\P{^Is_Age=+0_0_0_0_0_0004.1}', "");
Error('\p{Age=/a/ v5_0}');
Error('\P{Age=/a/ v5_0}');
Expect(1, 120779, '\p{Age=v50}', "");
Expect(0, 120779, '\p{^Age=v50}', "");
Expect(0, 120779, '\P{Age=v50}', "");
Expect(1, 120779, '\P{^Age=v50}', "");
Expect(0, 120780, '\p{Age=v50}', "");
Expect(1, 120780, '\p{^Age=v50}', "");
Expect(1, 120780, '\P{Age=v50}', "");
Expect(0, 120780, '\P{^Age=v50}', "");
Expect(1, 120779, '\p{Age= V5_0}', "");
Expect(0, 120779, '\p{^Age= V5_0}', "");
Expect(0, 120779, '\P{Age= V5_0}', "");
Expect(1, 120779, '\P{^Age= V5_0}', "");
Expect(0, 120780, '\p{Age= V5_0}', "");
Expect(1, 120780, '\p{^Age= V5_0}', "");
Expect(1, 120780, '\P{Age= V5_0}', "");
Expect(0, 120780, '\P{^Age= V5_0}', "");
Error('\p{Is_Age=/a/0_0_0_05.0}');
Error('\P{Is_Age=/a/0_0_0_05.0}');
Expect(1, 120779, '\p{Is_Age=00000_5.0}', "");
Expect(0, 120779, '\p{^Is_Age=00000_5.0}', "");
Expect(0, 120779, '\P{Is_Age=00000_5.0}', "");
Expect(1, 120779, '\P{^Is_Age=00000_5.0}', "");
Expect(0, 120780, '\p{Is_Age=00000_5.0}', "");
Expect(1, 120780, '\p{^Is_Age=00000_5.0}', "");
Expect(1, 120780, '\P{Is_Age=00000_5.0}', "");
Expect(0, 120780, '\P{^Is_Age=00000_5.0}', "");
Error('\p{Age=_	v5_1/a/}');
Error('\P{Age=_	v5_1/a/}');
Expect(1, 127123, '\p{Age=v51}', "");
Expect(0, 127123, '\p{^Age=v51}', "");
Expect(0, 127123, '\P{Age=v51}', "");
Expect(1, 127123, '\P{^Age=v51}', "");
Expect(0, 127124, '\p{Age=v51}', "");
Expect(1, 127124, '\p{^Age=v51}', "");
Expect(1, 127124, '\P{Age=v51}', "");
Expect(0, 127124, '\P{^Age=v51}', "");
Expect(1, 127123, '\p{Age=	-V5_1}', "");
Expect(0, 127123, '\p{^Age=	-V5_1}', "");
Expect(0, 127123, '\P{Age=	-V5_1}', "");
Expect(1, 127123, '\P{^Age=	-V5_1}', "");
Expect(0, 127124, '\p{Age=	-V5_1}', "");
Expect(1, 127124, '\p{^Age=	-V5_1}', "");
Expect(1, 127124, '\P{Age=	-V5_1}', "");
Expect(0, 127124, '\P{^Age=	-V5_1}', "");
Error('\p{Is_Age=_:=005.1}');
Error('\P{Is_Age=_:=005.1}');
Expect(1, 127123, '\p{Is_Age=00_00_00_05.1}', "");
Expect(0, 127123, '\p{^Is_Age=00_00_00_05.1}', "");
Expect(0, 127123, '\P{Is_Age=00_00_00_05.1}', "");
Expect(1, 127123, '\P{^Is_Age=00_00_00_05.1}', "");
Expect(0, 127124, '\p{Is_Age=00_00_00_05.1}', "");
Expect(1, 127124, '\p{^Is_Age=00_00_00_05.1}', "");
Expect(1, 127124, '\P{Is_Age=00_00_00_05.1}', "");
Expect(0, 127124, '\P{^Is_Age=00_00_00_05.1}', "");
Error('\p{Age=-v5_2:=}');
Error('\P{Age=-v5_2:=}');
Expect(1, 177972, '\p{Age=v52}', "");
Expect(0, 177972, '\p{^Age=v52}', "");
Expect(0, 177972, '\P{Age=v52}', "");
Expect(1, 177972, '\P{^Age=v52}', "");
Expect(0, 177973, '\p{Age=v52}', "");
Expect(1, 177973, '\p{^Age=v52}', "");
Expect(1, 177973, '\P{Age=v52}', "");
Expect(0, 177973, '\P{^Age=v52}', "");
Expect(1, 177972, '\p{Age=	_V5_2}', "");
Expect(0, 177972, '\p{^Age=	_V5_2}', "");
Expect(0, 177972, '\P{Age=	_V5_2}', "");
Expect(1, 177972, '\P{^Age=	_V5_2}', "");
Expect(0, 177973, '\p{Age=	_V5_2}', "");
Expect(1, 177973, '\p{^Age=	_V5_2}', "");
Expect(1, 177973, '\P{Age=	_V5_2}', "");
Expect(0, 177973, '\P{^Age=	_V5_2}', "");
Error('\p{Is_Age=	0000000_5.2/a/}');
Error('\P{Is_Age=	0000000_5.2/a/}');
Expect(1, 177972, '\p{Is_Age=+00_00_00_00_05.2}', "");
Expect(0, 177972, '\p{^Is_Age=+00_00_00_00_05.2}', "");
Expect(0, 177972, '\P{Is_Age=+00_00_00_00_05.2}', "");
Expect(1, 177972, '\P{^Is_Age=+00_00_00_00_05.2}', "");
Expect(0, 177973, '\p{Is_Age=+00_00_00_00_05.2}', "");
Expect(1, 177973, '\p{^Is_Age=+00_00_00_00_05.2}', "");
Expect(1, 177973, '\P{Is_Age=+00_00_00_00_05.2}', "");
Expect(0, 177973, '\P{^Is_Age=+00_00_00_00_05.2}', "");
Error('\p{Age= V6_0:=}');
Error('\P{Age= V6_0:=}');
Expect(1, 178205, '\p{Age=v60}', "");
Expect(0, 178205, '\p{^Age=v60}', "");
Expect(0, 178205, '\P{Age=v60}', "");
Expect(1, 178205, '\P{^Age=v60}', "");
Expect(0, 178206, '\p{Age=v60}', "");
Expect(1, 178206, '\p{^Age=v60}', "");
Expect(1, 178206, '\P{Age=v60}', "");
Expect(0, 178206, '\P{^Age=v60}', "");
Expect(1, 178205, '\p{Age=_V6_0}', "");
Expect(0, 178205, '\p{^Age=_V6_0}', "");
Expect(0, 178205, '\P{Age=_V6_0}', "");
Expect(1, 178205, '\P{^Age=_V6_0}', "");
Expect(0, 178206, '\p{Age=_V6_0}', "");
Expect(1, 178206, '\p{^Age=_V6_0}', "");
Expect(1, 178206, '\P{Age=_V6_0}', "");
Expect(0, 178206, '\P{^Age=_V6_0}', "");
Error('\p{Is_Age:_:=0_0_0_0_0_006.0}');
Error('\P{Is_Age:_:=0_0_0_0_0_006.0}');
Expect(1, 178205, '\p{Is_Age=+0000006.0}', "");
Expect(0, 178205, '\p{^Is_Age=+0000006.0}', "");
Expect(0, 178205, '\P{Is_Age=+0000006.0}', "");
Expect(1, 178205, '\P{^Is_Age=+0000006.0}', "");
Expect(0, 178206, '\p{Is_Age=+0000006.0}', "");
Expect(1, 178206, '\p{^Is_Age=+0000006.0}', "");
Expect(1, 178206, '\P{Is_Age=+0000006.0}', "");
Expect(0, 178206, '\P{^Is_Age=+0000006.0}', "");
Error('\p{Age=-:=V6_1}');
Error('\P{Age=-:=V6_1}');
Expect(1, 128564, '\p{Age=v61}', "");
Expect(0, 128564, '\p{^Age=v61}', "");
Expect(0, 128564, '\P{Age=v61}', "");
Expect(1, 128564, '\P{^Age=v61}', "");
Expect(0, 128565, '\p{Age=v61}', "");
Expect(1, 128565, '\p{^Age=v61}', "");
Expect(1, 128565, '\P{Age=v61}', "");
Expect(0, 128565, '\P{^Age=v61}', "");
Expect(1, 128564, '\p{Age=		V6_1}', "");
Expect(0, 128564, '\p{^Age=		V6_1}', "");
Expect(0, 128564, '\P{Age=		V6_1}', "");
Expect(1, 128564, '\P{^Age=		V6_1}', "");
Expect(0, 128565, '\p{Age=		V6_1}', "");
Expect(1, 128565, '\p{^Age=		V6_1}', "");
Expect(1, 128565, '\P{Age=		V6_1}', "");
Expect(0, 128565, '\P{^Age=		V6_1}', "");
Error('\p{Is_Age=/a/		000000006.1}');
Error('\P{Is_Age=/a/		000000006.1}');
Expect(1, 128564, '\p{Is_Age=+00_00_00_6.1}', "");
Expect(0, 128564, '\p{^Is_Age=+00_00_00_6.1}', "");
Expect(0, 128564, '\P{Is_Age=+00_00_00_6.1}', "");
Expect(1, 128564, '\P{^Is_Age=+00_00_00_6.1}', "");
Expect(0, 128565, '\p{Is_Age=+00_00_00_6.1}', "");
Expect(1, 128565, '\p{^Is_Age=+00_00_00_6.1}', "");
Expect(1, 128565, '\P{Is_Age=+00_00_00_6.1}', "");
Expect(0, 128565, '\P{^Is_Age=+00_00_00_6.1}', "");
Error('\p{Age= 	V6_2/a/}');
Error('\P{Age= 	V6_2/a/}');
Expect(1, 8378, '\p{Age=v62}', "");
Expect(0, 8378, '\p{^Age=v62}', "");
Expect(0, 8378, '\P{Age=v62}', "");
Expect(1, 8378, '\P{^Age=v62}', "");
Expect(0, 8379, '\p{Age=v62}', "");
Expect(1, 8379, '\p{^Age=v62}', "");
Expect(1, 8379, '\P{Age=v62}', "");
Expect(0, 8379, '\P{^Age=v62}', "");
Expect(1, 8378, '\p{Age:   -v6_2}', "");
Expect(0, 8378, '\p{^Age:   -v6_2}', "");
Expect(0, 8378, '\P{Age:   -v6_2}', "");
Expect(1, 8378, '\P{^Age:   -v6_2}', "");
Expect(0, 8379, '\p{Age:   -v6_2}', "");
Expect(1, 8379, '\p{^Age:   -v6_2}', "");
Expect(1, 8379, '\P{Age:   -v6_2}', "");
Expect(0, 8379, '\P{^Age:   -v6_2}', "");
Error('\p{Is_Age=	:=0000000006.2}');
Error('\P{Is_Age=	:=0000000006.2}');
Expect(1, 8378, '\p{Is_Age=00_00_6.2}', "");
Expect(0, 8378, '\p{^Is_Age=00_00_6.2}', "");
Expect(0, 8378, '\P{Is_Age=00_00_6.2}', "");
Expect(1, 8378, '\P{^Is_Age=00_00_6.2}', "");
Expect(0, 8379, '\p{Is_Age=00_00_6.2}', "");
Expect(1, 8379, '\p{^Is_Age=00_00_6.2}', "");
Expect(1, 8379, '\P{Is_Age=00_00_6.2}', "");
Expect(0, 8379, '\P{^Is_Age=00_00_6.2}', "");
Error('\p{Age=	unassigned/a/}');
Error('\P{Age=	unassigned/a/}');
Expect(1, 983037, '\p{Age=unassigned}', "");
Expect(0, 983037, '\p{^Age=unassigned}', "");
Expect(0, 983037, '\P{Age=unassigned}', "");
Expect(1, 983037, '\P{^Age=unassigned}', "");
Expect(0, 983040, '\p{Age=unassigned}', "");
Expect(1, 983040, '\p{^Age=unassigned}', "");
Expect(1, 983040, '\P{Age=unassigned}', "");
Expect(0, 983040, '\P{^Age=unassigned}', "");
Expect(1, 983037, '\p{Age=_Unassigned}', "");
Expect(0, 983037, '\p{^Age=_Unassigned}', "");
Expect(0, 983037, '\P{Age=_Unassigned}', "");
Expect(1, 983037, '\P{^Age=_Unassigned}', "");
Expect(0, 983040, '\p{Age=_Unassigned}', "");
Expect(1, 983040, '\p{^Age=_Unassigned}', "");
Expect(1, 983040, '\P{Age=_Unassigned}', "");
Expect(0, 983040, '\P{^Age=_Unassigned}', "");
Error('\p{Is_Age=/a/	 na}');
Error('\P{Is_Age=/a/	 na}');
Expect(1, 983037, '\p{Is_Age=na}', "");
Expect(0, 983037, '\p{^Is_Age=na}', "");
Expect(0, 983037, '\P{Is_Age=na}', "");
Expect(1, 983037, '\P{^Is_Age=na}', "");
Expect(0, 983040, '\p{Is_Age=na}', "");
Expect(1, 983040, '\p{^Is_Age=na}', "");
Expect(1, 983040, '\P{Is_Age=na}', "");
Expect(0, 983040, '\P{^Is_Age=na}', "");
Expect(1, 983037, '\p{Is_Age=_	NA}', "");
Expect(0, 983037, '\p{^Is_Age=_	NA}', "");
Expect(0, 983037, '\P{Is_Age=_	NA}', "");
Expect(1, 983037, '\P{^Is_Age=_	NA}', "");
Expect(0, 983040, '\p{Is_Age=_	NA}', "");
Expect(1, 983040, '\p{^Is_Age=_	NA}', "");
Expect(1, 983040, '\P{Is_Age=_	NA}', "");
Expect(0, 983040, '\P{^Is_Age=_	NA}', "");
Error('\p{Bidi_Class=	:=Arabic_LETTER}');
Error('\P{Bidi_Class=	:=Arabic_LETTER}');
Expect(1, 126719, '\p{Bidi_Class:arabicletter}', "");
Expect(0, 126719, '\p{^Bidi_Class:arabicletter}', "");
Expect(0, 126719, '\P{Bidi_Class:arabicletter}', "");
Expect(1, 126719, '\P{^Bidi_Class:arabicletter}', "");
Expect(0, 126720, '\p{Bidi_Class:arabicletter}', "");
Expect(1, 126720, '\p{^Bidi_Class:arabicletter}', "");
Expect(1, 126720, '\P{Bidi_Class:arabicletter}', "");
Expect(0, 126720, '\P{^Bidi_Class:arabicletter}', "");
Expect(1, 126719, '\p{Bidi_Class=ARABIC_Letter}', "");
Expect(0, 126719, '\p{^Bidi_Class=ARABIC_Letter}', "");
Expect(0, 126719, '\P{Bidi_Class=ARABIC_Letter}', "");
Expect(1, 126719, '\P{^Bidi_Class=ARABIC_Letter}', "");
Expect(0, 126720, '\p{Bidi_Class=ARABIC_Letter}', "");
Expect(1, 126720, '\p{^Bidi_Class=ARABIC_Letter}', "");
Expect(1, 126720, '\P{Bidi_Class=ARABIC_Letter}', "");
Expect(0, 126720, '\P{^Bidi_Class=ARABIC_Letter}', "");
Error('\p{Bc=/a/-AL}');
Error('\P{Bc=/a/-AL}');
Expect(1, 126719, '\p{Bc=al}', "");
Expect(0, 126719, '\p{^Bc=al}', "");
Expect(0, 126719, '\P{Bc=al}', "");
Expect(1, 126719, '\P{^Bc=al}', "");
Expect(0, 126720, '\p{Bc=al}', "");
Expect(1, 126720, '\p{^Bc=al}', "");
Expect(1, 126720, '\P{Bc=al}', "");
Expect(0, 126720, '\P{^Bc=al}', "");
Expect(1, 126719, '\p{Bc: 	_al}', "");
Expect(0, 126719, '\p{^Bc: 	_al}', "");
Expect(0, 126719, '\P{Bc: 	_al}', "");
Expect(1, 126719, '\P{^Bc: 	_al}', "");
Expect(0, 126720, '\p{Bc: 	_al}', "");
Expect(1, 126720, '\p{^Bc: 	_al}', "");
Expect(1, 126720, '\P{Bc: 	_al}', "");
Expect(0, 126720, '\P{^Bc: 	_al}', "");
Error('\p{Is_Bidi_Class=	/a/Arabic_Letter}');
Error('\P{Is_Bidi_Class=	/a/Arabic_Letter}');
Expect(1, 126719, '\p{Is_Bidi_Class=arabicletter}', "");
Expect(0, 126719, '\p{^Is_Bidi_Class=arabicletter}', "");
Expect(0, 126719, '\P{Is_Bidi_Class=arabicletter}', "");
Expect(1, 126719, '\P{^Is_Bidi_Class=arabicletter}', "");
Expect(0, 126720, '\p{Is_Bidi_Class=arabicletter}', "");
Expect(1, 126720, '\p{^Is_Bidi_Class=arabicletter}', "");
Expect(1, 126720, '\P{Is_Bidi_Class=arabicletter}', "");
Expect(0, 126720, '\P{^Is_Bidi_Class=arabicletter}', "");
Expect(1, 126719, '\p{Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(0, 126719, '\p{^Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(0, 126719, '\P{Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(1, 126719, '\P{^Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(0, 126720, '\p{Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(1, 126720, '\p{^Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(1, 126720, '\P{Is_Bidi_Class= 	Arabic_Letter}', "");
Expect(0, 126720, '\P{^Is_Bidi_Class= 	Arabic_Letter}', "");
Error('\p{Is_Bc=:=AL}');
Error('\P{Is_Bc=:=AL}');
Expect(1, 126719, '\p{Is_Bc:	al}', "");
Expect(0, 126719, '\p{^Is_Bc:	al}', "");
Expect(0, 126719, '\P{Is_Bc:	al}', "");
Expect(1, 126719, '\P{^Is_Bc:	al}', "");
Expect(0, 126720, '\p{Is_Bc:	al}', "");
Expect(1, 126720, '\p{^Is_Bc:	al}', "");
Expect(1, 126720, '\P{Is_Bc:	al}', "");
Expect(0, 126720, '\P{^Is_Bc:	al}', "");
Expect(1, 126719, '\p{Is_Bc=		AL}', "");
Expect(0, 126719, '\p{^Is_Bc=		AL}', "");
Expect(0, 126719, '\P{Is_Bc=		AL}', "");
Expect(1, 126719, '\P{^Is_Bc=		AL}', "");
Expect(0, 126720, '\p{Is_Bc=		AL}', "");
Expect(1, 126720, '\p{^Is_Bc=		AL}', "");
Expect(1, 126720, '\P{Is_Bc=		AL}', "");
Expect(0, 126720, '\P{^Is_Bc=		AL}', "");
Error('\p{Bidi_Class=/a/_ arabic_NUMBER}');
Error('\P{Bidi_Class=/a/_ arabic_NUMBER}');
Expect(1, 69246, '\p{Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\p{^Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\P{Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\P{^Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\p{Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\p{^Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\P{Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\P{^Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\p{Bidi_Class=	Arabic_NUMBER}', "");
Expect(0, 69246, '\p{^Bidi_Class=	Arabic_NUMBER}', "");
Expect(0, 69246, '\P{Bidi_Class=	Arabic_NUMBER}', "");
Expect(1, 69246, '\P{^Bidi_Class=	Arabic_NUMBER}', "");
Expect(0, 69247, '\p{Bidi_Class=	Arabic_NUMBER}', "");
Expect(1, 69247, '\p{^Bidi_Class=	Arabic_NUMBER}', "");
Expect(1, 69247, '\P{Bidi_Class=	Arabic_NUMBER}', "");
Expect(0, 69247, '\P{^Bidi_Class=	Arabic_NUMBER}', "");
Error('\p{Bc=	 an:=}');
Error('\P{Bc=	 an:=}');
Expect(1, 69246, '\p{Bc=an}', "");
Expect(0, 69246, '\p{^Bc=an}', "");
Expect(0, 69246, '\P{Bc=an}', "");
Expect(1, 69246, '\P{^Bc=an}', "");
Expect(0, 69247, '\p{Bc=an}', "");
Expect(1, 69247, '\p{^Bc=an}', "");
Expect(1, 69247, '\P{Bc=an}', "");
Expect(0, 69247, '\P{^Bc=an}', "");
Expect(1, 69246, '\p{Bc:	 _AN}', "");
Expect(0, 69246, '\p{^Bc:	 _AN}', "");
Expect(0, 69246, '\P{Bc:	 _AN}', "");
Expect(1, 69246, '\P{^Bc:	 _AN}', "");
Expect(0, 69247, '\p{Bc:	 _AN}', "");
Expect(1, 69247, '\p{^Bc:	 _AN}', "");
Expect(1, 69247, '\P{Bc:	 _AN}', "");
Expect(0, 69247, '\P{^Bc:	 _AN}', "");
Error('\p{Is_Bidi_Class=/a/-_arabic_NUMBER}');
Error('\P{Is_Bidi_Class=/a/-_arabic_NUMBER}');
Expect(1, 69246, '\p{Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\p{^Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69246, '\P{Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\P{^Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\p{Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\p{^Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69247, '\P{Is_Bidi_Class=arabicnumber}', "");
Expect(0, 69247, '\P{^Is_Bidi_Class=arabicnumber}', "");
Expect(1, 69246, '\p{Is_Bidi_Class=- Arabic_number}', "");
Expect(0, 69246, '\p{^Is_Bidi_Class=- Arabic_number}', "");
Expect(0, 69246, '\P{Is_Bidi_Class=- Arabic_number}', "");
Expect(1, 69246, '\P{^Is_Bidi_Class=- Arabic_number}', "");
Expect(0, 69247, '\p{Is_Bidi_Class=- Arabic_number}', "");
Expect(1, 69247, '\p{^Is_Bidi_Class=- Arabic_number}', "");
Expect(1, 69247, '\P{Is_Bidi_Class=- Arabic_number}', "");
Expect(0, 69247, '\P{^Is_Bidi_Class=- Arabic_number}', "");
Error('\p{Is_Bc=- AN/a/}');
Error('\P{Is_Bc=- AN/a/}');
Expect(1, 69246, '\p{Is_Bc=an}', "");
Expect(0, 69246, '\p{^Is_Bc=an}', "");
Expect(0, 69246, '\P{Is_Bc=an}', "");
Expect(1, 69246, '\P{^Is_Bc=an}', "");
Expect(0, 69247, '\p{Is_Bc=an}', "");
Expect(1, 69247, '\p{^Is_Bc=an}', "");
Expect(1, 69247, '\P{Is_Bc=an}', "");
Expect(0, 69247, '\P{^Is_Bc=an}', "");
Expect(1, 69246, '\p{Is_Bc=	AN}', "");
Expect(0, 69246, '\p{^Is_Bc=	AN}', "");
Expect(0, 69246, '\P{Is_Bc=	AN}', "");
Expect(1, 69246, '\P{^Is_Bc=	AN}', "");
Expect(0, 69247, '\p{Is_Bc=	AN}', "");
Expect(1, 69247, '\p{^Is_Bc=	AN}', "");
Expect(1, 69247, '\P{Is_Bc=	AN}', "");
Expect(0, 69247, '\P{^Is_Bc=	AN}', "");
Error('\p{Bidi_Class= _PARAGRAPH_SEPARATOR/a/}');
Error('\P{Bidi_Class= _PARAGRAPH_SEPARATOR/a/}');
Expect(1, 8233, '\p{Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\p{^Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\P{Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\P{^Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\p{Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\p{^Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\P{Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\P{^Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\p{Bidi_Class=-Paragraph_Separator}', "");
Expect(0, 8233, '\p{^Bidi_Class=-Paragraph_Separator}', "");
Expect(0, 8233, '\P{Bidi_Class=-Paragraph_Separator}', "");
Expect(1, 8233, '\P{^Bidi_Class=-Paragraph_Separator}', "");
Expect(0, 8234, '\p{Bidi_Class=-Paragraph_Separator}', "");
Expect(1, 8234, '\p{^Bidi_Class=-Paragraph_Separator}', "");
Expect(1, 8234, '\P{Bidi_Class=-Paragraph_Separator}', "");
Expect(0, 8234, '\P{^Bidi_Class=-Paragraph_Separator}', "");
Error('\p{Bc= /a/B}');
Error('\P{Bc= /a/B}');
Expect(1, 8233, '\p{Bc:	b}', "");
Expect(0, 8233, '\p{^Bc:	b}', "");
Expect(0, 8233, '\P{Bc:	b}', "");
Expect(1, 8233, '\P{^Bc:	b}', "");
Expect(0, 8234, '\p{Bc:	b}', "");
Expect(1, 8234, '\p{^Bc:	b}', "");
Expect(1, 8234, '\P{Bc:	b}', "");
Expect(0, 8234, '\P{^Bc:	b}', "");
Expect(1, 8233, '\p{Bc=B}', "");
Expect(0, 8233, '\p{^Bc=B}', "");
Expect(0, 8233, '\P{Bc=B}', "");
Expect(1, 8233, '\P{^Bc=B}', "");
Expect(0, 8234, '\p{Bc=B}', "");
Expect(1, 8234, '\p{^Bc=B}', "");
Expect(1, 8234, '\P{Bc=B}', "");
Expect(0, 8234, '\P{^Bc=B}', "");
Error('\p{Is_Bidi_Class:-paragraph_SEPARATOR/a/}');
Error('\P{Is_Bidi_Class:-paragraph_SEPARATOR/a/}');
Expect(1, 8233, '\p{Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\p{^Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8233, '\P{Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\P{^Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\p{Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\p{^Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8234, '\P{Is_Bidi_Class=paragraphseparator}', "");
Expect(0, 8234, '\P{^Is_Bidi_Class=paragraphseparator}', "");
Expect(1, 8233, '\p{Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(0, 8233, '\p{^Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(0, 8233, '\P{Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(1, 8233, '\P{^Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(0, 8234, '\p{Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(1, 8234, '\p{^Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(1, 8234, '\P{Is_Bidi_Class=	-paragraph_Separator}', "");
Expect(0, 8234, '\P{^Is_Bidi_Class=	-paragraph_Separator}', "");
Error('\p{Is_Bc:	_-B/a/}');
Error('\P{Is_Bc:	_-B/a/}');
Expect(1, 8233, '\p{Is_Bc:   b}', "");
Expect(0, 8233, '\p{^Is_Bc:   b}', "");
Expect(0, 8233, '\P{Is_Bc:   b}', "");
Expect(1, 8233, '\P{^Is_Bc:   b}', "");
Expect(0, 8234, '\p{Is_Bc:   b}', "");
Expect(1, 8234, '\p{^Is_Bc:   b}', "");
Expect(1, 8234, '\P{Is_Bc:   b}', "");
Expect(0, 8234, '\P{^Is_Bc:   b}', "");
Expect(1, 8233, '\p{Is_Bc:    	B}', "");
Expect(0, 8233, '\p{^Is_Bc:    	B}', "");
Expect(0, 8233, '\P{Is_Bc:    	B}', "");
Expect(1, 8233, '\P{^Is_Bc:    	B}', "");
Expect(0, 8234, '\p{Is_Bc:    	B}', "");
Expect(1, 8234, '\p{^Is_Bc:    	B}', "");
Expect(1, 8234, '\P{Is_Bc:    	B}', "");
Expect(0, 8234, '\P{^Is_Bc:    	B}', "");
Error('\p{Bidi_Class=	_Boundary_Neutral/a/}');
Error('\P{Bidi_Class=	_Boundary_Neutral/a/}');
Expect(1, 921599, '\p{Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\p{^Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\P{Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\P{^Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\p{Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\p{^Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\P{Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\P{^Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\p{Bidi_Class=-boundary_neutral}', "");
Expect(0, 921599, '\p{^Bidi_Class=-boundary_neutral}', "");
Expect(0, 921599, '\P{Bidi_Class=-boundary_neutral}', "");
Expect(1, 921599, '\P{^Bidi_Class=-boundary_neutral}', "");
Expect(0, 1114109, '\p{Bidi_Class=-boundary_neutral}', "");
Expect(1, 1114109, '\p{^Bidi_Class=-boundary_neutral}', "");
Expect(1, 1114109, '\P{Bidi_Class=-boundary_neutral}', "");
Expect(0, 1114109, '\P{^Bidi_Class=-boundary_neutral}', "");
Error('\p{Bc=/a/_ BN}');
Error('\P{Bc=/a/_ BN}');
Expect(1, 921599, '\p{Bc=bn}', "");
Expect(0, 921599, '\p{^Bc=bn}', "");
Expect(0, 921599, '\P{Bc=bn}', "");
Expect(1, 921599, '\P{^Bc=bn}', "");
Expect(0, 1114109, '\p{Bc=bn}', "");
Expect(1, 1114109, '\p{^Bc=bn}', "");
Expect(1, 1114109, '\P{Bc=bn}', "");
Expect(0, 1114109, '\P{^Bc=bn}', "");
Expect(1, 921599, '\p{Bc=_	BN}', "");
Expect(0, 921599, '\p{^Bc=_	BN}', "");
Expect(0, 921599, '\P{Bc=_	BN}', "");
Expect(1, 921599, '\P{^Bc=_	BN}', "");
Expect(0, 1114109, '\p{Bc=_	BN}', "");
Expect(1, 1114109, '\p{^Bc=_	BN}', "");
Expect(1, 1114109, '\P{Bc=_	BN}', "");
Expect(0, 1114109, '\P{^Bc=_	BN}', "");
Error('\p{Is_Bidi_Class=:=Boundary_Neutral}');
Error('\P{Is_Bidi_Class=:=Boundary_Neutral}');
Expect(1, 921599, '\p{Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\p{^Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 921599, '\P{Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\P{^Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\p{Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\p{^Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 1114109, '\P{Is_Bidi_Class=boundaryneutral}', "");
Expect(0, 1114109, '\P{^Is_Bidi_Class=boundaryneutral}', "");
Expect(1, 921599, '\p{Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(0, 921599, '\p{^Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(0, 921599, '\P{Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(1, 921599, '\P{^Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(0, 1114109, '\p{Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(1, 1114109, '\p{^Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(1, 1114109, '\P{Is_Bidi_Class:   -Boundary_Neutral}', "");
Expect(0, 1114109, '\P{^Is_Bidi_Class:   -Boundary_Neutral}', "");
Error('\p{Is_Bc=	BN/a/}');
Error('\P{Is_Bc=	BN/a/}');
Expect(1, 921599, '\p{Is_Bc:bn}', "");
Expect(0, 921599, '\p{^Is_Bc:bn}', "");
Expect(0, 921599, '\P{Is_Bc:bn}', "");
Expect(1, 921599, '\P{^Is_Bc:bn}', "");
Expect(0, 1114109, '\p{Is_Bc:bn}', "");
Expect(1, 1114109, '\p{^Is_Bc:bn}', "");
Expect(1, 1114109, '\P{Is_Bc:bn}', "");
Expect(0, 1114109, '\P{^Is_Bc:bn}', "");
Expect(1, 921599, '\p{Is_Bc=-BN}', "");
Expect(0, 921599, '\p{^Is_Bc=-BN}', "");
Expect(0, 921599, '\P{Is_Bc=-BN}', "");
Expect(1, 921599, '\P{^Is_Bc=-BN}', "");
Expect(0, 1114109, '\p{Is_Bc=-BN}', "");
Expect(1, 1114109, '\p{^Is_Bc=-BN}', "");
Expect(1, 1114109, '\P{Is_Bc=-BN}', "");
Expect(0, 1114109, '\P{^Is_Bc=-BN}', "");
Error('\p{Bidi_Class= :=Common_Separator}');
Error('\P{Bidi_Class= :=Common_Separator}');
Expect(1, 65306, '\p{Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\p{^Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\P{Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\P{^Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\p{Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\p{^Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\P{Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\P{^Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\p{Bidi_Class= _Common_Separator}', "");
Expect(0, 65306, '\p{^Bidi_Class= _Common_Separator}', "");
Expect(0, 65306, '\P{Bidi_Class= _Common_Separator}', "");
Expect(1, 65306, '\P{^Bidi_Class= _Common_Separator}', "");
Expect(0, 65307, '\p{Bidi_Class= _Common_Separator}', "");
Expect(1, 65307, '\p{^Bidi_Class= _Common_Separator}', "");
Expect(1, 65307, '\P{Bidi_Class= _Common_Separator}', "");
Expect(0, 65307, '\P{^Bidi_Class= _Common_Separator}', "");
Error('\p{Bc:	_/a/CS}');
Error('\P{Bc:	_/a/CS}');
Expect(1, 65306, '\p{Bc:cs}', "");
Expect(0, 65306, '\p{^Bc:cs}', "");
Expect(0, 65306, '\P{Bc:cs}', "");
Expect(1, 65306, '\P{^Bc:cs}', "");
Expect(0, 65307, '\p{Bc:cs}', "");
Expect(1, 65307, '\p{^Bc:cs}', "");
Expect(1, 65307, '\P{Bc:cs}', "");
Expect(0, 65307, '\P{^Bc:cs}', "");
Expect(1, 65306, '\p{Bc=_CS}', "");
Expect(0, 65306, '\p{^Bc=_CS}', "");
Expect(0, 65306, '\P{Bc=_CS}', "");
Expect(1, 65306, '\P{^Bc=_CS}', "");
Expect(0, 65307, '\p{Bc=_CS}', "");
Expect(1, 65307, '\p{^Bc=_CS}', "");
Expect(1, 65307, '\P{Bc=_CS}', "");
Expect(0, 65307, '\P{^Bc=_CS}', "");
Error('\p{Is_Bidi_Class=	/a/Common_Separator}');
Error('\P{Is_Bidi_Class=	/a/Common_Separator}');
Expect(1, 65306, '\p{Is_Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\p{^Is_Bidi_Class=commonseparator}', "");
Expect(0, 65306, '\P{Is_Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\P{^Is_Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\p{Is_Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\p{^Is_Bidi_Class=commonseparator}', "");
Expect(1, 65307, '\P{Is_Bidi_Class=commonseparator}', "");
Expect(0, 65307, '\P{^Is_Bidi_Class=commonseparator}', "");
Expect(1, 65306, '\p{Is_Bidi_Class=-common_Separator}', "");
Expect(0, 65306, '\p{^Is_Bidi_Class=-common_Separator}', "");
Expect(0, 65306, '\P{Is_Bidi_Class=-common_Separator}', "");
Expect(1, 65306, '\P{^Is_Bidi_Class=-common_Separator}', "");
Expect(0, 65307, '\p{Is_Bidi_Class=-common_Separator}', "");
Expect(1, 65307, '\p{^Is_Bidi_Class=-common_Separator}', "");
Expect(1, 65307, '\P{Is_Bidi_Class=-common_Separator}', "");
Expect(0, 65307, '\P{^Is_Bidi_Class=-common_Separator}', "");
Error('\p{Is_Bc=-:=CS}');
Error('\P{Is_Bc=-:=CS}');
Expect(1, 65306, '\p{Is_Bc=cs}', "");
Expect(0, 65306, '\p{^Is_Bc=cs}', "");
Expect(0, 65306, '\P{Is_Bc=cs}', "");
Expect(1, 65306, '\P{^Is_Bc=cs}', "");
Expect(0, 65307, '\p{Is_Bc=cs}', "");
Expect(1, 65307, '\p{^Is_Bc=cs}', "");
Expect(1, 65307, '\P{Is_Bc=cs}', "");
Expect(0, 65307, '\P{^Is_Bc=cs}', "");
Expect(1, 65306, '\p{Is_Bc=  cs}', "");
Expect(0, 65306, '\p{^Is_Bc=  cs}', "");
Expect(0, 65306, '\P{Is_Bc=  cs}', "");
Expect(1, 65306, '\P{^Is_Bc=  cs}', "");
Expect(0, 65307, '\p{Is_Bc=  cs}', "");
Expect(1, 65307, '\p{^Is_Bc=  cs}', "");
Expect(1, 65307, '\P{Is_Bc=  cs}', "");
Expect(0, 65307, '\P{^Is_Bc=  cs}', "");
Error('\p{Bidi_Class= :=EUROPEAN_NUMBER}');
Error('\P{Bidi_Class= :=EUROPEAN_NUMBER}');
Expect(1, 127242, '\p{Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\p{^Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\P{Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\P{^Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\p{Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\p{^Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\P{Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\P{^Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\p{Bidi_Class= 	european_Number}', "");
Expect(0, 127242, '\p{^Bidi_Class= 	european_Number}', "");
Expect(0, 127242, '\P{Bidi_Class= 	european_Number}', "");
Expect(1, 127242, '\P{^Bidi_Class= 	european_Number}', "");
Expect(0, 127243, '\p{Bidi_Class= 	european_Number}', "");
Expect(1, 127243, '\p{^Bidi_Class= 	european_Number}', "");
Expect(1, 127243, '\P{Bidi_Class= 	european_Number}', "");
Expect(0, 127243, '\P{^Bidi_Class= 	european_Number}', "");
Error('\p{Bc=/a/--en}');
Error('\P{Bc=/a/--en}');
Expect(1, 127242, '\p{Bc=en}', "");
Expect(0, 127242, '\p{^Bc=en}', "");
Expect(0, 127242, '\P{Bc=en}', "");
Expect(1, 127242, '\P{^Bc=en}', "");
Expect(0, 127243, '\p{Bc=en}', "");
Expect(1, 127243, '\p{^Bc=en}', "");
Expect(1, 127243, '\P{Bc=en}', "");
Expect(0, 127243, '\P{^Bc=en}', "");
Expect(1, 127242, '\p{Bc=_ EN}', "");
Expect(0, 127242, '\p{^Bc=_ EN}', "");
Expect(0, 127242, '\P{Bc=_ EN}', "");
Expect(1, 127242, '\P{^Bc=_ EN}', "");
Expect(0, 127243, '\p{Bc=_ EN}', "");
Expect(1, 127243, '\p{^Bc=_ EN}', "");
Expect(1, 127243, '\P{Bc=_ EN}', "");
Expect(0, 127243, '\P{^Bc=_ EN}', "");
Error('\p{Is_Bidi_Class=-_European_Number/a/}');
Error('\P{Is_Bidi_Class=-_European_Number/a/}');
Expect(1, 127242, '\p{Is_Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\p{^Is_Bidi_Class=europeannumber}', "");
Expect(0, 127242, '\P{Is_Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\P{^Is_Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\p{Is_Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\p{^Is_Bidi_Class=europeannumber}', "");
Expect(1, 127243, '\P{Is_Bidi_Class=europeannumber}', "");
Expect(0, 127243, '\P{^Is_Bidi_Class=europeannumber}', "");
Expect(1, 127242, '\p{Is_Bidi_Class=-	European_Number}', "");
Expect(0, 127242, '\p{^Is_Bidi_Class=-	European_Number}', "");
Expect(0, 127242, '\P{Is_Bidi_Class=-	European_Number}', "");
Expect(1, 127242, '\P{^Is_Bidi_Class=-	European_Number}', "");
Expect(0, 127243, '\p{Is_Bidi_Class=-	European_Number}', "");
Expect(1, 127243, '\p{^Is_Bidi_Class=-	European_Number}', "");
Expect(1, 127243, '\P{Is_Bidi_Class=-	European_Number}', "");
Expect(0, 127243, '\P{^Is_Bidi_Class=-	European_Number}', "");
Error('\p{Is_Bc=:=	EN}');
Error('\P{Is_Bc=:=	EN}');
Expect(1, 127242, '\p{Is_Bc=en}', "");
Expect(0, 127242, '\p{^Is_Bc=en}', "");
Expect(0, 127242, '\P{Is_Bc=en}', "");
Expect(1, 127242, '\P{^Is_Bc=en}', "");
Expect(0, 127243, '\p{Is_Bc=en}', "");
Expect(1, 127243, '\p{^Is_Bc=en}', "");
Expect(1, 127243, '\P{Is_Bc=en}', "");
Expect(0, 127243, '\P{^Is_Bc=en}', "");
Expect(1, 127242, '\p{Is_Bc=_	EN}', "");
Expect(0, 127242, '\p{^Is_Bc=_	EN}', "");
Expect(0, 127242, '\P{Is_Bc=_	EN}', "");
Expect(1, 127242, '\P{^Is_Bc=_	EN}', "");
Expect(0, 127243, '\p{Is_Bc=_	EN}', "");
Expect(1, 127243, '\p{^Is_Bc=_	EN}', "");
Expect(1, 127243, '\P{Is_Bc=_	EN}', "");
Expect(0, 127243, '\P{^Is_Bc=_	EN}', "");
Error('\p{Bidi_Class=	European_SEPARATOR:=}');
Error('\P{Bidi_Class=	European_SEPARATOR:=}');
Expect(1, 65293, '\p{Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\p{^Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\P{Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\P{^Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\p{Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\p{^Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\P{Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\P{^Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\p{Bidi_Class: -European_SEPARATOR}', "");
Expect(0, 65293, '\p{^Bidi_Class: -European_SEPARATOR}', "");
Expect(0, 65293, '\P{Bidi_Class: -European_SEPARATOR}', "");
Expect(1, 65293, '\P{^Bidi_Class: -European_SEPARATOR}', "");
Expect(0, 65294, '\p{Bidi_Class: -European_SEPARATOR}', "");
Expect(1, 65294, '\p{^Bidi_Class: -European_SEPARATOR}', "");
Expect(1, 65294, '\P{Bidi_Class: -European_SEPARATOR}', "");
Expect(0, 65294, '\P{^Bidi_Class: -European_SEPARATOR}', "");
Error('\p{Bc=:= ES}');
Error('\P{Bc=:= ES}');
Expect(1, 65293, '\p{Bc=es}', "");
Expect(0, 65293, '\p{^Bc=es}', "");
Expect(0, 65293, '\P{Bc=es}', "");
Expect(1, 65293, '\P{^Bc=es}', "");
Expect(0, 65294, '\p{Bc=es}', "");
Expect(1, 65294, '\p{^Bc=es}', "");
Expect(1, 65294, '\P{Bc=es}', "");
Expect(0, 65294, '\P{^Bc=es}', "");
Expect(1, 65293, '\p{Bc=ES}', "");
Expect(0, 65293, '\p{^Bc=ES}', "");
Expect(0, 65293, '\P{Bc=ES}', "");
Expect(1, 65293, '\P{^Bc=ES}', "");
Expect(0, 65294, '\p{Bc=ES}', "");
Expect(1, 65294, '\p{^Bc=ES}', "");
Expect(1, 65294, '\P{Bc=ES}', "");
Expect(0, 65294, '\P{^Bc=ES}', "");
Error('\p{Is_Bidi_Class:   /a/-European_separator}');
Error('\P{Is_Bidi_Class:   /a/-European_separator}');
Expect(1, 65293, '\p{Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\p{^Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65293, '\P{Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\P{^Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\p{Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\p{^Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65294, '\P{Is_Bidi_Class=europeanseparator}', "");
Expect(0, 65294, '\P{^Is_Bidi_Class=europeanseparator}', "");
Expect(1, 65293, '\p{Is_Bidi_Class=	-european_Separator}', "");
Expect(0, 65293, '\p{^Is_Bidi_Class=	-european_Separator}', "");
Expect(0, 65293, '\P{Is_Bidi_Class=	-european_Separator}', "");
Expect(1, 65293, '\P{^Is_Bidi_Class=	-european_Separator}', "");
Expect(0, 65294, '\p{Is_Bidi_Class=	-european_Separator}', "");
Expect(1, 65294, '\p{^Is_Bidi_Class=	-european_Separator}', "");
Expect(1, 65294, '\P{Is_Bidi_Class=	-european_Separator}', "");
Expect(0, 65294, '\P{^Is_Bidi_Class=	-european_Separator}', "");
Error('\p{Is_Bc: _:=ES}');
Error('\P{Is_Bc: _:=ES}');
Expect(1, 65293, '\p{Is_Bc=es}', "");
Expect(0, 65293, '\p{^Is_Bc=es}', "");
Expect(0, 65293, '\P{Is_Bc=es}', "");
Expect(1, 65293, '\P{^Is_Bc=es}', "");
Expect(0, 65294, '\p{Is_Bc=es}', "");
Expect(1, 65294, '\p{^Is_Bc=es}', "");
Expect(1, 65294, '\P{Is_Bc=es}', "");
Expect(0, 65294, '\P{^Is_Bc=es}', "");
Expect(1, 65293, '\p{Is_Bc= -ES}', "");
Expect(0, 65293, '\p{^Is_Bc= -ES}', "");
Expect(0, 65293, '\P{Is_Bc= -ES}', "");
Expect(1, 65293, '\P{^Is_Bc= -ES}', "");
Expect(0, 65294, '\p{Is_Bc= -ES}', "");
Expect(1, 65294, '\p{^Is_Bc= -ES}', "");
Expect(1, 65294, '\P{Is_Bc= -ES}', "");
Expect(0, 65294, '\P{^Is_Bc= -ES}', "");
Error('\p{Bidi_Class= _EUROPEAN_terminator:=}');
Error('\P{Bidi_Class= _EUROPEAN_terminator:=}');
Expect(1, 65510, '\p{Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\p{^Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\P{Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\P{^Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\p{Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\p{^Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\P{Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\P{^Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\p{Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(0, 65510, '\p{^Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(0, 65510, '\P{Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(1, 65510, '\P{^Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(0, 65511, '\p{Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(1, 65511, '\p{^Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(1, 65511, '\P{Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Expect(0, 65511, '\P{^Bidi_Class= _EUROPEAN_TERMINATOR}', "");
Error('\p{Bc=	:=ET}');
Error('\P{Bc=	:=ET}');
Expect(1, 65510, '\p{Bc=et}', "");
Expect(0, 65510, '\p{^Bc=et}', "");
Expect(0, 65510, '\P{Bc=et}', "");
Expect(1, 65510, '\P{^Bc=et}', "");
Expect(0, 65511, '\p{Bc=et}', "");
Expect(1, 65511, '\p{^Bc=et}', "");
Expect(1, 65511, '\P{Bc=et}', "");
Expect(0, 65511, '\P{^Bc=et}', "");
Expect(1, 65510, '\p{Bc:  ET}', "");
Expect(0, 65510, '\p{^Bc:  ET}', "");
Expect(0, 65510, '\P{Bc:  ET}', "");
Expect(1, 65510, '\P{^Bc:  ET}', "");
Expect(0, 65511, '\p{Bc:  ET}', "");
Expect(1, 65511, '\p{^Bc:  ET}', "");
Expect(1, 65511, '\P{Bc:  ET}', "");
Expect(0, 65511, '\P{^Bc:  ET}', "");
Error('\p{Is_Bidi_Class=	european_terminator:=}');
Error('\P{Is_Bidi_Class=	european_terminator:=}');
Expect(1, 65510, '\p{Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\p{^Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65510, '\P{Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\P{^Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\p{Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\p{^Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65511, '\P{Is_Bidi_Class=europeanterminator}', "");
Expect(0, 65511, '\P{^Is_Bidi_Class=europeanterminator}', "");
Expect(1, 65510, '\p{Is_Bidi_Class:	_european_terminator}', "");
Expect(0, 65510, '\p{^Is_Bidi_Class:	_european_terminator}', "");
Expect(0, 65510, '\P{Is_Bidi_Class:	_european_terminator}', "");
Expect(1, 65510, '\P{^Is_Bidi_Class:	_european_terminator}', "");
Expect(0, 65511, '\p{Is_Bidi_Class:	_european_terminator}', "");
Expect(1, 65511, '\p{^Is_Bidi_Class:	_european_terminator}', "");
Expect(1, 65511, '\P{Is_Bidi_Class:	_european_terminator}', "");
Expect(0, 65511, '\P{^Is_Bidi_Class:	_european_terminator}', "");
Error('\p{Is_Bc=	_ET/a/}');
Error('\P{Is_Bc=	_ET/a/}');
Expect(1, 65510, '\p{Is_Bc=et}', "");
Expect(0, 65510, '\p{^Is_Bc=et}', "");
Expect(0, 65510, '\P{Is_Bc=et}', "");
Expect(1, 65510, '\P{^Is_Bc=et}', "");
Expect(0, 65511, '\p{Is_Bc=et}', "");
Expect(1, 65511, '\p{^Is_Bc=et}', "");
Expect(1, 65511, '\P{Is_Bc=et}', "");
Expect(0, 65511, '\P{^Is_Bc=et}', "");
Expect(1, 65510, '\p{Is_Bc=-ET}', "");
Expect(0, 65510, '\p{^Is_Bc=-ET}', "");
Expect(0, 65510, '\P{Is_Bc=-ET}', "");
Expect(1, 65510, '\P{^Is_Bc=-ET}', "");
Expect(0, 65511, '\p{Is_Bc=-ET}', "");
Expect(1, 65511, '\p{^Is_Bc=-ET}', "");
Expect(1, 65511, '\P{Is_Bc=-ET}', "");
Expect(0, 65511, '\P{^Is_Bc=-ET}', "");
Error('\p{Bidi_Class= -left_to_right/a/}');
Error('\P{Bidi_Class= -left_to_right/a/}');
Expect(1, 1114109, '\p{Bidi_Class=lefttoright}', "");
Expect(0, 1114109, '\p{^Bidi_Class=lefttoright}', "");
Expect(0, 1114109, '\P{Bidi_Class=lefttoright}', "");
Expect(1, 1114109, '\P{^Bidi_Class=lefttoright}', "");
Expect(0, 921599, '\p{Bidi_Class=lefttoright}', "");
Expect(1, 921599, '\p{^Bidi_Class=lefttoright}', "");
Expect(1, 921599, '\P{Bidi_Class=lefttoright}', "");
Expect(0, 921599, '\P{^Bidi_Class=lefttoright}', "");
Expect(1, 1114109, '\p{Bidi_Class: _ Left_To_RIGHT}', "");
Expect(0, 1114109, '\p{^Bidi_Class: _ Left_To_RIGHT}', "");
Expect(0, 1114109, '\P{Bidi_Class: _ Left_To_RIGHT}', "");
Expect(1, 1114109, '\P{^Bidi_Class: _ Left_To_RIGHT}', "");
Expect(0, 921599, '\p{Bidi_Class: _ Left_To_RIGHT}', "");
Expect(1, 921599, '\p{^Bidi_Class: _ Left_To_RIGHT}', "");
Expect(1, 921599, '\P{Bidi_Class: _ Left_To_RIGHT}', "");
Expect(0, 921599, '\P{^Bidi_Class: _ Left_To_RIGHT}', "");
Error('\p{Bc=	/a/L}');
Error('\P{Bc=	/a/L}');
Expect(1, 1114109, '\p{Bc=l}', "");
Expect(0, 1114109, '\p{^Bc=l}', "");
Expect(0, 1114109, '\P{Bc=l}', "");
Expect(1, 1114109, '\P{^Bc=l}', "");
Expect(0, 921599, '\p{Bc=l}', "");
Expect(1, 921599, '\p{^Bc=l}', "");
Expect(1, 921599, '\P{Bc=l}', "");
Expect(0, 921599, '\P{^Bc=l}', "");
Expect(1, 1114109, '\p{Bc:  L}', "");
Expect(0, 1114109, '\p{^Bc:  L}', "");
Expect(0, 1114109, '\P{Bc:  L}', "");
Expect(1, 1114109, '\P{^Bc:  L}', "");
Expect(0, 921599, '\p{Bc:  L}', "");
Expect(1, 921599, '\p{^Bc:  L}', "");
Expect(1, 921599, '\P{Bc:  L}', "");
Expect(0, 921599, '\P{^Bc:  L}', "");
Error('\p{Is_Bidi_Class:	:=left_TO_Right}');
Error('\P{Is_Bidi_Class:	:=left_TO_Right}');
Expect(1, 1114109, '\p{Is_Bidi_Class=lefttoright}', "");
Expect(0, 1114109, '\p{^Is_Bidi_Class=lefttoright}', "");
Expect(0, 1114109, '\P{Is_Bidi_Class=lefttoright}', "");
Expect(1, 1114109, '\P{^Is_Bidi_Class=lefttoright}', "");
Expect(0, 921599, '\p{Is_Bidi_Class=lefttoright}', "");
Expect(1, 921599, '\p{^Is_Bidi_Class=lefttoright}', "");
Expect(1, 921599, '\P{Is_Bidi_Class=lefttoright}', "");
Expect(0, 921599, '\P{^Is_Bidi_Class=lefttoright}', "");
Expect(1, 1114109, '\p{Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(0, 1114109, '\p{^Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(0, 1114109, '\P{Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(1, 1114109, '\P{^Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(0, 921599, '\p{Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(1, 921599, '\p{^Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(1, 921599, '\P{Is_Bidi_Class: Left_To_RIGHT}', "");
Expect(0, 921599, '\P{^Is_Bidi_Class: Left_To_RIGHT}', "");
Error('\p{Is_Bc:   /a/	_L}');
Error('\P{Is_Bc:   /a/	_L}');
Expect(1, 1114109, '\p{Is_Bc=l}', "");
Expect(0, 1114109, '\p{^Is_Bc=l}', "");
Expect(0, 1114109, '\P{Is_Bc=l}', "");
Expect(1, 1114109, '\P{^Is_Bc=l}', "");
Expect(0, 921599, '\p{Is_Bc=l}', "");
Expect(1, 921599, '\p{^Is_Bc=l}', "");
Expect(1, 921599, '\P{Is_Bc=l}', "");
Expect(0, 921599, '\P{^Is_Bc=l}', "");
Expect(1, 1114109, '\p{Is_Bc= L}', "");
Expect(0, 1114109, '\p{^Is_Bc= L}', "");
Expect(0, 1114109, '\P{Is_Bc= L}', "");
Expect(1, 1114109, '\P{^Is_Bc= L}', "");
Expect(0, 921599, '\p{Is_Bc= L}', "");
Expect(1, 921599, '\p{^Is_Bc= L}', "");
Expect(1, 921599, '\P{Is_Bc= L}', "");
Expect(0, 921599, '\P{^Is_Bc= L}', "");
Error('\p{Bidi_Class=/a/_Left_to_Right_embedding}');
Error('\P{Bidi_Class=/a/_Left_to_Right_embedding}');
Expect(1, 8234, '\p{Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\p{^Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\P{Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\P{^Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\p{Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\p{^Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\P{Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\P{^Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\p{Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(0, 8234, '\p{^Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(0, 8234, '\P{Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(1, 8234, '\P{^Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(0, 8235, '\p{Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(1, 8235, '\p{^Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(1, 8235, '\P{Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Expect(0, 8235, '\P{^Bidi_Class=_LEFT_to_RIGHT_Embedding}', "");
Error('\p{Bc=-lre:=}');
Error('\P{Bc=-lre:=}');
Expect(1, 8234, '\p{Bc:   lre}', "");
Expect(0, 8234, '\p{^Bc:   lre}', "");
Expect(0, 8234, '\P{Bc:   lre}', "");
Expect(1, 8234, '\P{^Bc:   lre}', "");
Expect(0, 8235, '\p{Bc:   lre}', "");
Expect(1, 8235, '\p{^Bc:   lre}', "");
Expect(1, 8235, '\P{Bc:   lre}', "");
Expect(0, 8235, '\P{^Bc:   lre}', "");
Expect(1, 8234, '\p{Bc=-_lre}', "");
Expect(0, 8234, '\p{^Bc=-_lre}', "");
Expect(0, 8234, '\P{Bc=-_lre}', "");
Expect(1, 8234, '\P{^Bc=-_lre}', "");
Expect(0, 8235, '\p{Bc=-_lre}', "");
Expect(1, 8235, '\p{^Bc=-_lre}', "");
Expect(1, 8235, '\P{Bc=-_lre}', "");
Expect(0, 8235, '\P{^Bc=-_lre}', "");
Error('\p{Is_Bidi_Class=:=  left_to_RIGHT_embedding}');
Error('\P{Is_Bidi_Class=:=  left_to_RIGHT_embedding}');
Expect(1, 8234, '\p{Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\p{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8234, '\P{Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\P{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\p{Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\p{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8235, '\P{Is_Bidi_Class=lefttorightembedding}', "");
Expect(0, 8235, '\P{^Is_Bidi_Class=lefttorightembedding}', "");
Expect(1, 8234, '\p{Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(0, 8234, '\p{^Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(0, 8234, '\P{Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(1, 8234, '\P{^Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(0, 8235, '\p{Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(1, 8235, '\p{^Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(1, 8235, '\P{Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Expect(0, 8235, '\P{^Is_Bidi_Class:	_Left_TO_right_EMBEDDING}', "");
Error('\p{Is_Bc=/a/-lre}');
Error('\P{Is_Bc=/a/-lre}');
Expect(1, 8234, '\p{Is_Bc=lre}', "");
Expect(0, 8234, '\p{^Is_Bc=lre}', "");
Expect(0, 8234, '\P{Is_Bc=lre}', "");
Expect(1, 8234, '\P{^Is_Bc=lre}', "");
Expect(0, 8235, '\p{Is_Bc=lre}', "");
Expect(1, 8235, '\p{^Is_Bc=lre}', "");
Expect(1, 8235, '\P{Is_Bc=lre}', "");
Expect(0, 8235, '\P{^Is_Bc=lre}', "");
Expect(1, 8234, '\p{Is_Bc=__LRE}', "");
Expect(0, 8234, '\p{^Is_Bc=__LRE}', "");
Expect(0, 8234, '\P{Is_Bc=__LRE}', "");
Expect(1, 8234, '\P{^Is_Bc=__LRE}', "");
Expect(0, 8235, '\p{Is_Bc=__LRE}', "");
Expect(1, 8235, '\p{^Is_Bc=__LRE}', "");
Expect(1, 8235, '\P{Is_Bc=__LRE}', "");
Expect(0, 8235, '\P{^Is_Bc=__LRE}', "");
Error('\p{Bidi_Class=:=_LEFT_To_Right_override}');
Error('\P{Bidi_Class=:=_LEFT_To_Right_override}');
Expect(1, 8237, '\p{Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\p{^Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\P{Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\P{^Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\p{Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\p{^Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\P{Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\P{^Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\p{Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(0, 8237, '\p{^Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(0, 8237, '\P{Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(1, 8237, '\P{^Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(0, 8238, '\p{Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(1, 8238, '\p{^Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(1, 8238, '\P{Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Expect(0, 8238, '\P{^Bidi_Class=  Left_To_RIGHT_OVERRIDE}', "");
Error('\p{Bc=/a/-LRO}');
Error('\P{Bc=/a/-LRO}');
Expect(1, 8237, '\p{Bc=lro}', "");
Expect(0, 8237, '\p{^Bc=lro}', "");
Expect(0, 8237, '\P{Bc=lro}', "");
Expect(1, 8237, '\P{^Bc=lro}', "");
Expect(0, 8238, '\p{Bc=lro}', "");
Expect(1, 8238, '\p{^Bc=lro}', "");
Expect(1, 8238, '\P{Bc=lro}', "");
Expect(0, 8238, '\P{^Bc=lro}', "");
Expect(1, 8237, '\p{Bc=--lro}', "");
Expect(0, 8237, '\p{^Bc=--lro}', "");
Expect(0, 8237, '\P{Bc=--lro}', "");
Expect(1, 8237, '\P{^Bc=--lro}', "");
Expect(0, 8238, '\p{Bc=--lro}', "");
Expect(1, 8238, '\p{^Bc=--lro}', "");
Expect(1, 8238, '\P{Bc=--lro}', "");
Expect(0, 8238, '\P{^Bc=--lro}', "");
Error('\p{Is_Bidi_Class=	/a/left_to_Right_Override}');
Error('\P{Is_Bidi_Class=	/a/left_to_Right_Override}');
Expect(1, 8237, '\p{Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\p{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8237, '\P{Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\P{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\p{Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\p{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8238, '\P{Is_Bidi_Class=lefttorightoverride}', "");
Expect(0, 8238, '\P{^Is_Bidi_Class=lefttorightoverride}', "");
Expect(1, 8237, '\p{Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(0, 8237, '\p{^Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(0, 8237, '\P{Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(1, 8237, '\P{^Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(0, 8238, '\p{Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(1, 8238, '\p{^Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(1, 8238, '\P{Is_Bidi_Class=-	Left_to_Right_Override}', "");
Expect(0, 8238, '\P{^Is_Bidi_Class=-	Left_to_Right_Override}', "");
Error('\p{Is_Bc=:=_-LRO}');
Error('\P{Is_Bc=:=_-LRO}');
Expect(1, 8237, '\p{Is_Bc=lro}', "");
Expect(0, 8237, '\p{^Is_Bc=lro}', "");
Expect(0, 8237, '\P{Is_Bc=lro}', "");
Expect(1, 8237, '\P{^Is_Bc=lro}', "");
Expect(0, 8238, '\p{Is_Bc=lro}', "");
Expect(1, 8238, '\p{^Is_Bc=lro}', "");
Expect(1, 8238, '\P{Is_Bc=lro}', "");
Expect(0, 8238, '\P{^Is_Bc=lro}', "");
Expect(1, 8237, '\p{Is_Bc=-LRO}', "");
Expect(0, 8237, '\p{^Is_Bc=-LRO}', "");
Expect(0, 8237, '\P{Is_Bc=-LRO}', "");
Expect(1, 8237, '\P{^Is_Bc=-LRO}', "");
Expect(0, 8238, '\p{Is_Bc=-LRO}', "");
Expect(1, 8238, '\p{^Is_Bc=-LRO}', "");
Expect(1, 8238, '\P{Is_Bc=-LRO}', "");
Expect(0, 8238, '\P{^Is_Bc=-LRO}', "");
Error('\p{Bidi_Class=/a/Nonspacing_Mark}');
Error('\P{Bidi_Class=/a/Nonspacing_Mark}');
Expect(1, 917999, '\p{Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\p{^Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\P{Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\P{^Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\p{Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\p{^Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\P{Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\P{^Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\p{Bidi_Class=-Nonspacing_Mark}', "");
Expect(0, 917999, '\p{^Bidi_Class=-Nonspacing_Mark}', "");
Expect(0, 917999, '\P{Bidi_Class=-Nonspacing_Mark}', "");
Expect(1, 917999, '\P{^Bidi_Class=-Nonspacing_Mark}', "");
Expect(0, 918000, '\p{Bidi_Class=-Nonspacing_Mark}', "");
Expect(1, 918000, '\p{^Bidi_Class=-Nonspacing_Mark}', "");
Expect(1, 918000, '\P{Bidi_Class=-Nonspacing_Mark}', "");
Expect(0, 918000, '\P{^Bidi_Class=-Nonspacing_Mark}', "");
Error('\p{Bc=	-NSM:=}');
Error('\P{Bc=	-NSM:=}');
Expect(1, 917999, '\p{Bc=nsm}', "");
Expect(0, 917999, '\p{^Bc=nsm}', "");
Expect(0, 917999, '\P{Bc=nsm}', "");
Expect(1, 917999, '\P{^Bc=nsm}', "");
Expect(0, 918000, '\p{Bc=nsm}', "");
Expect(1, 918000, '\p{^Bc=nsm}', "");
Expect(1, 918000, '\P{Bc=nsm}', "");
Expect(0, 918000, '\P{^Bc=nsm}', "");
Expect(1, 917999, '\p{Bc=_NSM}', "");
Expect(0, 917999, '\p{^Bc=_NSM}', "");
Expect(0, 917999, '\P{Bc=_NSM}', "");
Expect(1, 917999, '\P{^Bc=_NSM}', "");
Expect(0, 918000, '\p{Bc=_NSM}', "");
Expect(1, 918000, '\p{^Bc=_NSM}', "");
Expect(1, 918000, '\P{Bc=_NSM}', "");
Expect(0, 918000, '\P{^Bc=_NSM}', "");
Error('\p{Is_Bidi_Class: Nonspacing_MARK/a/}');
Error('\P{Is_Bidi_Class: Nonspacing_MARK/a/}');
Expect(1, 917999, '\p{Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\p{^Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 917999, '\P{Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\P{^Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\p{Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\p{^Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 918000, '\P{Is_Bidi_Class=nonspacingmark}', "");
Expect(0, 918000, '\P{^Is_Bidi_Class=nonspacingmark}', "");
Expect(1, 917999, '\p{Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(0, 917999, '\p{^Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(0, 917999, '\P{Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(1, 917999, '\P{^Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(0, 918000, '\p{Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(1, 918000, '\p{^Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(1, 918000, '\P{Is_Bidi_Class=-	Nonspacing_mark}', "");
Expect(0, 918000, '\P{^Is_Bidi_Class=-	Nonspacing_mark}', "");
Error('\p{Is_Bc: nsm/a/}');
Error('\P{Is_Bc: nsm/a/}');
Expect(1, 917999, '\p{Is_Bc:	nsm}', "");
Expect(0, 917999, '\p{^Is_Bc:	nsm}', "");
Expect(0, 917999, '\P{Is_Bc:	nsm}', "");
Expect(1, 917999, '\P{^Is_Bc:	nsm}', "");
Expect(0, 918000, '\p{Is_Bc:	nsm}', "");
Expect(1, 918000, '\p{^Is_Bc:	nsm}', "");
Expect(1, 918000, '\P{Is_Bc:	nsm}', "");
Expect(0, 918000, '\P{^Is_Bc:	nsm}', "");
Expect(1, 917999, '\p{Is_Bc=_NSM}', "");
Expect(0, 917999, '\p{^Is_Bc=_NSM}', "");
Expect(0, 917999, '\P{Is_Bc=_NSM}', "");
Expect(1, 917999, '\P{^Is_Bc=_NSM}', "");
Expect(0, 918000, '\p{Is_Bc=_NSM}', "");
Expect(1, 918000, '\p{^Is_Bc=_NSM}', "");
Expect(1, 918000, '\P{Is_Bc=_NSM}', "");
Expect(0, 918000, '\P{^Is_Bc=_NSM}', "");
Error('\p{Bidi_Class:	-/a/Other_NEUTRAL}');
Error('\P{Bidi_Class:	-/a/Other_NEUTRAL}');
Expect(1, 128883, '\p{Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\p{^Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\P{Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\P{^Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\p{Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\p{^Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\P{Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\P{^Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\p{Bidi_Class:_Other_NEUTRAL}', "");
Expect(0, 128883, '\p{^Bidi_Class:_Other_NEUTRAL}', "");
Expect(0, 128883, '\P{Bidi_Class:_Other_NEUTRAL}', "");
Expect(1, 128883, '\P{^Bidi_Class:_Other_NEUTRAL}', "");
Expect(0, 128884, '\p{Bidi_Class:_Other_NEUTRAL}', "");
Expect(1, 128884, '\p{^Bidi_Class:_Other_NEUTRAL}', "");
Expect(1, 128884, '\P{Bidi_Class:_Other_NEUTRAL}', "");
Expect(0, 128884, '\P{^Bidi_Class:_Other_NEUTRAL}', "");
Error('\p{Bc: :=ON}');
Error('\P{Bc: :=ON}');
Expect(1, 128883, '\p{Bc=on}', "");
Expect(0, 128883, '\p{^Bc=on}', "");
Expect(0, 128883, '\P{Bc=on}', "");
Expect(1, 128883, '\P{^Bc=on}', "");
Expect(0, 128884, '\p{Bc=on}', "");
Expect(1, 128884, '\p{^Bc=on}', "");
Expect(1, 128884, '\P{Bc=on}', "");
Expect(0, 128884, '\P{^Bc=on}', "");
Expect(1, 128883, '\p{Bc=		ON}', "");
Expect(0, 128883, '\p{^Bc=		ON}', "");
Expect(0, 128883, '\P{Bc=		ON}', "");
Expect(1, 128883, '\P{^Bc=		ON}', "");
Expect(0, 128884, '\p{Bc=		ON}', "");
Expect(1, 128884, '\p{^Bc=		ON}', "");
Expect(1, 128884, '\P{Bc=		ON}', "");
Expect(0, 128884, '\P{^Bc=		ON}', "");
Error('\p{Is_Bidi_Class=	/a/Other_Neutral}');
Error('\P{Is_Bidi_Class=	/a/Other_Neutral}');
Expect(1, 128883, '\p{Is_Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\p{^Is_Bidi_Class=otherneutral}', "");
Expect(0, 128883, '\P{Is_Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\P{^Is_Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\p{Is_Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\p{^Is_Bidi_Class=otherneutral}', "");
Expect(1, 128884, '\P{Is_Bidi_Class=otherneutral}', "");
Expect(0, 128884, '\P{^Is_Bidi_Class=otherneutral}', "");
Expect(1, 128883, '\p{Is_Bidi_Class=  Other_Neutral}', "");
Expect(0, 128883, '\p{^Is_Bidi_Class=  Other_Neutral}', "");
Expect(0, 128883, '\P{Is_Bidi_Class=  Other_Neutral}', "");
Expect(1, 128883, '\P{^Is_Bidi_Class=  Other_Neutral}', "");
Expect(0, 128884, '\p{Is_Bidi_Class=  Other_Neutral}', "");
Expect(1, 128884, '\p{^Is_Bidi_Class=  Other_Neutral}', "");
Expect(1, 128884, '\P{Is_Bidi_Class=  Other_Neutral}', "");
Expect(0, 128884, '\P{^Is_Bidi_Class=  Other_Neutral}', "");
Error('\p{Is_Bc= on/a/}');
Error('\P{Is_Bc= on/a/}');
Expect(1, 128883, '\p{Is_Bc=on}', "");
Expect(0, 128883, '\p{^Is_Bc=on}', "");
Expect(0, 128883, '\P{Is_Bc=on}', "");
Expect(1, 128883, '\P{^Is_Bc=on}', "");
Expect(0, 128884, '\p{Is_Bc=on}', "");
Expect(1, 128884, '\p{^Is_Bc=on}', "");
Expect(1, 128884, '\P{Is_Bc=on}', "");
Expect(0, 128884, '\P{^Is_Bc=on}', "");
Expect(1, 128883, '\p{Is_Bc=_ON}', "");
Expect(0, 128883, '\p{^Is_Bc=_ON}', "");
Expect(0, 128883, '\P{Is_Bc=_ON}', "");
Expect(1, 128883, '\P{^Is_Bc=_ON}', "");
Expect(0, 128884, '\p{Is_Bc=_ON}', "");
Expect(1, 128884, '\p{^Is_Bc=_ON}', "");
Expect(1, 128884, '\P{Is_Bc=_ON}', "");
Expect(0, 128884, '\P{^Is_Bc=_ON}', "");
Error('\p{Bidi_Class=:=POP_directional_format}');
Error('\P{Bidi_Class=:=POP_directional_format}');
Expect(1, 8236, '\p{Bidi_Class=popdirectionalformat}', "");
Expect(0, 8236, '\p{^Bidi_Class=popdirectionalformat}', "");
Expect(0, 8236, '\P{Bidi_Class=popdirectionalformat}', "");
Expect(1, 8236, '\P{^Bidi_Class=popdirectionalformat}', "");
Expect(0, 8237, '\p{Bidi_Class=popdirectionalformat}', "");
Expect(1, 8237, '\p{^Bidi_Class=popdirectionalformat}', "");
Expect(1, 8237, '\P{Bidi_Class=popdirectionalformat}', "");
Expect(0, 8237, '\P{^Bidi_Class=popdirectionalformat}', "");
Expect(1, 8236, '\p{Bidi_Class=--pop_Directional_Format}', "");
Expect(0, 8236, '\p{^Bidi_Class=--pop_Directional_Format}', "");
Expect(0, 8236, '\P{Bidi_Class=--pop_Directional_Format}', "");
Expect(1, 8236, '\P{^Bidi_Class=--pop_Directional_Format}', "");
Expect(0, 8237, '\p{Bidi_Class=--pop_Directional_Format}', "");
Expect(1, 8237, '\p{^Bidi_Class=--pop_Directional_Format}', "");
Expect(1, 8237, '\P{Bidi_Class=--pop_Directional_Format}', "");
Expect(0, 8237, '\P{^Bidi_Class=--pop_Directional_Format}', "");
Error('\p{Bc=:= pdf}');
Error('\P{Bc=:= pdf}');
Expect(1, 8236, '\p{Bc=pdf}', "");
Expect(0, 8236, '\p{^Bc=pdf}', "");
Expect(0, 8236, '\P{Bc=pdf}', "");
Expect(1, 8236, '\P{^Bc=pdf}', "");
Expect(0, 8237, '\p{Bc=pdf}', "");
Expect(1, 8237, '\p{^Bc=pdf}', "");
Expect(1, 8237, '\P{Bc=pdf}', "");
Expect(0, 8237, '\P{^Bc=pdf}', "");
Expect(1, 8236, '\p{Bc=PDF}', "");
Expect(0, 8236, '\p{^Bc=PDF}', "");
Expect(0, 8236, '\P{Bc=PDF}', "");
Expect(1, 8236, '\P{^Bc=PDF}', "");
Expect(0, 8237, '\p{Bc=PDF}', "");
Expect(1, 8237, '\p{^Bc=PDF}', "");
Expect(1, 8237, '\P{Bc=PDF}', "");
Expect(0, 8237, '\P{^Bc=PDF}', "");
Error('\p{Is_Bidi_Class=POP_DIRECTIONAL_Format/a/}');
Error('\P{Is_Bidi_Class=POP_DIRECTIONAL_Format/a/}');
Expect(1, 8236, '\p{Is_Bidi_Class:popdirectionalformat}', "");
Expect(0, 8236, '\p{^Is_Bidi_Class:popdirectionalformat}', "");
Expect(0, 8236, '\P{Is_Bidi_Class:popdirectionalformat}', "");
Expect(1, 8236, '\P{^Is_Bidi_Class:popdirectionalformat}', "");
Expect(0, 8237, '\p{Is_Bidi_Class:popdirectionalformat}', "");
Expect(1, 8237, '\p{^Is_Bidi_Class:popdirectionalformat}', "");
Expect(1, 8237, '\P{Is_Bidi_Class:popdirectionalformat}', "");
Expect(0, 8237, '\P{^Is_Bidi_Class:popdirectionalformat}', "");
Expect(1, 8236, '\p{Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(0, 8236, '\p{^Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(0, 8236, '\P{Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(1, 8236, '\P{^Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(0, 8237, '\p{Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(1, 8237, '\p{^Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(1, 8237, '\P{Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Expect(0, 8237, '\P{^Is_Bidi_Class=		Pop_Directional_FORMAT}', "");
Error('\p{Is_Bc=:=PDF}');
Error('\P{Is_Bc=:=PDF}');
Expect(1, 8236, '\p{Is_Bc=pdf}', "");
Expect(0, 8236, '\p{^Is_Bc=pdf}', "");
Expect(0, 8236, '\P{Is_Bc=pdf}', "");
Expect(1, 8236, '\P{^Is_Bc=pdf}', "");
Expect(0, 8237, '\p{Is_Bc=pdf}', "");
Expect(1, 8237, '\p{^Is_Bc=pdf}', "");
Expect(1, 8237, '\P{Is_Bc=pdf}', "");
Expect(0, 8237, '\P{^Is_Bc=pdf}', "");
Expect(1, 8236, '\p{Is_Bc=- PDF}', "");
Expect(0, 8236, '\p{^Is_Bc=- PDF}', "");
Expect(0, 8236, '\P{Is_Bc=- PDF}', "");
Expect(1, 8236, '\P{^Is_Bc=- PDF}', "");
Expect(0, 8237, '\p{Is_Bc=- PDF}', "");
Expect(1, 8237, '\p{^Is_Bc=- PDF}', "");
Expect(1, 8237, '\P{Is_Bc=- PDF}', "");
Expect(0, 8237, '\P{^Is_Bc=- PDF}', "");
Error('\p{Bidi_Class=/a/  RIGHT_To_LEFT}');
Error('\P{Bidi_Class=/a/  RIGHT_To_LEFT}');
Expect(1, 126975, '\p{Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\p{^Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\P{Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\P{^Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\p{Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\p{^Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\P{Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\P{^Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\p{Bidi_Class=_Right_TO_Left}', "");
Expect(0, 126975, '\p{^Bidi_Class=_Right_TO_Left}', "");
Expect(0, 126975, '\P{Bidi_Class=_Right_TO_Left}', "");
Expect(1, 126975, '\P{^Bidi_Class=_Right_TO_Left}', "");
Expect(0, 126976, '\p{Bidi_Class=_Right_TO_Left}', "");
Expect(1, 126976, '\p{^Bidi_Class=_Right_TO_Left}', "");
Expect(1, 126976, '\P{Bidi_Class=_Right_TO_Left}', "");
Expect(0, 126976, '\P{^Bidi_Class=_Right_TO_Left}', "");
Error('\p{Bc=  R:=}');
Error('\P{Bc=  R:=}');
Expect(1, 126975, '\p{Bc=r}', "");
Expect(0, 126975, '\p{^Bc=r}', "");
Expect(0, 126975, '\P{Bc=r}', "");
Expect(1, 126975, '\P{^Bc=r}', "");
Expect(0, 126976, '\p{Bc=r}', "");
Expect(1, 126976, '\p{^Bc=r}', "");
Expect(1, 126976, '\P{Bc=r}', "");
Expect(0, 126976, '\P{^Bc=r}', "");
Expect(1, 126975, '\p{Bc= R}', "");
Expect(0, 126975, '\p{^Bc= R}', "");
Expect(0, 126975, '\P{Bc= R}', "");
Expect(1, 126975, '\P{^Bc= R}', "");
Expect(0, 126976, '\p{Bc= R}', "");
Expect(1, 126976, '\p{^Bc= R}', "");
Expect(1, 126976, '\P{Bc= R}', "");
Expect(0, 126976, '\P{^Bc= R}', "");
Error('\p{Is_Bidi_Class=/a/	Right_To_LEFT}');
Error('\P{Is_Bidi_Class=/a/	Right_To_LEFT}');
Expect(1, 126975, '\p{Is_Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\p{^Is_Bidi_Class=righttoleft}', "");
Expect(0, 126975, '\P{Is_Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\P{^Is_Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\p{Is_Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\p{^Is_Bidi_Class=righttoleft}', "");
Expect(1, 126976, '\P{Is_Bidi_Class=righttoleft}', "");
Expect(0, 126976, '\P{^Is_Bidi_Class=righttoleft}', "");
Expect(1, 126975, '\p{Is_Bidi_Class=right_TO_Left}', "");
Expect(0, 126975, '\p{^Is_Bidi_Class=right_TO_Left}', "");
Expect(0, 126975, '\P{Is_Bidi_Class=right_TO_Left}', "");
Expect(1, 126975, '\P{^Is_Bidi_Class=right_TO_Left}', "");
Expect(0, 126976, '\p{Is_Bidi_Class=right_TO_Left}', "");
Expect(1, 126976, '\p{^Is_Bidi_Class=right_TO_Left}', "");
Expect(1, 126976, '\P{Is_Bidi_Class=right_TO_Left}', "");
Expect(0, 126976, '\P{^Is_Bidi_Class=right_TO_Left}', "");
Error('\p{Is_Bc=/a/R}');
Error('\P{Is_Bc=/a/R}');
Expect(1, 126975, '\p{Is_Bc=r}', "");
Expect(0, 126975, '\p{^Is_Bc=r}', "");
Expect(0, 126975, '\P{Is_Bc=r}', "");
Expect(1, 126975, '\P{^Is_Bc=r}', "");
Expect(0, 126976, '\p{Is_Bc=r}', "");
Expect(1, 126976, '\p{^Is_Bc=r}', "");
Expect(1, 126976, '\P{Is_Bc=r}', "");
Expect(0, 126976, '\P{^Is_Bc=r}', "");
Expect(1, 126975, '\p{Is_Bc=-	R}', "");
Expect(0, 126975, '\p{^Is_Bc=-	R}', "");
Expect(0, 126975, '\P{Is_Bc=-	R}', "");
Expect(1, 126975, '\P{^Is_Bc=-	R}', "");
Expect(0, 126976, '\p{Is_Bc=-	R}', "");
Expect(1, 126976, '\p{^Is_Bc=-	R}', "");
Expect(1, 126976, '\P{Is_Bc=-	R}', "");
Expect(0, 126976, '\P{^Is_Bc=-	R}', "");
Error('\p{Bidi_Class:	 -RIGHT_To_Left_embedding:=}');
Error('\P{Bidi_Class:	 -RIGHT_To_Left_embedding:=}');
Expect(1, 8235, '\p{Bidi_Class=righttoleftembedding}', "");
Expect(0, 8235, '\p{^Bidi_Class=righttoleftembedding}', "");
Expect(0, 8235, '\P{Bidi_Class=righttoleftembedding}', "");
Expect(1, 8235, '\P{^Bidi_Class=righttoleftembedding}', "");
Expect(0, 8236, '\p{Bidi_Class=righttoleftembedding}', "");
Expect(1, 8236, '\p{^Bidi_Class=righttoleftembedding}', "");
Expect(1, 8236, '\P{Bidi_Class=righttoleftembedding}', "");
Expect(0, 8236, '\P{^Bidi_Class=righttoleftembedding}', "");
Expect(1, 8235, '\p{Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(0, 8235, '\p{^Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(0, 8235, '\P{Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(1, 8235, '\P{^Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(0, 8236, '\p{Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(1, 8236, '\p{^Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(1, 8236, '\P{Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Expect(0, 8236, '\P{^Bidi_Class=  Right_to_LEFT_EMBEDDING}', "");
Error('\p{Bc:   _-rle/a/}');
Error('\P{Bc:   _-rle/a/}');
Expect(1, 8235, '\p{Bc=rle}', "");
Expect(0, 8235, '\p{^Bc=rle}', "");
Expect(0, 8235, '\P{Bc=rle}', "");
Expect(1, 8235, '\P{^Bc=rle}', "");
Expect(0, 8236, '\p{Bc=rle}', "");
Expect(1, 8236, '\p{^Bc=rle}', "");
Expect(1, 8236, '\P{Bc=rle}', "");
Expect(0, 8236, '\P{^Bc=rle}', "");
Expect(1, 8235, '\p{Bc=__rle}', "");
Expect(0, 8235, '\p{^Bc=__rle}', "");
Expect(0, 8235, '\P{Bc=__rle}', "");
Expect(1, 8235, '\P{^Bc=__rle}', "");
Expect(0, 8236, '\p{Bc=__rle}', "");
Expect(1, 8236, '\p{^Bc=__rle}', "");
Expect(1, 8236, '\P{Bc=__rle}', "");
Expect(0, 8236, '\P{^Bc=__rle}', "");
Error('\p{Is_Bidi_Class:	:=right_To_Left_EMBEDDING}');
Error('\P{Is_Bidi_Class:	:=right_To_Left_EMBEDDING}');
Expect(1, 8235, '\p{Is_Bidi_Class:	righttoleftembedding}', "");
Expect(0, 8235, '\p{^Is_Bidi_Class:	righttoleftembedding}', "");
Expect(0, 8235, '\P{Is_Bidi_Class:	righttoleftembedding}', "");
Expect(1, 8235, '\P{^Is_Bidi_Class:	righttoleftembedding}', "");
Expect(0, 8236, '\p{Is_Bidi_Class:	righttoleftembedding}', "");
Expect(1, 8236, '\p{^Is_Bidi_Class:	righttoleftembedding}', "");
Expect(1, 8236, '\P{Is_Bidi_Class:	righttoleftembedding}', "");
Expect(0, 8236, '\P{^Is_Bidi_Class:	righttoleftembedding}', "");
Expect(1, 8235, '\p{Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(0, 8235, '\p{^Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(0, 8235, '\P{Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(1, 8235, '\P{^Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(0, 8236, '\p{Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(1, 8236, '\p{^Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(1, 8236, '\P{Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Expect(0, 8236, '\P{^Is_Bidi_Class:		 right_to_LEFT_embedding}', "");
Error('\p{Is_Bc= :=RLE}');
Error('\P{Is_Bc= :=RLE}');
Expect(1, 8235, '\p{Is_Bc=rle}', "");
Expect(0, 8235, '\p{^Is_Bc=rle}', "");
Expect(0, 8235, '\P{Is_Bc=rle}', "");
Expect(1, 8235, '\P{^Is_Bc=rle}', "");
Expect(0, 8236, '\p{Is_Bc=rle}', "");
Expect(1, 8236, '\p{^Is_Bc=rle}', "");
Expect(1, 8236, '\P{Is_Bc=rle}', "");
Expect(0, 8236, '\P{^Is_Bc=rle}', "");
Expect(1, 8235, '\p{Is_Bc=	-RLE}', "");
Expect(0, 8235, '\p{^Is_Bc=	-RLE}', "");
Expect(0, 8235, '\P{Is_Bc=	-RLE}', "");
Expect(1, 8235, '\P{^Is_Bc=	-RLE}', "");
Expect(0, 8236, '\p{Is_Bc=	-RLE}', "");
Expect(1, 8236, '\p{^Is_Bc=	-RLE}', "");
Expect(1, 8236, '\P{Is_Bc=	-RLE}', "");
Expect(0, 8236, '\P{^Is_Bc=	-RLE}', "");
Error('\p{Bidi_Class=/a/ _RIGHT_To_left_override}');
Error('\P{Bidi_Class=/a/ _RIGHT_To_left_override}');
Expect(1, 8238, '\p{Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\p{^Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\P{Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\P{^Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\p{Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\p{^Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\P{Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\P{^Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\p{Bidi_Class= 	right_TO_Left_Override}', "");
Expect(0, 8238, '\p{^Bidi_Class= 	right_TO_Left_Override}', "");
Expect(0, 8238, '\P{Bidi_Class= 	right_TO_Left_Override}', "");
Expect(1, 8238, '\P{^Bidi_Class= 	right_TO_Left_Override}', "");
Expect(0, 8239, '\p{Bidi_Class= 	right_TO_Left_Override}', "");
Expect(1, 8239, '\p{^Bidi_Class= 	right_TO_Left_Override}', "");
Expect(1, 8239, '\P{Bidi_Class= 	right_TO_Left_Override}', "");
Expect(0, 8239, '\P{^Bidi_Class= 	right_TO_Left_Override}', "");
Error('\p{Bc=:=RLO}');
Error('\P{Bc=:=RLO}');
Expect(1, 8238, '\p{Bc=rlo}', "");
Expect(0, 8238, '\p{^Bc=rlo}', "");
Expect(0, 8238, '\P{Bc=rlo}', "");
Expect(1, 8238, '\P{^Bc=rlo}', "");
Expect(0, 8239, '\p{Bc=rlo}', "");
Expect(1, 8239, '\p{^Bc=rlo}', "");
Expect(1, 8239, '\P{Bc=rlo}', "");
Expect(0, 8239, '\P{^Bc=rlo}', "");
Expect(1, 8238, '\p{Bc=	_RLO}', "");
Expect(0, 8238, '\p{^Bc=	_RLO}', "");
Expect(0, 8238, '\P{Bc=	_RLO}', "");
Expect(1, 8238, '\P{^Bc=	_RLO}', "");
Expect(0, 8239, '\p{Bc=	_RLO}', "");
Expect(1, 8239, '\p{^Bc=	_RLO}', "");
Expect(1, 8239, '\P{Bc=	_RLO}', "");
Expect(0, 8239, '\P{^Bc=	_RLO}', "");
Error('\p{Is_Bidi_Class= Right_TO_Left_Override/a/}');
Error('\P{Is_Bidi_Class= Right_TO_Left_Override/a/}');
Expect(1, 8238, '\p{Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\p{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8238, '\P{Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\P{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\p{Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\p{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8239, '\P{Is_Bidi_Class=righttoleftoverride}', "");
Expect(0, 8239, '\P{^Is_Bidi_Class=righttoleftoverride}', "");
Expect(1, 8238, '\p{Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(0, 8238, '\p{^Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(0, 8238, '\P{Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(1, 8238, '\P{^Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(0, 8239, '\p{Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(1, 8239, '\p{^Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(1, 8239, '\P{Is_Bidi_Class=_Right_TO_left_override}', "");
Expect(0, 8239, '\P{^Is_Bidi_Class=_Right_TO_left_override}', "");
Error('\p{Is_Bc=:=rlo}');
Error('\P{Is_Bc=:=rlo}');
Expect(1, 8238, '\p{Is_Bc=rlo}', "");
Expect(0, 8238, '\p{^Is_Bc=rlo}', "");
Expect(0, 8238, '\P{Is_Bc=rlo}', "");
Expect(1, 8238, '\P{^Is_Bc=rlo}', "");
Expect(0, 8239, '\p{Is_Bc=rlo}', "");
Expect(1, 8239, '\p{^Is_Bc=rlo}', "");
Expect(1, 8239, '\P{Is_Bc=rlo}', "");
Expect(0, 8239, '\P{^Is_Bc=rlo}', "");
Expect(1, 8238, '\p{Is_Bc=  rlo}', "");
Expect(0, 8238, '\p{^Is_Bc=  rlo}', "");
Expect(0, 8238, '\P{Is_Bc=  rlo}', "");
Expect(1, 8238, '\P{^Is_Bc=  rlo}', "");
Expect(0, 8239, '\p{Is_Bc=  rlo}', "");
Expect(1, 8239, '\p{^Is_Bc=  rlo}', "");
Expect(1, 8239, '\P{Is_Bc=  rlo}', "");
Expect(0, 8239, '\P{^Is_Bc=  rlo}', "");
Error('\p{Bidi_Class=--Segment_separator/a/}');
Error('\P{Bidi_Class=--Segment_separator/a/}');
Expect(1, 31, '\p{Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\p{^Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\P{Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\P{^Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\p{Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\p{^Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\P{Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\P{^Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\p{Bidi_Class=-Segment_separator}', "");
Expect(0, 31, '\p{^Bidi_Class=-Segment_separator}', "");
Expect(0, 31, '\P{Bidi_Class=-Segment_separator}', "");
Expect(1, 31, '\P{^Bidi_Class=-Segment_separator}', "");
Expect(0, 32, '\p{Bidi_Class=-Segment_separator}', "");
Expect(1, 32, '\p{^Bidi_Class=-Segment_separator}', "");
Expect(1, 32, '\P{Bidi_Class=-Segment_separator}', "");
Expect(0, 32, '\P{^Bidi_Class=-Segment_separator}', "");
Error('\p{Bc=-S:=}');
Error('\P{Bc=-S:=}');
Expect(1, 31, '\p{Bc=s}', "");
Expect(0, 31, '\p{^Bc=s}', "");
Expect(0, 31, '\P{Bc=s}', "");
Expect(1, 31, '\P{^Bc=s}', "");
Expect(0, 32, '\p{Bc=s}', "");
Expect(1, 32, '\p{^Bc=s}', "");
Expect(1, 32, '\P{Bc=s}', "");
Expect(0, 32, '\P{^Bc=s}', "");
Expect(1, 31, '\p{Bc= S}', "");
Expect(0, 31, '\p{^Bc= S}', "");
Expect(0, 31, '\P{Bc= S}', "");
Expect(1, 31, '\P{^Bc= S}', "");
Expect(0, 32, '\p{Bc= S}', "");
Expect(1, 32, '\p{^Bc= S}', "");
Expect(1, 32, '\P{Bc= S}', "");
Expect(0, 32, '\P{^Bc= S}', "");
Error('\p{Is_Bidi_Class=:=_ segment_SEPARATOR}');
Error('\P{Is_Bidi_Class=:=_ segment_SEPARATOR}');
Expect(1, 31, '\p{Is_Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\p{^Is_Bidi_Class=segmentseparator}', "");
Expect(0, 31, '\P{Is_Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\P{^Is_Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\p{Is_Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\p{^Is_Bidi_Class=segmentseparator}', "");
Expect(1, 32, '\P{Is_Bidi_Class=segmentseparator}', "");
Expect(0, 32, '\P{^Is_Bidi_Class=segmentseparator}', "");
Expect(1, 31, '\p{Is_Bidi_Class=-Segment_Separator}', "");
Expect(0, 31, '\p{^Is_Bidi_Class=-Segment_Separator}', "");
Expect(0, 31, '\P{Is_Bidi_Class=-Segment_Separator}', "");
Expect(1, 31, '\P{^Is_Bidi_Class=-Segment_Separator}', "");
Expect(0, 32, '\p{Is_Bidi_Class=-Segment_Separator}', "");
Expect(1, 32, '\p{^Is_Bidi_Class=-Segment_Separator}', "");
Expect(1, 32, '\P{Is_Bidi_Class=-Segment_Separator}', "");
Expect(0, 32, '\P{^Is_Bidi_Class=-Segment_Separator}', "");
Error('\p{Is_Bc=- S/a/}');
Error('\P{Is_Bc=- S/a/}');
Expect(1, 31, '\p{Is_Bc=s}', "");
Expect(0, 31, '\p{^Is_Bc=s}', "");
Expect(0, 31, '\P{Is_Bc=s}', "");
Expect(1, 31, '\P{^Is_Bc=s}', "");
Expect(0, 32, '\p{Is_Bc=s}', "");
Expect(1, 32, '\p{^Is_Bc=s}', "");
Expect(1, 32, '\P{Is_Bc=s}', "");
Expect(0, 32, '\P{^Is_Bc=s}', "");
Expect(1, 31, '\p{Is_Bc=_	S}', "");
Expect(0, 31, '\p{^Is_Bc=_	S}', "");
Expect(0, 31, '\P{Is_Bc=_	S}', "");
Expect(1, 31, '\P{^Is_Bc=_	S}', "");
Expect(0, 32, '\p{Is_Bc=_	S}', "");
Expect(1, 32, '\p{^Is_Bc=_	S}', "");
Expect(1, 32, '\P{Is_Bc=_	S}', "");
Expect(0, 32, '\P{^Is_Bc=_	S}', "");
Error('\p{Bidi_Class=_-WHITE_SPACE/a/}');
Error('\P{Bidi_Class=_-WHITE_SPACE/a/}');
Expect(1, 12288, '\p{Bidi_Class=whitespace}', "");
Expect(0, 12288, '\p{^Bidi_Class=whitespace}', "");
Expect(0, 12288, '\P{Bidi_Class=whitespace}', "");
Expect(1, 12288, '\P{^Bidi_Class=whitespace}', "");
Expect(0, 12289, '\p{Bidi_Class=whitespace}', "");
Expect(1, 12289, '\p{^Bidi_Class=whitespace}', "");
Expect(1, 12289, '\P{Bidi_Class=whitespace}', "");
Expect(0, 12289, '\P{^Bidi_Class=whitespace}', "");
Expect(1, 12288, '\p{Bidi_Class=-white_SPACE}', "");
Expect(0, 12288, '\p{^Bidi_Class=-white_SPACE}', "");
Expect(0, 12288, '\P{Bidi_Class=-white_SPACE}', "");
Expect(1, 12288, '\P{^Bidi_Class=-white_SPACE}', "");
Expect(0, 12289, '\p{Bidi_Class=-white_SPACE}', "");
Expect(1, 12289, '\p{^Bidi_Class=-white_SPACE}', "");
Expect(1, 12289, '\P{Bidi_Class=-white_SPACE}', "");
Expect(0, 12289, '\P{^Bidi_Class=-white_SPACE}', "");
Error('\p{Bc= ws/a/}');
Error('\P{Bc= ws/a/}');
Expect(1, 12288, '\p{Bc=ws}', "");
Expect(0, 12288, '\p{^Bc=ws}', "");
Expect(0, 12288, '\P{Bc=ws}', "");
Expect(1, 12288, '\P{^Bc=ws}', "");
Expect(0, 12289, '\p{Bc=ws}', "");
Expect(1, 12289, '\p{^Bc=ws}', "");
Expect(1, 12289, '\P{Bc=ws}', "");
Expect(0, 12289, '\P{^Bc=ws}', "");
Expect(1, 12288, '\p{Bc=_-WS}', "");
Expect(0, 12288, '\p{^Bc=_-WS}', "");
Expect(0, 12288, '\P{Bc=_-WS}', "");
Expect(1, 12288, '\P{^Bc=_-WS}', "");
Expect(0, 12289, '\p{Bc=_-WS}', "");
Expect(1, 12289, '\p{^Bc=_-WS}', "");
Expect(1, 12289, '\P{Bc=_-WS}', "");
Expect(0, 12289, '\P{^Bc=_-WS}', "");
Error('\p{Is_Bidi_Class=:=_White_SPACE}');
Error('\P{Is_Bidi_Class=:=_White_SPACE}');
Expect(1, 12288, '\p{Is_Bidi_Class=whitespace}', "");
Expect(0, 12288, '\p{^Is_Bidi_Class=whitespace}', "");
Expect(0, 12288, '\P{Is_Bidi_Class=whitespace}', "");
Expect(1, 12288, '\P{^Is_Bidi_Class=whitespace}', "");
Expect(0, 12289, '\p{Is_Bidi_Class=whitespace}', "");
Expect(1, 12289, '\p{^Is_Bidi_Class=whitespace}', "");
Expect(1, 12289, '\P{Is_Bidi_Class=whitespace}', "");
Expect(0, 12289, '\P{^Is_Bidi_Class=whitespace}', "");
Expect(1, 12288, '\p{Is_Bidi_Class:  White_space}', "");
Expect(0, 12288, '\p{^Is_Bidi_Class:  White_space}', "");
Expect(0, 12288, '\P{Is_Bidi_Class:  White_space}', "");
Expect(1, 12288, '\P{^Is_Bidi_Class:  White_space}', "");
Expect(0, 12289, '\p{Is_Bidi_Class:  White_space}', "");
Expect(1, 12289, '\p{^Is_Bidi_Class:  White_space}', "");
Expect(1, 12289, '\P{Is_Bidi_Class:  White_space}', "");
Expect(0, 12289, '\P{^Is_Bidi_Class:  White_space}', "");
Error('\p{Is_Bc=:=WS}');
Error('\P{Is_Bc=:=WS}');
Expect(1, 12288, '\p{Is_Bc=ws}', "");
Expect(0, 12288, '\p{^Is_Bc=ws}', "");
Expect(0, 12288, '\P{Is_Bc=ws}', "");
Expect(1, 12288, '\P{^Is_Bc=ws}', "");
Expect(0, 12289, '\p{Is_Bc=ws}', "");
Expect(1, 12289, '\p{^Is_Bc=ws}', "");
Expect(1, 12289, '\P{Is_Bc=ws}', "");
Expect(0, 12289, '\P{^Is_Bc=ws}', "");
Expect(1, 12288, '\p{Is_Bc=- WS}', "");
Expect(0, 12288, '\p{^Is_Bc=- WS}', "");
Expect(0, 12288, '\P{Is_Bc=- WS}', "");
Expect(1, 12288, '\P{^Is_Bc=- WS}', "");
Expect(0, 12289, '\p{Is_Bc=- WS}', "");
Expect(1, 12289, '\p{^Is_Bc=- WS}', "");
Expect(1, 12289, '\P{Is_Bc=- WS}', "");
Expect(0, 12289, '\P{^Is_Bc=- WS}', "");
Error('\p{Block:/a/ _basic_Latin}');
Error('\P{Block:/a/ _basic_Latin}');
Expect(1, 127, '\p{Block=basiclatin}', "");
Expect(0, 127, '\p{^Block=basiclatin}', "");
Expect(0, 127, '\P{Block=basiclatin}', "");
Expect(1, 127, '\P{^Block=basiclatin}', "");
Expect(0, 128, '\p{Block=basiclatin}', "");
Expect(1, 128, '\p{^Block=basiclatin}', "");
Expect(1, 128, '\P{Block=basiclatin}', "");
Expect(0, 128, '\P{^Block=basiclatin}', "");
Expect(1, 127, '\p{Block=-	basic_latin}', "");
Expect(0, 127, '\p{^Block=-	basic_latin}', "");
Expect(0, 127, '\P{Block=-	basic_latin}', "");
Expect(1, 127, '\P{^Block=-	basic_latin}', "");
Expect(0, 128, '\p{Block=-	basic_latin}', "");
Expect(1, 128, '\p{^Block=-	basic_latin}', "");
Expect(1, 128, '\P{Block=-	basic_latin}', "");
Expect(0, 128, '\P{^Block=-	basic_latin}', "");
Error('\p{Blk=_ ASCII/a/}');
Error('\P{Blk=_ ASCII/a/}');
Expect(1, 127, '\p{Blk=ascii}', "");
Expect(0, 127, '\p{^Blk=ascii}', "");
Expect(0, 127, '\P{Blk=ascii}', "");
Expect(1, 127, '\P{^Blk=ascii}', "");
Expect(0, 128, '\p{Blk=ascii}', "");
Expect(1, 128, '\p{^Blk=ascii}', "");
Expect(1, 128, '\P{Blk=ascii}', "");
Expect(0, 128, '\P{^Blk=ascii}', "");
Expect(1, 127, '\p{Blk=	ASCII}', "");
Expect(0, 127, '\p{^Blk=	ASCII}', "");
Expect(0, 127, '\P{Blk=	ASCII}', "");
Expect(1, 127, '\P{^Blk=	ASCII}', "");
Expect(0, 128, '\p{Blk=	ASCII}', "");
Expect(1, 128, '\p{^Blk=	ASCII}', "");
Expect(1, 128, '\P{Blk=	ASCII}', "");
Expect(0, 128, '\P{^Blk=	ASCII}', "");
Error('\p{Is_Block=:=-	Basic_Latin}');
Error('\P{Is_Block=:=-	Basic_Latin}');
Expect(1, 127, '\p{Is_Block=basiclatin}', "");
Expect(0, 127, '\p{^Is_Block=basiclatin}', "");
Expect(0, 127, '\P{Is_Block=basiclatin}', "");
Expect(1, 127, '\P{^Is_Block=basiclatin}', "");
Expect(0, 128, '\p{Is_Block=basiclatin}', "");
Expect(1, 128, '\p{^Is_Block=basiclatin}', "");
Expect(1, 128, '\P{Is_Block=basiclatin}', "");
Expect(0, 128, '\P{^Is_Block=basiclatin}', "");
Expect(1, 127, '\p{Is_Block=_ Basic_Latin}', "");
Expect(0, 127, '\p{^Is_Block=_ Basic_Latin}', "");
Expect(0, 127, '\P{Is_Block=_ Basic_Latin}', "");
Expect(1, 127, '\P{^Is_Block=_ Basic_Latin}', "");
Expect(0, 128, '\p{Is_Block=_ Basic_Latin}', "");
Expect(1, 128, '\p{^Is_Block=_ Basic_Latin}', "");
Expect(1, 128, '\P{Is_Block=_ Basic_Latin}', "");
Expect(0, 128, '\P{^Is_Block=_ Basic_Latin}', "");
Error('\p{Is_Blk=/a/	-ASCII}');
Error('\P{Is_Blk=/a/	-ASCII}');
Expect(1, 127, '\p{Is_Blk=ascii}', "");
Expect(0, 127, '\p{^Is_Blk=ascii}', "");
Expect(0, 127, '\P{Is_Blk=ascii}', "");
Expect(1, 127, '\P{^Is_Blk=ascii}', "");
Expect(0, 128, '\p{Is_Blk=ascii}', "");
Expect(1, 128, '\p{^Is_Blk=ascii}', "");
Expect(1, 128, '\P{Is_Blk=ascii}', "");
Expect(0, 128, '\P{^Is_Blk=ascii}', "");
Expect(1, 127, '\p{Is_Blk=_	ascii}', "");
Expect(0, 127, '\p{^Is_Blk=_	ascii}', "");
Expect(0, 127, '\P{Is_Blk=_	ascii}', "");
Expect(1, 127, '\P{^Is_Blk=_	ascii}', "");
Expect(0, 128, '\p{Is_Blk=_	ascii}', "");
Expect(1, 128, '\p{^Is_Blk=_	ascii}', "");
Expect(1, 128, '\P{Is_Blk=_	ascii}', "");
Expect(0, 128, '\P{^Is_Blk=_	ascii}', "");
Error('\p{Block=-Aegean_NUMBERS/a/}');
Error('\P{Block=-Aegean_NUMBERS/a/}');
Expect(1, 65855, '\p{Block=aegeannumbers}', "");
Expect(0, 65855, '\p{^Block=aegeannumbers}', "");
Expect(0, 65855, '\P{Block=aegeannumbers}', "");
Expect(1, 65855, '\P{^Block=aegeannumbers}', "");
Expect(0, 65856, '\p{Block=aegeannumbers}', "");
Expect(1, 65856, '\p{^Block=aegeannumbers}', "");
Expect(1, 65856, '\P{Block=aegeannumbers}', "");
Expect(0, 65856, '\P{^Block=aegeannumbers}', "");
Expect(1, 65855, '\p{Block=  aegean_Numbers}', "");
Expect(0, 65855, '\p{^Block=  aegean_Numbers}', "");
Expect(0, 65855, '\P{Block=  aegean_Numbers}', "");
Expect(1, 65855, '\P{^Block=  aegean_Numbers}', "");
Expect(0, 65856, '\p{Block=  aegean_Numbers}', "");
Expect(1, 65856, '\p{^Block=  aegean_Numbers}', "");
Expect(1, 65856, '\P{Block=  aegean_Numbers}', "");
Expect(0, 65856, '\P{^Block=  aegean_Numbers}', "");
Error('\p{Blk=:=_-aegean_Numbers}');
Error('\P{Blk=:=_-aegean_Numbers}');
Expect(1, 65855, '\p{Blk=aegeannumbers}', "");
Expect(0, 65855, '\p{^Blk=aegeannumbers}', "");
Expect(0, 65855, '\P{Blk=aegeannumbers}', "");
Expect(1, 65855, '\P{^Blk=aegeannumbers}', "");
Expect(0, 65856, '\p{Blk=aegeannumbers}', "");
Expect(1, 65856, '\p{^Blk=aegeannumbers}', "");
Expect(1, 65856, '\P{Blk=aegeannumbers}', "");
Expect(0, 65856, '\P{^Blk=aegeannumbers}', "");
Expect(1, 65855, '\p{Blk=-_Aegean_Numbers}', "");
Expect(0, 65855, '\p{^Blk=-_Aegean_Numbers}', "");
Expect(0, 65855, '\P{Blk=-_Aegean_Numbers}', "");
Expect(1, 65855, '\P{^Blk=-_Aegean_Numbers}', "");
Expect(0, 65856, '\p{Blk=-_Aegean_Numbers}', "");
Expect(1, 65856, '\p{^Blk=-_Aegean_Numbers}', "");
Expect(1, 65856, '\P{Blk=-_Aegean_Numbers}', "");
Expect(0, 65856, '\P{^Blk=-_Aegean_Numbers}', "");
Error('\p{Is_Block=	Aegean_Numbers:=}');
Error('\P{Is_Block=	Aegean_Numbers:=}');
Expect(1, 65855, '\p{Is_Block:	aegeannumbers}', "");
Expect(0, 65855, '\p{^Is_Block:	aegeannumbers}', "");
Expect(0, 65855, '\P{Is_Block:	aegeannumbers}', "");
Expect(1, 65855, '\P{^Is_Block:	aegeannumbers}', "");
Expect(0, 65856, '\p{Is_Block:	aegeannumbers}', "");
Expect(1, 65856, '\p{^Is_Block:	aegeannumbers}', "");
Expect(1, 65856, '\P{Is_Block:	aegeannumbers}', "");
Expect(0, 65856, '\P{^Is_Block:	aegeannumbers}', "");
Expect(1, 65855, '\p{Is_Block= Aegean_Numbers}', "");
Expect(0, 65855, '\p{^Is_Block= Aegean_Numbers}', "");
Expect(0, 65855, '\P{Is_Block= Aegean_Numbers}', "");
Expect(1, 65855, '\P{^Is_Block= Aegean_Numbers}', "");
Expect(0, 65856, '\p{Is_Block= Aegean_Numbers}', "");
Expect(1, 65856, '\p{^Is_Block= Aegean_Numbers}', "");
Expect(1, 65856, '\P{Is_Block= Aegean_Numbers}', "");
Expect(0, 65856, '\P{^Is_Block= Aegean_Numbers}', "");
Error('\p{Is_Blk:	/a/_-aegean_NUMBERS}');
Error('\P{Is_Blk:	/a/_-aegean_NUMBERS}');
Expect(1, 65855, '\p{Is_Blk=aegeannumbers}', "");
Expect(0, 65855, '\p{^Is_Blk=aegeannumbers}', "");
Expect(0, 65855, '\P{Is_Blk=aegeannumbers}', "");
Expect(1, 65855, '\P{^Is_Blk=aegeannumbers}', "");
Expect(0, 65856, '\p{Is_Blk=aegeannumbers}', "");
Expect(1, 65856, '\p{^Is_Blk=aegeannumbers}', "");
Expect(1, 65856, '\P{Is_Blk=aegeannumbers}', "");
Expect(0, 65856, '\P{^Is_Blk=aegeannumbers}', "");
Expect(1, 65855, '\p{Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(0, 65855, '\p{^Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(0, 65855, '\P{Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(1, 65855, '\P{^Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(0, 65856, '\p{Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(1, 65856, '\p{^Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(1, 65856, '\P{Is_Blk= -AEGEAN_NUMBERS}', "");
Expect(0, 65856, '\P{^Is_Blk= -AEGEAN_NUMBERS}', "");
Error('\p{Block:   :=_ Alchemical_SYMBOLS}');
Error('\P{Block:   :=_ Alchemical_SYMBOLS}');
Expect(1, 128895, '\p{Block=alchemicalsymbols}', "");
Expect(0, 128895, '\p{^Block=alchemicalsymbols}', "");
Expect(0, 128895, '\P{Block=alchemicalsymbols}', "");
Expect(1, 128895, '\P{^Block=alchemicalsymbols}', "");
Expect(0, 128896, '\p{Block=alchemicalsymbols}', "");
Expect(1, 128896, '\p{^Block=alchemicalsymbols}', "");
Expect(1, 128896, '\P{Block=alchemicalsymbols}', "");
Expect(0, 128896, '\P{^Block=alchemicalsymbols}', "");
Expect(1, 128895, '\p{Block=__ALCHEMICAL_Symbols}', "");
Expect(0, 128895, '\p{^Block=__ALCHEMICAL_Symbols}', "");
Expect(0, 128895, '\P{Block=__ALCHEMICAL_Symbols}', "");
Expect(1, 128895, '\P{^Block=__ALCHEMICAL_Symbols}', "");
Expect(0, 128896, '\p{Block=__ALCHEMICAL_Symbols}', "");
Expect(1, 128896, '\p{^Block=__ALCHEMICAL_Symbols}', "");
Expect(1, 128896, '\P{Block=__ALCHEMICAL_Symbols}', "");
Expect(0, 128896, '\P{^Block=__ALCHEMICAL_Symbols}', "");
Error('\p{Blk=:=Alchemical}');
Error('\P{Blk=:=Alchemical}');
Expect(1, 128895, '\p{Blk=alchemical}', "");
Expect(0, 128895, '\p{^Blk=alchemical}', "");
Expect(0, 128895, '\P{Blk=alchemical}', "");
Expect(1, 128895, '\P{^Blk=alchemical}', "");
Expect(0, 128896, '\p{Blk=alchemical}', "");
Expect(1, 128896, '\p{^Blk=alchemical}', "");
Expect(1, 128896, '\P{Blk=alchemical}', "");
Expect(0, 128896, '\P{^Blk=alchemical}', "");
Expect(1, 128895, '\p{Blk=_	Alchemical}', "");
Expect(0, 128895, '\p{^Blk=_	Alchemical}', "");
Expect(0, 128895, '\P{Blk=_	Alchemical}', "");
Expect(1, 128895, '\P{^Blk=_	Alchemical}', "");
Expect(0, 128896, '\p{Blk=_	Alchemical}', "");
Expect(1, 128896, '\p{^Blk=_	Alchemical}', "");
Expect(1, 128896, '\P{Blk=_	Alchemical}', "");
Expect(0, 128896, '\P{^Blk=_	Alchemical}', "");
Error('\p{Is_Block=_ALCHEMICAL_Symbols:=}');
Error('\P{Is_Block=_ALCHEMICAL_Symbols:=}');
Expect(1, 128895, '\p{Is_Block=alchemicalsymbols}', "");
Expect(0, 128895, '\p{^Is_Block=alchemicalsymbols}', "");
Expect(0, 128895, '\P{Is_Block=alchemicalsymbols}', "");
Expect(1, 128895, '\P{^Is_Block=alchemicalsymbols}', "");
Expect(0, 128896, '\p{Is_Block=alchemicalsymbols}', "");
Expect(1, 128896, '\p{^Is_Block=alchemicalsymbols}', "");
Expect(1, 128896, '\P{Is_Block=alchemicalsymbols}', "");
Expect(0, 128896, '\P{^Is_Block=alchemicalsymbols}', "");
Expect(1, 128895, '\p{Is_Block=alchemical_Symbols}', "");
Expect(0, 128895, '\p{^Is_Block=alchemical_Symbols}', "");
Expect(0, 128895, '\P{Is_Block=alchemical_Symbols}', "");
Expect(1, 128895, '\P{^Is_Block=alchemical_Symbols}', "");
Expect(0, 128896, '\p{Is_Block=alchemical_Symbols}', "");
Expect(1, 128896, '\p{^Is_Block=alchemical_Symbols}', "");
Expect(1, 128896, '\P{Is_Block=alchemical_Symbols}', "");
Expect(0, 128896, '\P{^Is_Block=alchemical_Symbols}', "");
Error('\p{Is_Blk=:=- Alchemical}');
Error('\P{Is_Blk=:=- Alchemical}');
Expect(1, 128895, '\p{Is_Blk:   alchemical}', "");
Expect(0, 128895, '\p{^Is_Blk:   alchemical}', "");
Expect(0, 128895, '\P{Is_Blk:   alchemical}', "");
Expect(1, 128895, '\P{^Is_Blk:   alchemical}', "");
Expect(0, 128896, '\p{Is_Blk:   alchemical}', "");
Expect(1, 128896, '\p{^Is_Blk:   alchemical}', "");
Expect(1, 128896, '\P{Is_Blk:   alchemical}', "");
Expect(0, 128896, '\P{^Is_Blk:   alchemical}', "");
Expect(1, 128895, '\p{Is_Blk=-Alchemical}', "");
Expect(0, 128895, '\p{^Is_Blk=-Alchemical}', "");
Expect(0, 128895, '\P{Is_Blk=-Alchemical}', "");
Expect(1, 128895, '\P{^Is_Blk=-Alchemical}', "");
Expect(0, 128896, '\p{Is_Blk=-Alchemical}', "");
Expect(1, 128896, '\p{^Is_Blk=-Alchemical}', "");
Expect(1, 128896, '\P{Is_Blk=-Alchemical}', "");
Expect(0, 128896, '\P{^Is_Blk=-Alchemical}', "");
Error('\p{Block=:=-_Alphabetic_PRESENTATION_forms}');
Error('\P{Block=:=-_Alphabetic_PRESENTATION_forms}');
Expect(1, 64335, '\p{Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\P{Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\p{Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\P{Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\p{Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64335, '\p{^Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64335, '\P{Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(1, 64335, '\P{^Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64336, '\p{Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(1, 64336, '\p{^Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(1, 64336, '\P{Block=	-alphabetic_PRESENTATION_Forms}', "");
Expect(0, 64336, '\P{^Block=	-alphabetic_PRESENTATION_Forms}', "");
Error('\p{Blk=_:=alphabetic_PF}');
Error('\P{Blk=_:=alphabetic_PF}');
Expect(1, 64335, '\p{Blk=alphabeticpf}', "");
Expect(0, 64335, '\p{^Blk=alphabeticpf}', "");
Expect(0, 64335, '\P{Blk=alphabeticpf}', "");
Expect(1, 64335, '\P{^Blk=alphabeticpf}', "");
Expect(0, 64336, '\p{Blk=alphabeticpf}', "");
Expect(1, 64336, '\p{^Blk=alphabeticpf}', "");
Expect(1, 64336, '\P{Blk=alphabeticpf}', "");
Expect(0, 64336, '\P{^Blk=alphabeticpf}', "");
Expect(1, 64335, '\p{Blk=	_ALPHABETIC_pf}', "");
Expect(0, 64335, '\p{^Blk=	_ALPHABETIC_pf}', "");
Expect(0, 64335, '\P{Blk=	_ALPHABETIC_pf}', "");
Expect(1, 64335, '\P{^Blk=	_ALPHABETIC_pf}', "");
Expect(0, 64336, '\p{Blk=	_ALPHABETIC_pf}', "");
Expect(1, 64336, '\p{^Blk=	_ALPHABETIC_pf}', "");
Expect(1, 64336, '\P{Blk=	_ALPHABETIC_pf}', "");
Expect(0, 64336, '\P{^Blk=	_ALPHABETIC_pf}', "");
Error('\p{Is_Block= /a/Alphabetic_Presentation_Forms}');
Error('\P{Is_Block= /a/Alphabetic_Presentation_Forms}');
Expect(1, 64335, '\p{Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64335, '\P{Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\p{Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64336, '\P{Is_Block=alphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^Is_Block=alphabeticpresentationforms}', "");
Expect(1, 64335, '\p{Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(0, 64335, '\p{^Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(0, 64335, '\P{Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(1, 64335, '\P{^Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(0, 64336, '\p{Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(1, 64336, '\p{^Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(1, 64336, '\P{Is_Block= -Alphabetic_Presentation_FORMS}', "");
Expect(0, 64336, '\P{^Is_Block= -Alphabetic_Presentation_FORMS}', "");
Error('\p{Is_Blk:   /a/-alphabetic_PF}');
Error('\P{Is_Blk:   /a/-alphabetic_PF}');
Expect(1, 64335, '\p{Is_Blk=alphabeticpf}', "");
Expect(0, 64335, '\p{^Is_Blk=alphabeticpf}', "");
Expect(0, 64335, '\P{Is_Blk=alphabeticpf}', "");
Expect(1, 64335, '\P{^Is_Blk=alphabeticpf}', "");
Expect(0, 64336, '\p{Is_Blk=alphabeticpf}', "");
Expect(1, 64336, '\p{^Is_Blk=alphabeticpf}', "");
Expect(1, 64336, '\P{Is_Blk=alphabeticpf}', "");
Expect(0, 64336, '\P{^Is_Blk=alphabeticpf}', "");
Expect(1, 64335, '\p{Is_Blk=_alphabetic_pf}', "");
Expect(0, 64335, '\p{^Is_Blk=_alphabetic_pf}', "");
Expect(0, 64335, '\P{Is_Blk=_alphabetic_pf}', "");
Expect(1, 64335, '\P{^Is_Blk=_alphabetic_pf}', "");
Expect(0, 64336, '\p{Is_Blk=_alphabetic_pf}', "");
Expect(1, 64336, '\p{^Is_Blk=_alphabetic_pf}', "");
Expect(1, 64336, '\P{Is_Blk=_alphabetic_pf}', "");
Expect(0, 64336, '\P{^Is_Blk=_alphabetic_pf}', "");
Error('\p{Block=:=  Ancient_Greek_musical_notation}');
Error('\P{Block=:=  Ancient_Greek_musical_notation}');
Expect(1, 119375, '\p{Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{Block=_ancient_Greek_Musical_Notation}', "");
Expect(0, 119375, '\p{^Block=_ancient_Greek_Musical_Notation}', "");
Expect(0, 119375, '\P{Block=_ancient_Greek_Musical_Notation}', "");
Expect(1, 119375, '\P{^Block=_ancient_Greek_Musical_Notation}', "");
Expect(0, 119376, '\p{Block=_ancient_Greek_Musical_Notation}', "");
Expect(1, 119376, '\p{^Block=_ancient_Greek_Musical_Notation}', "");
Expect(1, 119376, '\P{Block=_ancient_Greek_Musical_Notation}', "");
Expect(0, 119376, '\P{^Block=_ancient_Greek_Musical_Notation}', "");
Error('\p{Blk=_ Ancient_Greek_music:=}');
Error('\P{Blk=_ Ancient_Greek_music:=}');
Expect(1, 119375, '\p{Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\p{^Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\P{Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\P{^Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\p{Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\p{^Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\P{Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\P{^Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\p{Blk= -Ancient_greek_Music}', "");
Expect(0, 119375, '\p{^Blk= -Ancient_greek_Music}', "");
Expect(0, 119375, '\P{Blk= -Ancient_greek_Music}', "");
Expect(1, 119375, '\P{^Blk= -Ancient_greek_Music}', "");
Expect(0, 119376, '\p{Blk= -Ancient_greek_Music}', "");
Expect(1, 119376, '\p{^Blk= -Ancient_greek_Music}', "");
Expect(1, 119376, '\P{Blk= -Ancient_greek_Music}', "");
Expect(0, 119376, '\P{^Blk= -Ancient_greek_Music}', "");
Error('\p{Is_Block=-	ANCIENT_GREEK_Musical_NOTATION/a/}');
Error('\P{Is_Block=-	ANCIENT_GREEK_Musical_NOTATION/a/}');
Expect(1, 119375, '\p{Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{Is_Block=ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^Is_Block=ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{Is_Block=Ancient_greek_musical_Notation}', "");
Expect(0, 119375, '\p{^Is_Block=Ancient_greek_musical_Notation}', "");
Expect(0, 119375, '\P{Is_Block=Ancient_greek_musical_Notation}', "");
Expect(1, 119375, '\P{^Is_Block=Ancient_greek_musical_Notation}', "");
Expect(0, 119376, '\p{Is_Block=Ancient_greek_musical_Notation}', "");
Expect(1, 119376, '\p{^Is_Block=Ancient_greek_musical_Notation}', "");
Expect(1, 119376, '\P{Is_Block=Ancient_greek_musical_Notation}', "");
Expect(0, 119376, '\P{^Is_Block=Ancient_greek_musical_Notation}', "");
Error('\p{Is_Blk=/a/		Ancient_greek_music}');
Error('\P{Is_Blk=/a/		Ancient_greek_music}');
Expect(1, 119375, '\p{Is_Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\p{^Is_Blk=ancientgreekmusic}', "");
Expect(0, 119375, '\P{Is_Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\P{^Is_Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\p{Is_Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\p{^Is_Blk=ancientgreekmusic}', "");
Expect(1, 119376, '\P{Is_Blk=ancientgreekmusic}', "");
Expect(0, 119376, '\P{^Is_Blk=ancientgreekmusic}', "");
Expect(1, 119375, '\p{Is_Blk=_ancient_GREEK_Music}', "");
Expect(0, 119375, '\p{^Is_Blk=_ancient_GREEK_Music}', "");
Expect(0, 119375, '\P{Is_Blk=_ancient_GREEK_Music}', "");
Expect(1, 119375, '\P{^Is_Blk=_ancient_GREEK_Music}', "");
Expect(0, 119376, '\p{Is_Blk=_ancient_GREEK_Music}', "");
Expect(1, 119376, '\p{^Is_Blk=_ancient_GREEK_Music}', "");
Expect(1, 119376, '\P{Is_Blk=_ancient_GREEK_Music}', "");
Expect(0, 119376, '\P{^Is_Blk=_ancient_GREEK_Music}', "");
Error('\p{Block=/a/	Ancient_greek_numbers}');
Error('\P{Block=/a/	Ancient_greek_numbers}');
Expect(1, 65935, '\p{Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Block=	ancient_greek_Numbers}', "");
Expect(0, 65935, '\p{^Block=	ancient_greek_Numbers}', "");
Expect(0, 65935, '\P{Block=	ancient_greek_Numbers}', "");
Expect(1, 65935, '\P{^Block=	ancient_greek_Numbers}', "");
Expect(0, 65936, '\p{Block=	ancient_greek_Numbers}', "");
Expect(1, 65936, '\p{^Block=	ancient_greek_Numbers}', "");
Expect(1, 65936, '\P{Block=	ancient_greek_Numbers}', "");
Expect(0, 65936, '\P{^Block=	ancient_greek_Numbers}', "");
Error('\p{Blk=-:=Ancient_greek_Numbers}');
Error('\P{Blk=-:=Ancient_greek_Numbers}');
Expect(1, 65935, '\p{Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Blk=-Ancient_GREEK_Numbers}', "");
Expect(0, 65935, '\p{^Blk=-Ancient_GREEK_Numbers}', "");
Expect(0, 65935, '\P{Blk=-Ancient_GREEK_Numbers}', "");
Expect(1, 65935, '\P{^Blk=-Ancient_GREEK_Numbers}', "");
Expect(0, 65936, '\p{Blk=-Ancient_GREEK_Numbers}', "");
Expect(1, 65936, '\p{^Blk=-Ancient_GREEK_Numbers}', "");
Expect(1, 65936, '\P{Blk=-Ancient_GREEK_Numbers}', "");
Expect(0, 65936, '\P{^Blk=-Ancient_GREEK_Numbers}', "");
Error('\p{Is_Block=	Ancient_Greek_Numbers:=}');
Error('\P{Is_Block=	Ancient_Greek_Numbers:=}');
Expect(1, 65935, '\p{Is_Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Is_Block=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Is_Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Is_Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Is_Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Is_Block=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Is_Block=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Is_Block=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(0, 65935, '\p{^Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(0, 65935, '\P{Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(1, 65935, '\P{^Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(0, 65936, '\p{Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(1, 65936, '\p{^Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(1, 65936, '\P{Is_Block: --Ancient_greek_NUMBERS}', "");
Expect(0, 65936, '\P{^Is_Block: --Ancient_greek_NUMBERS}', "");
Error('\p{Is_Blk= -Ancient_Greek_Numbers:=}');
Error('\P{Is_Blk= -Ancient_Greek_Numbers:=}');
Expect(1, 65935, '\p{Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65935, '\P{Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\p{Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65936, '\P{Is_Blk=ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^Is_Blk=ancientgreeknumbers}', "");
Expect(1, 65935, '\p{Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(0, 65935, '\p{^Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(0, 65935, '\P{Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(1, 65935, '\P{^Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(0, 65936, '\p{Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(1, 65936, '\p{^Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(1, 65936, '\P{Is_Blk=-_Ancient_GREEK_numbers}', "");
Expect(0, 65936, '\P{^Is_Blk=-_Ancient_GREEK_numbers}', "");
Error('\p{Block=-_Ancient_Symbols/a/}');
Error('\P{Block=-_Ancient_Symbols/a/}');
Expect(1, 65999, '\p{Block=ancientsymbols}', "");
Expect(0, 65999, '\p{^Block=ancientsymbols}', "");
Expect(0, 65999, '\P{Block=ancientsymbols}', "");
Expect(1, 65999, '\P{^Block=ancientsymbols}', "");
Expect(0, 66000, '\p{Block=ancientsymbols}', "");
Expect(1, 66000, '\p{^Block=ancientsymbols}', "");
Expect(1, 66000, '\P{Block=ancientsymbols}', "");
Expect(0, 66000, '\P{^Block=ancientsymbols}', "");
Expect(1, 65999, '\p{Block= ancient_SYMBOLS}', "");
Expect(0, 65999, '\p{^Block= ancient_SYMBOLS}', "");
Expect(0, 65999, '\P{Block= ancient_SYMBOLS}', "");
Expect(1, 65999, '\P{^Block= ancient_SYMBOLS}', "");
Expect(0, 66000, '\p{Block= ancient_SYMBOLS}', "");
Expect(1, 66000, '\p{^Block= ancient_SYMBOLS}', "");
Expect(1, 66000, '\P{Block= ancient_SYMBOLS}', "");
Expect(0, 66000, '\P{^Block= ancient_SYMBOLS}', "");
Error('\p{Blk=:=ANCIENT_symbols}');
Error('\P{Blk=:=ANCIENT_symbols}');
Expect(1, 65999, '\p{Blk:   ancientsymbols}', "");
Expect(0, 65999, '\p{^Blk:   ancientsymbols}', "");
Expect(0, 65999, '\P{Blk:   ancientsymbols}', "");
Expect(1, 65999, '\P{^Blk:   ancientsymbols}', "");
Expect(0, 66000, '\p{Blk:   ancientsymbols}', "");
Expect(1, 66000, '\p{^Blk:   ancientsymbols}', "");
Expect(1, 66000, '\P{Blk:   ancientsymbols}', "");
Expect(0, 66000, '\P{^Blk:   ancientsymbols}', "");
Expect(1, 65999, '\p{Blk: -ancient_Symbols}', "");
Expect(0, 65999, '\p{^Blk: -ancient_Symbols}', "");
Expect(0, 65999, '\P{Blk: -ancient_Symbols}', "");
Expect(1, 65999, '\P{^Blk: -ancient_Symbols}', "");
Expect(0, 66000, '\p{Blk: -ancient_Symbols}', "");
Expect(1, 66000, '\p{^Blk: -ancient_Symbols}', "");
Expect(1, 66000, '\P{Blk: -ancient_Symbols}', "");
Expect(0, 66000, '\P{^Blk: -ancient_Symbols}', "");
Error('\p{Is_Block=:=-ANCIENT_Symbols}');
Error('\P{Is_Block=:=-ANCIENT_Symbols}');
Expect(1, 65999, '\p{Is_Block=ancientsymbols}', "");
Expect(0, 65999, '\p{^Is_Block=ancientsymbols}', "");
Expect(0, 65999, '\P{Is_Block=ancientsymbols}', "");
Expect(1, 65999, '\P{^Is_Block=ancientsymbols}', "");
Expect(0, 66000, '\p{Is_Block=ancientsymbols}', "");
Expect(1, 66000, '\p{^Is_Block=ancientsymbols}', "");
Expect(1, 66000, '\P{Is_Block=ancientsymbols}', "");
Expect(0, 66000, '\P{^Is_Block=ancientsymbols}', "");
Expect(1, 65999, '\p{Is_Block= -ancient_SYMBOLS}', "");
Expect(0, 65999, '\p{^Is_Block= -ancient_SYMBOLS}', "");
Expect(0, 65999, '\P{Is_Block= -ancient_SYMBOLS}', "");
Expect(1, 65999, '\P{^Is_Block= -ancient_SYMBOLS}', "");
Expect(0, 66000, '\p{Is_Block= -ancient_SYMBOLS}', "");
Expect(1, 66000, '\p{^Is_Block= -ancient_SYMBOLS}', "");
Expect(1, 66000, '\P{Is_Block= -ancient_SYMBOLS}', "");
Expect(0, 66000, '\P{^Is_Block= -ancient_SYMBOLS}', "");
Error('\p{Is_Blk=__Ancient_Symbols:=}');
Error('\P{Is_Blk=__Ancient_Symbols:=}');
Expect(1, 65999, '\p{Is_Blk=ancientsymbols}', "");
Expect(0, 65999, '\p{^Is_Blk=ancientsymbols}', "");
Expect(0, 65999, '\P{Is_Blk=ancientsymbols}', "");
Expect(1, 65999, '\P{^Is_Blk=ancientsymbols}', "");
Expect(0, 66000, '\p{Is_Blk=ancientsymbols}', "");
Expect(1, 66000, '\p{^Is_Blk=ancientsymbols}', "");
Expect(1, 66000, '\P{Is_Blk=ancientsymbols}', "");
Expect(0, 66000, '\P{^Is_Blk=ancientsymbols}', "");
Expect(1, 65999, '\p{Is_Blk= 	Ancient_Symbols}', "");
Expect(0, 65999, '\p{^Is_Blk= 	Ancient_Symbols}', "");
Expect(0, 65999, '\P{Is_Blk= 	Ancient_Symbols}', "");
Expect(1, 65999, '\P{^Is_Blk= 	Ancient_Symbols}', "");
Expect(0, 66000, '\p{Is_Blk= 	Ancient_Symbols}', "");
Expect(1, 66000, '\p{^Is_Blk= 	Ancient_Symbols}', "");
Expect(1, 66000, '\P{Is_Blk= 	Ancient_Symbols}', "");
Expect(0, 66000, '\P{^Is_Blk= 	Ancient_Symbols}', "");
Error('\p{Block:   /a/_ARABIC}');
Error('\P{Block:   /a/_ARABIC}');
Expect(1, 1791, '\p{Block=arabic}', "");
Expect(0, 1791, '\p{^Block=arabic}', "");
Expect(0, 1791, '\P{Block=arabic}', "");
Expect(1, 1791, '\P{^Block=arabic}', "");
Expect(0, 1792, '\p{Block=arabic}', "");
Expect(1, 1792, '\p{^Block=arabic}', "");
Expect(1, 1792, '\P{Block=arabic}', "");
Expect(0, 1792, '\P{^Block=arabic}', "");
Expect(1, 1791, '\p{Block= Arabic}', "");
Expect(0, 1791, '\p{^Block= Arabic}', "");
Expect(0, 1791, '\P{Block= Arabic}', "");
Expect(1, 1791, '\P{^Block= Arabic}', "");
Expect(0, 1792, '\p{Block= Arabic}', "");
Expect(1, 1792, '\p{^Block= Arabic}', "");
Expect(1, 1792, '\P{Block= Arabic}', "");
Expect(0, 1792, '\P{^Block= Arabic}', "");
Error('\p{Blk=:= _Arabic}');
Error('\P{Blk=:= _Arabic}');
Expect(1, 1791, '\p{Blk=arabic}', "");
Expect(0, 1791, '\p{^Blk=arabic}', "");
Expect(0, 1791, '\P{Blk=arabic}', "");
Expect(1, 1791, '\P{^Blk=arabic}', "");
Expect(0, 1792, '\p{Blk=arabic}', "");
Expect(1, 1792, '\p{^Blk=arabic}', "");
Expect(1, 1792, '\P{Blk=arabic}', "");
Expect(0, 1792, '\P{^Blk=arabic}', "");
Expect(1, 1791, '\p{Blk= ARABIC}', "");
Expect(0, 1791, '\p{^Blk= ARABIC}', "");
Expect(0, 1791, '\P{Blk= ARABIC}', "");
Expect(1, 1791, '\P{^Blk= ARABIC}', "");
Expect(0, 1792, '\p{Blk= ARABIC}', "");
Expect(1, 1792, '\p{^Blk= ARABIC}', "");
Expect(1, 1792, '\P{Blk= ARABIC}', "");
Expect(0, 1792, '\P{^Blk= ARABIC}', "");
Error('\p{Is_Block=/a/Arabic}');
Error('\P{Is_Block=/a/Arabic}');
Expect(1, 1791, '\p{Is_Block=arabic}', "");
Expect(0, 1791, '\p{^Is_Block=arabic}', "");
Expect(0, 1791, '\P{Is_Block=arabic}', "");
Expect(1, 1791, '\P{^Is_Block=arabic}', "");
Expect(0, 1792, '\p{Is_Block=arabic}', "");
Expect(1, 1792, '\p{^Is_Block=arabic}', "");
Expect(1, 1792, '\P{Is_Block=arabic}', "");
Expect(0, 1792, '\P{^Is_Block=arabic}', "");
Expect(1, 1791, '\p{Is_Block=ARABIC}', "");
Expect(0, 1791, '\p{^Is_Block=ARABIC}', "");
Expect(0, 1791, '\P{Is_Block=ARABIC}', "");
Expect(1, 1791, '\P{^Is_Block=ARABIC}', "");
Expect(0, 1792, '\p{Is_Block=ARABIC}', "");
Expect(1, 1792, '\p{^Is_Block=ARABIC}', "");
Expect(1, 1792, '\P{Is_Block=ARABIC}', "");
Expect(0, 1792, '\P{^Is_Block=ARABIC}', "");
Error('\p{Is_Blk=/a/ -Arabic}');
Error('\P{Is_Blk=/a/ -Arabic}');
Expect(1, 1791, '\p{Is_Blk=arabic}', "");
Expect(0, 1791, '\p{^Is_Blk=arabic}', "");
Expect(0, 1791, '\P{Is_Blk=arabic}', "");
Expect(1, 1791, '\P{^Is_Blk=arabic}', "");
Expect(0, 1792, '\p{Is_Blk=arabic}', "");
Expect(1, 1792, '\p{^Is_Blk=arabic}', "");
Expect(1, 1792, '\P{Is_Blk=arabic}', "");
Expect(0, 1792, '\P{^Is_Blk=arabic}', "");
Expect(1, 1791, '\p{Is_Blk=_	arabic}', "");
Expect(0, 1791, '\p{^Is_Blk=_	arabic}', "");
Expect(0, 1791, '\P{Is_Blk=_	arabic}', "");
Expect(1, 1791, '\P{^Is_Blk=_	arabic}', "");
Expect(0, 1792, '\p{Is_Blk=_	arabic}', "");
Expect(1, 1792, '\p{^Is_Blk=_	arabic}', "");
Expect(1, 1792, '\P{Is_Blk=_	arabic}', "");
Expect(0, 1792, '\P{^Is_Blk=_	arabic}', "");
Error('\p{Block=_arabic_EXTENDED_A:=}');
Error('\P{Block=_arabic_EXTENDED_A:=}');
Expect(1, 2303, '\p{Block=arabicextendeda}', "");
Expect(0, 2303, '\p{^Block=arabicextendeda}', "");
Expect(0, 2303, '\P{Block=arabicextendeda}', "");
Expect(1, 2303, '\P{^Block=arabicextendeda}', "");
Expect(0, 2304, '\p{Block=arabicextendeda}', "");
Expect(1, 2304, '\p{^Block=arabicextendeda}', "");
Expect(1, 2304, '\P{Block=arabicextendeda}', "");
Expect(0, 2304, '\P{^Block=arabicextendeda}', "");
Expect(1, 2303, '\p{Block=-Arabic_Extended_A}', "");
Expect(0, 2303, '\p{^Block=-Arabic_Extended_A}', "");
Expect(0, 2303, '\P{Block=-Arabic_Extended_A}', "");
Expect(1, 2303, '\P{^Block=-Arabic_Extended_A}', "");
Expect(0, 2304, '\p{Block=-Arabic_Extended_A}', "");
Expect(1, 2304, '\p{^Block=-Arabic_Extended_A}', "");
Expect(1, 2304, '\P{Block=-Arabic_Extended_A}', "");
Expect(0, 2304, '\P{^Block=-Arabic_Extended_A}', "");
Error('\p{Blk=:= _Arabic_EXT_a}');
Error('\P{Blk=:= _Arabic_EXT_a}');
Expect(1, 2303, '\p{Blk=arabicexta}', "");
Expect(0, 2303, '\p{^Blk=arabicexta}', "");
Expect(0, 2303, '\P{Blk=arabicexta}', "");
Expect(1, 2303, '\P{^Blk=arabicexta}', "");
Expect(0, 2304, '\p{Blk=arabicexta}', "");
Expect(1, 2304, '\p{^Blk=arabicexta}', "");
Expect(1, 2304, '\P{Blk=arabicexta}', "");
Expect(0, 2304, '\P{^Blk=arabicexta}', "");
Expect(1, 2303, '\p{Blk=-arabic_Ext_a}', "");
Expect(0, 2303, '\p{^Blk=-arabic_Ext_a}', "");
Expect(0, 2303, '\P{Blk=-arabic_Ext_a}', "");
Expect(1, 2303, '\P{^Blk=-arabic_Ext_a}', "");
Expect(0, 2304, '\p{Blk=-arabic_Ext_a}', "");
Expect(1, 2304, '\p{^Blk=-arabic_Ext_a}', "");
Expect(1, 2304, '\P{Blk=-arabic_Ext_a}', "");
Expect(0, 2304, '\P{^Blk=-arabic_Ext_a}', "");
Error('\p{Is_Block=__arabic_Extended_a:=}');
Error('\P{Is_Block=__arabic_Extended_a:=}');
Expect(1, 2303, '\p{Is_Block=arabicextendeda}', "");
Expect(0, 2303, '\p{^Is_Block=arabicextendeda}', "");
Expect(0, 2303, '\P{Is_Block=arabicextendeda}', "");
Expect(1, 2303, '\P{^Is_Block=arabicextendeda}', "");
Expect(0, 2304, '\p{Is_Block=arabicextendeda}', "");
Expect(1, 2304, '\p{^Is_Block=arabicextendeda}', "");
Expect(1, 2304, '\P{Is_Block=arabicextendeda}', "");
Expect(0, 2304, '\P{^Is_Block=arabicextendeda}', "");
Expect(1, 2303, '\p{Is_Block=_-Arabic_extended_A}', "");
Expect(0, 2303, '\p{^Is_Block=_-Arabic_extended_A}', "");
Expect(0, 2303, '\P{Is_Block=_-Arabic_extended_A}', "");
Expect(1, 2303, '\P{^Is_Block=_-Arabic_extended_A}', "");
Expect(0, 2304, '\p{Is_Block=_-Arabic_extended_A}', "");
Expect(1, 2304, '\p{^Is_Block=_-Arabic_extended_A}', "");
Expect(1, 2304, '\P{Is_Block=_-Arabic_extended_A}', "");
Expect(0, 2304, '\P{^Is_Block=_-Arabic_extended_A}', "");
Error('\p{Is_Blk=/a/__Arabic_ext_A}');
Error('\P{Is_Blk=/a/__Arabic_ext_A}');
Expect(1, 2303, '\p{Is_Blk=arabicexta}', "");
Expect(0, 2303, '\p{^Is_Blk=arabicexta}', "");
Expect(0, 2303, '\P{Is_Blk=arabicexta}', "");
Expect(1, 2303, '\P{^Is_Blk=arabicexta}', "");
Expect(0, 2304, '\p{Is_Blk=arabicexta}', "");
Expect(1, 2304, '\p{^Is_Blk=arabicexta}', "");
Expect(1, 2304, '\P{Is_Blk=arabicexta}', "");
Expect(0, 2304, '\P{^Is_Blk=arabicexta}', "");
Expect(1, 2303, '\p{Is_Blk=  Arabic_Ext_A}', "");
Expect(0, 2303, '\p{^Is_Blk=  Arabic_Ext_A}', "");
Expect(0, 2303, '\P{Is_Blk=  Arabic_Ext_A}', "");
Expect(1, 2303, '\P{^Is_Blk=  Arabic_Ext_A}', "");
Expect(0, 2304, '\p{Is_Blk=  Arabic_Ext_A}', "");
Expect(1, 2304, '\p{^Is_Blk=  Arabic_Ext_A}', "");
Expect(1, 2304, '\P{Is_Blk=  Arabic_Ext_A}', "");
Expect(0, 2304, '\P{^Is_Blk=  Arabic_Ext_A}', "");
Error('\p{Block=:=__Arabic_mathematical_alphabetic_Symbols}');
Error('\P{Block=:=__Arabic_mathematical_alphabetic_Symbols}');
Expect(1, 126719, '\p{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{Block=arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^Block=arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(0, 126719, '\p{^Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(0, 126719, '\P{Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(1, 126719, '\P{^Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(0, 126720, '\p{Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(1, 126720, '\p{^Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(1, 126720, '\P{Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Expect(0, 126720, '\P{^Block=	 ARABIC_mathematical_alphabetic_Symbols}', "");
Error('\p{Blk=--Arabic_MATH/a/}');
Error('\P{Blk=--Arabic_MATH/a/}');
Expect(1, 126719, '\p{Blk=arabicmath}', "");
Expect(0, 126719, '\p{^Blk=arabicmath}', "");
Expect(0, 126719, '\P{Blk=arabicmath}', "");
Expect(1, 126719, '\P{^Blk=arabicmath}', "");
Expect(0, 126720, '\p{Blk=arabicmath}', "");
Expect(1, 126720, '\p{^Blk=arabicmath}', "");
Expect(1, 126720, '\P{Blk=arabicmath}', "");
Expect(0, 126720, '\P{^Blk=arabicmath}', "");
Expect(1, 126719, '\p{Blk= _ARABIC_Math}', "");
Expect(0, 126719, '\p{^Blk= _ARABIC_Math}', "");
Expect(0, 126719, '\P{Blk= _ARABIC_Math}', "");
Expect(1, 126719, '\P{^Blk= _ARABIC_Math}', "");
Expect(0, 126720, '\p{Blk= _ARABIC_Math}', "");
Expect(1, 126720, '\p{^Blk= _ARABIC_Math}', "");
Expect(1, 126720, '\P{Blk= _ARABIC_Math}', "");
Expect(0, 126720, '\P{^Blk= _ARABIC_Math}', "");
Error('\p{Is_Block=/a/_ARABIC_MATHEMATICAL_alphabetic_Symbols}');
Error('\P{Is_Block=/a/_ARABIC_MATHEMATICAL_alphabetic_Symbols}');
Expect(1, 126719, '\p{Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^Is_Block:arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126719, '\p{^Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126719, '\P{Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126719, '\P{^Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126720, '\p{Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126720, '\p{^Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(1, 126720, '\P{Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Expect(0, 126720, '\P{^Is_Block=Arabic_Mathematical_Alphabetic_Symbols}', "");
Error('\p{Is_Blk=:=  Arabic_Math}');
Error('\P{Is_Blk=:=  Arabic_Math}');
Expect(1, 126719, '\p{Is_Blk:arabicmath}', "");
Expect(0, 126719, '\p{^Is_Blk:arabicmath}', "");
Expect(0, 126719, '\P{Is_Blk:arabicmath}', "");
Expect(1, 126719, '\P{^Is_Blk:arabicmath}', "");
Expect(0, 126720, '\p{Is_Blk:arabicmath}', "");
Expect(1, 126720, '\p{^Is_Blk:arabicmath}', "");
Expect(1, 126720, '\P{Is_Blk:arabicmath}', "");
Expect(0, 126720, '\P{^Is_Blk:arabicmath}', "");
Expect(1, 126719, '\p{Is_Blk:   _Arabic_Math}', "");
Expect(0, 126719, '\p{^Is_Blk:   _Arabic_Math}', "");
Expect(0, 126719, '\P{Is_Blk:   _Arabic_Math}', "");
Expect(1, 126719, '\P{^Is_Blk:   _Arabic_Math}', "");
Expect(0, 126720, '\p{Is_Blk:   _Arabic_Math}', "");
Expect(1, 126720, '\p{^Is_Blk:   _Arabic_Math}', "");
Expect(1, 126720, '\P{Is_Blk:   _Arabic_Math}', "");
Expect(0, 126720, '\P{^Is_Blk:   _Arabic_Math}', "");
Error('\p{Block=:= _Arabic_PRESENTATION_FORMS_A}');
Error('\P{Block=:= _Arabic_PRESENTATION_FORMS_A}');
Expect(1, 65023, '\p{Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\p{^Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\P{Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\P{^Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\p{Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\p{^Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\P{Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\P{^Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\p{Block=- Arabic_Presentation_Forms_A}', "");
Expect(0, 65023, '\p{^Block=- Arabic_Presentation_Forms_A}', "");
Expect(0, 65023, '\P{Block=- Arabic_Presentation_Forms_A}', "");
Expect(1, 65023, '\P{^Block=- Arabic_Presentation_Forms_A}', "");
Expect(0, 65024, '\p{Block=- Arabic_Presentation_Forms_A}', "");
Expect(1, 65024, '\p{^Block=- Arabic_Presentation_Forms_A}', "");
Expect(1, 65024, '\P{Block=- Arabic_Presentation_Forms_A}', "");
Expect(0, 65024, '\P{^Block=- Arabic_Presentation_Forms_A}', "");
Error('\p{Blk=	/a/arabic_PF_A}');
Error('\P{Blk=	/a/arabic_PF_A}');
Expect(1, 65023, '\p{Blk=arabicpfa}', "");
Expect(0, 65023, '\p{^Blk=arabicpfa}', "");
Expect(0, 65023, '\P{Blk=arabicpfa}', "");
Expect(1, 65023, '\P{^Blk=arabicpfa}', "");
Expect(0, 65024, '\p{Blk=arabicpfa}', "");
Expect(1, 65024, '\p{^Blk=arabicpfa}', "");
Expect(1, 65024, '\P{Blk=arabicpfa}', "");
Expect(0, 65024, '\P{^Blk=arabicpfa}', "");
Expect(1, 65023, '\p{Blk= _Arabic_PF_a}', "");
Expect(0, 65023, '\p{^Blk= _Arabic_PF_a}', "");
Expect(0, 65023, '\P{Blk= _Arabic_PF_a}', "");
Expect(1, 65023, '\P{^Blk= _Arabic_PF_a}', "");
Expect(0, 65024, '\p{Blk= _Arabic_PF_a}', "");
Expect(1, 65024, '\p{^Blk= _Arabic_PF_a}', "");
Expect(1, 65024, '\P{Blk= _Arabic_PF_a}', "");
Expect(0, 65024, '\P{^Blk= _Arabic_PF_a}', "");
Error('\p{Is_Block=:=arabic_presentation_Forms_A}');
Error('\P{Is_Block=:=arabic_presentation_Forms_A}');
Expect(1, 65023, '\p{Is_Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\p{^Is_Block=arabicpresentationformsa}', "");
Expect(0, 65023, '\P{Is_Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\P{^Is_Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\p{Is_Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\p{^Is_Block=arabicpresentationformsa}', "");
Expect(1, 65024, '\P{Is_Block=arabicpresentationformsa}', "");
Expect(0, 65024, '\P{^Is_Block=arabicpresentationformsa}', "");
Expect(1, 65023, '\p{Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(0, 65023, '\p{^Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(0, 65023, '\P{Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(1, 65023, '\P{^Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(0, 65024, '\p{Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(1, 65024, '\p{^Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(1, 65024, '\P{Is_Block= 	Arabic_Presentation_forms_a}', "");
Expect(0, 65024, '\P{^Is_Block= 	Arabic_Presentation_forms_a}', "");
Error('\p{Is_Blk=_	Arabic_PF_a:=}');
Error('\P{Is_Blk=_	Arabic_PF_a:=}');
Expect(1, 65023, '\p{Is_Blk=arabicpfa}', "");
Expect(0, 65023, '\p{^Is_Blk=arabicpfa}', "");
Expect(0, 65023, '\P{Is_Blk=arabicpfa}', "");
Expect(1, 65023, '\P{^Is_Blk=arabicpfa}', "");
Expect(0, 65024, '\p{Is_Blk=arabicpfa}', "");
Expect(1, 65024, '\p{^Is_Blk=arabicpfa}', "");
Expect(1, 65024, '\P{Is_Blk=arabicpfa}', "");
Expect(0, 65024, '\P{^Is_Blk=arabicpfa}', "");
Expect(1, 65023, '\p{Is_Blk= _arabic_PF_a}', "");
Expect(0, 65023, '\p{^Is_Blk= _arabic_PF_a}', "");
Expect(0, 65023, '\P{Is_Blk= _arabic_PF_a}', "");
Expect(1, 65023, '\P{^Is_Blk= _arabic_PF_a}', "");
Expect(0, 65024, '\p{Is_Blk= _arabic_PF_a}', "");
Expect(1, 65024, '\p{^Is_Blk= _arabic_PF_a}', "");
Expect(1, 65024, '\P{Is_Blk= _arabic_PF_a}', "");
Expect(0, 65024, '\P{^Is_Blk= _arabic_PF_a}', "");
Error('\p{Block=	Arabic_PRESENTATION_FORMS_B:=}');
Error('\P{Block=	Arabic_PRESENTATION_FORMS_B:=}');
Expect(1, 65279, '\p{Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\p{^Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\P{Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\P{^Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\p{Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\p{^Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\P{Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\P{^Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\p{Block=	_arabic_presentation_forms_B}', "");
Expect(0, 65279, '\p{^Block=	_arabic_presentation_forms_B}', "");
Expect(0, 65279, '\P{Block=	_arabic_presentation_forms_B}', "");
Expect(1, 65279, '\P{^Block=	_arabic_presentation_forms_B}', "");
Expect(0, 65280, '\p{Block=	_arabic_presentation_forms_B}', "");
Expect(1, 65280, '\p{^Block=	_arabic_presentation_forms_B}', "");
Expect(1, 65280, '\P{Block=	_arabic_presentation_forms_B}', "");
Expect(0, 65280, '\P{^Block=	_arabic_presentation_forms_B}', "");
Error('\p{Blk::= -ARABIC_PF_B}');
Error('\P{Blk::= -ARABIC_PF_B}');
Expect(1, 65279, '\p{Blk: arabicpfb}', "");
Expect(0, 65279, '\p{^Blk: arabicpfb}', "");
Expect(0, 65279, '\P{Blk: arabicpfb}', "");
Expect(1, 65279, '\P{^Blk: arabicpfb}', "");
Expect(0, 65280, '\p{Blk: arabicpfb}', "");
Expect(1, 65280, '\p{^Blk: arabicpfb}', "");
Expect(1, 65280, '\P{Blk: arabicpfb}', "");
Expect(0, 65280, '\P{^Blk: arabicpfb}', "");
Expect(1, 65279, '\p{Blk=_Arabic_PF_B}', "");
Expect(0, 65279, '\p{^Blk=_Arabic_PF_B}', "");
Expect(0, 65279, '\P{Blk=_Arabic_PF_B}', "");
Expect(1, 65279, '\P{^Blk=_Arabic_PF_B}', "");
Expect(0, 65280, '\p{Blk=_Arabic_PF_B}', "");
Expect(1, 65280, '\p{^Blk=_Arabic_PF_B}', "");
Expect(1, 65280, '\P{Blk=_Arabic_PF_B}', "");
Expect(0, 65280, '\P{^Blk=_Arabic_PF_B}', "");
Error('\p{Is_Block= :=ARABIC_presentation_Forms_B}');
Error('\P{Is_Block= :=ARABIC_presentation_Forms_B}');
Expect(1, 65279, '\p{Is_Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\p{^Is_Block=arabicpresentationformsb}', "");
Expect(0, 65279, '\P{Is_Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\P{^Is_Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\p{Is_Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\p{^Is_Block=arabicpresentationformsb}', "");
Expect(1, 65280, '\P{Is_Block=arabicpresentationformsb}', "");
Expect(0, 65280, '\P{^Is_Block=arabicpresentationformsb}', "");
Expect(1, 65279, '\p{Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(0, 65279, '\p{^Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(0, 65279, '\P{Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(1, 65279, '\P{^Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(0, 65280, '\p{Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(1, 65280, '\p{^Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(1, 65280, '\P{Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Expect(0, 65280, '\P{^Is_Block:   __ARABIC_PRESENTATION_forms_b}', "");
Error('\p{Is_Blk=:=ARABIC_PF_B}');
Error('\P{Is_Blk=:=ARABIC_PF_B}');
Expect(1, 65279, '\p{Is_Blk=arabicpfb}', "");
Expect(0, 65279, '\p{^Is_Blk=arabicpfb}', "");
Expect(0, 65279, '\P{Is_Blk=arabicpfb}', "");
Expect(1, 65279, '\P{^Is_Blk=arabicpfb}', "");
Expect(0, 65280, '\p{Is_Blk=arabicpfb}', "");
Expect(1, 65280, '\p{^Is_Blk=arabicpfb}', "");
Expect(1, 65280, '\P{Is_Blk=arabicpfb}', "");
Expect(0, 65280, '\P{^Is_Blk=arabicpfb}', "");
Expect(1, 65279, '\p{Is_Blk=  arabic_PF_B}', "");
Expect(0, 65279, '\p{^Is_Blk=  arabic_PF_B}', "");
Expect(0, 65279, '\P{Is_Blk=  arabic_PF_B}', "");
Expect(1, 65279, '\P{^Is_Blk=  arabic_PF_B}', "");
Expect(0, 65280, '\p{Is_Blk=  arabic_PF_B}', "");
Expect(1, 65280, '\p{^Is_Blk=  arabic_PF_B}', "");
Expect(1, 65280, '\P{Is_Blk=  arabic_PF_B}', "");
Expect(0, 65280, '\P{^Is_Blk=  arabic_PF_B}', "");
Error('\p{Block=_Arabic_supplement:=}');
Error('\P{Block=_Arabic_supplement:=}');
Expect(1, 1919, '\p{Block=arabicsupplement}', "");
Expect(0, 1919, '\p{^Block=arabicsupplement}', "");
Expect(0, 1919, '\P{Block=arabicsupplement}', "");
Expect(1, 1919, '\P{^Block=arabicsupplement}', "");
Expect(0, 1920, '\p{Block=arabicsupplement}', "");
Expect(1, 1920, '\p{^Block=arabicsupplement}', "");
Expect(1, 1920, '\P{Block=arabicsupplement}', "");
Expect(0, 1920, '\P{^Block=arabicsupplement}', "");
Expect(1, 1919, '\p{Block= -Arabic_supplement}', "");
Expect(0, 1919, '\p{^Block= -Arabic_supplement}', "");
Expect(0, 1919, '\P{Block= -Arabic_supplement}', "");
Expect(1, 1919, '\P{^Block= -Arabic_supplement}', "");
Expect(0, 1920, '\p{Block= -Arabic_supplement}', "");
Expect(1, 1920, '\p{^Block= -Arabic_supplement}', "");
Expect(1, 1920, '\P{Block= -Arabic_supplement}', "");
Expect(0, 1920, '\P{^Block= -Arabic_supplement}', "");
Error('\p{Blk= 	Arabic_Sup:=}');
Error('\P{Blk= 	Arabic_Sup:=}');
Expect(1, 1919, '\p{Blk=arabicsup}', "");
Expect(0, 1919, '\p{^Blk=arabicsup}', "");
Expect(0, 1919, '\P{Blk=arabicsup}', "");
Expect(1, 1919, '\P{^Blk=arabicsup}', "");
Expect(0, 1920, '\p{Blk=arabicsup}', "");
Expect(1, 1920, '\p{^Blk=arabicsup}', "");
Expect(1, 1920, '\P{Blk=arabicsup}', "");
Expect(0, 1920, '\P{^Blk=arabicsup}', "");
Expect(1, 1919, '\p{Blk=_ Arabic_Sup}', "");
Expect(0, 1919, '\p{^Blk=_ Arabic_Sup}', "");
Expect(0, 1919, '\P{Blk=_ Arabic_Sup}', "");
Expect(1, 1919, '\P{^Blk=_ Arabic_Sup}', "");
Expect(0, 1920, '\p{Blk=_ Arabic_Sup}', "");
Expect(1, 1920, '\p{^Blk=_ Arabic_Sup}', "");
Expect(1, 1920, '\P{Blk=_ Arabic_Sup}', "");
Expect(0, 1920, '\P{^Blk=_ Arabic_Sup}', "");
Error('\p{Is_Block= arabic_supplement:=}');
Error('\P{Is_Block= arabic_supplement:=}');
Expect(1, 1919, '\p{Is_Block=arabicsupplement}', "");
Expect(0, 1919, '\p{^Is_Block=arabicsupplement}', "");
Expect(0, 1919, '\P{Is_Block=arabicsupplement}', "");
Expect(1, 1919, '\P{^Is_Block=arabicsupplement}', "");
Expect(0, 1920, '\p{Is_Block=arabicsupplement}', "");
Expect(1, 1920, '\p{^Is_Block=arabicsupplement}', "");
Expect(1, 1920, '\P{Is_Block=arabicsupplement}', "");
Expect(0, 1920, '\P{^Is_Block=arabicsupplement}', "");
Expect(1, 1919, '\p{Is_Block: __arabic_supplement}', "");
Expect(0, 1919, '\p{^Is_Block: __arabic_supplement}', "");
Expect(0, 1919, '\P{Is_Block: __arabic_supplement}', "");
Expect(1, 1919, '\P{^Is_Block: __arabic_supplement}', "");
Expect(0, 1920, '\p{Is_Block: __arabic_supplement}', "");
Expect(1, 1920, '\p{^Is_Block: __arabic_supplement}', "");
Expect(1, 1920, '\P{Is_Block: __arabic_supplement}', "");
Expect(0, 1920, '\P{^Is_Block: __arabic_supplement}', "");
Error('\p{Is_Blk=/a/_-arabic_Sup}');
Error('\P{Is_Blk=/a/_-arabic_Sup}');
Expect(1, 1919, '\p{Is_Blk=arabicsup}', "");
Expect(0, 1919, '\p{^Is_Blk=arabicsup}', "");
Expect(0, 1919, '\P{Is_Blk=arabicsup}', "");
Expect(1, 1919, '\P{^Is_Blk=arabicsup}', "");
Expect(0, 1920, '\p{Is_Blk=arabicsup}', "");
Expect(1, 1920, '\p{^Is_Blk=arabicsup}', "");
Expect(1, 1920, '\P{Is_Blk=arabicsup}', "");
Expect(0, 1920, '\P{^Is_Blk=arabicsup}', "");
Expect(1, 1919, '\p{Is_Blk=	_arabic_Sup}', "");
Expect(0, 1919, '\p{^Is_Blk=	_arabic_Sup}', "");
Expect(0, 1919, '\P{Is_Blk=	_arabic_Sup}', "");
Expect(1, 1919, '\P{^Is_Blk=	_arabic_Sup}', "");
Expect(0, 1920, '\p{Is_Blk=	_arabic_Sup}', "");
Expect(1, 1920, '\p{^Is_Blk=	_arabic_Sup}', "");
Expect(1, 1920, '\P{Is_Blk=	_arabic_Sup}', "");
Expect(0, 1920, '\P{^Is_Blk=	_arabic_Sup}', "");
Error('\p{Block= :=ARMENIAN}');
Error('\P{Block= :=ARMENIAN}');
Expect(1, 1423, '\p{Block=armenian}', "");
Expect(0, 1423, '\p{^Block=armenian}', "");
Expect(0, 1423, '\P{Block=armenian}', "");
Expect(1, 1423, '\P{^Block=armenian}', "");
Expect(0, 1424, '\p{Block=armenian}', "");
Expect(1, 1424, '\p{^Block=armenian}', "");
Expect(1, 1424, '\P{Block=armenian}', "");
Expect(0, 1424, '\P{^Block=armenian}', "");
Expect(1, 1423, '\p{Block= 	Armenian}', "");
Expect(0, 1423, '\p{^Block= 	Armenian}', "");
Expect(0, 1423, '\P{Block= 	Armenian}', "");
Expect(1, 1423, '\P{^Block= 	Armenian}', "");
Expect(0, 1424, '\p{Block= 	Armenian}', "");
Expect(1, 1424, '\p{^Block= 	Armenian}', "");
Expect(1, 1424, '\P{Block= 	Armenian}', "");
Expect(0, 1424, '\P{^Block= 	Armenian}', "");
Error('\p{Blk=		Armenian:=}');
Error('\P{Blk=		Armenian:=}');
Expect(1, 1423, '\p{Blk=armenian}', "");
Expect(0, 1423, '\p{^Blk=armenian}', "");
Expect(0, 1423, '\P{Blk=armenian}', "");
Expect(1, 1423, '\P{^Blk=armenian}', "");
Expect(0, 1424, '\p{Blk=armenian}', "");
Expect(1, 1424, '\p{^Blk=armenian}', "");
Expect(1, 1424, '\P{Blk=armenian}', "");
Expect(0, 1424, '\P{^Blk=armenian}', "");
Expect(1, 1423, '\p{Blk= _ARMENIAN}', "");
Expect(0, 1423, '\p{^Blk= _ARMENIAN}', "");
Expect(0, 1423, '\P{Blk= _ARMENIAN}', "");
Expect(1, 1423, '\P{^Blk= _ARMENIAN}', "");
Expect(0, 1424, '\p{Blk= _ARMENIAN}', "");
Expect(1, 1424, '\p{^Blk= _ARMENIAN}', "");
Expect(1, 1424, '\P{Blk= _ARMENIAN}', "");
Expect(0, 1424, '\P{^Blk= _ARMENIAN}', "");
Error('\p{Is_Block=/a/armenian}');
Error('\P{Is_Block=/a/armenian}');
Expect(1, 1423, '\p{Is_Block=armenian}', "");
Expect(0, 1423, '\p{^Is_Block=armenian}', "");
Expect(0, 1423, '\P{Is_Block=armenian}', "");
Expect(1, 1423, '\P{^Is_Block=armenian}', "");
Expect(0, 1424, '\p{Is_Block=armenian}', "");
Expect(1, 1424, '\p{^Is_Block=armenian}', "");
Expect(1, 1424, '\P{Is_Block=armenian}', "");
Expect(0, 1424, '\P{^Is_Block=armenian}', "");
Expect(1, 1423, '\p{Is_Block= Armenian}', "");
Expect(0, 1423, '\p{^Is_Block= Armenian}', "");
Expect(0, 1423, '\P{Is_Block= Armenian}', "");
Expect(1, 1423, '\P{^Is_Block= Armenian}', "");
Expect(0, 1424, '\p{Is_Block= Armenian}', "");
Expect(1, 1424, '\p{^Is_Block= Armenian}', "");
Expect(1, 1424, '\P{Is_Block= Armenian}', "");
Expect(0, 1424, '\P{^Is_Block= Armenian}', "");
Error('\p{Is_Blk=_ Armenian:=}');
Error('\P{Is_Blk=_ Armenian:=}');
Expect(1, 1423, '\p{Is_Blk=armenian}', "");
Expect(0, 1423, '\p{^Is_Blk=armenian}', "");
Expect(0, 1423, '\P{Is_Blk=armenian}', "");
Expect(1, 1423, '\P{^Is_Blk=armenian}', "");
Expect(0, 1424, '\p{Is_Blk=armenian}', "");
Expect(1, 1424, '\p{^Is_Blk=armenian}', "");
Expect(1, 1424, '\P{Is_Blk=armenian}', "");
Expect(0, 1424, '\P{^Is_Blk=armenian}', "");
Expect(1, 1423, '\p{Is_Blk= 	ARMENIAN}', "");
Expect(0, 1423, '\p{^Is_Blk= 	ARMENIAN}', "");
Expect(0, 1423, '\P{Is_Blk= 	ARMENIAN}', "");
Expect(1, 1423, '\P{^Is_Blk= 	ARMENIAN}', "");
Expect(0, 1424, '\p{Is_Blk= 	ARMENIAN}', "");
Expect(1, 1424, '\p{^Is_Blk= 	ARMENIAN}', "");
Expect(1, 1424, '\P{Is_Blk= 	ARMENIAN}', "");
Expect(0, 1424, '\P{^Is_Blk= 	ARMENIAN}', "");
Error('\p{Block=_:=Arrows}');
Error('\P{Block=_:=Arrows}');
Expect(1, 8703, '\p{Block=arrows}', "");
Expect(0, 8703, '\p{^Block=arrows}', "");
Expect(0, 8703, '\P{Block=arrows}', "");
Expect(1, 8703, '\P{^Block=arrows}', "");
Expect(0, 8704, '\p{Block=arrows}', "");
Expect(1, 8704, '\p{^Block=arrows}', "");
Expect(1, 8704, '\P{Block=arrows}', "");
Expect(0, 8704, '\P{^Block=arrows}', "");
Expect(1, 8703, '\p{Block=	Arrows}', "");
Expect(0, 8703, '\p{^Block=	Arrows}', "");
Expect(0, 8703, '\P{Block=	Arrows}', "");
Expect(1, 8703, '\P{^Block=	Arrows}', "");
Expect(0, 8704, '\p{Block=	Arrows}', "");
Expect(1, 8704, '\p{^Block=	Arrows}', "");
Expect(1, 8704, '\P{Block=	Arrows}', "");
Expect(0, 8704, '\P{^Block=	Arrows}', "");
Error('\p{Blk=-/a/ARROWS}');
Error('\P{Blk=-/a/ARROWS}');
Expect(1, 8703, '\p{Blk:   arrows}', "");
Expect(0, 8703, '\p{^Blk:   arrows}', "");
Expect(0, 8703, '\P{Blk:   arrows}', "");
Expect(1, 8703, '\P{^Blk:   arrows}', "");
Expect(0, 8704, '\p{Blk:   arrows}', "");
Expect(1, 8704, '\p{^Blk:   arrows}', "");
Expect(1, 8704, '\P{Blk:   arrows}', "");
Expect(0, 8704, '\P{^Blk:   arrows}', "");
Expect(1, 8703, '\p{Blk:   	 arrows}', "");
Expect(0, 8703, '\p{^Blk:   	 arrows}', "");
Expect(0, 8703, '\P{Blk:   	 arrows}', "");
Expect(1, 8703, '\P{^Blk:   	 arrows}', "");
Expect(0, 8704, '\p{Blk:   	 arrows}', "");
Expect(1, 8704, '\p{^Blk:   	 arrows}', "");
Expect(1, 8704, '\P{Blk:   	 arrows}', "");
Expect(0, 8704, '\P{^Blk:   	 arrows}', "");
Error('\p{Is_Block:   --Arrows:=}');
Error('\P{Is_Block:   --Arrows:=}');
Expect(1, 8703, '\p{Is_Block=arrows}', "");
Expect(0, 8703, '\p{^Is_Block=arrows}', "");
Expect(0, 8703, '\P{Is_Block=arrows}', "");
Expect(1, 8703, '\P{^Is_Block=arrows}', "");
Expect(0, 8704, '\p{Is_Block=arrows}', "");
Expect(1, 8704, '\p{^Is_Block=arrows}', "");
Expect(1, 8704, '\P{Is_Block=arrows}', "");
Expect(0, 8704, '\P{^Is_Block=arrows}', "");
Expect(1, 8703, '\p{Is_Block= -ARROWS}', "");
Expect(0, 8703, '\p{^Is_Block= -ARROWS}', "");
Expect(0, 8703, '\P{Is_Block= -ARROWS}', "");
Expect(1, 8703, '\P{^Is_Block= -ARROWS}', "");
Expect(0, 8704, '\p{Is_Block= -ARROWS}', "");
Expect(1, 8704, '\p{^Is_Block= -ARROWS}', "");
Expect(1, 8704, '\P{Is_Block= -ARROWS}', "");
Expect(0, 8704, '\P{^Is_Block= -ARROWS}', "");
Error('\p{Is_Blk=-:=Arrows}');
Error('\P{Is_Blk=-:=Arrows}');
Expect(1, 8703, '\p{Is_Blk:	arrows}', "");
Expect(0, 8703, '\p{^Is_Blk:	arrows}', "");
Expect(0, 8703, '\P{Is_Blk:	arrows}', "");
Expect(1, 8703, '\P{^Is_Blk:	arrows}', "");
Expect(0, 8704, '\p{Is_Blk:	arrows}', "");
Expect(1, 8704, '\p{^Is_Blk:	arrows}', "");
Expect(1, 8704, '\P{Is_Blk:	arrows}', "");
Expect(0, 8704, '\P{^Is_Blk:	arrows}', "");
Expect(1, 8703, '\p{Is_Blk=_ Arrows}', "");
Expect(0, 8703, '\p{^Is_Blk=_ Arrows}', "");
Expect(0, 8703, '\P{Is_Blk=_ Arrows}', "");
Expect(1, 8703, '\P{^Is_Blk=_ Arrows}', "");
Expect(0, 8704, '\p{Is_Blk=_ Arrows}', "");
Expect(1, 8704, '\p{^Is_Blk=_ Arrows}', "");
Expect(1, 8704, '\P{Is_Blk=_ Arrows}', "");
Expect(0, 8704, '\P{^Is_Blk=_ Arrows}', "");
Error('\p{Block:	Avestan:=}');
Error('\P{Block:	Avestan:=}');
Expect(1, 68415, '\p{Block=avestan}', "");
Expect(0, 68415, '\p{^Block=avestan}', "");
Expect(0, 68415, '\P{Block=avestan}', "");
Expect(1, 68415, '\P{^Block=avestan}', "");
Expect(0, 68416, '\p{Block=avestan}', "");
Expect(1, 68416, '\p{^Block=avestan}', "");
Expect(1, 68416, '\P{Block=avestan}', "");
Expect(0, 68416, '\P{^Block=avestan}', "");
Expect(1, 68415, '\p{Block=	_Avestan}', "");
Expect(0, 68415, '\p{^Block=	_Avestan}', "");
Expect(0, 68415, '\P{Block=	_Avestan}', "");
Expect(1, 68415, '\P{^Block=	_Avestan}', "");
Expect(0, 68416, '\p{Block=	_Avestan}', "");
Expect(1, 68416, '\p{^Block=	_Avestan}', "");
Expect(1, 68416, '\P{Block=	_Avestan}', "");
Expect(0, 68416, '\P{^Block=	_Avestan}', "");
Error('\p{Blk=__AVESTAN:=}');
Error('\P{Blk=__AVESTAN:=}');
Expect(1, 68415, '\p{Blk=avestan}', "");
Expect(0, 68415, '\p{^Blk=avestan}', "");
Expect(0, 68415, '\P{Blk=avestan}', "");
Expect(1, 68415, '\P{^Blk=avestan}', "");
Expect(0, 68416, '\p{Blk=avestan}', "");
Expect(1, 68416, '\p{^Blk=avestan}', "");
Expect(1, 68416, '\P{Blk=avestan}', "");
Expect(0, 68416, '\P{^Blk=avestan}', "");
Expect(1, 68415, '\p{Blk= AVESTAN}', "");
Expect(0, 68415, '\p{^Blk= AVESTAN}', "");
Expect(0, 68415, '\P{Blk= AVESTAN}', "");
Expect(1, 68415, '\P{^Blk= AVESTAN}', "");
Expect(0, 68416, '\p{Blk= AVESTAN}', "");
Expect(1, 68416, '\p{^Blk= AVESTAN}', "");
Expect(1, 68416, '\P{Blk= AVESTAN}', "");
Expect(0, 68416, '\P{^Blk= AVESTAN}', "");
Error('\p{Is_Block=-/a/AVESTAN}');
Error('\P{Is_Block=-/a/AVESTAN}');
Expect(1, 68415, '\p{Is_Block=avestan}', "");
Expect(0, 68415, '\p{^Is_Block=avestan}', "");
Expect(0, 68415, '\P{Is_Block=avestan}', "");
Expect(1, 68415, '\P{^Is_Block=avestan}', "");
Expect(0, 68416, '\p{Is_Block=avestan}', "");
Expect(1, 68416, '\p{^Is_Block=avestan}', "");
Expect(1, 68416, '\P{Is_Block=avestan}', "");
Expect(0, 68416, '\P{^Is_Block=avestan}', "");
Expect(1, 68415, '\p{Is_Block:   _	Avestan}', "");
Expect(0, 68415, '\p{^Is_Block:   _	Avestan}', "");
Expect(0, 68415, '\P{Is_Block:   _	Avestan}', "");
Expect(1, 68415, '\P{^Is_Block:   _	Avestan}', "");
Expect(0, 68416, '\p{Is_Block:   _	Avestan}', "");
Expect(1, 68416, '\p{^Is_Block:   _	Avestan}', "");
Expect(1, 68416, '\P{Is_Block:   _	Avestan}', "");
Expect(0, 68416, '\P{^Is_Block:   _	Avestan}', "");
Error('\p{Is_Blk=_-Avestan:=}');
Error('\P{Is_Blk=_-Avestan:=}');
Expect(1, 68415, '\p{Is_Blk=avestan}', "");
Expect(0, 68415, '\p{^Is_Blk=avestan}', "");
Expect(0, 68415, '\P{Is_Blk=avestan}', "");
Expect(1, 68415, '\P{^Is_Blk=avestan}', "");
Expect(0, 68416, '\p{Is_Blk=avestan}', "");
Expect(1, 68416, '\p{^Is_Blk=avestan}', "");
Expect(1, 68416, '\P{Is_Blk=avestan}', "");
Expect(0, 68416, '\P{^Is_Blk=avestan}', "");
Expect(1, 68415, '\p{Is_Blk=_avestan}', "");
Expect(0, 68415, '\p{^Is_Blk=_avestan}', "");
Expect(0, 68415, '\P{Is_Blk=_avestan}', "");
Expect(1, 68415, '\P{^Is_Blk=_avestan}', "");
Expect(0, 68416, '\p{Is_Blk=_avestan}', "");
Expect(1, 68416, '\p{^Is_Blk=_avestan}', "");
Expect(1, 68416, '\P{Is_Blk=_avestan}', "");
Expect(0, 68416, '\P{^Is_Blk=_avestan}', "");
Error('\p{Block=/a/-	Balinese}');
Error('\P{Block=/a/-	Balinese}');
Expect(1, 7039, '\p{Block=balinese}', "");
Expect(0, 7039, '\p{^Block=balinese}', "");
Expect(0, 7039, '\P{Block=balinese}', "");
Expect(1, 7039, '\P{^Block=balinese}', "");
Expect(0, 7040, '\p{Block=balinese}', "");
Expect(1, 7040, '\p{^Block=balinese}', "");
Expect(1, 7040, '\P{Block=balinese}', "");
Expect(0, 7040, '\P{^Block=balinese}', "");
Expect(1, 7039, '\p{Block=		Balinese}', "");
Expect(0, 7039, '\p{^Block=		Balinese}', "");
Expect(0, 7039, '\P{Block=		Balinese}', "");
Expect(1, 7039, '\P{^Block=		Balinese}', "");
Expect(0, 7040, '\p{Block=		Balinese}', "");
Expect(1, 7040, '\p{^Block=		Balinese}', "");
Expect(1, 7040, '\P{Block=		Balinese}', "");
Expect(0, 7040, '\P{^Block=		Balinese}', "");
Error('\p{Blk=__Balinese:=}');
Error('\P{Blk=__Balinese:=}');
Expect(1, 7039, '\p{Blk=balinese}', "");
Expect(0, 7039, '\p{^Blk=balinese}', "");
Expect(0, 7039, '\P{Blk=balinese}', "");
Expect(1, 7039, '\P{^Blk=balinese}', "");
Expect(0, 7040, '\p{Blk=balinese}', "");
Expect(1, 7040, '\p{^Blk=balinese}', "");
Expect(1, 7040, '\P{Blk=balinese}', "");
Expect(0, 7040, '\P{^Blk=balinese}', "");
Expect(1, 7039, '\p{Blk=  Balinese}', "");
Expect(0, 7039, '\p{^Blk=  Balinese}', "");
Expect(0, 7039, '\P{Blk=  Balinese}', "");
Expect(1, 7039, '\P{^Blk=  Balinese}', "");
Expect(0, 7040, '\p{Blk=  Balinese}', "");
Expect(1, 7040, '\p{^Blk=  Balinese}', "");
Expect(1, 7040, '\P{Blk=  Balinese}', "");
Expect(0, 7040, '\P{^Blk=  Balinese}', "");
Error('\p{Is_Block=/a/-	balinese}');
Error('\P{Is_Block=/a/-	balinese}');
Expect(1, 7039, '\p{Is_Block=balinese}', "");
Expect(0, 7039, '\p{^Is_Block=balinese}', "");
Expect(0, 7039, '\P{Is_Block=balinese}', "");
Expect(1, 7039, '\P{^Is_Block=balinese}', "");
Expect(0, 7040, '\p{Is_Block=balinese}', "");
Expect(1, 7040, '\p{^Is_Block=balinese}', "");
Expect(1, 7040, '\P{Is_Block=balinese}', "");
Expect(0, 7040, '\P{^Is_Block=balinese}', "");
Expect(1, 7039, '\p{Is_Block=	-Balinese}', "");
Expect(0, 7039, '\p{^Is_Block=	-Balinese}', "");
Expect(0, 7039, '\P{Is_Block=	-Balinese}', "");
Expect(1, 7039, '\P{^Is_Block=	-Balinese}', "");
Expect(0, 7040, '\p{Is_Block=	-Balinese}', "");
Expect(1, 7040, '\p{^Is_Block=	-Balinese}', "");
Expect(1, 7040, '\P{Is_Block=	-Balinese}', "");
Expect(0, 7040, '\P{^Is_Block=	-Balinese}', "");
Error('\p{Is_Blk=/a/-	Balinese}');
Error('\P{Is_Blk=/a/-	Balinese}');
Expect(1, 7039, '\p{Is_Blk: balinese}', "");
Expect(0, 7039, '\p{^Is_Blk: balinese}', "");
Expect(0, 7039, '\P{Is_Blk: balinese}', "");
Expect(1, 7039, '\P{^Is_Blk: balinese}', "");
Expect(0, 7040, '\p{Is_Blk: balinese}', "");
Expect(1, 7040, '\p{^Is_Blk: balinese}', "");
Expect(1, 7040, '\P{Is_Blk: balinese}', "");
Expect(0, 7040, '\P{^Is_Blk: balinese}', "");
Expect(1, 7039, '\p{Is_Blk=-BALINESE}', "");
Expect(0, 7039, '\p{^Is_Blk=-BALINESE}', "");
Expect(0, 7039, '\P{Is_Blk=-BALINESE}', "");
Expect(1, 7039, '\P{^Is_Blk=-BALINESE}', "");
Expect(0, 7040, '\p{Is_Blk=-BALINESE}', "");
Expect(1, 7040, '\p{^Is_Blk=-BALINESE}', "");
Expect(1, 7040, '\P{Is_Blk=-BALINESE}', "");
Expect(0, 7040, '\P{^Is_Blk=-BALINESE}', "");
Error('\p{Block=/a/ Bamum}');
Error('\P{Block=/a/ Bamum}');
Expect(1, 42751, '\p{Block=bamum}', "");
Expect(0, 42751, '\p{^Block=bamum}', "");
Expect(0, 42751, '\P{Block=bamum}', "");
Expect(1, 42751, '\P{^Block=bamum}', "");
Expect(0, 42752, '\p{Block=bamum}', "");
Expect(1, 42752, '\p{^Block=bamum}', "");
Expect(1, 42752, '\P{Block=bamum}', "");
Expect(0, 42752, '\P{^Block=bamum}', "");
Expect(1, 42751, '\p{Block=-	bamum}', "");
Expect(0, 42751, '\p{^Block=-	bamum}', "");
Expect(0, 42751, '\P{Block=-	bamum}', "");
Expect(1, 42751, '\P{^Block=-	bamum}', "");
Expect(0, 42752, '\p{Block=-	bamum}', "");
Expect(1, 42752, '\p{^Block=-	bamum}', "");
Expect(1, 42752, '\P{Block=-	bamum}', "");
Expect(0, 42752, '\P{^Block=-	bamum}', "");
Error('\p{Blk:	:=Bamum}');
Error('\P{Blk:	:=Bamum}');
Expect(1, 42751, '\p{Blk=bamum}', "");
Expect(0, 42751, '\p{^Blk=bamum}', "");
Expect(0, 42751, '\P{Blk=bamum}', "");
Expect(1, 42751, '\P{^Blk=bamum}', "");
Expect(0, 42752, '\p{Blk=bamum}', "");
Expect(1, 42752, '\p{^Blk=bamum}', "");
Expect(1, 42752, '\P{Blk=bamum}', "");
Expect(0, 42752, '\P{^Blk=bamum}', "");
Expect(1, 42751, '\p{Blk:	_BAMUM}', "");
Expect(0, 42751, '\p{^Blk:	_BAMUM}', "");
Expect(0, 42751, '\P{Blk:	_BAMUM}', "");
Expect(1, 42751, '\P{^Blk:	_BAMUM}', "");
Expect(0, 42752, '\p{Blk:	_BAMUM}', "");
Expect(1, 42752, '\p{^Blk:	_BAMUM}', "");
Expect(1, 42752, '\P{Blk:	_BAMUM}', "");
Expect(0, 42752, '\P{^Blk:	_BAMUM}', "");
Error('\p{Is_Block=/a/		Bamum}');
Error('\P{Is_Block=/a/		Bamum}');
Expect(1, 42751, '\p{Is_Block=bamum}', "");
Expect(0, 42751, '\p{^Is_Block=bamum}', "");
Expect(0, 42751, '\P{Is_Block=bamum}', "");
Expect(1, 42751, '\P{^Is_Block=bamum}', "");
Expect(0, 42752, '\p{Is_Block=bamum}', "");
Expect(1, 42752, '\p{^Is_Block=bamum}', "");
Expect(1, 42752, '\P{Is_Block=bamum}', "");
Expect(0, 42752, '\P{^Is_Block=bamum}', "");
Expect(1, 42751, '\p{Is_Block=_	Bamum}', "");
Expect(0, 42751, '\p{^Is_Block=_	Bamum}', "");
Expect(0, 42751, '\P{Is_Block=_	Bamum}', "");
Expect(1, 42751, '\P{^Is_Block=_	Bamum}', "");
Expect(0, 42752, '\p{Is_Block=_	Bamum}', "");
Expect(1, 42752, '\p{^Is_Block=_	Bamum}', "");
Expect(1, 42752, '\P{Is_Block=_	Bamum}', "");
Expect(0, 42752, '\P{^Is_Block=_	Bamum}', "");
Error('\p{Is_Blk=  Bamum/a/}');
Error('\P{Is_Blk=  Bamum/a/}');
Expect(1, 42751, '\p{Is_Blk:   bamum}', "");
Expect(0, 42751, '\p{^Is_Blk:   bamum}', "");
Expect(0, 42751, '\P{Is_Blk:   bamum}', "");
Expect(1, 42751, '\P{^Is_Blk:   bamum}', "");
Expect(0, 42752, '\p{Is_Blk:   bamum}', "");
Expect(1, 42752, '\p{^Is_Blk:   bamum}', "");
Expect(1, 42752, '\P{Is_Blk:   bamum}', "");
Expect(0, 42752, '\P{^Is_Blk:   bamum}', "");
Expect(1, 42751, '\p{Is_Blk=	-BAMUM}', "");
Expect(0, 42751, '\p{^Is_Blk=	-BAMUM}', "");
Expect(0, 42751, '\P{Is_Blk=	-BAMUM}', "");
Expect(1, 42751, '\P{^Is_Blk=	-BAMUM}', "");
Expect(0, 42752, '\p{Is_Blk=	-BAMUM}', "");
Expect(1, 42752, '\p{^Is_Blk=	-BAMUM}', "");
Expect(1, 42752, '\P{Is_Blk=	-BAMUM}', "");
Expect(0, 42752, '\P{^Is_Blk=	-BAMUM}', "");
Error('\p{Block= /a/BAMUM_supplement}');
Error('\P{Block= /a/BAMUM_supplement}');
Expect(1, 92735, '\p{Block=bamumsupplement}', "");
Expect(0, 92735, '\p{^Block=bamumsupplement}', "");
Expect(0, 92735, '\P{Block=bamumsupplement}', "");
Expect(1, 92735, '\P{^Block=bamumsupplement}', "");
Expect(0, 92736, '\p{Block=bamumsupplement}', "");
Expect(1, 92736, '\p{^Block=bamumsupplement}', "");
Expect(1, 92736, '\P{Block=bamumsupplement}', "");
Expect(0, 92736, '\P{^Block=bamumsupplement}', "");
Expect(1, 92735, '\p{Block=	 Bamum_supplement}', "");
Expect(0, 92735, '\p{^Block=	 Bamum_supplement}', "");
Expect(0, 92735, '\P{Block=	 Bamum_supplement}', "");
Expect(1, 92735, '\P{^Block=	 Bamum_supplement}', "");
Expect(0, 92736, '\p{Block=	 Bamum_supplement}', "");
Expect(1, 92736, '\p{^Block=	 Bamum_supplement}', "");
Expect(1, 92736, '\P{Block=	 Bamum_supplement}', "");
Expect(0, 92736, '\P{^Block=	 Bamum_supplement}', "");
Error('\p{Blk=/a/-Bamum_Sup}');
Error('\P{Blk=/a/-Bamum_Sup}');
Expect(1, 92735, '\p{Blk=bamumsup}', "");
Expect(0, 92735, '\p{^Blk=bamumsup}', "");
Expect(0, 92735, '\P{Blk=bamumsup}', "");
Expect(1, 92735, '\P{^Blk=bamumsup}', "");
Expect(0, 92736, '\p{Blk=bamumsup}', "");
Expect(1, 92736, '\p{^Blk=bamumsup}', "");
Expect(1, 92736, '\P{Blk=bamumsup}', "");
Expect(0, 92736, '\P{^Blk=bamumsup}', "");
Expect(1, 92735, '\p{Blk=_-Bamum_SUP}', "");
Expect(0, 92735, '\p{^Blk=_-Bamum_SUP}', "");
Expect(0, 92735, '\P{Blk=_-Bamum_SUP}', "");
Expect(1, 92735, '\P{^Blk=_-Bamum_SUP}', "");
Expect(0, 92736, '\p{Blk=_-Bamum_SUP}', "");
Expect(1, 92736, '\p{^Blk=_-Bamum_SUP}', "");
Expect(1, 92736, '\P{Blk=_-Bamum_SUP}', "");
Expect(0, 92736, '\P{^Blk=_-Bamum_SUP}', "");
Error('\p{Is_Block=-/a/Bamum_Supplement}');
Error('\P{Is_Block=-/a/Bamum_Supplement}');
Expect(1, 92735, '\p{Is_Block=bamumsupplement}', "");
Expect(0, 92735, '\p{^Is_Block=bamumsupplement}', "");
Expect(0, 92735, '\P{Is_Block=bamumsupplement}', "");
Expect(1, 92735, '\P{^Is_Block=bamumsupplement}', "");
Expect(0, 92736, '\p{Is_Block=bamumsupplement}', "");
Expect(1, 92736, '\p{^Is_Block=bamumsupplement}', "");
Expect(1, 92736, '\P{Is_Block=bamumsupplement}', "");
Expect(0, 92736, '\P{^Is_Block=bamumsupplement}', "");
Expect(1, 92735, '\p{Is_Block=  Bamum_supplement}', "");
Expect(0, 92735, '\p{^Is_Block=  Bamum_supplement}', "");
Expect(0, 92735, '\P{Is_Block=  Bamum_supplement}', "");
Expect(1, 92735, '\P{^Is_Block=  Bamum_supplement}', "");
Expect(0, 92736, '\p{Is_Block=  Bamum_supplement}', "");
Expect(1, 92736, '\p{^Is_Block=  Bamum_supplement}', "");
Expect(1, 92736, '\P{Is_Block=  Bamum_supplement}', "");
Expect(0, 92736, '\P{^Is_Block=  Bamum_supplement}', "");
Error('\p{Is_Blk= /a/bamum_sup}');
Error('\P{Is_Blk= /a/bamum_sup}');
Expect(1, 92735, '\p{Is_Blk=bamumsup}', "");
Expect(0, 92735, '\p{^Is_Blk=bamumsup}', "");
Expect(0, 92735, '\P{Is_Blk=bamumsup}', "");
Expect(1, 92735, '\P{^Is_Blk=bamumsup}', "");
Expect(0, 92736, '\p{Is_Blk=bamumsup}', "");
Expect(1, 92736, '\p{^Is_Blk=bamumsup}', "");
Expect(1, 92736, '\P{Is_Blk=bamumsup}', "");
Expect(0, 92736, '\P{^Is_Blk=bamumsup}', "");
Expect(1, 92735, '\p{Is_Blk=_Bamum_sup}', "");
Expect(0, 92735, '\p{^Is_Blk=_Bamum_sup}', "");
Expect(0, 92735, '\P{Is_Blk=_Bamum_sup}', "");
Expect(1, 92735, '\P{^Is_Blk=_Bamum_sup}', "");
Expect(0, 92736, '\p{Is_Blk=_Bamum_sup}', "");
Expect(1, 92736, '\p{^Is_Blk=_Bamum_sup}', "");
Expect(1, 92736, '\P{Is_Blk=_Bamum_sup}', "");
Expect(0, 92736, '\P{^Is_Blk=_Bamum_sup}', "");
Error('\p{Block=-Batak/a/}');
Error('\P{Block=-Batak/a/}');
Expect(1, 7167, '\p{Block: batak}', "");
Expect(0, 7167, '\p{^Block: batak}', "");
Expect(0, 7167, '\P{Block: batak}', "");
Expect(1, 7167, '\P{^Block: batak}', "");
Expect(0, 7168, '\p{Block: batak}', "");
Expect(1, 7168, '\p{^Block: batak}', "");
Expect(1, 7168, '\P{Block: batak}', "");
Expect(0, 7168, '\P{^Block: batak}', "");
Expect(1, 7167, '\p{Block=- Batak}', "");
Expect(0, 7167, '\p{^Block=- Batak}', "");
Expect(0, 7167, '\P{Block=- Batak}', "");
Expect(1, 7167, '\P{^Block=- Batak}', "");
Expect(0, 7168, '\p{Block=- Batak}', "");
Expect(1, 7168, '\p{^Block=- Batak}', "");
Expect(1, 7168, '\P{Block=- Batak}', "");
Expect(0, 7168, '\P{^Block=- Batak}', "");
Error('\p{Blk=-:=Batak}');
Error('\P{Blk=-:=Batak}');
Expect(1, 7167, '\p{Blk:batak}', "");
Expect(0, 7167, '\p{^Blk:batak}', "");
Expect(0, 7167, '\P{Blk:batak}', "");
Expect(1, 7167, '\P{^Blk:batak}', "");
Expect(0, 7168, '\p{Blk:batak}', "");
Expect(1, 7168, '\p{^Blk:batak}', "");
Expect(1, 7168, '\P{Blk:batak}', "");
Expect(0, 7168, '\P{^Blk:batak}', "");
Expect(1, 7167, '\p{Blk:	-	Batak}', "");
Expect(0, 7167, '\p{^Blk:	-	Batak}', "");
Expect(0, 7167, '\P{Blk:	-	Batak}', "");
Expect(1, 7167, '\P{^Blk:	-	Batak}', "");
Expect(0, 7168, '\p{Blk:	-	Batak}', "");
Expect(1, 7168, '\p{^Blk:	-	Batak}', "");
Expect(1, 7168, '\P{Blk:	-	Batak}', "");
Expect(0, 7168, '\P{^Blk:	-	Batak}', "");
Error('\p{Is_Block=	:=batak}');
Error('\P{Is_Block=	:=batak}');
Expect(1, 7167, '\p{Is_Block=batak}', "");
Expect(0, 7167, '\p{^Is_Block=batak}', "");
Expect(0, 7167, '\P{Is_Block=batak}', "");
Expect(1, 7167, '\P{^Is_Block=batak}', "");
Expect(0, 7168, '\p{Is_Block=batak}', "");
Expect(1, 7168, '\p{^Is_Block=batak}', "");
Expect(1, 7168, '\P{Is_Block=batak}', "");
Expect(0, 7168, '\P{^Is_Block=batak}', "");
Expect(1, 7167, '\p{Is_Block=_	Batak}', "");
Expect(0, 7167, '\p{^Is_Block=_	Batak}', "");
Expect(0, 7167, '\P{Is_Block=_	Batak}', "");
Expect(1, 7167, '\P{^Is_Block=_	Batak}', "");
Expect(0, 7168, '\p{Is_Block=_	Batak}', "");
Expect(1, 7168, '\p{^Is_Block=_	Batak}', "");
Expect(1, 7168, '\P{Is_Block=_	Batak}', "");
Expect(0, 7168, '\P{^Is_Block=_	Batak}', "");
Error('\p{Is_Blk= -batak:=}');
Error('\P{Is_Blk= -batak:=}');
Expect(1, 7167, '\p{Is_Blk=batak}', "");
Expect(0, 7167, '\p{^Is_Blk=batak}', "");
Expect(0, 7167, '\P{Is_Blk=batak}', "");
Expect(1, 7167, '\P{^Is_Blk=batak}', "");
Expect(0, 7168, '\p{Is_Blk=batak}', "");
Expect(1, 7168, '\p{^Is_Blk=batak}', "");
Expect(1, 7168, '\P{Is_Blk=batak}', "");
Expect(0, 7168, '\P{^Is_Blk=batak}', "");
Expect(1, 7167, '\p{Is_Blk= Batak}', "");
Expect(0, 7167, '\p{^Is_Blk= Batak}', "");
Expect(0, 7167, '\P{Is_Blk= Batak}', "");
Expect(1, 7167, '\P{^Is_Blk= Batak}', "");
Expect(0, 7168, '\p{Is_Blk= Batak}', "");
Expect(1, 7168, '\p{^Is_Blk= Batak}', "");
Expect(1, 7168, '\P{Is_Blk= Batak}', "");
Expect(0, 7168, '\P{^Is_Blk= Batak}', "");
Error('\p{Block:   /a/_Bengali}');
Error('\P{Block:   /a/_Bengali}');
Expect(1, 2559, '\p{Block=bengali}', "");
Expect(0, 2559, '\p{^Block=bengali}', "");
Expect(0, 2559, '\P{Block=bengali}', "");
Expect(1, 2559, '\P{^Block=bengali}', "");
Expect(0, 2560, '\p{Block=bengali}', "");
Expect(1, 2560, '\p{^Block=bengali}', "");
Expect(1, 2560, '\P{Block=bengali}', "");
Expect(0, 2560, '\P{^Block=bengali}', "");
Expect(1, 2559, '\p{Block=	-bengali}', "");
Expect(0, 2559, '\p{^Block=	-bengali}', "");
Expect(0, 2559, '\P{Block=	-bengali}', "");
Expect(1, 2559, '\P{^Block=	-bengali}', "");
Expect(0, 2560, '\p{Block=	-bengali}', "");
Expect(1, 2560, '\p{^Block=	-bengali}', "");
Expect(1, 2560, '\P{Block=	-bengali}', "");
Expect(0, 2560, '\P{^Block=	-bengali}', "");
Error('\p{Blk=_:=Bengali}');
Error('\P{Blk=_:=Bengali}');
Expect(1, 2559, '\p{Blk=bengali}', "");
Expect(0, 2559, '\p{^Blk=bengali}', "");
Expect(0, 2559, '\P{Blk=bengali}', "");
Expect(1, 2559, '\P{^Blk=bengali}', "");
Expect(0, 2560, '\p{Blk=bengali}', "");
Expect(1, 2560, '\p{^Blk=bengali}', "");
Expect(1, 2560, '\P{Blk=bengali}', "");
Expect(0, 2560, '\P{^Blk=bengali}', "");
Expect(1, 2559, '\p{Blk=_-BENGALI}', "");
Expect(0, 2559, '\p{^Blk=_-BENGALI}', "");
Expect(0, 2559, '\P{Blk=_-BENGALI}', "");
Expect(1, 2559, '\P{^Blk=_-BENGALI}', "");
Expect(0, 2560, '\p{Blk=_-BENGALI}', "");
Expect(1, 2560, '\p{^Blk=_-BENGALI}', "");
Expect(1, 2560, '\P{Blk=_-BENGALI}', "");
Expect(0, 2560, '\P{^Blk=_-BENGALI}', "");
Error('\p{Is_Block=	BENGALI:=}');
Error('\P{Is_Block=	BENGALI:=}');
Expect(1, 2559, '\p{Is_Block=bengali}', "");
Expect(0, 2559, '\p{^Is_Block=bengali}', "");
Expect(0, 2559, '\P{Is_Block=bengali}', "");
Expect(1, 2559, '\P{^Is_Block=bengali}', "");
Expect(0, 2560, '\p{Is_Block=bengali}', "");
Expect(1, 2560, '\p{^Is_Block=bengali}', "");
Expect(1, 2560, '\P{Is_Block=bengali}', "");
Expect(0, 2560, '\P{^Is_Block=bengali}', "");
Expect(1, 2559, '\p{Is_Block= 	bengali}', "");
Expect(0, 2559, '\p{^Is_Block= 	bengali}', "");
Expect(0, 2559, '\P{Is_Block= 	bengali}', "");
Expect(1, 2559, '\P{^Is_Block= 	bengali}', "");
Expect(0, 2560, '\p{Is_Block= 	bengali}', "");
Expect(1, 2560, '\p{^Is_Block= 	bengali}', "");
Expect(1, 2560, '\P{Is_Block= 	bengali}', "");
Expect(0, 2560, '\P{^Is_Block= 	bengali}', "");
Error('\p{Is_Blk= /a/Bengali}');
Error('\P{Is_Blk= /a/Bengali}');
Expect(1, 2559, '\p{Is_Blk=bengali}', "");
Expect(0, 2559, '\p{^Is_Blk=bengali}', "");
Expect(0, 2559, '\P{Is_Blk=bengali}', "");
Expect(1, 2559, '\P{^Is_Blk=bengali}', "");
Expect(0, 2560, '\p{Is_Blk=bengali}', "");
Expect(1, 2560, '\p{^Is_Blk=bengali}', "");
Expect(1, 2560, '\P{Is_Blk=bengali}', "");
Expect(0, 2560, '\P{^Is_Blk=bengali}', "");
Expect(1, 2559, '\p{Is_Blk= -BENGALI}', "");
Expect(0, 2559, '\p{^Is_Blk= -BENGALI}', "");
Expect(0, 2559, '\P{Is_Blk= -BENGALI}', "");
Expect(1, 2559, '\P{^Is_Blk= -BENGALI}', "");
Expect(0, 2560, '\p{Is_Blk= -BENGALI}', "");
Expect(1, 2560, '\p{^Is_Blk= -BENGALI}', "");
Expect(1, 2560, '\P{Is_Blk= -BENGALI}', "");
Expect(0, 2560, '\P{^Is_Blk= -BENGALI}', "");
Error('\p{Block=:=	_Block_ELEMENTS}');
Error('\P{Block=:=	_Block_ELEMENTS}');
Expect(1, 9631, '\p{Block=blockelements}', "");
Expect(0, 9631, '\p{^Block=blockelements}', "");
Expect(0, 9631, '\P{Block=blockelements}', "");
Expect(1, 9631, '\P{^Block=blockelements}', "");
Expect(0, 9632, '\p{Block=blockelements}', "");
Expect(1, 9632, '\p{^Block=blockelements}', "");
Expect(1, 9632, '\P{Block=blockelements}', "");
Expect(0, 9632, '\P{^Block=blockelements}', "");
Expect(1, 9631, '\p{Block=-BLOCK_ELEMENTS}', "");
Expect(0, 9631, '\p{^Block=-BLOCK_ELEMENTS}', "");
Expect(0, 9631, '\P{Block=-BLOCK_ELEMENTS}', "");
Expect(1, 9631, '\P{^Block=-BLOCK_ELEMENTS}', "");
Expect(0, 9632, '\p{Block=-BLOCK_ELEMENTS}', "");
Expect(1, 9632, '\p{^Block=-BLOCK_ELEMENTS}', "");
Expect(1, 9632, '\P{Block=-BLOCK_ELEMENTS}', "");
Expect(0, 9632, '\P{^Block=-BLOCK_ELEMENTS}', "");
Error('\p{Blk= _Block_Elements/a/}');
Error('\P{Blk= _Block_Elements/a/}');
Expect(1, 9631, '\p{Blk=blockelements}', "");
Expect(0, 9631, '\p{^Blk=blockelements}', "");
Expect(0, 9631, '\P{Blk=blockelements}', "");
Expect(1, 9631, '\P{^Blk=blockelements}', "");
Expect(0, 9632, '\p{Blk=blockelements}', "");
Expect(1, 9632, '\p{^Blk=blockelements}', "");
Expect(1, 9632, '\P{Blk=blockelements}', "");
Expect(0, 9632, '\P{^Blk=blockelements}', "");
Expect(1, 9631, '\p{Blk=  BLOCK_Elements}', "");
Expect(0, 9631, '\p{^Blk=  BLOCK_Elements}', "");
Expect(0, 9631, '\P{Blk=  BLOCK_Elements}', "");
Expect(1, 9631, '\P{^Blk=  BLOCK_Elements}', "");
Expect(0, 9632, '\p{Blk=  BLOCK_Elements}', "");
Expect(1, 9632, '\p{^Blk=  BLOCK_Elements}', "");
Expect(1, 9632, '\P{Blk=  BLOCK_Elements}', "");
Expect(0, 9632, '\P{^Blk=  BLOCK_Elements}', "");
Error('\p{Is_Block=	_Block_Elements/a/}');
Error('\P{Is_Block=	_Block_Elements/a/}');
Expect(1, 9631, '\p{Is_Block=blockelements}', "");
Expect(0, 9631, '\p{^Is_Block=blockelements}', "");
Expect(0, 9631, '\P{Is_Block=blockelements}', "");
Expect(1, 9631, '\P{^Is_Block=blockelements}', "");
Expect(0, 9632, '\p{Is_Block=blockelements}', "");
Expect(1, 9632, '\p{^Is_Block=blockelements}', "");
Expect(1, 9632, '\P{Is_Block=blockelements}', "");
Expect(0, 9632, '\P{^Is_Block=blockelements}', "");
Expect(1, 9631, '\p{Is_Block: -_BLOCK_Elements}', "");
Expect(0, 9631, '\p{^Is_Block: -_BLOCK_Elements}', "");
Expect(0, 9631, '\P{Is_Block: -_BLOCK_Elements}', "");
Expect(1, 9631, '\P{^Is_Block: -_BLOCK_Elements}', "");
Expect(0, 9632, '\p{Is_Block: -_BLOCK_Elements}', "");
Expect(1, 9632, '\p{^Is_Block: -_BLOCK_Elements}', "");
Expect(1, 9632, '\P{Is_Block: -_BLOCK_Elements}', "");
Expect(0, 9632, '\P{^Is_Block: -_BLOCK_Elements}', "");
Error('\p{Is_Blk= /a/block_Elements}');
Error('\P{Is_Blk= /a/block_Elements}');
Expect(1, 9631, '\p{Is_Blk=blockelements}', "");
Expect(0, 9631, '\p{^Is_Blk=blockelements}', "");
Expect(0, 9631, '\P{Is_Blk=blockelements}', "");
Expect(1, 9631, '\P{^Is_Blk=blockelements}', "");
Expect(0, 9632, '\p{Is_Blk=blockelements}', "");
Expect(1, 9632, '\p{^Is_Blk=blockelements}', "");
Expect(1, 9632, '\P{Is_Blk=blockelements}', "");
Expect(0, 9632, '\P{^Is_Blk=blockelements}', "");
Expect(1, 9631, '\p{Is_Blk=-_Block_ELEMENTS}', "");
Expect(0, 9631, '\p{^Is_Blk=-_Block_ELEMENTS}', "");
Expect(0, 9631, '\P{Is_Blk=-_Block_ELEMENTS}', "");
Expect(1, 9631, '\P{^Is_Blk=-_Block_ELEMENTS}', "");
Expect(0, 9632, '\p{Is_Blk=-_Block_ELEMENTS}', "");
Expect(1, 9632, '\p{^Is_Blk=-_Block_ELEMENTS}', "");
Expect(1, 9632, '\P{Is_Blk=-_Block_ELEMENTS}', "");
Expect(0, 9632, '\P{^Is_Blk=-_Block_ELEMENTS}', "");
Error('\p{Block=/a/-Bopomofo}');
Error('\P{Block=/a/-Bopomofo}');
Expect(1, 12591, '\p{Block=bopomofo}', "");
Expect(0, 12591, '\p{^Block=bopomofo}', "");
Expect(0, 12591, '\P{Block=bopomofo}', "");
Expect(1, 12591, '\P{^Block=bopomofo}', "");
Expect(0, 12592, '\p{Block=bopomofo}', "");
Expect(1, 12592, '\p{^Block=bopomofo}', "");
Expect(1, 12592, '\P{Block=bopomofo}', "");
Expect(0, 12592, '\P{^Block=bopomofo}', "");
Expect(1, 12591, '\p{Block=-Bopomofo}', "");
Expect(0, 12591, '\p{^Block=-Bopomofo}', "");
Expect(0, 12591, '\P{Block=-Bopomofo}', "");
Expect(1, 12591, '\P{^Block=-Bopomofo}', "");
Expect(0, 12592, '\p{Block=-Bopomofo}', "");
Expect(1, 12592, '\p{^Block=-Bopomofo}', "");
Expect(1, 12592, '\P{Block=-Bopomofo}', "");
Expect(0, 12592, '\P{^Block=-Bopomofo}', "");
Error('\p{Blk=:=-Bopomofo}');
Error('\P{Blk=:=-Bopomofo}');
Expect(1, 12591, '\p{Blk=bopomofo}', "");
Expect(0, 12591, '\p{^Blk=bopomofo}', "");
Expect(0, 12591, '\P{Blk=bopomofo}', "");
Expect(1, 12591, '\P{^Blk=bopomofo}', "");
Expect(0, 12592, '\p{Blk=bopomofo}', "");
Expect(1, 12592, '\p{^Blk=bopomofo}', "");
Expect(1, 12592, '\P{Blk=bopomofo}', "");
Expect(0, 12592, '\P{^Blk=bopomofo}', "");
Expect(1, 12591, '\p{Blk=_-BOPOMOFO}', "");
Expect(0, 12591, '\p{^Blk=_-BOPOMOFO}', "");
Expect(0, 12591, '\P{Blk=_-BOPOMOFO}', "");
Expect(1, 12591, '\P{^Blk=_-BOPOMOFO}', "");
Expect(0, 12592, '\p{Blk=_-BOPOMOFO}', "");
Expect(1, 12592, '\p{^Blk=_-BOPOMOFO}', "");
Expect(1, 12592, '\P{Blk=_-BOPOMOFO}', "");
Expect(0, 12592, '\P{^Blk=_-BOPOMOFO}', "");
Error('\p{Is_Block=-/a/Bopomofo}');
Error('\P{Is_Block=-/a/Bopomofo}');
Expect(1, 12591, '\p{Is_Block=bopomofo}', "");
Expect(0, 12591, '\p{^Is_Block=bopomofo}', "");
Expect(0, 12591, '\P{Is_Block=bopomofo}', "");
Expect(1, 12591, '\P{^Is_Block=bopomofo}', "");
Expect(0, 12592, '\p{Is_Block=bopomofo}', "");
Expect(1, 12592, '\p{^Is_Block=bopomofo}', "");
Expect(1, 12592, '\P{Is_Block=bopomofo}', "");
Expect(0, 12592, '\P{^Is_Block=bopomofo}', "");
Expect(1, 12591, '\p{Is_Block= _Bopomofo}', "");
Expect(0, 12591, '\p{^Is_Block= _Bopomofo}', "");
Expect(0, 12591, '\P{Is_Block= _Bopomofo}', "");
Expect(1, 12591, '\P{^Is_Block= _Bopomofo}', "");
Expect(0, 12592, '\p{Is_Block= _Bopomofo}', "");
Expect(1, 12592, '\p{^Is_Block= _Bopomofo}', "");
Expect(1, 12592, '\P{Is_Block= _Bopomofo}', "");
Expect(0, 12592, '\P{^Is_Block= _Bopomofo}', "");
Error('\p{Is_Blk=/a/ 	BOPOMOFO}');
Error('\P{Is_Blk=/a/ 	BOPOMOFO}');
Expect(1, 12591, '\p{Is_Blk:	bopomofo}', "");
Expect(0, 12591, '\p{^Is_Blk:	bopomofo}', "");
Expect(0, 12591, '\P{Is_Blk:	bopomofo}', "");
Expect(1, 12591, '\P{^Is_Blk:	bopomofo}', "");
Expect(0, 12592, '\p{Is_Blk:	bopomofo}', "");
Expect(1, 12592, '\p{^Is_Blk:	bopomofo}', "");
Expect(1, 12592, '\P{Is_Blk:	bopomofo}', "");
Expect(0, 12592, '\P{^Is_Blk:	bopomofo}', "");
Expect(1, 12591, '\p{Is_Blk=	 BOPOMOFO}', "");
Expect(0, 12591, '\p{^Is_Blk=	 BOPOMOFO}', "");
Expect(0, 12591, '\P{Is_Blk=	 BOPOMOFO}', "");
Expect(1, 12591, '\P{^Is_Blk=	 BOPOMOFO}', "");
Expect(0, 12592, '\p{Is_Blk=	 BOPOMOFO}', "");
Expect(1, 12592, '\p{^Is_Blk=	 BOPOMOFO}', "");
Expect(1, 12592, '\P{Is_Blk=	 BOPOMOFO}', "");
Expect(0, 12592, '\P{^Is_Blk=	 BOPOMOFO}', "");
Error('\p{Block=_Bopomofo_Extended:=}');
Error('\P{Block=_Bopomofo_Extended:=}');
Expect(1, 12735, '\p{Block=bopomofoextended}', "");
Expect(0, 12735, '\p{^Block=bopomofoextended}', "");
Expect(0, 12735, '\P{Block=bopomofoextended}', "");
Expect(1, 12735, '\P{^Block=bopomofoextended}', "");
Expect(0, 12736, '\p{Block=bopomofoextended}', "");
Expect(1, 12736, '\p{^Block=bopomofoextended}', "");
Expect(1, 12736, '\P{Block=bopomofoextended}', "");
Expect(0, 12736, '\P{^Block=bopomofoextended}', "");
Expect(1, 12735, '\p{Block=Bopomofo_Extended}', "");
Expect(0, 12735, '\p{^Block=Bopomofo_Extended}', "");
Expect(0, 12735, '\P{Block=Bopomofo_Extended}', "");
Expect(1, 12735, '\P{^Block=Bopomofo_Extended}', "");
Expect(0, 12736, '\p{Block=Bopomofo_Extended}', "");
Expect(1, 12736, '\p{^Block=Bopomofo_Extended}', "");
Expect(1, 12736, '\P{Block=Bopomofo_Extended}', "");
Expect(0, 12736, '\P{^Block=Bopomofo_Extended}', "");
Error('\p{Blk=	/a/Bopomofo_Ext}');
Error('\P{Blk=	/a/Bopomofo_Ext}');
Expect(1, 12735, '\p{Blk=bopomofoext}', "");
Expect(0, 12735, '\p{^Blk=bopomofoext}', "");
Expect(0, 12735, '\P{Blk=bopomofoext}', "");
Expect(1, 12735, '\P{^Blk=bopomofoext}', "");
Expect(0, 12736, '\p{Blk=bopomofoext}', "");
Expect(1, 12736, '\p{^Blk=bopomofoext}', "");
Expect(1, 12736, '\P{Blk=bopomofoext}', "");
Expect(0, 12736, '\P{^Blk=bopomofoext}', "");
Expect(1, 12735, '\p{Blk=Bopomofo_ext}', "");
Expect(0, 12735, '\p{^Blk=Bopomofo_ext}', "");
Expect(0, 12735, '\P{Blk=Bopomofo_ext}', "");
Expect(1, 12735, '\P{^Blk=Bopomofo_ext}', "");
Expect(0, 12736, '\p{Blk=Bopomofo_ext}', "");
Expect(1, 12736, '\p{^Blk=Bopomofo_ext}', "");
Expect(1, 12736, '\P{Blk=Bopomofo_ext}', "");
Expect(0, 12736, '\P{^Blk=Bopomofo_ext}', "");
Error('\p{Is_Block: -:=Bopomofo_EXTENDED}');
Error('\P{Is_Block: -:=Bopomofo_EXTENDED}');
Expect(1, 12735, '\p{Is_Block=bopomofoextended}', "");
Expect(0, 12735, '\p{^Is_Block=bopomofoextended}', "");
Expect(0, 12735, '\P{Is_Block=bopomofoextended}', "");
Expect(1, 12735, '\P{^Is_Block=bopomofoextended}', "");
Expect(0, 12736, '\p{Is_Block=bopomofoextended}', "");
Expect(1, 12736, '\p{^Is_Block=bopomofoextended}', "");
Expect(1, 12736, '\P{Is_Block=bopomofoextended}', "");
Expect(0, 12736, '\P{^Is_Block=bopomofoextended}', "");
Expect(1, 12735, '\p{Is_Block=_	Bopomofo_extended}', "");
Expect(0, 12735, '\p{^Is_Block=_	Bopomofo_extended}', "");
Expect(0, 12735, '\P{Is_Block=_	Bopomofo_extended}', "");
Expect(1, 12735, '\P{^Is_Block=_	Bopomofo_extended}', "");
Expect(0, 12736, '\p{Is_Block=_	Bopomofo_extended}', "");
Expect(1, 12736, '\p{^Is_Block=_	Bopomofo_extended}', "");
Expect(1, 12736, '\P{Is_Block=_	Bopomofo_extended}', "");
Expect(0, 12736, '\P{^Is_Block=_	Bopomofo_extended}', "");
Error('\p{Is_Blk=/a/-_Bopomofo_EXT}');
Error('\P{Is_Blk=/a/-_Bopomofo_EXT}');
Expect(1, 12735, '\p{Is_Blk=bopomofoext}', "");
Expect(0, 12735, '\p{^Is_Blk=bopomofoext}', "");
Expect(0, 12735, '\P{Is_Blk=bopomofoext}', "");
Expect(1, 12735, '\P{^Is_Blk=bopomofoext}', "");
Expect(0, 12736, '\p{Is_Blk=bopomofoext}', "");
Expect(1, 12736, '\p{^Is_Blk=bopomofoext}', "");
Expect(1, 12736, '\P{Is_Blk=bopomofoext}', "");
Expect(0, 12736, '\P{^Is_Blk=bopomofoext}', "");
Expect(1, 12735, '\p{Is_Blk=	BOPOMOFO_EXT}', "");
Expect(0, 12735, '\p{^Is_Blk=	BOPOMOFO_EXT}', "");
Expect(0, 12735, '\P{Is_Blk=	BOPOMOFO_EXT}', "");
Expect(1, 12735, '\P{^Is_Blk=	BOPOMOFO_EXT}', "");
Expect(0, 12736, '\p{Is_Blk=	BOPOMOFO_EXT}', "");
Expect(1, 12736, '\p{^Is_Blk=	BOPOMOFO_EXT}', "");
Expect(1, 12736, '\P{Is_Blk=	BOPOMOFO_EXT}', "");
Expect(0, 12736, '\P{^Is_Blk=	BOPOMOFO_EXT}', "");
Error('\p{Block=-_box_Drawing/a/}');
Error('\P{Block=-_box_Drawing/a/}');
Expect(1, 9599, '\p{Block=boxdrawing}', "");
Expect(0, 9599, '\p{^Block=boxdrawing}', "");
Expect(0, 9599, '\P{Block=boxdrawing}', "");
Expect(1, 9599, '\P{^Block=boxdrawing}', "");
Expect(0, 9600, '\p{Block=boxdrawing}', "");
Expect(1, 9600, '\p{^Block=boxdrawing}', "");
Expect(1, 9600, '\P{Block=boxdrawing}', "");
Expect(0, 9600, '\P{^Block=boxdrawing}', "");
Expect(1, 9599, '\p{Block=-	box_drawing}', "");
Expect(0, 9599, '\p{^Block=-	box_drawing}', "");
Expect(0, 9599, '\P{Block=-	box_drawing}', "");
Expect(1, 9599, '\P{^Block=-	box_drawing}', "");
Expect(0, 9600, '\p{Block=-	box_drawing}', "");
Expect(1, 9600, '\p{^Block=-	box_drawing}', "");
Expect(1, 9600, '\P{Block=-	box_drawing}', "");
Expect(0, 9600, '\P{^Block=-	box_drawing}', "");
Error('\p{Blk=/a/ box_drawing}');
Error('\P{Blk=/a/ box_drawing}');
Expect(1, 9599, '\p{Blk=boxdrawing}', "");
Expect(0, 9599, '\p{^Blk=boxdrawing}', "");
Expect(0, 9599, '\P{Blk=boxdrawing}', "");
Expect(1, 9599, '\P{^Blk=boxdrawing}', "");
Expect(0, 9600, '\p{Blk=boxdrawing}', "");
Expect(1, 9600, '\p{^Blk=boxdrawing}', "");
Expect(1, 9600, '\P{Blk=boxdrawing}', "");
Expect(0, 9600, '\P{^Blk=boxdrawing}', "");
Expect(1, 9599, '\p{Blk=	box_drawing}', "");
Expect(0, 9599, '\p{^Blk=	box_drawing}', "");
Expect(0, 9599, '\P{Blk=	box_drawing}', "");
Expect(1, 9599, '\P{^Blk=	box_drawing}', "");
Expect(0, 9600, '\p{Blk=	box_drawing}', "");
Expect(1, 9600, '\p{^Blk=	box_drawing}', "");
Expect(1, 9600, '\P{Blk=	box_drawing}', "");
Expect(0, 9600, '\P{^Blk=	box_drawing}', "");
Error('\p{Is_Block=-Box_DRAWING:=}');
Error('\P{Is_Block=-Box_DRAWING:=}');
Expect(1, 9599, '\p{Is_Block=boxdrawing}', "");
Expect(0, 9599, '\p{^Is_Block=boxdrawing}', "");
Expect(0, 9599, '\P{Is_Block=boxdrawing}', "");
Expect(1, 9599, '\P{^Is_Block=boxdrawing}', "");
Expect(0, 9600, '\p{Is_Block=boxdrawing}', "");
Expect(1, 9600, '\p{^Is_Block=boxdrawing}', "");
Expect(1, 9600, '\P{Is_Block=boxdrawing}', "");
Expect(0, 9600, '\P{^Is_Block=boxdrawing}', "");
Expect(1, 9599, '\p{Is_Block=_Box_DRAWING}', "");
Expect(0, 9599, '\p{^Is_Block=_Box_DRAWING}', "");
Expect(0, 9599, '\P{Is_Block=_Box_DRAWING}', "");
Expect(1, 9599, '\P{^Is_Block=_Box_DRAWING}', "");
Expect(0, 9600, '\p{Is_Block=_Box_DRAWING}', "");
Expect(1, 9600, '\p{^Is_Block=_Box_DRAWING}', "");
Expect(1, 9600, '\P{Is_Block=_Box_DRAWING}', "");
Expect(0, 9600, '\P{^Is_Block=_Box_DRAWING}', "");
Error('\p{Is_Blk=	-Box_Drawing/a/}');
Error('\P{Is_Blk=	-Box_Drawing/a/}');
Expect(1, 9599, '\p{Is_Blk=boxdrawing}', "");
Expect(0, 9599, '\p{^Is_Blk=boxdrawing}', "");
Expect(0, 9599, '\P{Is_Blk=boxdrawing}', "");
Expect(1, 9599, '\P{^Is_Blk=boxdrawing}', "");
Expect(0, 9600, '\p{Is_Blk=boxdrawing}', "");
Expect(1, 9600, '\p{^Is_Blk=boxdrawing}', "");
Expect(1, 9600, '\P{Is_Blk=boxdrawing}', "");
Expect(0, 9600, '\P{^Is_Blk=boxdrawing}', "");
Expect(1, 9599, '\p{Is_Blk=	-box_drawing}', "");
Expect(0, 9599, '\p{^Is_Blk=	-box_drawing}', "");
Expect(0, 9599, '\P{Is_Blk=	-box_drawing}', "");
Expect(1, 9599, '\P{^Is_Blk=	-box_drawing}', "");
Expect(0, 9600, '\p{Is_Blk=	-box_drawing}', "");
Expect(1, 9600, '\p{^Is_Blk=	-box_drawing}', "");
Expect(1, 9600, '\P{Is_Blk=	-box_drawing}', "");
Expect(0, 9600, '\P{^Is_Blk=	-box_drawing}', "");
Error('\p{Block=	-Brahmi/a/}');
Error('\P{Block=	-Brahmi/a/}');
Expect(1, 69759, '\p{Block=brahmi}', "");
Expect(0, 69759, '\p{^Block=brahmi}', "");
Expect(0, 69759, '\P{Block=brahmi}', "");
Expect(1, 69759, '\P{^Block=brahmi}', "");
Expect(0, 69760, '\p{Block=brahmi}', "");
Expect(1, 69760, '\p{^Block=brahmi}', "");
Expect(1, 69760, '\P{Block=brahmi}', "");
Expect(0, 69760, '\P{^Block=brahmi}', "");
Expect(1, 69759, '\p{Block=__brahmi}', "");
Expect(0, 69759, '\p{^Block=__brahmi}', "");
Expect(0, 69759, '\P{Block=__brahmi}', "");
Expect(1, 69759, '\P{^Block=__brahmi}', "");
Expect(0, 69760, '\p{Block=__brahmi}', "");
Expect(1, 69760, '\p{^Block=__brahmi}', "");
Expect(1, 69760, '\P{Block=__brahmi}', "");
Expect(0, 69760, '\P{^Block=__brahmi}', "");
Error('\p{Blk=:=_Brahmi}');
Error('\P{Blk=:=_Brahmi}');
Expect(1, 69759, '\p{Blk=brahmi}', "");
Expect(0, 69759, '\p{^Blk=brahmi}', "");
Expect(0, 69759, '\P{Blk=brahmi}', "");
Expect(1, 69759, '\P{^Blk=brahmi}', "");
Expect(0, 69760, '\p{Blk=brahmi}', "");
Expect(1, 69760, '\p{^Blk=brahmi}', "");
Expect(1, 69760, '\P{Blk=brahmi}', "");
Expect(0, 69760, '\P{^Blk=brahmi}', "");
Expect(1, 69759, '\p{Blk=--Brahmi}', "");
Expect(0, 69759, '\p{^Blk=--Brahmi}', "");
Expect(0, 69759, '\P{Blk=--Brahmi}', "");
Expect(1, 69759, '\P{^Blk=--Brahmi}', "");
Expect(0, 69760, '\p{Blk=--Brahmi}', "");
Expect(1, 69760, '\p{^Blk=--Brahmi}', "");
Expect(1, 69760, '\P{Blk=--Brahmi}', "");
Expect(0, 69760, '\P{^Blk=--Brahmi}', "");
Error('\p{Is_Block=/a/ 	Brahmi}');
Error('\P{Is_Block=/a/ 	Brahmi}');
Expect(1, 69759, '\p{Is_Block:	brahmi}', "");
Expect(0, 69759, '\p{^Is_Block:	brahmi}', "");
Expect(0, 69759, '\P{Is_Block:	brahmi}', "");
Expect(1, 69759, '\P{^Is_Block:	brahmi}', "");
Expect(0, 69760, '\p{Is_Block:	brahmi}', "");
Expect(1, 69760, '\p{^Is_Block:	brahmi}', "");
Expect(1, 69760, '\P{Is_Block:	brahmi}', "");
Expect(0, 69760, '\P{^Is_Block:	brahmi}', "");
Expect(1, 69759, '\p{Is_Block=		Brahmi}', "");
Expect(0, 69759, '\p{^Is_Block=		Brahmi}', "");
Expect(0, 69759, '\P{Is_Block=		Brahmi}', "");
Expect(1, 69759, '\P{^Is_Block=		Brahmi}', "");
Expect(0, 69760, '\p{Is_Block=		Brahmi}', "");
Expect(1, 69760, '\p{^Is_Block=		Brahmi}', "");
Expect(1, 69760, '\P{Is_Block=		Brahmi}', "");
Expect(0, 69760, '\P{^Is_Block=		Brahmi}', "");
Error('\p{Is_Blk: brahmi:=}');
Error('\P{Is_Blk: brahmi:=}');
Expect(1, 69759, '\p{Is_Blk=brahmi}', "");
Expect(0, 69759, '\p{^Is_Blk=brahmi}', "");
Expect(0, 69759, '\P{Is_Blk=brahmi}', "");
Expect(1, 69759, '\P{^Is_Blk=brahmi}', "");
Expect(0, 69760, '\p{Is_Blk=brahmi}', "");
Expect(1, 69760, '\p{^Is_Blk=brahmi}', "");
Expect(1, 69760, '\P{Is_Blk=brahmi}', "");
Expect(0, 69760, '\P{^Is_Blk=brahmi}', "");
Expect(1, 69759, '\p{Is_Blk=  brahmi}', "");
Expect(0, 69759, '\p{^Is_Blk=  brahmi}', "");
Expect(0, 69759, '\P{Is_Blk=  brahmi}', "");
Expect(1, 69759, '\P{^Is_Blk=  brahmi}', "");
Expect(0, 69760, '\p{Is_Blk=  brahmi}', "");
Expect(1, 69760, '\p{^Is_Blk=  brahmi}', "");
Expect(1, 69760, '\P{Is_Blk=  brahmi}', "");
Expect(0, 69760, '\P{^Is_Blk=  brahmi}', "");
Error('\p{Block=:=_Braille_patterns}');
Error('\P{Block=:=_Braille_patterns}');
Expect(1, 10495, '\p{Block=braillepatterns}', "");
Expect(0, 10495, '\p{^Block=braillepatterns}', "");
Expect(0, 10495, '\P{Block=braillepatterns}', "");
Expect(1, 10495, '\P{^Block=braillepatterns}', "");
Expect(0, 10496, '\p{Block=braillepatterns}', "");
Expect(1, 10496, '\p{^Block=braillepatterns}', "");
Expect(1, 10496, '\P{Block=braillepatterns}', "");
Expect(0, 10496, '\P{^Block=braillepatterns}', "");
Expect(1, 10495, '\p{Block= 	Braille_patterns}', "");
Expect(0, 10495, '\p{^Block= 	Braille_patterns}', "");
Expect(0, 10495, '\P{Block= 	Braille_patterns}', "");
Expect(1, 10495, '\P{^Block= 	Braille_patterns}', "");
Expect(0, 10496, '\p{Block= 	Braille_patterns}', "");
Expect(1, 10496, '\p{^Block= 	Braille_patterns}', "");
Expect(1, 10496, '\P{Block= 	Braille_patterns}', "");
Expect(0, 10496, '\P{^Block= 	Braille_patterns}', "");
Error('\p{Blk=:= -Braille}');
Error('\P{Blk=:= -Braille}');
Expect(1, 10495, '\p{Blk=braille}', "");
Expect(0, 10495, '\p{^Blk=braille}', "");
Expect(0, 10495, '\P{Blk=braille}', "");
Expect(1, 10495, '\P{^Blk=braille}', "");
Expect(0, 10496, '\p{Blk=braille}', "");
Expect(1, 10496, '\p{^Blk=braille}', "");
Expect(1, 10496, '\P{Blk=braille}', "");
Expect(0, 10496, '\P{^Blk=braille}', "");
Expect(1, 10495, '\p{Blk=- Braille}', "");
Expect(0, 10495, '\p{^Blk=- Braille}', "");
Expect(0, 10495, '\P{Blk=- Braille}', "");
Expect(1, 10495, '\P{^Blk=- Braille}', "");
Expect(0, 10496, '\p{Blk=- Braille}', "");
Expect(1, 10496, '\p{^Blk=- Braille}', "");
Expect(1, 10496, '\P{Blk=- Braille}', "");
Expect(0, 10496, '\P{^Blk=- Braille}', "");
Error('\p{Is_Block=:=braille_Patterns}');
Error('\P{Is_Block=:=braille_Patterns}');
Expect(1, 10495, '\p{Is_Block=braillepatterns}', "");
Expect(0, 10495, '\p{^Is_Block=braillepatterns}', "");
Expect(0, 10495, '\P{Is_Block=braillepatterns}', "");
Expect(1, 10495, '\P{^Is_Block=braillepatterns}', "");
Expect(0, 10496, '\p{Is_Block=braillepatterns}', "");
Expect(1, 10496, '\p{^Is_Block=braillepatterns}', "");
Expect(1, 10496, '\P{Is_Block=braillepatterns}', "");
Expect(0, 10496, '\P{^Is_Block=braillepatterns}', "");
Expect(1, 10495, '\p{Is_Block: -_braille_Patterns}', "");
Expect(0, 10495, '\p{^Is_Block: -_braille_Patterns}', "");
Expect(0, 10495, '\P{Is_Block: -_braille_Patterns}', "");
Expect(1, 10495, '\P{^Is_Block: -_braille_Patterns}', "");
Expect(0, 10496, '\p{Is_Block: -_braille_Patterns}', "");
Expect(1, 10496, '\p{^Is_Block: -_braille_Patterns}', "");
Expect(1, 10496, '\P{Is_Block: -_braille_Patterns}', "");
Expect(0, 10496, '\P{^Is_Block: -_braille_Patterns}', "");
Error('\p{Is_Blk:    	BRAILLE:=}');
Error('\P{Is_Blk:    	BRAILLE:=}');
Expect(1, 10495, '\p{Is_Blk=braille}', "");
Expect(0, 10495, '\p{^Is_Blk=braille}', "");
Expect(0, 10495, '\P{Is_Blk=braille}', "");
Expect(1, 10495, '\P{^Is_Blk=braille}', "");
Expect(0, 10496, '\p{Is_Blk=braille}', "");
Expect(1, 10496, '\p{^Is_Blk=braille}', "");
Expect(1, 10496, '\P{Is_Blk=braille}', "");
Expect(0, 10496, '\P{^Is_Blk=braille}', "");
Expect(1, 10495, '\p{Is_Blk= BRAILLE}', "");
Expect(0, 10495, '\p{^Is_Blk= BRAILLE}', "");
Expect(0, 10495, '\P{Is_Blk= BRAILLE}', "");
Expect(1, 10495, '\P{^Is_Blk= BRAILLE}', "");
Expect(0, 10496, '\p{Is_Blk= BRAILLE}', "");
Expect(1, 10496, '\p{^Is_Blk= BRAILLE}', "");
Expect(1, 10496, '\P{Is_Blk= BRAILLE}', "");
Expect(0, 10496, '\P{^Is_Blk= BRAILLE}', "");
Error('\p{Block:   _/a/Buginese}');
Error('\P{Block:   _/a/Buginese}');
Expect(1, 6687, '\p{Block=buginese}', "");
Expect(0, 6687, '\p{^Block=buginese}', "");
Expect(0, 6687, '\P{Block=buginese}', "");
Expect(1, 6687, '\P{^Block=buginese}', "");
Expect(0, 6688, '\p{Block=buginese}', "");
Expect(1, 6688, '\p{^Block=buginese}', "");
Expect(1, 6688, '\P{Block=buginese}', "");
Expect(0, 6688, '\P{^Block=buginese}', "");
Expect(1, 6687, '\p{Block=	Buginese}', "");
Expect(0, 6687, '\p{^Block=	Buginese}', "");
Expect(0, 6687, '\P{Block=	Buginese}', "");
Expect(1, 6687, '\P{^Block=	Buginese}', "");
Expect(0, 6688, '\p{Block=	Buginese}', "");
Expect(1, 6688, '\p{^Block=	Buginese}', "");
Expect(1, 6688, '\P{Block=	Buginese}', "");
Expect(0, 6688, '\P{^Block=	Buginese}', "");
Error('\p{Blk=/a/ _Buginese}');
Error('\P{Blk=/a/ _Buginese}');
Expect(1, 6687, '\p{Blk=buginese}', "");
Expect(0, 6687, '\p{^Blk=buginese}', "");
Expect(0, 6687, '\P{Blk=buginese}', "");
Expect(1, 6687, '\P{^Blk=buginese}', "");
Expect(0, 6688, '\p{Blk=buginese}', "");
Expect(1, 6688, '\p{^Blk=buginese}', "");
Expect(1, 6688, '\P{Blk=buginese}', "");
Expect(0, 6688, '\P{^Blk=buginese}', "");
Expect(1, 6687, '\p{Blk=- buginese}', "");
Expect(0, 6687, '\p{^Blk=- buginese}', "");
Expect(0, 6687, '\P{Blk=- buginese}', "");
Expect(1, 6687, '\P{^Blk=- buginese}', "");
Expect(0, 6688, '\p{Blk=- buginese}', "");
Expect(1, 6688, '\p{^Blk=- buginese}', "");
Expect(1, 6688, '\P{Blk=- buginese}', "");
Expect(0, 6688, '\P{^Blk=- buginese}', "");
Error('\p{Is_Block=-/a/BUGINESE}');
Error('\P{Is_Block=-/a/BUGINESE}');
Expect(1, 6687, '\p{Is_Block=buginese}', "");
Expect(0, 6687, '\p{^Is_Block=buginese}', "");
Expect(0, 6687, '\P{Is_Block=buginese}', "");
Expect(1, 6687, '\P{^Is_Block=buginese}', "");
Expect(0, 6688, '\p{Is_Block=buginese}', "");
Expect(1, 6688, '\p{^Is_Block=buginese}', "");
Expect(1, 6688, '\P{Is_Block=buginese}', "");
Expect(0, 6688, '\P{^Is_Block=buginese}', "");
Expect(1, 6687, '\p{Is_Block:    	Buginese}', "");
Expect(0, 6687, '\p{^Is_Block:    	Buginese}', "");
Expect(0, 6687, '\P{Is_Block:    	Buginese}', "");
Expect(1, 6687, '\P{^Is_Block:    	Buginese}', "");
Expect(0, 6688, '\p{Is_Block:    	Buginese}', "");
Expect(1, 6688, '\p{^Is_Block:    	Buginese}', "");
Expect(1, 6688, '\P{Is_Block:    	Buginese}', "");
Expect(0, 6688, '\P{^Is_Block:    	Buginese}', "");
Error('\p{Is_Blk=-:=buginese}');
Error('\P{Is_Blk=-:=buginese}');
Expect(1, 6687, '\p{Is_Blk=buginese}', "");
Expect(0, 6687, '\p{^Is_Blk=buginese}', "");
Expect(0, 6687, '\P{Is_Blk=buginese}', "");
Expect(1, 6687, '\P{^Is_Blk=buginese}', "");
Expect(0, 6688, '\p{Is_Blk=buginese}', "");
Expect(1, 6688, '\p{^Is_Blk=buginese}', "");
Expect(1, 6688, '\P{Is_Blk=buginese}', "");
Expect(0, 6688, '\P{^Is_Blk=buginese}', "");
Expect(1, 6687, '\p{Is_Blk=	buginese}', "");
Expect(0, 6687, '\p{^Is_Blk=	buginese}', "");
Expect(0, 6687, '\P{Is_Blk=	buginese}', "");
Expect(1, 6687, '\P{^Is_Blk=	buginese}', "");
Expect(0, 6688, '\p{Is_Blk=	buginese}', "");
Expect(1, 6688, '\p{^Is_Blk=	buginese}', "");
Expect(1, 6688, '\P{Is_Blk=	buginese}', "");
Expect(0, 6688, '\P{^Is_Blk=	buginese}', "");
Error('\p{Block=  Buhid:=}');
Error('\P{Block=  Buhid:=}');
Expect(1, 5983, '\p{Block=buhid}', "");
Expect(0, 5983, '\p{^Block=buhid}', "");
Expect(0, 5983, '\P{Block=buhid}', "");
Expect(1, 5983, '\P{^Block=buhid}', "");
Expect(0, 5984, '\p{Block=buhid}', "");
Expect(1, 5984, '\p{^Block=buhid}', "");
Expect(1, 5984, '\P{Block=buhid}', "");
Expect(0, 5984, '\P{^Block=buhid}', "");
Expect(1, 5983, '\p{Block=Buhid}', "");
Expect(0, 5983, '\p{^Block=Buhid}', "");
Expect(0, 5983, '\P{Block=Buhid}', "");
Expect(1, 5983, '\P{^Block=Buhid}', "");
Expect(0, 5984, '\p{Block=Buhid}', "");
Expect(1, 5984, '\p{^Block=Buhid}', "");
Expect(1, 5984, '\P{Block=Buhid}', "");
Expect(0, 5984, '\P{^Block=Buhid}', "");
Error('\p{Blk=	-BUHID:=}');
Error('\P{Blk=	-BUHID:=}');
Expect(1, 5983, '\p{Blk=buhid}', "");
Expect(0, 5983, '\p{^Blk=buhid}', "");
Expect(0, 5983, '\P{Blk=buhid}', "");
Expect(1, 5983, '\P{^Blk=buhid}', "");
Expect(0, 5984, '\p{Blk=buhid}', "");
Expect(1, 5984, '\p{^Blk=buhid}', "");
Expect(1, 5984, '\P{Blk=buhid}', "");
Expect(0, 5984, '\P{^Blk=buhid}', "");
Expect(1, 5983, '\p{Blk=--BUHID}', "");
Expect(0, 5983, '\p{^Blk=--BUHID}', "");
Expect(0, 5983, '\P{Blk=--BUHID}', "");
Expect(1, 5983, '\P{^Blk=--BUHID}', "");
Expect(0, 5984, '\p{Blk=--BUHID}', "");
Expect(1, 5984, '\p{^Blk=--BUHID}', "");
Expect(1, 5984, '\P{Blk=--BUHID}', "");
Expect(0, 5984, '\P{^Blk=--BUHID}', "");
Error('\p{Is_Block=	_Buhid/a/}');
Error('\P{Is_Block=	_Buhid/a/}');
Expect(1, 5983, '\p{Is_Block=buhid}', "");
Expect(0, 5983, '\p{^Is_Block=buhid}', "");
Expect(0, 5983, '\P{Is_Block=buhid}', "");
Expect(1, 5983, '\P{^Is_Block=buhid}', "");
Expect(0, 5984, '\p{Is_Block=buhid}', "");
Expect(1, 5984, '\p{^Is_Block=buhid}', "");
Expect(1, 5984, '\P{Is_Block=buhid}', "");
Expect(0, 5984, '\P{^Is_Block=buhid}', "");
Expect(1, 5983, '\p{Is_Block=	BUHID}', "");
Expect(0, 5983, '\p{^Is_Block=	BUHID}', "");
Expect(0, 5983, '\P{Is_Block=	BUHID}', "");
Expect(1, 5983, '\P{^Is_Block=	BUHID}', "");
Expect(0, 5984, '\p{Is_Block=	BUHID}', "");
Expect(1, 5984, '\p{^Is_Block=	BUHID}', "");
Expect(1, 5984, '\P{Is_Block=	BUHID}', "");
Expect(0, 5984, '\P{^Is_Block=	BUHID}', "");
Error('\p{Is_Blk=:=  buhid}');
Error('\P{Is_Blk=:=  buhid}');
Expect(1, 5983, '\p{Is_Blk=buhid}', "");
Expect(0, 5983, '\p{^Is_Blk=buhid}', "");
Expect(0, 5983, '\P{Is_Blk=buhid}', "");
Expect(1, 5983, '\P{^Is_Blk=buhid}', "");
Expect(0, 5984, '\p{Is_Blk=buhid}', "");
Expect(1, 5984, '\p{^Is_Blk=buhid}', "");
Expect(1, 5984, '\P{Is_Blk=buhid}', "");
Expect(0, 5984, '\P{^Is_Blk=buhid}', "");
Expect(1, 5983, '\p{Is_Blk=_ Buhid}', "");
Expect(0, 5983, '\p{^Is_Blk=_ Buhid}', "");
Expect(0, 5983, '\P{Is_Blk=_ Buhid}', "");
Expect(1, 5983, '\P{^Is_Blk=_ Buhid}', "");
Expect(0, 5984, '\p{Is_Blk=_ Buhid}', "");
Expect(1, 5984, '\p{^Is_Blk=_ Buhid}', "");
Expect(1, 5984, '\P{Is_Blk=_ Buhid}', "");
Expect(0, 5984, '\P{^Is_Blk=_ Buhid}', "");
Error('\p{Block=	:=Byzantine_Musical_SYMBOLS}');
Error('\P{Block=	:=Byzantine_Musical_SYMBOLS}');
Expect(1, 119039, '\p{Block=byzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^Block=byzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{Block=byzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^Block=byzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{Block=byzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^Block=byzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{Block=byzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^Block=byzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{Block= -Byzantine_musical_Symbols}', "");
Expect(0, 119039, '\p{^Block= -Byzantine_musical_Symbols}', "");
Expect(0, 119039, '\P{Block= -Byzantine_musical_Symbols}', "");
Expect(1, 119039, '\P{^Block= -Byzantine_musical_Symbols}', "");
Expect(0, 119040, '\p{Block= -Byzantine_musical_Symbols}', "");
Expect(1, 119040, '\p{^Block= -Byzantine_musical_Symbols}', "");
Expect(1, 119040, '\P{Block= -Byzantine_musical_Symbols}', "");
Expect(0, 119040, '\P{^Block= -Byzantine_musical_Symbols}', "");
Error('\p{Blk=:=byzantine_music}');
Error('\P{Blk=:=byzantine_music}');
Expect(1, 119039, '\p{Blk=byzantinemusic}', "");
Expect(0, 119039, '\p{^Blk=byzantinemusic}', "");
Expect(0, 119039, '\P{Blk=byzantinemusic}', "");
Expect(1, 119039, '\P{^Blk=byzantinemusic}', "");
Expect(0, 119040, '\p{Blk=byzantinemusic}', "");
Expect(1, 119040, '\p{^Blk=byzantinemusic}', "");
Expect(1, 119040, '\P{Blk=byzantinemusic}', "");
Expect(0, 119040, '\P{^Blk=byzantinemusic}', "");
Expect(1, 119039, '\p{Blk:		byzantine_Music}', "");
Expect(0, 119039, '\p{^Blk:		byzantine_Music}', "");
Expect(0, 119039, '\P{Blk:		byzantine_Music}', "");
Expect(1, 119039, '\P{^Blk:		byzantine_Music}', "");
Expect(0, 119040, '\p{Blk:		byzantine_Music}', "");
Expect(1, 119040, '\p{^Blk:		byzantine_Music}', "");
Expect(1, 119040, '\P{Blk:		byzantine_Music}', "");
Expect(0, 119040, '\P{^Blk:		byzantine_Music}', "");
Error('\p{Is_Block=/a/- BYZANTINE_Musical_Symbols}');
Error('\P{Is_Block=/a/- BYZANTINE_Musical_Symbols}');
Expect(1, 119039, '\p{Is_Block: byzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^Is_Block: byzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{Is_Block: byzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^Is_Block: byzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{Is_Block: byzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^Is_Block: byzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{Is_Block: byzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^Is_Block: byzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(0, 119039, '\p{^Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(0, 119039, '\P{Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(1, 119039, '\P{^Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(0, 119040, '\p{Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(1, 119040, '\p{^Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(1, 119040, '\P{Is_Block=- Byzantine_MUSICAL_symbols}', "");
Expect(0, 119040, '\P{^Is_Block=- Byzantine_MUSICAL_symbols}', "");
Error('\p{Is_Blk=-Byzantine_MUSIC/a/}');
Error('\P{Is_Blk=-Byzantine_MUSIC/a/}');
Expect(1, 119039, '\p{Is_Blk=byzantinemusic}', "");
Expect(0, 119039, '\p{^Is_Blk=byzantinemusic}', "");
Expect(0, 119039, '\P{Is_Blk=byzantinemusic}', "");
Expect(1, 119039, '\P{^Is_Blk=byzantinemusic}', "");
Expect(0, 119040, '\p{Is_Blk=byzantinemusic}', "");
Expect(1, 119040, '\p{^Is_Blk=byzantinemusic}', "");
Expect(1, 119040, '\P{Is_Blk=byzantinemusic}', "");
Expect(0, 119040, '\P{^Is_Blk=byzantinemusic}', "");
Expect(1, 119039, '\p{Is_Blk=-Byzantine_Music}', "");
Expect(0, 119039, '\p{^Is_Blk=-Byzantine_Music}', "");
Expect(0, 119039, '\P{Is_Blk=-Byzantine_Music}', "");
Expect(1, 119039, '\P{^Is_Blk=-Byzantine_Music}', "");
Expect(0, 119040, '\p{Is_Blk=-Byzantine_Music}', "");
Expect(1, 119040, '\p{^Is_Blk=-Byzantine_Music}', "");
Expect(1, 119040, '\P{Is_Blk=-Byzantine_Music}', "");
Expect(0, 119040, '\P{^Is_Blk=-Byzantine_Music}', "");
Error('\p{Block=_	cjk_Unified_IDEOGRAPHS/a/}');
Error('\P{Block=_	cjk_Unified_IDEOGRAPHS/a/}');
Expect(1, 40959, '\p{Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\p{^Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\P{Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\P{^Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\p{Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\p{^Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\P{Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\P{^Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\p{Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(0, 40959, '\p{^Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(0, 40959, '\P{Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(1, 40959, '\P{^Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(0, 40960, '\p{Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(1, 40960, '\p{^Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(1, 40960, '\P{Block= 	cjk_UNIFIED_Ideographs}', "");
Expect(0, 40960, '\P{^Block= 	cjk_UNIFIED_Ideographs}', "");
Error('\p{Blk=	:=CJK}');
Error('\P{Blk=	:=CJK}');
Expect(1, 40959, '\p{Blk=cjk}', "");
Expect(0, 40959, '\p{^Blk=cjk}', "");
Expect(0, 40959, '\P{Blk=cjk}', "");
Expect(1, 40959, '\P{^Blk=cjk}', "");
Expect(0, 40960, '\p{Blk=cjk}', "");
Expect(1, 40960, '\p{^Blk=cjk}', "");
Expect(1, 40960, '\P{Blk=cjk}', "");
Expect(0, 40960, '\P{^Blk=cjk}', "");
Expect(1, 40959, '\p{Blk= -cjk}', "");
Expect(0, 40959, '\p{^Blk= -cjk}', "");
Expect(0, 40959, '\P{Blk= -cjk}', "");
Expect(1, 40959, '\P{^Blk= -cjk}', "");
Expect(0, 40960, '\p{Blk= -cjk}', "");
Expect(1, 40960, '\p{^Blk= -cjk}', "");
Expect(1, 40960, '\P{Blk= -cjk}', "");
Expect(0, 40960, '\P{^Blk= -cjk}', "");
Error('\p{Is_Block=/a/_ CJK_Unified_Ideographs}');
Error('\P{Is_Block=/a/_ CJK_Unified_Ideographs}');
Expect(1, 40959, '\p{Is_Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\p{^Is_Block=cjkunifiedideographs}', "");
Expect(0, 40959, '\P{Is_Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\P{^Is_Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\p{Is_Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\p{^Is_Block=cjkunifiedideographs}', "");
Expect(1, 40960, '\P{Is_Block=cjkunifiedideographs}', "");
Expect(0, 40960, '\P{^Is_Block=cjkunifiedideographs}', "");
Expect(1, 40959, '\p{Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\p{^Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(0, 40959, '\P{Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(1, 40959, '\P{^Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\p{Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\p{^Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(1, 40960, '\P{Is_Block:  -CJK_Unified_Ideographs}', "");
Expect(0, 40960, '\P{^Is_Block:  -CJK_Unified_Ideographs}', "");
Error('\p{Is_Blk=/a/cjk}');
Error('\P{Is_Blk=/a/cjk}');
Expect(1, 40959, '\p{Is_Blk=cjk}', "");
Expect(0, 40959, '\p{^Is_Blk=cjk}', "");
Expect(0, 40959, '\P{Is_Blk=cjk}', "");
Expect(1, 40959, '\P{^Is_Blk=cjk}', "");
Expect(0, 40960, '\p{Is_Blk=cjk}', "");
Expect(1, 40960, '\p{^Is_Blk=cjk}', "");
Expect(1, 40960, '\P{Is_Blk=cjk}', "");
Expect(0, 40960, '\P{^Is_Blk=cjk}', "");
Expect(1, 40959, '\p{Is_Blk= cjk}', "");
Expect(0, 40959, '\p{^Is_Blk= cjk}', "");
Expect(0, 40959, '\P{Is_Blk= cjk}', "");
Expect(1, 40959, '\P{^Is_Blk= cjk}', "");
Expect(0, 40960, '\p{Is_Blk= cjk}', "");
Expect(1, 40960, '\p{^Is_Blk= cjk}', "");
Expect(1, 40960, '\P{Is_Blk= cjk}', "");
Expect(0, 40960, '\P{^Is_Blk= cjk}', "");
Error('\p{Block=/a/ cjk_Compatibility}');
Error('\P{Block=/a/ cjk_Compatibility}');
Expect(1, 13311, '\p{Block=cjkcompatibility}', "");
Expect(0, 13311, '\p{^Block=cjkcompatibility}', "");
Expect(0, 13311, '\P{Block=cjkcompatibility}', "");
Expect(1, 13311, '\P{^Block=cjkcompatibility}', "");
Expect(0, 13312, '\p{Block=cjkcompatibility}', "");
Expect(1, 13312, '\p{^Block=cjkcompatibility}', "");
Expect(1, 13312, '\P{Block=cjkcompatibility}', "");
Expect(0, 13312, '\P{^Block=cjkcompatibility}', "");
Expect(1, 13311, '\p{Block:  CJK_COMPATIBILITY}', "");
Expect(0, 13311, '\p{^Block:  CJK_COMPATIBILITY}', "");
Expect(0, 13311, '\P{Block:  CJK_COMPATIBILITY}', "");
Expect(1, 13311, '\P{^Block:  CJK_COMPATIBILITY}', "");
Expect(0, 13312, '\p{Block:  CJK_COMPATIBILITY}', "");
Expect(1, 13312, '\p{^Block:  CJK_COMPATIBILITY}', "");
Expect(1, 13312, '\P{Block:  CJK_COMPATIBILITY}', "");
Expect(0, 13312, '\P{^Block:  CJK_COMPATIBILITY}', "");
Error('\p{Blk=  CJK_Compat:=}');
Error('\P{Blk=  CJK_Compat:=}');
Expect(1, 13311, '\p{Blk=cjkcompat}', "");
Expect(0, 13311, '\p{^Blk=cjkcompat}', "");
Expect(0, 13311, '\P{Blk=cjkcompat}', "");
Expect(1, 13311, '\P{^Blk=cjkcompat}', "");
Expect(0, 13312, '\p{Blk=cjkcompat}', "");
Expect(1, 13312, '\p{^Blk=cjkcompat}', "");
Expect(1, 13312, '\P{Blk=cjkcompat}', "");
Expect(0, 13312, '\P{^Blk=cjkcompat}', "");
Expect(1, 13311, '\p{Blk= 	CJK_COMPAT}', "");
Expect(0, 13311, '\p{^Blk= 	CJK_COMPAT}', "");
Expect(0, 13311, '\P{Blk= 	CJK_COMPAT}', "");
Expect(1, 13311, '\P{^Blk= 	CJK_COMPAT}', "");
Expect(0, 13312, '\p{Blk= 	CJK_COMPAT}', "");
Expect(1, 13312, '\p{^Blk= 	CJK_COMPAT}', "");
Expect(1, 13312, '\P{Blk= 	CJK_COMPAT}', "");
Expect(0, 13312, '\P{^Blk= 	CJK_COMPAT}', "");
Error('\p{Is_Block=	/a/cjk_compatibility}');
Error('\P{Is_Block=	/a/cjk_compatibility}');
Expect(1, 13311, '\p{Is_Block: cjkcompatibility}', "");
Expect(0, 13311, '\p{^Is_Block: cjkcompatibility}', "");
Expect(0, 13311, '\P{Is_Block: cjkcompatibility}', "");
Expect(1, 13311, '\P{^Is_Block: cjkcompatibility}', "");
Expect(0, 13312, '\p{Is_Block: cjkcompatibility}', "");
Expect(1, 13312, '\p{^Is_Block: cjkcompatibility}', "");
Expect(1, 13312, '\P{Is_Block: cjkcompatibility}', "");
Expect(0, 13312, '\P{^Is_Block: cjkcompatibility}', "");
Expect(1, 13311, '\p{Is_Block= 	CJK_Compatibility}', "");
Expect(0, 13311, '\p{^Is_Block= 	CJK_Compatibility}', "");
Expect(0, 13311, '\P{Is_Block= 	CJK_Compatibility}', "");
Expect(1, 13311, '\P{^Is_Block= 	CJK_Compatibility}', "");
Expect(0, 13312, '\p{Is_Block= 	CJK_Compatibility}', "");
Expect(1, 13312, '\p{^Is_Block= 	CJK_Compatibility}', "");
Expect(1, 13312, '\P{Is_Block= 	CJK_Compatibility}', "");
Expect(0, 13312, '\P{^Is_Block= 	CJK_Compatibility}', "");
Error('\p{Is_Blk=-	CJK_COMPAT/a/}');
Error('\P{Is_Blk=-	CJK_COMPAT/a/}');
Expect(1, 13311, '\p{Is_Blk=cjkcompat}', "");
Expect(0, 13311, '\p{^Is_Blk=cjkcompat}', "");
Expect(0, 13311, '\P{Is_Blk=cjkcompat}', "");
Expect(1, 13311, '\P{^Is_Blk=cjkcompat}', "");
Expect(0, 13312, '\p{Is_Blk=cjkcompat}', "");
Expect(1, 13312, '\p{^Is_Blk=cjkcompat}', "");
Expect(1, 13312, '\P{Is_Blk=cjkcompat}', "");
Expect(0, 13312, '\P{^Is_Blk=cjkcompat}', "");
Expect(1, 13311, '\p{Is_Blk:-	CJK_Compat}', "");
Expect(0, 13311, '\p{^Is_Blk:-	CJK_Compat}', "");
Expect(0, 13311, '\P{Is_Blk:-	CJK_Compat}', "");
Expect(1, 13311, '\P{^Is_Blk:-	CJK_Compat}', "");
Expect(0, 13312, '\p{Is_Blk:-	CJK_Compat}', "");
Expect(1, 13312, '\p{^Is_Blk:-	CJK_Compat}', "");
Expect(1, 13312, '\P{Is_Blk:-	CJK_Compat}', "");
Expect(0, 13312, '\P{^Is_Blk:-	CJK_Compat}', "");
Error('\p{Block=	_CJK_compatibility_forms/a/}');
Error('\P{Block=	_CJK_compatibility_forms/a/}');
Expect(1, 65103, '\p{Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\P{Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\p{Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\P{Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\p{Block:cjk_Compatibility_Forms}', "");
Expect(0, 65103, '\p{^Block:cjk_Compatibility_Forms}', "");
Expect(0, 65103, '\P{Block:cjk_Compatibility_Forms}', "");
Expect(1, 65103, '\P{^Block:cjk_Compatibility_Forms}', "");
Expect(0, 65104, '\p{Block:cjk_Compatibility_Forms}', "");
Expect(1, 65104, '\p{^Block:cjk_Compatibility_Forms}', "");
Expect(1, 65104, '\P{Block:cjk_Compatibility_Forms}', "");
Expect(0, 65104, '\P{^Block:cjk_Compatibility_Forms}', "");
Error('\p{Blk=_cjk_Compat_Forms:=}');
Error('\P{Blk=_cjk_Compat_Forms:=}');
Expect(1, 65103, '\p{Blk=cjkcompatforms}', "");
Expect(0, 65103, '\p{^Blk=cjkcompatforms}', "");
Expect(0, 65103, '\P{Blk=cjkcompatforms}', "");
Expect(1, 65103, '\P{^Blk=cjkcompatforms}', "");
Expect(0, 65104, '\p{Blk=cjkcompatforms}', "");
Expect(1, 65104, '\p{^Blk=cjkcompatforms}', "");
Expect(1, 65104, '\P{Blk=cjkcompatforms}', "");
Expect(0, 65104, '\P{^Blk=cjkcompatforms}', "");
Expect(1, 65103, '\p{Blk=_	CJK_Compat_Forms}', "");
Expect(0, 65103, '\p{^Blk=_	CJK_Compat_Forms}', "");
Expect(0, 65103, '\P{Blk=_	CJK_Compat_Forms}', "");
Expect(1, 65103, '\P{^Blk=_	CJK_Compat_Forms}', "");
Expect(0, 65104, '\p{Blk=_	CJK_Compat_Forms}', "");
Expect(1, 65104, '\p{^Blk=_	CJK_Compat_Forms}', "");
Expect(1, 65104, '\P{Blk=_	CJK_Compat_Forms}', "");
Expect(0, 65104, '\P{^Blk=_	CJK_Compat_Forms}', "");
Error('\p{Is_Block=-:=CJK_COMPATIBILITY_Forms}');
Error('\P{Is_Block=-:=CJK_COMPATIBILITY_Forms}');
Expect(1, 65103, '\p{Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65103, '\P{Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\p{Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65104, '\P{Is_Block=cjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^Is_Block=cjkcompatibilityforms}', "");
Expect(1, 65103, '\p{Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65103, '\p{^Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65103, '\P{Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65103, '\P{^Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65104, '\p{Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65104, '\p{^Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65104, '\P{Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65104, '\P{^Is_Block=  CJK_COMPATIBILITY_FORMS}', "");
Error('\p{Is_Blk=/a/ 	CJK_compat_FORMS}');
Error('\P{Is_Blk=/a/ 	CJK_compat_FORMS}');
Expect(1, 65103, '\p{Is_Blk: cjkcompatforms}', "");
Expect(0, 65103, '\p{^Is_Blk: cjkcompatforms}', "");
Expect(0, 65103, '\P{Is_Blk: cjkcompatforms}', "");
Expect(1, 65103, '\P{^Is_Blk: cjkcompatforms}', "");
Expect(0, 65104, '\p{Is_Blk: cjkcompatforms}', "");
Expect(1, 65104, '\p{^Is_Blk: cjkcompatforms}', "");
Expect(1, 65104, '\P{Is_Blk: cjkcompatforms}', "");
Expect(0, 65104, '\P{^Is_Blk: cjkcompatforms}', "");
Expect(1, 65103, '\p{Is_Blk= CJK_compat_Forms}', "");
Expect(0, 65103, '\p{^Is_Blk= CJK_compat_Forms}', "");
Expect(0, 65103, '\P{Is_Blk= CJK_compat_Forms}', "");
Expect(1, 65103, '\P{^Is_Blk= CJK_compat_Forms}', "");
Expect(0, 65104, '\p{Is_Blk= CJK_compat_Forms}', "");
Expect(1, 65104, '\p{^Is_Blk= CJK_compat_Forms}', "");
Expect(1, 65104, '\P{Is_Blk= CJK_compat_Forms}', "");
Expect(0, 65104, '\P{^Is_Blk= CJK_compat_Forms}', "");
Error('\p{Block=_/a/cjk_COMPATIBILITY_Ideographs}');
Error('\P{Block=_/a/cjk_COMPATIBILITY_Ideographs}');
Expect(1, 64255, '\p{Block:cjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^Block:cjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{Block:cjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^Block:cjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{Block:cjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^Block:cjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{Block:cjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^Block:cjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(0, 64255, '\p{^Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(0, 64255, '\P{Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(1, 64255, '\P{^Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(0, 64256, '\p{Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(1, 64256, '\p{^Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(1, 64256, '\P{Block=-CJK_COMPATIBILITY_ideographs}', "");
Expect(0, 64256, '\P{^Block=-CJK_COMPATIBILITY_ideographs}', "");
Error('\p{Blk=_/a/CJK_Compat_Ideographs}');
Error('\P{Blk=_/a/CJK_Compat_Ideographs}');
Expect(1, 64255, '\p{Blk=cjkcompatideographs}', "");
Expect(0, 64255, '\p{^Blk=cjkcompatideographs}', "");
Expect(0, 64255, '\P{Blk=cjkcompatideographs}', "");
Expect(1, 64255, '\P{^Blk=cjkcompatideographs}', "");
Expect(0, 64256, '\p{Blk=cjkcompatideographs}', "");
Expect(1, 64256, '\p{^Blk=cjkcompatideographs}', "");
Expect(1, 64256, '\P{Blk=cjkcompatideographs}', "");
Expect(0, 64256, '\P{^Blk=cjkcompatideographs}', "");
Expect(1, 64255, '\p{Blk:   	 cjk_Compat_ideographs}', "");
Expect(0, 64255, '\p{^Blk:   	 cjk_Compat_ideographs}', "");
Expect(0, 64255, '\P{Blk:   	 cjk_Compat_ideographs}', "");
Expect(1, 64255, '\P{^Blk:   	 cjk_Compat_ideographs}', "");
Expect(0, 64256, '\p{Blk:   	 cjk_Compat_ideographs}', "");
Expect(1, 64256, '\p{^Blk:   	 cjk_Compat_ideographs}', "");
Expect(1, 64256, '\P{Blk:   	 cjk_Compat_ideographs}', "");
Expect(0, 64256, '\P{^Blk:   	 cjk_Compat_ideographs}', "");
Error('\p{Is_Block=/a/	cjk_COMPATIBILITY_IDEOGRAPHS}');
Error('\P{Is_Block=/a/	cjk_COMPATIBILITY_IDEOGRAPHS}');
Expect(1, 64255, '\p{Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{Is_Block=cjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^Is_Block=cjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\p{^Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\P{Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(1, 64255, '\P{^Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\p{Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\p{^Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\P{Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\P{^Is_Block:   -	CJK_Compatibility_Ideographs}', "");
Error('\p{Is_Blk=	_cjk_compat_ideographs/a/}');
Error('\P{Is_Blk=	_cjk_compat_ideographs/a/}');
Expect(1, 64255, '\p{Is_Blk:cjkcompatideographs}', "");
Expect(0, 64255, '\p{^Is_Blk:cjkcompatideographs}', "");
Expect(0, 64255, '\P{Is_Blk:cjkcompatideographs}', "");
Expect(1, 64255, '\P{^Is_Blk:cjkcompatideographs}', "");
Expect(0, 64256, '\p{Is_Blk:cjkcompatideographs}', "");
Expect(1, 64256, '\p{^Is_Blk:cjkcompatideographs}', "");
Expect(1, 64256, '\P{Is_Blk:cjkcompatideographs}', "");
Expect(0, 64256, '\P{^Is_Blk:cjkcompatideographs}', "");
Expect(1, 64255, '\p{Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(0, 64255, '\p{^Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(0, 64255, '\P{Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(1, 64255, '\P{^Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(0, 64256, '\p{Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(1, 64256, '\p{^Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(1, 64256, '\P{Is_Blk=_CJK_Compat_Ideographs}', "");
Expect(0, 64256, '\P{^Is_Blk=_CJK_Compat_Ideographs}', "");
Error('\p{Block=/a/	CJK_Compatibility_IDEOGRAPHS_SUPPLEMENT}');
Error('\P{Block=/a/	CJK_Compatibility_IDEOGRAPHS_SUPPLEMENT}');
Expect(1, 195103, '\p{Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(0, 195103, '\p{^Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(0, 195103, '\P{Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(1, 195103, '\P{^Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(0, 195104, '\p{Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(1, 195104, '\p{^Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(1, 195104, '\P{Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Expect(0, 195104, '\P{^Block=CJK_Compatibility_Ideographs_SUPPLEMENT}', "");
Error('\p{Blk=-/a/CJK_COMPAT_ideographs_Sup}');
Error('\P{Blk=-/a/CJK_COMPAT_ideographs_Sup}');
Expect(1, 195103, '\p{Blk:   cjkcompatideographssup}', "");
Expect(0, 195103, '\p{^Blk:   cjkcompatideographssup}', "");
Expect(0, 195103, '\P{Blk:   cjkcompatideographssup}', "");
Expect(1, 195103, '\P{^Blk:   cjkcompatideographssup}', "");
Expect(0, 195104, '\p{Blk:   cjkcompatideographssup}', "");
Expect(1, 195104, '\p{^Blk:   cjkcompatideographssup}', "");
Expect(1, 195104, '\P{Blk:   cjkcompatideographssup}', "");
Expect(0, 195104, '\P{^Blk:   cjkcompatideographssup}', "");
Expect(1, 195103, '\p{Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(0, 195103, '\p{^Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(0, 195103, '\P{Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(1, 195103, '\P{^Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(0, 195104, '\p{Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(1, 195104, '\p{^Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(1, 195104, '\P{Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Expect(0, 195104, '\P{^Blk=		CJK_Compat_IDEOGRAPHS_SUP}', "");
Error('\p{Is_Block: _-CJK_compatibility_ideographs_SUPPLEMENT/a/}');
Error('\P{Is_Block: _-CJK_compatibility_ideographs_SUPPLEMENT/a/}');
Expect(1, 195103, '\p{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^Is_Block=cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(0, 195103, '\p{^Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(0, 195103, '\P{Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(1, 195103, '\P{^Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(0, 195104, '\p{Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(1, 195104, '\p{^Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(1, 195104, '\P{Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Expect(0, 195104, '\P{^Is_Block=-_CJK_COMPATIBILITY_IDEOGRAPHS_Supplement}', "");
Error('\p{Is_Blk= /a/CJK_Compat_Ideographs_Sup}');
Error('\P{Is_Blk= /a/CJK_Compat_Ideographs_Sup}');
Expect(1, 195103, '\p{Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195103, '\p{^Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195103, '\P{Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195103, '\P{^Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195104, '\p{Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195104, '\p{^Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195104, '\P{Is_Blk=cjkcompatideographssup}', "");
Expect(0, 195104, '\P{^Is_Blk=cjkcompatideographssup}', "");
Expect(1, 195103, '\p{Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(0, 195103, '\p{^Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(0, 195103, '\P{Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(1, 195103, '\P{^Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(0, 195104, '\p{Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(1, 195104, '\p{^Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(1, 195104, '\P{Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Expect(0, 195104, '\P{^Is_Blk=_ CJK_Compat_Ideographs_SUP}', "");
Error('\p{Block=/a/ CJK_Unified_Ideographs_Extension_a}');
Error('\P{Block=/a/ CJK_Unified_Ideographs_Extension_a}');
Expect(1, 19903, '\p{Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{Block=cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^Block=cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19903, '\p{^Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19903, '\P{Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(1, 19903, '\P{^Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19904, '\p{Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(1, 19904, '\p{^Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(1, 19904, '\P{Block=--CJK_Unified_Ideographs_Extension_A}', "");
Expect(0, 19904, '\P{^Block=--CJK_Unified_Ideographs_Extension_A}', "");
Error('\p{Blk= :=CJK_Ext_A}');
Error('\P{Blk= :=CJK_Ext_A}');
Expect(1, 19903, '\p{Blk=cjkexta}', "");
Expect(0, 19903, '\p{^Blk=cjkexta}', "");
Expect(0, 19903, '\P{Blk=cjkexta}', "");
Expect(1, 19903, '\P{^Blk=cjkexta}', "");
Expect(0, 19904, '\p{Blk=cjkexta}', "");
Expect(1, 19904, '\p{^Blk=cjkexta}', "");
Expect(1, 19904, '\P{Blk=cjkexta}', "");
Expect(0, 19904, '\P{^Blk=cjkexta}', "");
Expect(1, 19903, '\p{Blk=-CJK_EXT_A}', "");
Expect(0, 19903, '\p{^Blk=-CJK_EXT_A}', "");
Expect(0, 19903, '\P{Blk=-CJK_EXT_A}', "");
Expect(1, 19903, '\P{^Blk=-CJK_EXT_A}', "");
Expect(0, 19904, '\p{Blk=-CJK_EXT_A}', "");
Expect(1, 19904, '\p{^Blk=-CJK_EXT_A}', "");
Expect(1, 19904, '\P{Blk=-CJK_EXT_A}', "");
Expect(0, 19904, '\P{^Blk=-CJK_EXT_A}', "");
Error('\p{Is_Block=_	CJK_Unified_Ideographs_Extension_a/a/}');
Error('\P{Is_Block=_	CJK_Unified_Ideographs_Extension_a/a/}');
Expect(1, 19903, '\p{Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^Is_Block:   cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(0, 19903, '\p{^Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(0, 19903, '\P{Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(1, 19903, '\P{^Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(0, 19904, '\p{Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(1, 19904, '\p{^Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(1, 19904, '\P{Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Expect(0, 19904, '\P{^Is_Block:  _CJK_unified_Ideographs_Extension_a}', "");
Error('\p{Is_Blk=	_cjk_ext_A/a/}');
Error('\P{Is_Blk=	_cjk_ext_A/a/}');
Expect(1, 19903, '\p{Is_Blk=cjkexta}', "");
Expect(0, 19903, '\p{^Is_Blk=cjkexta}', "");
Expect(0, 19903, '\P{Is_Blk=cjkexta}', "");
Expect(1, 19903, '\P{^Is_Blk=cjkexta}', "");
Expect(0, 19904, '\p{Is_Blk=cjkexta}', "");
Expect(1, 19904, '\p{^Is_Blk=cjkexta}', "");
Expect(1, 19904, '\P{Is_Blk=cjkexta}', "");
Expect(0, 19904, '\P{^Is_Blk=cjkexta}', "");
Expect(1, 19903, '\p{Is_Blk=- CJK_Ext_A}', "");
Expect(0, 19903, '\p{^Is_Blk=- CJK_Ext_A}', "");
Expect(0, 19903, '\P{Is_Blk=- CJK_Ext_A}', "");
Expect(1, 19903, '\P{^Is_Blk=- CJK_Ext_A}', "");
Expect(0, 19904, '\p{Is_Blk=- CJK_Ext_A}', "");
Expect(1, 19904, '\p{^Is_Blk=- CJK_Ext_A}', "");
Expect(1, 19904, '\P{Is_Blk=- CJK_Ext_A}', "");
Expect(0, 19904, '\P{^Is_Blk=- CJK_Ext_A}', "");
Error('\p{Block=/a/ _CJK_unified_IDEOGRAPHS_Extension_B}');
Error('\P{Block=/a/ _CJK_unified_IDEOGRAPHS_Extension_B}');
Expect(1, 173791, '\p{Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(0, 173791, '\p{^Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(0, 173791, '\P{Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(1, 173791, '\P{^Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(0, 173792, '\p{Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(1, 173792, '\p{^Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(1, 173792, '\P{Block: cjk_Unified_Ideographs_Extension_B}', "");
Expect(0, 173792, '\P{^Block: cjk_Unified_Ideographs_Extension_B}', "");
Error('\p{Blk=/a/		cjk_ext_B}');
Error('\P{Blk=/a/		cjk_ext_B}');
Expect(1, 173791, '\p{Blk=cjkextb}', "");
Expect(0, 173791, '\p{^Blk=cjkextb}', "");
Expect(0, 173791, '\P{Blk=cjkextb}', "");
Expect(1, 173791, '\P{^Blk=cjkextb}', "");
Expect(0, 173792, '\p{Blk=cjkextb}', "");
Expect(1, 173792, '\p{^Blk=cjkextb}', "");
Expect(1, 173792, '\P{Blk=cjkextb}', "");
Expect(0, 173792, '\P{^Blk=cjkextb}', "");
Expect(1, 173791, '\p{Blk=-	CJK_Ext_B}', "");
Expect(0, 173791, '\p{^Blk=-	CJK_Ext_B}', "");
Expect(0, 173791, '\P{Blk=-	CJK_Ext_B}', "");
Expect(1, 173791, '\P{^Blk=-	CJK_Ext_B}', "");
Expect(0, 173792, '\p{Blk=-	CJK_Ext_B}', "");
Expect(1, 173792, '\p{^Blk=-	CJK_Ext_B}', "");
Expect(1, 173792, '\P{Blk=-	CJK_Ext_B}', "");
Expect(0, 173792, '\P{^Blk=-	CJK_Ext_B}', "");
Error('\p{Is_Block=-:=cjk_Unified_Ideographs_Extension_B}');
Error('\P{Is_Block=-:=cjk_Unified_Ideographs_Extension_B}');
Expect(1, 173791, '\p{Is_Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^Is_Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{Is_Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^Is_Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{Is_Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^Is_Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{Is_Block=cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^Is_Block=cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(0, 173791, '\p{^Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(0, 173791, '\P{Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(1, 173791, '\P{^Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(0, 173792, '\p{Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(1, 173792, '\p{^Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(1, 173792, '\P{Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Expect(0, 173792, '\P{^Is_Block: -_CJK_Unified_ideographs_Extension_B}', "");
Error('\p{Is_Blk=-	CJK_EXT_B:=}');
Error('\P{Is_Blk=-	CJK_EXT_B:=}');
Expect(1, 173791, '\p{Is_Blk=cjkextb}', "");
Expect(0, 173791, '\p{^Is_Blk=cjkextb}', "");
Expect(0, 173791, '\P{Is_Blk=cjkextb}', "");
Expect(1, 173791, '\P{^Is_Blk=cjkextb}', "");
Expect(0, 173792, '\p{Is_Blk=cjkextb}', "");
Expect(1, 173792, '\p{^Is_Blk=cjkextb}', "");
Expect(1, 173792, '\P{Is_Blk=cjkextb}', "");
Expect(0, 173792, '\P{^Is_Blk=cjkextb}', "");
Expect(1, 173791, '\p{Is_Blk=--cjk_ext_b}', "");
Expect(0, 173791, '\p{^Is_Blk=--cjk_ext_b}', "");
Expect(0, 173791, '\P{Is_Blk=--cjk_ext_b}', "");
Expect(1, 173791, '\P{^Is_Blk=--cjk_ext_b}', "");
Expect(0, 173792, '\p{Is_Blk=--cjk_ext_b}', "");
Expect(1, 173792, '\p{^Is_Blk=--cjk_ext_b}', "");
Expect(1, 173792, '\P{Is_Blk=--cjk_ext_b}', "");
Expect(0, 173792, '\P{^Is_Blk=--cjk_ext_b}', "");
Error('\p{Block=_ cjk_Unified_Ideographs_Extension_C:=}');
Error('\P{Block=_ cjk_Unified_Ideographs_Extension_C:=}');
Expect(1, 177983, '\p{Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\p{^Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\P{Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(1, 177983, '\P{^Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\p{Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\p{^Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\P{Block=--cjk_unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\P{^Block=--cjk_unified_Ideographs_Extension_C}', "");
Error('\p{Blk=/a/		cjk_Ext_C}');
Error('\P{Blk=/a/		cjk_Ext_C}');
Expect(1, 177983, '\p{Blk=cjkextc}', "");
Expect(0, 177983, '\p{^Blk=cjkextc}', "");
Expect(0, 177983, '\P{Blk=cjkextc}', "");
Expect(1, 177983, '\P{^Blk=cjkextc}', "");
Expect(0, 177984, '\p{Blk=cjkextc}', "");
Expect(1, 177984, '\p{^Blk=cjkextc}', "");
Expect(1, 177984, '\P{Blk=cjkextc}', "");
Expect(0, 177984, '\P{^Blk=cjkextc}', "");
Expect(1, 177983, '\p{Blk=CJK_EXT_C}', "");
Expect(0, 177983, '\p{^Blk=CJK_EXT_C}', "");
Expect(0, 177983, '\P{Blk=CJK_EXT_C}', "");
Expect(1, 177983, '\P{^Blk=CJK_EXT_C}', "");
Expect(0, 177984, '\p{Blk=CJK_EXT_C}', "");
Expect(1, 177984, '\p{^Blk=CJK_EXT_C}', "");
Expect(1, 177984, '\P{Blk=CJK_EXT_C}', "");
Expect(0, 177984, '\P{^Blk=CJK_EXT_C}', "");
Error('\p{Is_Block=-cjk_Unified_Ideographs_Extension_C:=}');
Error('\P{Is_Block=-cjk_Unified_Ideographs_Extension_C:=}');
Expect(1, 177983, '\p{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{Is_Block=cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^Is_Block=cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(0, 177983, '\p{^Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(0, 177983, '\P{Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(1, 177983, '\P{^Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(0, 177984, '\p{Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(1, 177984, '\p{^Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(1, 177984, '\P{Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Expect(0, 177984, '\P{^Is_Block=__CJK_unified_Ideographs_extension_c}', "");
Error('\p{Is_Blk::= CJK_Ext_C}');
Error('\P{Is_Blk::= CJK_Ext_C}');
Expect(1, 177983, '\p{Is_Blk=cjkextc}', "");
Expect(0, 177983, '\p{^Is_Blk=cjkextc}', "");
Expect(0, 177983, '\P{Is_Blk=cjkextc}', "");
Expect(1, 177983, '\P{^Is_Blk=cjkextc}', "");
Expect(0, 177984, '\p{Is_Blk=cjkextc}', "");
Expect(1, 177984, '\p{^Is_Blk=cjkextc}', "");
Expect(1, 177984, '\P{Is_Blk=cjkextc}', "");
Expect(0, 177984, '\P{^Is_Blk=cjkextc}', "");
Expect(1, 177983, '\p{Is_Blk= cjk_ext_C}', "");
Expect(0, 177983, '\p{^Is_Blk= cjk_ext_C}', "");
Expect(0, 177983, '\P{Is_Blk= cjk_ext_C}', "");
Expect(1, 177983, '\P{^Is_Blk= cjk_ext_C}', "");
Expect(0, 177984, '\p{Is_Blk= cjk_ext_C}', "");
Expect(1, 177984, '\p{^Is_Blk= cjk_ext_C}', "");
Expect(1, 177984, '\P{Is_Blk= cjk_ext_C}', "");
Expect(0, 177984, '\P{^Is_Blk= cjk_ext_C}', "");
Error('\p{Block=CJK_Unified_ideographs_Extension_d/a/}');
Error('\P{Block=CJK_Unified_ideographs_Extension_d/a/}');
Expect(1, 178207, '\p{Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(0, 178207, '\p{^Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(0, 178207, '\P{Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(1, 178207, '\P{^Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(0, 178208, '\p{Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(1, 178208, '\p{^Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(1, 178208, '\P{Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Expect(0, 178208, '\P{^Block=		CJK_UNIFIED_Ideographs_Extension_D}', "");
Error('\p{Blk=:=_ cjk_Ext_D}');
Error('\P{Blk=:=_ cjk_Ext_D}');
Expect(1, 178207, '\p{Blk=cjkextd}', "");
Expect(0, 178207, '\p{^Blk=cjkextd}', "");
Expect(0, 178207, '\P{Blk=cjkextd}', "");
Expect(1, 178207, '\P{^Blk=cjkextd}', "");
Expect(0, 178208, '\p{Blk=cjkextd}', "");
Expect(1, 178208, '\p{^Blk=cjkextd}', "");
Expect(1, 178208, '\P{Blk=cjkextd}', "");
Expect(0, 178208, '\P{^Blk=cjkextd}', "");
Expect(1, 178207, '\p{Blk= CJK_Ext_D}', "");
Expect(0, 178207, '\p{^Blk= CJK_Ext_D}', "");
Expect(0, 178207, '\P{Blk= CJK_Ext_D}', "");
Expect(1, 178207, '\P{^Blk= CJK_Ext_D}', "");
Expect(0, 178208, '\p{Blk= CJK_Ext_D}', "");
Expect(1, 178208, '\p{^Blk= CJK_Ext_D}', "");
Expect(1, 178208, '\P{Blk= CJK_Ext_D}', "");
Expect(0, 178208, '\P{^Blk= CJK_Ext_D}', "");
Error('\p{Is_Block=-/a/CJK_Unified_Ideographs_Extension_d}');
Error('\P{Is_Block=-/a/CJK_Unified_Ideographs_Extension_d}');
Expect(1, 178207, '\p{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{Is_Block=cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^Is_Block=cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(0, 178207, '\p{^Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(0, 178207, '\P{Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(1, 178207, '\P{^Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(0, 178208, '\p{Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(1, 178208, '\p{^Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(1, 178208, '\P{Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Expect(0, 178208, '\P{^Is_Block=	-cjk_Unified_ideographs_Extension_D}', "");
Error('\p{Is_Blk: :=-	CJK_EXT_D}');
Error('\P{Is_Blk: :=-	CJK_EXT_D}');
Expect(1, 178207, '\p{Is_Blk=cjkextd}', "");
Expect(0, 178207, '\p{^Is_Blk=cjkextd}', "");
Expect(0, 178207, '\P{Is_Blk=cjkextd}', "");
Expect(1, 178207, '\P{^Is_Blk=cjkextd}', "");
Expect(0, 178208, '\p{Is_Blk=cjkextd}', "");
Expect(1, 178208, '\p{^Is_Blk=cjkextd}', "");
Expect(1, 178208, '\P{Is_Blk=cjkextd}', "");
Expect(0, 178208, '\P{^Is_Blk=cjkextd}', "");
Expect(1, 178207, '\p{Is_Blk= CJK_EXT_d}', "");
Expect(0, 178207, '\p{^Is_Blk= CJK_EXT_d}', "");
Expect(0, 178207, '\P{Is_Blk= CJK_EXT_d}', "");
Expect(1, 178207, '\P{^Is_Blk= CJK_EXT_d}', "");
Expect(0, 178208, '\p{Is_Blk= CJK_EXT_d}', "");
Expect(1, 178208, '\p{^Is_Blk= CJK_EXT_d}', "");
Expect(1, 178208, '\P{Is_Blk= CJK_EXT_d}', "");
Expect(0, 178208, '\P{^Is_Blk= CJK_EXT_d}', "");
Error('\p{Block=/a/_CJK_Radicals_SUPPLEMENT}');
Error('\P{Block=/a/_CJK_Radicals_SUPPLEMENT}');
Expect(1, 12031, '\p{Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\p{^Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\P{Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\P{^Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\p{Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\p{^Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\P{Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\P{^Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\p{Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12031, '\p{^Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12031, '\P{Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12031, '\P{^Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12032, '\p{Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12032, '\p{^Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12032, '\P{Block=--CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12032, '\P{^Block=--CJK_RADICALS_SUPPLEMENT}', "");
Error('\p{Blk=_:=CJK_Radicals_SUP}');
Error('\P{Blk=_:=CJK_Radicals_SUP}');
Expect(1, 12031, '\p{Blk=cjkradicalssup}', "");
Expect(0, 12031, '\p{^Blk=cjkradicalssup}', "");
Expect(0, 12031, '\P{Blk=cjkradicalssup}', "");
Expect(1, 12031, '\P{^Blk=cjkradicalssup}', "");
Expect(0, 12032, '\p{Blk=cjkradicalssup}', "");
Expect(1, 12032, '\p{^Blk=cjkradicalssup}', "");
Expect(1, 12032, '\P{Blk=cjkradicalssup}', "");
Expect(0, 12032, '\P{^Blk=cjkradicalssup}', "");
Expect(1, 12031, '\p{Blk=-cjk_radicals_Sup}', "");
Expect(0, 12031, '\p{^Blk=-cjk_radicals_Sup}', "");
Expect(0, 12031, '\P{Blk=-cjk_radicals_Sup}', "");
Expect(1, 12031, '\P{^Blk=-cjk_radicals_Sup}', "");
Expect(0, 12032, '\p{Blk=-cjk_radicals_Sup}', "");
Expect(1, 12032, '\p{^Blk=-cjk_radicals_Sup}', "");
Expect(1, 12032, '\P{Blk=-cjk_radicals_Sup}', "");
Expect(0, 12032, '\P{^Blk=-cjk_radicals_Sup}', "");
Error('\p{Is_Block=_/a/CJK_radicals_Supplement}');
Error('\P{Is_Block=_/a/CJK_radicals_Supplement}');
Expect(1, 12031, '\p{Is_Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\p{^Is_Block=cjkradicalssupplement}', "");
Expect(0, 12031, '\P{Is_Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\P{^Is_Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\p{Is_Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\p{^Is_Block=cjkradicalssupplement}', "");
Expect(1, 12032, '\P{Is_Block=cjkradicalssupplement}', "");
Expect(0, 12032, '\P{^Is_Block=cjkradicalssupplement}', "");
Expect(1, 12031, '\p{Is_Block= -cjk_Radicals_supplement}', "");
Expect(0, 12031, '\p{^Is_Block= -cjk_Radicals_supplement}', "");
Expect(0, 12031, '\P{Is_Block= -cjk_Radicals_supplement}', "");
Expect(1, 12031, '\P{^Is_Block= -cjk_Radicals_supplement}', "");
Expect(0, 12032, '\p{Is_Block= -cjk_Radicals_supplement}', "");
Expect(1, 12032, '\p{^Is_Block= -cjk_Radicals_supplement}', "");
Expect(1, 12032, '\P{Is_Block= -cjk_Radicals_supplement}', "");
Expect(0, 12032, '\P{^Is_Block= -cjk_Radicals_supplement}', "");
Error('\p{Is_Blk=_:=cjk_radicals_sup}');
Error('\P{Is_Blk=_:=cjk_radicals_sup}');
Expect(1, 12031, '\p{Is_Blk=cjkradicalssup}', "");
Expect(0, 12031, '\p{^Is_Blk=cjkradicalssup}', "");
Expect(0, 12031, '\P{Is_Blk=cjkradicalssup}', "");
Expect(1, 12031, '\P{^Is_Blk=cjkradicalssup}', "");
Expect(0, 12032, '\p{Is_Blk=cjkradicalssup}', "");
Expect(1, 12032, '\p{^Is_Blk=cjkradicalssup}', "");
Expect(1, 12032, '\P{Is_Blk=cjkradicalssup}', "");
Expect(0, 12032, '\P{^Is_Blk=cjkradicalssup}', "");
Expect(1, 12031, '\p{Is_Blk= -CJK_Radicals_sup}', "");
Expect(0, 12031, '\p{^Is_Blk= -CJK_Radicals_sup}', "");
Expect(0, 12031, '\P{Is_Blk= -CJK_Radicals_sup}', "");
Expect(1, 12031, '\P{^Is_Blk= -CJK_Radicals_sup}', "");
Expect(0, 12032, '\p{Is_Blk= -CJK_Radicals_sup}', "");
Expect(1, 12032, '\p{^Is_Blk= -CJK_Radicals_sup}', "");
Expect(1, 12032, '\P{Is_Blk= -CJK_Radicals_sup}', "");
Expect(0, 12032, '\P{^Is_Blk= -CJK_Radicals_sup}', "");
Error('\p{Block:	 	CJK_Strokes/a/}');
Error('\P{Block:	 	CJK_Strokes/a/}');
Expect(1, 12783, '\p{Block: cjkstrokes}', "");
Expect(0, 12783, '\p{^Block: cjkstrokes}', "");
Expect(0, 12783, '\P{Block: cjkstrokes}', "");
Expect(1, 12783, '\P{^Block: cjkstrokes}', "");
Expect(0, 12784, '\p{Block: cjkstrokes}', "");
Expect(1, 12784, '\p{^Block: cjkstrokes}', "");
Expect(1, 12784, '\P{Block: cjkstrokes}', "");
Expect(0, 12784, '\P{^Block: cjkstrokes}', "");
Expect(1, 12783, '\p{Block=	-cjk_Strokes}', "");
Expect(0, 12783, '\p{^Block=	-cjk_Strokes}', "");
Expect(0, 12783, '\P{Block=	-cjk_Strokes}', "");
Expect(1, 12783, '\P{^Block=	-cjk_Strokes}', "");
Expect(0, 12784, '\p{Block=	-cjk_Strokes}', "");
Expect(1, 12784, '\p{^Block=	-cjk_Strokes}', "");
Expect(1, 12784, '\P{Block=	-cjk_Strokes}', "");
Expect(0, 12784, '\P{^Block=	-cjk_Strokes}', "");
Error('\p{Blk=:=  cjk_strokes}');
Error('\P{Blk=:=  cjk_strokes}');
Expect(1, 12783, '\p{Blk=cjkstrokes}', "");
Expect(0, 12783, '\p{^Blk=cjkstrokes}', "");
Expect(0, 12783, '\P{Blk=cjkstrokes}', "");
Expect(1, 12783, '\P{^Blk=cjkstrokes}', "");
Expect(0, 12784, '\p{Blk=cjkstrokes}', "");
Expect(1, 12784, '\p{^Blk=cjkstrokes}', "");
Expect(1, 12784, '\P{Blk=cjkstrokes}', "");
Expect(0, 12784, '\P{^Blk=cjkstrokes}', "");
Expect(1, 12783, '\p{Blk:    _CJK_strokes}', "");
Expect(0, 12783, '\p{^Blk:    _CJK_strokes}', "");
Expect(0, 12783, '\P{Blk:    _CJK_strokes}', "");
Expect(1, 12783, '\P{^Blk:    _CJK_strokes}', "");
Expect(0, 12784, '\p{Blk:    _CJK_strokes}', "");
Expect(1, 12784, '\p{^Blk:    _CJK_strokes}', "");
Expect(1, 12784, '\P{Blk:    _CJK_strokes}', "");
Expect(0, 12784, '\P{^Blk:    _CJK_strokes}', "");
Error('\p{Is_Block=:=-	cjk_STROKES}');
Error('\P{Is_Block=:=-	cjk_STROKES}');
Expect(1, 12783, '\p{Is_Block=cjkstrokes}', "");
Expect(0, 12783, '\p{^Is_Block=cjkstrokes}', "");
Expect(0, 12783, '\P{Is_Block=cjkstrokes}', "");
Expect(1, 12783, '\P{^Is_Block=cjkstrokes}', "");
Expect(0, 12784, '\p{Is_Block=cjkstrokes}', "");
Expect(1, 12784, '\p{^Is_Block=cjkstrokes}', "");
Expect(1, 12784, '\P{Is_Block=cjkstrokes}', "");
Expect(0, 12784, '\P{^Is_Block=cjkstrokes}', "");
Expect(1, 12783, '\p{Is_Block=-CJK_Strokes}', "");
Expect(0, 12783, '\p{^Is_Block=-CJK_Strokes}', "");
Expect(0, 12783, '\P{Is_Block=-CJK_Strokes}', "");
Expect(1, 12783, '\P{^Is_Block=-CJK_Strokes}', "");
Expect(0, 12784, '\p{Is_Block=-CJK_Strokes}', "");
Expect(1, 12784, '\p{^Is_Block=-CJK_Strokes}', "");
Expect(1, 12784, '\P{Is_Block=-CJK_Strokes}', "");
Expect(0, 12784, '\P{^Is_Block=-CJK_Strokes}', "");
Error('\p{Is_Blk:-CJK_STROKES/a/}');
Error('\P{Is_Blk:-CJK_STROKES/a/}');
Expect(1, 12783, '\p{Is_Blk=cjkstrokes}', "");
Expect(0, 12783, '\p{^Is_Blk=cjkstrokes}', "");
Expect(0, 12783, '\P{Is_Blk=cjkstrokes}', "");
Expect(1, 12783, '\P{^Is_Blk=cjkstrokes}', "");
Expect(0, 12784, '\p{Is_Blk=cjkstrokes}', "");
Expect(1, 12784, '\p{^Is_Blk=cjkstrokes}', "");
Expect(1, 12784, '\P{Is_Blk=cjkstrokes}', "");
Expect(0, 12784, '\P{^Is_Blk=cjkstrokes}', "");
Expect(1, 12783, '\p{Is_Blk=	 CJK_STROKES}', "");
Expect(0, 12783, '\p{^Is_Blk=	 CJK_STROKES}', "");
Expect(0, 12783, '\P{Is_Blk=	 CJK_STROKES}', "");
Expect(1, 12783, '\P{^Is_Blk=	 CJK_STROKES}', "");
Expect(0, 12784, '\p{Is_Blk=	 CJK_STROKES}', "");
Expect(1, 12784, '\p{^Is_Blk=	 CJK_STROKES}', "");
Expect(1, 12784, '\P{Is_Blk=	 CJK_STROKES}', "");
Expect(0, 12784, '\P{^Is_Blk=	 CJK_STROKES}', "");
Error('\p{Block=-/a/CJK_SYMBOLS_AND_PUNCTUATION}');
Error('\P{Block=-/a/CJK_SYMBOLS_AND_PUNCTUATION}');
Expect(1, 12351, '\p{Block=cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^Block=cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{Block=cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^Block=cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{Block=cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^Block=cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{Block=cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^Block=cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(0, 12351, '\p{^Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(0, 12351, '\P{Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(1, 12351, '\P{^Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(0, 12352, '\p{Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(1, 12352, '\p{^Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(1, 12352, '\P{Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Expect(0, 12352, '\P{^Block:	 -cjk_symbols_And_PUNCTUATION}', "");
Error('\p{Blk=_:=cjk_Symbols}');
Error('\P{Blk=_:=cjk_Symbols}');
Expect(1, 12351, '\p{Blk=cjksymbols}', "");
Expect(0, 12351, '\p{^Blk=cjksymbols}', "");
Expect(0, 12351, '\P{Blk=cjksymbols}', "");
Expect(1, 12351, '\P{^Blk=cjksymbols}', "");
Expect(0, 12352, '\p{Blk=cjksymbols}', "");
Expect(1, 12352, '\p{^Blk=cjksymbols}', "");
Expect(1, 12352, '\P{Blk=cjksymbols}', "");
Expect(0, 12352, '\P{^Blk=cjksymbols}', "");
Expect(1, 12351, '\p{Blk=	 CJK_Symbols}', "");
Expect(0, 12351, '\p{^Blk=	 CJK_Symbols}', "");
Expect(0, 12351, '\P{Blk=	 CJK_Symbols}', "");
Expect(1, 12351, '\P{^Blk=	 CJK_Symbols}', "");
Expect(0, 12352, '\p{Blk=	 CJK_Symbols}', "");
Expect(1, 12352, '\p{^Blk=	 CJK_Symbols}', "");
Expect(1, 12352, '\P{Blk=	 CJK_Symbols}', "");
Expect(0, 12352, '\P{^Blk=	 CJK_Symbols}', "");
Error('\p{Is_Block=-_CJK_SYMBOLS_And_Punctuation:=}');
Error('\P{Is_Block=-_CJK_SYMBOLS_And_Punctuation:=}');
Expect(1, 12351, '\p{Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{Is_Block=cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^Is_Block=cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(0, 12351, '\p{^Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(0, 12351, '\P{Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(1, 12351, '\P{^Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(0, 12352, '\p{Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(1, 12352, '\p{^Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(1, 12352, '\P{Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Expect(0, 12352, '\P{^Is_Block:		CJK_SYMBOLS_And_punctuation}', "");
Error('\p{Is_Blk:/a/CJK_SYMBOLS}');
Error('\P{Is_Blk:/a/CJK_SYMBOLS}');
Expect(1, 12351, '\p{Is_Blk=cjksymbols}', "");
Expect(0, 12351, '\p{^Is_Blk=cjksymbols}', "");
Expect(0, 12351, '\P{Is_Blk=cjksymbols}', "");
Expect(1, 12351, '\P{^Is_Blk=cjksymbols}', "");
Expect(0, 12352, '\p{Is_Blk=cjksymbols}', "");
Expect(1, 12352, '\p{^Is_Blk=cjksymbols}', "");
Expect(1, 12352, '\P{Is_Blk=cjksymbols}', "");
Expect(0, 12352, '\P{^Is_Blk=cjksymbols}', "");
Expect(1, 12351, '\p{Is_Blk=-_CJK_Symbols}', "");
Expect(0, 12351, '\p{^Is_Blk=-_CJK_Symbols}', "");
Expect(0, 12351, '\P{Is_Blk=-_CJK_Symbols}', "");
Expect(1, 12351, '\P{^Is_Blk=-_CJK_Symbols}', "");
Expect(0, 12352, '\p{Is_Blk=-_CJK_Symbols}', "");
Expect(1, 12352, '\p{^Is_Blk=-_CJK_Symbols}', "");
Expect(1, 12352, '\P{Is_Blk=-_CJK_Symbols}', "");
Expect(0, 12352, '\P{^Is_Blk=-_CJK_Symbols}', "");
Error('\p{Block=CARIAN:=}');
Error('\P{Block=CARIAN:=}');
Expect(1, 66271, '\p{Block=carian}', "");
Expect(0, 66271, '\p{^Block=carian}', "");
Expect(0, 66271, '\P{Block=carian}', "");
Expect(1, 66271, '\P{^Block=carian}', "");
Expect(0, 66272, '\p{Block=carian}', "");
Expect(1, 66272, '\p{^Block=carian}', "");
Expect(1, 66272, '\P{Block=carian}', "");
Expect(0, 66272, '\P{^Block=carian}', "");
Expect(1, 66271, '\p{Block=		CARIAN}', "");
Expect(0, 66271, '\p{^Block=		CARIAN}', "");
Expect(0, 66271, '\P{Block=		CARIAN}', "");
Expect(1, 66271, '\P{^Block=		CARIAN}', "");
Expect(0, 66272, '\p{Block=		CARIAN}', "");
Expect(1, 66272, '\p{^Block=		CARIAN}', "");
Expect(1, 66272, '\P{Block=		CARIAN}', "");
Expect(0, 66272, '\P{^Block=		CARIAN}', "");
Error('\p{Blk=-:=Carian}');
Error('\P{Blk=-:=Carian}');
Expect(1, 66271, '\p{Blk=carian}', "");
Expect(0, 66271, '\p{^Blk=carian}', "");
Expect(0, 66271, '\P{Blk=carian}', "");
Expect(1, 66271, '\P{^Blk=carian}', "");
Expect(0, 66272, '\p{Blk=carian}', "");
Expect(1, 66272, '\p{^Blk=carian}', "");
Expect(1, 66272, '\P{Blk=carian}', "");
Expect(0, 66272, '\P{^Blk=carian}', "");
Expect(1, 66271, '\p{Blk:   	-Carian}', "");
Expect(0, 66271, '\p{^Blk:   	-Carian}', "");
Expect(0, 66271, '\P{Blk:   	-Carian}', "");
Expect(1, 66271, '\P{^Blk:   	-Carian}', "");
Expect(0, 66272, '\p{Blk:   	-Carian}', "");
Expect(1, 66272, '\p{^Blk:   	-Carian}', "");
Expect(1, 66272, '\P{Blk:   	-Carian}', "");
Expect(0, 66272, '\P{^Blk:   	-Carian}', "");
Error('\p{Is_Block= /a/CARIAN}');
Error('\P{Is_Block= /a/CARIAN}');
Expect(1, 66271, '\p{Is_Block=carian}', "");
Expect(0, 66271, '\p{^Is_Block=carian}', "");
Expect(0, 66271, '\P{Is_Block=carian}', "");
Expect(1, 66271, '\P{^Is_Block=carian}', "");
Expect(0, 66272, '\p{Is_Block=carian}', "");
Expect(1, 66272, '\p{^Is_Block=carian}', "");
Expect(1, 66272, '\P{Is_Block=carian}', "");
Expect(0, 66272, '\P{^Is_Block=carian}', "");
Expect(1, 66271, '\p{Is_Block=__CARIAN}', "");
Expect(0, 66271, '\p{^Is_Block=__CARIAN}', "");
Expect(0, 66271, '\P{Is_Block=__CARIAN}', "");
Expect(1, 66271, '\P{^Is_Block=__CARIAN}', "");
Expect(0, 66272, '\p{Is_Block=__CARIAN}', "");
Expect(1, 66272, '\p{^Is_Block=__CARIAN}', "");
Expect(1, 66272, '\P{Is_Block=__CARIAN}', "");
Expect(0, 66272, '\P{^Is_Block=__CARIAN}', "");
Error('\p{Is_Blk=:=-	Carian}');
Error('\P{Is_Blk=:=-	Carian}');
Expect(1, 66271, '\p{Is_Blk=carian}', "");
Expect(0, 66271, '\p{^Is_Blk=carian}', "");
Expect(0, 66271, '\P{Is_Blk=carian}', "");
Expect(1, 66271, '\P{^Is_Blk=carian}', "");
Expect(0, 66272, '\p{Is_Blk=carian}', "");
Expect(1, 66272, '\p{^Is_Blk=carian}', "");
Expect(1, 66272, '\P{Is_Blk=carian}', "");
Expect(0, 66272, '\P{^Is_Blk=carian}', "");
Expect(1, 66271, '\p{Is_Blk=--carian}', "");
Expect(0, 66271, '\p{^Is_Blk=--carian}', "");
Expect(0, 66271, '\P{Is_Blk=--carian}', "");
Expect(1, 66271, '\P{^Is_Blk=--carian}', "");
Expect(0, 66272, '\p{Is_Blk=--carian}', "");
Expect(1, 66272, '\p{^Is_Blk=--carian}', "");
Expect(1, 66272, '\P{Is_Blk=--carian}', "");
Expect(0, 66272, '\P{^Is_Blk=--carian}', "");
Error('\p{Block=_/a/Chakma}');
Error('\P{Block=_/a/Chakma}');
Expect(1, 69967, '\p{Block:	chakma}', "");
Expect(0, 69967, '\p{^Block:	chakma}', "");
Expect(0, 69967, '\P{Block:	chakma}', "");
Expect(1, 69967, '\P{^Block:	chakma}', "");
Expect(0, 69968, '\p{Block:	chakma}', "");
Expect(1, 69968, '\p{^Block:	chakma}', "");
Expect(1, 69968, '\P{Block:	chakma}', "");
Expect(0, 69968, '\P{^Block:	chakma}', "");
Expect(1, 69967, '\p{Block:   	CHAKMA}', "");
Expect(0, 69967, '\p{^Block:   	CHAKMA}', "");
Expect(0, 69967, '\P{Block:   	CHAKMA}', "");
Expect(1, 69967, '\P{^Block:   	CHAKMA}', "");
Expect(0, 69968, '\p{Block:   	CHAKMA}', "");
Expect(1, 69968, '\p{^Block:   	CHAKMA}', "");
Expect(1, 69968, '\P{Block:   	CHAKMA}', "");
Expect(0, 69968, '\P{^Block:   	CHAKMA}', "");
Error('\p{Blk=-_Chakma:=}');
Error('\P{Blk=-_Chakma:=}');
Expect(1, 69967, '\p{Blk=chakma}', "");
Expect(0, 69967, '\p{^Blk=chakma}', "");
Expect(0, 69967, '\P{Blk=chakma}', "");
Expect(1, 69967, '\P{^Blk=chakma}', "");
Expect(0, 69968, '\p{Blk=chakma}', "");
Expect(1, 69968, '\p{^Blk=chakma}', "");
Expect(1, 69968, '\P{Blk=chakma}', "");
Expect(0, 69968, '\P{^Blk=chakma}', "");
Expect(1, 69967, '\p{Blk:	 chakma}', "");
Expect(0, 69967, '\p{^Blk:	 chakma}', "");
Expect(0, 69967, '\P{Blk:	 chakma}', "");
Expect(1, 69967, '\P{^Blk:	 chakma}', "");
Expect(0, 69968, '\p{Blk:	 chakma}', "");
Expect(1, 69968, '\p{^Blk:	 chakma}', "");
Expect(1, 69968, '\P{Blk:	 chakma}', "");
Expect(0, 69968, '\P{^Blk:	 chakma}', "");
Error('\p{Is_Block=:=Chakma}');
Error('\P{Is_Block=:=Chakma}');
Expect(1, 69967, '\p{Is_Block=chakma}', "");
Expect(0, 69967, '\p{^Is_Block=chakma}', "");
Expect(0, 69967, '\P{Is_Block=chakma}', "");
Expect(1, 69967, '\P{^Is_Block=chakma}', "");
Expect(0, 69968, '\p{Is_Block=chakma}', "");
Expect(1, 69968, '\p{^Is_Block=chakma}', "");
Expect(1, 69968, '\P{Is_Block=chakma}', "");
Expect(0, 69968, '\P{^Is_Block=chakma}', "");
Expect(1, 69967, '\p{Is_Block=_-CHAKMA}', "");
Expect(0, 69967, '\p{^Is_Block=_-CHAKMA}', "");
Expect(0, 69967, '\P{Is_Block=_-CHAKMA}', "");
Expect(1, 69967, '\P{^Is_Block=_-CHAKMA}', "");
Expect(0, 69968, '\p{Is_Block=_-CHAKMA}', "");
Expect(1, 69968, '\p{^Is_Block=_-CHAKMA}', "");
Expect(1, 69968, '\P{Is_Block=_-CHAKMA}', "");
Expect(0, 69968, '\P{^Is_Block=_-CHAKMA}', "");
Error('\p{Is_Blk=_chakma:=}');
Error('\P{Is_Blk=_chakma:=}');
Expect(1, 69967, '\p{Is_Blk=chakma}', "");
Expect(0, 69967, '\p{^Is_Blk=chakma}', "");
Expect(0, 69967, '\P{Is_Blk=chakma}', "");
Expect(1, 69967, '\P{^Is_Blk=chakma}', "");
Expect(0, 69968, '\p{Is_Blk=chakma}', "");
Expect(1, 69968, '\p{^Is_Blk=chakma}', "");
Expect(1, 69968, '\P{Is_Blk=chakma}', "");
Expect(0, 69968, '\P{^Is_Blk=chakma}', "");
Expect(1, 69967, '\p{Is_Blk: -CHAKMA}', "");
Expect(0, 69967, '\p{^Is_Blk: -CHAKMA}', "");
Expect(0, 69967, '\P{Is_Blk: -CHAKMA}', "");
Expect(1, 69967, '\P{^Is_Blk: -CHAKMA}', "");
Expect(0, 69968, '\p{Is_Blk: -CHAKMA}', "");
Expect(1, 69968, '\p{^Is_Blk: -CHAKMA}', "");
Expect(1, 69968, '\P{Is_Blk: -CHAKMA}', "");
Expect(0, 69968, '\P{^Is_Blk: -CHAKMA}', "");
Error('\p{Block=/a/-Cham}');
Error('\P{Block=/a/-Cham}');
Expect(1, 43615, '\p{Block=cham}', "");
Expect(0, 43615, '\p{^Block=cham}', "");
Expect(0, 43615, '\P{Block=cham}', "");
Expect(1, 43615, '\P{^Block=cham}', "");
Expect(0, 43616, '\p{Block=cham}', "");
Expect(1, 43616, '\p{^Block=cham}', "");
Expect(1, 43616, '\P{Block=cham}', "");
Expect(0, 43616, '\P{^Block=cham}', "");
Expect(1, 43615, '\p{Block=_-cham}', "");
Expect(0, 43615, '\p{^Block=_-cham}', "");
Expect(0, 43615, '\P{Block=_-cham}', "");
Expect(1, 43615, '\P{^Block=_-cham}', "");
Expect(0, 43616, '\p{Block=_-cham}', "");
Expect(1, 43616, '\p{^Block=_-cham}', "");
Expect(1, 43616, '\P{Block=_-cham}', "");
Expect(0, 43616, '\P{^Block=_-cham}', "");
Error('\p{Blk=:= _Cham}');
Error('\P{Blk=:= _Cham}');
Expect(1, 43615, '\p{Blk=cham}', "");
Expect(0, 43615, '\p{^Blk=cham}', "");
Expect(0, 43615, '\P{Blk=cham}', "");
Expect(1, 43615, '\P{^Blk=cham}', "");
Expect(0, 43616, '\p{Blk=cham}', "");
Expect(1, 43616, '\p{^Blk=cham}', "");
Expect(1, 43616, '\P{Blk=cham}', "");
Expect(0, 43616, '\P{^Blk=cham}', "");
Expect(1, 43615, '\p{Blk= 	cham}', "");
Expect(0, 43615, '\p{^Blk= 	cham}', "");
Expect(0, 43615, '\P{Blk= 	cham}', "");
Expect(1, 43615, '\P{^Blk= 	cham}', "");
Expect(0, 43616, '\p{Blk= 	cham}', "");
Expect(1, 43616, '\p{^Blk= 	cham}', "");
Expect(1, 43616, '\P{Blk= 	cham}', "");
Expect(0, 43616, '\P{^Blk= 	cham}', "");
Error('\p{Is_Block=	:=Cham}');
Error('\P{Is_Block=	:=Cham}');
Expect(1, 43615, '\p{Is_Block=cham}', "");
Expect(0, 43615, '\p{^Is_Block=cham}', "");
Expect(0, 43615, '\P{Is_Block=cham}', "");
Expect(1, 43615, '\P{^Is_Block=cham}', "");
Expect(0, 43616, '\p{Is_Block=cham}', "");
Expect(1, 43616, '\p{^Is_Block=cham}', "");
Expect(1, 43616, '\P{Is_Block=cham}', "");
Expect(0, 43616, '\P{^Is_Block=cham}', "");
Expect(1, 43615, '\p{Is_Block=__cham}', "");
Expect(0, 43615, '\p{^Is_Block=__cham}', "");
Expect(0, 43615, '\P{Is_Block=__cham}', "");
Expect(1, 43615, '\P{^Is_Block=__cham}', "");
Expect(0, 43616, '\p{Is_Block=__cham}', "");
Expect(1, 43616, '\p{^Is_Block=__cham}', "");
Expect(1, 43616, '\P{Is_Block=__cham}', "");
Expect(0, 43616, '\P{^Is_Block=__cham}', "");
Error('\p{Is_Blk=-Cham/a/}');
Error('\P{Is_Blk=-Cham/a/}');
Expect(1, 43615, '\p{Is_Blk=cham}', "");
Expect(0, 43615, '\p{^Is_Blk=cham}', "");
Expect(0, 43615, '\P{Is_Blk=cham}', "");
Expect(1, 43615, '\P{^Is_Blk=cham}', "");
Expect(0, 43616, '\p{Is_Blk=cham}', "");
Expect(1, 43616, '\p{^Is_Blk=cham}', "");
Expect(1, 43616, '\P{Is_Blk=cham}', "");
Expect(0, 43616, '\P{^Is_Blk=cham}', "");
Expect(1, 43615, '\p{Is_Blk=	CHAM}', "");
Expect(0, 43615, '\p{^Is_Blk=	CHAM}', "");
Expect(0, 43615, '\P{Is_Blk=	CHAM}', "");
Expect(1, 43615, '\P{^Is_Blk=	CHAM}', "");
Expect(0, 43616, '\p{Is_Blk=	CHAM}', "");
Expect(1, 43616, '\p{^Is_Blk=	CHAM}', "");
Expect(1, 43616, '\P{Is_Blk=	CHAM}', "");
Expect(0, 43616, '\P{^Is_Blk=	CHAM}', "");
Error('\p{Block=_/a/Cherokee}');
Error('\P{Block=_/a/Cherokee}');
Expect(1, 5119, '\p{Block=cherokee}', "");
Expect(0, 5119, '\p{^Block=cherokee}', "");
Expect(0, 5119, '\P{Block=cherokee}', "");
Expect(1, 5119, '\P{^Block=cherokee}', "");
Expect(0, 5120, '\p{Block=cherokee}', "");
Expect(1, 5120, '\p{^Block=cherokee}', "");
Expect(1, 5120, '\P{Block=cherokee}', "");
Expect(0, 5120, '\P{^Block=cherokee}', "");
Expect(1, 5119, '\p{Block= Cherokee}', "");
Expect(0, 5119, '\p{^Block= Cherokee}', "");
Expect(0, 5119, '\P{Block= Cherokee}', "");
Expect(1, 5119, '\P{^Block= Cherokee}', "");
Expect(0, 5120, '\p{Block= Cherokee}', "");
Expect(1, 5120, '\p{^Block= Cherokee}', "");
Expect(1, 5120, '\P{Block= Cherokee}', "");
Expect(0, 5120, '\P{^Block= Cherokee}', "");
Error('\p{Blk=	/a/cherokee}');
Error('\P{Blk=	/a/cherokee}');
Expect(1, 5119, '\p{Blk=cherokee}', "");
Expect(0, 5119, '\p{^Blk=cherokee}', "");
Expect(0, 5119, '\P{Blk=cherokee}', "");
Expect(1, 5119, '\P{^Blk=cherokee}', "");
Expect(0, 5120, '\p{Blk=cherokee}', "");
Expect(1, 5120, '\p{^Blk=cherokee}', "");
Expect(1, 5120, '\P{Blk=cherokee}', "");
Expect(0, 5120, '\P{^Blk=cherokee}', "");
Expect(1, 5119, '\p{Blk= -cherokee}', "");
Expect(0, 5119, '\p{^Blk= -cherokee}', "");
Expect(0, 5119, '\P{Blk= -cherokee}', "");
Expect(1, 5119, '\P{^Blk= -cherokee}', "");
Expect(0, 5120, '\p{Blk= -cherokee}', "");
Expect(1, 5120, '\p{^Blk= -cherokee}', "");
Expect(1, 5120, '\P{Blk= -cherokee}', "");
Expect(0, 5120, '\P{^Blk= -cherokee}', "");
Error('\p{Is_Block=/a/-Cherokee}');
Error('\P{Is_Block=/a/-Cherokee}');
Expect(1, 5119, '\p{Is_Block=cherokee}', "");
Expect(0, 5119, '\p{^Is_Block=cherokee}', "");
Expect(0, 5119, '\P{Is_Block=cherokee}', "");
Expect(1, 5119, '\P{^Is_Block=cherokee}', "");
Expect(0, 5120, '\p{Is_Block=cherokee}', "");
Expect(1, 5120, '\p{^Is_Block=cherokee}', "");
Expect(1, 5120, '\P{Is_Block=cherokee}', "");
Expect(0, 5120, '\P{^Is_Block=cherokee}', "");
Expect(1, 5119, '\p{Is_Block= -CHEROKEE}', "");
Expect(0, 5119, '\p{^Is_Block= -CHEROKEE}', "");
Expect(0, 5119, '\P{Is_Block= -CHEROKEE}', "");
Expect(1, 5119, '\P{^Is_Block= -CHEROKEE}', "");
Expect(0, 5120, '\p{Is_Block= -CHEROKEE}', "");
Expect(1, 5120, '\p{^Is_Block= -CHEROKEE}', "");
Expect(1, 5120, '\P{Is_Block= -CHEROKEE}', "");
Expect(0, 5120, '\P{^Is_Block= -CHEROKEE}', "");
Error('\p{Is_Blk=__cherokee:=}');
Error('\P{Is_Blk=__cherokee:=}');
Expect(1, 5119, '\p{Is_Blk=cherokee}', "");
Expect(0, 5119, '\p{^Is_Blk=cherokee}', "");
Expect(0, 5119, '\P{Is_Blk=cherokee}', "");
Expect(1, 5119, '\P{^Is_Blk=cherokee}', "");
Expect(0, 5120, '\p{Is_Blk=cherokee}', "");
Expect(1, 5120, '\p{^Is_Blk=cherokee}', "");
Expect(1, 5120, '\P{Is_Blk=cherokee}', "");
Expect(0, 5120, '\P{^Is_Blk=cherokee}', "");
Expect(1, 5119, '\p{Is_Blk: 	_CHEROKEE}', "");
Expect(0, 5119, '\p{^Is_Blk: 	_CHEROKEE}', "");
Expect(0, 5119, '\P{Is_Blk: 	_CHEROKEE}', "");
Expect(1, 5119, '\P{^Is_Blk: 	_CHEROKEE}', "");
Expect(0, 5120, '\p{Is_Blk: 	_CHEROKEE}', "");
Expect(1, 5120, '\p{^Is_Blk: 	_CHEROKEE}', "");
Expect(1, 5120, '\P{Is_Blk: 	_CHEROKEE}', "");
Expect(0, 5120, '\P{^Is_Blk: 	_CHEROKEE}', "");
Error('\p{Block=-/a/Hangul_Compatibility_Jamo}');
Error('\P{Block=-/a/Hangul_Compatibility_Jamo}');
Expect(1, 12687, '\p{Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(0, 12687, '\p{^Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(0, 12687, '\P{Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(1, 12687, '\P{^Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(0, 12688, '\p{Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(1, 12688, '\p{^Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(1, 12688, '\P{Block:-Hangul_COMPATIBILITY_jamo}', "");
Expect(0, 12688, '\P{^Block:-Hangul_COMPATIBILITY_jamo}', "");
Error('\p{Blk=:=  Compat_jamo}');
Error('\P{Blk=:=  Compat_jamo}');
Expect(1, 12687, '\p{Blk=compatjamo}', "");
Expect(0, 12687, '\p{^Blk=compatjamo}', "");
Expect(0, 12687, '\P{Blk=compatjamo}', "");
Expect(1, 12687, '\P{^Blk=compatjamo}', "");
Expect(0, 12688, '\p{Blk=compatjamo}', "");
Expect(1, 12688, '\p{^Blk=compatjamo}', "");
Expect(1, 12688, '\P{Blk=compatjamo}', "");
Expect(0, 12688, '\P{^Blk=compatjamo}', "");
Expect(1, 12687, '\p{Blk=-Compat_Jamo}', "");
Expect(0, 12687, '\p{^Blk=-Compat_Jamo}', "");
Expect(0, 12687, '\P{Blk=-Compat_Jamo}', "");
Expect(1, 12687, '\P{^Blk=-Compat_Jamo}', "");
Expect(0, 12688, '\p{Blk=-Compat_Jamo}', "");
Expect(1, 12688, '\p{^Blk=-Compat_Jamo}', "");
Expect(1, 12688, '\P{Blk=-Compat_Jamo}', "");
Expect(0, 12688, '\P{^Blk=-Compat_Jamo}', "");
Error('\p{Is_Block: /a/ _hangul_COMPATIBILITY_Jamo}');
Error('\P{Is_Block: /a/ _hangul_COMPATIBILITY_Jamo}');
Expect(1, 12687, '\p{Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{Is_Block=hangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^Is_Block=hangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{Is_Block= hangul_compatibility_Jamo}', "");
Expect(0, 12687, '\p{^Is_Block= hangul_compatibility_Jamo}', "");
Expect(0, 12687, '\P{Is_Block= hangul_compatibility_Jamo}', "");
Expect(1, 12687, '\P{^Is_Block= hangul_compatibility_Jamo}', "");
Expect(0, 12688, '\p{Is_Block= hangul_compatibility_Jamo}', "");
Expect(1, 12688, '\p{^Is_Block= hangul_compatibility_Jamo}', "");
Expect(1, 12688, '\P{Is_Block= hangul_compatibility_Jamo}', "");
Expect(0, 12688, '\P{^Is_Block= hangul_compatibility_Jamo}', "");
Error('\p{Is_Blk=-Compat_JAMO/a/}');
Error('\P{Is_Blk=-Compat_JAMO/a/}');
Expect(1, 12687, '\p{Is_Blk=compatjamo}', "");
Expect(0, 12687, '\p{^Is_Blk=compatjamo}', "");
Expect(0, 12687, '\P{Is_Blk=compatjamo}', "");
Expect(1, 12687, '\P{^Is_Blk=compatjamo}', "");
Expect(0, 12688, '\p{Is_Blk=compatjamo}', "");
Expect(1, 12688, '\p{^Is_Blk=compatjamo}', "");
Expect(1, 12688, '\P{Is_Blk=compatjamo}', "");
Expect(0, 12688, '\P{^Is_Blk=compatjamo}', "");
Expect(1, 12687, '\p{Is_Blk= _COMPAT_Jamo}', "");
Expect(0, 12687, '\p{^Is_Blk= _COMPAT_Jamo}', "");
Expect(0, 12687, '\P{Is_Blk= _COMPAT_Jamo}', "");
Expect(1, 12687, '\P{^Is_Blk= _COMPAT_Jamo}', "");
Expect(0, 12688, '\p{Is_Blk= _COMPAT_Jamo}', "");
Expect(1, 12688, '\p{^Is_Blk= _COMPAT_Jamo}', "");
Expect(1, 12688, '\P{Is_Blk= _COMPAT_Jamo}', "");
Expect(0, 12688, '\P{^Is_Blk= _COMPAT_Jamo}', "");
Error('\p{Block=:=_-Control_PICTURES}');
Error('\P{Block=:=_-Control_PICTURES}');
Expect(1, 9279, '\p{Block=controlpictures}', "");
Expect(0, 9279, '\p{^Block=controlpictures}', "");
Expect(0, 9279, '\P{Block=controlpictures}', "");
Expect(1, 9279, '\P{^Block=controlpictures}', "");
Expect(0, 9280, '\p{Block=controlpictures}', "");
Expect(1, 9280, '\p{^Block=controlpictures}', "");
Expect(1, 9280, '\P{Block=controlpictures}', "");
Expect(0, 9280, '\P{^Block=controlpictures}', "");
Expect(1, 9279, '\p{Block:	 _CONTROL_pictures}', "");
Expect(0, 9279, '\p{^Block:	 _CONTROL_pictures}', "");
Expect(0, 9279, '\P{Block:	 _CONTROL_pictures}', "");
Expect(1, 9279, '\P{^Block:	 _CONTROL_pictures}', "");
Expect(0, 9280, '\p{Block:	 _CONTROL_pictures}', "");
Expect(1, 9280, '\p{^Block:	 _CONTROL_pictures}', "");
Expect(1, 9280, '\P{Block:	 _CONTROL_pictures}', "");
Expect(0, 9280, '\P{^Block:	 _CONTROL_pictures}', "");
Error('\p{Blk=	Control_Pictures:=}');
Error('\P{Blk=	Control_Pictures:=}');
Expect(1, 9279, '\p{Blk=controlpictures}', "");
Expect(0, 9279, '\p{^Blk=controlpictures}', "");
Expect(0, 9279, '\P{Blk=controlpictures}', "");
Expect(1, 9279, '\P{^Blk=controlpictures}', "");
Expect(0, 9280, '\p{Blk=controlpictures}', "");
Expect(1, 9280, '\p{^Blk=controlpictures}', "");
Expect(1, 9280, '\P{Blk=controlpictures}', "");
Expect(0, 9280, '\P{^Blk=controlpictures}', "");
Expect(1, 9279, '\p{Blk= CONTROL_Pictures}', "");
Expect(0, 9279, '\p{^Blk= CONTROL_Pictures}', "");
Expect(0, 9279, '\P{Blk= CONTROL_Pictures}', "");
Expect(1, 9279, '\P{^Blk= CONTROL_Pictures}', "");
Expect(0, 9280, '\p{Blk= CONTROL_Pictures}', "");
Expect(1, 9280, '\p{^Blk= CONTROL_Pictures}', "");
Expect(1, 9280, '\P{Blk= CONTROL_Pictures}', "");
Expect(0, 9280, '\P{^Blk= CONTROL_Pictures}', "");
Error('\p{Is_Block=/a/ _Control_pictures}');
Error('\P{Is_Block=/a/ _Control_pictures}');
Expect(1, 9279, '\p{Is_Block=controlpictures}', "");
Expect(0, 9279, '\p{^Is_Block=controlpictures}', "");
Expect(0, 9279, '\P{Is_Block=controlpictures}', "");
Expect(1, 9279, '\P{^Is_Block=controlpictures}', "");
Expect(0, 9280, '\p{Is_Block=controlpictures}', "");
Expect(1, 9280, '\p{^Is_Block=controlpictures}', "");
Expect(1, 9280, '\P{Is_Block=controlpictures}', "");
Expect(0, 9280, '\P{^Is_Block=controlpictures}', "");
Expect(1, 9279, '\p{Is_Block=_Control_pictures}', "");
Expect(0, 9279, '\p{^Is_Block=_Control_pictures}', "");
Expect(0, 9279, '\P{Is_Block=_Control_pictures}', "");
Expect(1, 9279, '\P{^Is_Block=_Control_pictures}', "");
Expect(0, 9280, '\p{Is_Block=_Control_pictures}', "");
Expect(1, 9280, '\p{^Is_Block=_Control_pictures}', "");
Expect(1, 9280, '\P{Is_Block=_Control_pictures}', "");
Expect(0, 9280, '\P{^Is_Block=_Control_pictures}', "");
Error('\p{Is_Blk=_Control_PICTURES/a/}');
Error('\P{Is_Blk=_Control_PICTURES/a/}');
Expect(1, 9279, '\p{Is_Blk=controlpictures}', "");
Expect(0, 9279, '\p{^Is_Blk=controlpictures}', "");
Expect(0, 9279, '\P{Is_Blk=controlpictures}', "");
Expect(1, 9279, '\P{^Is_Blk=controlpictures}', "");
Expect(0, 9280, '\p{Is_Blk=controlpictures}', "");
Expect(1, 9280, '\p{^Is_Blk=controlpictures}', "");
Expect(1, 9280, '\P{Is_Blk=controlpictures}', "");
Expect(0, 9280, '\P{^Is_Blk=controlpictures}', "");
Expect(1, 9279, '\p{Is_Blk= -CONTROL_Pictures}', "");
Expect(0, 9279, '\p{^Is_Blk= -CONTROL_Pictures}', "");
Expect(0, 9279, '\P{Is_Blk= -CONTROL_Pictures}', "");
Expect(1, 9279, '\P{^Is_Blk= -CONTROL_Pictures}', "");
Expect(0, 9280, '\p{Is_Blk= -CONTROL_Pictures}', "");
Expect(1, 9280, '\p{^Is_Blk= -CONTROL_Pictures}', "");
Expect(1, 9280, '\P{Is_Blk= -CONTROL_Pictures}', "");
Expect(0, 9280, '\P{^Is_Blk= -CONTROL_Pictures}', "");
Error('\p{Block=-coptic:=}');
Error('\P{Block=-coptic:=}');
Expect(1, 11519, '\p{Block=coptic}', "");
Expect(0, 11519, '\p{^Block=coptic}', "");
Expect(0, 11519, '\P{Block=coptic}', "");
Expect(1, 11519, '\P{^Block=coptic}', "");
Expect(0, 11520, '\p{Block=coptic}', "");
Expect(1, 11520, '\p{^Block=coptic}', "");
Expect(1, 11520, '\P{Block=coptic}', "");
Expect(0, 11520, '\P{^Block=coptic}', "");
Expect(1, 11519, '\p{Block=__coptic}', "");
Expect(0, 11519, '\p{^Block=__coptic}', "");
Expect(0, 11519, '\P{Block=__coptic}', "");
Expect(1, 11519, '\P{^Block=__coptic}', "");
Expect(0, 11520, '\p{Block=__coptic}', "");
Expect(1, 11520, '\p{^Block=__coptic}', "");
Expect(1, 11520, '\P{Block=__coptic}', "");
Expect(0, 11520, '\P{^Block=__coptic}', "");
Error('\p{Blk=-Coptic/a/}');
Error('\P{Blk=-Coptic/a/}');
Expect(1, 11519, '\p{Blk=coptic}', "");
Expect(0, 11519, '\p{^Blk=coptic}', "");
Expect(0, 11519, '\P{Blk=coptic}', "");
Expect(1, 11519, '\P{^Blk=coptic}', "");
Expect(0, 11520, '\p{Blk=coptic}', "");
Expect(1, 11520, '\p{^Blk=coptic}', "");
Expect(1, 11520, '\P{Blk=coptic}', "");
Expect(0, 11520, '\P{^Blk=coptic}', "");
Expect(1, 11519, '\p{Blk=_ coptic}', "");
Expect(0, 11519, '\p{^Blk=_ coptic}', "");
Expect(0, 11519, '\P{Blk=_ coptic}', "");
Expect(1, 11519, '\P{^Blk=_ coptic}', "");
Expect(0, 11520, '\p{Blk=_ coptic}', "");
Expect(1, 11520, '\p{^Blk=_ coptic}', "");
Expect(1, 11520, '\P{Blk=_ coptic}', "");
Expect(0, 11520, '\P{^Blk=_ coptic}', "");
Error('\p{Is_Block=/a/_Coptic}');
Error('\P{Is_Block=/a/_Coptic}');
Expect(1, 11519, '\p{Is_Block=coptic}', "");
Expect(0, 11519, '\p{^Is_Block=coptic}', "");
Expect(0, 11519, '\P{Is_Block=coptic}', "");
Expect(1, 11519, '\P{^Is_Block=coptic}', "");
Expect(0, 11520, '\p{Is_Block=coptic}', "");
Expect(1, 11520, '\p{^Is_Block=coptic}', "");
Expect(1, 11520, '\P{Is_Block=coptic}', "");
Expect(0, 11520, '\P{^Is_Block=coptic}', "");
Expect(1, 11519, '\p{Is_Block=_ coptic}', "");
Expect(0, 11519, '\p{^Is_Block=_ coptic}', "");
Expect(0, 11519, '\P{Is_Block=_ coptic}', "");
Expect(1, 11519, '\P{^Is_Block=_ coptic}', "");
Expect(0, 11520, '\p{Is_Block=_ coptic}', "");
Expect(1, 11520, '\p{^Is_Block=_ coptic}', "");
Expect(1, 11520, '\P{Is_Block=_ coptic}', "");
Expect(0, 11520, '\P{^Is_Block=_ coptic}', "");
Error('\p{Is_Blk=		Coptic:=}');
Error('\P{Is_Blk=		Coptic:=}');
Expect(1, 11519, '\p{Is_Blk=coptic}', "");
Expect(0, 11519, '\p{^Is_Blk=coptic}', "");
Expect(0, 11519, '\P{Is_Blk=coptic}', "");
Expect(1, 11519, '\P{^Is_Blk=coptic}', "");
Expect(0, 11520, '\p{Is_Blk=coptic}', "");
Expect(1, 11520, '\p{^Is_Blk=coptic}', "");
Expect(1, 11520, '\P{Is_Blk=coptic}', "");
Expect(0, 11520, '\P{^Is_Blk=coptic}', "");
Expect(1, 11519, '\p{Is_Blk=_coptic}', "");
Expect(0, 11519, '\p{^Is_Blk=_coptic}', "");
Expect(0, 11519, '\P{Is_Blk=_coptic}', "");
Expect(1, 11519, '\P{^Is_Blk=_coptic}', "");
Expect(0, 11520, '\p{Is_Blk=_coptic}', "");
Expect(1, 11520, '\p{^Is_Blk=_coptic}', "");
Expect(1, 11520, '\P{Is_Blk=_coptic}', "");
Expect(0, 11520, '\P{^Is_Blk=_coptic}', "");
Error('\p{Block:	_:=counting_rod_NUMERALS}');
Error('\P{Block:	_:=counting_rod_NUMERALS}');
Expect(1, 119679, '\p{Block=countingrodnumerals}', "");
Expect(0, 119679, '\p{^Block=countingrodnumerals}', "");
Expect(0, 119679, '\P{Block=countingrodnumerals}', "");
Expect(1, 119679, '\P{^Block=countingrodnumerals}', "");
Expect(0, 119680, '\p{Block=countingrodnumerals}', "");
Expect(1, 119680, '\p{^Block=countingrodnumerals}', "");
Expect(1, 119680, '\P{Block=countingrodnumerals}', "");
Expect(0, 119680, '\P{^Block=countingrodnumerals}', "");
Expect(1, 119679, '\p{Block=-	Counting_ROD_NUMERALS}', "");
Expect(0, 119679, '\p{^Block=-	Counting_ROD_NUMERALS}', "");
Expect(0, 119679, '\P{Block=-	Counting_ROD_NUMERALS}', "");
Expect(1, 119679, '\P{^Block=-	Counting_ROD_NUMERALS}', "");
Expect(0, 119680, '\p{Block=-	Counting_ROD_NUMERALS}', "");
Expect(1, 119680, '\p{^Block=-	Counting_ROD_NUMERALS}', "");
Expect(1, 119680, '\P{Block=-	Counting_ROD_NUMERALS}', "");
Expect(0, 119680, '\P{^Block=-	Counting_ROD_NUMERALS}', "");
Error('\p{Blk=_-Counting_rod:=}');
Error('\P{Blk=_-Counting_rod:=}');
Expect(1, 119679, '\p{Blk=countingrod}', "");
Expect(0, 119679, '\p{^Blk=countingrod}', "");
Expect(0, 119679, '\P{Blk=countingrod}', "");
Expect(1, 119679, '\P{^Blk=countingrod}', "");
Expect(0, 119680, '\p{Blk=countingrod}', "");
Expect(1, 119680, '\p{^Blk=countingrod}', "");
Expect(1, 119680, '\P{Blk=countingrod}', "");
Expect(0, 119680, '\P{^Blk=countingrod}', "");
Expect(1, 119679, '\p{Blk=		counting_Rod}', "");
Expect(0, 119679, '\p{^Blk=		counting_Rod}', "");
Expect(0, 119679, '\P{Blk=		counting_Rod}', "");
Expect(1, 119679, '\P{^Blk=		counting_Rod}', "");
Expect(0, 119680, '\p{Blk=		counting_Rod}', "");
Expect(1, 119680, '\p{^Blk=		counting_Rod}', "");
Expect(1, 119680, '\P{Blk=		counting_Rod}', "");
Expect(0, 119680, '\P{^Blk=		counting_Rod}', "");
Error('\p{Is_Block::=  Counting_rod_Numerals}');
Error('\P{Is_Block::=  Counting_rod_Numerals}');
Expect(1, 119679, '\p{Is_Block=countingrodnumerals}', "");
Expect(0, 119679, '\p{^Is_Block=countingrodnumerals}', "");
Expect(0, 119679, '\P{Is_Block=countingrodnumerals}', "");
Expect(1, 119679, '\P{^Is_Block=countingrodnumerals}', "");
Expect(0, 119680, '\p{Is_Block=countingrodnumerals}', "");
Expect(1, 119680, '\p{^Is_Block=countingrodnumerals}', "");
Expect(1, 119680, '\P{Is_Block=countingrodnumerals}', "");
Expect(0, 119680, '\P{^Is_Block=countingrodnumerals}', "");
Expect(1, 119679, '\p{Is_Block:- COUNTING_rod_Numerals}', "");
Expect(0, 119679, '\p{^Is_Block:- COUNTING_rod_Numerals}', "");
Expect(0, 119679, '\P{Is_Block:- COUNTING_rod_Numerals}', "");
Expect(1, 119679, '\P{^Is_Block:- COUNTING_rod_Numerals}', "");
Expect(0, 119680, '\p{Is_Block:- COUNTING_rod_Numerals}', "");
Expect(1, 119680, '\p{^Is_Block:- COUNTING_rod_Numerals}', "");
Expect(1, 119680, '\P{Is_Block:- COUNTING_rod_Numerals}', "");
Expect(0, 119680, '\P{^Is_Block:- COUNTING_rod_Numerals}', "");
Error('\p{Is_Blk=	/a/Counting_rod}');
Error('\P{Is_Blk=	/a/Counting_rod}');
Expect(1, 119679, '\p{Is_Blk=countingrod}', "");
Expect(0, 119679, '\p{^Is_Blk=countingrod}', "");
Expect(0, 119679, '\P{Is_Blk=countingrod}', "");
Expect(1, 119679, '\P{^Is_Blk=countingrod}', "");
Expect(0, 119680, '\p{Is_Blk=countingrod}', "");
Expect(1, 119680, '\p{^Is_Blk=countingrod}', "");
Expect(1, 119680, '\P{Is_Blk=countingrod}', "");
Expect(0, 119680, '\P{^Is_Blk=countingrod}', "");
Expect(1, 119679, '\p{Is_Blk= 	Counting_rod}', "");
Expect(0, 119679, '\p{^Is_Blk= 	Counting_rod}', "");
Expect(0, 119679, '\P{Is_Blk= 	Counting_rod}', "");
Expect(1, 119679, '\P{^Is_Blk= 	Counting_rod}', "");
Expect(0, 119680, '\p{Is_Blk= 	Counting_rod}', "");
Expect(1, 119680, '\p{^Is_Blk= 	Counting_rod}', "");
Expect(1, 119680, '\P{Is_Blk= 	Counting_rod}', "");
Expect(0, 119680, '\P{^Is_Blk= 	Counting_rod}', "");
Error('\p{Block=:=CUNEIFORM}');
Error('\P{Block=:=CUNEIFORM}');
Expect(1, 74751, '\p{Block: cuneiform}', "");
Expect(0, 74751, '\p{^Block: cuneiform}', "");
Expect(0, 74751, '\P{Block: cuneiform}', "");
Expect(1, 74751, '\P{^Block: cuneiform}', "");
Expect(0, 74752, '\p{Block: cuneiform}', "");
Expect(1, 74752, '\p{^Block: cuneiform}', "");
Expect(1, 74752, '\P{Block: cuneiform}', "");
Expect(0, 74752, '\P{^Block: cuneiform}', "");
Expect(1, 74751, '\p{Block:  Cuneiform}', "");
Expect(0, 74751, '\p{^Block:  Cuneiform}', "");
Expect(0, 74751, '\P{Block:  Cuneiform}', "");
Expect(1, 74751, '\P{^Block:  Cuneiform}', "");
Expect(0, 74752, '\p{Block:  Cuneiform}', "");
Expect(1, 74752, '\p{^Block:  Cuneiform}', "");
Expect(1, 74752, '\P{Block:  Cuneiform}', "");
Expect(0, 74752, '\P{^Block:  Cuneiform}', "");
Error('\p{Blk:_	cuneiform:=}');
Error('\P{Blk:_	cuneiform:=}');
Expect(1, 74751, '\p{Blk=cuneiform}', "");
Expect(0, 74751, '\p{^Blk=cuneiform}', "");
Expect(0, 74751, '\P{Blk=cuneiform}', "");
Expect(1, 74751, '\P{^Blk=cuneiform}', "");
Expect(0, 74752, '\p{Blk=cuneiform}', "");
Expect(1, 74752, '\p{^Blk=cuneiform}', "");
Expect(1, 74752, '\P{Blk=cuneiform}', "");
Expect(0, 74752, '\P{^Blk=cuneiform}', "");
Expect(1, 74751, '\p{Blk=	-Cuneiform}', "");
Expect(0, 74751, '\p{^Blk=	-Cuneiform}', "");
Expect(0, 74751, '\P{Blk=	-Cuneiform}', "");
Expect(1, 74751, '\P{^Blk=	-Cuneiform}', "");
Expect(0, 74752, '\p{Blk=	-Cuneiform}', "");
Expect(1, 74752, '\p{^Blk=	-Cuneiform}', "");
Expect(1, 74752, '\P{Blk=	-Cuneiform}', "");
Expect(0, 74752, '\P{^Blk=	-Cuneiform}', "");
Error('\p{Is_Block=_/a/Cuneiform}');
Error('\P{Is_Block=_/a/Cuneiform}');
Expect(1, 74751, '\p{Is_Block=cuneiform}', "");
Expect(0, 74751, '\p{^Is_Block=cuneiform}', "");
Expect(0, 74751, '\P{Is_Block=cuneiform}', "");
Expect(1, 74751, '\P{^Is_Block=cuneiform}', "");
Expect(0, 74752, '\p{Is_Block=cuneiform}', "");
Expect(1, 74752, '\p{^Is_Block=cuneiform}', "");
Expect(1, 74752, '\P{Is_Block=cuneiform}', "");
Expect(0, 74752, '\P{^Is_Block=cuneiform}', "");
Expect(1, 74751, '\p{Is_Block=-	cuneiform}', "");
Expect(0, 74751, '\p{^Is_Block=-	cuneiform}', "");
Expect(0, 74751, '\P{Is_Block=-	cuneiform}', "");
Expect(1, 74751, '\P{^Is_Block=-	cuneiform}', "");
Expect(0, 74752, '\p{Is_Block=-	cuneiform}', "");
Expect(1, 74752, '\p{^Is_Block=-	cuneiform}', "");
Expect(1, 74752, '\P{Is_Block=-	cuneiform}', "");
Expect(0, 74752, '\P{^Is_Block=-	cuneiform}', "");
Error('\p{Is_Blk=:= -cuneiform}');
Error('\P{Is_Blk=:= -cuneiform}');
Expect(1, 74751, '\p{Is_Blk:	cuneiform}', "");
Expect(0, 74751, '\p{^Is_Blk:	cuneiform}', "");
Expect(0, 74751, '\P{Is_Blk:	cuneiform}', "");
Expect(1, 74751, '\P{^Is_Blk:	cuneiform}', "");
Expect(0, 74752, '\p{Is_Blk:	cuneiform}', "");
Expect(1, 74752, '\p{^Is_Blk:	cuneiform}', "");
Expect(1, 74752, '\P{Is_Blk:	cuneiform}', "");
Expect(0, 74752, '\P{^Is_Blk:	cuneiform}', "");
Expect(1, 74751, '\p{Is_Blk=	-Cuneiform}', "");
Expect(0, 74751, '\p{^Is_Blk=	-Cuneiform}', "");
Expect(0, 74751, '\P{Is_Blk=	-Cuneiform}', "");
Expect(1, 74751, '\P{^Is_Blk=	-Cuneiform}', "");
Expect(0, 74752, '\p{Is_Blk=	-Cuneiform}', "");
Expect(1, 74752, '\p{^Is_Blk=	-Cuneiform}', "");
Expect(1, 74752, '\P{Is_Blk=	-Cuneiform}', "");
Expect(0, 74752, '\P{^Is_Blk=	-Cuneiform}', "");
Error('\p{Block=/a/ cuneiform_numbers_And_Punctuation}');
Error('\P{Block=/a/ cuneiform_numbers_And_Punctuation}');
Expect(1, 74879, '\p{Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(0, 74879, '\p{^Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(0, 74879, '\P{Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(1, 74879, '\P{^Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(0, 74880, '\p{Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(1, 74880, '\p{^Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(1, 74880, '\P{Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Expect(0, 74880, '\P{^Block= -CUNEIFORM_Numbers_and_punctuation}', "");
Error('\p{Blk=	-Cuneiform_numbers/a/}');
Error('\P{Blk=	-Cuneiform_numbers/a/}');
Expect(1, 74879, '\p{Blk=cuneiformnumbers}', "");
Expect(0, 74879, '\p{^Blk=cuneiformnumbers}', "");
Expect(0, 74879, '\P{Blk=cuneiformnumbers}', "");
Expect(1, 74879, '\P{^Blk=cuneiformnumbers}', "");
Expect(0, 74880, '\p{Blk=cuneiformnumbers}', "");
Expect(1, 74880, '\p{^Blk=cuneiformnumbers}', "");
Expect(1, 74880, '\P{Blk=cuneiformnumbers}', "");
Expect(0, 74880, '\P{^Blk=cuneiformnumbers}', "");
Expect(1, 74879, '\p{Blk=	Cuneiform_numbers}', "");
Expect(0, 74879, '\p{^Blk=	Cuneiform_numbers}', "");
Expect(0, 74879, '\P{Blk=	Cuneiform_numbers}', "");
Expect(1, 74879, '\P{^Blk=	Cuneiform_numbers}', "");
Expect(0, 74880, '\p{Blk=	Cuneiform_numbers}', "");
Expect(1, 74880, '\p{^Blk=	Cuneiform_numbers}', "");
Expect(1, 74880, '\P{Blk=	Cuneiform_numbers}', "");
Expect(0, 74880, '\P{^Blk=	Cuneiform_numbers}', "");
Error('\p{Is_Block=	:=Cuneiform_Numbers_And_PUNCTUATION}');
Error('\P{Is_Block=	:=Cuneiform_Numbers_And_PUNCTUATION}');
Expect(1, 74879, '\p{Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^Is_Block=cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(0, 74879, '\p{^Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(0, 74879, '\P{Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(1, 74879, '\P{^Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(0, 74880, '\p{Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(1, 74880, '\p{^Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(1, 74880, '\P{Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Expect(0, 74880, '\P{^Is_Block:     Cuneiform_numbers_and_PUNCTUATION}', "");
Error('\p{Is_Blk=/a/	Cuneiform_Numbers}');
Error('\P{Is_Blk=/a/	Cuneiform_Numbers}');
Expect(1, 74879, '\p{Is_Blk=cuneiformnumbers}', "");
Expect(0, 74879, '\p{^Is_Blk=cuneiformnumbers}', "");
Expect(0, 74879, '\P{Is_Blk=cuneiformnumbers}', "");
Expect(1, 74879, '\P{^Is_Blk=cuneiformnumbers}', "");
Expect(0, 74880, '\p{Is_Blk=cuneiformnumbers}', "");
Expect(1, 74880, '\p{^Is_Blk=cuneiformnumbers}', "");
Expect(1, 74880, '\P{Is_Blk=cuneiformnumbers}', "");
Expect(0, 74880, '\P{^Is_Blk=cuneiformnumbers}', "");
Expect(1, 74879, '\p{Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(0, 74879, '\p{^Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(0, 74879, '\P{Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(1, 74879, '\P{^Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(0, 74880, '\p{Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(1, 74880, '\p{^Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(1, 74880, '\P{Is_Blk=-	CUNEIFORM_Numbers}', "");
Expect(0, 74880, '\P{^Is_Blk=-	CUNEIFORM_Numbers}', "");
Error('\p{Block=:=	 currency_SYMBOLS}');
Error('\P{Block=:=	 currency_SYMBOLS}');
Expect(1, 8399, '\p{Block=currencysymbols}', "");
Expect(0, 8399, '\p{^Block=currencysymbols}', "");
Expect(0, 8399, '\P{Block=currencysymbols}', "");
Expect(1, 8399, '\P{^Block=currencysymbols}', "");
Expect(0, 8400, '\p{Block=currencysymbols}', "");
Expect(1, 8400, '\p{^Block=currencysymbols}', "");
Expect(1, 8400, '\P{Block=currencysymbols}', "");
Expect(0, 8400, '\P{^Block=currencysymbols}', "");
Expect(1, 8399, '\p{Block=_currency_SYMBOLS}', "");
Expect(0, 8399, '\p{^Block=_currency_SYMBOLS}', "");
Expect(0, 8399, '\P{Block=_currency_SYMBOLS}', "");
Expect(1, 8399, '\P{^Block=_currency_SYMBOLS}', "");
Expect(0, 8400, '\p{Block=_currency_SYMBOLS}', "");
Expect(1, 8400, '\p{^Block=_currency_SYMBOLS}', "");
Expect(1, 8400, '\P{Block=_currency_SYMBOLS}', "");
Expect(0, 8400, '\P{^Block=_currency_SYMBOLS}', "");
Error('\p{Blk=	/a/Currency_SYMBOLS}');
Error('\P{Blk=	/a/Currency_SYMBOLS}');
Expect(1, 8399, '\p{Blk=currencysymbols}', "");
Expect(0, 8399, '\p{^Blk=currencysymbols}', "");
Expect(0, 8399, '\P{Blk=currencysymbols}', "");
Expect(1, 8399, '\P{^Blk=currencysymbols}', "");
Expect(0, 8400, '\p{Blk=currencysymbols}', "");
Expect(1, 8400, '\p{^Blk=currencysymbols}', "");
Expect(1, 8400, '\P{Blk=currencysymbols}', "");
Expect(0, 8400, '\P{^Blk=currencysymbols}', "");
Expect(1, 8399, '\p{Blk=-Currency_symbols}', "");
Expect(0, 8399, '\p{^Blk=-Currency_symbols}', "");
Expect(0, 8399, '\P{Blk=-Currency_symbols}', "");
Expect(1, 8399, '\P{^Blk=-Currency_symbols}', "");
Expect(0, 8400, '\p{Blk=-Currency_symbols}', "");
Expect(1, 8400, '\p{^Blk=-Currency_symbols}', "");
Expect(1, 8400, '\P{Blk=-Currency_symbols}', "");
Expect(0, 8400, '\P{^Blk=-Currency_symbols}', "");
Error('\p{Is_Block=	_CURRENCY_Symbols/a/}');
Error('\P{Is_Block=	_CURRENCY_Symbols/a/}');
Expect(1, 8399, '\p{Is_Block=currencysymbols}', "");
Expect(0, 8399, '\p{^Is_Block=currencysymbols}', "");
Expect(0, 8399, '\P{Is_Block=currencysymbols}', "");
Expect(1, 8399, '\P{^Is_Block=currencysymbols}', "");
Expect(0, 8400, '\p{Is_Block=currencysymbols}', "");
Expect(1, 8400, '\p{^Is_Block=currencysymbols}', "");
Expect(1, 8400, '\P{Is_Block=currencysymbols}', "");
Expect(0, 8400, '\P{^Is_Block=currencysymbols}', "");
Expect(1, 8399, '\p{Is_Block=--CURRENCY_symbols}', "");
Expect(0, 8399, '\p{^Is_Block=--CURRENCY_symbols}', "");
Expect(0, 8399, '\P{Is_Block=--CURRENCY_symbols}', "");
Expect(1, 8399, '\P{^Is_Block=--CURRENCY_symbols}', "");
Expect(0, 8400, '\p{Is_Block=--CURRENCY_symbols}', "");
Expect(1, 8400, '\p{^Is_Block=--CURRENCY_symbols}', "");
Expect(1, 8400, '\P{Is_Block=--CURRENCY_symbols}', "");
Expect(0, 8400, '\P{^Is_Block=--CURRENCY_symbols}', "");
Error('\p{Is_Blk=_Currency_symbols/a/}');
Error('\P{Is_Blk=_Currency_symbols/a/}');
Expect(1, 8399, '\p{Is_Blk=currencysymbols}', "");
Expect(0, 8399, '\p{^Is_Blk=currencysymbols}', "");
Expect(0, 8399, '\P{Is_Blk=currencysymbols}', "");
Expect(1, 8399, '\P{^Is_Blk=currencysymbols}', "");
Expect(0, 8400, '\p{Is_Blk=currencysymbols}', "");
Expect(1, 8400, '\p{^Is_Blk=currencysymbols}', "");
Expect(1, 8400, '\P{Is_Blk=currencysymbols}', "");
Expect(0, 8400, '\P{^Is_Blk=currencysymbols}', "");
Expect(1, 8399, '\p{Is_Blk=  currency_Symbols}', "");
Expect(0, 8399, '\p{^Is_Blk=  currency_Symbols}', "");
Expect(0, 8399, '\P{Is_Blk=  currency_Symbols}', "");
Expect(1, 8399, '\P{^Is_Blk=  currency_Symbols}', "");
Expect(0, 8400, '\p{Is_Blk=  currency_Symbols}', "");
Expect(1, 8400, '\p{^Is_Blk=  currency_Symbols}', "");
Expect(1, 8400, '\P{Is_Blk=  currency_Symbols}', "");
Expect(0, 8400, '\P{^Is_Blk=  currency_Symbols}', "");
Error('\p{Block=	Cypriot_Syllabary:=}');
Error('\P{Block=	Cypriot_Syllabary:=}');
Expect(1, 67647, '\p{Block=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Block=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Block=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Block=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Block=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Block=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Block=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Block=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Block=_CYPRIOT_Syllabary}', "");
Expect(0, 67647, '\p{^Block=_CYPRIOT_Syllabary}', "");
Expect(0, 67647, '\P{Block=_CYPRIOT_Syllabary}', "");
Expect(1, 67647, '\P{^Block=_CYPRIOT_Syllabary}', "");
Expect(0, 67648, '\p{Block=_CYPRIOT_Syllabary}', "");
Expect(1, 67648, '\p{^Block=_CYPRIOT_Syllabary}', "");
Expect(1, 67648, '\P{Block=_CYPRIOT_Syllabary}', "");
Expect(0, 67648, '\P{^Block=_CYPRIOT_Syllabary}', "");
Error('\p{Blk= 	CYPRIOT_SYLLABARY:=}');
Error('\P{Blk= 	CYPRIOT_SYLLABARY:=}');
Expect(1, 67647, '\p{Blk:cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Blk:cypriotsyllabary}', "");
Expect(0, 67647, '\P{Blk:cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Blk:cypriotsyllabary}', "");
Expect(0, 67648, '\p{Blk:cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Blk:cypriotsyllabary}', "");
Expect(1, 67648, '\P{Blk:cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Blk:cypriotsyllabary}', "");
Expect(1, 67647, '\p{Blk= -cypriot_Syllabary}', "");
Expect(0, 67647, '\p{^Blk= -cypriot_Syllabary}', "");
Expect(0, 67647, '\P{Blk= -cypriot_Syllabary}', "");
Expect(1, 67647, '\P{^Blk= -cypriot_Syllabary}', "");
Expect(0, 67648, '\p{Blk= -cypriot_Syllabary}', "");
Expect(1, 67648, '\p{^Blk= -cypriot_Syllabary}', "");
Expect(1, 67648, '\P{Blk= -cypriot_Syllabary}', "");
Expect(0, 67648, '\P{^Blk= -cypriot_Syllabary}', "");
Error('\p{Is_Block=_/a/cypriot_syllabary}');
Error('\P{Is_Block=_/a/cypriot_syllabary}');
Expect(1, 67647, '\p{Is_Block=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Is_Block=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Is_Block=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Is_Block=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Is_Block=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Is_Block=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Is_Block=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Is_Block=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Is_Block=-	Cypriot_Syllabary}', "");
Expect(0, 67647, '\p{^Is_Block=-	Cypriot_Syllabary}', "");
Expect(0, 67647, '\P{Is_Block=-	Cypriot_Syllabary}', "");
Expect(1, 67647, '\P{^Is_Block=-	Cypriot_Syllabary}', "");
Expect(0, 67648, '\p{Is_Block=-	Cypriot_Syllabary}', "");
Expect(1, 67648, '\p{^Is_Block=-	Cypriot_Syllabary}', "");
Expect(1, 67648, '\P{Is_Block=-	Cypriot_Syllabary}', "");
Expect(0, 67648, '\P{^Is_Block=-	Cypriot_Syllabary}', "");
Error('\p{Is_Blk=:=_-cypriot_SYLLABARY}');
Error('\P{Is_Blk=:=_-cypriot_SYLLABARY}');
Expect(1, 67647, '\p{Is_Blk=cypriotsyllabary}', "");
Expect(0, 67647, '\p{^Is_Blk=cypriotsyllabary}', "");
Expect(0, 67647, '\P{Is_Blk=cypriotsyllabary}', "");
Expect(1, 67647, '\P{^Is_Blk=cypriotsyllabary}', "");
Expect(0, 67648, '\p{Is_Blk=cypriotsyllabary}', "");
Expect(1, 67648, '\p{^Is_Blk=cypriotsyllabary}', "");
Expect(1, 67648, '\P{Is_Blk=cypriotsyllabary}', "");
Expect(0, 67648, '\P{^Is_Blk=cypriotsyllabary}', "");
Expect(1, 67647, '\p{Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\p{^Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(0, 67647, '\P{Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(1, 67647, '\P{^Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\p{Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\p{^Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(1, 67648, '\P{Is_Blk=__Cypriot_SYLLABARY}', "");
Expect(0, 67648, '\P{^Is_Blk=__Cypriot_SYLLABARY}', "");
Error('\p{Block=/a/Cyrillic}');
Error('\P{Block=/a/Cyrillic}');
Expect(1, 1279, '\p{Block=cyrillic}', "");
Expect(0, 1279, '\p{^Block=cyrillic}', "");
Expect(0, 1279, '\P{Block=cyrillic}', "");
Expect(1, 1279, '\P{^Block=cyrillic}', "");
Expect(0, 1280, '\p{Block=cyrillic}', "");
Expect(1, 1280, '\p{^Block=cyrillic}', "");
Expect(1, 1280, '\P{Block=cyrillic}', "");
Expect(0, 1280, '\P{^Block=cyrillic}', "");
Expect(1, 1279, '\p{Block= cyrillic}', "");
Expect(0, 1279, '\p{^Block= cyrillic}', "");
Expect(0, 1279, '\P{Block= cyrillic}', "");
Expect(1, 1279, '\P{^Block= cyrillic}', "");
Expect(0, 1280, '\p{Block= cyrillic}', "");
Expect(1, 1280, '\p{^Block= cyrillic}', "");
Expect(1, 1280, '\P{Block= cyrillic}', "");
Expect(0, 1280, '\P{^Block= cyrillic}', "");
Error('\p{Blk=:=_Cyrillic}');
Error('\P{Blk=:=_Cyrillic}');
Expect(1, 1279, '\p{Blk:cyrillic}', "");
Expect(0, 1279, '\p{^Blk:cyrillic}', "");
Expect(0, 1279, '\P{Blk:cyrillic}', "");
Expect(1, 1279, '\P{^Blk:cyrillic}', "");
Expect(0, 1280, '\p{Blk:cyrillic}', "");
Expect(1, 1280, '\p{^Blk:cyrillic}', "");
Expect(1, 1280, '\P{Blk:cyrillic}', "");
Expect(0, 1280, '\P{^Blk:cyrillic}', "");
Expect(1, 1279, '\p{Blk=	_Cyrillic}', "");
Expect(0, 1279, '\p{^Blk=	_Cyrillic}', "");
Expect(0, 1279, '\P{Blk=	_Cyrillic}', "");
Expect(1, 1279, '\P{^Blk=	_Cyrillic}', "");
Expect(0, 1280, '\p{Blk=	_Cyrillic}', "");
Expect(1, 1280, '\p{^Blk=	_Cyrillic}', "");
Expect(1, 1280, '\P{Blk=	_Cyrillic}', "");
Expect(0, 1280, '\P{^Blk=	_Cyrillic}', "");
Error('\p{Is_Block=	-cyrillic/a/}');
Error('\P{Is_Block=	-cyrillic/a/}');
Expect(1, 1279, '\p{Is_Block=cyrillic}', "");
Expect(0, 1279, '\p{^Is_Block=cyrillic}', "");
Expect(0, 1279, '\P{Is_Block=cyrillic}', "");
Expect(1, 1279, '\P{^Is_Block=cyrillic}', "");
Expect(0, 1280, '\p{Is_Block=cyrillic}', "");
Expect(1, 1280, '\p{^Is_Block=cyrillic}', "");
Expect(1, 1280, '\P{Is_Block=cyrillic}', "");
Expect(0, 1280, '\P{^Is_Block=cyrillic}', "");
Expect(1, 1279, '\p{Is_Block=- Cyrillic}', "");
Expect(0, 1279, '\p{^Is_Block=- Cyrillic}', "");
Expect(0, 1279, '\P{Is_Block=- Cyrillic}', "");
Expect(1, 1279, '\P{^Is_Block=- Cyrillic}', "");
Expect(0, 1280, '\p{Is_Block=- Cyrillic}', "");
Expect(1, 1280, '\p{^Is_Block=- Cyrillic}', "");
Expect(1, 1280, '\P{Is_Block=- Cyrillic}', "");
Expect(0, 1280, '\P{^Is_Block=- Cyrillic}', "");
Error('\p{Is_Blk=:=_-Cyrillic}');
Error('\P{Is_Blk=:=_-Cyrillic}');
Expect(1, 1279, '\p{Is_Blk=cyrillic}', "");
Expect(0, 1279, '\p{^Is_Blk=cyrillic}', "");
Expect(0, 1279, '\P{Is_Blk=cyrillic}', "");
Expect(1, 1279, '\P{^Is_Blk=cyrillic}', "");
Expect(0, 1280, '\p{Is_Blk=cyrillic}', "");
Expect(1, 1280, '\p{^Is_Blk=cyrillic}', "");
Expect(1, 1280, '\P{Is_Blk=cyrillic}', "");
Expect(0, 1280, '\P{^Is_Blk=cyrillic}', "");
Expect(1, 1279, '\p{Is_Blk= _cyrillic}', "");
Expect(0, 1279, '\p{^Is_Blk= _cyrillic}', "");
Expect(0, 1279, '\P{Is_Blk= _cyrillic}', "");
Expect(1, 1279, '\P{^Is_Blk= _cyrillic}', "");
Expect(0, 1280, '\p{Is_Blk= _cyrillic}', "");
Expect(1, 1280, '\p{^Is_Blk= _cyrillic}', "");
Expect(1, 1280, '\P{Is_Blk= _cyrillic}', "");
Expect(0, 1280, '\P{^Is_Blk= _cyrillic}', "");
Error('\p{Block=:=Cyrillic_extended_a}');
Error('\P{Block=:=Cyrillic_extended_a}');
Expect(1, 11775, '\p{Block=cyrillicextendeda}', "");
Expect(0, 11775, '\p{^Block=cyrillicextendeda}', "");
Expect(0, 11775, '\P{Block=cyrillicextendeda}', "");
Expect(1, 11775, '\P{^Block=cyrillicextendeda}', "");
Expect(0, 11776, '\p{Block=cyrillicextendeda}', "");
Expect(1, 11776, '\p{^Block=cyrillicextendeda}', "");
Expect(1, 11776, '\P{Block=cyrillicextendeda}', "");
Expect(0, 11776, '\P{^Block=cyrillicextendeda}', "");
Expect(1, 11775, '\p{Block=	-Cyrillic_Extended_A}', "");
Expect(0, 11775, '\p{^Block=	-Cyrillic_Extended_A}', "");
Expect(0, 11775, '\P{Block=	-Cyrillic_Extended_A}', "");
Expect(1, 11775, '\P{^Block=	-Cyrillic_Extended_A}', "");
Expect(0, 11776, '\p{Block=	-Cyrillic_Extended_A}', "");
Expect(1, 11776, '\p{^Block=	-Cyrillic_Extended_A}', "");
Expect(1, 11776, '\P{Block=	-Cyrillic_Extended_A}', "");
Expect(0, 11776, '\P{^Block=	-Cyrillic_Extended_A}', "");
Error('\p{Blk=:=-Cyrillic_ext_A}');
Error('\P{Blk=:=-Cyrillic_ext_A}');
Expect(1, 11775, '\p{Blk=cyrillicexta}', "");
Expect(0, 11775, '\p{^Blk=cyrillicexta}', "");
Expect(0, 11775, '\P{Blk=cyrillicexta}', "");
Expect(1, 11775, '\P{^Blk=cyrillicexta}', "");
Expect(0, 11776, '\p{Blk=cyrillicexta}', "");
Expect(1, 11776, '\p{^Blk=cyrillicexta}', "");
Expect(1, 11776, '\P{Blk=cyrillicexta}', "");
Expect(0, 11776, '\P{^Blk=cyrillicexta}', "");
Expect(1, 11775, '\p{Blk: -cyrillic_Ext_A}', "");
Expect(0, 11775, '\p{^Blk: -cyrillic_Ext_A}', "");
Expect(0, 11775, '\P{Blk: -cyrillic_Ext_A}', "");
Expect(1, 11775, '\P{^Blk: -cyrillic_Ext_A}', "");
Expect(0, 11776, '\p{Blk: -cyrillic_Ext_A}', "");
Expect(1, 11776, '\p{^Blk: -cyrillic_Ext_A}', "");
Expect(1, 11776, '\P{Blk: -cyrillic_Ext_A}', "");
Expect(0, 11776, '\P{^Blk: -cyrillic_Ext_A}', "");
Error('\p{Is_Block:	 /a/Cyrillic_Extended_A}');
Error('\P{Is_Block:	 /a/Cyrillic_Extended_A}');
Expect(1, 11775, '\p{Is_Block=cyrillicextendeda}', "");
Expect(0, 11775, '\p{^Is_Block=cyrillicextendeda}', "");
Expect(0, 11775, '\P{Is_Block=cyrillicextendeda}', "");
Expect(1, 11775, '\P{^Is_Block=cyrillicextendeda}', "");
Expect(0, 11776, '\p{Is_Block=cyrillicextendeda}', "");
Expect(1, 11776, '\p{^Is_Block=cyrillicextendeda}', "");
Expect(1, 11776, '\P{Is_Block=cyrillicextendeda}', "");
Expect(0, 11776, '\P{^Is_Block=cyrillicextendeda}', "");
Expect(1, 11775, '\p{Is_Block=-	Cyrillic_Extended_A}', "");
Expect(0, 11775, '\p{^Is_Block=-	Cyrillic_Extended_A}', "");
Expect(0, 11775, '\P{Is_Block=-	Cyrillic_Extended_A}', "");
Expect(1, 11775, '\P{^Is_Block=-	Cyrillic_Extended_A}', "");
Expect(0, 11776, '\p{Is_Block=-	Cyrillic_Extended_A}', "");
Expect(1, 11776, '\p{^Is_Block=-	Cyrillic_Extended_A}', "");
Expect(1, 11776, '\P{Is_Block=-	Cyrillic_Extended_A}', "");
Expect(0, 11776, '\P{^Is_Block=-	Cyrillic_Extended_A}', "");
Error('\p{Is_Blk:/a/ Cyrillic_Ext_a}');
Error('\P{Is_Blk:/a/ Cyrillic_Ext_a}');
Expect(1, 11775, '\p{Is_Blk=cyrillicexta}', "");
Expect(0, 11775, '\p{^Is_Blk=cyrillicexta}', "");
Expect(0, 11775, '\P{Is_Blk=cyrillicexta}', "");
Expect(1, 11775, '\P{^Is_Blk=cyrillicexta}', "");
Expect(0, 11776, '\p{Is_Blk=cyrillicexta}', "");
Expect(1, 11776, '\p{^Is_Blk=cyrillicexta}', "");
Expect(1, 11776, '\P{Is_Blk=cyrillicexta}', "");
Expect(0, 11776, '\P{^Is_Blk=cyrillicexta}', "");
Expect(1, 11775, '\p{Is_Blk= -cyrillic_Ext_A}', "");
Expect(0, 11775, '\p{^Is_Blk= -cyrillic_Ext_A}', "");
Expect(0, 11775, '\P{Is_Blk= -cyrillic_Ext_A}', "");
Expect(1, 11775, '\P{^Is_Blk= -cyrillic_Ext_A}', "");
Expect(0, 11776, '\p{Is_Blk= -cyrillic_Ext_A}', "");
Expect(1, 11776, '\p{^Is_Blk= -cyrillic_Ext_A}', "");
Expect(1, 11776, '\P{Is_Blk= -cyrillic_Ext_A}', "");
Expect(0, 11776, '\P{^Is_Blk= -cyrillic_Ext_A}', "");
Error('\p{Block=-:=cyrillic_EXTENDED_B}');
Error('\P{Block=-:=cyrillic_EXTENDED_B}');
Expect(1, 42655, '\p{Block=cyrillicextendedb}', "");
Expect(0, 42655, '\p{^Block=cyrillicextendedb}', "");
Expect(0, 42655, '\P{Block=cyrillicextendedb}', "");
Expect(1, 42655, '\P{^Block=cyrillicextendedb}', "");
Expect(0, 42656, '\p{Block=cyrillicextendedb}', "");
Expect(1, 42656, '\p{^Block=cyrillicextendedb}', "");
Expect(1, 42656, '\P{Block=cyrillicextendedb}', "");
Expect(0, 42656, '\P{^Block=cyrillicextendedb}', "");
Expect(1, 42655, '\p{Block=_-Cyrillic_Extended_b}', "");
Expect(0, 42655, '\p{^Block=_-Cyrillic_Extended_b}', "");
Expect(0, 42655, '\P{Block=_-Cyrillic_Extended_b}', "");
Expect(1, 42655, '\P{^Block=_-Cyrillic_Extended_b}', "");
Expect(0, 42656, '\p{Block=_-Cyrillic_Extended_b}', "");
Expect(1, 42656, '\p{^Block=_-Cyrillic_Extended_b}', "");
Expect(1, 42656, '\P{Block=_-Cyrillic_Extended_b}', "");
Expect(0, 42656, '\P{^Block=_-Cyrillic_Extended_b}', "");
Error('\p{Blk=/a/CYRILLIC_ext_B}');
Error('\P{Blk=/a/CYRILLIC_ext_B}');
Expect(1, 42655, '\p{Blk=cyrillicextb}', "");
Expect(0, 42655, '\p{^Blk=cyrillicextb}', "");
Expect(0, 42655, '\P{Blk=cyrillicextb}', "");
Expect(1, 42655, '\P{^Blk=cyrillicextb}', "");
Expect(0, 42656, '\p{Blk=cyrillicextb}', "");
Expect(1, 42656, '\p{^Blk=cyrillicextb}', "");
Expect(1, 42656, '\P{Blk=cyrillicextb}', "");
Expect(0, 42656, '\P{^Blk=cyrillicextb}', "");
Expect(1, 42655, '\p{Blk=	Cyrillic_ext_B}', "");
Expect(0, 42655, '\p{^Blk=	Cyrillic_ext_B}', "");
Expect(0, 42655, '\P{Blk=	Cyrillic_ext_B}', "");
Expect(1, 42655, '\P{^Blk=	Cyrillic_ext_B}', "");
Expect(0, 42656, '\p{Blk=	Cyrillic_ext_B}', "");
Expect(1, 42656, '\p{^Blk=	Cyrillic_ext_B}', "");
Expect(1, 42656, '\P{Blk=	Cyrillic_ext_B}', "");
Expect(0, 42656, '\P{^Blk=	Cyrillic_ext_B}', "");
Error('\p{Is_Block=-:=CYRILLIC_EXTENDED_B}');
Error('\P{Is_Block=-:=CYRILLIC_EXTENDED_B}');
Expect(1, 42655, '\p{Is_Block=cyrillicextendedb}', "");
Expect(0, 42655, '\p{^Is_Block=cyrillicextendedb}', "");
Expect(0, 42655, '\P{Is_Block=cyrillicextendedb}', "");
Expect(1, 42655, '\P{^Is_Block=cyrillicextendedb}', "");
Expect(0, 42656, '\p{Is_Block=cyrillicextendedb}', "");
Expect(1, 42656, '\p{^Is_Block=cyrillicextendedb}', "");
Expect(1, 42656, '\P{Is_Block=cyrillicextendedb}', "");
Expect(0, 42656, '\P{^Is_Block=cyrillicextendedb}', "");
Expect(1, 42655, '\p{Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(0, 42655, '\p{^Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(0, 42655, '\P{Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(1, 42655, '\P{^Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(0, 42656, '\p{Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(1, 42656, '\p{^Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(1, 42656, '\P{Is_Block= _Cyrillic_EXTENDED_B}', "");
Expect(0, 42656, '\P{^Is_Block= _Cyrillic_EXTENDED_B}', "");
Error('\p{Is_Blk=	/a/CYRILLIC_EXT_B}');
Error('\P{Is_Blk=	/a/CYRILLIC_EXT_B}');
Expect(1, 42655, '\p{Is_Blk=cyrillicextb}', "");
Expect(0, 42655, '\p{^Is_Blk=cyrillicextb}', "");
Expect(0, 42655, '\P{Is_Blk=cyrillicextb}', "");
Expect(1, 42655, '\P{^Is_Blk=cyrillicextb}', "");
Expect(0, 42656, '\p{Is_Blk=cyrillicextb}', "");
Expect(1, 42656, '\p{^Is_Blk=cyrillicextb}', "");
Expect(1, 42656, '\P{Is_Blk=cyrillicextb}', "");
Expect(0, 42656, '\P{^Is_Blk=cyrillicextb}', "");
Expect(1, 42655, '\p{Is_Blk=		Cyrillic_Ext_B}', "");
Expect(0, 42655, '\p{^Is_Blk=		Cyrillic_Ext_B}', "");
Expect(0, 42655, '\P{Is_Blk=		Cyrillic_Ext_B}', "");
Expect(1, 42655, '\P{^Is_Blk=		Cyrillic_Ext_B}', "");
Expect(0, 42656, '\p{Is_Blk=		Cyrillic_Ext_B}', "");
Expect(1, 42656, '\p{^Is_Blk=		Cyrillic_Ext_B}', "");
Expect(1, 42656, '\P{Is_Blk=		Cyrillic_Ext_B}', "");
Expect(0, 42656, '\P{^Is_Blk=		Cyrillic_Ext_B}', "");
Error('\p{Block=_/a/CYRILLIC_SUPPLEMENT}');
Error('\P{Block=_/a/CYRILLIC_SUPPLEMENT}');
Expect(1, 1327, '\p{Block: cyrillicsupplement}', "");
Expect(0, 1327, '\p{^Block: cyrillicsupplement}', "");
Expect(0, 1327, '\P{Block: cyrillicsupplement}', "");
Expect(1, 1327, '\P{^Block: cyrillicsupplement}', "");
Expect(0, 1328, '\p{Block: cyrillicsupplement}', "");
Expect(1, 1328, '\p{^Block: cyrillicsupplement}', "");
Expect(1, 1328, '\P{Block: cyrillicsupplement}', "");
Expect(0, 1328, '\P{^Block: cyrillicsupplement}', "");
Expect(1, 1327, '\p{Block:   	_cyrillic_supplement}', "");
Expect(0, 1327, '\p{^Block:   	_cyrillic_supplement}', "");
Expect(0, 1327, '\P{Block:   	_cyrillic_supplement}', "");
Expect(1, 1327, '\P{^Block:   	_cyrillic_supplement}', "");
Expect(0, 1328, '\p{Block:   	_cyrillic_supplement}', "");
Expect(1, 1328, '\p{^Block:   	_cyrillic_supplement}', "");
Expect(1, 1328, '\P{Block:   	_cyrillic_supplement}', "");
Expect(0, 1328, '\P{^Block:   	_cyrillic_supplement}', "");
Error('\p{Blk=_:=Cyrillic_Sup}');
Error('\P{Blk=_:=Cyrillic_Sup}');
Expect(1, 1327, '\p{Blk=cyrillicsup}', "");
Expect(0, 1327, '\p{^Blk=cyrillicsup}', "");
Expect(0, 1327, '\P{Blk=cyrillicsup}', "");
Expect(1, 1327, '\P{^Blk=cyrillicsup}', "");
Expect(0, 1328, '\p{Blk=cyrillicsup}', "");
Expect(1, 1328, '\p{^Blk=cyrillicsup}', "");
Expect(1, 1328, '\P{Blk=cyrillicsup}', "");
Expect(0, 1328, '\P{^Blk=cyrillicsup}', "");
Expect(1, 1327, '\p{Blk=  Cyrillic_Sup}', "");
Expect(0, 1327, '\p{^Blk=  Cyrillic_Sup}', "");
Expect(0, 1327, '\P{Blk=  Cyrillic_Sup}', "");
Expect(1, 1327, '\P{^Blk=  Cyrillic_Sup}', "");
Expect(0, 1328, '\p{Blk=  Cyrillic_Sup}', "");
Expect(1, 1328, '\p{^Blk=  Cyrillic_Sup}', "");
Expect(1, 1328, '\P{Blk=  Cyrillic_Sup}', "");
Expect(0, 1328, '\P{^Blk=  Cyrillic_Sup}', "");
Error('\p{Is_Block=:=__cyrillic_supplementary}');
Error('\P{Is_Block=:=__cyrillic_supplementary}');
Expect(1, 1327, '\p{Is_Block=cyrillicsupplementary}', "");
Expect(0, 1327, '\p{^Is_Block=cyrillicsupplementary}', "");
Expect(0, 1327, '\P{Is_Block=cyrillicsupplementary}', "");
Expect(1, 1327, '\P{^Is_Block=cyrillicsupplementary}', "");
Expect(0, 1328, '\p{Is_Block=cyrillicsupplementary}', "");
Expect(1, 1328, '\p{^Is_Block=cyrillicsupplementary}', "");
Expect(1, 1328, '\P{Is_Block=cyrillicsupplementary}', "");
Expect(0, 1328, '\P{^Is_Block=cyrillicsupplementary}', "");
Expect(1, 1327, '\p{Is_Block=- Cyrillic_Supplementary}', "");
Expect(0, 1327, '\p{^Is_Block=- Cyrillic_Supplementary}', "");
Expect(0, 1327, '\P{Is_Block=- Cyrillic_Supplementary}', "");
Expect(1, 1327, '\P{^Is_Block=- Cyrillic_Supplementary}', "");
Expect(0, 1328, '\p{Is_Block=- Cyrillic_Supplementary}', "");
Expect(1, 1328, '\p{^Is_Block=- Cyrillic_Supplementary}', "");
Expect(1, 1328, '\P{Is_Block=- Cyrillic_Supplementary}', "");
Expect(0, 1328, '\P{^Is_Block=- Cyrillic_Supplementary}', "");
Error('\p{Is_Blk=	/a/cyrillic_supplement}');
Error('\P{Is_Blk=	/a/cyrillic_supplement}');
Expect(1, 1327, '\p{Is_Blk=cyrillicsupplement}', "");
Expect(0, 1327, '\p{^Is_Blk=cyrillicsupplement}', "");
Expect(0, 1327, '\P{Is_Blk=cyrillicsupplement}', "");
Expect(1, 1327, '\P{^Is_Blk=cyrillicsupplement}', "");
Expect(0, 1328, '\p{Is_Blk=cyrillicsupplement}', "");
Expect(1, 1328, '\p{^Is_Blk=cyrillicsupplement}', "");
Expect(1, 1328, '\P{Is_Blk=cyrillicsupplement}', "");
Expect(0, 1328, '\P{^Is_Blk=cyrillicsupplement}', "");
Expect(1, 1327, '\p{Is_Blk=_ CYRILLIC_supplement}', "");
Expect(0, 1327, '\p{^Is_Blk=_ CYRILLIC_supplement}', "");
Expect(0, 1327, '\P{Is_Blk=_ CYRILLIC_supplement}', "");
Expect(1, 1327, '\P{^Is_Blk=_ CYRILLIC_supplement}', "");
Expect(0, 1328, '\p{Is_Blk=_ CYRILLIC_supplement}', "");
Expect(1, 1328, '\p{^Is_Blk=_ CYRILLIC_supplement}', "");
Expect(1, 1328, '\P{Is_Blk=_ CYRILLIC_supplement}', "");
Expect(0, 1328, '\P{^Is_Blk=_ CYRILLIC_supplement}', "");
Error('\p{Block=/a/	Deseret}');
Error('\P{Block=/a/	Deseret}');
Expect(1, 66639, '\p{Block=deseret}', "");
Expect(0, 66639, '\p{^Block=deseret}', "");
Expect(0, 66639, '\P{Block=deseret}', "");
Expect(1, 66639, '\P{^Block=deseret}', "");
Expect(0, 66640, '\p{Block=deseret}', "");
Expect(1, 66640, '\p{^Block=deseret}', "");
Expect(1, 66640, '\P{Block=deseret}', "");
Expect(0, 66640, '\P{^Block=deseret}', "");
Expect(1, 66639, '\p{Block:	-Deseret}', "");
Expect(0, 66639, '\p{^Block:	-Deseret}', "");
Expect(0, 66639, '\P{Block:	-Deseret}', "");
Expect(1, 66639, '\P{^Block:	-Deseret}', "");
Expect(0, 66640, '\p{Block:	-Deseret}', "");
Expect(1, 66640, '\p{^Block:	-Deseret}', "");
Expect(1, 66640, '\P{Block:	-Deseret}', "");
Expect(0, 66640, '\P{^Block:	-Deseret}', "");
Error('\p{Blk:/a/ Deseret}');
Error('\P{Blk:/a/ Deseret}');
Expect(1, 66639, '\p{Blk=deseret}', "");
Expect(0, 66639, '\p{^Blk=deseret}', "");
Expect(0, 66639, '\P{Blk=deseret}', "");
Expect(1, 66639, '\P{^Blk=deseret}', "");
Expect(0, 66640, '\p{Blk=deseret}', "");
Expect(1, 66640, '\p{^Blk=deseret}', "");
Expect(1, 66640, '\P{Blk=deseret}', "");
Expect(0, 66640, '\P{^Blk=deseret}', "");
Expect(1, 66639, '\p{Blk=		Deseret}', "");
Expect(0, 66639, '\p{^Blk=		Deseret}', "");
Expect(0, 66639, '\P{Blk=		Deseret}', "");
Expect(1, 66639, '\P{^Blk=		Deseret}', "");
Expect(0, 66640, '\p{Blk=		Deseret}', "");
Expect(1, 66640, '\p{^Blk=		Deseret}', "");
Expect(1, 66640, '\P{Blk=		Deseret}', "");
Expect(0, 66640, '\P{^Blk=		Deseret}', "");
Error('\p{Is_Block=-:=Deseret}');
Error('\P{Is_Block=-:=Deseret}');
Expect(1, 66639, '\p{Is_Block=deseret}', "");
Expect(0, 66639, '\p{^Is_Block=deseret}', "");
Expect(0, 66639, '\P{Is_Block=deseret}', "");
Expect(1, 66639, '\P{^Is_Block=deseret}', "");
Expect(0, 66640, '\p{Is_Block=deseret}', "");
Expect(1, 66640, '\p{^Is_Block=deseret}', "");
Expect(1, 66640, '\P{Is_Block=deseret}', "");
Expect(0, 66640, '\P{^Is_Block=deseret}', "");
Expect(1, 66639, '\p{Is_Block=-DESERET}', "");
Expect(0, 66639, '\p{^Is_Block=-DESERET}', "");
Expect(0, 66639, '\P{Is_Block=-DESERET}', "");
Expect(1, 66639, '\P{^Is_Block=-DESERET}', "");
Expect(0, 66640, '\p{Is_Block=-DESERET}', "");
Expect(1, 66640, '\p{^Is_Block=-DESERET}', "");
Expect(1, 66640, '\P{Is_Block=-DESERET}', "");
Expect(0, 66640, '\P{^Is_Block=-DESERET}', "");
Error('\p{Is_Blk=  Deseret/a/}');
Error('\P{Is_Blk=  Deseret/a/}');
Expect(1, 66639, '\p{Is_Blk=deseret}', "");
Expect(0, 66639, '\p{^Is_Blk=deseret}', "");
Expect(0, 66639, '\P{Is_Blk=deseret}', "");
Expect(1, 66639, '\P{^Is_Blk=deseret}', "");
Expect(0, 66640, '\p{Is_Blk=deseret}', "");
Expect(1, 66640, '\p{^Is_Blk=deseret}', "");
Expect(1, 66640, '\P{Is_Blk=deseret}', "");
Expect(0, 66640, '\P{^Is_Blk=deseret}', "");
Expect(1, 66639, '\p{Is_Blk:	DESERET}', "");
Expect(0, 66639, '\p{^Is_Blk:	DESERET}', "");
Expect(0, 66639, '\P{Is_Blk:	DESERET}', "");
Expect(1, 66639, '\P{^Is_Blk:	DESERET}', "");
Expect(0, 66640, '\p{Is_Blk:	DESERET}', "");
Expect(1, 66640, '\p{^Is_Blk:	DESERET}', "");
Expect(1, 66640, '\P{Is_Blk:	DESERET}', "");
Expect(0, 66640, '\P{^Is_Blk:	DESERET}', "");
Error('\p{Block=	 Devanagari:=}');
Error('\P{Block=	 Devanagari:=}');
Expect(1, 2431, '\p{Block=devanagari}', "");
Expect(0, 2431, '\p{^Block=devanagari}', "");
Expect(0, 2431, '\P{Block=devanagari}', "");
Expect(1, 2431, '\P{^Block=devanagari}', "");
Expect(0, 2432, '\p{Block=devanagari}', "");
Expect(1, 2432, '\p{^Block=devanagari}', "");
Expect(1, 2432, '\P{Block=devanagari}', "");
Expect(0, 2432, '\P{^Block=devanagari}', "");
Expect(1, 2431, '\p{Block=_Devanagari}', "");
Expect(0, 2431, '\p{^Block=_Devanagari}', "");
Expect(0, 2431, '\P{Block=_Devanagari}', "");
Expect(1, 2431, '\P{^Block=_Devanagari}', "");
Expect(0, 2432, '\p{Block=_Devanagari}', "");
Expect(1, 2432, '\p{^Block=_Devanagari}', "");
Expect(1, 2432, '\P{Block=_Devanagari}', "");
Expect(0, 2432, '\P{^Block=_Devanagari}', "");
Error('\p{Blk= :=devanagari}');
Error('\P{Blk= :=devanagari}');
Expect(1, 2431, '\p{Blk=devanagari}', "");
Expect(0, 2431, '\p{^Blk=devanagari}', "");
Expect(0, 2431, '\P{Blk=devanagari}', "");
Expect(1, 2431, '\P{^Blk=devanagari}', "");
Expect(0, 2432, '\p{Blk=devanagari}', "");
Expect(1, 2432, '\p{^Blk=devanagari}', "");
Expect(1, 2432, '\P{Blk=devanagari}', "");
Expect(0, 2432, '\P{^Blk=devanagari}', "");
Expect(1, 2431, '\p{Blk=- DEVANAGARI}', "");
Expect(0, 2431, '\p{^Blk=- DEVANAGARI}', "");
Expect(0, 2431, '\P{Blk=- DEVANAGARI}', "");
Expect(1, 2431, '\P{^Blk=- DEVANAGARI}', "");
Expect(0, 2432, '\p{Blk=- DEVANAGARI}', "");
Expect(1, 2432, '\p{^Blk=- DEVANAGARI}', "");
Expect(1, 2432, '\P{Blk=- DEVANAGARI}', "");
Expect(0, 2432, '\P{^Blk=- DEVANAGARI}', "");
Error('\p{Is_Block=-:=Devanagari}');
Error('\P{Is_Block=-:=Devanagari}');
Expect(1, 2431, '\p{Is_Block=devanagari}', "");
Expect(0, 2431, '\p{^Is_Block=devanagari}', "");
Expect(0, 2431, '\P{Is_Block=devanagari}', "");
Expect(1, 2431, '\P{^Is_Block=devanagari}', "");
Expect(0, 2432, '\p{Is_Block=devanagari}', "");
Expect(1, 2432, '\p{^Is_Block=devanagari}', "");
Expect(1, 2432, '\P{Is_Block=devanagari}', "");
Expect(0, 2432, '\P{^Is_Block=devanagari}', "");
Expect(1, 2431, '\p{Is_Block= Devanagari}', "");
Expect(0, 2431, '\p{^Is_Block= Devanagari}', "");
Expect(0, 2431, '\P{Is_Block= Devanagari}', "");
Expect(1, 2431, '\P{^Is_Block= Devanagari}', "");
Expect(0, 2432, '\p{Is_Block= Devanagari}', "");
Expect(1, 2432, '\p{^Is_Block= Devanagari}', "");
Expect(1, 2432, '\P{Is_Block= Devanagari}', "");
Expect(0, 2432, '\P{^Is_Block= Devanagari}', "");
Error('\p{Is_Blk=/a/	_Devanagari}');
Error('\P{Is_Blk=/a/	_Devanagari}');
Expect(1, 2431, '\p{Is_Blk=devanagari}', "");
Expect(0, 2431, '\p{^Is_Blk=devanagari}', "");
Expect(0, 2431, '\P{Is_Blk=devanagari}', "");
Expect(1, 2431, '\P{^Is_Blk=devanagari}', "");
Expect(0, 2432, '\p{Is_Blk=devanagari}', "");
Expect(1, 2432, '\p{^Is_Blk=devanagari}', "");
Expect(1, 2432, '\P{Is_Blk=devanagari}', "");
Expect(0, 2432, '\P{^Is_Blk=devanagari}', "");
Expect(1, 2431, '\p{Is_Blk=_Devanagari}', "");
Expect(0, 2431, '\p{^Is_Blk=_Devanagari}', "");
Expect(0, 2431, '\P{Is_Blk=_Devanagari}', "");
Expect(1, 2431, '\P{^Is_Blk=_Devanagari}', "");
Expect(0, 2432, '\p{Is_Blk=_Devanagari}', "");
Expect(1, 2432, '\p{^Is_Blk=_Devanagari}', "");
Expect(1, 2432, '\P{Is_Blk=_Devanagari}', "");
Expect(0, 2432, '\P{^Is_Blk=_Devanagari}', "");
Error('\p{Block=/a/		Devanagari_extended}');
Error('\P{Block=/a/		Devanagari_extended}');
Expect(1, 43263, '\p{Block:   devanagariextended}', "");
Expect(0, 43263, '\p{^Block:   devanagariextended}', "");
Expect(0, 43263, '\P{Block:   devanagariextended}', "");
Expect(1, 43263, '\P{^Block:   devanagariextended}', "");
Expect(0, 43264, '\p{Block:   devanagariextended}', "");
Expect(1, 43264, '\p{^Block:   devanagariextended}', "");
Expect(1, 43264, '\P{Block:   devanagariextended}', "");
Expect(0, 43264, '\P{^Block:   devanagariextended}', "");
Expect(1, 43263, '\p{Block=	 devanagari_Extended}', "");
Expect(0, 43263, '\p{^Block=	 devanagari_Extended}', "");
Expect(0, 43263, '\P{Block=	 devanagari_Extended}', "");
Expect(1, 43263, '\P{^Block=	 devanagari_Extended}', "");
Expect(0, 43264, '\p{Block=	 devanagari_Extended}', "");
Expect(1, 43264, '\p{^Block=	 devanagari_Extended}', "");
Expect(1, 43264, '\P{Block=	 devanagari_Extended}', "");
Expect(0, 43264, '\P{^Block=	 devanagari_Extended}', "");
Error('\p{Blk=/a/-	Devanagari_ext}');
Error('\P{Blk=/a/-	Devanagari_ext}');
Expect(1, 43263, '\p{Blk=devanagariext}', "");
Expect(0, 43263, '\p{^Blk=devanagariext}', "");
Expect(0, 43263, '\P{Blk=devanagariext}', "");
Expect(1, 43263, '\P{^Blk=devanagariext}', "");
Expect(0, 43264, '\p{Blk=devanagariext}', "");
Expect(1, 43264, '\p{^Blk=devanagariext}', "");
Expect(1, 43264, '\P{Blk=devanagariext}', "");
Expect(0, 43264, '\P{^Blk=devanagariext}', "");
Expect(1, 43263, '\p{Blk=_ Devanagari_Ext}', "");
Expect(0, 43263, '\p{^Blk=_ Devanagari_Ext}', "");
Expect(0, 43263, '\P{Blk=_ Devanagari_Ext}', "");
Expect(1, 43263, '\P{^Blk=_ Devanagari_Ext}', "");
Expect(0, 43264, '\p{Blk=_ Devanagari_Ext}', "");
Expect(1, 43264, '\p{^Blk=_ Devanagari_Ext}', "");
Expect(1, 43264, '\P{Blk=_ Devanagari_Ext}', "");
Expect(0, 43264, '\P{^Blk=_ Devanagari_Ext}', "");
Error('\p{Is_Block=		DEVANAGARI_extended:=}');
Error('\P{Is_Block=		DEVANAGARI_extended:=}');
Expect(1, 43263, '\p{Is_Block=devanagariextended}', "");
Expect(0, 43263, '\p{^Is_Block=devanagariextended}', "");
Expect(0, 43263, '\P{Is_Block=devanagariextended}', "");
Expect(1, 43263, '\P{^Is_Block=devanagariextended}', "");
Expect(0, 43264, '\p{Is_Block=devanagariextended}', "");
Expect(1, 43264, '\p{^Is_Block=devanagariextended}', "");
Expect(1, 43264, '\P{Is_Block=devanagariextended}', "");
Expect(0, 43264, '\P{^Is_Block=devanagariextended}', "");
Expect(1, 43263, '\p{Is_Block=-_Devanagari_Extended}', "");
Expect(0, 43263, '\p{^Is_Block=-_Devanagari_Extended}', "");
Expect(0, 43263, '\P{Is_Block=-_Devanagari_Extended}', "");
Expect(1, 43263, '\P{^Is_Block=-_Devanagari_Extended}', "");
Expect(0, 43264, '\p{Is_Block=-_Devanagari_Extended}', "");
Expect(1, 43264, '\p{^Is_Block=-_Devanagari_Extended}', "");
Expect(1, 43264, '\P{Is_Block=-_Devanagari_Extended}', "");
Expect(0, 43264, '\P{^Is_Block=-_Devanagari_Extended}', "");
Error('\p{Is_Blk=_-devanagari_Ext:=}');
Error('\P{Is_Blk=_-devanagari_Ext:=}');
Expect(1, 43263, '\p{Is_Blk=devanagariext}', "");
Expect(0, 43263, '\p{^Is_Blk=devanagariext}', "");
Expect(0, 43263, '\P{Is_Blk=devanagariext}', "");
Expect(1, 43263, '\P{^Is_Blk=devanagariext}', "");
Expect(0, 43264, '\p{Is_Blk=devanagariext}', "");
Expect(1, 43264, '\p{^Is_Blk=devanagariext}', "");
Expect(1, 43264, '\P{Is_Blk=devanagariext}', "");
Expect(0, 43264, '\P{^Is_Blk=devanagariext}', "");
Expect(1, 43263, '\p{Is_Blk=-	Devanagari_Ext}', "");
Expect(0, 43263, '\p{^Is_Blk=-	Devanagari_Ext}', "");
Expect(0, 43263, '\P{Is_Blk=-	Devanagari_Ext}', "");
Expect(1, 43263, '\P{^Is_Blk=-	Devanagari_Ext}', "");
Expect(0, 43264, '\p{Is_Blk=-	Devanagari_Ext}', "");
Expect(1, 43264, '\p{^Is_Blk=-	Devanagari_Ext}', "");
Expect(1, 43264, '\P{Is_Blk=-	Devanagari_Ext}', "");
Expect(0, 43264, '\P{^Is_Blk=-	Devanagari_Ext}', "");
Error('\p{Block=/a/ -Combining_Diacritical_Marks}');
Error('\P{Block=/a/ -Combining_Diacritical_Marks}');
Expect(1, 879, '\p{Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\P{Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\p{Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\P{Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\p{Block:_-Combining_Diacritical_MARKS}', "");
Expect(0, 879, '\p{^Block:_-Combining_Diacritical_MARKS}', "");
Expect(0, 879, '\P{Block:_-Combining_Diacritical_MARKS}', "");
Expect(1, 879, '\P{^Block:_-Combining_Diacritical_MARKS}', "");
Expect(0, 880, '\p{Block:_-Combining_Diacritical_MARKS}', "");
Expect(1, 880, '\p{^Block:_-Combining_Diacritical_MARKS}', "");
Expect(1, 880, '\P{Block:_-Combining_Diacritical_MARKS}', "");
Expect(0, 880, '\P{^Block:_-Combining_Diacritical_MARKS}', "");
Error('\p{Blk:		/a/DIACRITICALS}');
Error('\P{Blk:		/a/DIACRITICALS}');
Expect(1, 879, '\p{Blk=diacriticals}', "");
Expect(0, 879, '\p{^Blk=diacriticals}', "");
Expect(0, 879, '\P{Blk=diacriticals}', "");
Expect(1, 879, '\P{^Blk=diacriticals}', "");
Expect(0, 880, '\p{Blk=diacriticals}', "");
Expect(1, 880, '\p{^Blk=diacriticals}', "");
Expect(1, 880, '\P{Blk=diacriticals}', "");
Expect(0, 880, '\P{^Blk=diacriticals}', "");
Expect(1, 879, '\p{Blk= 	DIACRITICALS}', "");
Expect(0, 879, '\p{^Blk= 	DIACRITICALS}', "");
Expect(0, 879, '\P{Blk= 	DIACRITICALS}', "");
Expect(1, 879, '\P{^Blk= 	DIACRITICALS}', "");
Expect(0, 880, '\p{Blk= 	DIACRITICALS}', "");
Expect(1, 880, '\p{^Blk= 	DIACRITICALS}', "");
Expect(1, 880, '\P{Blk= 	DIACRITICALS}', "");
Expect(0, 880, '\P{^Blk= 	DIACRITICALS}', "");
Error('\p{Is_Block=/a/ combining_DIACRITICAL_Marks}');
Error('\P{Is_Block=/a/ combining_DIACRITICAL_Marks}');
Expect(1, 879, '\p{Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 879, '\P{Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\p{Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 880, '\P{Is_Block=combiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^Is_Block=combiningdiacriticalmarks}', "");
Expect(1, 879, '\p{Is_Block=		combining_Diacritical_Marks}', "");
Expect(0, 879, '\p{^Is_Block=		combining_Diacritical_Marks}', "");
Expect(0, 879, '\P{Is_Block=		combining_Diacritical_Marks}', "");
Expect(1, 879, '\P{^Is_Block=		combining_Diacritical_Marks}', "");
Expect(0, 880, '\p{Is_Block=		combining_Diacritical_Marks}', "");
Expect(1, 880, '\p{^Is_Block=		combining_Diacritical_Marks}', "");
Expect(1, 880, '\P{Is_Block=		combining_Diacritical_Marks}', "");
Expect(0, 880, '\P{^Is_Block=		combining_Diacritical_Marks}', "");
Error('\p{Is_Blk=:= -Diacriticals}');
Error('\P{Is_Blk=:= -Diacriticals}');
Expect(1, 879, '\p{Is_Blk=diacriticals}', "");
Expect(0, 879, '\p{^Is_Blk=diacriticals}', "");
Expect(0, 879, '\P{Is_Blk=diacriticals}', "");
Expect(1, 879, '\P{^Is_Blk=diacriticals}', "");
Expect(0, 880, '\p{Is_Blk=diacriticals}', "");
Expect(1, 880, '\p{^Is_Blk=diacriticals}', "");
Expect(1, 880, '\P{Is_Blk=diacriticals}', "");
Expect(0, 880, '\P{^Is_Blk=diacriticals}', "");
Expect(1, 879, '\p{Is_Blk=	diacriticals}', "");
Expect(0, 879, '\p{^Is_Blk=	diacriticals}', "");
Expect(0, 879, '\P{Is_Blk=	diacriticals}', "");
Expect(1, 879, '\P{^Is_Blk=	diacriticals}', "");
Expect(0, 880, '\p{Is_Blk=	diacriticals}', "");
Expect(1, 880, '\p{^Is_Blk=	diacriticals}', "");
Expect(1, 880, '\P{Is_Blk=	diacriticals}', "");
Expect(0, 880, '\P{^Is_Blk=	diacriticals}', "");
Error('\p{Block=-Combining_Diacritical_MARKS_For_SYMBOLS/a/}');
Error('\P{Block=-Combining_Diacritical_MARKS_For_SYMBOLS/a/}');
Expect(1, 8447, '\p{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{Block=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^Block=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8447, '\p{^Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8447, '\P{Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8447, '\P{^Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8448, '\p{Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8448, '\p{^Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8448, '\P{Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8448, '\P{^Block= Combining_Diacritical_Marks_For_SYMBOLS}', "");
Error('\p{Blk=-/a/DIACRITICALS_For_Symbols}');
Error('\P{Blk=-/a/DIACRITICALS_For_Symbols}');
Expect(1, 8447, '\p{Blk=diacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^Blk=diacriticalsforsymbols}', "");
Expect(0, 8447, '\P{Blk=diacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^Blk=diacriticalsforsymbols}', "");
Expect(0, 8448, '\p{Blk=diacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^Blk=diacriticalsforsymbols}', "");
Expect(1, 8448, '\P{Blk=diacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^Blk=diacriticalsforsymbols}', "");
Expect(1, 8447, '\p{Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(0, 8447, '\p{^Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(0, 8447, '\P{Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(1, 8447, '\P{^Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(0, 8448, '\p{Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(1, 8448, '\p{^Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(1, 8448, '\P{Blk=	-DIACRITICALS_FOR_symbols}', "");
Expect(0, 8448, '\P{^Blk=	-DIACRITICALS_FOR_symbols}', "");
Error('\p{Is_Block=-Combining_marks_For_symbols/a/}');
Error('\P{Is_Block=-Combining_marks_For_symbols/a/}');
Expect(1, 8447, '\p{Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8447, '\P{Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8448, '\p{Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8448, '\P{Is_Block=combiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^Is_Block=combiningmarksforsymbols}', "");
Expect(1, 8447, '\p{Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(0, 8447, '\p{^Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(0, 8447, '\P{Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(1, 8447, '\P{^Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(0, 8448, '\p{Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(1, 8448, '\p{^Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(1, 8448, '\P{Is_Block=_Combining_Marks_for_Symbols}', "");
Expect(0, 8448, '\P{^Is_Block=_Combining_Marks_for_Symbols}', "");
Error('\p{Is_Blk: :=_-COMBINING_Diacritical_MARKS_for_Symbols}');
Error('\P{Is_Blk: :=_-COMBINING_Diacritical_MARKS_for_Symbols}');
Expect(1, 8447, '\p{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^Is_Blk=combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(0, 8447, '\p{^Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(0, 8447, '\P{Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(1, 8447, '\P{^Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(0, 8448, '\p{Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(1, 8448, '\p{^Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(1, 8448, '\P{Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Expect(0, 8448, '\P{^Is_Blk=  Combining_Diacritical_MARKS_For_symbols}', "");
Error('\p{Block=:=COMBINING_diacritical_Marks_Supplement}');
Error('\P{Block=:=COMBINING_diacritical_Marks_Supplement}');
Expect(1, 7679, '\p{Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{Block: combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^Block: combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7679, '\p{^Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7679, '\P{Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(1, 7679, '\P{^Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7680, '\p{Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(1, 7680, '\p{^Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(1, 7680, '\P{Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7680, '\P{^Block= _Combining_Diacritical_marks_SUPPLEMENT}', "");
Error('\p{Blk=:=-	Diacriticals_Sup}');
Error('\P{Blk=:=-	Diacriticals_Sup}');
Expect(1, 7679, '\p{Blk=diacriticalssup}', "");
Expect(0, 7679, '\p{^Blk=diacriticalssup}', "");
Expect(0, 7679, '\P{Blk=diacriticalssup}', "");
Expect(1, 7679, '\P{^Blk=diacriticalssup}', "");
Expect(0, 7680, '\p{Blk=diacriticalssup}', "");
Expect(1, 7680, '\p{^Blk=diacriticalssup}', "");
Expect(1, 7680, '\P{Blk=diacriticalssup}', "");
Expect(0, 7680, '\P{^Blk=diacriticalssup}', "");
Expect(1, 7679, '\p{Blk=-	diacriticals_Sup}', "");
Expect(0, 7679, '\p{^Blk=-	diacriticals_Sup}', "");
Expect(0, 7679, '\P{Blk=-	diacriticals_Sup}', "");
Expect(1, 7679, '\P{^Blk=-	diacriticals_Sup}', "");
Expect(0, 7680, '\p{Blk=-	diacriticals_Sup}', "");
Expect(1, 7680, '\p{^Blk=-	diacriticals_Sup}', "");
Expect(1, 7680, '\P{Blk=-	diacriticals_Sup}', "");
Expect(0, 7680, '\P{^Blk=-	diacriticals_Sup}', "");
Error('\p{Is_Block=-_COMBINING_diacritical_MARKS_Supplement/a/}');
Error('\P{Is_Block=-_COMBINING_diacritical_MARKS_Supplement/a/}');
Expect(1, 7679, '\p{Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^Is_Block=combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(0, 7679, '\p{^Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(0, 7679, '\P{Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(1, 7679, '\P{^Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(0, 7680, '\p{Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(1, 7680, '\p{^Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(1, 7680, '\P{Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Expect(0, 7680, '\P{^Is_Block:   		Combining_Diacritical_marks_supplement}', "");
Error('\p{Is_Blk:    _diacriticals_Sup:=}');
Error('\P{Is_Blk:    _diacriticals_Sup:=}');
Expect(1, 7679, '\p{Is_Blk=diacriticalssup}', "");
Expect(0, 7679, '\p{^Is_Blk=diacriticalssup}', "");
Expect(0, 7679, '\P{Is_Blk=diacriticalssup}', "");
Expect(1, 7679, '\P{^Is_Blk=diacriticalssup}', "");
Expect(0, 7680, '\p{Is_Blk=diacriticalssup}', "");
Expect(1, 7680, '\p{^Is_Blk=diacriticalssup}', "");
Expect(1, 7680, '\P{Is_Blk=diacriticalssup}', "");
Expect(0, 7680, '\P{^Is_Blk=diacriticalssup}', "");
Expect(1, 7679, '\p{Is_Blk= _diacriticals_Sup}', "");
Expect(0, 7679, '\p{^Is_Blk= _diacriticals_Sup}', "");
Expect(0, 7679, '\P{Is_Blk= _diacriticals_Sup}', "");
Expect(1, 7679, '\P{^Is_Blk= _diacriticals_Sup}', "");
Expect(0, 7680, '\p{Is_Blk= _diacriticals_Sup}', "");
Expect(1, 7680, '\p{^Is_Blk= _diacriticals_Sup}', "");
Expect(1, 7680, '\P{Is_Blk= _diacriticals_Sup}', "");
Expect(0, 7680, '\P{^Is_Blk= _diacriticals_Sup}', "");
Error('\p{Block=_ Dingbats/a/}');
Error('\P{Block=_ Dingbats/a/}');
Expect(1, 10175, '\p{Block=dingbats}', "");
Expect(0, 10175, '\p{^Block=dingbats}', "");
Expect(0, 10175, '\P{Block=dingbats}', "");
Expect(1, 10175, '\P{^Block=dingbats}', "");
Expect(0, 10176, '\p{Block=dingbats}', "");
Expect(1, 10176, '\p{^Block=dingbats}', "");
Expect(1, 10176, '\P{Block=dingbats}', "");
Expect(0, 10176, '\P{^Block=dingbats}', "");
Expect(1, 10175, '\p{Block=_Dingbats}', "");
Expect(0, 10175, '\p{^Block=_Dingbats}', "");
Expect(0, 10175, '\P{Block=_Dingbats}', "");
Expect(1, 10175, '\P{^Block=_Dingbats}', "");
Expect(0, 10176, '\p{Block=_Dingbats}', "");
Expect(1, 10176, '\p{^Block=_Dingbats}', "");
Expect(1, 10176, '\P{Block=_Dingbats}', "");
Expect(0, 10176, '\P{^Block=_Dingbats}', "");
Error('\p{Blk=:=	_dingbats}');
Error('\P{Blk=:=	_dingbats}');
Expect(1, 10175, '\p{Blk=dingbats}', "");
Expect(0, 10175, '\p{^Blk=dingbats}', "");
Expect(0, 10175, '\P{Blk=dingbats}', "");
Expect(1, 10175, '\P{^Blk=dingbats}', "");
Expect(0, 10176, '\p{Blk=dingbats}', "");
Expect(1, 10176, '\p{^Blk=dingbats}', "");
Expect(1, 10176, '\P{Blk=dingbats}', "");
Expect(0, 10176, '\P{^Blk=dingbats}', "");
Expect(1, 10175, '\p{Blk=__Dingbats}', "");
Expect(0, 10175, '\p{^Blk=__Dingbats}', "");
Expect(0, 10175, '\P{Blk=__Dingbats}', "");
Expect(1, 10175, '\P{^Blk=__Dingbats}', "");
Expect(0, 10176, '\p{Blk=__Dingbats}', "");
Expect(1, 10176, '\p{^Blk=__Dingbats}', "");
Expect(1, 10176, '\P{Blk=__Dingbats}', "");
Expect(0, 10176, '\P{^Blk=__Dingbats}', "");
Error('\p{Is_Block=-Dingbats:=}');
Error('\P{Is_Block=-Dingbats:=}');
Expect(1, 10175, '\p{Is_Block:dingbats}', "");
Expect(0, 10175, '\p{^Is_Block:dingbats}', "");
Expect(0, 10175, '\P{Is_Block:dingbats}', "");
Expect(1, 10175, '\P{^Is_Block:dingbats}', "");
Expect(0, 10176, '\p{Is_Block:dingbats}', "");
Expect(1, 10176, '\p{^Is_Block:dingbats}', "");
Expect(1, 10176, '\P{Is_Block:dingbats}', "");
Expect(0, 10176, '\P{^Is_Block:dingbats}', "");
Expect(1, 10175, '\p{Is_Block=--DINGBATS}', "");
Expect(0, 10175, '\p{^Is_Block=--DINGBATS}', "");
Expect(0, 10175, '\P{Is_Block=--DINGBATS}', "");
Expect(1, 10175, '\P{^Is_Block=--DINGBATS}', "");
Expect(0, 10176, '\p{Is_Block=--DINGBATS}', "");
Expect(1, 10176, '\p{^Is_Block=--DINGBATS}', "");
Expect(1, 10176, '\P{Is_Block=--DINGBATS}', "");
Expect(0, 10176, '\P{^Is_Block=--DINGBATS}', "");
Error('\p{Is_Blk=:=Dingbats}');
Error('\P{Is_Blk=:=Dingbats}');
Expect(1, 10175, '\p{Is_Blk=dingbats}', "");
Expect(0, 10175, '\p{^Is_Blk=dingbats}', "");
Expect(0, 10175, '\P{Is_Blk=dingbats}', "");
Expect(1, 10175, '\P{^Is_Blk=dingbats}', "");
Expect(0, 10176, '\p{Is_Blk=dingbats}', "");
Expect(1, 10176, '\p{^Is_Blk=dingbats}', "");
Expect(1, 10176, '\P{Is_Blk=dingbats}', "");
Expect(0, 10176, '\P{^Is_Blk=dingbats}', "");
Expect(1, 10175, '\p{Is_Blk=  Dingbats}', "");
Expect(0, 10175, '\p{^Is_Blk=  Dingbats}', "");
Expect(0, 10175, '\P{Is_Blk=  Dingbats}', "");
Expect(1, 10175, '\P{^Is_Blk=  Dingbats}', "");
Expect(0, 10176, '\p{Is_Blk=  Dingbats}', "");
Expect(1, 10176, '\p{^Is_Blk=  Dingbats}', "");
Expect(1, 10176, '\P{Is_Blk=  Dingbats}', "");
Expect(0, 10176, '\P{^Is_Blk=  Dingbats}', "");
Error('\p{Block:	:=Domino_Tiles}');
Error('\P{Block:	:=Domino_Tiles}');
Expect(1, 127135, '\p{Block=dominotiles}', "");
Expect(0, 127135, '\p{^Block=dominotiles}', "");
Expect(0, 127135, '\P{Block=dominotiles}', "");
Expect(1, 127135, '\P{^Block=dominotiles}', "");
Expect(0, 127136, '\p{Block=dominotiles}', "");
Expect(1, 127136, '\p{^Block=dominotiles}', "");
Expect(1, 127136, '\P{Block=dominotiles}', "");
Expect(0, 127136, '\P{^Block=dominotiles}', "");
Expect(1, 127135, '\p{Block:	- DOMINO_TILES}', "");
Expect(0, 127135, '\p{^Block:	- DOMINO_TILES}', "");
Expect(0, 127135, '\P{Block:	- DOMINO_TILES}', "");
Expect(1, 127135, '\P{^Block:	- DOMINO_TILES}', "");
Expect(0, 127136, '\p{Block:	- DOMINO_TILES}', "");
Expect(1, 127136, '\p{^Block:	- DOMINO_TILES}', "");
Expect(1, 127136, '\P{Block:	- DOMINO_TILES}', "");
Expect(0, 127136, '\P{^Block:	- DOMINO_TILES}', "");
Error('\p{Blk=__Domino:=}');
Error('\P{Blk=__Domino:=}');
Expect(1, 127135, '\p{Blk=domino}', "");
Expect(0, 127135, '\p{^Blk=domino}', "");
Expect(0, 127135, '\P{Blk=domino}', "");
Expect(1, 127135, '\P{^Blk=domino}', "");
Expect(0, 127136, '\p{Blk=domino}', "");
Expect(1, 127136, '\p{^Blk=domino}', "");
Expect(1, 127136, '\P{Blk=domino}', "");
Expect(0, 127136, '\P{^Blk=domino}', "");
Expect(1, 127135, '\p{Blk=__DOMINO}', "");
Expect(0, 127135, '\p{^Blk=__DOMINO}', "");
Expect(0, 127135, '\P{Blk=__DOMINO}', "");
Expect(1, 127135, '\P{^Blk=__DOMINO}', "");
Expect(0, 127136, '\p{Blk=__DOMINO}', "");
Expect(1, 127136, '\p{^Blk=__DOMINO}', "");
Expect(1, 127136, '\P{Blk=__DOMINO}', "");
Expect(0, 127136, '\P{^Blk=__DOMINO}', "");
Error('\p{Is_Block=:=Domino_Tiles}');
Error('\P{Is_Block=:=Domino_Tiles}');
Expect(1, 127135, '\p{Is_Block=dominotiles}', "");
Expect(0, 127135, '\p{^Is_Block=dominotiles}', "");
Expect(0, 127135, '\P{Is_Block=dominotiles}', "");
Expect(1, 127135, '\P{^Is_Block=dominotiles}', "");
Expect(0, 127136, '\p{Is_Block=dominotiles}', "");
Expect(1, 127136, '\p{^Is_Block=dominotiles}', "");
Expect(1, 127136, '\P{Is_Block=dominotiles}', "");
Expect(0, 127136, '\P{^Is_Block=dominotiles}', "");
Expect(1, 127135, '\p{Is_Block= Domino_tiles}', "");
Expect(0, 127135, '\p{^Is_Block= Domino_tiles}', "");
Expect(0, 127135, '\P{Is_Block= Domino_tiles}', "");
Expect(1, 127135, '\P{^Is_Block= Domino_tiles}', "");
Expect(0, 127136, '\p{Is_Block= Domino_tiles}', "");
Expect(1, 127136, '\p{^Is_Block= Domino_tiles}', "");
Expect(1, 127136, '\P{Is_Block= Domino_tiles}', "");
Expect(0, 127136, '\P{^Is_Block= Domino_tiles}', "");
Error('\p{Is_Blk=_-DOMINO:=}');
Error('\P{Is_Blk=_-DOMINO:=}');
Expect(1, 127135, '\p{Is_Blk=domino}', "");
Expect(0, 127135, '\p{^Is_Blk=domino}', "");
Expect(0, 127135, '\P{Is_Blk=domino}', "");
Expect(1, 127135, '\P{^Is_Blk=domino}', "");
Expect(0, 127136, '\p{Is_Blk=domino}', "");
Expect(1, 127136, '\p{^Is_Blk=domino}', "");
Expect(1, 127136, '\P{Is_Blk=domino}', "");
Expect(0, 127136, '\P{^Is_Blk=domino}', "");
Expect(1, 127135, '\p{Is_Blk=__Domino}', "");
Expect(0, 127135, '\p{^Is_Blk=__Domino}', "");
Expect(0, 127135, '\P{Is_Blk=__Domino}', "");
Expect(1, 127135, '\P{^Is_Blk=__Domino}', "");
Expect(0, 127136, '\p{Is_Blk=__Domino}', "");
Expect(1, 127136, '\p{^Is_Blk=__Domino}', "");
Expect(1, 127136, '\P{Is_Blk=__Domino}', "");
Expect(0, 127136, '\P{^Is_Blk=__Domino}', "");
Error('\p{Block=-_egyptian_HIEROGLYPHS/a/}');
Error('\P{Block=-_egyptian_HIEROGLYPHS/a/}');
Expect(1, 78895, '\p{Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Block=-_Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Block=-_Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{Block=-_Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Block=-_Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\p{Block=-_Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Block=-_Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\P{Block=-_Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Block=-_Egyptian_Hieroglyphs}', "");
Error('\p{Blk=/a/_ EGYPTIAN_hieroglyphs}');
Error('\P{Blk=/a/_ EGYPTIAN_hieroglyphs}');
Expect(1, 78895, '\p{Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\P{Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78896, '\p{Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78896, '\P{Blk=_ EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Blk=_ EGYPTIAN_Hieroglyphs}', "");
Error('\p{Is_Block=	_egyptian_HIEROGLYPHS/a/}');
Error('\P{Is_Block=	_egyptian_HIEROGLYPHS/a/}');
Expect(1, 78895, '\p{Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Is_Block=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Block=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Is_Block=  Egyptian_hieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Block=  Egyptian_hieroglyphs}', "");
Expect(0, 78895, '\P{Is_Block=  Egyptian_hieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Block=  Egyptian_hieroglyphs}', "");
Expect(0, 78896, '\p{Is_Block=  Egyptian_hieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Block=  Egyptian_hieroglyphs}', "");
Expect(1, 78896, '\P{Is_Block=  Egyptian_hieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Block=  Egyptian_hieroglyphs}', "");
Error('\p{Is_Blk=	 egyptian_HIEROGLYPHS/a/}');
Error('\P{Is_Blk=	 egyptian_HIEROGLYPHS/a/}');
Expect(1, 78895, '\p{Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\p{Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78896, '\P{Is_Blk=egyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Blk=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{^Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{^Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\p{Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\p{^Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(1, 78896, '\P{Is_Blk: -Egyptian_Hieroglyphs}', "");
Expect(0, 78896, '\P{^Is_Blk: -Egyptian_Hieroglyphs}', "");
Error('\p{Block=	:=EMOTICONS}');
Error('\P{Block=	:=EMOTICONS}');
Expect(1, 128591, '\p{Block=emoticons}', "");
Expect(0, 128591, '\p{^Block=emoticons}', "");
Expect(0, 128591, '\P{Block=emoticons}', "");
Expect(1, 128591, '\P{^Block=emoticons}', "");
Expect(0, 128592, '\p{Block=emoticons}', "");
Expect(1, 128592, '\p{^Block=emoticons}', "");
Expect(1, 128592, '\P{Block=emoticons}', "");
Expect(0, 128592, '\P{^Block=emoticons}', "");
Expect(1, 128591, '\p{Block=_ emoticons}', "");
Expect(0, 128591, '\p{^Block=_ emoticons}', "");
Expect(0, 128591, '\P{Block=_ emoticons}', "");
Expect(1, 128591, '\P{^Block=_ emoticons}', "");
Expect(0, 128592, '\p{Block=_ emoticons}', "");
Expect(1, 128592, '\p{^Block=_ emoticons}', "");
Expect(1, 128592, '\P{Block=_ emoticons}', "");
Expect(0, 128592, '\P{^Block=_ emoticons}', "");
Error('\p{Blk=/a/_	EMOTICONS}');
Error('\P{Blk=/a/_	EMOTICONS}');
Expect(1, 128591, '\p{Blk=emoticons}', "");
Expect(0, 128591, '\p{^Blk=emoticons}', "");
Expect(0, 128591, '\P{Blk=emoticons}', "");
Expect(1, 128591, '\P{^Blk=emoticons}', "");
Expect(0, 128592, '\p{Blk=emoticons}', "");
Expect(1, 128592, '\p{^Blk=emoticons}', "");
Expect(1, 128592, '\P{Blk=emoticons}', "");
Expect(0, 128592, '\P{^Blk=emoticons}', "");
Expect(1, 128591, '\p{Blk=Emoticons}', "");
Expect(0, 128591, '\p{^Blk=Emoticons}', "");
Expect(0, 128591, '\P{Blk=Emoticons}', "");
Expect(1, 128591, '\P{^Blk=Emoticons}', "");
Expect(0, 128592, '\p{Blk=Emoticons}', "");
Expect(1, 128592, '\p{^Blk=Emoticons}', "");
Expect(1, 128592, '\P{Blk=Emoticons}', "");
Expect(0, 128592, '\P{^Blk=Emoticons}', "");
Error('\p{Is_Block= Emoticons:=}');
Error('\P{Is_Block= Emoticons:=}');
Expect(1, 128591, '\p{Is_Block=emoticons}', "");
Expect(0, 128591, '\p{^Is_Block=emoticons}', "");
Expect(0, 128591, '\P{Is_Block=emoticons}', "");
Expect(1, 128591, '\P{^Is_Block=emoticons}', "");
Expect(0, 128592, '\p{Is_Block=emoticons}', "");
Expect(1, 128592, '\p{^Is_Block=emoticons}', "");
Expect(1, 128592, '\P{Is_Block=emoticons}', "");
Expect(0, 128592, '\P{^Is_Block=emoticons}', "");
Expect(1, 128591, '\p{Is_Block=--Emoticons}', "");
Expect(0, 128591, '\p{^Is_Block=--Emoticons}', "");
Expect(0, 128591, '\P{Is_Block=--Emoticons}', "");
Expect(1, 128591, '\P{^Is_Block=--Emoticons}', "");
Expect(0, 128592, '\p{Is_Block=--Emoticons}', "");
Expect(1, 128592, '\p{^Is_Block=--Emoticons}', "");
Expect(1, 128592, '\P{Is_Block=--Emoticons}', "");
Expect(0, 128592, '\P{^Is_Block=--Emoticons}', "");
Error('\p{Is_Blk:   /a/Emoticons}');
Error('\P{Is_Blk:   /a/Emoticons}');
Expect(1, 128591, '\p{Is_Blk=emoticons}', "");
Expect(0, 128591, '\p{^Is_Blk=emoticons}', "");
Expect(0, 128591, '\P{Is_Blk=emoticons}', "");
Expect(1, 128591, '\P{^Is_Blk=emoticons}', "");
Expect(0, 128592, '\p{Is_Blk=emoticons}', "");
Expect(1, 128592, '\p{^Is_Blk=emoticons}', "");
Expect(1, 128592, '\P{Is_Blk=emoticons}', "");
Expect(0, 128592, '\P{^Is_Blk=emoticons}', "");
Expect(1, 128591, '\p{Is_Blk=_Emoticons}', "");
Expect(0, 128591, '\p{^Is_Blk=_Emoticons}', "");
Expect(0, 128591, '\P{Is_Blk=_Emoticons}', "");
Expect(1, 128591, '\P{^Is_Blk=_Emoticons}', "");
Expect(0, 128592, '\p{Is_Blk=_Emoticons}', "");
Expect(1, 128592, '\p{^Is_Blk=_Emoticons}', "");
Expect(1, 128592, '\P{Is_Blk=_Emoticons}', "");
Expect(0, 128592, '\P{^Is_Blk=_Emoticons}', "");
Error('\p{Block: -_Enclosed_alphanumerics:=}');
Error('\P{Block: -_Enclosed_alphanumerics:=}');
Expect(1, 9471, '\p{Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\p{^Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\P{Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\P{^Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\p{Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\p{^Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\P{Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\P{^Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\p{Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(0, 9471, '\p{^Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(0, 9471, '\P{Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(1, 9471, '\P{^Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(0, 9472, '\p{Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(1, 9472, '\p{^Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(1, 9472, '\P{Block=-_Enclosed_ALPHANUMERICS}', "");
Expect(0, 9472, '\P{^Block=-_Enclosed_ALPHANUMERICS}', "");
Error('\p{Blk:   -	ENCLOSED_ALPHANUM:=}');
Error('\P{Blk:   -	ENCLOSED_ALPHANUM:=}');
Expect(1, 9471, '\p{Blk=enclosedalphanum}', "");
Expect(0, 9471, '\p{^Blk=enclosedalphanum}', "");
Expect(0, 9471, '\P{Blk=enclosedalphanum}', "");
Expect(1, 9471, '\P{^Blk=enclosedalphanum}', "");
Expect(0, 9472, '\p{Blk=enclosedalphanum}', "");
Expect(1, 9472, '\p{^Blk=enclosedalphanum}', "");
Expect(1, 9472, '\P{Blk=enclosedalphanum}', "");
Expect(0, 9472, '\P{^Blk=enclosedalphanum}', "");
Expect(1, 9471, '\p{Blk=	 Enclosed_Alphanum}', "");
Expect(0, 9471, '\p{^Blk=	 Enclosed_Alphanum}', "");
Expect(0, 9471, '\P{Blk=	 Enclosed_Alphanum}', "");
Expect(1, 9471, '\P{^Blk=	 Enclosed_Alphanum}', "");
Expect(0, 9472, '\p{Blk=	 Enclosed_Alphanum}', "");
Expect(1, 9472, '\p{^Blk=	 Enclosed_Alphanum}', "");
Expect(1, 9472, '\P{Blk=	 Enclosed_Alphanum}', "");
Expect(0, 9472, '\P{^Blk=	 Enclosed_Alphanum}', "");
Error('\p{Is_Block:/a/		enclosed_ALPHANUMERICS}');
Error('\P{Is_Block:/a/		enclosed_ALPHANUMERICS}');
Expect(1, 9471, '\p{Is_Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\p{^Is_Block=enclosedalphanumerics}', "");
Expect(0, 9471, '\P{Is_Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\P{^Is_Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\p{Is_Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\p{^Is_Block=enclosedalphanumerics}', "");
Expect(1, 9472, '\P{Is_Block=enclosedalphanumerics}', "");
Expect(0, 9472, '\P{^Is_Block=enclosedalphanumerics}', "");
Expect(1, 9471, '\p{Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(0, 9471, '\p{^Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(0, 9471, '\P{Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(1, 9471, '\P{^Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(0, 9472, '\p{Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(1, 9472, '\p{^Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(1, 9472, '\P{Is_Block=_ENCLOSED_Alphanumerics}', "");
Expect(0, 9472, '\P{^Is_Block=_ENCLOSED_Alphanumerics}', "");
Error('\p{Is_Blk=  ENCLOSED_alphanum:=}');
Error('\P{Is_Blk=  ENCLOSED_alphanum:=}');
Expect(1, 9471, '\p{Is_Blk=enclosedalphanum}', "");
Expect(0, 9471, '\p{^Is_Blk=enclosedalphanum}', "");
Expect(0, 9471, '\P{Is_Blk=enclosedalphanum}', "");
Expect(1, 9471, '\P{^Is_Blk=enclosedalphanum}', "");
Expect(0, 9472, '\p{Is_Blk=enclosedalphanum}', "");
Expect(1, 9472, '\p{^Is_Blk=enclosedalphanum}', "");
Expect(1, 9472, '\P{Is_Blk=enclosedalphanum}', "");
Expect(0, 9472, '\P{^Is_Blk=enclosedalphanum}', "");
Expect(1, 9471, '\p{Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(0, 9471, '\p{^Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(0, 9471, '\P{Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(1, 9471, '\P{^Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(0, 9472, '\p{Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(1, 9472, '\p{^Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(1, 9472, '\P{Is_Blk=--ENCLOSED_ALPHANUM}', "");
Expect(0, 9472, '\P{^Is_Blk=--ENCLOSED_ALPHANUM}', "");
Error('\p{Block=	Enclosed_Alphanumeric_Supplement:=}');
Error('\P{Block=	Enclosed_Alphanumeric_Supplement:=}');
Expect(1, 127487, '\p{Block=enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^Block=enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{Block=enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^Block=enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{Block=enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^Block=enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{Block=enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^Block=enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\p{^Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\P{Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(1, 127487, '\P{^Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\p{Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\p{^Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\P{Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\P{^Block=		enclosed_ALPHANUMERIC_Supplement}', "");
Error('\p{Blk=/a/enclosed_Alphanum_sup}');
Error('\P{Blk=/a/enclosed_Alphanum_sup}');
Expect(1, 127487, '\p{Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\p{^Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\P{Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\P{^Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\p{Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\p{^Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\P{Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\P{^Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\p{Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(0, 127487, '\p{^Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(0, 127487, '\P{Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(1, 127487, '\P{^Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(0, 127488, '\p{Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(1, 127488, '\p{^Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(1, 127488, '\P{Blk= ENCLOSED_Alphanum_Sup}', "");
Expect(0, 127488, '\P{^Blk= ENCLOSED_Alphanum_Sup}', "");
Error('\p{Is_Block=_ENCLOSED_Alphanumeric_Supplement:=}');
Error('\P{Is_Block=_ENCLOSED_Alphanumeric_Supplement:=}');
Expect(1, 127487, '\p{Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{Is_Block=enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^Is_Block=enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\p{^Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127487, '\P{Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(1, 127487, '\P{^Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\p{Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\p{^Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(1, 127488, '\P{Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Expect(0, 127488, '\P{^Is_Block= 	Enclosed_ALPHANUMERIC_Supplement}', "");
Error('\p{Is_Blk=:=--ENCLOSED_ALPHANUM_SUP}');
Error('\P{Is_Blk=:=--ENCLOSED_ALPHANUM_SUP}');
Expect(1, 127487, '\p{Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\p{^Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127487, '\P{Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\P{^Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\p{Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\p{^Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127488, '\P{Is_Blk=enclosedalphanumsup}', "");
Expect(0, 127488, '\P{^Is_Blk=enclosedalphanumsup}', "");
Expect(1, 127487, '\p{Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(0, 127487, '\p{^Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(0, 127487, '\P{Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(1, 127487, '\P{^Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(0, 127488, '\p{Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(1, 127488, '\p{^Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(1, 127488, '\P{Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Expect(0, 127488, '\P{^Is_Blk=_ Enclosed_Alphanum_Sup}', "");
Error('\p{Block=		Enclosed_CJK_letters_And_MONTHS:=}');
Error('\P{Block=		Enclosed_CJK_letters_And_MONTHS:=}');
Expect(1, 13055, '\p{Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(0, 13055, '\p{^Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(0, 13055, '\P{Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(1, 13055, '\P{^Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(0, 13056, '\p{Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(1, 13056, '\p{^Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(1, 13056, '\P{Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Expect(0, 13056, '\P{^Block=	 Enclosed_CJK_LETTERS_And_Months}', "");
Error('\p{Blk:/a/enclosed_cjk}');
Error('\P{Blk:/a/enclosed_cjk}');
Expect(1, 13055, '\p{Blk=enclosedcjk}', "");
Expect(0, 13055, '\p{^Blk=enclosedcjk}', "");
Expect(0, 13055, '\P{Blk=enclosedcjk}', "");
Expect(1, 13055, '\P{^Blk=enclosedcjk}', "");
Expect(0, 13056, '\p{Blk=enclosedcjk}', "");
Expect(1, 13056, '\p{^Blk=enclosedcjk}', "");
Expect(1, 13056, '\P{Blk=enclosedcjk}', "");
Expect(0, 13056, '\P{^Blk=enclosedcjk}', "");
Expect(1, 13055, '\p{Blk=	Enclosed_cjk}', "");
Expect(0, 13055, '\p{^Blk=	Enclosed_cjk}', "");
Expect(0, 13055, '\P{Blk=	Enclosed_cjk}', "");
Expect(1, 13055, '\P{^Blk=	Enclosed_cjk}', "");
Expect(0, 13056, '\p{Blk=	Enclosed_cjk}', "");
Expect(1, 13056, '\p{^Blk=	Enclosed_cjk}', "");
Expect(1, 13056, '\P{Blk=	Enclosed_cjk}', "");
Expect(0, 13056, '\P{^Blk=	Enclosed_cjk}', "");
Error('\p{Is_Block=	_ENCLOSED_CJK_LETTERS_And_months/a/}');
Error('\P{Is_Block=	_ENCLOSED_CJK_LETTERS_And_months/a/}');
Expect(1, 13055, '\p{Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{Is_Block=enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^Is_Block=enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(0, 13055, '\p{^Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(0, 13055, '\P{Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(1, 13055, '\P{^Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(0, 13056, '\p{Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(1, 13056, '\p{^Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(1, 13056, '\P{Is_Block=--enclosed_CJK_letters_And_Months}', "");
Expect(0, 13056, '\P{^Is_Block=--enclosed_CJK_letters_And_Months}', "");
Error('\p{Is_Blk:	enclosed_cjk:=}');
Error('\P{Is_Blk:	enclosed_cjk:=}');
Expect(1, 13055, '\p{Is_Blk=enclosedcjk}', "");
Expect(0, 13055, '\p{^Is_Blk=enclosedcjk}', "");
Expect(0, 13055, '\P{Is_Blk=enclosedcjk}', "");
Expect(1, 13055, '\P{^Is_Blk=enclosedcjk}', "");
Expect(0, 13056, '\p{Is_Blk=enclosedcjk}', "");
Expect(1, 13056, '\p{^Is_Blk=enclosedcjk}', "");
Expect(1, 13056, '\P{Is_Blk=enclosedcjk}', "");
Expect(0, 13056, '\P{^Is_Blk=enclosedcjk}', "");
Expect(1, 13055, '\p{Is_Blk= -enclosed_CJK}', "");
Expect(0, 13055, '\p{^Is_Blk= -enclosed_CJK}', "");
Expect(0, 13055, '\P{Is_Blk= -enclosed_CJK}', "");
Expect(1, 13055, '\P{^Is_Blk= -enclosed_CJK}', "");
Expect(0, 13056, '\p{Is_Blk= -enclosed_CJK}', "");
Expect(1, 13056, '\p{^Is_Blk= -enclosed_CJK}', "");
Expect(1, 13056, '\P{Is_Blk= -enclosed_CJK}', "");
Expect(0, 13056, '\P{^Is_Blk= -enclosed_CJK}', "");
Error('\p{Block=Enclosed_IDEOGRAPHIC_Supplement/a/}');
Error('\P{Block=Enclosed_IDEOGRAPHIC_Supplement/a/}');
Expect(1, 127743, '\p{Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\P{Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\p{Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\P{Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\p{Block= Enclosed_Ideographic_supplement}', "");
Expect(0, 127743, '\p{^Block= Enclosed_Ideographic_supplement}', "");
Expect(0, 127743, '\P{Block= Enclosed_Ideographic_supplement}', "");
Expect(1, 127743, '\P{^Block= Enclosed_Ideographic_supplement}', "");
Expect(0, 127744, '\p{Block= Enclosed_Ideographic_supplement}', "");
Expect(1, 127744, '\p{^Block= Enclosed_Ideographic_supplement}', "");
Expect(1, 127744, '\P{Block= Enclosed_Ideographic_supplement}', "");
Expect(0, 127744, '\P{^Block= Enclosed_Ideographic_supplement}', "");
Error('\p{Blk= /a/enclosed_IDEOGRAPHIC_Sup}');
Error('\P{Blk= /a/enclosed_IDEOGRAPHIC_Sup}');
Expect(1, 127743, '\p{Blk=enclosedideographicsup}', "");
Expect(0, 127743, '\p{^Blk=enclosedideographicsup}', "");
Expect(0, 127743, '\P{Blk=enclosedideographicsup}', "");
Expect(1, 127743, '\P{^Blk=enclosedideographicsup}', "");
Expect(0, 127744, '\p{Blk=enclosedideographicsup}', "");
Expect(1, 127744, '\p{^Blk=enclosedideographicsup}', "");
Expect(1, 127744, '\P{Blk=enclosedideographicsup}', "");
Expect(0, 127744, '\P{^Blk=enclosedideographicsup}', "");
Expect(1, 127743, '\p{Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127743, '\p{^Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127743, '\P{Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(1, 127743, '\P{^Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127744, '\p{Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(1, 127744, '\p{^Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(1, 127744, '\P{Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Expect(0, 127744, '\P{^Blk=		Enclosed_IDEOGRAPHIC_Sup}', "");
Error('\p{Is_Block=--Enclosed_Ideographic_supplement:=}');
Error('\P{Is_Block=--Enclosed_Ideographic_supplement:=}');
Expect(1, 127743, '\p{Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127743, '\P{Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\p{Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127744, '\P{Is_Block=enclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^Is_Block=enclosedideographicsupplement}', "");
Expect(1, 127743, '\p{Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(0, 127743, '\p{^Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(0, 127743, '\P{Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(1, 127743, '\P{^Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(0, 127744, '\p{Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(1, 127744, '\p{^Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(1, 127744, '\P{Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Expect(0, 127744, '\P{^Is_Block=__Enclosed_Ideographic_SUPPLEMENT}', "");
Error('\p{Is_Blk=-/a/ENCLOSED_Ideographic_sup}');
Error('\P{Is_Blk=-/a/ENCLOSED_Ideographic_sup}');
Expect(1, 127743, '\p{Is_Blk:enclosedideographicsup}', "");
Expect(0, 127743, '\p{^Is_Blk:enclosedideographicsup}', "");
Expect(0, 127743, '\P{Is_Blk:enclosedideographicsup}', "");
Expect(1, 127743, '\P{^Is_Blk:enclosedideographicsup}', "");
Expect(0, 127744, '\p{Is_Blk:enclosedideographicsup}', "");
Expect(1, 127744, '\p{^Is_Blk:enclosedideographicsup}', "");
Expect(1, 127744, '\P{Is_Blk:enclosedideographicsup}', "");
Expect(0, 127744, '\P{^Is_Blk:enclosedideographicsup}', "");
Expect(1, 127743, '\p{Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(0, 127743, '\p{^Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(0, 127743, '\P{Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(1, 127743, '\P{^Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(0, 127744, '\p{Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(1, 127744, '\p{^Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(1, 127744, '\P{Is_Blk=- Enclosed_Ideographic_SUP}', "");
Expect(0, 127744, '\P{^Is_Blk=- Enclosed_Ideographic_SUP}', "");
Error('\p{Block=-/a/Ethiopic}');
Error('\P{Block=-/a/Ethiopic}');
Expect(1, 4991, '\p{Block=ethiopic}', "");
Expect(0, 4991, '\p{^Block=ethiopic}', "");
Expect(0, 4991, '\P{Block=ethiopic}', "");
Expect(1, 4991, '\P{^Block=ethiopic}', "");
Expect(0, 4992, '\p{Block=ethiopic}', "");
Expect(1, 4992, '\p{^Block=ethiopic}', "");
Expect(1, 4992, '\P{Block=ethiopic}', "");
Expect(0, 4992, '\P{^Block=ethiopic}', "");
Expect(1, 4991, '\p{Block=-_ethiopic}', "");
Expect(0, 4991, '\p{^Block=-_ethiopic}', "");
Expect(0, 4991, '\P{Block=-_ethiopic}', "");
Expect(1, 4991, '\P{^Block=-_ethiopic}', "");
Expect(0, 4992, '\p{Block=-_ethiopic}', "");
Expect(1, 4992, '\p{^Block=-_ethiopic}', "");
Expect(1, 4992, '\P{Block=-_ethiopic}', "");
Expect(0, 4992, '\P{^Block=-_ethiopic}', "");
Error('\p{Blk=/a/_ Ethiopic}');
Error('\P{Blk=/a/_ Ethiopic}');
Expect(1, 4991, '\p{Blk=ethiopic}', "");
Expect(0, 4991, '\p{^Blk=ethiopic}', "");
Expect(0, 4991, '\P{Blk=ethiopic}', "");
Expect(1, 4991, '\P{^Blk=ethiopic}', "");
Expect(0, 4992, '\p{Blk=ethiopic}', "");
Expect(1, 4992, '\p{^Blk=ethiopic}', "");
Expect(1, 4992, '\P{Blk=ethiopic}', "");
Expect(0, 4992, '\P{^Blk=ethiopic}', "");
Expect(1, 4991, '\p{Blk:    	Ethiopic}', "");
Expect(0, 4991, '\p{^Blk:    	Ethiopic}', "");
Expect(0, 4991, '\P{Blk:    	Ethiopic}', "");
Expect(1, 4991, '\P{^Blk:    	Ethiopic}', "");
Expect(0, 4992, '\p{Blk:    	Ethiopic}', "");
Expect(1, 4992, '\p{^Blk:    	Ethiopic}', "");
Expect(1, 4992, '\P{Blk:    	Ethiopic}', "");
Expect(0, 4992, '\P{^Blk:    	Ethiopic}', "");
Error('\p{Is_Block=_/a/Ethiopic}');
Error('\P{Is_Block=_/a/Ethiopic}');
Expect(1, 4991, '\p{Is_Block: ethiopic}', "");
Expect(0, 4991, '\p{^Is_Block: ethiopic}', "");
Expect(0, 4991, '\P{Is_Block: ethiopic}', "");
Expect(1, 4991, '\P{^Is_Block: ethiopic}', "");
Expect(0, 4992, '\p{Is_Block: ethiopic}', "");
Expect(1, 4992, '\p{^Is_Block: ethiopic}', "");
Expect(1, 4992, '\P{Is_Block: ethiopic}', "");
Expect(0, 4992, '\P{^Is_Block: ethiopic}', "");
Expect(1, 4991, '\p{Is_Block=	 Ethiopic}', "");
Expect(0, 4991, '\p{^Is_Block=	 Ethiopic}', "");
Expect(0, 4991, '\P{Is_Block=	 Ethiopic}', "");
Expect(1, 4991, '\P{^Is_Block=	 Ethiopic}', "");
Expect(0, 4992, '\p{Is_Block=	 Ethiopic}', "");
Expect(1, 4992, '\p{^Is_Block=	 Ethiopic}', "");
Expect(1, 4992, '\P{Is_Block=	 Ethiopic}', "");
Expect(0, 4992, '\P{^Is_Block=	 Ethiopic}', "");
Error('\p{Is_Blk=_/a/Ethiopic}');
Error('\P{Is_Blk=_/a/Ethiopic}');
Expect(1, 4991, '\p{Is_Blk=ethiopic}', "");
Expect(0, 4991, '\p{^Is_Blk=ethiopic}', "");
Expect(0, 4991, '\P{Is_Blk=ethiopic}', "");
Expect(1, 4991, '\P{^Is_Blk=ethiopic}', "");
Expect(0, 4992, '\p{Is_Blk=ethiopic}', "");
Expect(1, 4992, '\p{^Is_Blk=ethiopic}', "");
Expect(1, 4992, '\P{Is_Blk=ethiopic}', "");
Expect(0, 4992, '\P{^Is_Blk=ethiopic}', "");
Expect(1, 4991, '\p{Is_Blk=-ETHIOPIC}', "");
Expect(0, 4991, '\p{^Is_Blk=-ETHIOPIC}', "");
Expect(0, 4991, '\P{Is_Blk=-ETHIOPIC}', "");
Expect(1, 4991, '\P{^Is_Blk=-ETHIOPIC}', "");
Expect(0, 4992, '\p{Is_Blk=-ETHIOPIC}', "");
Expect(1, 4992, '\p{^Is_Blk=-ETHIOPIC}', "");
Expect(1, 4992, '\P{Is_Blk=-ETHIOPIC}', "");
Expect(0, 4992, '\P{^Is_Blk=-ETHIOPIC}', "");
Error('\p{Block=  Ethiopic_Extended:=}');
Error('\P{Block=  Ethiopic_Extended:=}');
Expect(1, 11743, '\p{Block=ethiopicextended}', "");
Expect(0, 11743, '\p{^Block=ethiopicextended}', "");
Expect(0, 11743, '\P{Block=ethiopicextended}', "");
Expect(1, 11743, '\P{^Block=ethiopicextended}', "");
Expect(0, 11744, '\p{Block=ethiopicextended}', "");
Expect(1, 11744, '\p{^Block=ethiopicextended}', "");
Expect(1, 11744, '\P{Block=ethiopicextended}', "");
Expect(0, 11744, '\P{^Block=ethiopicextended}', "");
Expect(1, 11743, '\p{Block=	Ethiopic_Extended}', "");
Expect(0, 11743, '\p{^Block=	Ethiopic_Extended}', "");
Expect(0, 11743, '\P{Block=	Ethiopic_Extended}', "");
Expect(1, 11743, '\P{^Block=	Ethiopic_Extended}', "");
Expect(0, 11744, '\p{Block=	Ethiopic_Extended}', "");
Expect(1, 11744, '\p{^Block=	Ethiopic_Extended}', "");
Expect(1, 11744, '\P{Block=	Ethiopic_Extended}', "");
Expect(0, 11744, '\P{^Block=	Ethiopic_Extended}', "");
Error('\p{Blk= Ethiopic_Ext/a/}');
Error('\P{Blk= Ethiopic_Ext/a/}');
Expect(1, 11743, '\p{Blk=ethiopicext}', "");
Expect(0, 11743, '\p{^Blk=ethiopicext}', "");
Expect(0, 11743, '\P{Blk=ethiopicext}', "");
Expect(1, 11743, '\P{^Blk=ethiopicext}', "");
Expect(0, 11744, '\p{Blk=ethiopicext}', "");
Expect(1, 11744, '\p{^Blk=ethiopicext}', "");
Expect(1, 11744, '\P{Blk=ethiopicext}', "");
Expect(0, 11744, '\P{^Blk=ethiopicext}', "");
Expect(1, 11743, '\p{Blk: 	_ethiopic_ext}', "");
Expect(0, 11743, '\p{^Blk: 	_ethiopic_ext}', "");
Expect(0, 11743, '\P{Blk: 	_ethiopic_ext}', "");
Expect(1, 11743, '\P{^Blk: 	_ethiopic_ext}', "");
Expect(0, 11744, '\p{Blk: 	_ethiopic_ext}', "");
Expect(1, 11744, '\p{^Blk: 	_ethiopic_ext}', "");
Expect(1, 11744, '\P{Blk: 	_ethiopic_ext}', "");
Expect(0, 11744, '\P{^Blk: 	_ethiopic_ext}', "");
Error('\p{Is_Block=__ethiopic_Extended/a/}');
Error('\P{Is_Block=__ethiopic_Extended/a/}');
Expect(1, 11743, '\p{Is_Block=ethiopicextended}', "");
Expect(0, 11743, '\p{^Is_Block=ethiopicextended}', "");
Expect(0, 11743, '\P{Is_Block=ethiopicextended}', "");
Expect(1, 11743, '\P{^Is_Block=ethiopicextended}', "");
Expect(0, 11744, '\p{Is_Block=ethiopicextended}', "");
Expect(1, 11744, '\p{^Is_Block=ethiopicextended}', "");
Expect(1, 11744, '\P{Is_Block=ethiopicextended}', "");
Expect(0, 11744, '\P{^Is_Block=ethiopicextended}', "");
Expect(1, 11743, '\p{Is_Block=	_Ethiopic_extended}', "");
Expect(0, 11743, '\p{^Is_Block=	_Ethiopic_extended}', "");
Expect(0, 11743, '\P{Is_Block=	_Ethiopic_extended}', "");
Expect(1, 11743, '\P{^Is_Block=	_Ethiopic_extended}', "");
Expect(0, 11744, '\p{Is_Block=	_Ethiopic_extended}', "");
Expect(1, 11744, '\p{^Is_Block=	_Ethiopic_extended}', "");
Expect(1, 11744, '\P{Is_Block=	_Ethiopic_extended}', "");
Expect(0, 11744, '\P{^Is_Block=	_Ethiopic_extended}', "");
Error('\p{Is_Blk=_/a/ethiopic_Ext}');
Error('\P{Is_Blk=_/a/ethiopic_Ext}');
Expect(1, 11743, '\p{Is_Blk:ethiopicext}', "");
Expect(0, 11743, '\p{^Is_Blk:ethiopicext}', "");
Expect(0, 11743, '\P{Is_Blk:ethiopicext}', "");
Expect(1, 11743, '\P{^Is_Blk:ethiopicext}', "");
Expect(0, 11744, '\p{Is_Blk:ethiopicext}', "");
Expect(1, 11744, '\p{^Is_Blk:ethiopicext}', "");
Expect(1, 11744, '\P{Is_Blk:ethiopicext}', "");
Expect(0, 11744, '\P{^Is_Blk:ethiopicext}', "");
Expect(1, 11743, '\p{Is_Blk=	ethiopic_ext}', "");
Expect(0, 11743, '\p{^Is_Blk=	ethiopic_ext}', "");
Expect(0, 11743, '\P{Is_Blk=	ethiopic_ext}', "");
Expect(1, 11743, '\P{^Is_Blk=	ethiopic_ext}', "");
Expect(0, 11744, '\p{Is_Blk=	ethiopic_ext}', "");
Expect(1, 11744, '\p{^Is_Blk=	ethiopic_ext}', "");
Expect(1, 11744, '\P{Is_Blk=	ethiopic_ext}', "");
Expect(0, 11744, '\P{^Is_Blk=	ethiopic_ext}', "");
Error('\p{Block=:=	Ethiopic_extended_A}');
Error('\P{Block=:=	Ethiopic_extended_A}');
Expect(1, 43823, '\p{Block=ethiopicextendeda}', "");
Expect(0, 43823, '\p{^Block=ethiopicextendeda}', "");
Expect(0, 43823, '\P{Block=ethiopicextendeda}', "");
Expect(1, 43823, '\P{^Block=ethiopicextendeda}', "");
Expect(0, 43824, '\p{Block=ethiopicextendeda}', "");
Expect(1, 43824, '\p{^Block=ethiopicextendeda}', "");
Expect(1, 43824, '\P{Block=ethiopicextendeda}', "");
Expect(0, 43824, '\P{^Block=ethiopicextendeda}', "");
Expect(1, 43823, '\p{Block=-ETHIOPIC_Extended_A}', "");
Expect(0, 43823, '\p{^Block=-ETHIOPIC_Extended_A}', "");
Expect(0, 43823, '\P{Block=-ETHIOPIC_Extended_A}', "");
Expect(1, 43823, '\P{^Block=-ETHIOPIC_Extended_A}', "");
Expect(0, 43824, '\p{Block=-ETHIOPIC_Extended_A}', "");
Expect(1, 43824, '\p{^Block=-ETHIOPIC_Extended_A}', "");
Expect(1, 43824, '\P{Block=-ETHIOPIC_Extended_A}', "");
Expect(0, 43824, '\P{^Block=-ETHIOPIC_Extended_A}', "");
Error('\p{Blk:	_/a/Ethiopic_EXT_A}');
Error('\P{Blk:	_/a/Ethiopic_EXT_A}');
Expect(1, 43823, '\p{Blk=ethiopicexta}', "");
Expect(0, 43823, '\p{^Blk=ethiopicexta}', "");
Expect(0, 43823, '\P{Blk=ethiopicexta}', "");
Expect(1, 43823, '\P{^Blk=ethiopicexta}', "");
Expect(0, 43824, '\p{Blk=ethiopicexta}', "");
Expect(1, 43824, '\p{^Blk=ethiopicexta}', "");
Expect(1, 43824, '\P{Blk=ethiopicexta}', "");
Expect(0, 43824, '\P{^Blk=ethiopicexta}', "");
Expect(1, 43823, '\p{Blk=-	ethiopic_ext_a}', "");
Expect(0, 43823, '\p{^Blk=-	ethiopic_ext_a}', "");
Expect(0, 43823, '\P{Blk=-	ethiopic_ext_a}', "");
Expect(1, 43823, '\P{^Blk=-	ethiopic_ext_a}', "");
Expect(0, 43824, '\p{Blk=-	ethiopic_ext_a}', "");
Expect(1, 43824, '\p{^Blk=-	ethiopic_ext_a}', "");
Expect(1, 43824, '\P{Blk=-	ethiopic_ext_a}', "");
Expect(0, 43824, '\P{^Blk=-	ethiopic_ext_a}', "");
Error('\p{Is_Block=:=_Ethiopic_Extended_a}');
Error('\P{Is_Block=:=_Ethiopic_Extended_a}');
Expect(1, 43823, '\p{Is_Block=ethiopicextendeda}', "");
Expect(0, 43823, '\p{^Is_Block=ethiopicextendeda}', "");
Expect(0, 43823, '\P{Is_Block=ethiopicextendeda}', "");
Expect(1, 43823, '\P{^Is_Block=ethiopicextendeda}', "");
Expect(0, 43824, '\p{Is_Block=ethiopicextendeda}', "");
Expect(1, 43824, '\p{^Is_Block=ethiopicextendeda}', "");
Expect(1, 43824, '\P{Is_Block=ethiopicextendeda}', "");
Expect(0, 43824, '\P{^Is_Block=ethiopicextendeda}', "");
Expect(1, 43823, '\p{Is_Block:_ETHIOPIC_extended_A}', "");
Expect(0, 43823, '\p{^Is_Block:_ETHIOPIC_extended_A}', "");
Expect(0, 43823, '\P{Is_Block:_ETHIOPIC_extended_A}', "");
Expect(1, 43823, '\P{^Is_Block:_ETHIOPIC_extended_A}', "");
Expect(0, 43824, '\p{Is_Block:_ETHIOPIC_extended_A}', "");
Expect(1, 43824, '\p{^Is_Block:_ETHIOPIC_extended_A}', "");
Expect(1, 43824, '\P{Is_Block:_ETHIOPIC_extended_A}', "");
Expect(0, 43824, '\P{^Is_Block:_ETHIOPIC_extended_A}', "");
Error('\p{Is_Blk=/a/_	Ethiopic_Ext_A}');
Error('\P{Is_Blk=/a/_	Ethiopic_Ext_A}');
Expect(1, 43823, '\p{Is_Blk=ethiopicexta}', "");
Expect(0, 43823, '\p{^Is_Blk=ethiopicexta}', "");
Expect(0, 43823, '\P{Is_Blk=ethiopicexta}', "");
Expect(1, 43823, '\P{^Is_Blk=ethiopicexta}', "");
Expect(0, 43824, '\p{Is_Blk=ethiopicexta}', "");
Expect(1, 43824, '\p{^Is_Blk=ethiopicexta}', "");
Expect(1, 43824, '\P{Is_Blk=ethiopicexta}', "");
Expect(0, 43824, '\P{^Is_Blk=ethiopicexta}', "");
Expect(1, 43823, '\p{Is_Blk= 	Ethiopic_ext_a}', "");
Expect(0, 43823, '\p{^Is_Blk= 	Ethiopic_ext_a}', "");
Expect(0, 43823, '\P{Is_Blk= 	Ethiopic_ext_a}', "");
Expect(1, 43823, '\P{^Is_Blk= 	Ethiopic_ext_a}', "");
Expect(0, 43824, '\p{Is_Blk= 	Ethiopic_ext_a}', "");
Expect(1, 43824, '\p{^Is_Blk= 	Ethiopic_ext_a}', "");
Expect(1, 43824, '\P{Is_Blk= 	Ethiopic_ext_a}', "");
Expect(0, 43824, '\P{^Is_Blk= 	Ethiopic_ext_a}', "");
Error('\p{Block=/a/_Ethiopic_Supplement}');
Error('\P{Block=/a/_Ethiopic_Supplement}');
Expect(1, 5023, '\p{Block=ethiopicsupplement}', "");
Expect(0, 5023, '\p{^Block=ethiopicsupplement}', "");
Expect(0, 5023, '\P{Block=ethiopicsupplement}', "");
Expect(1, 5023, '\P{^Block=ethiopicsupplement}', "");
Expect(0, 5024, '\p{Block=ethiopicsupplement}', "");
Expect(1, 5024, '\p{^Block=ethiopicsupplement}', "");
Expect(1, 5024, '\P{Block=ethiopicsupplement}', "");
Expect(0, 5024, '\P{^Block=ethiopicsupplement}', "");
Expect(1, 5023, '\p{Block=- ethiopic_Supplement}', "");
Expect(0, 5023, '\p{^Block=- ethiopic_Supplement}', "");
Expect(0, 5023, '\P{Block=- ethiopic_Supplement}', "");
Expect(1, 5023, '\P{^Block=- ethiopic_Supplement}', "");
Expect(0, 5024, '\p{Block=- ethiopic_Supplement}', "");
Expect(1, 5024, '\p{^Block=- ethiopic_Supplement}', "");
Expect(1, 5024, '\P{Block=- ethiopic_Supplement}', "");
Expect(0, 5024, '\P{^Block=- ethiopic_Supplement}', "");
Error('\p{Blk=:=--ETHIOPIC_SUP}');
Error('\P{Blk=:=--ETHIOPIC_SUP}');
Expect(1, 5023, '\p{Blk=ethiopicsup}', "");
Expect(0, 5023, '\p{^Blk=ethiopicsup}', "");
Expect(0, 5023, '\P{Blk=ethiopicsup}', "");
Expect(1, 5023, '\P{^Blk=ethiopicsup}', "");
Expect(0, 5024, '\p{Blk=ethiopicsup}', "");
Expect(1, 5024, '\p{^Blk=ethiopicsup}', "");
Expect(1, 5024, '\P{Blk=ethiopicsup}', "");
Expect(0, 5024, '\P{^Blk=ethiopicsup}', "");
Expect(1, 5023, '\p{Blk=-ethiopic_Sup}', "");
Expect(0, 5023, '\p{^Blk=-ethiopic_Sup}', "");
Expect(0, 5023, '\P{Blk=-ethiopic_Sup}', "");
Expect(1, 5023, '\P{^Blk=-ethiopic_Sup}', "");
Expect(0, 5024, '\p{Blk=-ethiopic_Sup}', "");
Expect(1, 5024, '\p{^Blk=-ethiopic_Sup}', "");
Expect(1, 5024, '\P{Blk=-ethiopic_Sup}', "");
Expect(0, 5024, '\P{^Blk=-ethiopic_Sup}', "");
Error('\p{Is_Block= /a/ethiopic_Supplement}');
Error('\P{Is_Block= /a/ethiopic_Supplement}');
Expect(1, 5023, '\p{Is_Block=ethiopicsupplement}', "");
Expect(0, 5023, '\p{^Is_Block=ethiopicsupplement}', "");
Expect(0, 5023, '\P{Is_Block=ethiopicsupplement}', "");
Expect(1, 5023, '\P{^Is_Block=ethiopicsupplement}', "");
Expect(0, 5024, '\p{Is_Block=ethiopicsupplement}', "");
Expect(1, 5024, '\p{^Is_Block=ethiopicsupplement}', "");
Expect(1, 5024, '\P{Is_Block=ethiopicsupplement}', "");
Expect(0, 5024, '\P{^Is_Block=ethiopicsupplement}', "");
Expect(1, 5023, '\p{Is_Block=		Ethiopic_Supplement}', "");
Expect(0, 5023, '\p{^Is_Block=		Ethiopic_Supplement}', "");
Expect(0, 5023, '\P{Is_Block=		Ethiopic_Supplement}', "");
Expect(1, 5023, '\P{^Is_Block=		Ethiopic_Supplement}', "");
Expect(0, 5024, '\p{Is_Block=		Ethiopic_Supplement}', "");
Expect(1, 5024, '\p{^Is_Block=		Ethiopic_Supplement}', "");
Expect(1, 5024, '\P{Is_Block=		Ethiopic_Supplement}', "");
Expect(0, 5024, '\P{^Is_Block=		Ethiopic_Supplement}', "");
Error('\p{Is_Blk= -Ethiopic_SUP:=}');
Error('\P{Is_Blk= -Ethiopic_SUP:=}');
Expect(1, 5023, '\p{Is_Blk=ethiopicsup}', "");
Expect(0, 5023, '\p{^Is_Blk=ethiopicsup}', "");
Expect(0, 5023, '\P{Is_Blk=ethiopicsup}', "");
Expect(1, 5023, '\P{^Is_Blk=ethiopicsup}', "");
Expect(0, 5024, '\p{Is_Blk=ethiopicsup}', "");
Expect(1, 5024, '\p{^Is_Blk=ethiopicsup}', "");
Expect(1, 5024, '\P{Is_Blk=ethiopicsup}', "");
Expect(0, 5024, '\P{^Is_Blk=ethiopicsup}', "");
Expect(1, 5023, '\p{Is_Blk:   -Ethiopic_Sup}', "");
Expect(0, 5023, '\p{^Is_Blk:   -Ethiopic_Sup}', "");
Expect(0, 5023, '\P{Is_Blk:   -Ethiopic_Sup}', "");
Expect(1, 5023, '\P{^Is_Blk:   -Ethiopic_Sup}', "");
Expect(0, 5024, '\p{Is_Blk:   -Ethiopic_Sup}', "");
Expect(1, 5024, '\p{^Is_Blk:   -Ethiopic_Sup}', "");
Expect(1, 5024, '\P{Is_Blk:   -Ethiopic_Sup}', "");
Expect(0, 5024, '\P{^Is_Blk:   -Ethiopic_Sup}', "");
Error('\p{Block=-:=geometric_SHAPES}');
Error('\P{Block=-:=geometric_SHAPES}');
Expect(1, 9727, '\p{Block=geometricshapes}', "");
Expect(0, 9727, '\p{^Block=geometricshapes}', "");
Expect(0, 9727, '\P{Block=geometricshapes}', "");
Expect(1, 9727, '\P{^Block=geometricshapes}', "");
Expect(0, 9728, '\p{Block=geometricshapes}', "");
Expect(1, 9728, '\p{^Block=geometricshapes}', "");
Expect(1, 9728, '\P{Block=geometricshapes}', "");
Expect(0, 9728, '\P{^Block=geometricshapes}', "");
Expect(1, 9727, '\p{Block=-	geometric_Shapes}', "");
Expect(0, 9727, '\p{^Block=-	geometric_Shapes}', "");
Expect(0, 9727, '\P{Block=-	geometric_Shapes}', "");
Expect(1, 9727, '\P{^Block=-	geometric_Shapes}', "");
Expect(0, 9728, '\p{Block=-	geometric_Shapes}', "");
Expect(1, 9728, '\p{^Block=-	geometric_Shapes}', "");
Expect(1, 9728, '\P{Block=-	geometric_Shapes}', "");
Expect(0, 9728, '\P{^Block=-	geometric_Shapes}', "");
Error('\p{Blk=:=_ Geometric_Shapes}');
Error('\P{Blk=:=_ Geometric_Shapes}');
Expect(1, 9727, '\p{Blk=geometricshapes}', "");
Expect(0, 9727, '\p{^Blk=geometricshapes}', "");
Expect(0, 9727, '\P{Blk=geometricshapes}', "");
Expect(1, 9727, '\P{^Blk=geometricshapes}', "");
Expect(0, 9728, '\p{Blk=geometricshapes}', "");
Expect(1, 9728, '\p{^Blk=geometricshapes}', "");
Expect(1, 9728, '\P{Blk=geometricshapes}', "");
Expect(0, 9728, '\P{^Blk=geometricshapes}', "");
Expect(1, 9727, '\p{Blk= GEOMETRIC_shapes}', "");
Expect(0, 9727, '\p{^Blk= GEOMETRIC_shapes}', "");
Expect(0, 9727, '\P{Blk= GEOMETRIC_shapes}', "");
Expect(1, 9727, '\P{^Blk= GEOMETRIC_shapes}', "");
Expect(0, 9728, '\p{Blk= GEOMETRIC_shapes}', "");
Expect(1, 9728, '\p{^Blk= GEOMETRIC_shapes}', "");
Expect(1, 9728, '\P{Blk= GEOMETRIC_shapes}', "");
Expect(0, 9728, '\P{^Blk= GEOMETRIC_shapes}', "");
Error('\p{Is_Block=/a/ GEOMETRIC_SHAPES}');
Error('\P{Is_Block=/a/ GEOMETRIC_SHAPES}');
Expect(1, 9727, '\p{Is_Block=geometricshapes}', "");
Expect(0, 9727, '\p{^Is_Block=geometricshapes}', "");
Expect(0, 9727, '\P{Is_Block=geometricshapes}', "");
Expect(1, 9727, '\P{^Is_Block=geometricshapes}', "");
Expect(0, 9728, '\p{Is_Block=geometricshapes}', "");
Expect(1, 9728, '\p{^Is_Block=geometricshapes}', "");
Expect(1, 9728, '\P{Is_Block=geometricshapes}', "");
Expect(0, 9728, '\P{^Is_Block=geometricshapes}', "");
Expect(1, 9727, '\p{Is_Block=_	Geometric_shapes}', "");
Expect(0, 9727, '\p{^Is_Block=_	Geometric_shapes}', "");
Expect(0, 9727, '\P{Is_Block=_	Geometric_shapes}', "");
Expect(1, 9727, '\P{^Is_Block=_	Geometric_shapes}', "");
Expect(0, 9728, '\p{Is_Block=_	Geometric_shapes}', "");
Expect(1, 9728, '\p{^Is_Block=_	Geometric_shapes}', "");
Expect(1, 9728, '\P{Is_Block=_	Geometric_shapes}', "");
Expect(0, 9728, '\P{^Is_Block=_	Geometric_shapes}', "");
Error('\p{Is_Blk=/a/--Geometric_Shapes}');
Error('\P{Is_Blk=/a/--Geometric_Shapes}');
Expect(1, 9727, '\p{Is_Blk=geometricshapes}', "");
Expect(0, 9727, '\p{^Is_Blk=geometricshapes}', "");
Expect(0, 9727, '\P{Is_Blk=geometricshapes}', "");
Expect(1, 9727, '\P{^Is_Blk=geometricshapes}', "");
Expect(0, 9728, '\p{Is_Blk=geometricshapes}', "");
Expect(1, 9728, '\p{^Is_Blk=geometricshapes}', "");
Expect(1, 9728, '\P{Is_Blk=geometricshapes}', "");
Expect(0, 9728, '\P{^Is_Blk=geometricshapes}', "");
Expect(1, 9727, '\p{Is_Blk= Geometric_SHAPES}', "");
Expect(0, 9727, '\p{^Is_Blk= Geometric_SHAPES}', "");
Expect(0, 9727, '\P{Is_Blk= Geometric_SHAPES}', "");
Expect(1, 9727, '\P{^Is_Blk= Geometric_SHAPES}', "");
Expect(0, 9728, '\p{Is_Blk= Geometric_SHAPES}', "");
Expect(1, 9728, '\p{^Is_Blk= Geometric_SHAPES}', "");
Expect(1, 9728, '\P{Is_Blk= Geometric_SHAPES}', "");
Expect(0, 9728, '\P{^Is_Blk= Geometric_SHAPES}', "");
Error('\p{Block=_-GEORGIAN:=}');
Error('\P{Block=_-GEORGIAN:=}');
Expect(1, 4351, '\p{Block=georgian}', "");
Expect(0, 4351, '\p{^Block=georgian}', "");
Expect(0, 4351, '\P{Block=georgian}', "");
Expect(1, 4351, '\P{^Block=georgian}', "");
Expect(0, 4352, '\p{Block=georgian}', "");
Expect(1, 4352, '\p{^Block=georgian}', "");
Expect(1, 4352, '\P{Block=georgian}', "");
Expect(0, 4352, '\P{^Block=georgian}', "");
Expect(1, 4351, '\p{Block= Georgian}', "");
Expect(0, 4351, '\p{^Block= Georgian}', "");
Expect(0, 4351, '\P{Block= Georgian}', "");
Expect(1, 4351, '\P{^Block= Georgian}', "");
Expect(0, 4352, '\p{Block= Georgian}', "");
Expect(1, 4352, '\p{^Block= Georgian}', "");
Expect(1, 4352, '\P{Block= Georgian}', "");
Expect(0, 4352, '\P{^Block= Georgian}', "");
Error('\p{Blk=	 Georgian/a/}');
Error('\P{Blk=	 Georgian/a/}');
Expect(1, 4351, '\p{Blk=georgian}', "");
Expect(0, 4351, '\p{^Blk=georgian}', "");
Expect(0, 4351, '\P{Blk=georgian}', "");
Expect(1, 4351, '\P{^Blk=georgian}', "");
Expect(0, 4352, '\p{Blk=georgian}', "");
Expect(1, 4352, '\p{^Blk=georgian}', "");
Expect(1, 4352, '\P{Blk=georgian}', "");
Expect(0, 4352, '\P{^Blk=georgian}', "");
Expect(1, 4351, '\p{Blk=		georgian}', "");
Expect(0, 4351, '\p{^Blk=		georgian}', "");
Expect(0, 4351, '\P{Blk=		georgian}', "");
Expect(1, 4351, '\P{^Blk=		georgian}', "");
Expect(0, 4352, '\p{Blk=		georgian}', "");
Expect(1, 4352, '\p{^Blk=		georgian}', "");
Expect(1, 4352, '\P{Blk=		georgian}', "");
Expect(0, 4352, '\P{^Blk=		georgian}', "");
Error('\p{Is_Block=/a/	Georgian}');
Error('\P{Is_Block=/a/	Georgian}');
Expect(1, 4351, '\p{Is_Block=georgian}', "");
Expect(0, 4351, '\p{^Is_Block=georgian}', "");
Expect(0, 4351, '\P{Is_Block=georgian}', "");
Expect(1, 4351, '\P{^Is_Block=georgian}', "");
Expect(0, 4352, '\p{Is_Block=georgian}', "");
Expect(1, 4352, '\p{^Is_Block=georgian}', "");
Expect(1, 4352, '\P{Is_Block=georgian}', "");
Expect(0, 4352, '\P{^Is_Block=georgian}', "");
Expect(1, 4351, '\p{Is_Block=	-GEORGIAN}', "");
Expect(0, 4351, '\p{^Is_Block=	-GEORGIAN}', "");
Expect(0, 4351, '\P{Is_Block=	-GEORGIAN}', "");
Expect(1, 4351, '\P{^Is_Block=	-GEORGIAN}', "");
Expect(0, 4352, '\p{Is_Block=	-GEORGIAN}', "");
Expect(1, 4352, '\p{^Is_Block=	-GEORGIAN}', "");
Expect(1, 4352, '\P{Is_Block=	-GEORGIAN}', "");
Expect(0, 4352, '\P{^Is_Block=	-GEORGIAN}', "");
Error('\p{Is_Blk=:= 	Georgian}');
Error('\P{Is_Blk=:= 	Georgian}');
Expect(1, 4351, '\p{Is_Blk=georgian}', "");
Expect(0, 4351, '\p{^Is_Blk=georgian}', "");
Expect(0, 4351, '\P{Is_Blk=georgian}', "");
Expect(1, 4351, '\P{^Is_Blk=georgian}', "");
Expect(0, 4352, '\p{Is_Blk=georgian}', "");
Expect(1, 4352, '\p{^Is_Blk=georgian}', "");
Expect(1, 4352, '\P{Is_Blk=georgian}', "");
Expect(0, 4352, '\P{^Is_Blk=georgian}', "");
Expect(1, 4351, '\p{Is_Blk=_GEORGIAN}', "");
Expect(0, 4351, '\p{^Is_Blk=_GEORGIAN}', "");
Expect(0, 4351, '\P{Is_Blk=_GEORGIAN}', "");
Expect(1, 4351, '\P{^Is_Blk=_GEORGIAN}', "");
Expect(0, 4352, '\p{Is_Blk=_GEORGIAN}', "");
Expect(1, 4352, '\p{^Is_Blk=_GEORGIAN}', "");
Expect(1, 4352, '\P{Is_Blk=_GEORGIAN}', "");
Expect(0, 4352, '\P{^Is_Blk=_GEORGIAN}', "");
Error('\p{Block=-Georgian_supplement/a/}');
Error('\P{Block=-Georgian_supplement/a/}');
Expect(1, 11567, '\p{Block=georgiansupplement}', "");
Expect(0, 11567, '\p{^Block=georgiansupplement}', "");
Expect(0, 11567, '\P{Block=georgiansupplement}', "");
Expect(1, 11567, '\P{^Block=georgiansupplement}', "");
Expect(0, 11568, '\p{Block=georgiansupplement}', "");
Expect(1, 11568, '\p{^Block=georgiansupplement}', "");
Expect(1, 11568, '\P{Block=georgiansupplement}', "");
Expect(0, 11568, '\P{^Block=georgiansupplement}', "");
Expect(1, 11567, '\p{Block:		 GEORGIAN_Supplement}', "");
Expect(0, 11567, '\p{^Block:		 GEORGIAN_Supplement}', "");
Expect(0, 11567, '\P{Block:		 GEORGIAN_Supplement}', "");
Expect(1, 11567, '\P{^Block:		 GEORGIAN_Supplement}', "");
Expect(0, 11568, '\p{Block:		 GEORGIAN_Supplement}', "");
Expect(1, 11568, '\p{^Block:		 GEORGIAN_Supplement}', "");
Expect(1, 11568, '\P{Block:		 GEORGIAN_Supplement}', "");
Expect(0, 11568, '\P{^Block:		 GEORGIAN_Supplement}', "");
Error('\p{Blk=GEORGIAN_Sup/a/}');
Error('\P{Blk=GEORGIAN_Sup/a/}');
Expect(1, 11567, '\p{Blk:georgiansup}', "");
Expect(0, 11567, '\p{^Blk:georgiansup}', "");
Expect(0, 11567, '\P{Blk:georgiansup}', "");
Expect(1, 11567, '\P{^Blk:georgiansup}', "");
Expect(0, 11568, '\p{Blk:georgiansup}', "");
Expect(1, 11568, '\p{^Blk:georgiansup}', "");
Expect(1, 11568, '\P{Blk:georgiansup}', "");
Expect(0, 11568, '\P{^Blk:georgiansup}', "");
Expect(1, 11567, '\p{Blk:		 georgian_sup}', "");
Expect(0, 11567, '\p{^Blk:		 georgian_sup}', "");
Expect(0, 11567, '\P{Blk:		 georgian_sup}', "");
Expect(1, 11567, '\P{^Blk:		 georgian_sup}', "");
Expect(0, 11568, '\p{Blk:		 georgian_sup}', "");
Expect(1, 11568, '\p{^Blk:		 georgian_sup}', "");
Expect(1, 11568, '\P{Blk:		 georgian_sup}', "");
Expect(0, 11568, '\P{^Blk:		 georgian_sup}', "");
Error('\p{Is_Block=:=__Georgian_supplement}');
Error('\P{Is_Block=:=__Georgian_supplement}');
Expect(1, 11567, '\p{Is_Block=georgiansupplement}', "");
Expect(0, 11567, '\p{^Is_Block=georgiansupplement}', "");
Expect(0, 11567, '\P{Is_Block=georgiansupplement}', "");
Expect(1, 11567, '\P{^Is_Block=georgiansupplement}', "");
Expect(0, 11568, '\p{Is_Block=georgiansupplement}', "");
Expect(1, 11568, '\p{^Is_Block=georgiansupplement}', "");
Expect(1, 11568, '\P{Is_Block=georgiansupplement}', "");
Expect(0, 11568, '\P{^Is_Block=georgiansupplement}', "");
Expect(1, 11567, '\p{Is_Block=GEORGIAN_Supplement}', "");
Expect(0, 11567, '\p{^Is_Block=GEORGIAN_Supplement}', "");
Expect(0, 11567, '\P{Is_Block=GEORGIAN_Supplement}', "");
Expect(1, 11567, '\P{^Is_Block=GEORGIAN_Supplement}', "");
Expect(0, 11568, '\p{Is_Block=GEORGIAN_Supplement}', "");
Expect(1, 11568, '\p{^Is_Block=GEORGIAN_Supplement}', "");
Expect(1, 11568, '\P{Is_Block=GEORGIAN_Supplement}', "");
Expect(0, 11568, '\P{^Is_Block=GEORGIAN_Supplement}', "");
Error('\p{Is_Blk=:=_-Georgian_sup}');
Error('\P{Is_Blk=:=_-Georgian_sup}');
Expect(1, 11567, '\p{Is_Blk=georgiansup}', "");
Expect(0, 11567, '\p{^Is_Blk=georgiansup}', "");
Expect(0, 11567, '\P{Is_Blk=georgiansup}', "");
Expect(1, 11567, '\P{^Is_Blk=georgiansup}', "");
Expect(0, 11568, '\p{Is_Blk=georgiansup}', "");
Expect(1, 11568, '\p{^Is_Blk=georgiansup}', "");
Expect(1, 11568, '\P{Is_Blk=georgiansup}', "");
Expect(0, 11568, '\P{^Is_Blk=georgiansup}', "");
Expect(1, 11567, '\p{Is_Blk= _Georgian_Sup}', "");
Expect(0, 11567, '\p{^Is_Blk= _Georgian_Sup}', "");
Expect(0, 11567, '\P{Is_Blk= _Georgian_Sup}', "");
Expect(1, 11567, '\P{^Is_Blk= _Georgian_Sup}', "");
Expect(0, 11568, '\p{Is_Blk= _Georgian_Sup}', "");
Expect(1, 11568, '\p{^Is_Blk= _Georgian_Sup}', "");
Expect(1, 11568, '\P{Is_Blk= _Georgian_Sup}', "");
Expect(0, 11568, '\P{^Is_Blk= _Georgian_Sup}', "");
Error('\p{Block:	_:=Glagolitic}');
Error('\P{Block:	_:=Glagolitic}');
Expect(1, 11359, '\p{Block=glagolitic}', "");
Expect(0, 11359, '\p{^Block=glagolitic}', "");
Expect(0, 11359, '\P{Block=glagolitic}', "");
Expect(1, 11359, '\P{^Block=glagolitic}', "");
Expect(0, 11360, '\p{Block=glagolitic}', "");
Expect(1, 11360, '\p{^Block=glagolitic}', "");
Expect(1, 11360, '\P{Block=glagolitic}', "");
Expect(0, 11360, '\P{^Block=glagolitic}', "");
Expect(1, 11359, '\p{Block=_-Glagolitic}', "");
Expect(0, 11359, '\p{^Block=_-Glagolitic}', "");
Expect(0, 11359, '\P{Block=_-Glagolitic}', "");
Expect(1, 11359, '\P{^Block=_-Glagolitic}', "");
Expect(0, 11360, '\p{Block=_-Glagolitic}', "");
Expect(1, 11360, '\p{^Block=_-Glagolitic}', "");
Expect(1, 11360, '\P{Block=_-Glagolitic}', "");
Expect(0, 11360, '\P{^Block=_-Glagolitic}', "");
Error('\p{Blk=_ glagolitic:=}');
Error('\P{Blk=_ glagolitic:=}');
Expect(1, 11359, '\p{Blk=glagolitic}', "");
Expect(0, 11359, '\p{^Blk=glagolitic}', "");
Expect(0, 11359, '\P{Blk=glagolitic}', "");
Expect(1, 11359, '\P{^Blk=glagolitic}', "");
Expect(0, 11360, '\p{Blk=glagolitic}', "");
Expect(1, 11360, '\p{^Blk=glagolitic}', "");
Expect(1, 11360, '\P{Blk=glagolitic}', "");
Expect(0, 11360, '\P{^Blk=glagolitic}', "");
Expect(1, 11359, '\p{Blk=		glagolitic}', "");
Expect(0, 11359, '\p{^Blk=		glagolitic}', "");
Expect(0, 11359, '\P{Blk=		glagolitic}', "");
Expect(1, 11359, '\P{^Blk=		glagolitic}', "");
Expect(0, 11360, '\p{Blk=		glagolitic}', "");
Expect(1, 11360, '\p{^Blk=		glagolitic}', "");
Expect(1, 11360, '\P{Blk=		glagolitic}', "");
Expect(0, 11360, '\P{^Blk=		glagolitic}', "");
Error('\p{Is_Block=	/a/GLAGOLITIC}');
Error('\P{Is_Block=	/a/GLAGOLITIC}');
Expect(1, 11359, '\p{Is_Block=glagolitic}', "");
Expect(0, 11359, '\p{^Is_Block=glagolitic}', "");
Expect(0, 11359, '\P{Is_Block=glagolitic}', "");
Expect(1, 11359, '\P{^Is_Block=glagolitic}', "");
Expect(0, 11360, '\p{Is_Block=glagolitic}', "");
Expect(1, 11360, '\p{^Is_Block=glagolitic}', "");
Expect(1, 11360, '\P{Is_Block=glagolitic}', "");
Expect(0, 11360, '\P{^Is_Block=glagolitic}', "");
Expect(1, 11359, '\p{Is_Block=--glagolitic}', "");
Expect(0, 11359, '\p{^Is_Block=--glagolitic}', "");
Expect(0, 11359, '\P{Is_Block=--glagolitic}', "");
Expect(1, 11359, '\P{^Is_Block=--glagolitic}', "");
Expect(0, 11360, '\p{Is_Block=--glagolitic}', "");
Expect(1, 11360, '\p{^Is_Block=--glagolitic}', "");
Expect(1, 11360, '\P{Is_Block=--glagolitic}', "");
Expect(0, 11360, '\P{^Is_Block=--glagolitic}', "");
Error('\p{Is_Blk=-	glagolitic:=}');
Error('\P{Is_Blk=-	glagolitic:=}');
Expect(1, 11359, '\p{Is_Blk=glagolitic}', "");
Expect(0, 11359, '\p{^Is_Blk=glagolitic}', "");
Expect(0, 11359, '\P{Is_Blk=glagolitic}', "");
Expect(1, 11359, '\P{^Is_Blk=glagolitic}', "");
Expect(0, 11360, '\p{Is_Blk=glagolitic}', "");
Expect(1, 11360, '\p{^Is_Blk=glagolitic}', "");
Expect(1, 11360, '\P{Is_Blk=glagolitic}', "");
Expect(0, 11360, '\P{^Is_Blk=glagolitic}', "");
Expect(1, 11359, '\p{Is_Blk= _Glagolitic}', "");
Expect(0, 11359, '\p{^Is_Blk= _Glagolitic}', "");
Expect(0, 11359, '\P{Is_Blk= _Glagolitic}', "");
Expect(1, 11359, '\P{^Is_Blk= _Glagolitic}', "");
Expect(0, 11360, '\p{Is_Blk= _Glagolitic}', "");
Expect(1, 11360, '\p{^Is_Blk= _Glagolitic}', "");
Expect(1, 11360, '\P{Is_Blk= _Glagolitic}', "");
Expect(0, 11360, '\P{^Is_Blk= _Glagolitic}', "");
Error('\p{Block=:=	 Gothic}');
Error('\P{Block=:=	 Gothic}');
Expect(1, 66383, '\p{Block=gothic}', "");
Expect(0, 66383, '\p{^Block=gothic}', "");
Expect(0, 66383, '\P{Block=gothic}', "");
Expect(1, 66383, '\P{^Block=gothic}', "");
Expect(0, 66384, '\p{Block=gothic}', "");
Expect(1, 66384, '\p{^Block=gothic}', "");
Expect(1, 66384, '\P{Block=gothic}', "");
Expect(0, 66384, '\P{^Block=gothic}', "");
Expect(1, 66383, '\p{Block:   _gothic}', "");
Expect(0, 66383, '\p{^Block:   _gothic}', "");
Expect(0, 66383, '\P{Block:   _gothic}', "");
Expect(1, 66383, '\P{^Block:   _gothic}', "");
Expect(0, 66384, '\p{Block:   _gothic}', "");
Expect(1, 66384, '\p{^Block:   _gothic}', "");
Expect(1, 66384, '\P{Block:   _gothic}', "");
Expect(0, 66384, '\P{^Block:   _gothic}', "");
Error('\p{Blk=:=		gothic}');
Error('\P{Blk=:=		gothic}');
Expect(1, 66383, '\p{Blk=gothic}', "");
Expect(0, 66383, '\p{^Blk=gothic}', "");
Expect(0, 66383, '\P{Blk=gothic}', "");
Expect(1, 66383, '\P{^Blk=gothic}', "");
Expect(0, 66384, '\p{Blk=gothic}', "");
Expect(1, 66384, '\p{^Blk=gothic}', "");
Expect(1, 66384, '\P{Blk=gothic}', "");
Expect(0, 66384, '\P{^Blk=gothic}', "");
Expect(1, 66383, '\p{Blk=Gothic}', "");
Expect(0, 66383, '\p{^Blk=Gothic}', "");
Expect(0, 66383, '\P{Blk=Gothic}', "");
Expect(1, 66383, '\P{^Blk=Gothic}', "");
Expect(0, 66384, '\p{Blk=Gothic}', "");
Expect(1, 66384, '\p{^Blk=Gothic}', "");
Expect(1, 66384, '\P{Blk=Gothic}', "");
Expect(0, 66384, '\P{^Blk=Gothic}', "");
Error('\p{Is_Block=:= 	Gothic}');
Error('\P{Is_Block=:= 	Gothic}');
Expect(1, 66383, '\p{Is_Block=gothic}', "");
Expect(0, 66383, '\p{^Is_Block=gothic}', "");
Expect(0, 66383, '\P{Is_Block=gothic}', "");
Expect(1, 66383, '\P{^Is_Block=gothic}', "");
Expect(0, 66384, '\p{Is_Block=gothic}', "");
Expect(1, 66384, '\p{^Is_Block=gothic}', "");
Expect(1, 66384, '\P{Is_Block=gothic}', "");
Expect(0, 66384, '\P{^Is_Block=gothic}', "");
Expect(1, 66383, '\p{Is_Block=Gothic}', "");
Expect(0, 66383, '\p{^Is_Block=Gothic}', "");
Expect(0, 66383, '\P{Is_Block=Gothic}', "");
Expect(1, 66383, '\P{^Is_Block=Gothic}', "");
Expect(0, 66384, '\p{Is_Block=Gothic}', "");
Expect(1, 66384, '\p{^Is_Block=Gothic}', "");
Expect(1, 66384, '\P{Is_Block=Gothic}', "");
Expect(0, 66384, '\P{^Is_Block=Gothic}', "");
Error('\p{Is_Blk=:=	 Gothic}');
Error('\P{Is_Blk=:=	 Gothic}');
Expect(1, 66383, '\p{Is_Blk=gothic}', "");
Expect(0, 66383, '\p{^Is_Blk=gothic}', "");
Expect(0, 66383, '\P{Is_Blk=gothic}', "");
Expect(1, 66383, '\P{^Is_Blk=gothic}', "");
Expect(0, 66384, '\p{Is_Blk=gothic}', "");
Expect(1, 66384, '\p{^Is_Blk=gothic}', "");
Expect(1, 66384, '\P{Is_Blk=gothic}', "");
Expect(0, 66384, '\P{^Is_Blk=gothic}', "");
Expect(1, 66383, '\p{Is_Blk=_	Gothic}', "");
Expect(0, 66383, '\p{^Is_Blk=_	Gothic}', "");
Expect(0, 66383, '\P{Is_Blk=_	Gothic}', "");
Expect(1, 66383, '\P{^Is_Blk=_	Gothic}', "");
Expect(0, 66384, '\p{Is_Blk=_	Gothic}', "");
Expect(1, 66384, '\p{^Is_Blk=_	Gothic}', "");
Expect(1, 66384, '\P{Is_Blk=_	Gothic}', "");
Expect(0, 66384, '\P{^Is_Blk=_	Gothic}', "");
Error('\p{Block=-_greek_and_coptic/a/}');
Error('\P{Block=-_greek_and_coptic/a/}');
Expect(1, 1023, '\p{Block=greekandcoptic}', "");
Expect(0, 1023, '\p{^Block=greekandcoptic}', "");
Expect(0, 1023, '\P{Block=greekandcoptic}', "");
Expect(1, 1023, '\P{^Block=greekandcoptic}', "");
Expect(0, 1024, '\p{Block=greekandcoptic}', "");
Expect(1, 1024, '\p{^Block=greekandcoptic}', "");
Expect(1, 1024, '\P{Block=greekandcoptic}', "");
Expect(0, 1024, '\P{^Block=greekandcoptic}', "");
Expect(1, 1023, '\p{Block=--Greek_And_Coptic}', "");
Expect(0, 1023, '\p{^Block=--Greek_And_Coptic}', "");
Expect(0, 1023, '\P{Block=--Greek_And_Coptic}', "");
Expect(1, 1023, '\P{^Block=--Greek_And_Coptic}', "");
Expect(0, 1024, '\p{Block=--Greek_And_Coptic}', "");
Expect(1, 1024, '\p{^Block=--Greek_And_Coptic}', "");
Expect(1, 1024, '\P{Block=--Greek_And_Coptic}', "");
Expect(0, 1024, '\P{^Block=--Greek_And_Coptic}', "");
Error('\p{Blk= 	GREEK:=}');
Error('\P{Blk= 	GREEK:=}');
Expect(1, 1023, '\p{Blk=greek}', "");
Expect(0, 1023, '\p{^Blk=greek}', "");
Expect(0, 1023, '\P{Blk=greek}', "");
Expect(1, 1023, '\P{^Blk=greek}', "");
Expect(0, 1024, '\p{Blk=greek}', "");
Expect(1, 1024, '\p{^Blk=greek}', "");
Expect(1, 1024, '\P{Blk=greek}', "");
Expect(0, 1024, '\P{^Blk=greek}', "");
Expect(1, 1023, '\p{Blk: _GREEK}', "");
Expect(0, 1023, '\p{^Blk: _GREEK}', "");
Expect(0, 1023, '\P{Blk: _GREEK}', "");
Expect(1, 1023, '\P{^Blk: _GREEK}', "");
Expect(0, 1024, '\p{Blk: _GREEK}', "");
Expect(1, 1024, '\p{^Blk: _GREEK}', "");
Expect(1, 1024, '\P{Blk: _GREEK}', "");
Expect(0, 1024, '\P{^Blk: _GREEK}', "");
Error('\p{Is_Block:	-:=Greek_and_COPTIC}');
Error('\P{Is_Block:	-:=Greek_and_COPTIC}');
Expect(1, 1023, '\p{Is_Block=greekandcoptic}', "");
Expect(0, 1023, '\p{^Is_Block=greekandcoptic}', "");
Expect(0, 1023, '\P{Is_Block=greekandcoptic}', "");
Expect(1, 1023, '\P{^Is_Block=greekandcoptic}', "");
Expect(0, 1024, '\p{Is_Block=greekandcoptic}', "");
Expect(1, 1024, '\p{^Is_Block=greekandcoptic}', "");
Expect(1, 1024, '\P{Is_Block=greekandcoptic}', "");
Expect(0, 1024, '\P{^Is_Block=greekandcoptic}', "");
Expect(1, 1023, '\p{Is_Block= _Greek_And_Coptic}', "");
Expect(0, 1023, '\p{^Is_Block= _Greek_And_Coptic}', "");
Expect(0, 1023, '\P{Is_Block= _Greek_And_Coptic}', "");
Expect(1, 1023, '\P{^Is_Block= _Greek_And_Coptic}', "");
Expect(0, 1024, '\p{Is_Block= _Greek_And_Coptic}', "");
Expect(1, 1024, '\p{^Is_Block= _Greek_And_Coptic}', "");
Expect(1, 1024, '\P{Is_Block= _Greek_And_Coptic}', "");
Expect(0, 1024, '\P{^Is_Block= _Greek_And_Coptic}', "");
Error('\p{Is_Blk=:=--GREEK}');
Error('\P{Is_Blk=:=--GREEK}');
Expect(1, 1023, '\p{Is_Blk=greek}', "");
Expect(0, 1023, '\p{^Is_Blk=greek}', "");
Expect(0, 1023, '\P{Is_Blk=greek}', "");
Expect(1, 1023, '\P{^Is_Blk=greek}', "");
Expect(0, 1024, '\p{Is_Blk=greek}', "");
Expect(1, 1024, '\p{^Is_Blk=greek}', "");
Expect(1, 1024, '\P{Is_Blk=greek}', "");
Expect(0, 1024, '\P{^Is_Blk=greek}', "");
Expect(1, 1023, '\p{Is_Blk=-greek}', "");
Expect(0, 1023, '\p{^Is_Blk=-greek}', "");
Expect(0, 1023, '\P{Is_Blk=-greek}', "");
Expect(1, 1023, '\P{^Is_Blk=-greek}', "");
Expect(0, 1024, '\p{Is_Blk=-greek}', "");
Expect(1, 1024, '\p{^Is_Blk=-greek}', "");
Expect(1, 1024, '\P{Is_Blk=-greek}', "");
Expect(0, 1024, '\P{^Is_Blk=-greek}', "");
Error('\p{Block=/a/GREEK_Extended}');
Error('\P{Block=/a/GREEK_Extended}');
Expect(1, 8191, '\p{Block=greekextended}', "");
Expect(0, 8191, '\p{^Block=greekextended}', "");
Expect(0, 8191, '\P{Block=greekextended}', "");
Expect(1, 8191, '\P{^Block=greekextended}', "");
Expect(0, 8192, '\p{Block=greekextended}', "");
Expect(1, 8192, '\p{^Block=greekextended}', "");
Expect(1, 8192, '\P{Block=greekextended}', "");
Expect(0, 8192, '\P{^Block=greekextended}', "");
Expect(1, 8191, '\p{Block:	 Greek_Extended}', "");
Expect(0, 8191, '\p{^Block:	 Greek_Extended}', "");
Expect(0, 8191, '\P{Block:	 Greek_Extended}', "");
Expect(1, 8191, '\P{^Block:	 Greek_Extended}', "");
Expect(0, 8192, '\p{Block:	 Greek_Extended}', "");
Expect(1, 8192, '\p{^Block:	 Greek_Extended}', "");
Expect(1, 8192, '\P{Block:	 Greek_Extended}', "");
Expect(0, 8192, '\P{^Block:	 Greek_Extended}', "");
Error('\p{Blk=:=greek_EXT}');
Error('\P{Blk=:=greek_EXT}');
Expect(1, 8191, '\p{Blk:   greekext}', "");
Expect(0, 8191, '\p{^Blk:   greekext}', "");
Expect(0, 8191, '\P{Blk:   greekext}', "");
Expect(1, 8191, '\P{^Blk:   greekext}', "");
Expect(0, 8192, '\p{Blk:   greekext}', "");
Expect(1, 8192, '\p{^Blk:   greekext}', "");
Expect(1, 8192, '\P{Blk:   greekext}', "");
Expect(0, 8192, '\P{^Blk:   greekext}', "");
Expect(1, 8191, '\p{Blk=	greek_EXT}', "");
Expect(0, 8191, '\p{^Blk=	greek_EXT}', "");
Expect(0, 8191, '\P{Blk=	greek_EXT}', "");
Expect(1, 8191, '\P{^Blk=	greek_EXT}', "");
Expect(0, 8192, '\p{Blk=	greek_EXT}', "");
Expect(1, 8192, '\p{^Blk=	greek_EXT}', "");
Expect(1, 8192, '\P{Blk=	greek_EXT}', "");
Expect(0, 8192, '\P{^Blk=	greek_EXT}', "");
Error('\p{Is_Block=- GREEK_EXTENDED/a/}');
Error('\P{Is_Block=- GREEK_EXTENDED/a/}');
Expect(1, 8191, '\p{Is_Block=greekextended}', "");
Expect(0, 8191, '\p{^Is_Block=greekextended}', "");
Expect(0, 8191, '\P{Is_Block=greekextended}', "");
Expect(1, 8191, '\P{^Is_Block=greekextended}', "");
Expect(0, 8192, '\p{Is_Block=greekextended}', "");
Expect(1, 8192, '\p{^Is_Block=greekextended}', "");
Expect(1, 8192, '\P{Is_Block=greekextended}', "");
Expect(0, 8192, '\P{^Is_Block=greekextended}', "");
Expect(1, 8191, '\p{Is_Block=--GREEK_Extended}', "");
Expect(0, 8191, '\p{^Is_Block=--GREEK_Extended}', "");
Expect(0, 8191, '\P{Is_Block=--GREEK_Extended}', "");
Expect(1, 8191, '\P{^Is_Block=--GREEK_Extended}', "");
Expect(0, 8192, '\p{Is_Block=--GREEK_Extended}', "");
Expect(1, 8192, '\p{^Is_Block=--GREEK_Extended}', "");
Expect(1, 8192, '\P{Is_Block=--GREEK_Extended}', "");
Expect(0, 8192, '\P{^Is_Block=--GREEK_Extended}', "");
Error('\p{Is_Blk=:= 	Greek_Ext}');
Error('\P{Is_Blk=:= 	Greek_Ext}');
Expect(1, 8191, '\p{Is_Blk=greekext}', "");
Expect(0, 8191, '\p{^Is_Blk=greekext}', "");
Expect(0, 8191, '\P{Is_Blk=greekext}', "");
Expect(1, 8191, '\P{^Is_Blk=greekext}', "");
Expect(0, 8192, '\p{Is_Blk=greekext}', "");
Expect(1, 8192, '\p{^Is_Blk=greekext}', "");
Expect(1, 8192, '\P{Is_Blk=greekext}', "");
Expect(0, 8192, '\P{^Is_Blk=greekext}', "");
Expect(1, 8191, '\p{Is_Blk=	 Greek_ext}', "");
Expect(0, 8191, '\p{^Is_Blk=	 Greek_ext}', "");
Expect(0, 8191, '\P{Is_Blk=	 Greek_ext}', "");
Expect(1, 8191, '\P{^Is_Blk=	 Greek_ext}', "");
Expect(0, 8192, '\p{Is_Blk=	 Greek_ext}', "");
Expect(1, 8192, '\p{^Is_Blk=	 Greek_ext}', "");
Expect(1, 8192, '\P{Is_Blk=	 Greek_ext}', "");
Expect(0, 8192, '\P{^Is_Blk=	 Greek_ext}', "");
Error('\p{Block=_ Gujarati/a/}');
Error('\P{Block=_ Gujarati/a/}');
Expect(1, 2815, '\p{Block=gujarati}', "");
Expect(0, 2815, '\p{^Block=gujarati}', "");
Expect(0, 2815, '\P{Block=gujarati}', "");
Expect(1, 2815, '\P{^Block=gujarati}', "");
Expect(0, 2816, '\p{Block=gujarati}', "");
Expect(1, 2816, '\p{^Block=gujarati}', "");
Expect(1, 2816, '\P{Block=gujarati}', "");
Expect(0, 2816, '\P{^Block=gujarati}', "");
Expect(1, 2815, '\p{Block=	_Gujarati}', "");
Expect(0, 2815, '\p{^Block=	_Gujarati}', "");
Expect(0, 2815, '\P{Block=	_Gujarati}', "");
Expect(1, 2815, '\P{^Block=	_Gujarati}', "");
Expect(0, 2816, '\p{Block=	_Gujarati}', "");
Expect(1, 2816, '\p{^Block=	_Gujarati}', "");
Expect(1, 2816, '\P{Block=	_Gujarati}', "");
Expect(0, 2816, '\P{^Block=	_Gujarati}', "");
Error('\p{Blk=	:=GUJARATI}');
Error('\P{Blk=	:=GUJARATI}');
Expect(1, 2815, '\p{Blk=gujarati}', "");
Expect(0, 2815, '\p{^Blk=gujarati}', "");
Expect(0, 2815, '\P{Blk=gujarati}', "");
Expect(1, 2815, '\P{^Blk=gujarati}', "");
Expect(0, 2816, '\p{Blk=gujarati}', "");
Expect(1, 2816, '\p{^Blk=gujarati}', "");
Expect(1, 2816, '\P{Blk=gujarati}', "");
Expect(0, 2816, '\P{^Blk=gujarati}', "");
Expect(1, 2815, '\p{Blk=_-Gujarati}', "");
Expect(0, 2815, '\p{^Blk=_-Gujarati}', "");
Expect(0, 2815, '\P{Blk=_-Gujarati}', "");
Expect(1, 2815, '\P{^Blk=_-Gujarati}', "");
Expect(0, 2816, '\p{Blk=_-Gujarati}', "");
Expect(1, 2816, '\p{^Blk=_-Gujarati}', "");
Expect(1, 2816, '\P{Blk=_-Gujarati}', "");
Expect(0, 2816, '\P{^Blk=_-Gujarati}', "");
Error('\p{Is_Block=-/a/Gujarati}');
Error('\P{Is_Block=-/a/Gujarati}');
Expect(1, 2815, '\p{Is_Block=gujarati}', "");
Expect(0, 2815, '\p{^Is_Block=gujarati}', "");
Expect(0, 2815, '\P{Is_Block=gujarati}', "");
Expect(1, 2815, '\P{^Is_Block=gujarati}', "");
Expect(0, 2816, '\p{Is_Block=gujarati}', "");
Expect(1, 2816, '\p{^Is_Block=gujarati}', "");
Expect(1, 2816, '\P{Is_Block=gujarati}', "");
Expect(0, 2816, '\P{^Is_Block=gujarati}', "");
Expect(1, 2815, '\p{Is_Block= _Gujarati}', "");
Expect(0, 2815, '\p{^Is_Block= _Gujarati}', "");
Expect(0, 2815, '\P{Is_Block= _Gujarati}', "");
Expect(1, 2815, '\P{^Is_Block= _Gujarati}', "");
Expect(0, 2816, '\p{Is_Block= _Gujarati}', "");
Expect(1, 2816, '\p{^Is_Block= _Gujarati}', "");
Expect(1, 2816, '\P{Is_Block= _Gujarati}', "");
Expect(0, 2816, '\P{^Is_Block= _Gujarati}', "");
Error('\p{Is_Blk=	_gujarati/a/}');
Error('\P{Is_Blk=	_gujarati/a/}');
Expect(1, 2815, '\p{Is_Blk=gujarati}', "");
Expect(0, 2815, '\p{^Is_Blk=gujarati}', "");
Expect(0, 2815, '\P{Is_Blk=gujarati}', "");
Expect(1, 2815, '\P{^Is_Blk=gujarati}', "");
Expect(0, 2816, '\p{Is_Blk=gujarati}', "");
Expect(1, 2816, '\p{^Is_Blk=gujarati}', "");
Expect(1, 2816, '\P{Is_Blk=gujarati}', "");
Expect(0, 2816, '\P{^Is_Blk=gujarati}', "");
Expect(1, 2815, '\p{Is_Blk=		GUJARATI}', "");
Expect(0, 2815, '\p{^Is_Blk=		GUJARATI}', "");
Expect(0, 2815, '\P{Is_Blk=		GUJARATI}', "");
Expect(1, 2815, '\P{^Is_Blk=		GUJARATI}', "");
Expect(0, 2816, '\p{Is_Blk=		GUJARATI}', "");
Expect(1, 2816, '\p{^Is_Blk=		GUJARATI}', "");
Expect(1, 2816, '\P{Is_Blk=		GUJARATI}', "");
Expect(0, 2816, '\P{^Is_Blk=		GUJARATI}', "");
Error('\p{Block=:=- Gurmukhi}');
Error('\P{Block=:=- Gurmukhi}');
Expect(1, 2687, '\p{Block=gurmukhi}', "");
Expect(0, 2687, '\p{^Block=gurmukhi}', "");
Expect(0, 2687, '\P{Block=gurmukhi}', "");
Expect(1, 2687, '\P{^Block=gurmukhi}', "");
Expect(0, 2688, '\p{Block=gurmukhi}', "");
Expect(1, 2688, '\p{^Block=gurmukhi}', "");
Expect(1, 2688, '\P{Block=gurmukhi}', "");
Expect(0, 2688, '\P{^Block=gurmukhi}', "");
Expect(1, 2687, '\p{Block=-Gurmukhi}', "");
Expect(0, 2687, '\p{^Block=-Gurmukhi}', "");
Expect(0, 2687, '\P{Block=-Gurmukhi}', "");
Expect(1, 2687, '\P{^Block=-Gurmukhi}', "");
Expect(0, 2688, '\p{Block=-Gurmukhi}', "");
Expect(1, 2688, '\p{^Block=-Gurmukhi}', "");
Expect(1, 2688, '\P{Block=-Gurmukhi}', "");
Expect(0, 2688, '\P{^Block=-Gurmukhi}', "");
Error('\p{Blk=/a/-	Gurmukhi}');
Error('\P{Blk=/a/-	Gurmukhi}');
Expect(1, 2687, '\p{Blk=gurmukhi}', "");
Expect(0, 2687, '\p{^Blk=gurmukhi}', "");
Expect(0, 2687, '\P{Blk=gurmukhi}', "");
Expect(1, 2687, '\P{^Blk=gurmukhi}', "");
Expect(0, 2688, '\p{Blk=gurmukhi}', "");
Expect(1, 2688, '\p{^Blk=gurmukhi}', "");
Expect(1, 2688, '\P{Blk=gurmukhi}', "");
Expect(0, 2688, '\P{^Blk=gurmukhi}', "");
Expect(1, 2687, '\p{Blk=	-GURMUKHI}', "");
Expect(0, 2687, '\p{^Blk=	-GURMUKHI}', "");
Expect(0, 2687, '\P{Blk=	-GURMUKHI}', "");
Expect(1, 2687, '\P{^Blk=	-GURMUKHI}', "");
Expect(0, 2688, '\p{Blk=	-GURMUKHI}', "");
Expect(1, 2688, '\p{^Blk=	-GURMUKHI}', "");
Expect(1, 2688, '\P{Blk=	-GURMUKHI}', "");
Expect(0, 2688, '\P{^Blk=	-GURMUKHI}', "");
Error('\p{Is_Block=Gurmukhi/a/}');
Error('\P{Is_Block=Gurmukhi/a/}');
Expect(1, 2687, '\p{Is_Block=gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Block=gurmukhi}', "");
Expect(0, 2687, '\P{Is_Block=gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Block=gurmukhi}', "");
Expect(0, 2688, '\p{Is_Block=gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Block=gurmukhi}', "");
Expect(1, 2688, '\P{Is_Block=gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Block=gurmukhi}', "");
Expect(1, 2687, '\p{Is_Block: 	 gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Block: 	 gurmukhi}', "");
Expect(0, 2687, '\P{Is_Block: 	 gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Block: 	 gurmukhi}', "");
Expect(0, 2688, '\p{Is_Block: 	 gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Block: 	 gurmukhi}', "");
Expect(1, 2688, '\P{Is_Block: 	 gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Block: 	 gurmukhi}', "");
Error('\p{Is_Blk=/a/GURMUKHI}');
Error('\P{Is_Blk=/a/GURMUKHI}');
Expect(1, 2687, '\p{Is_Blk=gurmukhi}', "");
Expect(0, 2687, '\p{^Is_Blk=gurmukhi}', "");
Expect(0, 2687, '\P{Is_Blk=gurmukhi}', "");
Expect(1, 2687, '\P{^Is_Blk=gurmukhi}', "");
Expect(0, 2688, '\p{Is_Blk=gurmukhi}', "");
Expect(1, 2688, '\p{^Is_Blk=gurmukhi}', "");
Expect(1, 2688, '\P{Is_Blk=gurmukhi}', "");
Expect(0, 2688, '\P{^Is_Blk=gurmukhi}', "");
Expect(1, 2687, '\p{Is_Blk=	_GURMUKHI}', "");
Expect(0, 2687, '\p{^Is_Blk=	_GURMUKHI}', "");
Expect(0, 2687, '\P{Is_Blk=	_GURMUKHI}', "");
Expect(1, 2687, '\P{^Is_Blk=	_GURMUKHI}', "");
Expect(0, 2688, '\p{Is_Blk=	_GURMUKHI}', "");
Expect(1, 2688, '\p{^Is_Blk=	_GURMUKHI}', "");
Expect(1, 2688, '\P{Is_Blk=	_GURMUKHI}', "");
Expect(0, 2688, '\P{^Is_Blk=	_GURMUKHI}', "");
Error('\p{Block= 	Halfwidth_and_fullwidth_Forms/a/}');
Error('\P{Block= 	Halfwidth_and_fullwidth_Forms/a/}');
Expect(1, 65519, '\p{Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(0, 65519, '\p{^Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(0, 65519, '\P{Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(1, 65519, '\P{^Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(0, 65520, '\p{Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(1, 65520, '\p{^Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(1, 65520, '\P{Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Expect(0, 65520, '\P{^Block=-	HALFWIDTH_And_Fullwidth_FORMS}', "");
Error('\p{Blk=_Half_AND_Full_FORMS/a/}');
Error('\P{Blk=_Half_AND_Full_FORMS/a/}');
Expect(1, 65519, '\p{Blk=halfandfullforms}', "");
Expect(0, 65519, '\p{^Blk=halfandfullforms}', "");
Expect(0, 65519, '\P{Blk=halfandfullforms}', "");
Expect(1, 65519, '\P{^Blk=halfandfullforms}', "");
Expect(0, 65520, '\p{Blk=halfandfullforms}', "");
Expect(1, 65520, '\p{^Blk=halfandfullforms}', "");
Expect(1, 65520, '\P{Blk=halfandfullforms}', "");
Expect(0, 65520, '\P{^Blk=halfandfullforms}', "");
Expect(1, 65519, '\p{Blk=-_HALF_And_Full_forms}', "");
Expect(0, 65519, '\p{^Blk=-_HALF_And_Full_forms}', "");
Expect(0, 65519, '\P{Blk=-_HALF_And_Full_forms}', "");
Expect(1, 65519, '\P{^Blk=-_HALF_And_Full_forms}', "");
Expect(0, 65520, '\p{Blk=-_HALF_And_Full_forms}', "");
Expect(1, 65520, '\p{^Blk=-_HALF_And_Full_forms}', "");
Expect(1, 65520, '\P{Blk=-_HALF_And_Full_forms}', "");
Expect(0, 65520, '\P{^Blk=-_HALF_And_Full_forms}', "");
Error('\p{Is_Block=-:=halfwidth_AND_FULLWIDTH_forms}');
Error('\P{Is_Block=-:=halfwidth_AND_FULLWIDTH_forms}');
Expect(1, 65519, '\p{Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{Is_Block=halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^Is_Block=halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(0, 65519, '\p{^Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(0, 65519, '\P{Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(1, 65519, '\P{^Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(0, 65520, '\p{Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(1, 65520, '\p{^Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(1, 65520, '\P{Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Expect(0, 65520, '\P{^Is_Block=--HALFWIDTH_And_Fullwidth_forms}', "");
Error('\p{Is_Blk=/a/- Half_And_Full_FORMS}');
Error('\P{Is_Blk=/a/- Half_And_Full_FORMS}');
Expect(1, 65519, '\p{Is_Blk: halfandfullforms}', "");
Expect(0, 65519, '\p{^Is_Blk: halfandfullforms}', "");
Expect(0, 65519, '\P{Is_Blk: halfandfullforms}', "");
Expect(1, 65519, '\P{^Is_Blk: halfandfullforms}', "");
Expect(0, 65520, '\p{Is_Blk: halfandfullforms}', "");
Expect(1, 65520, '\p{^Is_Blk: halfandfullforms}', "");
Expect(1, 65520, '\P{Is_Blk: halfandfullforms}', "");
Expect(0, 65520, '\P{^Is_Blk: halfandfullforms}', "");
Expect(1, 65519, '\p{Is_Blk=	half_AND_full_FORMS}', "");
Expect(0, 65519, '\p{^Is_Blk=	half_AND_full_FORMS}', "");
Expect(0, 65519, '\P{Is_Blk=	half_AND_full_FORMS}', "");
Expect(1, 65519, '\P{^Is_Blk=	half_AND_full_FORMS}', "");
Expect(0, 65520, '\p{Is_Blk=	half_AND_full_FORMS}', "");
Expect(1, 65520, '\p{^Is_Blk=	half_AND_full_FORMS}', "");
Expect(1, 65520, '\P{Is_Blk=	half_AND_full_FORMS}', "");
Expect(0, 65520, '\P{^Is_Blk=	half_AND_full_FORMS}', "");
Error('\p{Block:-/a/combining_HALF_marks}');
Error('\P{Block:-/a/combining_HALF_marks}');
Expect(1, 65071, '\p{Block=combininghalfmarks}', "");
Expect(0, 65071, '\p{^Block=combininghalfmarks}', "");
Expect(0, 65071, '\P{Block=combininghalfmarks}', "");
Expect(1, 65071, '\P{^Block=combininghalfmarks}', "");
Expect(0, 65072, '\p{Block=combininghalfmarks}', "");
Expect(1, 65072, '\p{^Block=combininghalfmarks}', "");
Expect(1, 65072, '\P{Block=combininghalfmarks}', "");
Expect(0, 65072, '\P{^Block=combininghalfmarks}', "");
Expect(1, 65071, '\p{Block=_-combining_HALF_marks}', "");
Expect(0, 65071, '\p{^Block=_-combining_HALF_marks}', "");
Expect(0, 65071, '\P{Block=_-combining_HALF_marks}', "");
Expect(1, 65071, '\P{^Block=_-combining_HALF_marks}', "");
Expect(0, 65072, '\p{Block=_-combining_HALF_marks}', "");
Expect(1, 65072, '\p{^Block=_-combining_HALF_marks}', "");
Expect(1, 65072, '\P{Block=_-combining_HALF_marks}', "");
Expect(0, 65072, '\P{^Block=_-combining_HALF_marks}', "");
Error('\p{Blk=-HALF_Marks/a/}');
Error('\P{Blk=-HALF_Marks/a/}');
Expect(1, 65071, '\p{Blk=halfmarks}', "");
Expect(0, 65071, '\p{^Blk=halfmarks}', "");
Expect(0, 65071, '\P{Blk=halfmarks}', "");
Expect(1, 65071, '\P{^Blk=halfmarks}', "");
Expect(0, 65072, '\p{Blk=halfmarks}', "");
Expect(1, 65072, '\p{^Blk=halfmarks}', "");
Expect(1, 65072, '\P{Blk=halfmarks}', "");
Expect(0, 65072, '\P{^Blk=halfmarks}', "");
Expect(1, 65071, '\p{Blk=	 HALF_Marks}', "");
Expect(0, 65071, '\p{^Blk=	 HALF_Marks}', "");
Expect(0, 65071, '\P{Blk=	 HALF_Marks}', "");
Expect(1, 65071, '\P{^Blk=	 HALF_Marks}', "");
Expect(0, 65072, '\p{Blk=	 HALF_Marks}', "");
Expect(1, 65072, '\p{^Blk=	 HALF_Marks}', "");
Expect(1, 65072, '\P{Blk=	 HALF_Marks}', "");
Expect(0, 65072, '\P{^Blk=	 HALF_Marks}', "");
Error('\p{Is_Block=:=	Combining_Half_Marks}');
Error('\P{Is_Block=:=	Combining_Half_Marks}');
Expect(1, 65071, '\p{Is_Block:combininghalfmarks}', "");
Expect(0, 65071, '\p{^Is_Block:combininghalfmarks}', "");
Expect(0, 65071, '\P{Is_Block:combininghalfmarks}', "");
Expect(1, 65071, '\P{^Is_Block:combininghalfmarks}', "");
Expect(0, 65072, '\p{Is_Block:combininghalfmarks}', "");
Expect(1, 65072, '\p{^Is_Block:combininghalfmarks}', "");
Expect(1, 65072, '\P{Is_Block:combininghalfmarks}', "");
Expect(0, 65072, '\P{^Is_Block:combininghalfmarks}', "");
Expect(1, 65071, '\p{Is_Block: __combining_half_MARKS}', "");
Expect(0, 65071, '\p{^Is_Block: __combining_half_MARKS}', "");
Expect(0, 65071, '\P{Is_Block: __combining_half_MARKS}', "");
Expect(1, 65071, '\P{^Is_Block: __combining_half_MARKS}', "");
Expect(0, 65072, '\p{Is_Block: __combining_half_MARKS}', "");
Expect(1, 65072, '\p{^Is_Block: __combining_half_MARKS}', "");
Expect(1, 65072, '\P{Is_Block: __combining_half_MARKS}', "");
Expect(0, 65072, '\P{^Is_Block: __combining_half_MARKS}', "");
Error('\p{Is_Blk=-:=Half_Marks}');
Error('\P{Is_Blk=-:=Half_Marks}');
Expect(1, 65071, '\p{Is_Blk=halfmarks}', "");
Expect(0, 65071, '\p{^Is_Blk=halfmarks}', "");
Expect(0, 65071, '\P{Is_Blk=halfmarks}', "");
Expect(1, 65071, '\P{^Is_Blk=halfmarks}', "");
Expect(0, 65072, '\p{Is_Blk=halfmarks}', "");
Expect(1, 65072, '\p{^Is_Blk=halfmarks}', "");
Expect(1, 65072, '\P{Is_Blk=halfmarks}', "");
Expect(0, 65072, '\P{^Is_Blk=halfmarks}', "");
Expect(1, 65071, '\p{Is_Blk= -half_marks}', "");
Expect(0, 65071, '\p{^Is_Blk= -half_marks}', "");
Expect(0, 65071, '\P{Is_Blk= -half_marks}', "");
Expect(1, 65071, '\P{^Is_Blk= -half_marks}', "");
Expect(0, 65072, '\p{Is_Blk= -half_marks}', "");
Expect(1, 65072, '\p{^Is_Blk= -half_marks}', "");
Expect(1, 65072, '\P{Is_Blk= -half_marks}', "");
Expect(0, 65072, '\P{^Is_Blk= -half_marks}', "");
Error('\p{Block=_hangul_Syllables/a/}');
Error('\P{Block=_hangul_Syllables/a/}');
Expect(1, 55215, '\p{Block=hangulsyllables}', "");
Expect(0, 55215, '\p{^Block=hangulsyllables}', "");
Expect(0, 55215, '\P{Block=hangulsyllables}', "");
Expect(1, 55215, '\P{^Block=hangulsyllables}', "");
Expect(0, 55216, '\p{Block=hangulsyllables}', "");
Expect(1, 55216, '\p{^Block=hangulsyllables}', "");
Expect(1, 55216, '\P{Block=hangulsyllables}', "");
Expect(0, 55216, '\P{^Block=hangulsyllables}', "");
Expect(1, 55215, '\p{Block=  HANGUL_Syllables}', "");
Expect(0, 55215, '\p{^Block=  HANGUL_Syllables}', "");
Expect(0, 55215, '\P{Block=  HANGUL_Syllables}', "");
Expect(1, 55215, '\P{^Block=  HANGUL_Syllables}', "");
Expect(0, 55216, '\p{Block=  HANGUL_Syllables}', "");
Expect(1, 55216, '\p{^Block=  HANGUL_Syllables}', "");
Expect(1, 55216, '\P{Block=  HANGUL_Syllables}', "");
Expect(0, 55216, '\P{^Block=  HANGUL_Syllables}', "");
Error('\p{Blk=/a/_ HANGUL}');
Error('\P{Blk=/a/_ HANGUL}');
Expect(1, 55215, '\p{Blk=hangul}', "");
Expect(0, 55215, '\p{^Blk=hangul}', "");
Expect(0, 55215, '\P{Blk=hangul}', "");
Expect(1, 55215, '\P{^Blk=hangul}', "");
Expect(0, 55216, '\p{Blk=hangul}', "");
Expect(1, 55216, '\p{^Blk=hangul}', "");
Expect(1, 55216, '\P{Blk=hangul}', "");
Expect(0, 55216, '\P{^Blk=hangul}', "");
Expect(1, 55215, '\p{Blk=	 hangul}', "");
Expect(0, 55215, '\p{^Blk=	 hangul}', "");
Expect(0, 55215, '\P{Blk=	 hangul}', "");
Expect(1, 55215, '\P{^Blk=	 hangul}', "");
Expect(0, 55216, '\p{Blk=	 hangul}', "");
Expect(1, 55216, '\p{^Blk=	 hangul}', "");
Expect(1, 55216, '\P{Blk=	 hangul}', "");
Expect(0, 55216, '\P{^Blk=	 hangul}', "");
Error('\p{Is_Block=	 Hangul_Syllables/a/}');
Error('\P{Is_Block=	 Hangul_Syllables/a/}');
Expect(1, 55215, '\p{Is_Block: hangulsyllables}', "");
Expect(0, 55215, '\p{^Is_Block: hangulsyllables}', "");
Expect(0, 55215, '\P{Is_Block: hangulsyllables}', "");
Expect(1, 55215, '\P{^Is_Block: hangulsyllables}', "");
Expect(0, 55216, '\p{Is_Block: hangulsyllables}', "");
Expect(1, 55216, '\p{^Is_Block: hangulsyllables}', "");
Expect(1, 55216, '\P{Is_Block: hangulsyllables}', "");
Expect(0, 55216, '\P{^Is_Block: hangulsyllables}', "");
Expect(1, 55215, '\p{Is_Block=_Hangul_syllables}', "");
Expect(0, 55215, '\p{^Is_Block=_Hangul_syllables}', "");
Expect(0, 55215, '\P{Is_Block=_Hangul_syllables}', "");
Expect(1, 55215, '\P{^Is_Block=_Hangul_syllables}', "");
Expect(0, 55216, '\p{Is_Block=_Hangul_syllables}', "");
Expect(1, 55216, '\p{^Is_Block=_Hangul_syllables}', "");
Expect(1, 55216, '\P{Is_Block=_Hangul_syllables}', "");
Expect(0, 55216, '\P{^Is_Block=_Hangul_syllables}', "");
Error('\p{Is_Blk=/a/__HANGUL}');
Error('\P{Is_Blk=/a/__HANGUL}');
Expect(1, 55215, '\p{Is_Blk=hangul}', "");
Expect(0, 55215, '\p{^Is_Blk=hangul}', "");
Expect(0, 55215, '\P{Is_Blk=hangul}', "");
Expect(1, 55215, '\P{^Is_Blk=hangul}', "");
Expect(0, 55216, '\p{Is_Blk=hangul}', "");
Expect(1, 55216, '\p{^Is_Blk=hangul}', "");
Expect(1, 55216, '\P{Is_Blk=hangul}', "");
Expect(0, 55216, '\P{^Is_Blk=hangul}', "");
Expect(1, 55215, '\p{Is_Blk=		Hangul}', "");
Expect(0, 55215, '\p{^Is_Blk=		Hangul}', "");
Expect(0, 55215, '\P{Is_Blk=		Hangul}', "");
Expect(1, 55215, '\P{^Is_Blk=		Hangul}', "");
Expect(0, 55216, '\p{Is_Blk=		Hangul}', "");
Expect(1, 55216, '\p{^Is_Blk=		Hangul}', "");
Expect(1, 55216, '\P{Is_Blk=		Hangul}', "");
Expect(0, 55216, '\P{^Is_Blk=		Hangul}', "");
Error('\p{Block=:=-_Hanunoo}');
Error('\P{Block=:=-_Hanunoo}');
Expect(1, 5951, '\p{Block=hanunoo}', "");
Expect(0, 5951, '\p{^Block=hanunoo}', "");
Expect(0, 5951, '\P{Block=hanunoo}', "");
Expect(1, 5951, '\P{^Block=hanunoo}', "");
Expect(0, 5952, '\p{Block=hanunoo}', "");
Expect(1, 5952, '\p{^Block=hanunoo}', "");
Expect(1, 5952, '\P{Block=hanunoo}', "");
Expect(0, 5952, '\P{^Block=hanunoo}', "");
Expect(1, 5951, '\p{Block=_ Hanunoo}', "");
Expect(0, 5951, '\p{^Block=_ Hanunoo}', "");
Expect(0, 5951, '\P{Block=_ Hanunoo}', "");
Expect(1, 5951, '\P{^Block=_ Hanunoo}', "");
Expect(0, 5952, '\p{Block=_ Hanunoo}', "");
Expect(1, 5952, '\p{^Block=_ Hanunoo}', "");
Expect(1, 5952, '\P{Block=_ Hanunoo}', "");
Expect(0, 5952, '\P{^Block=_ Hanunoo}', "");
Error('\p{Blk=:=_-hanunoo}');
Error('\P{Blk=:=_-hanunoo}');
Expect(1, 5951, '\p{Blk=hanunoo}', "");
Expect(0, 5951, '\p{^Blk=hanunoo}', "");
Expect(0, 5951, '\P{Blk=hanunoo}', "");
Expect(1, 5951, '\P{^Blk=hanunoo}', "");
Expect(0, 5952, '\p{Blk=hanunoo}', "");
Expect(1, 5952, '\p{^Blk=hanunoo}', "");
Expect(1, 5952, '\P{Blk=hanunoo}', "");
Expect(0, 5952, '\P{^Blk=hanunoo}', "");
Expect(1, 5951, '\p{Blk=-hanunoo}', "");
Expect(0, 5951, '\p{^Blk=-hanunoo}', "");
Expect(0, 5951, '\P{Blk=-hanunoo}', "");
Expect(1, 5951, '\P{^Blk=-hanunoo}', "");
Expect(0, 5952, '\p{Blk=-hanunoo}', "");
Expect(1, 5952, '\p{^Blk=-hanunoo}', "");
Expect(1, 5952, '\P{Blk=-hanunoo}', "");
Expect(0, 5952, '\P{^Blk=-hanunoo}', "");
Error('\p{Is_Block=_/a/HANUNOO}');
Error('\P{Is_Block=_/a/HANUNOO}');
Expect(1, 5951, '\p{Is_Block=hanunoo}', "");
Expect(0, 5951, '\p{^Is_Block=hanunoo}', "");
Expect(0, 5951, '\P{Is_Block=hanunoo}', "");
Expect(1, 5951, '\P{^Is_Block=hanunoo}', "");
Expect(0, 5952, '\p{Is_Block=hanunoo}', "");
Expect(1, 5952, '\p{^Is_Block=hanunoo}', "");
Expect(1, 5952, '\P{Is_Block=hanunoo}', "");
Expect(0, 5952, '\P{^Is_Block=hanunoo}', "");
Expect(1, 5951, '\p{Is_Block=	hanunoo}', "");
Expect(0, 5951, '\p{^Is_Block=	hanunoo}', "");
Expect(0, 5951, '\P{Is_Block=	hanunoo}', "");
Expect(1, 5951, '\P{^Is_Block=	hanunoo}', "");
Expect(0, 5952, '\p{Is_Block=	hanunoo}', "");
Expect(1, 5952, '\p{^Is_Block=	hanunoo}', "");
Expect(1, 5952, '\P{Is_Block=	hanunoo}', "");
Expect(0, 5952, '\P{^Is_Block=	hanunoo}', "");
Error('\p{Is_Blk=_ Hanunoo:=}');
Error('\P{Is_Blk=_ Hanunoo:=}');
Expect(1, 5951, '\p{Is_Blk=hanunoo}', "");
Expect(0, 5951, '\p{^Is_Blk=hanunoo}', "");
Expect(0, 5951, '\P{Is_Blk=hanunoo}', "");
Expect(1, 5951, '\P{^Is_Blk=hanunoo}', "");
Expect(0, 5952, '\p{Is_Blk=hanunoo}', "");
Expect(1, 5952, '\p{^Is_Blk=hanunoo}', "");
Expect(1, 5952, '\P{Is_Blk=hanunoo}', "");
Expect(0, 5952, '\P{^Is_Blk=hanunoo}', "");
Expect(1, 5951, '\p{Is_Blk=	Hanunoo}', "");
Expect(0, 5951, '\p{^Is_Blk=	Hanunoo}', "");
Expect(0, 5951, '\P{Is_Blk=	Hanunoo}', "");
Expect(1, 5951, '\P{^Is_Blk=	Hanunoo}', "");
Expect(0, 5952, '\p{Is_Blk=	Hanunoo}', "");
Expect(1, 5952, '\p{^Is_Blk=	Hanunoo}', "");
Expect(1, 5952, '\P{Is_Blk=	Hanunoo}', "");
Expect(0, 5952, '\P{^Is_Blk=	Hanunoo}', "");
Error('\p{Block=	_Hebrew/a/}');
Error('\P{Block=	_Hebrew/a/}');
Expect(1, 1535, '\p{Block=hebrew}', "");
Expect(0, 1535, '\p{^Block=hebrew}', "");
Expect(0, 1535, '\P{Block=hebrew}', "");
Expect(1, 1535, '\P{^Block=hebrew}', "");
Expect(0, 1536, '\p{Block=hebrew}', "");
Expect(1, 1536, '\p{^Block=hebrew}', "");
Expect(1, 1536, '\P{Block=hebrew}', "");
Expect(0, 1536, '\P{^Block=hebrew}', "");
Expect(1, 1535, '\p{Block= hebrew}', "");
Expect(0, 1535, '\p{^Block= hebrew}', "");
Expect(0, 1535, '\P{Block= hebrew}', "");
Expect(1, 1535, '\P{^Block= hebrew}', "");
Expect(0, 1536, '\p{Block= hebrew}', "");
Expect(1, 1536, '\p{^Block= hebrew}', "");
Expect(1, 1536, '\P{Block= hebrew}', "");
Expect(0, 1536, '\P{^Block= hebrew}', "");
Error('\p{Blk=:=-Hebrew}');
Error('\P{Blk=:=-Hebrew}');
Expect(1, 1535, '\p{Blk=hebrew}', "");
Expect(0, 1535, '\p{^Blk=hebrew}', "");
Expect(0, 1535, '\P{Blk=hebrew}', "");
Expect(1, 1535, '\P{^Blk=hebrew}', "");
Expect(0, 1536, '\p{Blk=hebrew}', "");
Expect(1, 1536, '\p{^Blk=hebrew}', "");
Expect(1, 1536, '\P{Blk=hebrew}', "");
Expect(0, 1536, '\P{^Blk=hebrew}', "");
Expect(1, 1535, '\p{Blk= Hebrew}', "");
Expect(0, 1535, '\p{^Blk= Hebrew}', "");
Expect(0, 1535, '\P{Blk= Hebrew}', "");
Expect(1, 1535, '\P{^Blk= Hebrew}', "");
Expect(0, 1536, '\p{Blk= Hebrew}', "");
Expect(1, 1536, '\p{^Blk= Hebrew}', "");
Expect(1, 1536, '\P{Blk= Hebrew}', "");
Expect(0, 1536, '\P{^Blk= Hebrew}', "");
Error('\p{Is_Block=:=  hebrew}');
Error('\P{Is_Block=:=  hebrew}');
Expect(1, 1535, '\p{Is_Block=hebrew}', "");
Expect(0, 1535, '\p{^Is_Block=hebrew}', "");
Expect(0, 1535, '\P{Is_Block=hebrew}', "");
Expect(1, 1535, '\P{^Is_Block=hebrew}', "");
Expect(0, 1536, '\p{Is_Block=hebrew}', "");
Expect(1, 1536, '\p{^Is_Block=hebrew}', "");
Expect(1, 1536, '\P{Is_Block=hebrew}', "");
Expect(0, 1536, '\P{^Is_Block=hebrew}', "");
Expect(1, 1535, '\p{Is_Block=Hebrew}', "");
Expect(0, 1535, '\p{^Is_Block=Hebrew}', "");
Expect(0, 1535, '\P{Is_Block=Hebrew}', "");
Expect(1, 1535, '\P{^Is_Block=Hebrew}', "");
Expect(0, 1536, '\p{Is_Block=Hebrew}', "");
Expect(1, 1536, '\p{^Is_Block=Hebrew}', "");
Expect(1, 1536, '\P{Is_Block=Hebrew}', "");
Expect(0, 1536, '\P{^Is_Block=Hebrew}', "");
Error('\p{Is_Blk= 	Hebrew/a/}');
Error('\P{Is_Blk= 	Hebrew/a/}');
Expect(1, 1535, '\p{Is_Blk=hebrew}', "");
Expect(0, 1535, '\p{^Is_Blk=hebrew}', "");
Expect(0, 1535, '\P{Is_Blk=hebrew}', "");
Expect(1, 1535, '\P{^Is_Blk=hebrew}', "");
Expect(0, 1536, '\p{Is_Blk=hebrew}', "");
Expect(1, 1536, '\p{^Is_Blk=hebrew}', "");
Expect(1, 1536, '\P{Is_Blk=hebrew}', "");
Expect(0, 1536, '\P{^Is_Blk=hebrew}', "");
Expect(1, 1535, '\p{Is_Blk=_-HEBREW}', "");
Expect(0, 1535, '\p{^Is_Blk=_-HEBREW}', "");
Expect(0, 1535, '\P{Is_Blk=_-HEBREW}', "");
Expect(1, 1535, '\P{^Is_Blk=_-HEBREW}', "");
Expect(0, 1536, '\p{Is_Blk=_-HEBREW}', "");
Expect(1, 1536, '\p{^Is_Blk=_-HEBREW}', "");
Expect(1, 1536, '\P{Is_Blk=_-HEBREW}', "");
Expect(0, 1536, '\P{^Is_Blk=_-HEBREW}', "");
Error('\p{Block=- high_Private_Use_SURROGATES/a/}');
Error('\P{Block=- high_Private_Use_SURROGATES/a/}');
Expect(1, 56319, '\p{Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\p{^Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\P{Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\P{^Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\p{Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\p{^Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\P{Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\P{^Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\p{Block= _high_private_USE_surrogates}', "");
Expect(0, 56319, '\p{^Block= _high_private_USE_surrogates}', "");
Expect(0, 56319, '\P{Block= _high_private_USE_surrogates}', "");
Expect(1, 56319, '\P{^Block= _high_private_USE_surrogates}', "");
Expect(0, 57344, '\p{Block= _high_private_USE_surrogates}', "");
Expect(1, 57344, '\p{^Block= _high_private_USE_surrogates}', "");
Expect(1, 57344, '\P{Block= _high_private_USE_surrogates}', "");
Expect(0, 57344, '\P{^Block= _high_private_USE_surrogates}', "");
Error('\p{Blk:	/a/HIGH_pu_surrogates}');
Error('\P{Blk:	/a/HIGH_pu_surrogates}');
Expect(1, 56319, '\p{Blk:highpusurrogates}', "");
Expect(0, 56319, '\p{^Blk:highpusurrogates}', "");
Expect(0, 56319, '\P{Blk:highpusurrogates}', "");
Expect(1, 56319, '\P{^Blk:highpusurrogates}', "");
Expect(0, 57344, '\p{Blk:highpusurrogates}', "");
Expect(1, 57344, '\p{^Blk:highpusurrogates}', "");
Expect(1, 57344, '\P{Blk:highpusurrogates}', "");
Expect(0, 57344, '\P{^Blk:highpusurrogates}', "");
Expect(1, 56319, '\p{Blk=HIGH_PU_Surrogates}', "");
Expect(0, 56319, '\p{^Blk=HIGH_PU_Surrogates}', "");
Expect(0, 56319, '\P{Blk=HIGH_PU_Surrogates}', "");
Expect(1, 56319, '\P{^Blk=HIGH_PU_Surrogates}', "");
Expect(0, 57344, '\p{Blk=HIGH_PU_Surrogates}', "");
Expect(1, 57344, '\p{^Blk=HIGH_PU_Surrogates}', "");
Expect(1, 57344, '\P{Blk=HIGH_PU_Surrogates}', "");
Expect(0, 57344, '\P{^Blk=HIGH_PU_Surrogates}', "");
Error('\p{Is_Block=/a/-	High_Private_use_surrogates}');
Error('\P{Is_Block=/a/-	High_Private_use_surrogates}');
Expect(1, 56319, '\p{Is_Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\p{^Is_Block=highprivateusesurrogates}', "");
Expect(0, 56319, '\P{Is_Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\P{^Is_Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\p{Is_Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\p{^Is_Block=highprivateusesurrogates}', "");
Expect(1, 57344, '\P{Is_Block=highprivateusesurrogates}', "");
Expect(0, 57344, '\P{^Is_Block=highprivateusesurrogates}', "");
Expect(1, 56319, '\p{Is_Block=-High_Private_use_SURROGATES}', "");
Expect(0, 56319, '\p{^Is_Block=-High_Private_use_SURROGATES}', "");
Expect(0, 56319, '\P{Is_Block=-High_Private_use_SURROGATES}', "");
Expect(1, 56319, '\P{^Is_Block=-High_Private_use_SURROGATES}', "");
Expect(0, 57344, '\p{Is_Block=-High_Private_use_SURROGATES}', "");
Expect(1, 57344, '\p{^Is_Block=-High_Private_use_SURROGATES}', "");
Expect(1, 57344, '\P{Is_Block=-High_Private_use_SURROGATES}', "");
Expect(0, 57344, '\P{^Is_Block=-High_Private_use_SURROGATES}', "");
Error('\p{Is_Blk=_	High_PU_Surrogates/a/}');
Error('\P{Is_Blk=_	High_PU_Surrogates/a/}');
Expect(1, 56319, '\p{Is_Blk: highpusurrogates}', "");
Expect(0, 56319, '\p{^Is_Blk: highpusurrogates}', "");
Expect(0, 56319, '\P{Is_Blk: highpusurrogates}', "");
Expect(1, 56319, '\P{^Is_Blk: highpusurrogates}', "");
Expect(0, 57344, '\p{Is_Blk: highpusurrogates}', "");
Expect(1, 57344, '\p{^Is_Blk: highpusurrogates}', "");
Expect(1, 57344, '\P{Is_Blk: highpusurrogates}', "");
Expect(0, 57344, '\P{^Is_Blk: highpusurrogates}', "");
Expect(1, 56319, '\p{Is_Blk= High_PU_Surrogates}', "");
Expect(0, 56319, '\p{^Is_Blk= High_PU_Surrogates}', "");
Expect(0, 56319, '\P{Is_Blk= High_PU_Surrogates}', "");
Expect(1, 56319, '\P{^Is_Blk= High_PU_Surrogates}', "");
Expect(0, 57344, '\p{Is_Blk= High_PU_Surrogates}', "");
Expect(1, 57344, '\p{^Is_Blk= High_PU_Surrogates}', "");
Expect(1, 57344, '\P{Is_Blk= High_PU_Surrogates}', "");
Expect(0, 57344, '\P{^Is_Blk= High_PU_Surrogates}', "");
Error('\p{Block=_:=high_surrogates}');
Error('\P{Block=_:=high_surrogates}');
Expect(1, 56191, '\p{Block=highsurrogates}', "");
Expect(0, 56191, '\p{^Block=highsurrogates}', "");
Expect(0, 56191, '\P{Block=highsurrogates}', "");
Expect(1, 56191, '\P{^Block=highsurrogates}', "");
Expect(0, 57344, '\p{Block=highsurrogates}', "");
Expect(1, 57344, '\p{^Block=highsurrogates}', "");
Expect(1, 57344, '\P{Block=highsurrogates}', "");
Expect(0, 57344, '\P{^Block=highsurrogates}', "");
Expect(1, 56191, '\p{Block= 	High_Surrogates}', "");
Expect(0, 56191, '\p{^Block= 	High_Surrogates}', "");
Expect(0, 56191, '\P{Block= 	High_Surrogates}', "");
Expect(1, 56191, '\P{^Block= 	High_Surrogates}', "");
Expect(0, 57344, '\p{Block= 	High_Surrogates}', "");
Expect(1, 57344, '\p{^Block= 	High_Surrogates}', "");
Expect(1, 57344, '\P{Block= 	High_Surrogates}', "");
Expect(0, 57344, '\P{^Block= 	High_Surrogates}', "");
Error('\p{Blk=:= 	high_surrogates}');
Error('\P{Blk=:= 	high_surrogates}');
Expect(1, 56191, '\p{Blk=highsurrogates}', "");
Expect(0, 56191, '\p{^Blk=highsurrogates}', "");
Expect(0, 56191, '\P{Blk=highsurrogates}', "");
Expect(1, 56191, '\P{^Blk=highsurrogates}', "");
Expect(0, 57344, '\p{Blk=highsurrogates}', "");
Expect(1, 57344, '\p{^Blk=highsurrogates}', "");
Expect(1, 57344, '\P{Blk=highsurrogates}', "");
Expect(0, 57344, '\P{^Blk=highsurrogates}', "");
Expect(1, 56191, '\p{Blk=HIGH_surrogates}', "");
Expect(0, 56191, '\p{^Blk=HIGH_surrogates}', "");
Expect(0, 56191, '\P{Blk=HIGH_surrogates}', "");
Expect(1, 56191, '\P{^Blk=HIGH_surrogates}', "");
Expect(0, 57344, '\p{Blk=HIGH_surrogates}', "");
Expect(1, 57344, '\p{^Blk=HIGH_surrogates}', "");
Expect(1, 57344, '\P{Blk=HIGH_surrogates}', "");
Expect(0, 57344, '\P{^Blk=HIGH_surrogates}', "");
Error('\p{Is_Block=/a/- High_SURROGATES}');
Error('\P{Is_Block=/a/- High_SURROGATES}');
Expect(1, 56191, '\p{Is_Block=highsurrogates}', "");
Expect(0, 56191, '\p{^Is_Block=highsurrogates}', "");
Expect(0, 56191, '\P{Is_Block=highsurrogates}', "");
Expect(1, 56191, '\P{^Is_Block=highsurrogates}', "");
Expect(0, 57344, '\p{Is_Block=highsurrogates}', "");
Expect(1, 57344, '\p{^Is_Block=highsurrogates}', "");
Expect(1, 57344, '\P{Is_Block=highsurrogates}', "");
Expect(0, 57344, '\P{^Is_Block=highsurrogates}', "");
Expect(1, 56191, '\p{Is_Block=-High_Surrogates}', "");
Expect(0, 56191, '\p{^Is_Block=-High_Surrogates}', "");
Expect(0, 56191, '\P{Is_Block=-High_Surrogates}', "");
Expect(1, 56191, '\P{^Is_Block=-High_Surrogates}', "");
Expect(0, 57344, '\p{Is_Block=-High_Surrogates}', "");
Expect(1, 57344, '\p{^Is_Block=-High_Surrogates}', "");
Expect(1, 57344, '\P{Is_Block=-High_Surrogates}', "");
Expect(0, 57344, '\P{^Is_Block=-High_Surrogates}', "");
Error('\p{Is_Blk=_-high_SURROGATES:=}');
Error('\P{Is_Blk=_-high_SURROGATES:=}');
Expect(1, 56191, '\p{Is_Blk=highsurrogates}', "");
Expect(0, 56191, '\p{^Is_Blk=highsurrogates}', "");
Expect(0, 56191, '\P{Is_Blk=highsurrogates}', "");
Expect(1, 56191, '\P{^Is_Blk=highsurrogates}', "");
Expect(0, 57344, '\p{Is_Blk=highsurrogates}', "");
Expect(1, 57344, '\p{^Is_Blk=highsurrogates}', "");
Expect(1, 57344, '\P{Is_Blk=highsurrogates}', "");
Expect(0, 57344, '\P{^Is_Blk=highsurrogates}', "");
Expect(1, 56191, '\p{Is_Blk= High_surrogates}', "");
Expect(0, 56191, '\p{^Is_Blk= High_surrogates}', "");
Expect(0, 56191, '\P{Is_Blk= High_surrogates}', "");
Expect(1, 56191, '\P{^Is_Blk= High_surrogates}', "");
Expect(0, 57344, '\p{Is_Blk= High_surrogates}', "");
Expect(1, 57344, '\p{^Is_Blk= High_surrogates}', "");
Expect(1, 57344, '\P{Is_Blk= High_surrogates}', "");
Expect(0, 57344, '\P{^Is_Blk= High_surrogates}', "");
Error('\p{Block=-HIRAGANA:=}');
Error('\P{Block=-HIRAGANA:=}');
Expect(1, 12447, '\p{Block=hiragana}', "");
Expect(0, 12447, '\p{^Block=hiragana}', "");
Expect(0, 12447, '\P{Block=hiragana}', "");
Expect(1, 12447, '\P{^Block=hiragana}', "");
Expect(0, 12448, '\p{Block=hiragana}', "");
Expect(1, 12448, '\p{^Block=hiragana}', "");
Expect(1, 12448, '\P{Block=hiragana}', "");
Expect(0, 12448, '\P{^Block=hiragana}', "");
Expect(1, 12447, '\p{Block= -Hiragana}', "");
Expect(0, 12447, '\p{^Block= -Hiragana}', "");
Expect(0, 12447, '\P{Block= -Hiragana}', "");
Expect(1, 12447, '\P{^Block= -Hiragana}', "");
Expect(0, 12448, '\p{Block= -Hiragana}', "");
Expect(1, 12448, '\p{^Block= -Hiragana}', "");
Expect(1, 12448, '\P{Block= -Hiragana}', "");
Expect(0, 12448, '\P{^Block= -Hiragana}', "");
Error('\p{Blk= hiragana/a/}');
Error('\P{Blk= hiragana/a/}');
Expect(1, 12447, '\p{Blk=hiragana}', "");
Expect(0, 12447, '\p{^Blk=hiragana}', "");
Expect(0, 12447, '\P{Blk=hiragana}', "");
Expect(1, 12447, '\P{^Blk=hiragana}', "");
Expect(0, 12448, '\p{Blk=hiragana}', "");
Expect(1, 12448, '\p{^Blk=hiragana}', "");
Expect(1, 12448, '\P{Blk=hiragana}', "");
Expect(0, 12448, '\P{^Blk=hiragana}', "");
Error('\p{Is_Block:   :=_Hiragana}');
Error('\P{Is_Block:   :=_Hiragana}');
Expect(1, 12447, '\p{Is_Block=hiragana}', "");
Expect(0, 12447, '\p{^Is_Block=hiragana}', "");
Expect(0, 12447, '\P{Is_Block=hiragana}', "");
Expect(1, 12447, '\P{^Is_Block=hiragana}', "");
Expect(0, 12448, '\p{Is_Block=hiragana}', "");
Expect(1, 12448, '\p{^Is_Block=hiragana}', "");
Expect(1, 12448, '\P{Is_Block=hiragana}', "");
Expect(0, 12448, '\P{^Is_Block=hiragana}', "");
Expect(1, 12447, '\p{Is_Block: --HIRAGANA}', "");
Expect(0, 12447, '\p{^Is_Block: --HIRAGANA}', "");
Expect(0, 12447, '\P{Is_Block: --HIRAGANA}', "");
Expect(1, 12447, '\P{^Is_Block: --HIRAGANA}', "");
Expect(0, 12448, '\p{Is_Block: --HIRAGANA}', "");
Expect(1, 12448, '\p{^Is_Block: --HIRAGANA}', "");
Expect(1, 12448, '\P{Is_Block: --HIRAGANA}', "");
Expect(0, 12448, '\P{^Is_Block: --HIRAGANA}', "");
Error('\p{Is_Blk=:=- Hiragana}');
Error('\P{Is_Blk=:=- Hiragana}');
Expect(1, 12447, '\p{Is_Blk=hiragana}', "");
Expect(0, 12447, '\p{^Is_Blk=hiragana}', "");
Expect(0, 12447, '\P{Is_Blk=hiragana}', "");
Expect(1, 12447, '\P{^Is_Blk=hiragana}', "");
Expect(0, 12448, '\p{Is_Blk=hiragana}', "");
Expect(1, 12448, '\p{^Is_Blk=hiragana}', "");
Expect(1, 12448, '\P{Is_Blk=hiragana}', "");
Expect(0, 12448, '\P{^Is_Blk=hiragana}', "");
Expect(1, 12447, '\p{Is_Blk=	 Hiragana}', "");
Expect(0, 12447, '\p{^Is_Blk=	 Hiragana}', "");
Expect(0, 12447, '\P{Is_Blk=	 Hiragana}', "");
Expect(1, 12447, '\P{^Is_Blk=	 Hiragana}', "");
Expect(0, 12448, '\p{Is_Blk=	 Hiragana}', "");
Expect(1, 12448, '\p{^Is_Blk=	 Hiragana}', "");
Expect(1, 12448, '\P{Is_Blk=	 Hiragana}', "");
Expect(0, 12448, '\P{^Is_Blk=	 Hiragana}', "");
Error('\p{Block=-/a/Ideographic_description_characters}');
Error('\P{Block=-/a/Ideographic_description_characters}');
Expect(1, 12287, '\p{Block=ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^Block=ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{Block=ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^Block=ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{Block=ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^Block=ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{Block=ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^Block=ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{Block=_ ideographic_Description_Characters}', "");
Expect(0, 12287, '\p{^Block=_ ideographic_Description_Characters}', "");
Expect(0, 12287, '\P{Block=_ ideographic_Description_Characters}', "");
Expect(1, 12287, '\P{^Block=_ ideographic_Description_Characters}', "");
Expect(0, 12288, '\p{Block=_ ideographic_Description_Characters}', "");
Expect(1, 12288, '\p{^Block=_ ideographic_Description_Characters}', "");
Expect(1, 12288, '\P{Block=_ ideographic_Description_Characters}', "");
Expect(0, 12288, '\P{^Block=_ ideographic_Description_Characters}', "");
Error('\p{Blk=:=_IDC}');
Error('\P{Blk=:=_IDC}');
Expect(1, 12287, '\p{Blk=idc}', "");
Expect(0, 12287, '\p{^Blk=idc}', "");
Expect(0, 12287, '\P{Blk=idc}', "");
Expect(1, 12287, '\P{^Blk=idc}', "");
Expect(0, 12288, '\p{Blk=idc}', "");
Expect(1, 12288, '\p{^Blk=idc}', "");
Expect(1, 12288, '\P{Blk=idc}', "");
Expect(0, 12288, '\P{^Blk=idc}', "");
Expect(1, 12287, '\p{Blk=_-IDC}', "");
Expect(0, 12287, '\p{^Blk=_-IDC}', "");
Expect(0, 12287, '\P{Blk=_-IDC}', "");
Expect(1, 12287, '\P{^Blk=_-IDC}', "");
Expect(0, 12288, '\p{Blk=_-IDC}', "");
Expect(1, 12288, '\p{^Blk=_-IDC}', "");
Expect(1, 12288, '\P{Blk=_-IDC}', "");
Expect(0, 12288, '\P{^Blk=_-IDC}', "");
Error('\p{Is_Block=  Ideographic_description_Characters:=}');
Error('\P{Is_Block=  Ideographic_description_Characters:=}');
Expect(1, 12287, '\p{Is_Block: ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^Is_Block: ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{Is_Block: ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^Is_Block: ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{Is_Block: ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^Is_Block: ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{Is_Block: ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^Is_Block: ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(0, 12287, '\p{^Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(0, 12287, '\P{Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(1, 12287, '\P{^Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(0, 12288, '\p{Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(1, 12288, '\p{^Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(1, 12288, '\P{Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Expect(0, 12288, '\P{^Is_Block=_-IDEOGRAPHIC_Description_Characters}', "");
Error('\p{Is_Blk:   /a/- IDC}');
Error('\P{Is_Blk:   /a/- IDC}');
Expect(1, 12287, '\p{Is_Blk=idc}', "");
Expect(0, 12287, '\p{^Is_Blk=idc}', "");
Expect(0, 12287, '\P{Is_Blk=idc}', "");
Expect(1, 12287, '\P{^Is_Blk=idc}', "");
Expect(0, 12288, '\p{Is_Blk=idc}', "");
Expect(1, 12288, '\p{^Is_Blk=idc}', "");
Expect(1, 12288, '\P{Is_Blk=idc}', "");
Expect(0, 12288, '\P{^Is_Blk=idc}', "");
Expect(1, 12287, '\p{Is_Blk=- idc}', "");
Expect(0, 12287, '\p{^Is_Blk=- idc}', "");
Expect(0, 12287, '\P{Is_Blk=- idc}', "");
Expect(1, 12287, '\P{^Is_Blk=- idc}', "");
Expect(0, 12288, '\p{Is_Blk=- idc}', "");
Expect(1, 12288, '\p{^Is_Blk=- idc}', "");
Expect(1, 12288, '\P{Is_Blk=- idc}', "");
Expect(0, 12288, '\P{^Is_Blk=- idc}', "");
Error('\p{Block=	-IPA_extensions:=}');
Error('\P{Block=	-IPA_extensions:=}');
Expect(1, 687, '\p{Block: ipaextensions}', "");
Expect(0, 687, '\p{^Block: ipaextensions}', "");
Expect(0, 687, '\P{Block: ipaextensions}', "");
Expect(1, 687, '\P{^Block: ipaextensions}', "");
Expect(0, 688, '\p{Block: ipaextensions}', "");
Expect(1, 688, '\p{^Block: ipaextensions}', "");
Expect(1, 688, '\P{Block: ipaextensions}', "");
Expect(0, 688, '\P{^Block: ipaextensions}', "");
Expect(1, 687, '\p{Block=_	IPA_Extensions}', "");
Expect(0, 687, '\p{^Block=_	IPA_Extensions}', "");
Expect(0, 687, '\P{Block=_	IPA_Extensions}', "");
Expect(1, 687, '\P{^Block=_	IPA_Extensions}', "");
Expect(0, 688, '\p{Block=_	IPA_Extensions}', "");
Expect(1, 688, '\p{^Block=_	IPA_Extensions}', "");
Expect(1, 688, '\P{Block=_	IPA_Extensions}', "");
Expect(0, 688, '\P{^Block=_	IPA_Extensions}', "");
Error('\p{Blk=- IPA_ext/a/}');
Error('\P{Blk=- IPA_ext/a/}');
Expect(1, 687, '\p{Blk=ipaext}', "");
Expect(0, 687, '\p{^Blk=ipaext}', "");
Expect(0, 687, '\P{Blk=ipaext}', "");
Expect(1, 687, '\P{^Blk=ipaext}', "");
Expect(0, 688, '\p{Blk=ipaext}', "");
Expect(1, 688, '\p{^Blk=ipaext}', "");
Expect(1, 688, '\P{Blk=ipaext}', "");
Expect(0, 688, '\P{^Blk=ipaext}', "");
Expect(1, 687, '\p{Blk=_ ipa_Ext}', "");
Expect(0, 687, '\p{^Blk=_ ipa_Ext}', "");
Expect(0, 687, '\P{Blk=_ ipa_Ext}', "");
Expect(1, 687, '\P{^Blk=_ ipa_Ext}', "");
Expect(0, 688, '\p{Blk=_ ipa_Ext}', "");
Expect(1, 688, '\p{^Blk=_ ipa_Ext}', "");
Expect(1, 688, '\P{Blk=_ ipa_Ext}', "");
Expect(0, 688, '\P{^Blk=_ ipa_Ext}', "");
Error('\p{Is_Block=_ ipa_Extensions:=}');
Error('\P{Is_Block=_ ipa_Extensions:=}');
Expect(1, 687, '\p{Is_Block=ipaextensions}', "");
Expect(0, 687, '\p{^Is_Block=ipaextensions}', "");
Expect(0, 687, '\P{Is_Block=ipaextensions}', "");
Expect(1, 687, '\P{^Is_Block=ipaextensions}', "");
Expect(0, 688, '\p{Is_Block=ipaextensions}', "");
Expect(1, 688, '\p{^Is_Block=ipaextensions}', "");
Expect(1, 688, '\P{Is_Block=ipaextensions}', "");
Expect(0, 688, '\P{^Is_Block=ipaextensions}', "");
Expect(1, 687, '\p{Is_Block=_ ipa_Extensions}', "");
Expect(0, 687, '\p{^Is_Block=_ ipa_Extensions}', "");
Expect(0, 687, '\P{Is_Block=_ ipa_Extensions}', "");
Expect(1, 687, '\P{^Is_Block=_ ipa_Extensions}', "");
Expect(0, 688, '\p{Is_Block=_ ipa_Extensions}', "");
Expect(1, 688, '\p{^Is_Block=_ ipa_Extensions}', "");
Expect(1, 688, '\P{Is_Block=_ ipa_Extensions}', "");
Expect(0, 688, '\P{^Is_Block=_ ipa_Extensions}', "");
Error('\p{Is_Blk=	/a/ipa_Ext}');
Error('\P{Is_Blk=	/a/ipa_Ext}');
Expect(1, 687, '\p{Is_Blk=ipaext}', "");
Expect(0, 687, '\p{^Is_Blk=ipaext}', "");
Expect(0, 687, '\P{Is_Blk=ipaext}', "");
Expect(1, 687, '\P{^Is_Blk=ipaext}', "");
Expect(0, 688, '\p{Is_Blk=ipaext}', "");
Expect(1, 688, '\p{^Is_Blk=ipaext}', "");
Expect(1, 688, '\P{Is_Blk=ipaext}', "");
Expect(0, 688, '\P{^Is_Blk=ipaext}', "");
Expect(1, 687, '\p{Is_Blk= ipa_Ext}', "");
Expect(0, 687, '\p{^Is_Blk= ipa_Ext}', "");
Expect(0, 687, '\P{Is_Blk= ipa_Ext}', "");
Expect(1, 687, '\P{^Is_Blk= ipa_Ext}', "");
Expect(0, 688, '\p{Is_Blk= ipa_Ext}', "");
Expect(1, 688, '\p{^Is_Blk= ipa_Ext}', "");
Expect(1, 688, '\P{Is_Blk= ipa_Ext}', "");
Expect(0, 688, '\P{^Is_Blk= ipa_Ext}', "");
Error('\p{Block=/a/Imperial_aramaic}');
Error('\P{Block=/a/Imperial_aramaic}');
Expect(1, 67679, '\p{Block=imperialaramaic}', "");
Expect(0, 67679, '\p{^Block=imperialaramaic}', "");
Expect(0, 67679, '\P{Block=imperialaramaic}', "");
Expect(1, 67679, '\P{^Block=imperialaramaic}', "");
Expect(0, 67680, '\p{Block=imperialaramaic}', "");
Expect(1, 67680, '\p{^Block=imperialaramaic}', "");
Expect(1, 67680, '\P{Block=imperialaramaic}', "");
Expect(0, 67680, '\P{^Block=imperialaramaic}', "");
Expect(1, 67679, '\p{Block=	Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Block=	Imperial_Aramaic}', "");
Expect(0, 67679, '\P{Block=	Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Block=	Imperial_Aramaic}', "");
Expect(0, 67680, '\p{Block=	Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Block=	Imperial_Aramaic}', "");
Expect(1, 67680, '\P{Block=	Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Block=	Imperial_Aramaic}', "");
Error('\p{Blk=:=_-Imperial_ARAMAIC}');
Error('\P{Blk=:=_-Imperial_ARAMAIC}');
Expect(1, 67679, '\p{Blk=imperialaramaic}', "");
Expect(0, 67679, '\p{^Blk=imperialaramaic}', "");
Expect(0, 67679, '\P{Blk=imperialaramaic}', "");
Expect(1, 67679, '\P{^Blk=imperialaramaic}', "");
Expect(0, 67680, '\p{Blk=imperialaramaic}', "");
Expect(1, 67680, '\p{^Blk=imperialaramaic}', "");
Expect(1, 67680, '\P{Blk=imperialaramaic}', "");
Expect(0, 67680, '\P{^Blk=imperialaramaic}', "");
Expect(1, 67679, '\p{Blk=	-IMPERIAL_Aramaic}', "");
Expect(0, 67679, '\p{^Blk=	-IMPERIAL_Aramaic}', "");
Expect(0, 67679, '\P{Blk=	-IMPERIAL_Aramaic}', "");
Expect(1, 67679, '\P{^Blk=	-IMPERIAL_Aramaic}', "");
Expect(0, 67680, '\p{Blk=	-IMPERIAL_Aramaic}', "");
Expect(1, 67680, '\p{^Blk=	-IMPERIAL_Aramaic}', "");
Expect(1, 67680, '\P{Blk=	-IMPERIAL_Aramaic}', "");
Expect(0, 67680, '\P{^Blk=	-IMPERIAL_Aramaic}', "");
Error('\p{Is_Block=/a/-	IMPERIAL_ARAMAIC}');
Error('\P{Is_Block=/a/-	IMPERIAL_ARAMAIC}');
Expect(1, 67679, '\p{Is_Block=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Block=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Block=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Block=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Block=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Block=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Block=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Block=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Block=_imperial_ARAMAIC}', "");
Expect(0, 67679, '\p{^Is_Block=_imperial_ARAMAIC}', "");
Expect(0, 67679, '\P{Is_Block=_imperial_ARAMAIC}', "");
Expect(1, 67679, '\P{^Is_Block=_imperial_ARAMAIC}', "");
Expect(0, 67680, '\p{Is_Block=_imperial_ARAMAIC}', "");
Expect(1, 67680, '\p{^Is_Block=_imperial_ARAMAIC}', "");
Expect(1, 67680, '\P{Is_Block=_imperial_ARAMAIC}', "");
Expect(0, 67680, '\P{^Is_Block=_imperial_ARAMAIC}', "");
Error('\p{Is_Blk=/a/ IMPERIAL_ARAMAIC}');
Error('\P{Is_Blk=/a/ IMPERIAL_ARAMAIC}');
Expect(1, 67679, '\p{Is_Blk=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Blk=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Blk=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Blk=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Blk=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Blk=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Blk=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Blk=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Blk=Imperial_aramaic}', "");
Expect(0, 67679, '\p{^Is_Blk=Imperial_aramaic}', "");
Expect(0, 67679, '\P{Is_Blk=Imperial_aramaic}', "");
Expect(1, 67679, '\P{^Is_Blk=Imperial_aramaic}', "");
Expect(0, 67680, '\p{Is_Blk=Imperial_aramaic}', "");
Expect(1, 67680, '\p{^Is_Blk=Imperial_aramaic}', "");
Expect(1, 67680, '\P{Is_Blk=Imperial_aramaic}', "");
Expect(0, 67680, '\P{^Is_Blk=Imperial_aramaic}', "");
Error('\p{Block=:=  Common_INDIC_Number_FORMS}');
Error('\P{Block=:=  Common_INDIC_Number_FORMS}');
Expect(1, 43071, '\p{Block=commonindicnumberforms}', "");
Expect(0, 43071, '\p{^Block=commonindicnumberforms}', "");
Expect(0, 43071, '\P{Block=commonindicnumberforms}', "");
Expect(1, 43071, '\P{^Block=commonindicnumberforms}', "");
Expect(0, 43072, '\p{Block=commonindicnumberforms}', "");
Expect(1, 43072, '\p{^Block=commonindicnumberforms}', "");
Expect(1, 43072, '\P{Block=commonindicnumberforms}', "");
Expect(0, 43072, '\P{^Block=commonindicnumberforms}', "");
Expect(1, 43071, '\p{Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(0, 43071, '\p{^Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(0, 43071, '\P{Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(1, 43071, '\P{^Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(0, 43072, '\p{Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(1, 43072, '\p{^Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(1, 43072, '\P{Block=	-COMMON_INDIC_Number_Forms}', "");
Expect(0, 43072, '\P{^Block=	-COMMON_INDIC_Number_Forms}', "");
Error('\p{Blk=- Indic_number_Forms:=}');
Error('\P{Blk=- Indic_number_Forms:=}');
Expect(1, 43071, '\p{Blk:indicnumberforms}', "");
Expect(0, 43071, '\p{^Blk:indicnumberforms}', "");
Expect(0, 43071, '\P{Blk:indicnumberforms}', "");
Expect(1, 43071, '\P{^Blk:indicnumberforms}', "");
Expect(0, 43072, '\p{Blk:indicnumberforms}', "");
Expect(1, 43072, '\p{^Blk:indicnumberforms}', "");
Expect(1, 43072, '\P{Blk:indicnumberforms}', "");
Expect(0, 43072, '\P{^Blk:indicnumberforms}', "");
Expect(1, 43071, '\p{Blk=- Indic_Number_forms}', "");
Expect(0, 43071, '\p{^Blk=- Indic_Number_forms}', "");
Expect(0, 43071, '\P{Blk=- Indic_Number_forms}', "");
Expect(1, 43071, '\P{^Blk=- Indic_Number_forms}', "");
Expect(0, 43072, '\p{Blk=- Indic_Number_forms}', "");
Expect(1, 43072, '\p{^Blk=- Indic_Number_forms}', "");
Expect(1, 43072, '\P{Blk=- Indic_Number_forms}', "");
Expect(0, 43072, '\P{^Blk=- Indic_Number_forms}', "");
Error('\p{Is_Block= COMMON_INDIC_Number_forms/a/}');
Error('\P{Is_Block= COMMON_INDIC_Number_forms/a/}');
Expect(1, 43071, '\p{Is_Block=commonindicnumberforms}', "");
Expect(0, 43071, '\p{^Is_Block=commonindicnumberforms}', "");
Expect(0, 43071, '\P{Is_Block=commonindicnumberforms}', "");
Expect(1, 43071, '\P{^Is_Block=commonindicnumberforms}', "");
Expect(0, 43072, '\p{Is_Block=commonindicnumberforms}', "");
Expect(1, 43072, '\p{^Is_Block=commonindicnumberforms}', "");
Expect(1, 43072, '\P{Is_Block=commonindicnumberforms}', "");
Expect(0, 43072, '\P{^Is_Block=commonindicnumberforms}', "");
Expect(1, 43071, '\p{Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(0, 43071, '\p{^Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(0, 43071, '\P{Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(1, 43071, '\P{^Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(0, 43072, '\p{Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(1, 43072, '\p{^Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(1, 43072, '\P{Is_Block= COMMON_Indic_Number_FORMS}', "");
Expect(0, 43072, '\P{^Is_Block= COMMON_Indic_Number_FORMS}', "");
Error('\p{Is_Blk=/a/_ INDIC_Number_forms}');
Error('\P{Is_Blk=/a/_ INDIC_Number_forms}');
Expect(1, 43071, '\p{Is_Blk=indicnumberforms}', "");
Expect(0, 43071, '\p{^Is_Blk=indicnumberforms}', "");
Expect(0, 43071, '\P{Is_Blk=indicnumberforms}', "");
Expect(1, 43071, '\P{^Is_Blk=indicnumberforms}', "");
Expect(0, 43072, '\p{Is_Blk=indicnumberforms}', "");
Expect(1, 43072, '\p{^Is_Blk=indicnumberforms}', "");
Expect(1, 43072, '\P{Is_Blk=indicnumberforms}', "");
Expect(0, 43072, '\P{^Is_Blk=indicnumberforms}', "");
Expect(1, 43071, '\p{Is_Blk=-indic_Number_Forms}', "");
Expect(0, 43071, '\p{^Is_Blk=-indic_Number_Forms}', "");
Expect(0, 43071, '\P{Is_Blk=-indic_Number_Forms}', "");
Expect(1, 43071, '\P{^Is_Blk=-indic_Number_Forms}', "");
Expect(0, 43072, '\p{Is_Blk=-indic_Number_Forms}', "");
Expect(1, 43072, '\p{^Is_Blk=-indic_Number_Forms}', "");
Expect(1, 43072, '\P{Is_Blk=-indic_Number_Forms}', "");
Expect(0, 43072, '\P{^Is_Blk=-indic_Number_Forms}', "");
Error('\p{Block=-Inscriptional_pahlavi/a/}');
Error('\P{Block=-Inscriptional_pahlavi/a/}');
Expect(1, 68479, '\p{Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68479, '\p{^Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68479, '\P{Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(1, 68479, '\P{^Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68480, '\p{Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(1, 68480, '\p{^Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(1, 68480, '\P{Block= _INSCRIPTIONAL_PAHLAVI}', "");
Expect(0, 68480, '\P{^Block= _INSCRIPTIONAL_PAHLAVI}', "");
Error('\p{Blk=	INSCRIPTIONAL_PAHLAVI:=}');
Error('\P{Blk=	INSCRIPTIONAL_PAHLAVI:=}');
Expect(1, 68479, '\p{Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Blk=	_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^Blk=	_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{Blk=	_Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^Blk=	_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{Blk=	_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^Blk=	_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{Blk=	_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^Blk=	_Inscriptional_Pahlavi}', "");
Error('\p{Is_Block=-/a/Inscriptional_Pahlavi}');
Error('\P{Is_Block=-/a/Inscriptional_Pahlavi}');
Expect(1, 68479, '\p{Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Block=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Block=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Block=-_Inscriptional_pahlavi}', "");
Expect(0, 68479, '\p{^Is_Block=-_Inscriptional_pahlavi}', "");
Expect(0, 68479, '\P{Is_Block=-_Inscriptional_pahlavi}', "");
Expect(1, 68479, '\P{^Is_Block=-_Inscriptional_pahlavi}', "");
Expect(0, 68480, '\p{Is_Block=-_Inscriptional_pahlavi}', "");
Expect(1, 68480, '\p{^Is_Block=-_Inscriptional_pahlavi}', "");
Expect(1, 68480, '\P{Is_Block=-_Inscriptional_pahlavi}', "");
Expect(0, 68480, '\P{^Is_Block=-_Inscriptional_pahlavi}', "");
Error('\p{Is_Blk= /a/inscriptional_Pahlavi}');
Error('\P{Is_Blk= /a/inscriptional_Pahlavi}');
Expect(1, 68479, '\p{Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Blk=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Blk=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\p{^Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\P{Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(1, 68479, '\P{^Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\p{Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\p{^Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\P{Is_Blk= 	Inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\P{^Is_Blk= 	Inscriptional_PAHLAVI}', "");
Error('\p{Block=INSCRIPTIONAL_Parthian:=}');
Error('\P{Block=INSCRIPTIONAL_Parthian:=}');
Expect(1, 68447, '\p{Block=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Block=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Block=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Block=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Block=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Block=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Block=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Block=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Block=  Inscriptional_Parthian}', "");
Expect(0, 68447, '\p{^Block=  Inscriptional_Parthian}', "");
Expect(0, 68447, '\P{Block=  Inscriptional_Parthian}', "");
Expect(1, 68447, '\P{^Block=  Inscriptional_Parthian}', "");
Expect(0, 68448, '\p{Block=  Inscriptional_Parthian}', "");
Expect(1, 68448, '\p{^Block=  Inscriptional_Parthian}', "");
Expect(1, 68448, '\P{Block=  Inscriptional_Parthian}', "");
Expect(0, 68448, '\P{^Block=  Inscriptional_Parthian}', "");
Error('\p{Blk=-/a/INSCRIPTIONAL_parthian}');
Error('\P{Blk=-/a/INSCRIPTIONAL_parthian}');
Expect(1, 68447, '\p{Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{Blk:	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^Blk:	 INSCRIPTIONAL_Parthian}', "");
Error('\p{Is_Block=/a/inscriptional_Parthian}');
Error('\P{Is_Block=/a/inscriptional_Parthian}');
Expect(1, 68447, '\p{Is_Block:inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Block:inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Block:inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Block:inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Block:inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Block:inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Block:inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Block:inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Block=_Inscriptional_parthian}', "");
Expect(0, 68447, '\p{^Is_Block=_Inscriptional_parthian}', "");
Expect(0, 68447, '\P{Is_Block=_Inscriptional_parthian}', "");
Expect(1, 68447, '\P{^Is_Block=_Inscriptional_parthian}', "");
Expect(0, 68448, '\p{Is_Block=_Inscriptional_parthian}', "");
Expect(1, 68448, '\p{^Is_Block=_Inscriptional_parthian}', "");
Expect(1, 68448, '\P{Is_Block=_Inscriptional_parthian}', "");
Expect(0, 68448, '\P{^Is_Block=_Inscriptional_parthian}', "");
Error('\p{Is_Blk=-	inscriptional_Parthian:=}');
Error('\P{Is_Blk=-	inscriptional_Parthian:=}');
Expect(1, 68447, '\p{Is_Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Blk=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Blk=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Blk=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Blk=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Blk=_	inscriptional_parthian}', "");
Expect(0, 68447, '\p{^Is_Blk=_	inscriptional_parthian}', "");
Expect(0, 68447, '\P{Is_Blk=_	inscriptional_parthian}', "");
Expect(1, 68447, '\P{^Is_Blk=_	inscriptional_parthian}', "");
Expect(0, 68448, '\p{Is_Blk=_	inscriptional_parthian}', "");
Expect(1, 68448, '\p{^Is_Blk=_	inscriptional_parthian}', "");
Expect(1, 68448, '\P{Is_Blk=_	inscriptional_parthian}', "");
Expect(0, 68448, '\P{^Is_Blk=_	inscriptional_parthian}', "");
Error('\p{Block=/a/-Hangul_Jamo}');
Error('\P{Block=/a/-Hangul_Jamo}');
Expect(1, 4607, '\p{Block=hanguljamo}', "");
Expect(0, 4607, '\p{^Block=hanguljamo}', "");
Expect(0, 4607, '\P{Block=hanguljamo}', "");
Expect(1, 4607, '\P{^Block=hanguljamo}', "");
Expect(0, 4608, '\p{Block=hanguljamo}', "");
Expect(1, 4608, '\p{^Block=hanguljamo}', "");
Expect(1, 4608, '\P{Block=hanguljamo}', "");
Expect(0, 4608, '\P{^Block=hanguljamo}', "");
Expect(1, 4607, '\p{Block=- hangul_Jamo}', "");
Expect(0, 4607, '\p{^Block=- hangul_Jamo}', "");
Expect(0, 4607, '\P{Block=- hangul_Jamo}', "");
Expect(1, 4607, '\P{^Block=- hangul_Jamo}', "");
Expect(0, 4608, '\p{Block=- hangul_Jamo}', "");
Expect(1, 4608, '\p{^Block=- hangul_Jamo}', "");
Expect(1, 4608, '\P{Block=- hangul_Jamo}', "");
Expect(0, 4608, '\P{^Block=- hangul_Jamo}', "");
Error('\p{Blk=	_jamo:=}');
Error('\P{Blk=	_jamo:=}');
Expect(1, 4607, '\p{Blk:jamo}', "");
Expect(0, 4607, '\p{^Blk:jamo}', "");
Expect(0, 4607, '\P{Blk:jamo}', "");
Expect(1, 4607, '\P{^Blk:jamo}', "");
Expect(0, 4608, '\p{Blk:jamo}', "");
Expect(1, 4608, '\p{^Blk:jamo}', "");
Expect(1, 4608, '\P{Blk:jamo}', "");
Expect(0, 4608, '\P{^Blk:jamo}', "");
Expect(1, 4607, '\p{Blk=	_Jamo}', "");
Expect(0, 4607, '\p{^Blk=	_Jamo}', "");
Expect(0, 4607, '\P{Blk=	_Jamo}', "");
Expect(1, 4607, '\P{^Blk=	_Jamo}', "");
Expect(0, 4608, '\p{Blk=	_Jamo}', "");
Expect(1, 4608, '\p{^Blk=	_Jamo}', "");
Expect(1, 4608, '\P{Blk=	_Jamo}', "");
Expect(0, 4608, '\P{^Blk=	_Jamo}', "");
Error('\p{Is_Block=:=		HANGUL_JAMO}');
Error('\P{Is_Block=:=		HANGUL_JAMO}');
Expect(1, 4607, '\p{Is_Block=hanguljamo}', "");
Expect(0, 4607, '\p{^Is_Block=hanguljamo}', "");
Expect(0, 4607, '\P{Is_Block=hanguljamo}', "");
Expect(1, 4607, '\P{^Is_Block=hanguljamo}', "");
Expect(0, 4608, '\p{Is_Block=hanguljamo}', "");
Expect(1, 4608, '\p{^Is_Block=hanguljamo}', "");
Expect(1, 4608, '\P{Is_Block=hanguljamo}', "");
Expect(0, 4608, '\P{^Is_Block=hanguljamo}', "");
Expect(1, 4607, '\p{Is_Block= _Hangul_JAMO}', "");
Expect(0, 4607, '\p{^Is_Block= _Hangul_JAMO}', "");
Expect(0, 4607, '\P{Is_Block= _Hangul_JAMO}', "");
Expect(1, 4607, '\P{^Is_Block= _Hangul_JAMO}', "");
Expect(0, 4608, '\p{Is_Block= _Hangul_JAMO}', "");
Expect(1, 4608, '\p{^Is_Block= _Hangul_JAMO}', "");
Expect(1, 4608, '\P{Is_Block= _Hangul_JAMO}', "");
Expect(0, 4608, '\P{^Is_Block= _Hangul_JAMO}', "");
Error('\p{Is_Blk=/a/	Jamo}');
Error('\P{Is_Blk=/a/	Jamo}');
Expect(1, 4607, '\p{Is_Blk=jamo}', "");
Expect(0, 4607, '\p{^Is_Blk=jamo}', "");
Expect(0, 4607, '\P{Is_Blk=jamo}', "");
Expect(1, 4607, '\P{^Is_Blk=jamo}', "");
Expect(0, 4608, '\p{Is_Blk=jamo}', "");
Expect(1, 4608, '\p{^Is_Blk=jamo}', "");
Expect(1, 4608, '\P{Is_Blk=jamo}', "");
Expect(0, 4608, '\P{^Is_Blk=jamo}', "");
Expect(1, 4607, '\p{Is_Blk=-	JAMO}', "");
Expect(0, 4607, '\p{^Is_Blk=-	JAMO}', "");
Expect(0, 4607, '\P{Is_Blk=-	JAMO}', "");
Expect(1, 4607, '\P{^Is_Blk=-	JAMO}', "");
Expect(0, 4608, '\p{Is_Blk=-	JAMO}', "");
Expect(1, 4608, '\p{^Is_Blk=-	JAMO}', "");
Expect(1, 4608, '\P{Is_Blk=-	JAMO}', "");
Expect(0, 4608, '\P{^Is_Blk=-	JAMO}', "");
Error('\p{Block=/a/_Hangul_jamo_extended_a}');
Error('\P{Block=/a/_Hangul_jamo_extended_a}');
Expect(1, 43391, '\p{Block=hanguljamoextendeda}', "");
Expect(0, 43391, '\p{^Block=hanguljamoextendeda}', "");
Expect(0, 43391, '\P{Block=hanguljamoextendeda}', "");
Expect(1, 43391, '\P{^Block=hanguljamoextendeda}', "");
Expect(0, 43392, '\p{Block=hanguljamoextendeda}', "");
Expect(1, 43392, '\p{^Block=hanguljamoextendeda}', "");
Expect(1, 43392, '\P{Block=hanguljamoextendeda}', "");
Expect(0, 43392, '\P{^Block=hanguljamoextendeda}', "");
Expect(1, 43391, '\p{Block=_hangul_Jamo_extended_A}', "");
Expect(0, 43391, '\p{^Block=_hangul_Jamo_extended_A}', "");
Expect(0, 43391, '\P{Block=_hangul_Jamo_extended_A}', "");
Expect(1, 43391, '\P{^Block=_hangul_Jamo_extended_A}', "");
Expect(0, 43392, '\p{Block=_hangul_Jamo_extended_A}', "");
Expect(1, 43392, '\p{^Block=_hangul_Jamo_extended_A}', "");
Expect(1, 43392, '\P{Block=_hangul_Jamo_extended_A}', "");
Expect(0, 43392, '\P{^Block=_hangul_Jamo_extended_A}', "");
Error('\p{Blk=/a/jamo_ext_A}');
Error('\P{Blk=/a/jamo_ext_A}');
Expect(1, 43391, '\p{Blk=jamoexta}', "");
Expect(0, 43391, '\p{^Blk=jamoexta}', "");
Expect(0, 43391, '\P{Blk=jamoexta}', "");
Expect(1, 43391, '\P{^Blk=jamoexta}', "");
Expect(0, 43392, '\p{Blk=jamoexta}', "");
Expect(1, 43392, '\p{^Blk=jamoexta}', "");
Expect(1, 43392, '\P{Blk=jamoexta}', "");
Expect(0, 43392, '\P{^Blk=jamoexta}', "");
Expect(1, 43391, '\p{Blk=		JAMO_Ext_A}', "");
Expect(0, 43391, '\p{^Blk=		JAMO_Ext_A}', "");
Expect(0, 43391, '\P{Blk=		JAMO_Ext_A}', "");
Expect(1, 43391, '\P{^Blk=		JAMO_Ext_A}', "");
Expect(0, 43392, '\p{Blk=		JAMO_Ext_A}', "");
Expect(1, 43392, '\p{^Blk=		JAMO_Ext_A}', "");
Expect(1, 43392, '\P{Blk=		JAMO_Ext_A}', "");
Expect(0, 43392, '\P{^Blk=		JAMO_Ext_A}', "");
Error('\p{Is_Block=_HANGUL_Jamo_Extended_A:=}');
Error('\P{Is_Block=_HANGUL_Jamo_Extended_A:=}');
Expect(1, 43391, '\p{Is_Block=hanguljamoextendeda}', "");
Expect(0, 43391, '\p{^Is_Block=hanguljamoextendeda}', "");
Expect(0, 43391, '\P{Is_Block=hanguljamoextendeda}', "");
Expect(1, 43391, '\P{^Is_Block=hanguljamoextendeda}', "");
Expect(0, 43392, '\p{Is_Block=hanguljamoextendeda}', "");
Expect(1, 43392, '\p{^Is_Block=hanguljamoextendeda}', "");
Expect(1, 43392, '\P{Is_Block=hanguljamoextendeda}', "");
Expect(0, 43392, '\P{^Is_Block=hanguljamoextendeda}', "");
Expect(1, 43391, '\p{Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(0, 43391, '\p{^Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(0, 43391, '\P{Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(1, 43391, '\P{^Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(0, 43392, '\p{Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(1, 43392, '\p{^Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(1, 43392, '\P{Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Expect(0, 43392, '\P{^Is_Block=__Hangul_Jamo_EXTENDED_A}', "");
Error('\p{Is_Blk=:=	Jamo_Ext_A}');
Error('\P{Is_Blk=:=	Jamo_Ext_A}');
Expect(1, 43391, '\p{Is_Blk=jamoexta}', "");
Expect(0, 43391, '\p{^Is_Blk=jamoexta}', "");
Expect(0, 43391, '\P{Is_Blk=jamoexta}', "");
Expect(1, 43391, '\P{^Is_Blk=jamoexta}', "");
Expect(0, 43392, '\p{Is_Blk=jamoexta}', "");
Expect(1, 43392, '\p{^Is_Blk=jamoexta}', "");
Expect(1, 43392, '\P{Is_Blk=jamoexta}', "");
Expect(0, 43392, '\P{^Is_Blk=jamoexta}', "");
Expect(1, 43391, '\p{Is_Blk=_ jamo_Ext_A}', "");
Expect(0, 43391, '\p{^Is_Blk=_ jamo_Ext_A}', "");
Expect(0, 43391, '\P{Is_Blk=_ jamo_Ext_A}', "");
Expect(1, 43391, '\P{^Is_Blk=_ jamo_Ext_A}', "");
Expect(0, 43392, '\p{Is_Blk=_ jamo_Ext_A}', "");
Expect(1, 43392, '\p{^Is_Blk=_ jamo_Ext_A}', "");
Expect(1, 43392, '\P{Is_Blk=_ jamo_Ext_A}', "");
Expect(0, 43392, '\P{^Is_Blk=_ jamo_Ext_A}', "");
Error('\p{Block=-_Hangul_Jamo_Extended_B/a/}');
Error('\P{Block=-_Hangul_Jamo_Extended_B/a/}');
Expect(1, 55295, '\p{Block:   hanguljamoextendedb}', "");
Expect(0, 55295, '\p{^Block:   hanguljamoextendedb}', "");
Expect(0, 55295, '\P{Block:   hanguljamoextendedb}', "");
Expect(1, 55295, '\P{^Block:   hanguljamoextendedb}', "");
Expect(0, 57344, '\p{Block:   hanguljamoextendedb}', "");
Expect(1, 57344, '\p{^Block:   hanguljamoextendedb}', "");
Expect(1, 57344, '\P{Block:   hanguljamoextendedb}', "");
Expect(0, 57344, '\P{^Block:   hanguljamoextendedb}', "");
Expect(1, 55295, '\p{Block=  HANGUL_Jamo_Extended_b}', "");
Expect(0, 55295, '\p{^Block=  HANGUL_Jamo_Extended_b}', "");
Expect(0, 55295, '\P{Block=  HANGUL_Jamo_Extended_b}', "");
Expect(1, 55295, '\P{^Block=  HANGUL_Jamo_Extended_b}', "");
Expect(0, 57344, '\p{Block=  HANGUL_Jamo_Extended_b}', "");
Expect(1, 57344, '\p{^Block=  HANGUL_Jamo_Extended_b}', "");
Expect(1, 57344, '\P{Block=  HANGUL_Jamo_Extended_b}', "");
Expect(0, 57344, '\P{^Block=  HANGUL_Jamo_Extended_b}', "");
Error('\p{Blk=:=	_jamo_Ext_B}');
Error('\P{Blk=:=	_jamo_Ext_B}');
Expect(1, 55295, '\p{Blk=jamoextb}', "");
Expect(0, 55295, '\p{^Blk=jamoextb}', "");
Expect(0, 55295, '\P{Blk=jamoextb}', "");
Expect(1, 55295, '\P{^Blk=jamoextb}', "");
Expect(0, 57344, '\p{Blk=jamoextb}', "");
Expect(1, 57344, '\p{^Blk=jamoextb}', "");
Expect(1, 57344, '\P{Blk=jamoextb}', "");
Expect(0, 57344, '\P{^Blk=jamoextb}', "");
Expect(1, 55295, '\p{Blk= 	Jamo_Ext_b}', "");
Expect(0, 55295, '\p{^Blk= 	Jamo_Ext_b}', "");
Expect(0, 55295, '\P{Blk= 	Jamo_Ext_b}', "");
Expect(1, 55295, '\P{^Blk= 	Jamo_Ext_b}', "");
Expect(0, 57344, '\p{Blk= 	Jamo_Ext_b}', "");
Expect(1, 57344, '\p{^Blk= 	Jamo_Ext_b}', "");
Expect(1, 57344, '\P{Blk= 	Jamo_Ext_b}', "");
Expect(0, 57344, '\P{^Blk= 	Jamo_Ext_b}', "");
Error('\p{Is_Block=_ HANGUL_jamo_EXTENDED_B/a/}');
Error('\P{Is_Block=_ HANGUL_jamo_EXTENDED_B/a/}');
Expect(1, 55295, '\p{Is_Block=hanguljamoextendedb}', "");
Expect(0, 55295, '\p{^Is_Block=hanguljamoextendedb}', "");
Expect(0, 55295, '\P{Is_Block=hanguljamoextendedb}', "");
Expect(1, 55295, '\P{^Is_Block=hanguljamoextendedb}', "");
Expect(0, 57344, '\p{Is_Block=hanguljamoextendedb}', "");
Expect(1, 57344, '\p{^Is_Block=hanguljamoextendedb}', "");
Expect(1, 57344, '\P{Is_Block=hanguljamoextendedb}', "");
Expect(0, 57344, '\P{^Is_Block=hanguljamoextendedb}', "");
Expect(1, 55295, '\p{Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(0, 55295, '\p{^Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(0, 55295, '\P{Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(1, 55295, '\P{^Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(0, 57344, '\p{Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(1, 57344, '\p{^Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(1, 57344, '\P{Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Expect(0, 57344, '\P{^Is_Block:    -Hangul_Jamo_EXTENDED_b}', "");
Error('\p{Is_Blk=:=jamo_Ext_B}');
Error('\P{Is_Blk=:=jamo_Ext_B}');
Expect(1, 55295, '\p{Is_Blk:	jamoextb}', "");
Expect(0, 55295, '\p{^Is_Blk:	jamoextb}', "");
Expect(0, 55295, '\P{Is_Blk:	jamoextb}', "");
Expect(1, 55295, '\P{^Is_Blk:	jamoextb}', "");
Expect(0, 57344, '\p{Is_Blk:	jamoextb}', "");
Expect(1, 57344, '\p{^Is_Blk:	jamoextb}', "");
Expect(1, 57344, '\P{Is_Blk:	jamoextb}', "");
Expect(0, 57344, '\P{^Is_Blk:	jamoextb}', "");
Expect(1, 55295, '\p{Is_Blk=_Jamo_EXT_B}', "");
Expect(0, 55295, '\p{^Is_Blk=_Jamo_EXT_B}', "");
Expect(0, 55295, '\P{Is_Blk=_Jamo_EXT_B}', "");
Expect(1, 55295, '\P{^Is_Blk=_Jamo_EXT_B}', "");
Expect(0, 57344, '\p{Is_Blk=_Jamo_EXT_B}', "");
Expect(1, 57344, '\p{^Is_Blk=_Jamo_EXT_B}', "");
Expect(1, 57344, '\P{Is_Blk=_Jamo_EXT_B}', "");
Expect(0, 57344, '\P{^Is_Blk=_Jamo_EXT_B}', "");
Error('\p{Block=/a/JAVANESE}');
Error('\P{Block=/a/JAVANESE}');
Expect(1, 43487, '\p{Block=javanese}', "");
Expect(0, 43487, '\p{^Block=javanese}', "");
Expect(0, 43487, '\P{Block=javanese}', "");
Expect(1, 43487, '\P{^Block=javanese}', "");
Expect(0, 43488, '\p{Block=javanese}', "");
Expect(1, 43488, '\p{^Block=javanese}', "");
Expect(1, 43488, '\P{Block=javanese}', "");
Expect(0, 43488, '\P{^Block=javanese}', "");
Expect(1, 43487, '\p{Block=	-javanese}', "");
Expect(0, 43487, '\p{^Block=	-javanese}', "");
Expect(0, 43487, '\P{Block=	-javanese}', "");
Expect(1, 43487, '\P{^Block=	-javanese}', "");
Expect(0, 43488, '\p{Block=	-javanese}', "");
Expect(1, 43488, '\p{^Block=	-javanese}', "");
Expect(1, 43488, '\P{Block=	-javanese}', "");
Expect(0, 43488, '\P{^Block=	-javanese}', "");
Error('\p{Blk=:= JAVANESE}');
Error('\P{Blk=:= JAVANESE}');
Expect(1, 43487, '\p{Blk=javanese}', "");
Expect(0, 43487, '\p{^Blk=javanese}', "");
Expect(0, 43487, '\P{Blk=javanese}', "");
Expect(1, 43487, '\P{^Blk=javanese}', "");
Expect(0, 43488, '\p{Blk=javanese}', "");
Expect(1, 43488, '\p{^Blk=javanese}', "");
Expect(1, 43488, '\P{Blk=javanese}', "");
Expect(0, 43488, '\P{^Blk=javanese}', "");
Expect(1, 43487, '\p{Blk=  Javanese}', "");
Expect(0, 43487, '\p{^Blk=  Javanese}', "");
Expect(0, 43487, '\P{Blk=  Javanese}', "");
Expect(1, 43487, '\P{^Blk=  Javanese}', "");
Expect(0, 43488, '\p{Blk=  Javanese}', "");
Expect(1, 43488, '\p{^Blk=  Javanese}', "");
Expect(1, 43488, '\P{Blk=  Javanese}', "");
Expect(0, 43488, '\P{^Blk=  Javanese}', "");
Error('\p{Is_Block= :=Javanese}');
Error('\P{Is_Block= :=Javanese}');
Expect(1, 43487, '\p{Is_Block=javanese}', "");
Expect(0, 43487, '\p{^Is_Block=javanese}', "");
Expect(0, 43487, '\P{Is_Block=javanese}', "");
Expect(1, 43487, '\P{^Is_Block=javanese}', "");
Expect(0, 43488, '\p{Is_Block=javanese}', "");
Expect(1, 43488, '\p{^Is_Block=javanese}', "");
Expect(1, 43488, '\P{Is_Block=javanese}', "");
Expect(0, 43488, '\P{^Is_Block=javanese}', "");
Expect(1, 43487, '\p{Is_Block=_	JAVANESE}', "");
Expect(0, 43487, '\p{^Is_Block=_	JAVANESE}', "");
Expect(0, 43487, '\P{Is_Block=_	JAVANESE}', "");
Expect(1, 43487, '\P{^Is_Block=_	JAVANESE}', "");
Expect(0, 43488, '\p{Is_Block=_	JAVANESE}', "");
Expect(1, 43488, '\p{^Is_Block=_	JAVANESE}', "");
Expect(1, 43488, '\P{Is_Block=_	JAVANESE}', "");
Expect(0, 43488, '\P{^Is_Block=_	JAVANESE}', "");
Error('\p{Is_Blk:_/a/Javanese}');
Error('\P{Is_Blk:_/a/Javanese}');
Expect(1, 43487, '\p{Is_Blk=javanese}', "");
Expect(0, 43487, '\p{^Is_Blk=javanese}', "");
Expect(0, 43487, '\P{Is_Blk=javanese}', "");
Expect(1, 43487, '\P{^Is_Blk=javanese}', "");
Expect(0, 43488, '\p{Is_Blk=javanese}', "");
Expect(1, 43488, '\p{^Is_Blk=javanese}', "");
Expect(1, 43488, '\P{Is_Blk=javanese}', "");
Expect(0, 43488, '\P{^Is_Blk=javanese}', "");
Expect(1, 43487, '\p{Is_Blk=-	Javanese}', "");
Expect(0, 43487, '\p{^Is_Blk=-	Javanese}', "");
Expect(0, 43487, '\P{Is_Blk=-	Javanese}', "");
Expect(1, 43487, '\P{^Is_Blk=-	Javanese}', "");
Expect(0, 43488, '\p{Is_Blk=-	Javanese}', "");
Expect(1, 43488, '\p{^Is_Blk=-	Javanese}', "");
Expect(1, 43488, '\P{Is_Blk=-	Javanese}', "");
Expect(0, 43488, '\P{^Is_Blk=-	Javanese}', "");
Error('\p{Block= :=kaithi}');
Error('\P{Block= :=kaithi}');
Expect(1, 69839, '\p{Block=kaithi}', "");
Expect(0, 69839, '\p{^Block=kaithi}', "");
Expect(0, 69839, '\P{Block=kaithi}', "");
Expect(1, 69839, '\P{^Block=kaithi}', "");
Expect(0, 69840, '\p{Block=kaithi}', "");
Expect(1, 69840, '\p{^Block=kaithi}', "");
Expect(1, 69840, '\P{Block=kaithi}', "");
Expect(0, 69840, '\P{^Block=kaithi}', "");
Expect(1, 69839, '\p{Block=	Kaithi}', "");
Expect(0, 69839, '\p{^Block=	Kaithi}', "");
Expect(0, 69839, '\P{Block=	Kaithi}', "");
Expect(1, 69839, '\P{^Block=	Kaithi}', "");
Expect(0, 69840, '\p{Block=	Kaithi}', "");
Expect(1, 69840, '\p{^Block=	Kaithi}', "");
Expect(1, 69840, '\P{Block=	Kaithi}', "");
Expect(0, 69840, '\P{^Block=	Kaithi}', "");
Error('\p{Blk: /a/KAITHI}');
Error('\P{Blk: /a/KAITHI}');
Expect(1, 69839, '\p{Blk=kaithi}', "");
Expect(0, 69839, '\p{^Blk=kaithi}', "");
Expect(0, 69839, '\P{Blk=kaithi}', "");
Expect(1, 69839, '\P{^Blk=kaithi}', "");
Expect(0, 69840, '\p{Blk=kaithi}', "");
Expect(1, 69840, '\p{^Blk=kaithi}', "");
Expect(1, 69840, '\P{Blk=kaithi}', "");
Expect(0, 69840, '\P{^Blk=kaithi}', "");
Expect(1, 69839, '\p{Blk: -Kaithi}', "");
Expect(0, 69839, '\p{^Blk: -Kaithi}', "");
Expect(0, 69839, '\P{Blk: -Kaithi}', "");
Expect(1, 69839, '\P{^Blk: -Kaithi}', "");
Expect(0, 69840, '\p{Blk: -Kaithi}', "");
Expect(1, 69840, '\p{^Blk: -Kaithi}', "");
Expect(1, 69840, '\P{Blk: -Kaithi}', "");
Expect(0, 69840, '\P{^Blk: -Kaithi}', "");
Error('\p{Is_Block= kaithi/a/}');
Error('\P{Is_Block= kaithi/a/}');
Expect(1, 69839, '\p{Is_Block=kaithi}', "");
Expect(0, 69839, '\p{^Is_Block=kaithi}', "");
Expect(0, 69839, '\P{Is_Block=kaithi}', "");
Expect(1, 69839, '\P{^Is_Block=kaithi}', "");
Expect(0, 69840, '\p{Is_Block=kaithi}', "");
Expect(1, 69840, '\p{^Is_Block=kaithi}', "");
Expect(1, 69840, '\P{Is_Block=kaithi}', "");
Expect(0, 69840, '\P{^Is_Block=kaithi}', "");
Expect(1, 69839, '\p{Is_Block=-	Kaithi}', "");
Expect(0, 69839, '\p{^Is_Block=-	Kaithi}', "");
Expect(0, 69839, '\P{Is_Block=-	Kaithi}', "");
Expect(1, 69839, '\P{^Is_Block=-	Kaithi}', "");
Expect(0, 69840, '\p{Is_Block=-	Kaithi}', "");
Expect(1, 69840, '\p{^Is_Block=-	Kaithi}', "");
Expect(1, 69840, '\P{Is_Block=-	Kaithi}', "");
Expect(0, 69840, '\P{^Is_Block=-	Kaithi}', "");
Error('\p{Is_Blk=kaithi/a/}');
Error('\P{Is_Blk=kaithi/a/}');
Expect(1, 69839, '\p{Is_Blk=kaithi}', "");
Expect(0, 69839, '\p{^Is_Blk=kaithi}', "");
Expect(0, 69839, '\P{Is_Blk=kaithi}', "");
Expect(1, 69839, '\P{^Is_Blk=kaithi}', "");
Expect(0, 69840, '\p{Is_Blk=kaithi}', "");
Expect(1, 69840, '\p{^Is_Blk=kaithi}', "");
Expect(1, 69840, '\P{Is_Blk=kaithi}', "");
Expect(0, 69840, '\P{^Is_Blk=kaithi}', "");
Expect(1, 69839, '\p{Is_Blk=  Kaithi}', "");
Expect(0, 69839, '\p{^Is_Blk=  Kaithi}', "");
Expect(0, 69839, '\P{Is_Blk=  Kaithi}', "");
Expect(1, 69839, '\P{^Is_Blk=  Kaithi}', "");
Expect(0, 69840, '\p{Is_Blk=  Kaithi}', "");
Expect(1, 69840, '\p{^Is_Blk=  Kaithi}', "");
Expect(1, 69840, '\P{Is_Blk=  Kaithi}', "");
Expect(0, 69840, '\P{^Is_Blk=  Kaithi}', "");
Error('\p{Block= :=Kana_Supplement}');
Error('\P{Block= :=Kana_Supplement}');
Expect(1, 110847, '\p{Block=kanasupplement}', "");
Expect(0, 110847, '\p{^Block=kanasupplement}', "");
Expect(0, 110847, '\P{Block=kanasupplement}', "");
Expect(1, 110847, '\P{^Block=kanasupplement}', "");
Expect(0, 110848, '\p{Block=kanasupplement}', "");
Expect(1, 110848, '\p{^Block=kanasupplement}', "");
Expect(1, 110848, '\P{Block=kanasupplement}', "");
Expect(0, 110848, '\P{^Block=kanasupplement}', "");
Expect(1, 110847, '\p{Block=  kana_Supplement}', "");
Expect(0, 110847, '\p{^Block=  kana_Supplement}', "");
Expect(0, 110847, '\P{Block=  kana_Supplement}', "");
Expect(1, 110847, '\P{^Block=  kana_Supplement}', "");
Expect(0, 110848, '\p{Block=  kana_Supplement}', "");
Expect(1, 110848, '\p{^Block=  kana_Supplement}', "");
Expect(1, 110848, '\P{Block=  kana_Supplement}', "");
Expect(0, 110848, '\P{^Block=  kana_Supplement}', "");
Error('\p{Blk=-/a/KANA_SUP}');
Error('\P{Blk=-/a/KANA_SUP}');
Expect(1, 110847, '\p{Blk=kanasup}', "");
Expect(0, 110847, '\p{^Blk=kanasup}', "");
Expect(0, 110847, '\P{Blk=kanasup}', "");
Expect(1, 110847, '\P{^Blk=kanasup}', "");
Expect(0, 110848, '\p{Blk=kanasup}', "");
Expect(1, 110848, '\p{^Blk=kanasup}', "");
Expect(1, 110848, '\P{Blk=kanasup}', "");
Expect(0, 110848, '\P{^Blk=kanasup}', "");
Expect(1, 110847, '\p{Blk=  kana_SUP}', "");
Expect(0, 110847, '\p{^Blk=  kana_SUP}', "");
Expect(0, 110847, '\P{Blk=  kana_SUP}', "");
Expect(1, 110847, '\P{^Blk=  kana_SUP}', "");
Expect(0, 110848, '\p{Blk=  kana_SUP}', "");
Expect(1, 110848, '\p{^Blk=  kana_SUP}', "");
Expect(1, 110848, '\P{Blk=  kana_SUP}', "");
Expect(0, 110848, '\P{^Blk=  kana_SUP}', "");
Error('\p{Is_Block=:=__KANA_supplement}');
Error('\P{Is_Block=:=__KANA_supplement}');
Expect(1, 110847, '\p{Is_Block=kanasupplement}', "");
Expect(0, 110847, '\p{^Is_Block=kanasupplement}', "");
Expect(0, 110847, '\P{Is_Block=kanasupplement}', "");
Expect(1, 110847, '\P{^Is_Block=kanasupplement}', "");
Expect(0, 110848, '\p{Is_Block=kanasupplement}', "");
Expect(1, 110848, '\p{^Is_Block=kanasupplement}', "");
Expect(1, 110848, '\P{Is_Block=kanasupplement}', "");
Expect(0, 110848, '\P{^Is_Block=kanasupplement}', "");
Expect(1, 110847, '\p{Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\p{^Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\P{Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(1, 110847, '\P{^Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\p{Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\p{^Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\P{Is_Block=	-Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\P{^Is_Block=	-Kana_SUPPLEMENT}', "");
Error('\p{Is_Blk: _:=Kana_Sup}');
Error('\P{Is_Blk: _:=Kana_Sup}');
Expect(1, 110847, '\p{Is_Blk=kanasup}', "");
Expect(0, 110847, '\p{^Is_Blk=kanasup}', "");
Expect(0, 110847, '\P{Is_Blk=kanasup}', "");
Expect(1, 110847, '\P{^Is_Blk=kanasup}', "");
Expect(0, 110848, '\p{Is_Blk=kanasup}', "");
Expect(1, 110848, '\p{^Is_Blk=kanasup}', "");
Expect(1, 110848, '\P{Is_Blk=kanasup}', "");
Expect(0, 110848, '\P{^Is_Blk=kanasup}', "");
Expect(1, 110847, '\p{Is_Blk=		KANA_Sup}', "");
Expect(0, 110847, '\p{^Is_Blk=		KANA_Sup}', "");
Expect(0, 110847, '\P{Is_Blk=		KANA_Sup}', "");
Expect(1, 110847, '\P{^Is_Blk=		KANA_Sup}', "");
Expect(0, 110848, '\p{Is_Blk=		KANA_Sup}', "");
Expect(1, 110848, '\p{^Is_Blk=		KANA_Sup}', "");
Expect(1, 110848, '\P{Is_Blk=		KANA_Sup}', "");
Expect(0, 110848, '\P{^Is_Blk=		KANA_Sup}', "");
Error('\p{Block=:=Kanbun}');
Error('\P{Block=:=Kanbun}');
Expect(1, 12703, '\p{Block=kanbun}', "");
Expect(0, 12703, '\p{^Block=kanbun}', "");
Expect(0, 12703, '\P{Block=kanbun}', "");
Expect(1, 12703, '\P{^Block=kanbun}', "");
Expect(0, 12704, '\p{Block=kanbun}', "");
Expect(1, 12704, '\p{^Block=kanbun}', "");
Expect(1, 12704, '\P{Block=kanbun}', "");
Expect(0, 12704, '\P{^Block=kanbun}', "");
Expect(1, 12703, '\p{Block= _Kanbun}', "");
Expect(0, 12703, '\p{^Block= _Kanbun}', "");
Expect(0, 12703, '\P{Block= _Kanbun}', "");
Expect(1, 12703, '\P{^Block= _Kanbun}', "");
Expect(0, 12704, '\p{Block= _Kanbun}', "");
Expect(1, 12704, '\p{^Block= _Kanbun}', "");
Expect(1, 12704, '\P{Block= _Kanbun}', "");
Expect(0, 12704, '\P{^Block= _Kanbun}', "");
Error('\p{Blk=__KANBUN/a/}');
Error('\P{Blk=__KANBUN/a/}');
Expect(1, 12703, '\p{Blk: kanbun}', "");
Expect(0, 12703, '\p{^Blk: kanbun}', "");
Expect(0, 12703, '\P{Blk: kanbun}', "");
Expect(1, 12703, '\P{^Blk: kanbun}', "");
Expect(0, 12704, '\p{Blk: kanbun}', "");
Expect(1, 12704, '\p{^Blk: kanbun}', "");
Expect(1, 12704, '\P{Blk: kanbun}', "");
Expect(0, 12704, '\P{^Blk: kanbun}', "");
Expect(1, 12703, '\p{Blk= 	kanbun}', "");
Expect(0, 12703, '\p{^Blk= 	kanbun}', "");
Expect(0, 12703, '\P{Blk= 	kanbun}', "");
Expect(1, 12703, '\P{^Blk= 	kanbun}', "");
Expect(0, 12704, '\p{Blk= 	kanbun}', "");
Expect(1, 12704, '\p{^Blk= 	kanbun}', "");
Expect(1, 12704, '\P{Blk= 	kanbun}', "");
Expect(0, 12704, '\P{^Blk= 	kanbun}', "");
Error('\p{Is_Block=--Kanbun/a/}');
Error('\P{Is_Block=--Kanbun/a/}');
Expect(1, 12703, '\p{Is_Block=kanbun}', "");
Expect(0, 12703, '\p{^Is_Block=kanbun}', "");
Expect(0, 12703, '\P{Is_Block=kanbun}', "");
Expect(1, 12703, '\P{^Is_Block=kanbun}', "");
Expect(0, 12704, '\p{Is_Block=kanbun}', "");
Expect(1, 12704, '\p{^Is_Block=kanbun}', "");
Expect(1, 12704, '\P{Is_Block=kanbun}', "");
Expect(0, 12704, '\P{^Is_Block=kanbun}', "");
Expect(1, 12703, '\p{Is_Block=	Kanbun}', "");
Expect(0, 12703, '\p{^Is_Block=	Kanbun}', "");
Expect(0, 12703, '\P{Is_Block=	Kanbun}', "");
Expect(1, 12703, '\P{^Is_Block=	Kanbun}', "");
Expect(0, 12704, '\p{Is_Block=	Kanbun}', "");
Expect(1, 12704, '\p{^Is_Block=	Kanbun}', "");
Expect(1, 12704, '\P{Is_Block=	Kanbun}', "");
Expect(0, 12704, '\P{^Is_Block=	Kanbun}', "");
Error('\p{Is_Blk= 	KANBUN/a/}');
Error('\P{Is_Blk= 	KANBUN/a/}');
Expect(1, 12703, '\p{Is_Blk=kanbun}', "");
Expect(0, 12703, '\p{^Is_Blk=kanbun}', "");
Expect(0, 12703, '\P{Is_Blk=kanbun}', "");
Expect(1, 12703, '\P{^Is_Blk=kanbun}', "");
Expect(0, 12704, '\p{Is_Blk=kanbun}', "");
Expect(1, 12704, '\p{^Is_Blk=kanbun}', "");
Expect(1, 12704, '\P{Is_Blk=kanbun}', "");
Expect(0, 12704, '\P{^Is_Blk=kanbun}', "");
Expect(1, 12703, '\p{Is_Blk=	kanbun}', "");
Expect(0, 12703, '\p{^Is_Blk=	kanbun}', "");
Expect(0, 12703, '\P{Is_Blk=	kanbun}', "");
Expect(1, 12703, '\P{^Is_Blk=	kanbun}', "");
Expect(0, 12704, '\p{Is_Blk=	kanbun}', "");
Expect(1, 12704, '\p{^Is_Blk=	kanbun}', "");
Expect(1, 12704, '\P{Is_Blk=	kanbun}', "");
Expect(0, 12704, '\P{^Is_Blk=	kanbun}', "");
Error('\p{Block::=__kangxi_Radicals}');
Error('\P{Block::=__kangxi_Radicals}');
Expect(1, 12255, '\p{Block=kangxiradicals}', "");
Expect(0, 12255, '\p{^Block=kangxiradicals}', "");
Expect(0, 12255, '\P{Block=kangxiradicals}', "");
Expect(1, 12255, '\P{^Block=kangxiradicals}', "");
Expect(0, 12256, '\p{Block=kangxiradicals}', "");
Expect(1, 12256, '\p{^Block=kangxiradicals}', "");
Expect(1, 12256, '\P{Block=kangxiradicals}', "");
Expect(0, 12256, '\P{^Block=kangxiradicals}', "");
Expect(1, 12255, '\p{Block=  kangxi_radicals}', "");
Expect(0, 12255, '\p{^Block=  kangxi_radicals}', "");
Expect(0, 12255, '\P{Block=  kangxi_radicals}', "");
Expect(1, 12255, '\P{^Block=  kangxi_radicals}', "");
Expect(0, 12256, '\p{Block=  kangxi_radicals}', "");
Expect(1, 12256, '\p{^Block=  kangxi_radicals}', "");
Expect(1, 12256, '\P{Block=  kangxi_radicals}', "");
Expect(0, 12256, '\P{^Block=  kangxi_radicals}', "");
Error('\p{Blk=	_KANGXI:=}');
Error('\P{Blk=	_KANGXI:=}');
Expect(1, 12255, '\p{Blk=kangxi}', "");
Expect(0, 12255, '\p{^Blk=kangxi}', "");
Expect(0, 12255, '\P{Blk=kangxi}', "");
Expect(1, 12255, '\P{^Blk=kangxi}', "");
Expect(0, 12256, '\p{Blk=kangxi}', "");
Expect(1, 12256, '\p{^Blk=kangxi}', "");
Expect(1, 12256, '\P{Blk=kangxi}', "");
Expect(0, 12256, '\P{^Blk=kangxi}', "");
Expect(1, 12255, '\p{Blk=	 Kangxi}', "");
Expect(0, 12255, '\p{^Blk=	 Kangxi}', "");
Expect(0, 12255, '\P{Blk=	 Kangxi}', "");
Expect(1, 12255, '\P{^Blk=	 Kangxi}', "");
Expect(0, 12256, '\p{Blk=	 Kangxi}', "");
Expect(1, 12256, '\p{^Blk=	 Kangxi}', "");
Expect(1, 12256, '\P{Blk=	 Kangxi}', "");
Expect(0, 12256, '\P{^Blk=	 Kangxi}', "");
Error('\p{Is_Block=/a/KANGXI_radicals}');
Error('\P{Is_Block=/a/KANGXI_radicals}');
Expect(1, 12255, '\p{Is_Block=kangxiradicals}', "");
Expect(0, 12255, '\p{^Is_Block=kangxiradicals}', "");
Expect(0, 12255, '\P{Is_Block=kangxiradicals}', "");
Expect(1, 12255, '\P{^Is_Block=kangxiradicals}', "");
Expect(0, 12256, '\p{Is_Block=kangxiradicals}', "");
Expect(1, 12256, '\p{^Is_Block=kangxiradicals}', "");
Expect(1, 12256, '\P{Is_Block=kangxiradicals}', "");
Expect(0, 12256, '\P{^Is_Block=kangxiradicals}', "");
Expect(1, 12255, '\p{Is_Block:   	kangxi_Radicals}', "");
Expect(0, 12255, '\p{^Is_Block:   	kangxi_Radicals}', "");
Expect(0, 12255, '\P{Is_Block:   	kangxi_Radicals}', "");
Expect(1, 12255, '\P{^Is_Block:   	kangxi_Radicals}', "");
Expect(0, 12256, '\p{Is_Block:   	kangxi_Radicals}', "");
Expect(1, 12256, '\p{^Is_Block:   	kangxi_Radicals}', "");
Expect(1, 12256, '\P{Is_Block:   	kangxi_Radicals}', "");
Expect(0, 12256, '\P{^Is_Block:   	kangxi_Radicals}', "");
Error('\p{Is_Blk=		Kangxi/a/}');
Error('\P{Is_Blk=		Kangxi/a/}');
Expect(1, 12255, '\p{Is_Blk=kangxi}', "");
Expect(0, 12255, '\p{^Is_Blk=kangxi}', "");
Expect(0, 12255, '\P{Is_Blk=kangxi}', "");
Expect(1, 12255, '\P{^Is_Blk=kangxi}', "");
Expect(0, 12256, '\p{Is_Blk=kangxi}', "");
Expect(1, 12256, '\p{^Is_Blk=kangxi}', "");
Expect(1, 12256, '\P{Is_Blk=kangxi}', "");
Expect(0, 12256, '\P{^Is_Blk=kangxi}', "");
Expect(1, 12255, '\p{Is_Blk=	 kangxi}', "");
Expect(0, 12255, '\p{^Is_Blk=	 kangxi}', "");
Expect(0, 12255, '\P{Is_Blk=	 kangxi}', "");
Expect(1, 12255, '\P{^Is_Blk=	 kangxi}', "");
Expect(0, 12256, '\p{Is_Blk=	 kangxi}', "");
Expect(1, 12256, '\p{^Is_Blk=	 kangxi}', "");
Expect(1, 12256, '\P{Is_Blk=	 kangxi}', "");
Expect(0, 12256, '\P{^Is_Blk=	 kangxi}', "");
Error('\p{Block: 	 Kannada/a/}');
Error('\P{Block: 	 Kannada/a/}');
Expect(1, 3327, '\p{Block=kannada}', "");
Expect(0, 3327, '\p{^Block=kannada}', "");
Expect(0, 3327, '\P{Block=kannada}', "");
Expect(1, 3327, '\P{^Block=kannada}', "");
Expect(0, 3328, '\p{Block=kannada}', "");
Expect(1, 3328, '\p{^Block=kannada}', "");
Expect(1, 3328, '\P{Block=kannada}', "");
Expect(0, 3328, '\P{^Block=kannada}', "");
Expect(1, 3327, '\p{Block:--Kannada}', "");
Expect(0, 3327, '\p{^Block:--Kannada}', "");
Expect(0, 3327, '\P{Block:--Kannada}', "");
Expect(1, 3327, '\P{^Block:--Kannada}', "");
Expect(0, 3328, '\p{Block:--Kannada}', "");
Expect(1, 3328, '\p{^Block:--Kannada}', "");
Expect(1, 3328, '\P{Block:--Kannada}', "");
Expect(0, 3328, '\P{^Block:--Kannada}', "");
Error('\p{Blk=_kannada:=}');
Error('\P{Blk=_kannada:=}');
Expect(1, 3327, '\p{Blk=kannada}', "");
Expect(0, 3327, '\p{^Blk=kannada}', "");
Expect(0, 3327, '\P{Blk=kannada}', "");
Expect(1, 3327, '\P{^Blk=kannada}', "");
Expect(0, 3328, '\p{Blk=kannada}', "");
Expect(1, 3328, '\p{^Blk=kannada}', "");
Expect(1, 3328, '\P{Blk=kannada}', "");
Expect(0, 3328, '\P{^Blk=kannada}', "");
Expect(1, 3327, '\p{Blk=_-Kannada}', "");
Expect(0, 3327, '\p{^Blk=_-Kannada}', "");
Expect(0, 3327, '\P{Blk=_-Kannada}', "");
Expect(1, 3327, '\P{^Blk=_-Kannada}', "");
Expect(0, 3328, '\p{Blk=_-Kannada}', "");
Expect(1, 3328, '\p{^Blk=_-Kannada}', "");
Expect(1, 3328, '\P{Blk=_-Kannada}', "");
Expect(0, 3328, '\P{^Blk=_-Kannada}', "");
Error('\p{Is_Block=/a/_ KANNADA}');
Error('\P{Is_Block=/a/_ KANNADA}');
Expect(1, 3327, '\p{Is_Block=kannada}', "");
Expect(0, 3327, '\p{^Is_Block=kannada}', "");
Expect(0, 3327, '\P{Is_Block=kannada}', "");
Expect(1, 3327, '\P{^Is_Block=kannada}', "");
Expect(0, 3328, '\p{Is_Block=kannada}', "");
Expect(1, 3328, '\p{^Is_Block=kannada}', "");
Expect(1, 3328, '\P{Is_Block=kannada}', "");
Expect(0, 3328, '\P{^Is_Block=kannada}', "");
Expect(1, 3327, '\p{Is_Block=_Kannada}', "");
Expect(0, 3327, '\p{^Is_Block=_Kannada}', "");
Expect(0, 3327, '\P{Is_Block=_Kannada}', "");
Expect(1, 3327, '\P{^Is_Block=_Kannada}', "");
Expect(0, 3328, '\p{Is_Block=_Kannada}', "");
Expect(1, 3328, '\p{^Is_Block=_Kannada}', "");
Expect(1, 3328, '\P{Is_Block=_Kannada}', "");
Expect(0, 3328, '\P{^Is_Block=_Kannada}', "");
Error('\p{Is_Blk=/a/_-Kannada}');
Error('\P{Is_Blk=/a/_-Kannada}');
Expect(1, 3327, '\p{Is_Blk=kannada}', "");
Expect(0, 3327, '\p{^Is_Blk=kannada}', "");
Expect(0, 3327, '\P{Is_Blk=kannada}', "");
Expect(1, 3327, '\P{^Is_Blk=kannada}', "");
Expect(0, 3328, '\p{Is_Blk=kannada}', "");
Expect(1, 3328, '\p{^Is_Blk=kannada}', "");
Expect(1, 3328, '\P{Is_Blk=kannada}', "");
Expect(0, 3328, '\P{^Is_Blk=kannada}', "");
Expect(1, 3327, '\p{Is_Blk=-kannada}', "");
Expect(0, 3327, '\p{^Is_Blk=-kannada}', "");
Expect(0, 3327, '\P{Is_Blk=-kannada}', "");
Expect(1, 3327, '\P{^Is_Blk=-kannada}', "");
Expect(0, 3328, '\p{Is_Blk=-kannada}', "");
Expect(1, 3328, '\p{^Is_Blk=-kannada}', "");
Expect(1, 3328, '\P{Is_Blk=-kannada}', "");
Expect(0, 3328, '\P{^Is_Blk=-kannada}', "");
Error('\p{Block=-	KATAKANA:=}');
Error('\P{Block=-	KATAKANA:=}');
Expect(1, 12543, '\p{Block=katakana}', "");
Expect(0, 12543, '\p{^Block=katakana}', "");
Expect(0, 12543, '\P{Block=katakana}', "");
Expect(1, 12543, '\P{^Block=katakana}', "");
Expect(0, 12544, '\p{Block=katakana}', "");
Expect(1, 12544, '\p{^Block=katakana}', "");
Expect(1, 12544, '\P{Block=katakana}', "");
Expect(0, 12544, '\P{^Block=katakana}', "");
Expect(1, 12543, '\p{Block=	-katakana}', "");
Expect(0, 12543, '\p{^Block=	-katakana}', "");
Expect(0, 12543, '\P{Block=	-katakana}', "");
Expect(1, 12543, '\P{^Block=	-katakana}', "");
Expect(0, 12544, '\p{Block=	-katakana}', "");
Expect(1, 12544, '\p{^Block=	-katakana}', "");
Expect(1, 12544, '\P{Block=	-katakana}', "");
Expect(0, 12544, '\P{^Block=	-katakana}', "");
Error('\p{Blk= -Katakana:=}');
Error('\P{Blk= -Katakana:=}');
Expect(1, 12543, '\p{Blk=katakana}', "");
Expect(0, 12543, '\p{^Blk=katakana}', "");
Expect(0, 12543, '\P{Blk=katakana}', "");
Expect(1, 12543, '\P{^Blk=katakana}', "");
Expect(0, 12544, '\p{Blk=katakana}', "");
Expect(1, 12544, '\p{^Blk=katakana}', "");
Expect(1, 12544, '\P{Blk=katakana}', "");
Expect(0, 12544, '\P{^Blk=katakana}', "");
Expect(1, 12543, '\p{Blk=		KATAKANA}', "");
Expect(0, 12543, '\p{^Blk=		KATAKANA}', "");
Expect(0, 12543, '\P{Blk=		KATAKANA}', "");
Expect(1, 12543, '\P{^Blk=		KATAKANA}', "");
Expect(0, 12544, '\p{Blk=		KATAKANA}', "");
Expect(1, 12544, '\p{^Blk=		KATAKANA}', "");
Expect(1, 12544, '\P{Blk=		KATAKANA}', "");
Expect(0, 12544, '\P{^Blk=		KATAKANA}', "");
Error('\p{Is_Block=--Katakana/a/}');
Error('\P{Is_Block=--Katakana/a/}');
Expect(1, 12543, '\p{Is_Block=katakana}', "");
Expect(0, 12543, '\p{^Is_Block=katakana}', "");
Expect(0, 12543, '\P{Is_Block=katakana}', "");
Expect(1, 12543, '\P{^Is_Block=katakana}', "");
Expect(0, 12544, '\p{Is_Block=katakana}', "");
Expect(1, 12544, '\p{^Is_Block=katakana}', "");
Expect(1, 12544, '\P{Is_Block=katakana}', "");
Expect(0, 12544, '\P{^Is_Block=katakana}', "");
Expect(1, 12543, '\p{Is_Block=--Katakana}', "");
Expect(0, 12543, '\p{^Is_Block=--Katakana}', "");
Expect(0, 12543, '\P{Is_Block=--Katakana}', "");
Expect(1, 12543, '\P{^Is_Block=--Katakana}', "");
Expect(0, 12544, '\p{Is_Block=--Katakana}', "");
Expect(1, 12544, '\p{^Is_Block=--Katakana}', "");
Expect(1, 12544, '\P{Is_Block=--Katakana}', "");
Expect(0, 12544, '\P{^Is_Block=--Katakana}', "");
Error('\p{Is_Blk=--Katakana:=}');
Error('\P{Is_Blk=--Katakana:=}');
Expect(1, 12543, '\p{Is_Blk=katakana}', "");
Expect(0, 12543, '\p{^Is_Blk=katakana}', "");
Expect(0, 12543, '\P{Is_Blk=katakana}', "");
Expect(1, 12543, '\P{^Is_Blk=katakana}', "");
Expect(0, 12544, '\p{Is_Blk=katakana}', "");
Expect(1, 12544, '\p{^Is_Blk=katakana}', "");
Expect(1, 12544, '\P{Is_Blk=katakana}', "");
Expect(0, 12544, '\P{^Is_Blk=katakana}', "");
Expect(1, 12543, '\p{Is_Blk=_KATAKANA}', "");
Expect(0, 12543, '\p{^Is_Blk=_KATAKANA}', "");
Expect(0, 12543, '\P{Is_Blk=_KATAKANA}', "");
Expect(1, 12543, '\P{^Is_Blk=_KATAKANA}', "");
Expect(0, 12544, '\p{Is_Blk=_KATAKANA}', "");
Expect(1, 12544, '\p{^Is_Blk=_KATAKANA}', "");
Expect(1, 12544, '\P{Is_Blk=_KATAKANA}', "");
Expect(0, 12544, '\P{^Is_Blk=_KATAKANA}', "");
Error('\p{Block=_/a/katakana_Phonetic_Extensions}');
Error('\P{Block=_/a/katakana_Phonetic_Extensions}');
Expect(1, 12799, '\p{Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\P{Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\p{Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\P{Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\p{Block=katakana_phonetic_Extensions}', "");
Expect(0, 12799, '\p{^Block=katakana_phonetic_Extensions}', "");
Expect(0, 12799, '\P{Block=katakana_phonetic_Extensions}', "");
Expect(1, 12799, '\P{^Block=katakana_phonetic_Extensions}', "");
Expect(0, 12800, '\p{Block=katakana_phonetic_Extensions}', "");
Expect(1, 12800, '\p{^Block=katakana_phonetic_Extensions}', "");
Expect(1, 12800, '\P{Block=katakana_phonetic_Extensions}', "");
Expect(0, 12800, '\P{^Block=katakana_phonetic_Extensions}', "");
Error('\p{Blk=/a/-	KATAKANA_Ext}');
Error('\P{Blk=/a/-	KATAKANA_Ext}');
Expect(1, 12799, '\p{Blk=katakanaext}', "");
Expect(0, 12799, '\p{^Blk=katakanaext}', "");
Expect(0, 12799, '\P{Blk=katakanaext}', "");
Expect(1, 12799, '\P{^Blk=katakanaext}', "");
Expect(0, 12800, '\p{Blk=katakanaext}', "");
Expect(1, 12800, '\p{^Blk=katakanaext}', "");
Expect(1, 12800, '\P{Blk=katakanaext}', "");
Expect(0, 12800, '\P{^Blk=katakanaext}', "");
Expect(1, 12799, '\p{Blk:   -Katakana_EXT}', "");
Expect(0, 12799, '\p{^Blk:   -Katakana_EXT}', "");
Expect(0, 12799, '\P{Blk:   -Katakana_EXT}', "");
Expect(1, 12799, '\P{^Blk:   -Katakana_EXT}', "");
Expect(0, 12800, '\p{Blk:   -Katakana_EXT}', "");
Expect(1, 12800, '\p{^Blk:   -Katakana_EXT}', "");
Expect(1, 12800, '\P{Blk:   -Katakana_EXT}', "");
Expect(0, 12800, '\P{^Blk:   -Katakana_EXT}', "");
Error('\p{Is_Block= /a/Katakana_PHONETIC_extensions}');
Error('\P{Is_Block= /a/Katakana_PHONETIC_extensions}');
Expect(1, 12799, '\p{Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12799, '\P{Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\p{Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12800, '\P{Is_Block=katakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^Is_Block=katakanaphoneticextensions}', "");
Expect(1, 12799, '\p{Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(0, 12799, '\p{^Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(0, 12799, '\P{Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(1, 12799, '\P{^Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(0, 12800, '\p{Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(1, 12800, '\p{^Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(1, 12800, '\P{Is_Block=	 Katakana_Phonetic_Extensions}', "");
Expect(0, 12800, '\P{^Is_Block=	 Katakana_Phonetic_Extensions}', "");
Error('\p{Is_Blk= -KATAKANA_Ext:=}');
Error('\P{Is_Blk= -KATAKANA_Ext:=}');
Expect(1, 12799, '\p{Is_Blk:   katakanaext}', "");
Expect(0, 12799, '\p{^Is_Blk:   katakanaext}', "");
Expect(0, 12799, '\P{Is_Blk:   katakanaext}', "");
Expect(1, 12799, '\P{^Is_Blk:   katakanaext}', "");
Expect(0, 12800, '\p{Is_Blk:   katakanaext}', "");
Expect(1, 12800, '\p{^Is_Blk:   katakanaext}', "");
Expect(1, 12800, '\P{Is_Blk:   katakanaext}', "");
Expect(0, 12800, '\P{^Is_Blk:   katakanaext}', "");
Expect(1, 12799, '\p{Is_Blk=  KATAKANA_Ext}', "");
Expect(0, 12799, '\p{^Is_Blk=  KATAKANA_Ext}', "");
Expect(0, 12799, '\P{Is_Blk=  KATAKANA_Ext}', "");
Expect(1, 12799, '\P{^Is_Blk=  KATAKANA_Ext}', "");
Expect(0, 12800, '\p{Is_Blk=  KATAKANA_Ext}', "");
Expect(1, 12800, '\p{^Is_Blk=  KATAKANA_Ext}', "");
Expect(1, 12800, '\P{Is_Blk=  KATAKANA_Ext}', "");
Expect(0, 12800, '\P{^Is_Blk=  KATAKANA_Ext}', "");
Error('\p{Block=	Kayah_li:=}');
Error('\P{Block=	Kayah_li:=}');
Expect(1, 43311, '\p{Block=kayahli}', "");
Expect(0, 43311, '\p{^Block=kayahli}', "");
Expect(0, 43311, '\P{Block=kayahli}', "");
Expect(1, 43311, '\P{^Block=kayahli}', "");
Expect(0, 43312, '\p{Block=kayahli}', "");
Expect(1, 43312, '\p{^Block=kayahli}', "");
Expect(1, 43312, '\P{Block=kayahli}', "");
Expect(0, 43312, '\P{^Block=kayahli}', "");
Expect(1, 43311, '\p{Block= Kayah_Li}', "");
Expect(0, 43311, '\p{^Block= Kayah_Li}', "");
Expect(0, 43311, '\P{Block= Kayah_Li}', "");
Expect(1, 43311, '\P{^Block= Kayah_Li}', "");
Expect(0, 43312, '\p{Block= Kayah_Li}', "");
Expect(1, 43312, '\p{^Block= Kayah_Li}', "");
Expect(1, 43312, '\P{Block= Kayah_Li}', "");
Expect(0, 43312, '\P{^Block= Kayah_Li}', "");
Error('\p{Blk=	/a/kayah_Li}');
Error('\P{Blk=	/a/kayah_Li}');
Expect(1, 43311, '\p{Blk: kayahli}', "");
Expect(0, 43311, '\p{^Blk: kayahli}', "");
Expect(0, 43311, '\P{Blk: kayahli}', "");
Expect(1, 43311, '\P{^Blk: kayahli}', "");
Expect(0, 43312, '\p{Blk: kayahli}', "");
Expect(1, 43312, '\p{^Blk: kayahli}', "");
Expect(1, 43312, '\P{Blk: kayahli}', "");
Expect(0, 43312, '\P{^Blk: kayahli}', "");
Expect(1, 43311, '\p{Blk=_-Kayah_LI}', "");
Expect(0, 43311, '\p{^Blk=_-Kayah_LI}', "");
Expect(0, 43311, '\P{Blk=_-Kayah_LI}', "");
Expect(1, 43311, '\P{^Blk=_-Kayah_LI}', "");
Expect(0, 43312, '\p{Blk=_-Kayah_LI}', "");
Expect(1, 43312, '\p{^Blk=_-Kayah_LI}', "");
Expect(1, 43312, '\P{Blk=_-Kayah_LI}', "");
Expect(0, 43312, '\P{^Blk=_-Kayah_LI}', "");
Error('\p{Is_Block=_-Kayah_li/a/}');
Error('\P{Is_Block=_-Kayah_li/a/}');
Expect(1, 43311, '\p{Is_Block=kayahli}', "");
Expect(0, 43311, '\p{^Is_Block=kayahli}', "");
Expect(0, 43311, '\P{Is_Block=kayahli}', "");
Expect(1, 43311, '\P{^Is_Block=kayahli}', "");
Expect(0, 43312, '\p{Is_Block=kayahli}', "");
Expect(1, 43312, '\p{^Is_Block=kayahli}', "");
Expect(1, 43312, '\P{Is_Block=kayahli}', "");
Expect(0, 43312, '\P{^Is_Block=kayahli}', "");
Expect(1, 43311, '\p{Is_Block=_KAYAH_li}', "");
Expect(0, 43311, '\p{^Is_Block=_KAYAH_li}', "");
Expect(0, 43311, '\P{Is_Block=_KAYAH_li}', "");
Expect(1, 43311, '\P{^Is_Block=_KAYAH_li}', "");
Expect(0, 43312, '\p{Is_Block=_KAYAH_li}', "");
Expect(1, 43312, '\p{^Is_Block=_KAYAH_li}', "");
Expect(1, 43312, '\P{Is_Block=_KAYAH_li}', "");
Expect(0, 43312, '\P{^Is_Block=_KAYAH_li}', "");
Error('\p{Is_Blk=:=	-KAYAH_Li}');
Error('\P{Is_Blk=:=	-KAYAH_Li}');
Expect(1, 43311, '\p{Is_Blk=kayahli}', "");
Expect(0, 43311, '\p{^Is_Blk=kayahli}', "");
Expect(0, 43311, '\P{Is_Blk=kayahli}', "");
Expect(1, 43311, '\P{^Is_Blk=kayahli}', "");
Expect(0, 43312, '\p{Is_Blk=kayahli}', "");
Expect(1, 43312, '\p{^Is_Blk=kayahli}', "");
Expect(1, 43312, '\P{Is_Blk=kayahli}', "");
Expect(0, 43312, '\P{^Is_Blk=kayahli}', "");
Expect(1, 43311, '\p{Is_Blk= _Kayah_Li}', "");
Expect(0, 43311, '\p{^Is_Blk= _Kayah_Li}', "");
Expect(0, 43311, '\P{Is_Blk= _Kayah_Li}', "");
Expect(1, 43311, '\P{^Is_Blk= _Kayah_Li}', "");
Expect(0, 43312, '\p{Is_Blk= _Kayah_Li}', "");
Expect(1, 43312, '\p{^Is_Blk= _Kayah_Li}', "");
Expect(1, 43312, '\P{Is_Blk= _Kayah_Li}', "");
Expect(0, 43312, '\P{^Is_Blk= _Kayah_Li}', "");
Error('\p{Block=- KHAROSHTHI:=}');
Error('\P{Block=- KHAROSHTHI:=}');
Expect(1, 68191, '\p{Block=kharoshthi}', "");
Expect(0, 68191, '\p{^Block=kharoshthi}', "");
Expect(0, 68191, '\P{Block=kharoshthi}', "");
Expect(1, 68191, '\P{^Block=kharoshthi}', "");
Expect(0, 68192, '\p{Block=kharoshthi}', "");
Expect(1, 68192, '\p{^Block=kharoshthi}', "");
Expect(1, 68192, '\P{Block=kharoshthi}', "");
Expect(0, 68192, '\P{^Block=kharoshthi}', "");
Expect(1, 68191, '\p{Block= Kharoshthi}', "");
Expect(0, 68191, '\p{^Block= Kharoshthi}', "");
Expect(0, 68191, '\P{Block= Kharoshthi}', "");
Expect(1, 68191, '\P{^Block= Kharoshthi}', "");
Expect(0, 68192, '\p{Block= Kharoshthi}', "");
Expect(1, 68192, '\p{^Block= Kharoshthi}', "");
Expect(1, 68192, '\P{Block= Kharoshthi}', "");
Expect(0, 68192, '\P{^Block= Kharoshthi}', "");
Error('\p{Blk=/a/Kharoshthi}');
Error('\P{Blk=/a/Kharoshthi}');
Expect(1, 68191, '\p{Blk:   kharoshthi}', "");
Expect(0, 68191, '\p{^Blk:   kharoshthi}', "");
Expect(0, 68191, '\P{Blk:   kharoshthi}', "");
Expect(1, 68191, '\P{^Blk:   kharoshthi}', "");
Expect(0, 68192, '\p{Blk:   kharoshthi}', "");
Expect(1, 68192, '\p{^Blk:   kharoshthi}', "");
Expect(1, 68192, '\P{Blk:   kharoshthi}', "");
Expect(0, 68192, '\P{^Blk:   kharoshthi}', "");
Expect(1, 68191, '\p{Blk=- kharoshthi}', "");
Expect(0, 68191, '\p{^Blk=- kharoshthi}', "");
Expect(0, 68191, '\P{Blk=- kharoshthi}', "");
Expect(1, 68191, '\P{^Blk=- kharoshthi}', "");
Expect(0, 68192, '\p{Blk=- kharoshthi}', "");
Expect(1, 68192, '\p{^Blk=- kharoshthi}', "");
Expect(1, 68192, '\P{Blk=- kharoshthi}', "");
Expect(0, 68192, '\P{^Blk=- kharoshthi}', "");
Error('\p{Is_Block=-	KHAROSHTHI:=}');
Error('\P{Is_Block=-	KHAROSHTHI:=}');
Expect(1, 68191, '\p{Is_Block=kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Block=kharoshthi}', "");
Expect(0, 68191, '\P{Is_Block=kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Block=kharoshthi}', "");
Expect(0, 68192, '\p{Is_Block=kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Block=kharoshthi}', "");
Expect(1, 68192, '\P{Is_Block=kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Block=kharoshthi}', "");
Expect(1, 68191, '\p{Is_Block=-kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Block=-kharoshthi}', "");
Expect(0, 68191, '\P{Is_Block=-kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Block=-kharoshthi}', "");
Expect(0, 68192, '\p{Is_Block=-kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Block=-kharoshthi}', "");
Expect(1, 68192, '\P{Is_Block=-kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Block=-kharoshthi}', "");
Error('\p{Is_Blk=	/a/Kharoshthi}');
Error('\P{Is_Blk=	/a/Kharoshthi}');
Expect(1, 68191, '\p{Is_Blk=kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Blk=kharoshthi}', "");
Expect(0, 68191, '\P{Is_Blk=kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Blk=kharoshthi}', "");
Expect(0, 68192, '\p{Is_Blk=kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Blk=kharoshthi}', "");
Expect(1, 68192, '\P{Is_Blk=kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Blk=kharoshthi}', "");
Expect(1, 68191, '\p{Is_Blk=-kharoshthi}', "");
Expect(0, 68191, '\p{^Is_Blk=-kharoshthi}', "");
Expect(0, 68191, '\P{Is_Blk=-kharoshthi}', "");
Expect(1, 68191, '\P{^Is_Blk=-kharoshthi}', "");
Expect(0, 68192, '\p{Is_Blk=-kharoshthi}', "");
Expect(1, 68192, '\p{^Is_Blk=-kharoshthi}', "");
Expect(1, 68192, '\P{Is_Blk=-kharoshthi}', "");
Expect(0, 68192, '\P{^Is_Blk=-kharoshthi}', "");
Error('\p{Block=:= -khmer}');
Error('\P{Block=:= -khmer}');
Expect(1, 6143, '\p{Block=khmer}', "");
Expect(0, 6143, '\p{^Block=khmer}', "");
Expect(0, 6143, '\P{Block=khmer}', "");
Expect(1, 6143, '\P{^Block=khmer}', "");
Expect(0, 6144, '\p{Block=khmer}', "");
Expect(1, 6144, '\p{^Block=khmer}', "");
Expect(1, 6144, '\P{Block=khmer}', "");
Expect(0, 6144, '\P{^Block=khmer}', "");
Expect(1, 6143, '\p{Block=--KHMER}', "");
Expect(0, 6143, '\p{^Block=--KHMER}', "");
Expect(0, 6143, '\P{Block=--KHMER}', "");
Expect(1, 6143, '\P{^Block=--KHMER}', "");
Expect(0, 6144, '\p{Block=--KHMER}', "");
Expect(1, 6144, '\p{^Block=--KHMER}', "");
Expect(1, 6144, '\P{Block=--KHMER}', "");
Expect(0, 6144, '\P{^Block=--KHMER}', "");
Error('\p{Blk=	Khmer:=}');
Error('\P{Blk=	Khmer:=}');
Expect(1, 6143, '\p{Blk=khmer}', "");
Expect(0, 6143, '\p{^Blk=khmer}', "");
Expect(0, 6143, '\P{Blk=khmer}', "");
Expect(1, 6143, '\P{^Blk=khmer}', "");
Expect(0, 6144, '\p{Blk=khmer}', "");
Expect(1, 6144, '\p{^Blk=khmer}', "");
Expect(1, 6144, '\P{Blk=khmer}', "");
Expect(0, 6144, '\P{^Blk=khmer}', "");
Expect(1, 6143, '\p{Blk= khmer}', "");
Expect(0, 6143, '\p{^Blk= khmer}', "");
Expect(0, 6143, '\P{Blk= khmer}', "");
Expect(1, 6143, '\P{^Blk= khmer}', "");
Expect(0, 6144, '\p{Blk= khmer}', "");
Expect(1, 6144, '\p{^Blk= khmer}', "");
Expect(1, 6144, '\P{Blk= khmer}', "");
Expect(0, 6144, '\P{^Blk= khmer}', "");
Error('\p{Is_Block= :=Khmer}');
Error('\P{Is_Block= :=Khmer}');
Expect(1, 6143, '\p{Is_Block:khmer}', "");
Expect(0, 6143, '\p{^Is_Block:khmer}', "");
Expect(0, 6143, '\P{Is_Block:khmer}', "");
Expect(1, 6143, '\P{^Is_Block:khmer}', "");
Expect(0, 6144, '\p{Is_Block:khmer}', "");
Expect(1, 6144, '\p{^Is_Block:khmer}', "");
Expect(1, 6144, '\P{Is_Block:khmer}', "");
Expect(0, 6144, '\P{^Is_Block:khmer}', "");
Expect(1, 6143, '\p{Is_Block=	_khmer}', "");
Expect(0, 6143, '\p{^Is_Block=	_khmer}', "");
Expect(0, 6143, '\P{Is_Block=	_khmer}', "");
Expect(1, 6143, '\P{^Is_Block=	_khmer}', "");
Expect(0, 6144, '\p{Is_Block=	_khmer}', "");
Expect(1, 6144, '\p{^Is_Block=	_khmer}', "");
Expect(1, 6144, '\P{Is_Block=	_khmer}', "");
Expect(0, 6144, '\P{^Is_Block=	_khmer}', "");
Error('\p{Is_Blk=__Khmer:=}');
Error('\P{Is_Blk=__Khmer:=}');
Expect(1, 6143, '\p{Is_Blk=khmer}', "");
Expect(0, 6143, '\p{^Is_Blk=khmer}', "");
Expect(0, 6143, '\P{Is_Blk=khmer}', "");
Expect(1, 6143, '\P{^Is_Blk=khmer}', "");
Expect(0, 6144, '\p{Is_Blk=khmer}', "");
Expect(1, 6144, '\p{^Is_Blk=khmer}', "");
Expect(1, 6144, '\P{Is_Blk=khmer}', "");
Expect(0, 6144, '\P{^Is_Blk=khmer}', "");
Expect(1, 6143, '\p{Is_Blk=		Khmer}', "");
Expect(0, 6143, '\p{^Is_Blk=		Khmer}', "");
Expect(0, 6143, '\P{Is_Blk=		Khmer}', "");
Expect(1, 6143, '\P{^Is_Blk=		Khmer}', "");
Expect(0, 6144, '\p{Is_Blk=		Khmer}', "");
Expect(1, 6144, '\p{^Is_Blk=		Khmer}', "");
Expect(1, 6144, '\P{Is_Blk=		Khmer}', "");
Expect(0, 6144, '\P{^Is_Blk=		Khmer}', "");
Error('\p{Block:/a/_	khmer_Symbols}');
Error('\P{Block:/a/_	khmer_Symbols}');
Expect(1, 6655, '\p{Block:   khmersymbols}', "");
Expect(0, 6655, '\p{^Block:   khmersymbols}', "");
Expect(0, 6655, '\P{Block:   khmersymbols}', "");
Expect(1, 6655, '\P{^Block:   khmersymbols}', "");
Expect(0, 6656, '\p{Block:   khmersymbols}', "");
Expect(1, 6656, '\p{^Block:   khmersymbols}', "");
Expect(1, 6656, '\P{Block:   khmersymbols}', "");
Expect(0, 6656, '\P{^Block:   khmersymbols}', "");
Expect(1, 6655, '\p{Block= Khmer_SYMBOLS}', "");
Expect(0, 6655, '\p{^Block= Khmer_SYMBOLS}', "");
Expect(0, 6655, '\P{Block= Khmer_SYMBOLS}', "");
Expect(1, 6655, '\P{^Block= Khmer_SYMBOLS}', "");
Expect(0, 6656, '\p{Block= Khmer_SYMBOLS}', "");
Expect(1, 6656, '\p{^Block= Khmer_SYMBOLS}', "");
Expect(1, 6656, '\P{Block= Khmer_SYMBOLS}', "");
Expect(0, 6656, '\P{^Block= Khmer_SYMBOLS}', "");
Error('\p{Blk=/a/KHMER_Symbols}');
Error('\P{Blk=/a/KHMER_Symbols}');
Expect(1, 6655, '\p{Blk=khmersymbols}', "");
Expect(0, 6655, '\p{^Blk=khmersymbols}', "");
Expect(0, 6655, '\P{Blk=khmersymbols}', "");
Expect(1, 6655, '\P{^Blk=khmersymbols}', "");
Expect(0, 6656, '\p{Blk=khmersymbols}', "");
Expect(1, 6656, '\p{^Blk=khmersymbols}', "");
Expect(1, 6656, '\P{Blk=khmersymbols}', "");
Expect(0, 6656, '\P{^Blk=khmersymbols}', "");
Expect(1, 6655, '\p{Blk=_Khmer_SYMBOLS}', "");
Expect(0, 6655, '\p{^Blk=_Khmer_SYMBOLS}', "");
Expect(0, 6655, '\P{Blk=_Khmer_SYMBOLS}', "");
Expect(1, 6655, '\P{^Blk=_Khmer_SYMBOLS}', "");
Expect(0, 6656, '\p{Blk=_Khmer_SYMBOLS}', "");
Expect(1, 6656, '\p{^Blk=_Khmer_SYMBOLS}', "");
Expect(1, 6656, '\P{Blk=_Khmer_SYMBOLS}', "");
Expect(0, 6656, '\P{^Blk=_Khmer_SYMBOLS}', "");
Error('\p{Is_Block:   _/a/KHMER_Symbols}');
Error('\P{Is_Block:   _/a/KHMER_Symbols}');
Expect(1, 6655, '\p{Is_Block=khmersymbols}', "");
Expect(0, 6655, '\p{^Is_Block=khmersymbols}', "");
Expect(0, 6655, '\P{Is_Block=khmersymbols}', "");
Expect(1, 6655, '\P{^Is_Block=khmersymbols}', "");
Expect(0, 6656, '\p{Is_Block=khmersymbols}', "");
Expect(1, 6656, '\p{^Is_Block=khmersymbols}', "");
Expect(1, 6656, '\P{Is_Block=khmersymbols}', "");
Expect(0, 6656, '\P{^Is_Block=khmersymbols}', "");
Expect(1, 6655, '\p{Is_Block= Khmer_SYMBOLS}', "");
Expect(0, 6655, '\p{^Is_Block= Khmer_SYMBOLS}', "");
Expect(0, 6655, '\P{Is_Block= Khmer_SYMBOLS}', "");
Expect(1, 6655, '\P{^Is_Block= Khmer_SYMBOLS}', "");
Expect(0, 6656, '\p{Is_Block= Khmer_SYMBOLS}', "");
Expect(1, 6656, '\p{^Is_Block= Khmer_SYMBOLS}', "");
Expect(1, 6656, '\P{Is_Block= Khmer_SYMBOLS}', "");
Expect(0, 6656, '\P{^Is_Block= Khmer_SYMBOLS}', "");
Error('\p{Is_Blk=	-Khmer_symbols:=}');
Error('\P{Is_Blk=	-Khmer_symbols:=}');
Expect(1, 6655, '\p{Is_Blk=khmersymbols}', "");
Expect(0, 6655, '\p{^Is_Blk=khmersymbols}', "");
Expect(0, 6655, '\P{Is_Blk=khmersymbols}', "");
Expect(1, 6655, '\P{^Is_Blk=khmersymbols}', "");
Expect(0, 6656, '\p{Is_Blk=khmersymbols}', "");
Expect(1, 6656, '\p{^Is_Blk=khmersymbols}', "");
Expect(1, 6656, '\P{Is_Blk=khmersymbols}', "");
Expect(0, 6656, '\P{^Is_Blk=khmersymbols}', "");
Expect(1, 6655, '\p{Is_Blk=__KHMER_SYMBOLS}', "");
Expect(0, 6655, '\p{^Is_Blk=__KHMER_SYMBOLS}', "");
Expect(0, 6655, '\P{Is_Blk=__KHMER_SYMBOLS}', "");
Expect(1, 6655, '\P{^Is_Blk=__KHMER_SYMBOLS}', "");
Expect(0, 6656, '\p{Is_Blk=__KHMER_SYMBOLS}', "");
Expect(1, 6656, '\p{^Is_Blk=__KHMER_SYMBOLS}', "");
Expect(1, 6656, '\P{Is_Blk=__KHMER_SYMBOLS}', "");
Expect(0, 6656, '\P{^Is_Blk=__KHMER_SYMBOLS}', "");
Error('\p{Block=/a/	-Lao}');
Error('\P{Block=/a/	-Lao}');
Expect(1, 3839, '\p{Block=lao}', "");
Expect(0, 3839, '\p{^Block=lao}', "");
Expect(0, 3839, '\P{Block=lao}', "");
Expect(1, 3839, '\P{^Block=lao}', "");
Expect(0, 3840, '\p{Block=lao}', "");
Expect(1, 3840, '\p{^Block=lao}', "");
Expect(1, 3840, '\P{Block=lao}', "");
Expect(0, 3840, '\P{^Block=lao}', "");
Expect(1, 3839, '\p{Block=- Lao}', "");
Expect(0, 3839, '\p{^Block=- Lao}', "");
Expect(0, 3839, '\P{Block=- Lao}', "");
Expect(1, 3839, '\P{^Block=- Lao}', "");
Expect(0, 3840, '\p{Block=- Lao}', "");
Expect(1, 3840, '\p{^Block=- Lao}', "");
Expect(1, 3840, '\P{Block=- Lao}', "");
Expect(0, 3840, '\P{^Block=- Lao}', "");
Error('\p{Blk=--lao:=}');
Error('\P{Blk=--lao:=}');
Expect(1, 3839, '\p{Blk: lao}', "");
Expect(0, 3839, '\p{^Blk: lao}', "");
Expect(0, 3839, '\P{Blk: lao}', "");
Expect(1, 3839, '\P{^Blk: lao}', "");
Expect(0, 3840, '\p{Blk: lao}', "");
Expect(1, 3840, '\p{^Blk: lao}', "");
Expect(1, 3840, '\P{Blk: lao}', "");
Expect(0, 3840, '\P{^Blk: lao}', "");
Expect(1, 3839, '\p{Blk=	_Lao}', "");
Expect(0, 3839, '\p{^Blk=	_Lao}', "");
Expect(0, 3839, '\P{Blk=	_Lao}', "");
Expect(1, 3839, '\P{^Blk=	_Lao}', "");
Expect(0, 3840, '\p{Blk=	_Lao}', "");
Expect(1, 3840, '\p{^Blk=	_Lao}', "");
Expect(1, 3840, '\P{Blk=	_Lao}', "");
Expect(0, 3840, '\P{^Blk=	_Lao}', "");
Error('\p{Is_Block=/a/- LAO}');
Error('\P{Is_Block=/a/- LAO}');
Expect(1, 3839, '\p{Is_Block=lao}', "");
Expect(0, 3839, '\p{^Is_Block=lao}', "");
Expect(0, 3839, '\P{Is_Block=lao}', "");
Expect(1, 3839, '\P{^Is_Block=lao}', "");
Expect(0, 3840, '\p{Is_Block=lao}', "");
Expect(1, 3840, '\p{^Is_Block=lao}', "");
Expect(1, 3840, '\P{Is_Block=lao}', "");
Expect(0, 3840, '\P{^Is_Block=lao}', "");
Expect(1, 3839, '\p{Is_Block=	_Lao}', "");
Expect(0, 3839, '\p{^Is_Block=	_Lao}', "");
Expect(0, 3839, '\P{Is_Block=	_Lao}', "");
Expect(1, 3839, '\P{^Is_Block=	_Lao}', "");
Expect(0, 3840, '\p{Is_Block=	_Lao}', "");
Expect(1, 3840, '\p{^Is_Block=	_Lao}', "");
Expect(1, 3840, '\P{Is_Block=	_Lao}', "");
Expect(0, 3840, '\P{^Is_Block=	_Lao}', "");
Error('\p{Is_Blk=	 LAO/a/}');
Error('\P{Is_Blk=	 LAO/a/}');
Expect(1, 3839, '\p{Is_Blk=lao}', "");
Expect(0, 3839, '\p{^Is_Blk=lao}', "");
Expect(0, 3839, '\P{Is_Blk=lao}', "");
Expect(1, 3839, '\P{^Is_Blk=lao}', "");
Expect(0, 3840, '\p{Is_Blk=lao}', "");
Expect(1, 3840, '\p{^Is_Blk=lao}', "");
Expect(1, 3840, '\P{Is_Blk=lao}', "");
Expect(0, 3840, '\P{^Is_Blk=lao}', "");
Expect(1, 3839, '\p{Is_Blk=_	LAO}', "");
Expect(0, 3839, '\p{^Is_Blk=_	LAO}', "");
Expect(0, 3839, '\P{Is_Blk=_	LAO}', "");
Expect(1, 3839, '\P{^Is_Blk=_	LAO}', "");
Expect(0, 3840, '\p{Is_Blk=_	LAO}', "");
Expect(1, 3840, '\p{^Is_Blk=_	LAO}', "");
Expect(1, 3840, '\P{Is_Blk=_	LAO}', "");
Expect(0, 3840, '\P{^Is_Blk=_	LAO}', "");
Error('\p{Block= /a/latin_1_Supplement}');
Error('\P{Block= /a/latin_1_Supplement}');
Expect(1, 255, '\p{Block=latin1supplement}', "");
Expect(0, 255, '\p{^Block=latin1supplement}', "");
Expect(0, 255, '\P{Block=latin1supplement}', "");
Expect(1, 255, '\P{^Block=latin1supplement}', "");
Expect(0, 256, '\p{Block=latin1supplement}', "");
Expect(1, 256, '\p{^Block=latin1supplement}', "");
Expect(1, 256, '\P{Block=latin1supplement}', "");
Expect(0, 256, '\P{^Block=latin1supplement}', "");
Expect(1, 255, '\p{Block=-LATIN_1_SUPPLEMENT}', "");
Expect(0, 255, '\p{^Block=-LATIN_1_SUPPLEMENT}', "");
Expect(0, 255, '\P{Block=-LATIN_1_SUPPLEMENT}', "");
Expect(1, 255, '\P{^Block=-LATIN_1_SUPPLEMENT}', "");
Expect(0, 256, '\p{Block=-LATIN_1_SUPPLEMENT}', "");
Expect(1, 256, '\p{^Block=-LATIN_1_SUPPLEMENT}', "");
Expect(1, 256, '\P{Block=-LATIN_1_SUPPLEMENT}', "");
Expect(0, 256, '\P{^Block=-LATIN_1_SUPPLEMENT}', "");
Error('\p{Blk=/a/		latin_1_sup}');
Error('\P{Blk=/a/		latin_1_sup}');
Expect(1, 255, '\p{Blk=latin1sup}', "");
Expect(0, 255, '\p{^Blk=latin1sup}', "");
Expect(0, 255, '\P{Blk=latin1sup}', "");
Expect(1, 255, '\P{^Blk=latin1sup}', "");
Expect(0, 256, '\p{Blk=latin1sup}', "");
Expect(1, 256, '\p{^Blk=latin1sup}', "");
Expect(1, 256, '\P{Blk=latin1sup}', "");
Expect(0, 256, '\P{^Blk=latin1sup}', "");
Expect(1, 255, '\p{Blk= _latin_1_Sup}', "");
Expect(0, 255, '\p{^Blk= _latin_1_Sup}', "");
Expect(0, 255, '\P{Blk= _latin_1_Sup}', "");
Expect(1, 255, '\P{^Blk= _latin_1_Sup}', "");
Expect(0, 256, '\p{Blk= _latin_1_Sup}', "");
Expect(1, 256, '\p{^Blk= _latin_1_Sup}', "");
Expect(1, 256, '\P{Blk= _latin_1_Sup}', "");
Expect(0, 256, '\P{^Blk= _latin_1_Sup}', "");
Error('\p{Is_Block: latin_1/a/}');
Error('\P{Is_Block: latin_1/a/}');
Expect(1, 255, '\p{Is_Block=latin1}', "");
Expect(0, 255, '\p{^Is_Block=latin1}', "");
Expect(0, 255, '\P{Is_Block=latin1}', "");
Expect(1, 255, '\P{^Is_Block=latin1}', "");
Expect(0, 256, '\p{Is_Block=latin1}', "");
Expect(1, 256, '\p{^Is_Block=latin1}', "");
Expect(1, 256, '\P{Is_Block=latin1}', "");
Expect(0, 256, '\P{^Is_Block=latin1}', "");
Expect(1, 255, '\p{Is_Block=	Latin_1}', "");
Expect(0, 255, '\p{^Is_Block=	Latin_1}', "");
Expect(0, 255, '\P{Is_Block=	Latin_1}', "");
Expect(1, 255, '\P{^Is_Block=	Latin_1}', "");
Expect(0, 256, '\p{Is_Block=	Latin_1}', "");
Expect(1, 256, '\p{^Is_Block=	Latin_1}', "");
Expect(1, 256, '\P{Is_Block=	Latin_1}', "");
Expect(0, 256, '\P{^Is_Block=	Latin_1}', "");
Error('\p{Is_Blk=_ Latin_1_Supplement:=}');
Error('\P{Is_Blk=_ Latin_1_Supplement:=}');
Expect(1, 255, '\p{Is_Blk=latin1supplement}', "");
Expect(0, 255, '\p{^Is_Blk=latin1supplement}', "");
Expect(0, 255, '\P{Is_Blk=latin1supplement}', "");
Expect(1, 255, '\P{^Is_Blk=latin1supplement}', "");
Expect(0, 256, '\p{Is_Blk=latin1supplement}', "");
Expect(1, 256, '\p{^Is_Blk=latin1supplement}', "");
Expect(1, 256, '\P{Is_Blk=latin1supplement}', "");
Expect(0, 256, '\P{^Is_Blk=latin1supplement}', "");
Expect(1, 255, '\p{Is_Blk=- LATIN_1_Supplement}', "");
Expect(0, 255, '\p{^Is_Blk=- LATIN_1_Supplement}', "");
Expect(0, 255, '\P{Is_Blk=- LATIN_1_Supplement}', "");
Expect(1, 255, '\P{^Is_Blk=- LATIN_1_Supplement}', "");
Expect(0, 256, '\p{Is_Blk=- LATIN_1_Supplement}', "");
Expect(1, 256, '\p{^Is_Blk=- LATIN_1_Supplement}', "");
Expect(1, 256, '\P{Is_Blk=- LATIN_1_Supplement}', "");
Expect(0, 256, '\P{^Is_Blk=- LATIN_1_Supplement}', "");
Error('\p{Block=_:=latin_Extended_A}');
Error('\P{Block=_:=latin_Extended_A}');
Expect(1, 383, '\p{Block=latinextendeda}', "");
Expect(0, 383, '\p{^Block=latinextendeda}', "");
Expect(0, 383, '\P{Block=latinextendeda}', "");
Expect(1, 383, '\P{^Block=latinextendeda}', "");
Expect(0, 384, '\p{Block=latinextendeda}', "");
Expect(1, 384, '\p{^Block=latinextendeda}', "");
Expect(1, 384, '\P{Block=latinextendeda}', "");
Expect(0, 384, '\P{^Block=latinextendeda}', "");
Expect(1, 383, '\p{Block=	 LATIN_Extended_A}', "");
Expect(0, 383, '\p{^Block=	 LATIN_Extended_A}', "");
Expect(0, 383, '\P{Block=	 LATIN_Extended_A}', "");
Expect(1, 383, '\P{^Block=	 LATIN_Extended_A}', "");
Expect(0, 384, '\p{Block=	 LATIN_Extended_A}', "");
Expect(1, 384, '\p{^Block=	 LATIN_Extended_A}', "");
Expect(1, 384, '\P{Block=	 LATIN_Extended_A}', "");
Expect(0, 384, '\P{^Block=	 LATIN_Extended_A}', "");
Error('\p{Blk=	 latin_ext_a/a/}');
Error('\P{Blk=	 latin_ext_a/a/}');
Expect(1, 383, '\p{Blk=latinexta}', "");
Expect(0, 383, '\p{^Blk=latinexta}', "");
Expect(0, 383, '\P{Blk=latinexta}', "");
Expect(1, 383, '\P{^Blk=latinexta}', "");
Expect(0, 384, '\p{Blk=latinexta}', "");
Expect(1, 384, '\p{^Blk=latinexta}', "");
Expect(1, 384, '\P{Blk=latinexta}', "");
Expect(0, 384, '\P{^Blk=latinexta}', "");
Expect(1, 383, '\p{Blk=_ Latin_ext_A}', "");
Expect(0, 383, '\p{^Blk=_ Latin_ext_A}', "");
Expect(0, 383, '\P{Blk=_ Latin_ext_A}', "");
Expect(1, 383, '\P{^Blk=_ Latin_ext_A}', "");
Expect(0, 384, '\p{Blk=_ Latin_ext_A}', "");
Expect(1, 384, '\p{^Blk=_ Latin_ext_A}', "");
Expect(1, 384, '\P{Blk=_ Latin_ext_A}', "");
Expect(0, 384, '\P{^Blk=_ Latin_ext_A}', "");
Error('\p{Is_Block=/a/-Latin_EXTENDED_A}');
Error('\P{Is_Block=/a/-Latin_EXTENDED_A}');
Expect(1, 383, '\p{Is_Block=latinextendeda}', "");
Expect(0, 383, '\p{^Is_Block=latinextendeda}', "");
Expect(0, 383, '\P{Is_Block=latinextendeda}', "");
Expect(1, 383, '\P{^Is_Block=latinextendeda}', "");
Expect(0, 384, '\p{Is_Block=latinextendeda}', "");
Expect(1, 384, '\p{^Is_Block=latinextendeda}', "");
Expect(1, 384, '\P{Is_Block=latinextendeda}', "");
Expect(0, 384, '\P{^Is_Block=latinextendeda}', "");
Expect(1, 383, '\p{Is_Block= Latin_extended_A}', "");
Expect(0, 383, '\p{^Is_Block= Latin_extended_A}', "");
Expect(0, 383, '\P{Is_Block= Latin_extended_A}', "");
Expect(1, 383, '\P{^Is_Block= Latin_extended_A}', "");
Expect(0, 384, '\p{Is_Block= Latin_extended_A}', "");
Expect(1, 384, '\p{^Is_Block= Latin_extended_A}', "");
Expect(1, 384, '\P{Is_Block= Latin_extended_A}', "");
Expect(0, 384, '\P{^Is_Block= Latin_extended_A}', "");
Error('\p{Is_Blk=:=LATIN_Ext_a}');
Error('\P{Is_Blk=:=LATIN_Ext_a}');
Expect(1, 383, '\p{Is_Blk=latinexta}', "");
Expect(0, 383, '\p{^Is_Blk=latinexta}', "");
Expect(0, 383, '\P{Is_Blk=latinexta}', "");
Expect(1, 383, '\P{^Is_Blk=latinexta}', "");
Expect(0, 384, '\p{Is_Blk=latinexta}', "");
Expect(1, 384, '\p{^Is_Blk=latinexta}', "");
Expect(1, 384, '\P{Is_Blk=latinexta}', "");
Expect(0, 384, '\P{^Is_Blk=latinexta}', "");
Expect(1, 383, '\p{Is_Blk= latin_Ext_A}', "");
Expect(0, 383, '\p{^Is_Blk= latin_Ext_A}', "");
Expect(0, 383, '\P{Is_Blk= latin_Ext_A}', "");
Expect(1, 383, '\P{^Is_Blk= latin_Ext_A}', "");
Expect(0, 384, '\p{Is_Blk= latin_Ext_A}', "");
Expect(1, 384, '\p{^Is_Blk= latin_Ext_A}', "");
Expect(1, 384, '\P{Is_Blk= latin_Ext_A}', "");
Expect(0, 384, '\P{^Is_Blk= latin_Ext_A}', "");
Error('\p{Block=-	Latin_Extended_ADDITIONAL/a/}');
Error('\P{Block=-	Latin_Extended_ADDITIONAL/a/}');
Expect(1, 7935, '\p{Block:	latinextendedadditional}', "");
Expect(0, 7935, '\p{^Block:	latinextendedadditional}', "");
Expect(0, 7935, '\P{Block:	latinextendedadditional}', "");
Expect(1, 7935, '\P{^Block:	latinextendedadditional}', "");
Expect(0, 7936, '\p{Block:	latinextendedadditional}', "");
Expect(1, 7936, '\p{^Block:	latinextendedadditional}', "");
Expect(1, 7936, '\P{Block:	latinextendedadditional}', "");
Expect(0, 7936, '\P{^Block:	latinextendedadditional}', "");
Expect(1, 7935, '\p{Block=__LATIN_EXTENDED_Additional}', "");
Expect(0, 7935, '\p{^Block=__LATIN_EXTENDED_Additional}', "");
Expect(0, 7935, '\P{Block=__LATIN_EXTENDED_Additional}', "");
Expect(1, 7935, '\P{^Block=__LATIN_EXTENDED_Additional}', "");
Expect(0, 7936, '\p{Block=__LATIN_EXTENDED_Additional}', "");
Expect(1, 7936, '\p{^Block=__LATIN_EXTENDED_Additional}', "");
Expect(1, 7936, '\P{Block=__LATIN_EXTENDED_Additional}', "");
Expect(0, 7936, '\P{^Block=__LATIN_EXTENDED_Additional}', "");
Error('\p{Blk=:=LATIN_Ext_Additional}');
Error('\P{Blk=:=LATIN_Ext_Additional}');
Expect(1, 7935, '\p{Blk=latinextadditional}', "");
Expect(0, 7935, '\p{^Blk=latinextadditional}', "");
Expect(0, 7935, '\P{Blk=latinextadditional}', "");
Expect(1, 7935, '\P{^Blk=latinextadditional}', "");
Expect(0, 7936, '\p{Blk=latinextadditional}', "");
Expect(1, 7936, '\p{^Blk=latinextadditional}', "");
Expect(1, 7936, '\P{Blk=latinextadditional}', "");
Expect(0, 7936, '\P{^Blk=latinextadditional}', "");
Expect(1, 7935, '\p{Blk= latin_EXT_Additional}', "");
Expect(0, 7935, '\p{^Blk= latin_EXT_Additional}', "");
Expect(0, 7935, '\P{Blk= latin_EXT_Additional}', "");
Expect(1, 7935, '\P{^Blk= latin_EXT_Additional}', "");
Expect(0, 7936, '\p{Blk= latin_EXT_Additional}', "");
Expect(1, 7936, '\p{^Blk= latin_EXT_Additional}', "");
Expect(1, 7936, '\P{Blk= latin_EXT_Additional}', "");
Expect(0, 7936, '\P{^Blk= latin_EXT_Additional}', "");
Error('\p{Is_Block=:= -LATIN_Extended_ADDITIONAL}');
Error('\P{Is_Block=:= -LATIN_Extended_ADDITIONAL}');
Expect(1, 7935, '\p{Is_Block=latinextendedadditional}', "");
Expect(0, 7935, '\p{^Is_Block=latinextendedadditional}', "");
Expect(0, 7935, '\P{Is_Block=latinextendedadditional}', "");
Expect(1, 7935, '\P{^Is_Block=latinextendedadditional}', "");
Expect(0, 7936, '\p{Is_Block=latinextendedadditional}', "");
Expect(1, 7936, '\p{^Is_Block=latinextendedadditional}', "");
Expect(1, 7936, '\P{Is_Block=latinextendedadditional}', "");
Expect(0, 7936, '\P{^Is_Block=latinextendedadditional}', "");
Expect(1, 7935, '\p{Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(0, 7935, '\p{^Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(0, 7935, '\P{Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(1, 7935, '\P{^Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(0, 7936, '\p{Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(1, 7936, '\p{^Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(1, 7936, '\P{Is_Block=_	Latin_EXTENDED_additional}', "");
Expect(0, 7936, '\P{^Is_Block=_	Latin_EXTENDED_additional}', "");
Error('\p{Is_Blk=- LATIN_Ext_ADDITIONAL:=}');
Error('\P{Is_Blk=- LATIN_Ext_ADDITIONAL:=}');
Expect(1, 7935, '\p{Is_Blk=latinextadditional}', "");
Expect(0, 7935, '\p{^Is_Blk=latinextadditional}', "");
Expect(0, 7935, '\P{Is_Blk=latinextadditional}', "");
Expect(1, 7935, '\P{^Is_Blk=latinextadditional}', "");
Expect(0, 7936, '\p{Is_Blk=latinextadditional}', "");
Expect(1, 7936, '\p{^Is_Blk=latinextadditional}', "");
Expect(1, 7936, '\P{Is_Blk=latinextadditional}', "");
Expect(0, 7936, '\P{^Is_Blk=latinextadditional}', "");
Expect(1, 7935, '\p{Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(0, 7935, '\p{^Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(0, 7935, '\P{Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(1, 7935, '\P{^Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(0, 7936, '\p{Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(1, 7936, '\p{^Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(1, 7936, '\P{Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Expect(0, 7936, '\P{^Is_Blk=_ Latin_EXT_ADDITIONAL}', "");
Error('\p{Block=-:=latin_Extended_b}');
Error('\P{Block=-:=latin_Extended_b}');
Expect(1, 591, '\p{Block=latinextendedb}', "");
Expect(0, 591, '\p{^Block=latinextendedb}', "");
Expect(0, 591, '\P{Block=latinextendedb}', "");
Expect(1, 591, '\P{^Block=latinextendedb}', "");
Expect(0, 592, '\p{Block=latinextendedb}', "");
Expect(1, 592, '\p{^Block=latinextendedb}', "");
Expect(1, 592, '\P{Block=latinextendedb}', "");
Expect(0, 592, '\P{^Block=latinextendedb}', "");
Expect(1, 591, '\p{Block=-	LATIN_extended_b}', "");
Expect(0, 591, '\p{^Block=-	LATIN_extended_b}', "");
Expect(0, 591, '\P{Block=-	LATIN_extended_b}', "");
Expect(1, 591, '\P{^Block=-	LATIN_extended_b}', "");
Expect(0, 592, '\p{Block=-	LATIN_extended_b}', "");
Expect(1, 592, '\p{^Block=-	LATIN_extended_b}', "");
Expect(1, 592, '\P{Block=-	LATIN_extended_b}', "");
Expect(0, 592, '\P{^Block=-	LATIN_extended_b}', "");
Error('\p{Blk=:= _Latin_Ext_B}');
Error('\P{Blk=:= _Latin_Ext_B}');
Expect(1, 591, '\p{Blk=latinextb}', "");
Expect(0, 591, '\p{^Blk=latinextb}', "");
Expect(0, 591, '\P{Blk=latinextb}', "");
Expect(1, 591, '\P{^Blk=latinextb}', "");
Expect(0, 592, '\p{Blk=latinextb}', "");
Expect(1, 592, '\p{^Blk=latinextb}', "");
Expect(1, 592, '\P{Blk=latinextb}', "");
Expect(0, 592, '\P{^Blk=latinextb}', "");
Expect(1, 591, '\p{Blk=		LATIN_Ext_B}', "");
Expect(0, 591, '\p{^Blk=		LATIN_Ext_B}', "");
Expect(0, 591, '\P{Blk=		LATIN_Ext_B}', "");
Expect(1, 591, '\P{^Blk=		LATIN_Ext_B}', "");
Expect(0, 592, '\p{Blk=		LATIN_Ext_B}', "");
Expect(1, 592, '\p{^Blk=		LATIN_Ext_B}', "");
Expect(1, 592, '\P{Blk=		LATIN_Ext_B}', "");
Expect(0, 592, '\P{^Blk=		LATIN_Ext_B}', "");
Error('\p{Is_Block:	/a/-_Latin_EXTENDED_b}');
Error('\P{Is_Block:	/a/-_Latin_EXTENDED_b}');
Expect(1, 591, '\p{Is_Block=latinextendedb}', "");
Expect(0, 591, '\p{^Is_Block=latinextendedb}', "");
Expect(0, 591, '\P{Is_Block=latinextendedb}', "");
Expect(1, 591, '\P{^Is_Block=latinextendedb}', "");
Expect(0, 592, '\p{Is_Block=latinextendedb}', "");
Expect(1, 592, '\p{^Is_Block=latinextendedb}', "");
Expect(1, 592, '\P{Is_Block=latinextendedb}', "");
Expect(0, 592, '\P{^Is_Block=latinextendedb}', "");
Expect(1, 591, '\p{Is_Block=		Latin_Extended_B}', "");
Expect(0, 591, '\p{^Is_Block=		Latin_Extended_B}', "");
Expect(0, 591, '\P{Is_Block=		Latin_Extended_B}', "");
Expect(1, 591, '\P{^Is_Block=		Latin_Extended_B}', "");
Expect(0, 592, '\p{Is_Block=		Latin_Extended_B}', "");
Expect(1, 592, '\p{^Is_Block=		Latin_Extended_B}', "");
Expect(1, 592, '\P{Is_Block=		Latin_Extended_B}', "");
Expect(0, 592, '\P{^Is_Block=		Latin_Extended_B}', "");
Error('\p{Is_Blk:_/a/Latin_Ext_b}');
Error('\P{Is_Blk:_/a/Latin_Ext_b}');
Expect(1, 591, '\p{Is_Blk=latinextb}', "");
Expect(0, 591, '\p{^Is_Blk=latinextb}', "");
Expect(0, 591, '\P{Is_Blk=latinextb}', "");
Expect(1, 591, '\P{^Is_Blk=latinextb}', "");
Expect(0, 592, '\p{Is_Blk=latinextb}', "");
Expect(1, 592, '\p{^Is_Blk=latinextb}', "");
Expect(1, 592, '\P{Is_Blk=latinextb}', "");
Expect(0, 592, '\P{^Is_Blk=latinextb}', "");
Expect(1, 591, '\p{Is_Blk=--latin_Ext_B}', "");
Expect(0, 591, '\p{^Is_Blk=--latin_Ext_B}', "");
Expect(0, 591, '\P{Is_Blk=--latin_Ext_B}', "");
Expect(1, 591, '\P{^Is_Blk=--latin_Ext_B}', "");
Expect(0, 592, '\p{Is_Blk=--latin_Ext_B}', "");
Expect(1, 592, '\p{^Is_Blk=--latin_Ext_B}', "");
Expect(1, 592, '\P{Is_Blk=--latin_Ext_B}', "");
Expect(0, 592, '\P{^Is_Blk=--latin_Ext_B}', "");
Error('\p{Block: := _Latin_extended_C}');
Error('\P{Block: := _Latin_extended_C}');
Expect(1, 11391, '\p{Block=latinextendedc}', "");
Expect(0, 11391, '\p{^Block=latinextendedc}', "");
Expect(0, 11391, '\P{Block=latinextendedc}', "");
Expect(1, 11391, '\P{^Block=latinextendedc}', "");
Expect(0, 11392, '\p{Block=latinextendedc}', "");
Expect(1, 11392, '\p{^Block=latinextendedc}', "");
Expect(1, 11392, '\P{Block=latinextendedc}', "");
Expect(0, 11392, '\P{^Block=latinextendedc}', "");
Expect(1, 11391, '\p{Block=-latin_Extended_c}', "");
Expect(0, 11391, '\p{^Block=-latin_Extended_c}', "");
Expect(0, 11391, '\P{Block=-latin_Extended_c}', "");
Expect(1, 11391, '\P{^Block=-latin_Extended_c}', "");
Expect(0, 11392, '\p{Block=-latin_Extended_c}', "");
Expect(1, 11392, '\p{^Block=-latin_Extended_c}', "");
Expect(1, 11392, '\P{Block=-latin_Extended_c}', "");
Expect(0, 11392, '\P{^Block=-latin_Extended_c}', "");
Error('\p{Blk=:=_Latin_Ext_C}');
Error('\P{Blk=:=_Latin_Ext_C}');
Expect(1, 11391, '\p{Blk=latinextc}', "");
Expect(0, 11391, '\p{^Blk=latinextc}', "");
Expect(0, 11391, '\P{Blk=latinextc}', "");
Expect(1, 11391, '\P{^Blk=latinextc}', "");
Expect(0, 11392, '\p{Blk=latinextc}', "");
Expect(1, 11392, '\p{^Blk=latinextc}', "");
Expect(1, 11392, '\P{Blk=latinextc}', "");
Expect(0, 11392, '\P{^Blk=latinextc}', "");
Expect(1, 11391, '\p{Blk=_Latin_Ext_C}', "");
Expect(0, 11391, '\p{^Blk=_Latin_Ext_C}', "");
Expect(0, 11391, '\P{Blk=_Latin_Ext_C}', "");
Expect(1, 11391, '\P{^Blk=_Latin_Ext_C}', "");
Expect(0, 11392, '\p{Blk=_Latin_Ext_C}', "");
Expect(1, 11392, '\p{^Blk=_Latin_Ext_C}', "");
Expect(1, 11392, '\P{Blk=_Latin_Ext_C}', "");
Expect(0, 11392, '\P{^Blk=_Latin_Ext_C}', "");
Error('\p{Is_Block=:=_ LATIN_EXTENDED_C}');
Error('\P{Is_Block=:=_ LATIN_EXTENDED_C}');
Expect(1, 11391, '\p{Is_Block:   latinextendedc}', "");
Expect(0, 11391, '\p{^Is_Block:   latinextendedc}', "");
Expect(0, 11391, '\P{Is_Block:   latinextendedc}', "");
Expect(1, 11391, '\P{^Is_Block:   latinextendedc}', "");
Expect(0, 11392, '\p{Is_Block:   latinextendedc}', "");
Expect(1, 11392, '\p{^Is_Block:   latinextendedc}', "");
Expect(1, 11392, '\P{Is_Block:   latinextendedc}', "");
Expect(0, 11392, '\P{^Is_Block:   latinextendedc}', "");
Expect(1, 11391, '\p{Is_Block=__latin_Extended_c}', "");
Expect(0, 11391, '\p{^Is_Block=__latin_Extended_c}', "");
Expect(0, 11391, '\P{Is_Block=__latin_Extended_c}', "");
Expect(1, 11391, '\P{^Is_Block=__latin_Extended_c}', "");
Expect(0, 11392, '\p{Is_Block=__latin_Extended_c}', "");
Expect(1, 11392, '\p{^Is_Block=__latin_Extended_c}', "");
Expect(1, 11392, '\P{Is_Block=__latin_Extended_c}', "");
Expect(0, 11392, '\P{^Is_Block=__latin_Extended_c}', "");
Error('\p{Is_Blk=_	Latin_EXT_C:=}');
Error('\P{Is_Blk=_	Latin_EXT_C:=}');
Expect(1, 11391, '\p{Is_Blk=latinextc}', "");
Expect(0, 11391, '\p{^Is_Blk=latinextc}', "");
Expect(0, 11391, '\P{Is_Blk=latinextc}', "");
Expect(1, 11391, '\P{^Is_Blk=latinextc}', "");
Expect(0, 11392, '\p{Is_Blk=latinextc}', "");
Expect(1, 11392, '\p{^Is_Blk=latinextc}', "");
Expect(1, 11392, '\P{Is_Blk=latinextc}', "");
Expect(0, 11392, '\P{^Is_Blk=latinextc}', "");
Expect(1, 11391, '\p{Is_Blk: 	Latin_ext_C}', "");
Expect(0, 11391, '\p{^Is_Blk: 	Latin_ext_C}', "");
Expect(0, 11391, '\P{Is_Blk: 	Latin_ext_C}', "");
Expect(1, 11391, '\P{^Is_Blk: 	Latin_ext_C}', "");
Expect(0, 11392, '\p{Is_Blk: 	Latin_ext_C}', "");
Expect(1, 11392, '\p{^Is_Blk: 	Latin_ext_C}', "");
Expect(1, 11392, '\P{Is_Blk: 	Latin_ext_C}', "");
Expect(0, 11392, '\P{^Is_Blk: 	Latin_ext_C}', "");
Error('\p{Block=:=--Latin_Extended_d}');
Error('\P{Block=:=--Latin_Extended_d}');
Expect(1, 43007, '\p{Block=latinextendedd}', "");
Expect(0, 43007, '\p{^Block=latinextendedd}', "");
Expect(0, 43007, '\P{Block=latinextendedd}', "");
Expect(1, 43007, '\P{^Block=latinextendedd}', "");
Expect(0, 43008, '\p{Block=latinextendedd}', "");
Expect(1, 43008, '\p{^Block=latinextendedd}', "");
Expect(1, 43008, '\P{Block=latinextendedd}', "");
Expect(0, 43008, '\P{^Block=latinextendedd}', "");
Expect(1, 43007, '\p{Block=_ latin_Extended_D}', "");
Expect(0, 43007, '\p{^Block=_ latin_Extended_D}', "");
Expect(0, 43007, '\P{Block=_ latin_Extended_D}', "");
Expect(1, 43007, '\P{^Block=_ latin_Extended_D}', "");
Expect(0, 43008, '\p{Block=_ latin_Extended_D}', "");
Expect(1, 43008, '\p{^Block=_ latin_Extended_D}', "");
Expect(1, 43008, '\P{Block=_ latin_Extended_D}', "");
Expect(0, 43008, '\P{^Block=_ latin_Extended_D}', "");
Error('\p{Blk=	-LATIN_Ext_D/a/}');
Error('\P{Blk=	-LATIN_Ext_D/a/}');
Expect(1, 43007, '\p{Blk=latinextd}', "");
Expect(0, 43007, '\p{^Blk=latinextd}', "");
Expect(0, 43007, '\P{Blk=latinextd}', "");
Expect(1, 43007, '\P{^Blk=latinextd}', "");
Expect(0, 43008, '\p{Blk=latinextd}', "");
Expect(1, 43008, '\p{^Blk=latinextd}', "");
Expect(1, 43008, '\P{Blk=latinextd}', "");
Expect(0, 43008, '\P{^Blk=latinextd}', "");
Expect(1, 43007, '\p{Blk=	latin_Ext_D}', "");
Expect(0, 43007, '\p{^Blk=	latin_Ext_D}', "");
Expect(0, 43007, '\P{Blk=	latin_Ext_D}', "");
Expect(1, 43007, '\P{^Blk=	latin_Ext_D}', "");
Expect(0, 43008, '\p{Blk=	latin_Ext_D}', "");
Expect(1, 43008, '\p{^Blk=	latin_Ext_D}', "");
Expect(1, 43008, '\P{Blk=	latin_Ext_D}', "");
Expect(0, 43008, '\P{^Blk=	latin_Ext_D}', "");
Error('\p{Is_Block:   :=  Latin_Extended_d}');
Error('\P{Is_Block:   :=  Latin_Extended_d}');
Expect(1, 43007, '\p{Is_Block=latinextendedd}', "");
Expect(0, 43007, '\p{^Is_Block=latinextendedd}', "");
Expect(0, 43007, '\P{Is_Block=latinextendedd}', "");
Expect(1, 43007, '\P{^Is_Block=latinextendedd}', "");
Expect(0, 43008, '\p{Is_Block=latinextendedd}', "");
Expect(1, 43008, '\p{^Is_Block=latinextendedd}', "");
Expect(1, 43008, '\P{Is_Block=latinextendedd}', "");
Expect(0, 43008, '\P{^Is_Block=latinextendedd}', "");
Expect(1, 43007, '\p{Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(0, 43007, '\p{^Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(0, 43007, '\P{Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(1, 43007, '\P{^Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(0, 43008, '\p{Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(1, 43008, '\p{^Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(1, 43008, '\P{Is_Block=_-LATIN_EXTENDED_D}', "");
Expect(0, 43008, '\P{^Is_Block=_-LATIN_EXTENDED_D}', "");
Error('\p{Is_Blk=	latin_Ext_d:=}');
Error('\P{Is_Blk=	latin_Ext_d:=}');
Expect(1, 43007, '\p{Is_Blk=latinextd}', "");
Expect(0, 43007, '\p{^Is_Blk=latinextd}', "");
Expect(0, 43007, '\P{Is_Blk=latinextd}', "");
Expect(1, 43007, '\P{^Is_Blk=latinextd}', "");
Expect(0, 43008, '\p{Is_Blk=latinextd}', "");
Expect(1, 43008, '\p{^Is_Blk=latinextd}', "");
Expect(1, 43008, '\P{Is_Blk=latinextd}', "");
Expect(0, 43008, '\P{^Is_Blk=latinextd}', "");
Expect(1, 43007, '\p{Is_Blk=-Latin_EXT_D}', "");
Expect(0, 43007, '\p{^Is_Blk=-Latin_EXT_D}', "");
Expect(0, 43007, '\P{Is_Blk=-Latin_EXT_D}', "");
Expect(1, 43007, '\P{^Is_Blk=-Latin_EXT_D}', "");
Expect(0, 43008, '\p{Is_Blk=-Latin_EXT_D}', "");
Expect(1, 43008, '\p{^Is_Blk=-Latin_EXT_D}', "");
Expect(1, 43008, '\P{Is_Blk=-Latin_EXT_D}', "");
Expect(0, 43008, '\P{^Is_Blk=-Latin_EXT_D}', "");
Error('\p{Block=  LEPCHA/a/}');
Error('\P{Block=  LEPCHA/a/}');
Expect(1, 7247, '\p{Block=lepcha}', "");
Expect(0, 7247, '\p{^Block=lepcha}', "");
Expect(0, 7247, '\P{Block=lepcha}', "");
Expect(1, 7247, '\P{^Block=lepcha}', "");
Expect(0, 7248, '\p{Block=lepcha}', "");
Expect(1, 7248, '\p{^Block=lepcha}', "");
Expect(1, 7248, '\P{Block=lepcha}', "");
Expect(0, 7248, '\P{^Block=lepcha}', "");
Expect(1, 7247, '\p{Block:    Lepcha}', "");
Expect(0, 7247, '\p{^Block:    Lepcha}', "");
Expect(0, 7247, '\P{Block:    Lepcha}', "");
Expect(1, 7247, '\P{^Block:    Lepcha}', "");
Expect(0, 7248, '\p{Block:    Lepcha}', "");
Expect(1, 7248, '\p{^Block:    Lepcha}', "");
Expect(1, 7248, '\P{Block:    Lepcha}', "");
Expect(0, 7248, '\P{^Block:    Lepcha}', "");
Error('\p{Blk:   /a/lepcha}');
Error('\P{Blk:   /a/lepcha}');
Expect(1, 7247, '\p{Blk:lepcha}', "");
Expect(0, 7247, '\p{^Blk:lepcha}', "");
Expect(0, 7247, '\P{Blk:lepcha}', "");
Expect(1, 7247, '\P{^Blk:lepcha}', "");
Expect(0, 7248, '\p{Blk:lepcha}', "");
Expect(1, 7248, '\p{^Blk:lepcha}', "");
Expect(1, 7248, '\P{Blk:lepcha}', "");
Expect(0, 7248, '\P{^Blk:lepcha}', "");
Expect(1, 7247, '\p{Blk=LEPCHA}', "");
Expect(0, 7247, '\p{^Blk=LEPCHA}', "");
Expect(0, 7247, '\P{Blk=LEPCHA}', "");
Expect(1, 7247, '\P{^Blk=LEPCHA}', "");
Expect(0, 7248, '\p{Blk=LEPCHA}', "");
Expect(1, 7248, '\p{^Blk=LEPCHA}', "");
Expect(1, 7248, '\P{Blk=LEPCHA}', "");
Expect(0, 7248, '\P{^Blk=LEPCHA}', "");
Error('\p{Is_Block=LEPCHA/a/}');
Error('\P{Is_Block=LEPCHA/a/}');
Expect(1, 7247, '\p{Is_Block=lepcha}', "");
Expect(0, 7247, '\p{^Is_Block=lepcha}', "");
Expect(0, 7247, '\P{Is_Block=lepcha}', "");
Expect(1, 7247, '\P{^Is_Block=lepcha}', "");
Expect(0, 7248, '\p{Is_Block=lepcha}', "");
Expect(1, 7248, '\p{^Is_Block=lepcha}', "");
Expect(1, 7248, '\P{Is_Block=lepcha}', "");
Expect(0, 7248, '\P{^Is_Block=lepcha}', "");
Expect(1, 7247, '\p{Is_Block=-lepcha}', "");
Expect(0, 7247, '\p{^Is_Block=-lepcha}', "");
Expect(0, 7247, '\P{Is_Block=-lepcha}', "");
Expect(1, 7247, '\P{^Is_Block=-lepcha}', "");
Expect(0, 7248, '\p{Is_Block=-lepcha}', "");
Expect(1, 7248, '\p{^Is_Block=-lepcha}', "");
Expect(1, 7248, '\P{Is_Block=-lepcha}', "");
Expect(0, 7248, '\P{^Is_Block=-lepcha}', "");
Error('\p{Is_Blk= :=LEPCHA}');
Error('\P{Is_Blk= :=LEPCHA}');
Expect(1, 7247, '\p{Is_Blk=lepcha}', "");
Expect(0, 7247, '\p{^Is_Blk=lepcha}', "");
Expect(0, 7247, '\P{Is_Blk=lepcha}', "");
Expect(1, 7247, '\P{^Is_Blk=lepcha}', "");
Expect(0, 7248, '\p{Is_Blk=lepcha}', "");
Expect(1, 7248, '\p{^Is_Blk=lepcha}', "");
Expect(1, 7248, '\P{Is_Blk=lepcha}', "");
Expect(0, 7248, '\P{^Is_Blk=lepcha}', "");
Expect(1, 7247, '\p{Is_Blk=- lepcha}', "");
Expect(0, 7247, '\p{^Is_Blk=- lepcha}', "");
Expect(0, 7247, '\P{Is_Blk=- lepcha}', "");
Expect(1, 7247, '\P{^Is_Blk=- lepcha}', "");
Expect(0, 7248, '\p{Is_Blk=- lepcha}', "");
Expect(1, 7248, '\p{^Is_Blk=- lepcha}', "");
Expect(1, 7248, '\P{Is_Blk=- lepcha}', "");
Expect(0, 7248, '\P{^Is_Blk=- lepcha}', "");
Error('\p{Block=_-Letterlike_Symbols/a/}');
Error('\P{Block=_-Letterlike_Symbols/a/}');
Expect(1, 8527, '\p{Block=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Block=letterlikesymbols}', "");
Expect(0, 8527, '\P{Block=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Block=letterlikesymbols}', "");
Expect(0, 8528, '\p{Block=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Block=letterlikesymbols}', "");
Expect(1, 8528, '\P{Block=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Block=letterlikesymbols}', "");
Expect(1, 8527, '\p{Block:  _letterlike_SYMBOLS}', "");
Expect(0, 8527, '\p{^Block:  _letterlike_SYMBOLS}', "");
Expect(0, 8527, '\P{Block:  _letterlike_SYMBOLS}', "");
Expect(1, 8527, '\P{^Block:  _letterlike_SYMBOLS}', "");
Expect(0, 8528, '\p{Block:  _letterlike_SYMBOLS}', "");
Expect(1, 8528, '\p{^Block:  _letterlike_SYMBOLS}', "");
Expect(1, 8528, '\P{Block:  _letterlike_SYMBOLS}', "");
Expect(0, 8528, '\P{^Block:  _letterlike_SYMBOLS}', "");
Error('\p{Blk=	-Letterlike_symbols:=}');
Error('\P{Blk=	-Letterlike_symbols:=}');
Expect(1, 8527, '\p{Blk=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Blk=letterlikesymbols}', "");
Expect(0, 8527, '\P{Blk=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Blk=letterlikesymbols}', "");
Expect(0, 8528, '\p{Blk=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Blk=letterlikesymbols}', "");
Expect(1, 8528, '\P{Blk=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Blk=letterlikesymbols}', "");
Expect(1, 8527, '\p{Blk= _letterlike_Symbols}', "");
Expect(0, 8527, '\p{^Blk= _letterlike_Symbols}', "");
Expect(0, 8527, '\P{Blk= _letterlike_Symbols}', "");
Expect(1, 8527, '\P{^Blk= _letterlike_Symbols}', "");
Expect(0, 8528, '\p{Blk= _letterlike_Symbols}', "");
Expect(1, 8528, '\p{^Blk= _letterlike_Symbols}', "");
Expect(1, 8528, '\P{Blk= _letterlike_Symbols}', "");
Expect(0, 8528, '\P{^Blk= _letterlike_Symbols}', "");
Error('\p{Is_Block= 	LETTERLIKE_Symbols/a/}');
Error('\P{Is_Block= 	LETTERLIKE_Symbols/a/}');
Expect(1, 8527, '\p{Is_Block=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Is_Block=letterlikesymbols}', "");
Expect(0, 8527, '\P{Is_Block=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Is_Block=letterlikesymbols}', "");
Expect(0, 8528, '\p{Is_Block=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Is_Block=letterlikesymbols}', "");
Expect(1, 8528, '\P{Is_Block=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Is_Block=letterlikesymbols}', "");
Expect(1, 8527, '\p{Is_Block= 	Letterlike_Symbols}', "");
Expect(0, 8527, '\p{^Is_Block= 	Letterlike_Symbols}', "");
Expect(0, 8527, '\P{Is_Block= 	Letterlike_Symbols}', "");
Expect(1, 8527, '\P{^Is_Block= 	Letterlike_Symbols}', "");
Expect(0, 8528, '\p{Is_Block= 	Letterlike_Symbols}', "");
Expect(1, 8528, '\p{^Is_Block= 	Letterlike_Symbols}', "");
Expect(1, 8528, '\P{Is_Block= 	Letterlike_Symbols}', "");
Expect(0, 8528, '\P{^Is_Block= 	Letterlike_Symbols}', "");
Error('\p{Is_Blk: _/a/Letterlike_symbols}');
Error('\P{Is_Blk: _/a/Letterlike_symbols}');
Expect(1, 8527, '\p{Is_Blk=letterlikesymbols}', "");
Expect(0, 8527, '\p{^Is_Blk=letterlikesymbols}', "");
Expect(0, 8527, '\P{Is_Blk=letterlikesymbols}', "");
Expect(1, 8527, '\P{^Is_Blk=letterlikesymbols}', "");
Expect(0, 8528, '\p{Is_Blk=letterlikesymbols}', "");
Expect(1, 8528, '\p{^Is_Blk=letterlikesymbols}', "");
Expect(1, 8528, '\P{Is_Blk=letterlikesymbols}', "");
Expect(0, 8528, '\P{^Is_Blk=letterlikesymbols}', "");
Expect(1, 8527, '\p{Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(0, 8527, '\p{^Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(0, 8527, '\P{Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(1, 8527, '\P{^Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(0, 8528, '\p{Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(1, 8528, '\p{^Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(1, 8528, '\P{Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Expect(0, 8528, '\P{^Is_Blk=_	LETTERLIKE_SYMBOLS}', "");
Error('\p{Block=_:=limbu}');
Error('\P{Block=_:=limbu}');
Expect(1, 6479, '\p{Block=limbu}', "");
Expect(0, 6479, '\p{^Block=limbu}', "");
Expect(0, 6479, '\P{Block=limbu}', "");
Expect(1, 6479, '\P{^Block=limbu}', "");
Expect(0, 6480, '\p{Block=limbu}', "");
Expect(1, 6480, '\p{^Block=limbu}', "");
Expect(1, 6480, '\P{Block=limbu}', "");
Expect(0, 6480, '\P{^Block=limbu}', "");
Expect(1, 6479, '\p{Block=--Limbu}', "");
Expect(0, 6479, '\p{^Block=--Limbu}', "");
Expect(0, 6479, '\P{Block=--Limbu}', "");
Expect(1, 6479, '\P{^Block=--Limbu}', "");
Expect(0, 6480, '\p{Block=--Limbu}', "");
Expect(1, 6480, '\p{^Block=--Limbu}', "");
Expect(1, 6480, '\P{Block=--Limbu}', "");
Expect(0, 6480, '\P{^Block=--Limbu}', "");
Error('\p{Blk= LIMBU/a/}');
Error('\P{Blk= LIMBU/a/}');
Expect(1, 6479, '\p{Blk=limbu}', "");
Expect(0, 6479, '\p{^Blk=limbu}', "");
Expect(0, 6479, '\P{Blk=limbu}', "");
Expect(1, 6479, '\P{^Blk=limbu}', "");
Expect(0, 6480, '\p{Blk=limbu}', "");
Expect(1, 6480, '\p{^Blk=limbu}', "");
Expect(1, 6480, '\P{Blk=limbu}', "");
Expect(0, 6480, '\P{^Blk=limbu}', "");
Expect(1, 6479, '\p{Blk=-LIMBU}', "");
Expect(0, 6479, '\p{^Blk=-LIMBU}', "");
Expect(0, 6479, '\P{Blk=-LIMBU}', "");
Expect(1, 6479, '\P{^Blk=-LIMBU}', "");
Expect(0, 6480, '\p{Blk=-LIMBU}', "");
Expect(1, 6480, '\p{^Blk=-LIMBU}', "");
Expect(1, 6480, '\P{Blk=-LIMBU}', "");
Expect(0, 6480, '\P{^Blk=-LIMBU}', "");
Error('\p{Is_Block=_/a/Limbu}');
Error('\P{Is_Block=_/a/Limbu}');
Expect(1, 6479, '\p{Is_Block=limbu}', "");
Expect(0, 6479, '\p{^Is_Block=limbu}', "");
Expect(0, 6479, '\P{Is_Block=limbu}', "");
Expect(1, 6479, '\P{^Is_Block=limbu}', "");
Expect(0, 6480, '\p{Is_Block=limbu}', "");
Expect(1, 6480, '\p{^Is_Block=limbu}', "");
Expect(1, 6480, '\P{Is_Block=limbu}', "");
Expect(0, 6480, '\P{^Is_Block=limbu}', "");
Expect(1, 6479, '\p{Is_Block=	-Limbu}', "");
Expect(0, 6479, '\p{^Is_Block=	-Limbu}', "");
Expect(0, 6479, '\P{Is_Block=	-Limbu}', "");
Expect(1, 6479, '\P{^Is_Block=	-Limbu}', "");
Expect(0, 6480, '\p{Is_Block=	-Limbu}', "");
Expect(1, 6480, '\p{^Is_Block=	-Limbu}', "");
Expect(1, 6480, '\P{Is_Block=	-Limbu}', "");
Expect(0, 6480, '\P{^Is_Block=	-Limbu}', "");
Error('\p{Is_Blk= _limbu/a/}');
Error('\P{Is_Blk= _limbu/a/}');
Expect(1, 6479, '\p{Is_Blk=limbu}', "");
Expect(0, 6479, '\p{^Is_Blk=limbu}', "");
Expect(0, 6479, '\P{Is_Blk=limbu}', "");
Expect(1, 6479, '\P{^Is_Blk=limbu}', "");
Expect(0, 6480, '\p{Is_Blk=limbu}', "");
Expect(1, 6480, '\p{^Is_Blk=limbu}', "");
Expect(1, 6480, '\P{Is_Blk=limbu}', "");
Expect(0, 6480, '\P{^Is_Blk=limbu}', "");
Expect(1, 6479, '\p{Is_Blk=--LIMBU}', "");
Expect(0, 6479, '\p{^Is_Blk=--LIMBU}', "");
Expect(0, 6479, '\P{Is_Blk=--LIMBU}', "");
Expect(1, 6479, '\P{^Is_Blk=--LIMBU}', "");
Expect(0, 6480, '\p{Is_Blk=--LIMBU}', "");
Expect(1, 6480, '\p{^Is_Blk=--LIMBU}', "");
Expect(1, 6480, '\P{Is_Blk=--LIMBU}', "");
Expect(0, 6480, '\P{^Is_Blk=--LIMBU}', "");
Error('\p{Block=/a/__LINEAR_B_ideograms}');
Error('\P{Block=/a/__LINEAR_B_ideograms}');
Expect(1, 65791, '\p{Block=linearbideograms}', "");
Expect(0, 65791, '\p{^Block=linearbideograms}', "");
Expect(0, 65791, '\P{Block=linearbideograms}', "");
Expect(1, 65791, '\P{^Block=linearbideograms}', "");
Expect(0, 65792, '\p{Block=linearbideograms}', "");
Expect(1, 65792, '\p{^Block=linearbideograms}', "");
Expect(1, 65792, '\P{Block=linearbideograms}', "");
Expect(0, 65792, '\P{^Block=linearbideograms}', "");
Expect(1, 65791, '\p{Block= _Linear_B_IDEOGRAMS}', "");
Expect(0, 65791, '\p{^Block= _Linear_B_IDEOGRAMS}', "");
Expect(0, 65791, '\P{Block= _Linear_B_IDEOGRAMS}', "");
Expect(1, 65791, '\P{^Block= _Linear_B_IDEOGRAMS}', "");
Expect(0, 65792, '\p{Block= _Linear_B_IDEOGRAMS}', "");
Expect(1, 65792, '\p{^Block= _Linear_B_IDEOGRAMS}', "");
Expect(1, 65792, '\P{Block= _Linear_B_IDEOGRAMS}', "");
Expect(0, 65792, '\P{^Block= _Linear_B_IDEOGRAMS}', "");
Error('\p{Blk:   :=Linear_b_Ideograms}');
Error('\P{Blk:   :=Linear_b_Ideograms}');
Expect(1, 65791, '\p{Blk=linearbideograms}', "");
Expect(0, 65791, '\p{^Blk=linearbideograms}', "");
Expect(0, 65791, '\P{Blk=linearbideograms}', "");
Expect(1, 65791, '\P{^Blk=linearbideograms}', "");
Expect(0, 65792, '\p{Blk=linearbideograms}', "");
Expect(1, 65792, '\p{^Blk=linearbideograms}', "");
Expect(1, 65792, '\P{Blk=linearbideograms}', "");
Expect(0, 65792, '\P{^Blk=linearbideograms}', "");
Expect(1, 65791, '\p{Blk=-	Linear_b_Ideograms}', "");
Expect(0, 65791, '\p{^Blk=-	Linear_b_Ideograms}', "");
Expect(0, 65791, '\P{Blk=-	Linear_b_Ideograms}', "");
Expect(1, 65791, '\P{^Blk=-	Linear_b_Ideograms}', "");
Expect(0, 65792, '\p{Blk=-	Linear_b_Ideograms}', "");
Expect(1, 65792, '\p{^Blk=-	Linear_b_Ideograms}', "");
Expect(1, 65792, '\P{Blk=-	Linear_b_Ideograms}', "");
Expect(0, 65792, '\P{^Blk=-	Linear_b_Ideograms}', "");
Error('\p{Is_Block=	:=Linear_B_Ideograms}');
Error('\P{Is_Block=	:=Linear_B_Ideograms}');
Expect(1, 65791, '\p{Is_Block=linearbideograms}', "");
Expect(0, 65791, '\p{^Is_Block=linearbideograms}', "");
Expect(0, 65791, '\P{Is_Block=linearbideograms}', "");
Expect(1, 65791, '\P{^Is_Block=linearbideograms}', "");
Expect(0, 65792, '\p{Is_Block=linearbideograms}', "");
Expect(1, 65792, '\p{^Is_Block=linearbideograms}', "");
Expect(1, 65792, '\P{Is_Block=linearbideograms}', "");
Expect(0, 65792, '\P{^Is_Block=linearbideograms}', "");
Expect(1, 65791, '\p{Is_Block=	_linear_B_ideograms}', "");
Expect(0, 65791, '\p{^Is_Block=	_linear_B_ideograms}', "");
Expect(0, 65791, '\P{Is_Block=	_linear_B_ideograms}', "");
Expect(1, 65791, '\P{^Is_Block=	_linear_B_ideograms}', "");
Expect(0, 65792, '\p{Is_Block=	_linear_B_ideograms}', "");
Expect(1, 65792, '\p{^Is_Block=	_linear_B_ideograms}', "");
Expect(1, 65792, '\P{Is_Block=	_linear_B_ideograms}', "");
Expect(0, 65792, '\P{^Is_Block=	_linear_B_ideograms}', "");
Error('\p{Is_Blk=:=--LINEAR_B_Ideograms}');
Error('\P{Is_Blk=:=--LINEAR_B_Ideograms}');
Expect(1, 65791, '\p{Is_Blk=linearbideograms}', "");
Expect(0, 65791, '\p{^Is_Blk=linearbideograms}', "");
Expect(0, 65791, '\P{Is_Blk=linearbideograms}', "");
Expect(1, 65791, '\P{^Is_Blk=linearbideograms}', "");
Expect(0, 65792, '\p{Is_Blk=linearbideograms}', "");
Expect(1, 65792, '\p{^Is_Blk=linearbideograms}', "");
Expect(1, 65792, '\P{Is_Blk=linearbideograms}', "");
Expect(0, 65792, '\P{^Is_Blk=linearbideograms}', "");
Expect(1, 65791, '\p{Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(0, 65791, '\p{^Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(0, 65791, '\P{Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(1, 65791, '\P{^Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(0, 65792, '\p{Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(1, 65792, '\p{^Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(1, 65792, '\P{Is_Blk=-Linear_B_IDEOGRAMS}', "");
Expect(0, 65792, '\P{^Is_Blk=-Linear_B_IDEOGRAMS}', "");
Error('\p{Block=_:=Linear_B_syllabary}');
Error('\P{Block=_:=Linear_B_syllabary}');
Expect(1, 65663, '\p{Block=linearbsyllabary}', "");
Expect(0, 65663, '\p{^Block=linearbsyllabary}', "");
Expect(0, 65663, '\P{Block=linearbsyllabary}', "");
Expect(1, 65663, '\P{^Block=linearbsyllabary}', "");
Expect(0, 65664, '\p{Block=linearbsyllabary}', "");
Expect(1, 65664, '\p{^Block=linearbsyllabary}', "");
Expect(1, 65664, '\P{Block=linearbsyllabary}', "");
Expect(0, 65664, '\P{^Block=linearbsyllabary}', "");
Expect(1, 65663, '\p{Block=_-Linear_B_SYLLABARY}', "");
Expect(0, 65663, '\p{^Block=_-Linear_B_SYLLABARY}', "");
Expect(0, 65663, '\P{Block=_-Linear_B_SYLLABARY}', "");
Expect(1, 65663, '\P{^Block=_-Linear_B_SYLLABARY}', "");
Expect(0, 65664, '\p{Block=_-Linear_B_SYLLABARY}', "");
Expect(1, 65664, '\p{^Block=_-Linear_B_SYLLABARY}', "");
Expect(1, 65664, '\P{Block=_-Linear_B_SYLLABARY}', "");
Expect(0, 65664, '\P{^Block=_-Linear_B_SYLLABARY}', "");
Error('\p{Blk=:=  linear_B_Syllabary}');
Error('\P{Blk=:=  linear_B_Syllabary}');
Expect(1, 65663, '\p{Blk:linearbsyllabary}', "");
Expect(0, 65663, '\p{^Blk:linearbsyllabary}', "");
Expect(0, 65663, '\P{Blk:linearbsyllabary}', "");
Expect(1, 65663, '\P{^Blk:linearbsyllabary}', "");
Expect(0, 65664, '\p{Blk:linearbsyllabary}', "");
Expect(1, 65664, '\p{^Blk:linearbsyllabary}', "");
Expect(1, 65664, '\P{Blk:linearbsyllabary}', "");
Expect(0, 65664, '\P{^Blk:linearbsyllabary}', "");
Expect(1, 65663, '\p{Blk=_LINEAR_B_Syllabary}', "");
Expect(0, 65663, '\p{^Blk=_LINEAR_B_Syllabary}', "");
Expect(0, 65663, '\P{Blk=_LINEAR_B_Syllabary}', "");
Expect(1, 65663, '\P{^Blk=_LINEAR_B_Syllabary}', "");
Expect(0, 65664, '\p{Blk=_LINEAR_B_Syllabary}', "");
Expect(1, 65664, '\p{^Blk=_LINEAR_B_Syllabary}', "");
Expect(1, 65664, '\P{Blk=_LINEAR_B_Syllabary}', "");
Expect(0, 65664, '\P{^Blk=_LINEAR_B_Syllabary}', "");
Error('\p{Is_Block=	/a/Linear_b_syllabary}');
Error('\P{Is_Block=	/a/Linear_b_syllabary}');
Expect(1, 65663, '\p{Is_Block=linearbsyllabary}', "");
Expect(0, 65663, '\p{^Is_Block=linearbsyllabary}', "");
Expect(0, 65663, '\P{Is_Block=linearbsyllabary}', "");
Expect(1, 65663, '\P{^Is_Block=linearbsyllabary}', "");
Expect(0, 65664, '\p{Is_Block=linearbsyllabary}', "");
Expect(1, 65664, '\p{^Is_Block=linearbsyllabary}', "");
Expect(1, 65664, '\P{Is_Block=linearbsyllabary}', "");
Expect(0, 65664, '\P{^Is_Block=linearbsyllabary}', "");
Expect(1, 65663, '\p{Is_Block=-Linear_b_syllabary}', "");
Expect(0, 65663, '\p{^Is_Block=-Linear_b_syllabary}', "");
Expect(0, 65663, '\P{Is_Block=-Linear_b_syllabary}', "");
Expect(1, 65663, '\P{^Is_Block=-Linear_b_syllabary}', "");
Expect(0, 65664, '\p{Is_Block=-Linear_b_syllabary}', "");
Expect(1, 65664, '\p{^Is_Block=-Linear_b_syllabary}', "");
Expect(1, 65664, '\P{Is_Block=-Linear_b_syllabary}', "");
Expect(0, 65664, '\P{^Is_Block=-Linear_b_syllabary}', "");
Error('\p{Is_Blk=:=linear_B_syllabary}');
Error('\P{Is_Blk=:=linear_B_syllabary}');
Expect(1, 65663, '\p{Is_Blk: linearbsyllabary}', "");
Expect(0, 65663, '\p{^Is_Blk: linearbsyllabary}', "");
Expect(0, 65663, '\P{Is_Blk: linearbsyllabary}', "");
Expect(1, 65663, '\P{^Is_Blk: linearbsyllabary}', "");
Expect(0, 65664, '\p{Is_Blk: linearbsyllabary}', "");
Expect(1, 65664, '\p{^Is_Blk: linearbsyllabary}', "");
Expect(1, 65664, '\P{Is_Blk: linearbsyllabary}', "");
Expect(0, 65664, '\P{^Is_Blk: linearbsyllabary}', "");
Expect(1, 65663, '\p{Is_Blk=	 linear_b_Syllabary}', "");
Expect(0, 65663, '\p{^Is_Blk=	 linear_b_Syllabary}', "");
Expect(0, 65663, '\P{Is_Blk=	 linear_b_Syllabary}', "");
Expect(1, 65663, '\P{^Is_Blk=	 linear_b_Syllabary}', "");
Expect(0, 65664, '\p{Is_Blk=	 linear_b_Syllabary}', "");
Expect(1, 65664, '\p{^Is_Blk=	 linear_b_Syllabary}', "");
Expect(1, 65664, '\P{Is_Blk=	 linear_b_Syllabary}', "");
Expect(0, 65664, '\P{^Is_Blk=	 linear_b_Syllabary}', "");
Error('\p{Block=:=	Lisu}');
Error('\P{Block=:=	Lisu}');
Expect(1, 42239, '\p{Block=lisu}', "");
Expect(0, 42239, '\p{^Block=lisu}', "");
Expect(0, 42239, '\P{Block=lisu}', "");
Expect(1, 42239, '\P{^Block=lisu}', "");
Expect(0, 42240, '\p{Block=lisu}', "");
Expect(1, 42240, '\p{^Block=lisu}', "");
Expect(1, 42240, '\P{Block=lisu}', "");
Expect(0, 42240, '\P{^Block=lisu}', "");
Error('\p{Blk= /a/Lisu}');
Error('\P{Blk= /a/Lisu}');
Expect(1, 42239, '\p{Blk=lisu}', "");
Expect(0, 42239, '\p{^Blk=lisu}', "");
Expect(0, 42239, '\P{Blk=lisu}', "");
Expect(1, 42239, '\P{^Blk=lisu}', "");
Expect(0, 42240, '\p{Blk=lisu}', "");
Expect(1, 42240, '\p{^Blk=lisu}', "");
Expect(1, 42240, '\P{Blk=lisu}', "");
Expect(0, 42240, '\P{^Blk=lisu}', "");
Expect(1, 42239, '\p{Blk=  Lisu}', "");
Expect(0, 42239, '\p{^Blk=  Lisu}', "");
Expect(0, 42239, '\P{Blk=  Lisu}', "");
Expect(1, 42239, '\P{^Blk=  Lisu}', "");
Expect(0, 42240, '\p{Blk=  Lisu}', "");
Expect(1, 42240, '\p{^Blk=  Lisu}', "");
Expect(1, 42240, '\P{Blk=  Lisu}', "");
Expect(0, 42240, '\P{^Blk=  Lisu}', "");
Error('\p{Is_Block=-:=Lisu}');
Error('\P{Is_Block=-:=Lisu}');
Expect(1, 42239, '\p{Is_Block: lisu}', "");
Expect(0, 42239, '\p{^Is_Block: lisu}', "");
Expect(0, 42239, '\P{Is_Block: lisu}', "");
Expect(1, 42239, '\P{^Is_Block: lisu}', "");
Expect(0, 42240, '\p{Is_Block: lisu}', "");
Expect(1, 42240, '\p{^Is_Block: lisu}', "");
Expect(1, 42240, '\P{Is_Block: lisu}', "");
Expect(0, 42240, '\P{^Is_Block: lisu}', "");
Expect(1, 42239, '\p{Is_Block:    lisu}', "");
Expect(0, 42239, '\p{^Is_Block:    lisu}', "");
Expect(0, 42239, '\P{Is_Block:    lisu}', "");
Expect(1, 42239, '\P{^Is_Block:    lisu}', "");
Expect(0, 42240, '\p{Is_Block:    lisu}', "");
Expect(1, 42240, '\p{^Is_Block:    lisu}', "");
Expect(1, 42240, '\P{Is_Block:    lisu}', "");
Expect(0, 42240, '\P{^Is_Block:    lisu}', "");
Error('\p{Is_Blk= :=lisu}');
Error('\P{Is_Blk= :=lisu}');
Expect(1, 42239, '\p{Is_Blk=lisu}', "");
Expect(0, 42239, '\p{^Is_Blk=lisu}', "");
Expect(0, 42239, '\P{Is_Blk=lisu}', "");
Expect(1, 42239, '\P{^Is_Blk=lisu}', "");
Expect(0, 42240, '\p{Is_Blk=lisu}', "");
Expect(1, 42240, '\p{^Is_Blk=lisu}', "");
Expect(1, 42240, '\P{Is_Blk=lisu}', "");
Expect(0, 42240, '\P{^Is_Blk=lisu}', "");
Expect(1, 42239, '\p{Is_Blk:   _lisu}', "");
Expect(0, 42239, '\p{^Is_Blk:   _lisu}', "");
Expect(0, 42239, '\P{Is_Blk:   _lisu}', "");
Expect(1, 42239, '\P{^Is_Blk:   _lisu}', "");
Expect(0, 42240, '\p{Is_Blk:   _lisu}', "");
Expect(1, 42240, '\p{^Is_Blk:   _lisu}', "");
Expect(1, 42240, '\P{Is_Blk:   _lisu}', "");
Expect(0, 42240, '\P{^Is_Blk:   _lisu}', "");
Error('\p{Block:--low_Surrogates:=}');
Error('\P{Block:--low_Surrogates:=}');
Expect(1, 57343, '\p{Block=lowsurrogates}', "");
Expect(0, 57343, '\p{^Block=lowsurrogates}', "");
Expect(0, 57343, '\P{Block=lowsurrogates}', "");
Expect(1, 57343, '\P{^Block=lowsurrogates}', "");
Expect(0, 57344, '\p{Block=lowsurrogates}', "");
Expect(1, 57344, '\p{^Block=lowsurrogates}', "");
Expect(1, 57344, '\P{Block=lowsurrogates}', "");
Expect(0, 57344, '\P{^Block=lowsurrogates}', "");
Expect(1, 57343, '\p{Block=	Low_Surrogates}', "");
Expect(0, 57343, '\p{^Block=	Low_Surrogates}', "");
Expect(0, 57343, '\P{Block=	Low_Surrogates}', "");
Expect(1, 57343, '\P{^Block=	Low_Surrogates}', "");
Expect(0, 57344, '\p{Block=	Low_Surrogates}', "");
Expect(1, 57344, '\p{^Block=	Low_Surrogates}', "");
Expect(1, 57344, '\P{Block=	Low_Surrogates}', "");
Expect(0, 57344, '\P{^Block=	Low_Surrogates}', "");
Error('\p{Blk=- Low_Surrogates/a/}');
Error('\P{Blk=- Low_Surrogates/a/}');
Expect(1, 57343, '\p{Blk=lowsurrogates}', "");
Expect(0, 57343, '\p{^Blk=lowsurrogates}', "");
Expect(0, 57343, '\P{Blk=lowsurrogates}', "");
Expect(1, 57343, '\P{^Blk=lowsurrogates}', "");
Expect(0, 57344, '\p{Blk=lowsurrogates}', "");
Expect(1, 57344, '\p{^Blk=lowsurrogates}', "");
Expect(1, 57344, '\P{Blk=lowsurrogates}', "");
Expect(0, 57344, '\P{^Blk=lowsurrogates}', "");
Expect(1, 57343, '\p{Blk:	_Low_SURROGATES}', "");
Expect(0, 57343, '\p{^Blk:	_Low_SURROGATES}', "");
Expect(0, 57343, '\P{Blk:	_Low_SURROGATES}', "");
Expect(1, 57343, '\P{^Blk:	_Low_SURROGATES}', "");
Expect(0, 57344, '\p{Blk:	_Low_SURROGATES}', "");
Expect(1, 57344, '\p{^Blk:	_Low_SURROGATES}', "");
Expect(1, 57344, '\P{Blk:	_Low_SURROGATES}', "");
Expect(0, 57344, '\P{^Blk:	_Low_SURROGATES}', "");
Error('\p{Is_Block=	low_surrogates/a/}');
Error('\P{Is_Block=	low_surrogates/a/}');
Expect(1, 57343, '\p{Is_Block=lowsurrogates}', "");
Expect(0, 57343, '\p{^Is_Block=lowsurrogates}', "");
Expect(0, 57343, '\P{Is_Block=lowsurrogates}', "");
Expect(1, 57343, '\P{^Is_Block=lowsurrogates}', "");
Expect(0, 57344, '\p{Is_Block=lowsurrogates}', "");
Expect(1, 57344, '\p{^Is_Block=lowsurrogates}', "");
Expect(1, 57344, '\P{Is_Block=lowsurrogates}', "");
Expect(0, 57344, '\P{^Is_Block=lowsurrogates}', "");
Expect(1, 57343, '\p{Is_Block=- low_SURROGATES}', "");
Expect(0, 57343, '\p{^Is_Block=- low_SURROGATES}', "");
Expect(0, 57343, '\P{Is_Block=- low_SURROGATES}', "");
Expect(1, 57343, '\P{^Is_Block=- low_SURROGATES}', "");
Expect(0, 57344, '\p{Is_Block=- low_SURROGATES}', "");
Expect(1, 57344, '\p{^Is_Block=- low_SURROGATES}', "");
Expect(1, 57344, '\P{Is_Block=- low_SURROGATES}', "");
Expect(0, 57344, '\P{^Is_Block=- low_SURROGATES}', "");
Error('\p{Is_Blk=  Low_Surrogates/a/}');
Error('\P{Is_Blk=  Low_Surrogates/a/}');
Expect(1, 57343, '\p{Is_Blk=lowsurrogates}', "");
Expect(0, 57343, '\p{^Is_Blk=lowsurrogates}', "");
Expect(0, 57343, '\P{Is_Blk=lowsurrogates}', "");
Expect(1, 57343, '\P{^Is_Blk=lowsurrogates}', "");
Expect(0, 57344, '\p{Is_Blk=lowsurrogates}', "");
Expect(1, 57344, '\p{^Is_Blk=lowsurrogates}', "");
Expect(1, 57344, '\P{Is_Blk=lowsurrogates}', "");
Expect(0, 57344, '\P{^Is_Blk=lowsurrogates}', "");
Expect(1, 57343, '\p{Is_Blk=-	Low_SURROGATES}', "");
Expect(0, 57343, '\p{^Is_Blk=-	Low_SURROGATES}', "");
Expect(0, 57343, '\P{Is_Blk=-	Low_SURROGATES}', "");
Expect(1, 57343, '\P{^Is_Blk=-	Low_SURROGATES}', "");
Expect(0, 57344, '\p{Is_Blk=-	Low_SURROGATES}', "");
Expect(1, 57344, '\p{^Is_Blk=-	Low_SURROGATES}', "");
Expect(1, 57344, '\P{Is_Blk=-	Low_SURROGATES}', "");
Expect(0, 57344, '\P{^Is_Blk=-	Low_SURROGATES}', "");
Error('\p{Block=:=_-lycian}');
Error('\P{Block=:=_-lycian}');
Expect(1, 66207, '\p{Block=lycian}', "");
Expect(0, 66207, '\p{^Block=lycian}', "");
Expect(0, 66207, '\P{Block=lycian}', "");
Expect(1, 66207, '\P{^Block=lycian}', "");
Expect(0, 66208, '\p{Block=lycian}', "");
Expect(1, 66208, '\p{^Block=lycian}', "");
Expect(1, 66208, '\P{Block=lycian}', "");
Expect(0, 66208, '\P{^Block=lycian}', "");
Expect(1, 66207, '\p{Block=-LYCIAN}', "");
Expect(0, 66207, '\p{^Block=-LYCIAN}', "");
Expect(0, 66207, '\P{Block=-LYCIAN}', "");
Expect(1, 66207, '\P{^Block=-LYCIAN}', "");
Expect(0, 66208, '\p{Block=-LYCIAN}', "");
Expect(1, 66208, '\p{^Block=-LYCIAN}', "");
Expect(1, 66208, '\P{Block=-LYCIAN}', "");
Expect(0, 66208, '\P{^Block=-LYCIAN}', "");
Error('\p{Blk=/a/Lycian}');
Error('\P{Blk=/a/Lycian}');
Expect(1, 66207, '\p{Blk=lycian}', "");
Expect(0, 66207, '\p{^Blk=lycian}', "");
Expect(0, 66207, '\P{Blk=lycian}', "");
Expect(1, 66207, '\P{^Blk=lycian}', "");
Expect(0, 66208, '\p{Blk=lycian}', "");
Expect(1, 66208, '\p{^Blk=lycian}', "");
Expect(1, 66208, '\P{Blk=lycian}', "");
Expect(0, 66208, '\P{^Blk=lycian}', "");
Expect(1, 66207, '\p{Blk=		Lycian}', "");
Expect(0, 66207, '\p{^Blk=		Lycian}', "");
Expect(0, 66207, '\P{Blk=		Lycian}', "");
Expect(1, 66207, '\P{^Blk=		Lycian}', "");
Expect(0, 66208, '\p{Blk=		Lycian}', "");
Expect(1, 66208, '\p{^Blk=		Lycian}', "");
Expect(1, 66208, '\P{Blk=		Lycian}', "");
Expect(0, 66208, '\P{^Blk=		Lycian}', "");
Error('\p{Is_Block=_LYCIAN/a/}');
Error('\P{Is_Block=_LYCIAN/a/}');
Expect(1, 66207, '\p{Is_Block:lycian}', "");
Expect(0, 66207, '\p{^Is_Block:lycian}', "");
Expect(0, 66207, '\P{Is_Block:lycian}', "");
Expect(1, 66207, '\P{^Is_Block:lycian}', "");
Expect(0, 66208, '\p{Is_Block:lycian}', "");
Expect(1, 66208, '\p{^Is_Block:lycian}', "");
Expect(1, 66208, '\P{Is_Block:lycian}', "");
Expect(0, 66208, '\P{^Is_Block:lycian}', "");
Expect(1, 66207, '\p{Is_Block=-	Lycian}', "");
Expect(0, 66207, '\p{^Is_Block=-	Lycian}', "");
Expect(0, 66207, '\P{Is_Block=-	Lycian}', "");
Expect(1, 66207, '\P{^Is_Block=-	Lycian}', "");
Expect(0, 66208, '\p{Is_Block=-	Lycian}', "");
Expect(1, 66208, '\p{^Is_Block=-	Lycian}', "");
Expect(1, 66208, '\P{Is_Block=-	Lycian}', "");
Expect(0, 66208, '\P{^Is_Block=-	Lycian}', "");
Error('\p{Is_Blk= lycian/a/}');
Error('\P{Is_Blk= lycian/a/}');
Expect(1, 66207, '\p{Is_Blk=lycian}', "");
Expect(0, 66207, '\p{^Is_Blk=lycian}', "");
Expect(0, 66207, '\P{Is_Blk=lycian}', "");
Expect(1, 66207, '\P{^Is_Blk=lycian}', "");
Expect(0, 66208, '\p{Is_Blk=lycian}', "");
Expect(1, 66208, '\p{^Is_Blk=lycian}', "");
Expect(1, 66208, '\P{Is_Blk=lycian}', "");
Expect(0, 66208, '\P{^Is_Blk=lycian}', "");
Expect(1, 66207, '\p{Is_Blk=Lycian}', "");
Expect(0, 66207, '\p{^Is_Blk=Lycian}', "");
Expect(0, 66207, '\P{Is_Blk=Lycian}', "");
Expect(1, 66207, '\P{^Is_Blk=Lycian}', "");
Expect(0, 66208, '\p{Is_Blk=Lycian}', "");
Expect(1, 66208, '\p{^Is_Blk=Lycian}', "");
Expect(1, 66208, '\P{Is_Blk=Lycian}', "");
Expect(0, 66208, '\P{^Is_Blk=Lycian}', "");
Error('\p{Block=:=_Lydian}');
Error('\P{Block=:=_Lydian}');
Expect(1, 67903, '\p{Block=lydian}', "");
Expect(0, 67903, '\p{^Block=lydian}', "");
Expect(0, 67903, '\P{Block=lydian}', "");
Expect(1, 67903, '\P{^Block=lydian}', "");
Expect(0, 67904, '\p{Block=lydian}', "");
Expect(1, 67904, '\p{^Block=lydian}', "");
Expect(1, 67904, '\P{Block=lydian}', "");
Expect(0, 67904, '\P{^Block=lydian}', "");
Expect(1, 67903, '\p{Block=_	Lydian}', "");
Expect(0, 67903, '\p{^Block=_	Lydian}', "");
Expect(0, 67903, '\P{Block=_	Lydian}', "");
Expect(1, 67903, '\P{^Block=_	Lydian}', "");
Expect(0, 67904, '\p{Block=_	Lydian}', "");
Expect(1, 67904, '\p{^Block=_	Lydian}', "");
Expect(1, 67904, '\P{Block=_	Lydian}', "");
Expect(0, 67904, '\P{^Block=_	Lydian}', "");
Error('\p{Blk=_/a/lydian}');
Error('\P{Blk=_/a/lydian}');
Expect(1, 67903, '\p{Blk=lydian}', "");
Expect(0, 67903, '\p{^Blk=lydian}', "");
Expect(0, 67903, '\P{Blk=lydian}', "");
Expect(1, 67903, '\P{^Blk=lydian}', "");
Expect(0, 67904, '\p{Blk=lydian}', "");
Expect(1, 67904, '\p{^Blk=lydian}', "");
Expect(1, 67904, '\P{Blk=lydian}', "");
Expect(0, 67904, '\P{^Blk=lydian}', "");
Expect(1, 67903, '\p{Blk:  Lydian}', "");
Expect(0, 67903, '\p{^Blk:  Lydian}', "");
Expect(0, 67903, '\P{Blk:  Lydian}', "");
Expect(1, 67903, '\P{^Blk:  Lydian}', "");
Expect(0, 67904, '\p{Blk:  Lydian}', "");
Expect(1, 67904, '\p{^Blk:  Lydian}', "");
Expect(1, 67904, '\P{Blk:  Lydian}', "");
Expect(0, 67904, '\P{^Blk:  Lydian}', "");
Error('\p{Is_Block=__Lydian/a/}');
Error('\P{Is_Block=__Lydian/a/}');
Expect(1, 67903, '\p{Is_Block=lydian}', "");
Expect(0, 67903, '\p{^Is_Block=lydian}', "");
Expect(0, 67903, '\P{Is_Block=lydian}', "");
Expect(1, 67903, '\P{^Is_Block=lydian}', "");
Expect(0, 67904, '\p{Is_Block=lydian}', "");
Expect(1, 67904, '\p{^Is_Block=lydian}', "");
Expect(1, 67904, '\P{Is_Block=lydian}', "");
Expect(0, 67904, '\P{^Is_Block=lydian}', "");
Expect(1, 67903, '\p{Is_Block=__Lydian}', "");
Expect(0, 67903, '\p{^Is_Block=__Lydian}', "");
Expect(0, 67903, '\P{Is_Block=__Lydian}', "");
Expect(1, 67903, '\P{^Is_Block=__Lydian}', "");
Expect(0, 67904, '\p{Is_Block=__Lydian}', "");
Expect(1, 67904, '\p{^Is_Block=__Lydian}', "");
Expect(1, 67904, '\P{Is_Block=__Lydian}', "");
Expect(0, 67904, '\P{^Is_Block=__Lydian}', "");
Error('\p{Is_Blk=:=	-Lydian}');
Error('\P{Is_Blk=:=	-Lydian}');
Expect(1, 67903, '\p{Is_Blk=lydian}', "");
Expect(0, 67903, '\p{^Is_Blk=lydian}', "");
Expect(0, 67903, '\P{Is_Blk=lydian}', "");
Expect(1, 67903, '\P{^Is_Blk=lydian}', "");
Expect(0, 67904, '\p{Is_Blk=lydian}', "");
Expect(1, 67904, '\p{^Is_Blk=lydian}', "");
Expect(1, 67904, '\P{Is_Blk=lydian}', "");
Expect(0, 67904, '\P{^Is_Blk=lydian}', "");
Expect(1, 67903, '\p{Is_Blk=		Lydian}', "");
Expect(0, 67903, '\p{^Is_Blk=		Lydian}', "");
Expect(0, 67903, '\P{Is_Blk=		Lydian}', "");
Expect(1, 67903, '\P{^Is_Blk=		Lydian}', "");
Expect(0, 67904, '\p{Is_Blk=		Lydian}', "");
Expect(1, 67904, '\p{^Is_Blk=		Lydian}', "");
Expect(1, 67904, '\P{Is_Blk=		Lydian}', "");
Expect(0, 67904, '\P{^Is_Blk=		Lydian}', "");
Error('\p{Block=-:=mahjong_tiles}');
Error('\P{Block=-:=mahjong_tiles}');
Expect(1, 127023, '\p{Block=mahjongtiles}', "");
Expect(0, 127023, '\p{^Block=mahjongtiles}', "");
Expect(0, 127023, '\P{Block=mahjongtiles}', "");
Expect(1, 127023, '\P{^Block=mahjongtiles}', "");
Expect(0, 127024, '\p{Block=mahjongtiles}', "");
Expect(1, 127024, '\p{^Block=mahjongtiles}', "");
Expect(1, 127024, '\P{Block=mahjongtiles}', "");
Expect(0, 127024, '\P{^Block=mahjongtiles}', "");
Expect(1, 127023, '\p{Block= _MAHJONG_tiles}', "");
Expect(0, 127023, '\p{^Block= _MAHJONG_tiles}', "");
Expect(0, 127023, '\P{Block= _MAHJONG_tiles}', "");
Expect(1, 127023, '\P{^Block= _MAHJONG_tiles}', "");
Expect(0, 127024, '\p{Block= _MAHJONG_tiles}', "");
Expect(1, 127024, '\p{^Block= _MAHJONG_tiles}', "");
Expect(1, 127024, '\P{Block= _MAHJONG_tiles}', "");
Expect(0, 127024, '\P{^Block= _MAHJONG_tiles}', "");
Error('\p{Blk= Mahjong/a/}');
Error('\P{Blk= Mahjong/a/}');
Expect(1, 127023, '\p{Blk=mahjong}', "");
Expect(0, 127023, '\p{^Blk=mahjong}', "");
Expect(0, 127023, '\P{Blk=mahjong}', "");
Expect(1, 127023, '\P{^Blk=mahjong}', "");
Expect(0, 127024, '\p{Blk=mahjong}', "");
Expect(1, 127024, '\p{^Blk=mahjong}', "");
Expect(1, 127024, '\P{Blk=mahjong}', "");
Expect(0, 127024, '\P{^Blk=mahjong}', "");
Expect(1, 127023, '\p{Blk=_-Mahjong}', "");
Expect(0, 127023, '\p{^Blk=_-Mahjong}', "");
Expect(0, 127023, '\P{Blk=_-Mahjong}', "");
Expect(1, 127023, '\P{^Blk=_-Mahjong}', "");
Expect(0, 127024, '\p{Blk=_-Mahjong}', "");
Expect(1, 127024, '\p{^Blk=_-Mahjong}', "");
Expect(1, 127024, '\P{Blk=_-Mahjong}', "");
Expect(0, 127024, '\P{^Blk=_-Mahjong}', "");
Error('\p{Is_Block=/a/_	MAHJONG_Tiles}');
Error('\P{Is_Block=/a/_	MAHJONG_Tiles}');
Expect(1, 127023, '\p{Is_Block=mahjongtiles}', "");
Expect(0, 127023, '\p{^Is_Block=mahjongtiles}', "");
Expect(0, 127023, '\P{Is_Block=mahjongtiles}', "");
Expect(1, 127023, '\P{^Is_Block=mahjongtiles}', "");
Expect(0, 127024, '\p{Is_Block=mahjongtiles}', "");
Expect(1, 127024, '\p{^Is_Block=mahjongtiles}', "");
Expect(1, 127024, '\P{Is_Block=mahjongtiles}', "");
Expect(0, 127024, '\P{^Is_Block=mahjongtiles}', "");
Expect(1, 127023, '\p{Is_Block= _MAHJONG_tiles}', "");
Expect(0, 127023, '\p{^Is_Block= _MAHJONG_tiles}', "");
Expect(0, 127023, '\P{Is_Block= _MAHJONG_tiles}', "");
Expect(1, 127023, '\P{^Is_Block= _MAHJONG_tiles}', "");
Expect(0, 127024, '\p{Is_Block= _MAHJONG_tiles}', "");
Expect(1, 127024, '\p{^Is_Block= _MAHJONG_tiles}', "");
Expect(1, 127024, '\P{Is_Block= _MAHJONG_tiles}', "");
Expect(0, 127024, '\P{^Is_Block= _MAHJONG_tiles}', "");
Error('\p{Is_Blk=	mahjong:=}');
Error('\P{Is_Blk=	mahjong:=}');
Expect(1, 127023, '\p{Is_Blk=mahjong}', "");
Expect(0, 127023, '\p{^Is_Blk=mahjong}', "");
Expect(0, 127023, '\P{Is_Blk=mahjong}', "");
Expect(1, 127023, '\P{^Is_Blk=mahjong}', "");
Expect(0, 127024, '\p{Is_Blk=mahjong}', "");
Expect(1, 127024, '\p{^Is_Blk=mahjong}', "");
Expect(1, 127024, '\P{Is_Blk=mahjong}', "");
Expect(0, 127024, '\P{^Is_Blk=mahjong}', "");
Expect(1, 127023, '\p{Is_Blk=_Mahjong}', "");
Expect(0, 127023, '\p{^Is_Blk=_Mahjong}', "");
Expect(0, 127023, '\P{Is_Blk=_Mahjong}', "");
Expect(1, 127023, '\P{^Is_Blk=_Mahjong}', "");
Expect(0, 127024, '\p{Is_Blk=_Mahjong}', "");
Expect(1, 127024, '\p{^Is_Blk=_Mahjong}', "");
Expect(1, 127024, '\P{Is_Blk=_Mahjong}', "");
Expect(0, 127024, '\P{^Is_Blk=_Mahjong}', "");
Error('\p{Block=		malayalam:=}');
Error('\P{Block=		malayalam:=}');
Expect(1, 3455, '\p{Block=malayalam}', "");
Expect(0, 3455, '\p{^Block=malayalam}', "");
Expect(0, 3455, '\P{Block=malayalam}', "");
Expect(1, 3455, '\P{^Block=malayalam}', "");
Expect(0, 3456, '\p{Block=malayalam}', "");
Expect(1, 3456, '\p{^Block=malayalam}', "");
Expect(1, 3456, '\P{Block=malayalam}', "");
Expect(0, 3456, '\P{^Block=malayalam}', "");
Expect(1, 3455, '\p{Block=__MALAYALAM}', "");
Expect(0, 3455, '\p{^Block=__MALAYALAM}', "");
Expect(0, 3455, '\P{Block=__MALAYALAM}', "");
Expect(1, 3455, '\P{^Block=__MALAYALAM}', "");
Expect(0, 3456, '\p{Block=__MALAYALAM}', "");
Expect(1, 3456, '\p{^Block=__MALAYALAM}', "");
Expect(1, 3456, '\P{Block=__MALAYALAM}', "");
Expect(0, 3456, '\P{^Block=__MALAYALAM}', "");
Error('\p{Blk=/a/-_MALAYALAM}');
Error('\P{Blk=/a/-_MALAYALAM}');
Expect(1, 3455, '\p{Blk=malayalam}', "");
Expect(0, 3455, '\p{^Blk=malayalam}', "");
Expect(0, 3455, '\P{Blk=malayalam}', "");
Expect(1, 3455, '\P{^Blk=malayalam}', "");
Expect(0, 3456, '\p{Blk=malayalam}', "");
Expect(1, 3456, '\p{^Blk=malayalam}', "");
Expect(1, 3456, '\P{Blk=malayalam}', "");
Expect(0, 3456, '\P{^Blk=malayalam}', "");
Expect(1, 3455, '\p{Blk=-Malayalam}', "");
Expect(0, 3455, '\p{^Blk=-Malayalam}', "");
Expect(0, 3455, '\P{Blk=-Malayalam}', "");
Expect(1, 3455, '\P{^Blk=-Malayalam}', "");
Expect(0, 3456, '\p{Blk=-Malayalam}', "");
Expect(1, 3456, '\p{^Blk=-Malayalam}', "");
Expect(1, 3456, '\P{Blk=-Malayalam}', "");
Expect(0, 3456, '\P{^Blk=-Malayalam}', "");
Error('\p{Is_Block=:=	MALAYALAM}');
Error('\P{Is_Block=:=	MALAYALAM}');
Expect(1, 3455, '\p{Is_Block=malayalam}', "");
Expect(0, 3455, '\p{^Is_Block=malayalam}', "");
Expect(0, 3455, '\P{Is_Block=malayalam}', "");
Expect(1, 3455, '\P{^Is_Block=malayalam}', "");
Expect(0, 3456, '\p{Is_Block=malayalam}', "");
Expect(1, 3456, '\p{^Is_Block=malayalam}', "");
Expect(1, 3456, '\P{Is_Block=malayalam}', "");
Expect(0, 3456, '\P{^Is_Block=malayalam}', "");
Expect(1, 3455, '\p{Is_Block=	MALAYALAM}', "");
Expect(0, 3455, '\p{^Is_Block=	MALAYALAM}', "");
Expect(0, 3455, '\P{Is_Block=	MALAYALAM}', "");
Expect(1, 3455, '\P{^Is_Block=	MALAYALAM}', "");
Expect(0, 3456, '\p{Is_Block=	MALAYALAM}', "");
Expect(1, 3456, '\p{^Is_Block=	MALAYALAM}', "");
Expect(1, 3456, '\P{Is_Block=	MALAYALAM}', "");
Expect(0, 3456, '\P{^Is_Block=	MALAYALAM}', "");
Error('\p{Is_Blk=/a/Malayalam}');
Error('\P{Is_Blk=/a/Malayalam}');
Expect(1, 3455, '\p{Is_Blk=malayalam}', "");
Expect(0, 3455, '\p{^Is_Blk=malayalam}', "");
Expect(0, 3455, '\P{Is_Blk=malayalam}', "");
Expect(1, 3455, '\P{^Is_Blk=malayalam}', "");
Expect(0, 3456, '\p{Is_Blk=malayalam}', "");
Expect(1, 3456, '\p{^Is_Blk=malayalam}', "");
Expect(1, 3456, '\P{Is_Blk=malayalam}', "");
Expect(0, 3456, '\P{^Is_Blk=malayalam}', "");
Expect(1, 3455, '\p{Is_Blk=		MALAYALAM}', "");
Expect(0, 3455, '\p{^Is_Blk=		MALAYALAM}', "");
Expect(0, 3455, '\P{Is_Blk=		MALAYALAM}', "");
Expect(1, 3455, '\P{^Is_Blk=		MALAYALAM}', "");
Expect(0, 3456, '\p{Is_Blk=		MALAYALAM}', "");
Expect(1, 3456, '\p{^Is_Blk=		MALAYALAM}', "");
Expect(1, 3456, '\P{Is_Blk=		MALAYALAM}', "");
Expect(0, 3456, '\P{^Is_Blk=		MALAYALAM}', "");
Error('\p{Block=:=	 Mandaic}');
Error('\P{Block=:=	 Mandaic}');
Expect(1, 2143, '\p{Block=mandaic}', "");
Expect(0, 2143, '\p{^Block=mandaic}', "");
Expect(0, 2143, '\P{Block=mandaic}', "");
Expect(1, 2143, '\P{^Block=mandaic}', "");
Expect(0, 2144, '\p{Block=mandaic}', "");
Expect(1, 2144, '\p{^Block=mandaic}', "");
Expect(1, 2144, '\P{Block=mandaic}', "");
Expect(0, 2144, '\P{^Block=mandaic}', "");
Expect(1, 2143, '\p{Block= 	Mandaic}', "");
Expect(0, 2143, '\p{^Block= 	Mandaic}', "");
Expect(0, 2143, '\P{Block= 	Mandaic}', "");
Expect(1, 2143, '\P{^Block= 	Mandaic}', "");
Expect(0, 2144, '\p{Block= 	Mandaic}', "");
Expect(1, 2144, '\p{^Block= 	Mandaic}', "");
Expect(1, 2144, '\P{Block= 	Mandaic}', "");
Expect(0, 2144, '\P{^Block= 	Mandaic}', "");
Error('\p{Blk= :=Mandaic}');
Error('\P{Blk= :=Mandaic}');
Expect(1, 2143, '\p{Blk: mandaic}', "");
Expect(0, 2143, '\p{^Blk: mandaic}', "");
Expect(0, 2143, '\P{Blk: mandaic}', "");
Expect(1, 2143, '\P{^Blk: mandaic}', "");
Expect(0, 2144, '\p{Blk: mandaic}', "");
Expect(1, 2144, '\p{^Blk: mandaic}', "");
Expect(1, 2144, '\P{Blk: mandaic}', "");
Expect(0, 2144, '\P{^Blk: mandaic}', "");
Expect(1, 2143, '\p{Blk= 	mandaic}', "");
Expect(0, 2143, '\p{^Blk= 	mandaic}', "");
Expect(0, 2143, '\P{Blk= 	mandaic}', "");
Expect(1, 2143, '\P{^Blk= 	mandaic}', "");
Expect(0, 2144, '\p{Blk= 	mandaic}', "");
Expect(1, 2144, '\p{^Blk= 	mandaic}', "");
Expect(1, 2144, '\P{Blk= 	mandaic}', "");
Expect(0, 2144, '\P{^Blk= 	mandaic}', "");
Error('\p{Is_Block: 		mandaic:=}');
Error('\P{Is_Block: 		mandaic:=}');
Expect(1, 2143, '\p{Is_Block=mandaic}', "");
Expect(0, 2143, '\p{^Is_Block=mandaic}', "");
Expect(0, 2143, '\P{Is_Block=mandaic}', "");
Expect(1, 2143, '\P{^Is_Block=mandaic}', "");
Expect(0, 2144, '\p{Is_Block=mandaic}', "");
Expect(1, 2144, '\p{^Is_Block=mandaic}', "");
Expect(1, 2144, '\P{Is_Block=mandaic}', "");
Expect(0, 2144, '\P{^Is_Block=mandaic}', "");
Expect(1, 2143, '\p{Is_Block=	Mandaic}', "");
Expect(0, 2143, '\p{^Is_Block=	Mandaic}', "");
Expect(0, 2143, '\P{Is_Block=	Mandaic}', "");
Expect(1, 2143, '\P{^Is_Block=	Mandaic}', "");
Expect(0, 2144, '\p{Is_Block=	Mandaic}', "");
Expect(1, 2144, '\p{^Is_Block=	Mandaic}', "");
Expect(1, 2144, '\P{Is_Block=	Mandaic}', "");
Expect(0, 2144, '\P{^Is_Block=	Mandaic}', "");
Error('\p{Is_Blk=:=	 MANDAIC}');
Error('\P{Is_Blk=:=	 MANDAIC}');
Expect(1, 2143, '\p{Is_Blk=mandaic}', "");
Expect(0, 2143, '\p{^Is_Blk=mandaic}', "");
Expect(0, 2143, '\P{Is_Blk=mandaic}', "");
Expect(1, 2143, '\P{^Is_Blk=mandaic}', "");
Expect(0, 2144, '\p{Is_Blk=mandaic}', "");
Expect(1, 2144, '\p{^Is_Blk=mandaic}', "");
Expect(1, 2144, '\P{Is_Blk=mandaic}', "");
Expect(0, 2144, '\P{^Is_Blk=mandaic}', "");
Expect(1, 2143, '\p{Is_Blk=_ mandaic}', "");
Expect(0, 2143, '\p{^Is_Blk=_ mandaic}', "");
Expect(0, 2143, '\P{Is_Blk=_ mandaic}', "");
Expect(1, 2143, '\P{^Is_Blk=_ mandaic}', "");
Expect(0, 2144, '\p{Is_Blk=_ mandaic}', "");
Expect(1, 2144, '\p{^Is_Blk=_ mandaic}', "");
Expect(1, 2144, '\P{Is_Blk=_ mandaic}', "");
Expect(0, 2144, '\P{^Is_Blk=_ mandaic}', "");
Error('\p{Block=-	MATHEMATICAL_alphanumeric_Symbols/a/}');
Error('\P{Block=-	MATHEMATICAL_alphanumeric_Symbols/a/}');
Expect(1, 120831, '\p{Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(0, 120831, '\p{^Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(0, 120831, '\P{Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(1, 120831, '\P{^Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(0, 120832, '\p{Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(1, 120832, '\p{^Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(1, 120832, '\P{Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Expect(0, 120832, '\P{^Block=- mathematical_Alphanumeric_SYMBOLS}', "");
Error('\p{Blk=:=-	math_ALPHANUM}');
Error('\P{Blk=:=-	math_ALPHANUM}');
Expect(1, 120831, '\p{Blk:   mathalphanum}', "");
Expect(0, 120831, '\p{^Blk:   mathalphanum}', "");
Expect(0, 120831, '\P{Blk:   mathalphanum}', "");
Expect(1, 120831, '\P{^Blk:   mathalphanum}', "");
Expect(0, 120832, '\p{Blk:   mathalphanum}', "");
Expect(1, 120832, '\p{^Blk:   mathalphanum}', "");
Expect(1, 120832, '\P{Blk:   mathalphanum}', "");
Expect(0, 120832, '\P{^Blk:   mathalphanum}', "");
Expect(1, 120831, '\p{Blk= MATH_alphanum}', "");
Expect(0, 120831, '\p{^Blk= MATH_alphanum}', "");
Expect(0, 120831, '\P{Blk= MATH_alphanum}', "");
Expect(1, 120831, '\P{^Blk= MATH_alphanum}', "");
Expect(0, 120832, '\p{Blk= MATH_alphanum}', "");
Expect(1, 120832, '\p{^Blk= MATH_alphanum}', "");
Expect(1, 120832, '\P{Blk= MATH_alphanum}', "");
Expect(0, 120832, '\P{^Blk= MATH_alphanum}', "");
Error('\p{Is_Block=_mathematical_Alphanumeric_SYMBOLS:=}');
Error('\P{Is_Block=_mathematical_Alphanumeric_SYMBOLS:=}');
Expect(1, 120831, '\p{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{Is_Block=mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^Is_Block=mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(0, 120831, '\p{^Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(0, 120831, '\P{Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(1, 120831, '\P{^Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(0, 120832, '\p{Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(1, 120832, '\p{^Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(1, 120832, '\P{Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Expect(0, 120832, '\P{^Is_Block:	_ Mathematical_Alphanumeric_symbols}', "");
Error('\p{Is_Blk=	:=MATH_Alphanum}');
Error('\P{Is_Blk=	:=MATH_Alphanum}');
Expect(1, 120831, '\p{Is_Blk=mathalphanum}', "");
Expect(0, 120831, '\p{^Is_Blk=mathalphanum}', "");
Expect(0, 120831, '\P{Is_Blk=mathalphanum}', "");
Expect(1, 120831, '\P{^Is_Blk=mathalphanum}', "");
Expect(0, 120832, '\p{Is_Blk=mathalphanum}', "");
Expect(1, 120832, '\p{^Is_Blk=mathalphanum}', "");
Expect(1, 120832, '\P{Is_Blk=mathalphanum}', "");
Expect(0, 120832, '\P{^Is_Blk=mathalphanum}', "");
Expect(1, 120831, '\p{Is_Blk=-Math_alphanum}', "");
Expect(0, 120831, '\p{^Is_Blk=-Math_alphanum}', "");
Expect(0, 120831, '\P{Is_Blk=-Math_alphanum}', "");
Expect(1, 120831, '\P{^Is_Blk=-Math_alphanum}', "");
Expect(0, 120832, '\p{Is_Blk=-Math_alphanum}', "");
Expect(1, 120832, '\p{^Is_Blk=-Math_alphanum}', "");
Expect(1, 120832, '\P{Is_Blk=-Math_alphanum}', "");
Expect(0, 120832, '\P{^Is_Blk=-Math_alphanum}', "");
Error('\p{Block=/a/ Mathematical_OPERATORS}');
Error('\P{Block=/a/ Mathematical_OPERATORS}');
Expect(1, 8959, '\p{Block=mathematicaloperators}', "");
Expect(0, 8959, '\p{^Block=mathematicaloperators}', "");
Expect(0, 8959, '\P{Block=mathematicaloperators}', "");
Expect(1, 8959, '\P{^Block=mathematicaloperators}', "");
Expect(0, 8960, '\p{Block=mathematicaloperators}', "");
Expect(1, 8960, '\p{^Block=mathematicaloperators}', "");
Expect(1, 8960, '\P{Block=mathematicaloperators}', "");
Expect(0, 8960, '\P{^Block=mathematicaloperators}', "");
Expect(1, 8959, '\p{Block= Mathematical_Operators}', "");
Expect(0, 8959, '\p{^Block= Mathematical_Operators}', "");
Expect(0, 8959, '\P{Block= Mathematical_Operators}', "");
Expect(1, 8959, '\P{^Block= Mathematical_Operators}', "");
Expect(0, 8960, '\p{Block= Mathematical_Operators}', "");
Expect(1, 8960, '\p{^Block= Mathematical_Operators}', "");
Expect(1, 8960, '\P{Block= Mathematical_Operators}', "");
Expect(0, 8960, '\P{^Block= Mathematical_Operators}', "");
Error('\p{Blk=:=- MATH_Operators}');
Error('\P{Blk=:=- MATH_Operators}');
Expect(1, 8959, '\p{Blk=mathoperators}', "");
Expect(0, 8959, '\p{^Blk=mathoperators}', "");
Expect(0, 8959, '\P{Blk=mathoperators}', "");
Expect(1, 8959, '\P{^Blk=mathoperators}', "");
Expect(0, 8960, '\p{Blk=mathoperators}', "");
Expect(1, 8960, '\p{^Blk=mathoperators}', "");
Expect(1, 8960, '\P{Blk=mathoperators}', "");
Expect(0, 8960, '\P{^Blk=mathoperators}', "");
Expect(1, 8959, '\p{Blk=	Math_operators}', "");
Expect(0, 8959, '\p{^Blk=	Math_operators}', "");
Expect(0, 8959, '\P{Blk=	Math_operators}', "");
Expect(1, 8959, '\P{^Blk=	Math_operators}', "");
Expect(0, 8960, '\p{Blk=	Math_operators}', "");
Expect(1, 8960, '\p{^Blk=	Math_operators}', "");
Expect(1, 8960, '\P{Blk=	Math_operators}', "");
Expect(0, 8960, '\P{^Blk=	Math_operators}', "");
Error('\p{Is_Block= /a/MATHEMATICAL_operators}');
Error('\P{Is_Block= /a/MATHEMATICAL_operators}');
Expect(1, 8959, '\p{Is_Block=mathematicaloperators}', "");
Expect(0, 8959, '\p{^Is_Block=mathematicaloperators}', "");
Expect(0, 8959, '\P{Is_Block=mathematicaloperators}', "");
Expect(1, 8959, '\P{^Is_Block=mathematicaloperators}', "");
Expect(0, 8960, '\p{Is_Block=mathematicaloperators}', "");
Expect(1, 8960, '\p{^Is_Block=mathematicaloperators}', "");
Expect(1, 8960, '\P{Is_Block=mathematicaloperators}', "");
Expect(0, 8960, '\P{^Is_Block=mathematicaloperators}', "");
Expect(1, 8959, '\p{Is_Block= mathematical_Operators}', "");
Expect(0, 8959, '\p{^Is_Block= mathematical_Operators}', "");
Expect(0, 8959, '\P{Is_Block= mathematical_Operators}', "");
Expect(1, 8959, '\P{^Is_Block= mathematical_Operators}', "");
Expect(0, 8960, '\p{Is_Block= mathematical_Operators}', "");
Expect(1, 8960, '\p{^Is_Block= mathematical_Operators}', "");
Expect(1, 8960, '\P{Is_Block= mathematical_Operators}', "");
Expect(0, 8960, '\P{^Is_Block= mathematical_Operators}', "");
Error('\p{Is_Blk=	_Math_OPERATORS:=}');
Error('\P{Is_Blk=	_Math_OPERATORS:=}');
Expect(1, 8959, '\p{Is_Blk: mathoperators}', "");
Expect(0, 8959, '\p{^Is_Blk: mathoperators}', "");
Expect(0, 8959, '\P{Is_Blk: mathoperators}', "");
Expect(1, 8959, '\P{^Is_Blk: mathoperators}', "");
Expect(0, 8960, '\p{Is_Blk: mathoperators}', "");
Expect(1, 8960, '\p{^Is_Blk: mathoperators}', "");
Expect(1, 8960, '\P{Is_Blk: mathoperators}', "");
Expect(0, 8960, '\P{^Is_Blk: mathoperators}', "");
Expect(1, 8959, '\p{Is_Blk=_ math_OPERATORS}', "");
Expect(0, 8959, '\p{^Is_Blk=_ math_OPERATORS}', "");
Expect(0, 8959, '\P{Is_Blk=_ math_OPERATORS}', "");
Expect(1, 8959, '\P{^Is_Blk=_ math_OPERATORS}', "");
Expect(0, 8960, '\p{Is_Blk=_ math_OPERATORS}', "");
Expect(1, 8960, '\p{^Is_Blk=_ math_OPERATORS}', "");
Expect(1, 8960, '\P{Is_Blk=_ math_OPERATORS}', "");
Expect(0, 8960, '\P{^Is_Blk=_ math_OPERATORS}', "");
Error('\p{Block=:=- meetei_Mayek}');
Error('\P{Block=:=- meetei_Mayek}');
Expect(1, 44031, '\p{Block:   meeteimayek}', "");
Expect(0, 44031, '\p{^Block:   meeteimayek}', "");
Expect(0, 44031, '\P{Block:   meeteimayek}', "");
Expect(1, 44031, '\P{^Block:   meeteimayek}', "");
Expect(0, 44032, '\p{Block:   meeteimayek}', "");
Expect(1, 44032, '\p{^Block:   meeteimayek}', "");
Expect(1, 44032, '\P{Block:   meeteimayek}', "");
Expect(0, 44032, '\P{^Block:   meeteimayek}', "");
Expect(1, 44031, '\p{Block=_ meetei_Mayek}', "");
Expect(0, 44031, '\p{^Block=_ meetei_Mayek}', "");
Expect(0, 44031, '\P{Block=_ meetei_Mayek}', "");
Expect(1, 44031, '\P{^Block=_ meetei_Mayek}', "");
Expect(0, 44032, '\p{Block=_ meetei_Mayek}', "");
Expect(1, 44032, '\p{^Block=_ meetei_Mayek}', "");
Expect(1, 44032, '\P{Block=_ meetei_Mayek}', "");
Expect(0, 44032, '\P{^Block=_ meetei_Mayek}', "");
Error('\p{Blk=		Meetei_mayek/a/}');
Error('\P{Blk=		Meetei_mayek/a/}');
Expect(1, 44031, '\p{Blk=meeteimayek}', "");
Expect(0, 44031, '\p{^Blk=meeteimayek}', "");
Expect(0, 44031, '\P{Blk=meeteimayek}', "");
Expect(1, 44031, '\P{^Blk=meeteimayek}', "");
Expect(0, 44032, '\p{Blk=meeteimayek}', "");
Expect(1, 44032, '\p{^Blk=meeteimayek}', "");
Expect(1, 44032, '\P{Blk=meeteimayek}', "");
Expect(0, 44032, '\P{^Blk=meeteimayek}', "");
Expect(1, 44031, '\p{Blk=-	MEETEI_Mayek}', "");
Expect(0, 44031, '\p{^Blk=-	MEETEI_Mayek}', "");
Expect(0, 44031, '\P{Blk=-	MEETEI_Mayek}', "");
Expect(1, 44031, '\P{^Blk=-	MEETEI_Mayek}', "");
Expect(0, 44032, '\p{Blk=-	MEETEI_Mayek}', "");
Expect(1, 44032, '\p{^Blk=-	MEETEI_Mayek}', "");
Expect(1, 44032, '\P{Blk=-	MEETEI_Mayek}', "");
Expect(0, 44032, '\P{^Blk=-	MEETEI_Mayek}', "");
Error('\p{Is_Block=_	MEETEI_Mayek:=}');
Error('\P{Is_Block=_	MEETEI_Mayek:=}');
Expect(1, 44031, '\p{Is_Block=meeteimayek}', "");
Expect(0, 44031, '\p{^Is_Block=meeteimayek}', "");
Expect(0, 44031, '\P{Is_Block=meeteimayek}', "");
Expect(1, 44031, '\P{^Is_Block=meeteimayek}', "");
Expect(0, 44032, '\p{Is_Block=meeteimayek}', "");
Expect(1, 44032, '\p{^Is_Block=meeteimayek}', "");
Expect(1, 44032, '\P{Is_Block=meeteimayek}', "");
Expect(0, 44032, '\P{^Is_Block=meeteimayek}', "");
Expect(1, 44031, '\p{Is_Block=__meetei_MAYEK}', "");
Expect(0, 44031, '\p{^Is_Block=__meetei_MAYEK}', "");
Expect(0, 44031, '\P{Is_Block=__meetei_MAYEK}', "");
Expect(1, 44031, '\P{^Is_Block=__meetei_MAYEK}', "");
Expect(0, 44032, '\p{Is_Block=__meetei_MAYEK}', "");
Expect(1, 44032, '\p{^Is_Block=__meetei_MAYEK}', "");
Expect(1, 44032, '\P{Is_Block=__meetei_MAYEK}', "");
Expect(0, 44032, '\P{^Is_Block=__meetei_MAYEK}', "");
Error('\p{Is_Blk= /a/MEETEI_Mayek}');
Error('\P{Is_Blk= /a/MEETEI_Mayek}');
Expect(1, 44031, '\p{Is_Blk=meeteimayek}', "");
Expect(0, 44031, '\p{^Is_Blk=meeteimayek}', "");
Expect(0, 44031, '\P{Is_Blk=meeteimayek}', "");
Expect(1, 44031, '\P{^Is_Blk=meeteimayek}', "");
Expect(0, 44032, '\p{Is_Blk=meeteimayek}', "");
Expect(1, 44032, '\p{^Is_Blk=meeteimayek}', "");
Expect(1, 44032, '\P{Is_Blk=meeteimayek}', "");
Expect(0, 44032, '\P{^Is_Blk=meeteimayek}', "");
Expect(1, 44031, '\p{Is_Blk=_ Meetei_MAYEK}', "");
Expect(0, 44031, '\p{^Is_Blk=_ Meetei_MAYEK}', "");
Expect(0, 44031, '\P{Is_Blk=_ Meetei_MAYEK}', "");
Expect(1, 44031, '\P{^Is_Blk=_ Meetei_MAYEK}', "");
Expect(0, 44032, '\p{Is_Blk=_ Meetei_MAYEK}', "");
Expect(1, 44032, '\p{^Is_Blk=_ Meetei_MAYEK}', "");
Expect(1, 44032, '\P{Is_Blk=_ Meetei_MAYEK}', "");
Expect(0, 44032, '\P{^Is_Blk=_ Meetei_MAYEK}', "");
Error('\p{Block=-	Meetei_Mayek_EXTENSIONS:=}');
Error('\P{Block=-	Meetei_Mayek_EXTENSIONS:=}');
Expect(1, 43775, '\p{Block=meeteimayekextensions}', "");
Expect(0, 43775, '\p{^Block=meeteimayekextensions}', "");
Expect(0, 43775, '\P{Block=meeteimayekextensions}', "");
Expect(1, 43775, '\P{^Block=meeteimayekextensions}', "");
Expect(0, 43776, '\p{Block=meeteimayekextensions}', "");
Expect(1, 43776, '\p{^Block=meeteimayekextensions}', "");
Expect(1, 43776, '\P{Block=meeteimayekextensions}', "");
Expect(0, 43776, '\P{^Block=meeteimayekextensions}', "");
Expect(1, 43775, '\p{Block=--meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\p{^Block=--meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\P{Block=--meetei_Mayek_Extensions}', "");
Expect(1, 43775, '\P{^Block=--meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\p{Block=--meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\p{^Block=--meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\P{Block=--meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\P{^Block=--meetei_Mayek_Extensions}', "");
Error('\p{Blk= :=Meetei_Mayek_Ext}');
Error('\P{Blk= :=Meetei_Mayek_Ext}');
Expect(1, 43775, '\p{Blk=meeteimayekext}', "");
Expect(0, 43775, '\p{^Blk=meeteimayekext}', "");
Expect(0, 43775, '\P{Blk=meeteimayekext}', "");
Expect(1, 43775, '\P{^Blk=meeteimayekext}', "");
Expect(0, 43776, '\p{Blk=meeteimayekext}', "");
Expect(1, 43776, '\p{^Blk=meeteimayekext}', "");
Expect(1, 43776, '\P{Blk=meeteimayekext}', "");
Expect(0, 43776, '\P{^Blk=meeteimayekext}', "");
Expect(1, 43775, '\p{Blk=	-Meetei_mayek_EXT}', "");
Expect(0, 43775, '\p{^Blk=	-Meetei_mayek_EXT}', "");
Expect(0, 43775, '\P{Blk=	-Meetei_mayek_EXT}', "");
Expect(1, 43775, '\P{^Blk=	-Meetei_mayek_EXT}', "");
Expect(0, 43776, '\p{Blk=	-Meetei_mayek_EXT}', "");
Expect(1, 43776, '\p{^Blk=	-Meetei_mayek_EXT}', "");
Expect(1, 43776, '\P{Blk=	-Meetei_mayek_EXT}', "");
Expect(0, 43776, '\P{^Blk=	-Meetei_mayek_EXT}', "");
Error('\p{Is_Block:   :=--MEETEI_Mayek_Extensions}');
Error('\P{Is_Block:   :=--MEETEI_Mayek_Extensions}');
Expect(1, 43775, '\p{Is_Block=meeteimayekextensions}', "");
Expect(0, 43775, '\p{^Is_Block=meeteimayekextensions}', "");
Expect(0, 43775, '\P{Is_Block=meeteimayekextensions}', "");
Expect(1, 43775, '\P{^Is_Block=meeteimayekextensions}', "");
Expect(0, 43776, '\p{Is_Block=meeteimayekextensions}', "");
Expect(1, 43776, '\p{^Is_Block=meeteimayekextensions}', "");
Expect(1, 43776, '\P{Is_Block=meeteimayekextensions}', "");
Expect(0, 43776, '\P{^Is_Block=meeteimayekextensions}', "");
Expect(1, 43775, '\p{Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(0, 43775, '\p{^Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(0, 43775, '\P{Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(1, 43775, '\P{^Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(0, 43776, '\p{Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(1, 43776, '\p{^Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(1, 43776, '\P{Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Expect(0, 43776, '\P{^Is_Block=	MEETEI_Mayek_EXTENSIONS}', "");
Error('\p{Is_Blk= /a/Meetei_Mayek_EXT}');
Error('\P{Is_Blk= /a/Meetei_Mayek_EXT}');
Expect(1, 43775, '\p{Is_Blk=meeteimayekext}', "");
Expect(0, 43775, '\p{^Is_Blk=meeteimayekext}', "");
Expect(0, 43775, '\P{Is_Blk=meeteimayekext}', "");
Expect(1, 43775, '\P{^Is_Blk=meeteimayekext}', "");
Expect(0, 43776, '\p{Is_Blk=meeteimayekext}', "");
Expect(1, 43776, '\p{^Is_Blk=meeteimayekext}', "");
Expect(1, 43776, '\P{Is_Blk=meeteimayekext}', "");
Expect(0, 43776, '\P{^Is_Blk=meeteimayekext}', "");
Expect(1, 43775, '\p{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43775, '\p{^Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43775, '\P{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(1, 43775, '\P{^Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43776, '\p{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(1, 43776, '\p{^Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(1, 43776, '\P{Is_Blk= -MEETEI_mayek_Ext}', "");
Expect(0, 43776, '\P{^Is_Blk= -MEETEI_mayek_Ext}', "");
Error('\p{Block= -Meroitic_Cursive:=}');
Error('\P{Block= -Meroitic_Cursive:=}');
Expect(1, 68095, '\p{Block=meroiticcursive}', "");
Expect(0, 68095, '\p{^Block=meroiticcursive}', "");
Expect(0, 68095, '\P{Block=meroiticcursive}', "");
Expect(1, 68095, '\P{^Block=meroiticcursive}', "");
Expect(0, 68096, '\p{Block=meroiticcursive}', "");
Expect(1, 68096, '\p{^Block=meroiticcursive}', "");
Expect(1, 68096, '\P{Block=meroiticcursive}', "");
Expect(0, 68096, '\P{^Block=meroiticcursive}', "");
Expect(1, 68095, '\p{Block=-Meroitic_cursive}', "");
Expect(0, 68095, '\p{^Block=-Meroitic_cursive}', "");
Expect(0, 68095, '\P{Block=-Meroitic_cursive}', "");
Expect(1, 68095, '\P{^Block=-Meroitic_cursive}', "");
Expect(0, 68096, '\p{Block=-Meroitic_cursive}', "");
Expect(1, 68096, '\p{^Block=-Meroitic_cursive}', "");
Expect(1, 68096, '\P{Block=-Meroitic_cursive}', "");
Expect(0, 68096, '\P{^Block=-Meroitic_cursive}', "");
Error('\p{Blk=	/a/Meroitic_Cursive}');
Error('\P{Blk=	/a/Meroitic_Cursive}');
Expect(1, 68095, '\p{Blk=meroiticcursive}', "");
Expect(0, 68095, '\p{^Blk=meroiticcursive}', "");
Expect(0, 68095, '\P{Blk=meroiticcursive}', "");
Expect(1, 68095, '\P{^Blk=meroiticcursive}', "");
Expect(0, 68096, '\p{Blk=meroiticcursive}', "");
Expect(1, 68096, '\p{^Blk=meroiticcursive}', "");
Expect(1, 68096, '\P{Blk=meroiticcursive}', "");
Expect(0, 68096, '\P{^Blk=meroiticcursive}', "");
Expect(1, 68095, '\p{Blk:    meroitic_Cursive}', "");
Expect(0, 68095, '\p{^Blk:    meroitic_Cursive}', "");
Expect(0, 68095, '\P{Blk:    meroitic_Cursive}', "");
Expect(1, 68095, '\P{^Blk:    meroitic_Cursive}', "");
Expect(0, 68096, '\p{Blk:    meroitic_Cursive}', "");
Expect(1, 68096, '\p{^Blk:    meroitic_Cursive}', "");
Expect(1, 68096, '\P{Blk:    meroitic_Cursive}', "");
Expect(0, 68096, '\P{^Blk:    meroitic_Cursive}', "");
Error('\p{Is_Block=_:=meroitic_Cursive}');
Error('\P{Is_Block=_:=meroitic_Cursive}');
Expect(1, 68095, '\p{Is_Block=meroiticcursive}', "");
Expect(0, 68095, '\p{^Is_Block=meroiticcursive}', "");
Expect(0, 68095, '\P{Is_Block=meroiticcursive}', "");
Expect(1, 68095, '\P{^Is_Block=meroiticcursive}', "");
Expect(0, 68096, '\p{Is_Block=meroiticcursive}', "");
Expect(1, 68096, '\p{^Is_Block=meroiticcursive}', "");
Expect(1, 68096, '\P{Is_Block=meroiticcursive}', "");
Expect(0, 68096, '\P{^Is_Block=meroiticcursive}', "");
Expect(1, 68095, '\p{Is_Block=	Meroitic_Cursive}', "");
Expect(0, 68095, '\p{^Is_Block=	Meroitic_Cursive}', "");
Expect(0, 68095, '\P{Is_Block=	Meroitic_Cursive}', "");
Expect(1, 68095, '\P{^Is_Block=	Meroitic_Cursive}', "");
Expect(0, 68096, '\p{Is_Block=	Meroitic_Cursive}', "");
Expect(1, 68096, '\p{^Is_Block=	Meroitic_Cursive}', "");
Expect(1, 68096, '\P{Is_Block=	Meroitic_Cursive}', "");
Expect(0, 68096, '\P{^Is_Block=	Meroitic_Cursive}', "");
Error('\p{Is_Blk=__MEROITIC_Cursive:=}');
Error('\P{Is_Blk=__MEROITIC_Cursive:=}');
Expect(1, 68095, '\p{Is_Blk: meroiticcursive}', "");
Expect(0, 68095, '\p{^Is_Blk: meroiticcursive}', "");
Expect(0, 68095, '\P{Is_Blk: meroiticcursive}', "");
Expect(1, 68095, '\P{^Is_Blk: meroiticcursive}', "");
Expect(0, 68096, '\p{Is_Blk: meroiticcursive}', "");
Expect(1, 68096, '\p{^Is_Blk: meroiticcursive}', "");
Expect(1, 68096, '\P{Is_Blk: meroiticcursive}', "");
Expect(0, 68096, '\P{^Is_Blk: meroiticcursive}', "");
Expect(1, 68095, '\p{Is_Blk= _Meroitic_Cursive}', "");
Expect(0, 68095, '\p{^Is_Blk= _Meroitic_Cursive}', "");
Expect(0, 68095, '\P{Is_Blk= _Meroitic_Cursive}', "");
Expect(1, 68095, '\P{^Is_Blk= _Meroitic_Cursive}', "");
Expect(0, 68096, '\p{Is_Blk= _Meroitic_Cursive}', "");
Expect(1, 68096, '\p{^Is_Blk= _Meroitic_Cursive}', "");
Expect(1, 68096, '\P{Is_Blk= _Meroitic_Cursive}', "");
Expect(0, 68096, '\P{^Is_Blk= _Meroitic_Cursive}', "");
Error('\p{Block= Meroitic_Hieroglyphs:=}');
Error('\P{Block= Meroitic_Hieroglyphs:=}');
Expect(1, 67999, '\p{Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Block= _MEROITIC_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Block= _MEROITIC_Hieroglyphs}', "");
Expect(0, 67999, '\P{Block= _MEROITIC_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Block= _MEROITIC_Hieroglyphs}', "");
Expect(0, 68000, '\p{Block= _MEROITIC_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Block= _MEROITIC_Hieroglyphs}', "");
Expect(1, 68000, '\P{Block= _MEROITIC_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Block= _MEROITIC_Hieroglyphs}', "");
Error('\p{Blk=:=	-MEROITIC_hieroglyphs}');
Error('\P{Blk=:=	-MEROITIC_hieroglyphs}');
Expect(1, 67999, '\p{Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Blk=	Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Blk=	Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Blk=	Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Blk=	Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Blk=	Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Blk=	Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Blk=	Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Blk=	Meroitic_Hieroglyphs}', "");
Error('\p{Is_Block:	_MEROITIC_Hieroglyphs/a/}');
Error('\P{Is_Block:	_MEROITIC_Hieroglyphs/a/}');
Expect(1, 67999, '\p{Is_Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Block=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Block=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Block=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Block=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^Is_Block=-	Meroitic_HIEROGLYPHS}', "");
Error('\p{Is_Blk=-	Meroitic_HIEROGLYPHS/a/}');
Error('\P{Is_Blk=-	Meroitic_HIEROGLYPHS/a/}');
Expect(1, 67999, '\p{Is_Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Blk=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Blk=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Blk=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Blk=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(0, 67999, '\P{Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(0, 68000, '\p{Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(1, 68000, '\P{Is_Blk=--Meroitic_hieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Blk=--Meroitic_hieroglyphs}', "");
Error('\p{Block= /a/miao}');
Error('\P{Block= /a/miao}');
Expect(1, 94111, '\p{Block:miao}', "");
Expect(0, 94111, '\p{^Block:miao}', "");
Expect(0, 94111, '\P{Block:miao}', "");
Expect(1, 94111, '\P{^Block:miao}', "");
Expect(0, 94112, '\p{Block:miao}', "");
Expect(1, 94112, '\p{^Block:miao}', "");
Expect(1, 94112, '\P{Block:miao}', "");
Expect(0, 94112, '\P{^Block:miao}', "");
Expect(1, 94111, '\p{Block= MIAO}', "");
Expect(0, 94111, '\p{^Block= MIAO}', "");
Expect(0, 94111, '\P{Block= MIAO}', "");
Expect(1, 94111, '\P{^Block= MIAO}', "");
Expect(0, 94112, '\p{Block= MIAO}', "");
Expect(1, 94112, '\p{^Block= MIAO}', "");
Expect(1, 94112, '\P{Block= MIAO}', "");
Expect(0, 94112, '\P{^Block= MIAO}', "");
Error('\p{Blk=	-MIAO:=}');
Error('\P{Blk=	-MIAO:=}');
Expect(1, 94111, '\p{Blk=miao}', "");
Expect(0, 94111, '\p{^Blk=miao}', "");
Expect(0, 94111, '\P{Blk=miao}', "");
Expect(1, 94111, '\P{^Blk=miao}', "");
Expect(0, 94112, '\p{Blk=miao}', "");
Expect(1, 94112, '\p{^Blk=miao}', "");
Expect(1, 94112, '\P{Blk=miao}', "");
Expect(0, 94112, '\P{^Blk=miao}', "");
Expect(1, 94111, '\p{Blk= miao}', "");
Expect(0, 94111, '\p{^Blk= miao}', "");
Expect(0, 94111, '\P{Blk= miao}', "");
Expect(1, 94111, '\P{^Blk= miao}', "");
Expect(0, 94112, '\p{Blk= miao}', "");
Expect(1, 94112, '\p{^Blk= miao}', "");
Expect(1, 94112, '\P{Blk= miao}', "");
Expect(0, 94112, '\P{^Blk= miao}', "");
Error('\p{Is_Block=-Miao/a/}');
Error('\P{Is_Block=-Miao/a/}');
Expect(1, 94111, '\p{Is_Block=miao}', "");
Expect(0, 94111, '\p{^Is_Block=miao}', "");
Expect(0, 94111, '\P{Is_Block=miao}', "");
Expect(1, 94111, '\P{^Is_Block=miao}', "");
Expect(0, 94112, '\p{Is_Block=miao}', "");
Expect(1, 94112, '\p{^Is_Block=miao}', "");
Expect(1, 94112, '\P{Is_Block=miao}', "");
Expect(0, 94112, '\P{^Is_Block=miao}', "");
Expect(1, 94111, '\p{Is_Block= MIAO}', "");
Expect(0, 94111, '\p{^Is_Block= MIAO}', "");
Expect(0, 94111, '\P{Is_Block= MIAO}', "");
Expect(1, 94111, '\P{^Is_Block= MIAO}', "");
Expect(0, 94112, '\p{Is_Block= MIAO}', "");
Expect(1, 94112, '\p{^Is_Block= MIAO}', "");
Expect(1, 94112, '\P{Is_Block= MIAO}', "");
Expect(0, 94112, '\P{^Is_Block= MIAO}', "");
Error('\p{Is_Blk=	Miao:=}');
Error('\P{Is_Blk=	Miao:=}');
Expect(1, 94111, '\p{Is_Blk=miao}', "");
Expect(0, 94111, '\p{^Is_Blk=miao}', "");
Expect(0, 94111, '\P{Is_Blk=miao}', "");
Expect(1, 94111, '\P{^Is_Blk=miao}', "");
Expect(0, 94112, '\p{Is_Blk=miao}', "");
Expect(1, 94112, '\p{^Is_Blk=miao}', "");
Expect(1, 94112, '\P{Is_Blk=miao}', "");
Expect(0, 94112, '\P{^Is_Blk=miao}', "");
Expect(1, 94111, '\p{Is_Blk=		miao}', "");
Expect(0, 94111, '\p{^Is_Blk=		miao}', "");
Expect(0, 94111, '\P{Is_Blk=		miao}', "");
Expect(1, 94111, '\P{^Is_Blk=		miao}', "");
Expect(0, 94112, '\p{Is_Blk=		miao}', "");
Expect(1, 94112, '\p{^Is_Blk=		miao}', "");
Expect(1, 94112, '\P{Is_Blk=		miao}', "");
Expect(0, 94112, '\P{^Is_Blk=		miao}', "");
Error('\p{Block=/a/  Miscellaneous_SYMBOLS_And_Arrows}');
Error('\P{Block=/a/  Miscellaneous_SYMBOLS_And_Arrows}');
Expect(1, 11263, '\p{Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(0, 11263, '\p{^Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(0, 11263, '\P{Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(1, 11263, '\P{^Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(0, 11264, '\p{Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(1, 11264, '\p{^Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(1, 11264, '\P{Block: _Miscellaneous_symbols_and_Arrows}', "");
Expect(0, 11264, '\P{^Block: _Miscellaneous_symbols_and_Arrows}', "");
Error('\p{Blk=-	Misc_Arrows:=}');
Error('\P{Blk=-	Misc_Arrows:=}');
Expect(1, 11263, '\p{Blk=miscarrows}', "");
Expect(0, 11263, '\p{^Blk=miscarrows}', "");
Expect(0, 11263, '\P{Blk=miscarrows}', "");
Expect(1, 11263, '\P{^Blk=miscarrows}', "");
Expect(0, 11264, '\p{Blk=miscarrows}', "");
Expect(1, 11264, '\p{^Blk=miscarrows}', "");
Expect(1, 11264, '\P{Blk=miscarrows}', "");
Expect(0, 11264, '\P{^Blk=miscarrows}', "");
Expect(1, 11263, '\p{Blk=		misc_ARROWS}', "");
Expect(0, 11263, '\p{^Blk=		misc_ARROWS}', "");
Expect(0, 11263, '\P{Blk=		misc_ARROWS}', "");
Expect(1, 11263, '\P{^Blk=		misc_ARROWS}', "");
Expect(0, 11264, '\p{Blk=		misc_ARROWS}', "");
Expect(1, 11264, '\p{^Blk=		misc_ARROWS}', "");
Expect(1, 11264, '\P{Blk=		misc_ARROWS}', "");
Expect(0, 11264, '\P{^Blk=		misc_ARROWS}', "");
Error('\p{Is_Block:   _MISCELLANEOUS_Symbols_And_ARROWS/a/}');
Error('\P{Is_Block:   _MISCELLANEOUS_Symbols_And_ARROWS/a/}');
Expect(1, 11263, '\p{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^Is_Block=miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11263, '\p{^Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11263, '\P{Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(1, 11263, '\P{^Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11264, '\p{Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(1, 11264, '\p{^Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(1, 11264, '\P{Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11264, '\P{^Is_Block:Miscellaneous_symbols_And_Arrows}', "");
Error('\p{Is_Blk=	Misc_ARROWS:=}');
Error('\P{Is_Blk=	Misc_ARROWS:=}');
Expect(1, 11263, '\p{Is_Blk=miscarrows}', "");
Expect(0, 11263, '\p{^Is_Blk=miscarrows}', "");
Expect(0, 11263, '\P{Is_Blk=miscarrows}', "");
Expect(1, 11263, '\P{^Is_Blk=miscarrows}', "");
Expect(0, 11264, '\p{Is_Blk=miscarrows}', "");
Expect(1, 11264, '\p{^Is_Blk=miscarrows}', "");
Expect(1, 11264, '\P{Is_Blk=miscarrows}', "");
Expect(0, 11264, '\P{^Is_Blk=miscarrows}', "");
Expect(1, 11263, '\p{Is_Blk=_ Misc_ARROWS}', "");
Expect(0, 11263, '\p{^Is_Blk=_ Misc_ARROWS}', "");
Expect(0, 11263, '\P{Is_Blk=_ Misc_ARROWS}', "");
Expect(1, 11263, '\P{^Is_Blk=_ Misc_ARROWS}', "");
Expect(0, 11264, '\p{Is_Blk=_ Misc_ARROWS}', "");
Expect(1, 11264, '\p{^Is_Blk=_ Misc_ARROWS}', "");
Expect(1, 11264, '\P{Is_Blk=_ Misc_ARROWS}', "");
Expect(0, 11264, '\P{^Is_Blk=_ Misc_ARROWS}', "");
Error('\p{Block=-miscellaneous_Mathematical_Symbols_A/a/}');
Error('\P{Block=-miscellaneous_Mathematical_Symbols_A/a/}');
Expect(1, 10223, '\p{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10223, '\p{^Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10223, '\P{Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(1, 10223, '\P{^Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10224, '\p{Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(1, 10224, '\p{^Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(1, 10224, '\P{Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Expect(0, 10224, '\P{^Block=_	Miscellaneous_MATHEMATICAL_Symbols_A}', "");
Error('\p{Blk= misc_Math_symbols_A:=}');
Error('\P{Blk= misc_Math_symbols_A:=}');
Expect(1, 10223, '\p{Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\p{^Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\P{Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\P{^Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\p{Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\p{^Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\P{Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\P{^Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\p{Blk=-	MISC_math_Symbols_A}', "");
Expect(0, 10223, '\p{^Blk=-	MISC_math_Symbols_A}', "");
Expect(0, 10223, '\P{Blk=-	MISC_math_Symbols_A}', "");
Expect(1, 10223, '\P{^Blk=-	MISC_math_Symbols_A}', "");
Expect(0, 10224, '\p{Blk=-	MISC_math_Symbols_A}', "");
Expect(1, 10224, '\p{^Blk=-	MISC_math_Symbols_A}', "");
Expect(1, 10224, '\P{Blk=-	MISC_math_Symbols_A}', "");
Expect(0, 10224, '\P{^Blk=-	MISC_math_Symbols_A}', "");
Error('\p{Is_Block=:=- Miscellaneous_mathematical_Symbols_A}');
Error('\P{Is_Block=:=- Miscellaneous_mathematical_Symbols_A}');
Expect(1, 10223, '\p{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^Is_Block=miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10223, '\p{^Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10223, '\P{Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10223, '\P{^Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10224, '\p{Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10224, '\p{^Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10224, '\P{Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10224, '\P{^Is_Block=-Miscellaneous_Mathematical_Symbols_A}', "");
Error('\p{Is_Blk=:= MISC_math_symbols_a}');
Error('\P{Is_Blk=:= MISC_math_symbols_a}');
Expect(1, 10223, '\p{Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\p{^Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10223, '\P{Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\P{^Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\p{Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\p{^Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10224, '\P{Is_Blk=miscmathsymbolsa}', "");
Expect(0, 10224, '\P{^Is_Blk=miscmathsymbolsa}', "");
Expect(1, 10223, '\p{Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(0, 10223, '\p{^Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(0, 10223, '\P{Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(1, 10223, '\P{^Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(0, 10224, '\p{Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(1, 10224, '\p{^Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(1, 10224, '\P{Is_Blk=-Misc_Math_Symbols_A}', "");
Expect(0, 10224, '\P{^Is_Blk=-Misc_Math_Symbols_A}', "");
Error('\p{Block=-/a/Miscellaneous_Mathematical_SYMBOLS_b}');
Error('\P{Block=-/a/Miscellaneous_Mathematical_SYMBOLS_b}');
Expect(1, 10751, '\p{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10751, '\p{^Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10751, '\P{Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(1, 10751, '\P{^Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10752, '\p{Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(1, 10752, '\p{^Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(1, 10752, '\P{Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Expect(0, 10752, '\P{^Block=_-miscellaneous_MATHEMATICAL_SYMBOLS_B}', "");
Error('\p{Blk=	 Misc_MATH_SYMBOLS_B/a/}');
Error('\P{Blk=	 Misc_MATH_SYMBOLS_B/a/}');
Expect(1, 10751, '\p{Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\p{^Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\P{Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\P{^Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\p{Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\p{^Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\P{Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\P{^Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\p{Blk=_ Misc_math_Symbols_B}', "");
Expect(0, 10751, '\p{^Blk=_ Misc_math_Symbols_B}', "");
Expect(0, 10751, '\P{Blk=_ Misc_math_Symbols_B}', "");
Expect(1, 10751, '\P{^Blk=_ Misc_math_Symbols_B}', "");
Expect(0, 10752, '\p{Blk=_ Misc_math_Symbols_B}', "");
Expect(1, 10752, '\p{^Blk=_ Misc_math_Symbols_B}', "");
Expect(1, 10752, '\P{Blk=_ Misc_math_Symbols_B}', "");
Expect(0, 10752, '\P{^Blk=_ Misc_math_Symbols_B}', "");
Error('\p{Is_Block=-Miscellaneous_Mathematical_symbols_B/a/}');
Error('\P{Is_Block=-Miscellaneous_Mathematical_symbols_B/a/}');
Expect(1, 10751, '\p{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^Is_Block=miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10751, '\p{^Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10751, '\P{Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(1, 10751, '\P{^Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10752, '\p{Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(1, 10752, '\p{^Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(1, 10752, '\P{Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Expect(0, 10752, '\P{^Is_Block:	 _Miscellaneous_MATHEMATICAL_Symbols_B}', "");
Error('\p{Is_Blk=:= _Misc_Math_SYMBOLS_B}');
Error('\P{Is_Blk=:= _Misc_Math_SYMBOLS_B}');
Expect(1, 10751, '\p{Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\p{^Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10751, '\P{Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\P{^Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\p{Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\p{^Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10752, '\P{Is_Blk=miscmathsymbolsb}', "");
Expect(0, 10752, '\P{^Is_Blk=miscmathsymbolsb}', "");
Expect(1, 10751, '\p{Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(0, 10751, '\p{^Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(0, 10751, '\P{Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(1, 10751, '\P{^Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(0, 10752, '\p{Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(1, 10752, '\p{^Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(1, 10752, '\P{Is_Blk=  Misc_Math_Symbols_b}', "");
Expect(0, 10752, '\P{^Is_Blk=  Misc_Math_Symbols_b}', "");
Error('\p{Block:	 /a/miscellaneous_SYMBOLS_And_PICTOGRAPHS}');
Error('\P{Block:	 /a/miscellaneous_SYMBOLS_And_PICTOGRAPHS}');
Expect(1, 128511, '\p{Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(0, 128511, '\p{^Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(0, 128511, '\P{Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(1, 128511, '\P{^Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(0, 128512, '\p{Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(1, 128512, '\p{^Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(1, 128512, '\P{Block=		Miscellaneous_symbols_And_pictographs}', "");
Expect(0, 128512, '\P{^Block=		Miscellaneous_symbols_And_pictographs}', "");
Error('\p{Blk=  Misc_Pictographs:=}');
Error('\P{Blk=  Misc_Pictographs:=}');
Expect(1, 128511, '\p{Blk=miscpictographs}', "");
Expect(0, 128511, '\p{^Blk=miscpictographs}', "");
Expect(0, 128511, '\P{Blk=miscpictographs}', "");
Expect(1, 128511, '\P{^Blk=miscpictographs}', "");
Expect(0, 128512, '\p{Blk=miscpictographs}', "");
Expect(1, 128512, '\p{^Blk=miscpictographs}', "");
Expect(1, 128512, '\P{Blk=miscpictographs}', "");
Expect(0, 128512, '\P{^Blk=miscpictographs}', "");
Expect(1, 128511, '\p{Blk=	-misc_PICTOGRAPHS}', "");
Expect(0, 128511, '\p{^Blk=	-misc_PICTOGRAPHS}', "");
Expect(0, 128511, '\P{Blk=	-misc_PICTOGRAPHS}', "");
Expect(1, 128511, '\P{^Blk=	-misc_PICTOGRAPHS}', "");
Expect(0, 128512, '\p{Blk=	-misc_PICTOGRAPHS}', "");
Expect(1, 128512, '\p{^Blk=	-misc_PICTOGRAPHS}', "");
Expect(1, 128512, '\P{Blk=	-misc_PICTOGRAPHS}', "");
Expect(0, 128512, '\P{^Blk=	-misc_PICTOGRAPHS}', "");
Error('\p{Is_Block: 	 Miscellaneous_Symbols_And_pictographs/a/}');
Error('\P{Is_Block: 	 Miscellaneous_Symbols_And_pictographs/a/}');
Expect(1, 128511, '\p{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^Is_Block=miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(0, 128511, '\p{^Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(0, 128511, '\P{Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(1, 128511, '\P{^Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(0, 128512, '\p{Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(1, 128512, '\p{^Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(1, 128512, '\P{Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Expect(0, 128512, '\P{^Is_Block=--miscellaneous_symbols_and_Pictographs}', "");
Error('\p{Is_Blk=-_Misc_pictographs/a/}');
Error('\P{Is_Blk=-_Misc_pictographs/a/}');
Expect(1, 128511, '\p{Is_Blk=miscpictographs}', "");
Expect(0, 128511, '\p{^Is_Blk=miscpictographs}', "");
Expect(0, 128511, '\P{Is_Blk=miscpictographs}', "");
Expect(1, 128511, '\P{^Is_Blk=miscpictographs}', "");
Expect(0, 128512, '\p{Is_Blk=miscpictographs}', "");
Expect(1, 128512, '\p{^Is_Blk=miscpictographs}', "");
Expect(1, 128512, '\P{Is_Blk=miscpictographs}', "");
Expect(0, 128512, '\P{^Is_Blk=miscpictographs}', "");
Expect(1, 128511, '\p{Is_Blk=-	misc_Pictographs}', "");
Expect(0, 128511, '\p{^Is_Blk=-	misc_Pictographs}', "");
Expect(0, 128511, '\P{Is_Blk=-	misc_Pictographs}', "");
Expect(1, 128511, '\P{^Is_Blk=-	misc_Pictographs}', "");
Expect(0, 128512, '\p{Is_Blk=-	misc_Pictographs}', "");
Expect(1, 128512, '\p{^Is_Blk=-	misc_Pictographs}', "");
Expect(1, 128512, '\P{Is_Blk=-	misc_Pictographs}', "");
Expect(0, 128512, '\P{^Is_Blk=-	misc_Pictographs}', "");
Error('\p{Block=/a/  Miscellaneous_Symbols}');
Error('\P{Block=/a/  Miscellaneous_Symbols}');
Expect(1, 9983, '\p{Block=miscellaneoussymbols}', "");
Expect(0, 9983, '\p{^Block=miscellaneoussymbols}', "");
Expect(0, 9983, '\P{Block=miscellaneoussymbols}', "");
Expect(1, 9983, '\P{^Block=miscellaneoussymbols}', "");
Expect(0, 9984, '\p{Block=miscellaneoussymbols}', "");
Expect(1, 9984, '\p{^Block=miscellaneoussymbols}', "");
Expect(1, 9984, '\P{Block=miscellaneoussymbols}', "");
Expect(0, 9984, '\P{^Block=miscellaneoussymbols}', "");
Expect(1, 9983, '\p{Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(0, 9983, '\p{^Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(0, 9983, '\P{Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(1, 9983, '\P{^Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(0, 9984, '\p{Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(1, 9984, '\p{^Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(1, 9984, '\P{Block=-MISCELLANEOUS_SYMBOLS}', "");
Expect(0, 9984, '\P{^Block=-MISCELLANEOUS_SYMBOLS}', "");
Error('\p{Blk=/a/_ misc_SYMBOLS}');
Error('\P{Blk=/a/_ misc_SYMBOLS}');
Expect(1, 9983, '\p{Blk=miscsymbols}', "");
Expect(0, 9983, '\p{^Blk=miscsymbols}', "");
Expect(0, 9983, '\P{Blk=miscsymbols}', "");
Expect(1, 9983, '\P{^Blk=miscsymbols}', "");
Expect(0, 9984, '\p{Blk=miscsymbols}', "");
Expect(1, 9984, '\p{^Blk=miscsymbols}', "");
Expect(1, 9984, '\P{Blk=miscsymbols}', "");
Expect(0, 9984, '\P{^Blk=miscsymbols}', "");
Expect(1, 9983, '\p{Blk=_misc_symbols}', "");
Expect(0, 9983, '\p{^Blk=_misc_symbols}', "");
Expect(0, 9983, '\P{Blk=_misc_symbols}', "");
Expect(1, 9983, '\P{^Blk=_misc_symbols}', "");
Expect(0, 9984, '\p{Blk=_misc_symbols}', "");
Expect(1, 9984, '\p{^Blk=_misc_symbols}', "");
Expect(1, 9984, '\P{Blk=_misc_symbols}', "");
Expect(0, 9984, '\P{^Blk=_misc_symbols}', "");
Error('\p{Is_Block:	-	Miscellaneous_Symbols/a/}');
Error('\P{Is_Block:	-	Miscellaneous_Symbols/a/}');
Expect(1, 9983, '\p{Is_Block=miscellaneoussymbols}', "");
Expect(0, 9983, '\p{^Is_Block=miscellaneoussymbols}', "");
Expect(0, 9983, '\P{Is_Block=miscellaneoussymbols}', "");
Expect(1, 9983, '\P{^Is_Block=miscellaneoussymbols}', "");
Expect(0, 9984, '\p{Is_Block=miscellaneoussymbols}', "");
Expect(1, 9984, '\p{^Is_Block=miscellaneoussymbols}', "");
Expect(1, 9984, '\P{Is_Block=miscellaneoussymbols}', "");
Expect(0, 9984, '\P{^Is_Block=miscellaneoussymbols}', "");
Expect(1, 9983, '\p{Is_Block=-Miscellaneous_Symbols}', "");
Expect(0, 9983, '\p{^Is_Block=-Miscellaneous_Symbols}', "");
Expect(0, 9983, '\P{Is_Block=-Miscellaneous_Symbols}', "");
Expect(1, 9983, '\P{^Is_Block=-Miscellaneous_Symbols}', "");
Expect(0, 9984, '\p{Is_Block=-Miscellaneous_Symbols}', "");
Expect(1, 9984, '\p{^Is_Block=-Miscellaneous_Symbols}', "");
Expect(1, 9984, '\P{Is_Block=-Miscellaneous_Symbols}', "");
Expect(0, 9984, '\P{^Is_Block=-Miscellaneous_Symbols}', "");
Error('\p{Is_Blk:	:=misc_Symbols}');
Error('\P{Is_Blk:	:=misc_Symbols}');
Expect(1, 9983, '\p{Is_Blk=miscsymbols}', "");
Expect(0, 9983, '\p{^Is_Blk=miscsymbols}', "");
Expect(0, 9983, '\P{Is_Blk=miscsymbols}', "");
Expect(1, 9983, '\P{^Is_Blk=miscsymbols}', "");
Expect(0, 9984, '\p{Is_Blk=miscsymbols}', "");
Expect(1, 9984, '\p{^Is_Blk=miscsymbols}', "");
Expect(1, 9984, '\P{Is_Blk=miscsymbols}', "");
Expect(0, 9984, '\P{^Is_Blk=miscsymbols}', "");
Expect(1, 9983, '\p{Is_Blk=	Misc_SYMBOLS}', "");
Expect(0, 9983, '\p{^Is_Blk=	Misc_SYMBOLS}', "");
Expect(0, 9983, '\P{Is_Blk=	Misc_SYMBOLS}', "");
Expect(1, 9983, '\P{^Is_Blk=	Misc_SYMBOLS}', "");
Expect(0, 9984, '\p{Is_Blk=	Misc_SYMBOLS}', "");
Expect(1, 9984, '\p{^Is_Blk=	Misc_SYMBOLS}', "");
Expect(1, 9984, '\P{Is_Blk=	Misc_SYMBOLS}', "");
Expect(0, 9984, '\P{^Is_Blk=	Misc_SYMBOLS}', "");
Error('\p{Block=miscellaneous_Technical/a/}');
Error('\P{Block=miscellaneous_Technical/a/}');
Expect(1, 9215, '\p{Block=miscellaneoustechnical}', "");
Expect(0, 9215, '\p{^Block=miscellaneoustechnical}', "");
Expect(0, 9215, '\P{Block=miscellaneoustechnical}', "");
Expect(1, 9215, '\P{^Block=miscellaneoustechnical}', "");
Expect(0, 9216, '\p{Block=miscellaneoustechnical}', "");
Expect(1, 9216, '\p{^Block=miscellaneoustechnical}', "");
Expect(1, 9216, '\P{Block=miscellaneoustechnical}', "");
Expect(0, 9216, '\P{^Block=miscellaneoustechnical}', "");
Expect(1, 9215, '\p{Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9215, '\p{^Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9215, '\P{Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(1, 9215, '\P{^Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9216, '\p{Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(1, 9216, '\p{^Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(1, 9216, '\P{Block=MISCELLANEOUS_TECHNICAL}', "");
Expect(0, 9216, '\P{^Block=MISCELLANEOUS_TECHNICAL}', "");
Error('\p{Blk= -misc_technical/a/}');
Error('\P{Blk= -misc_technical/a/}');
Expect(1, 9215, '\p{Blk=misctechnical}', "");
Expect(0, 9215, '\p{^Blk=misctechnical}', "");
Expect(0, 9215, '\P{Blk=misctechnical}', "");
Expect(1, 9215, '\P{^Blk=misctechnical}', "");
Expect(0, 9216, '\p{Blk=misctechnical}', "");
Expect(1, 9216, '\p{^Blk=misctechnical}', "");
Expect(1, 9216, '\P{Blk=misctechnical}', "");
Expect(0, 9216, '\P{^Blk=misctechnical}', "");
Expect(1, 9215, '\p{Blk=	 MISC_TECHNICAL}', "");
Expect(0, 9215, '\p{^Blk=	 MISC_TECHNICAL}', "");
Expect(0, 9215, '\P{Blk=	 MISC_TECHNICAL}', "");
Expect(1, 9215, '\P{^Blk=	 MISC_TECHNICAL}', "");
Expect(0, 9216, '\p{Blk=	 MISC_TECHNICAL}', "");
Expect(1, 9216, '\p{^Blk=	 MISC_TECHNICAL}', "");
Expect(1, 9216, '\P{Blk=	 MISC_TECHNICAL}', "");
Expect(0, 9216, '\P{^Blk=	 MISC_TECHNICAL}', "");
Error('\p{Is_Block:   	 miscellaneous_TECHNICAL:=}');
Error('\P{Is_Block:   	 miscellaneous_TECHNICAL:=}');
Expect(1, 9215, '\p{Is_Block=miscellaneoustechnical}', "");
Expect(0, 9215, '\p{^Is_Block=miscellaneoustechnical}', "");
Expect(0, 9215, '\P{Is_Block=miscellaneoustechnical}', "");
Expect(1, 9215, '\P{^Is_Block=miscellaneoustechnical}', "");
Expect(0, 9216, '\p{Is_Block=miscellaneoustechnical}', "");
Expect(1, 9216, '\p{^Is_Block=miscellaneoustechnical}', "");
Expect(1, 9216, '\P{Is_Block=miscellaneoustechnical}', "");
Expect(0, 9216, '\P{^Is_Block=miscellaneoustechnical}', "");
Expect(1, 9215, '\p{Is_Block:	 Miscellaneous_Technical}', "");
Expect(0, 9215, '\p{^Is_Block:	 Miscellaneous_Technical}', "");
Expect(0, 9215, '\P{Is_Block:	 Miscellaneous_Technical}', "");
Expect(1, 9215, '\P{^Is_Block:	 Miscellaneous_Technical}', "");
Expect(0, 9216, '\p{Is_Block:	 Miscellaneous_Technical}', "");
Expect(1, 9216, '\p{^Is_Block:	 Miscellaneous_Technical}', "");
Expect(1, 9216, '\P{Is_Block:	 Miscellaneous_Technical}', "");
Expect(0, 9216, '\P{^Is_Block:	 Miscellaneous_Technical}', "");
Error('\p{Is_Blk:_:=Misc_Technical}');
Error('\P{Is_Blk:_:=Misc_Technical}');
Expect(1, 9215, '\p{Is_Blk:   misctechnical}', "");
Expect(0, 9215, '\p{^Is_Blk:   misctechnical}', "");
Expect(0, 9215, '\P{Is_Blk:   misctechnical}', "");
Expect(1, 9215, '\P{^Is_Blk:   misctechnical}', "");
Expect(0, 9216, '\p{Is_Blk:   misctechnical}', "");
Expect(1, 9216, '\p{^Is_Blk:   misctechnical}', "");
Expect(1, 9216, '\P{Is_Blk:   misctechnical}', "");
Expect(0, 9216, '\P{^Is_Blk:   misctechnical}', "");
Expect(1, 9215, '\p{Is_Blk=		misc_TECHNICAL}', "");
Expect(0, 9215, '\p{^Is_Blk=		misc_TECHNICAL}', "");
Expect(0, 9215, '\P{Is_Blk=		misc_TECHNICAL}', "");
Expect(1, 9215, '\P{^Is_Blk=		misc_TECHNICAL}', "");
Expect(0, 9216, '\p{Is_Blk=		misc_TECHNICAL}', "");
Expect(1, 9216, '\p{^Is_Blk=		misc_TECHNICAL}', "");
Expect(1, 9216, '\P{Is_Blk=		misc_TECHNICAL}', "");
Expect(0, 9216, '\P{^Is_Blk=		misc_TECHNICAL}', "");
Error('\p{Block= 	Spacing_Modifier_Letters:=}');
Error('\P{Block= 	Spacing_Modifier_Letters:=}');
Expect(1, 767, '\p{Block=spacingmodifierletters}', "");
Expect(0, 767, '\p{^Block=spacingmodifierletters}', "");
Expect(0, 767, '\P{Block=spacingmodifierletters}', "");
Expect(1, 767, '\P{^Block=spacingmodifierletters}', "");
Expect(0, 768, '\p{Block=spacingmodifierletters}', "");
Expect(1, 768, '\p{^Block=spacingmodifierletters}', "");
Expect(1, 768, '\P{Block=spacingmodifierletters}', "");
Expect(0, 768, '\P{^Block=spacingmodifierletters}', "");
Expect(1, 767, '\p{Block=_Spacing_Modifier_LETTERS}', "");
Expect(0, 767, '\p{^Block=_Spacing_Modifier_LETTERS}', "");
Expect(0, 767, '\P{Block=_Spacing_Modifier_LETTERS}', "");
Expect(1, 767, '\P{^Block=_Spacing_Modifier_LETTERS}', "");
Expect(0, 768, '\p{Block=_Spacing_Modifier_LETTERS}', "");
Expect(1, 768, '\p{^Block=_Spacing_Modifier_LETTERS}', "");
Expect(1, 768, '\P{Block=_Spacing_Modifier_LETTERS}', "");
Expect(0, 768, '\P{^Block=_Spacing_Modifier_LETTERS}', "");
Error('\p{Blk= :=Modifier_Letters}');
Error('\P{Blk= :=Modifier_Letters}');
Expect(1, 767, '\p{Blk=modifierletters}', "");
Expect(0, 767, '\p{^Blk=modifierletters}', "");
Expect(0, 767, '\P{Blk=modifierletters}', "");
Expect(1, 767, '\P{^Blk=modifierletters}', "");
Expect(0, 768, '\p{Blk=modifierletters}', "");
Expect(1, 768, '\p{^Blk=modifierletters}', "");
Expect(1, 768, '\P{Blk=modifierletters}', "");
Expect(0, 768, '\P{^Blk=modifierletters}', "");
Expect(1, 767, '\p{Blk= modifier_letters}', "");
Expect(0, 767, '\p{^Blk= modifier_letters}', "");
Expect(0, 767, '\P{Blk= modifier_letters}', "");
Expect(1, 767, '\P{^Blk= modifier_letters}', "");
Expect(0, 768, '\p{Blk= modifier_letters}', "");
Expect(1, 768, '\p{^Blk= modifier_letters}', "");
Expect(1, 768, '\P{Blk= modifier_letters}', "");
Expect(0, 768, '\P{^Blk= modifier_letters}', "");
Error('\p{Is_Block= /a/Spacing_Modifier_LETTERS}');
Error('\P{Is_Block= /a/Spacing_Modifier_LETTERS}');
Expect(1, 767, '\p{Is_Block=spacingmodifierletters}', "");
Expect(0, 767, '\p{^Is_Block=spacingmodifierletters}', "");
Expect(0, 767, '\P{Is_Block=spacingmodifierletters}', "");
Expect(1, 767, '\P{^Is_Block=spacingmodifierletters}', "");
Expect(0, 768, '\p{Is_Block=spacingmodifierletters}', "");
Expect(1, 768, '\p{^Is_Block=spacingmodifierletters}', "");
Expect(1, 768, '\P{Is_Block=spacingmodifierletters}', "");
Expect(0, 768, '\P{^Is_Block=spacingmodifierletters}', "");
Expect(1, 767, '\p{Is_Block=-Spacing_Modifier_Letters}', "");
Expect(0, 767, '\p{^Is_Block=-Spacing_Modifier_Letters}', "");
Expect(0, 767, '\P{Is_Block=-Spacing_Modifier_Letters}', "");
Expect(1, 767, '\P{^Is_Block=-Spacing_Modifier_Letters}', "");
Expect(0, 768, '\p{Is_Block=-Spacing_Modifier_Letters}', "");
Expect(1, 768, '\p{^Is_Block=-Spacing_Modifier_Letters}', "");
Expect(1, 768, '\P{Is_Block=-Spacing_Modifier_Letters}', "");
Expect(0, 768, '\P{^Is_Block=-Spacing_Modifier_Letters}', "");
Error('\p{Is_Blk=/a/	modifier_LETTERS}');
Error('\P{Is_Blk=/a/	modifier_LETTERS}');
Expect(1, 767, '\p{Is_Blk=modifierletters}', "");
Expect(0, 767, '\p{^Is_Blk=modifierletters}', "");
Expect(0, 767, '\P{Is_Blk=modifierletters}', "");
Expect(1, 767, '\P{^Is_Blk=modifierletters}', "");
Expect(0, 768, '\p{Is_Blk=modifierletters}', "");
Expect(1, 768, '\p{^Is_Blk=modifierletters}', "");
Expect(1, 768, '\P{Is_Blk=modifierletters}', "");
Expect(0, 768, '\P{^Is_Blk=modifierletters}', "");
Expect(1, 767, '\p{Is_Blk=	-modifier_Letters}', "");
Expect(0, 767, '\p{^Is_Blk=	-modifier_Letters}', "");
Expect(0, 767, '\P{Is_Blk=	-modifier_Letters}', "");
Expect(1, 767, '\P{^Is_Blk=	-modifier_Letters}', "");
Expect(0, 768, '\p{Is_Blk=	-modifier_Letters}', "");
Expect(1, 768, '\p{^Is_Blk=	-modifier_Letters}', "");
Expect(1, 768, '\P{Is_Blk=	-modifier_Letters}', "");
Expect(0, 768, '\P{^Is_Blk=	-modifier_Letters}', "");
Error('\p{Block=-MODIFIER_TONE_LETTERS:=}');
Error('\P{Block=-MODIFIER_TONE_LETTERS:=}');
Expect(1, 42783, '\p{Block=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Block=modifiertoneletters}', "");
Expect(0, 42783, '\P{Block=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Block=modifiertoneletters}', "");
Expect(0, 42784, '\p{Block=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Block=modifiertoneletters}', "");
Expect(1, 42784, '\P{Block=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Block=modifiertoneletters}', "");
Expect(1, 42783, '\p{Block=	_Modifier_Tone_LETTERS}', "");
Expect(0, 42783, '\p{^Block=	_Modifier_Tone_LETTERS}', "");
Expect(0, 42783, '\P{Block=	_Modifier_Tone_LETTERS}', "");
Expect(1, 42783, '\P{^Block=	_Modifier_Tone_LETTERS}', "");
Expect(0, 42784, '\p{Block=	_Modifier_Tone_LETTERS}', "");
Expect(1, 42784, '\p{^Block=	_Modifier_Tone_LETTERS}', "");
Expect(1, 42784, '\P{Block=	_Modifier_Tone_LETTERS}', "");
Expect(0, 42784, '\P{^Block=	_Modifier_Tone_LETTERS}', "");
Error('\p{Blk=/a/Modifier_TONE_letters}');
Error('\P{Blk=/a/Modifier_TONE_letters}');
Expect(1, 42783, '\p{Blk=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Blk=modifiertoneletters}', "");
Expect(0, 42783, '\P{Blk=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Blk=modifiertoneletters}', "");
Expect(0, 42784, '\p{Blk=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Blk=modifiertoneletters}', "");
Expect(1, 42784, '\P{Blk=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Blk=modifiertoneletters}', "");
Expect(1, 42783, '\p{Blk=Modifier_tone_Letters}', "");
Expect(0, 42783, '\p{^Blk=Modifier_tone_Letters}', "");
Expect(0, 42783, '\P{Blk=Modifier_tone_Letters}', "");
Expect(1, 42783, '\P{^Blk=Modifier_tone_Letters}', "");
Expect(0, 42784, '\p{Blk=Modifier_tone_Letters}', "");
Expect(1, 42784, '\p{^Blk=Modifier_tone_Letters}', "");
Expect(1, 42784, '\P{Blk=Modifier_tone_Letters}', "");
Expect(0, 42784, '\P{^Blk=Modifier_tone_Letters}', "");
Error('\p{Is_Block:/a/- Modifier_tone_letters}');
Error('\P{Is_Block:/a/- Modifier_tone_letters}');
Expect(1, 42783, '\p{Is_Block=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Is_Block=modifiertoneletters}', "");
Expect(0, 42783, '\P{Is_Block=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Is_Block=modifiertoneletters}', "");
Expect(0, 42784, '\p{Is_Block=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Is_Block=modifiertoneletters}', "");
Expect(1, 42784, '\P{Is_Block=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Is_Block=modifiertoneletters}', "");
Expect(1, 42783, '\p{Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(0, 42783, '\p{^Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(0, 42783, '\P{Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(1, 42783, '\P{^Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(0, 42784, '\p{Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(1, 42784, '\p{^Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(1, 42784, '\P{Is_Block=_	Modifier_TONE_LETTERS}', "");
Expect(0, 42784, '\P{^Is_Block=_	Modifier_TONE_LETTERS}', "");
Error('\p{Is_Blk=_MODIFIER_tone_letters/a/}');
Error('\P{Is_Blk=_MODIFIER_tone_letters/a/}');
Expect(1, 42783, '\p{Is_Blk=modifiertoneletters}', "");
Expect(0, 42783, '\p{^Is_Blk=modifiertoneletters}', "");
Expect(0, 42783, '\P{Is_Blk=modifiertoneletters}', "");
Expect(1, 42783, '\P{^Is_Blk=modifiertoneletters}', "");
Expect(0, 42784, '\p{Is_Blk=modifiertoneletters}', "");
Expect(1, 42784, '\p{^Is_Blk=modifiertoneletters}', "");
Expect(1, 42784, '\P{Is_Blk=modifiertoneletters}', "");
Expect(0, 42784, '\P{^Is_Blk=modifiertoneletters}', "");
Expect(1, 42783, '\p{Is_Blk= -Modifier_tone_Letters}', "");
Expect(0, 42783, '\p{^Is_Blk= -Modifier_tone_Letters}', "");
Expect(0, 42783, '\P{Is_Blk= -Modifier_tone_Letters}', "");
Expect(1, 42783, '\P{^Is_Blk= -Modifier_tone_Letters}', "");
Expect(0, 42784, '\p{Is_Blk= -Modifier_tone_Letters}', "");
Expect(1, 42784, '\p{^Is_Blk= -Modifier_tone_Letters}', "");
Expect(1, 42784, '\P{Is_Blk= -Modifier_tone_Letters}', "");
Expect(0, 42784, '\P{^Is_Blk= -Modifier_tone_Letters}', "");
Error('\p{Block=-/a/MONGOLIAN}');
Error('\P{Block=-/a/MONGOLIAN}');
Expect(1, 6319, '\p{Block=mongolian}', "");
Expect(0, 6319, '\p{^Block=mongolian}', "");
Expect(0, 6319, '\P{Block=mongolian}', "");
Expect(1, 6319, '\P{^Block=mongolian}', "");
Expect(0, 6320, '\p{Block=mongolian}', "");
Expect(1, 6320, '\p{^Block=mongolian}', "");
Expect(1, 6320, '\P{Block=mongolian}', "");
Expect(0, 6320, '\P{^Block=mongolian}', "");
Expect(1, 6319, '\p{Block= 	MONGOLIAN}', "");
Expect(0, 6319, '\p{^Block= 	MONGOLIAN}', "");
Expect(0, 6319, '\P{Block= 	MONGOLIAN}', "");
Expect(1, 6319, '\P{^Block= 	MONGOLIAN}', "");
Expect(0, 6320, '\p{Block= 	MONGOLIAN}', "");
Expect(1, 6320, '\p{^Block= 	MONGOLIAN}', "");
Expect(1, 6320, '\P{Block= 	MONGOLIAN}', "");
Expect(0, 6320, '\P{^Block= 	MONGOLIAN}', "");
Error('\p{Blk=_/a/Mongolian}');
Error('\P{Blk=_/a/Mongolian}');
Expect(1, 6319, '\p{Blk=mongolian}', "");
Expect(0, 6319, '\p{^Blk=mongolian}', "");
Expect(0, 6319, '\P{Blk=mongolian}', "");
Expect(1, 6319, '\P{^Blk=mongolian}', "");
Expect(0, 6320, '\p{Blk=mongolian}', "");
Expect(1, 6320, '\p{^Blk=mongolian}', "");
Expect(1, 6320, '\P{Blk=mongolian}', "");
Expect(0, 6320, '\P{^Blk=mongolian}', "");
Expect(1, 6319, '\p{Blk:   _Mongolian}', "");
Expect(0, 6319, '\p{^Blk:   _Mongolian}', "");
Expect(0, 6319, '\P{Blk:   _Mongolian}', "");
Expect(1, 6319, '\P{^Blk:   _Mongolian}', "");
Expect(0, 6320, '\p{Blk:   _Mongolian}', "");
Expect(1, 6320, '\p{^Blk:   _Mongolian}', "");
Expect(1, 6320, '\P{Blk:   _Mongolian}', "");
Expect(0, 6320, '\P{^Blk:   _Mongolian}', "");
Error('\p{Is_Block=_Mongolian/a/}');
Error('\P{Is_Block=_Mongolian/a/}');
Expect(1, 6319, '\p{Is_Block:   mongolian}', "");
Expect(0, 6319, '\p{^Is_Block:   mongolian}', "");
Expect(0, 6319, '\P{Is_Block:   mongolian}', "");
Expect(1, 6319, '\P{^Is_Block:   mongolian}', "");
Expect(0, 6320, '\p{Is_Block:   mongolian}', "");
Expect(1, 6320, '\p{^Is_Block:   mongolian}', "");
Expect(1, 6320, '\P{Is_Block:   mongolian}', "");
Expect(0, 6320, '\P{^Is_Block:   mongolian}', "");
Expect(1, 6319, '\p{Is_Block=-_MONGOLIAN}', "");
Expect(0, 6319, '\p{^Is_Block=-_MONGOLIAN}', "");
Expect(0, 6319, '\P{Is_Block=-_MONGOLIAN}', "");
Expect(1, 6319, '\P{^Is_Block=-_MONGOLIAN}', "");
Expect(0, 6320, '\p{Is_Block=-_MONGOLIAN}', "");
Expect(1, 6320, '\p{^Is_Block=-_MONGOLIAN}', "");
Expect(1, 6320, '\P{Is_Block=-_MONGOLIAN}', "");
Expect(0, 6320, '\P{^Is_Block=-_MONGOLIAN}', "");
Error('\p{Is_Blk= /a/mongolian}');
Error('\P{Is_Blk= /a/mongolian}');
Expect(1, 6319, '\p{Is_Blk=mongolian}', "");
Expect(0, 6319, '\p{^Is_Blk=mongolian}', "");
Expect(0, 6319, '\P{Is_Blk=mongolian}', "");
Expect(1, 6319, '\P{^Is_Blk=mongolian}', "");
Expect(0, 6320, '\p{Is_Blk=mongolian}', "");
Expect(1, 6320, '\p{^Is_Blk=mongolian}', "");
Expect(1, 6320, '\P{Is_Blk=mongolian}', "");
Expect(0, 6320, '\P{^Is_Blk=mongolian}', "");
Expect(1, 6319, '\p{Is_Blk=__mongolian}', "");
Expect(0, 6319, '\p{^Is_Blk=__mongolian}', "");
Expect(0, 6319, '\P{Is_Blk=__mongolian}', "");
Expect(1, 6319, '\P{^Is_Blk=__mongolian}', "");
Expect(0, 6320, '\p{Is_Blk=__mongolian}', "");
Expect(1, 6320, '\p{^Is_Blk=__mongolian}', "");
Expect(1, 6320, '\P{Is_Blk=__mongolian}', "");
Expect(0, 6320, '\P{^Is_Blk=__mongolian}', "");
Error('\p{Block=	:=MUSICAL_symbols}');
Error('\P{Block=	:=MUSICAL_symbols}');
Expect(1, 119295, '\p{Block=musicalsymbols}', "");
Expect(0, 119295, '\p{^Block=musicalsymbols}', "");
Expect(0, 119295, '\P{Block=musicalsymbols}', "");
Expect(1, 119295, '\P{^Block=musicalsymbols}', "");
Expect(0, 119296, '\p{Block=musicalsymbols}', "");
Expect(1, 119296, '\p{^Block=musicalsymbols}', "");
Expect(1, 119296, '\P{Block=musicalsymbols}', "");
Expect(0, 119296, '\P{^Block=musicalsymbols}', "");
Expect(1, 119295, '\p{Block=musical_symbols}', "");
Expect(0, 119295, '\p{^Block=musical_symbols}', "");
Expect(0, 119295, '\P{Block=musical_symbols}', "");
Expect(1, 119295, '\P{^Block=musical_symbols}', "");
Expect(0, 119296, '\p{Block=musical_symbols}', "");
Expect(1, 119296, '\p{^Block=musical_symbols}', "");
Expect(1, 119296, '\P{Block=musical_symbols}', "");
Expect(0, 119296, '\P{^Block=musical_symbols}', "");
Error('\p{Blk=-/a/Music}');
Error('\P{Blk=-/a/Music}');
Expect(1, 119295, '\p{Blk=music}', "");
Expect(0, 119295, '\p{^Blk=music}', "");
Expect(0, 119295, '\P{Blk=music}', "");
Expect(1, 119295, '\P{^Blk=music}', "");
Expect(0, 119296, '\p{Blk=music}', "");
Expect(1, 119296, '\p{^Blk=music}', "");
Expect(1, 119296, '\P{Blk=music}', "");
Expect(0, 119296, '\P{^Blk=music}', "");
Expect(1, 119295, '\p{Blk= Music}', "");
Expect(0, 119295, '\p{^Blk= Music}', "");
Expect(0, 119295, '\P{Blk= Music}', "");
Expect(1, 119295, '\P{^Blk= Music}', "");
Expect(0, 119296, '\p{Blk= Music}', "");
Expect(1, 119296, '\p{^Blk= Music}', "");
Expect(1, 119296, '\P{Blk= Music}', "");
Expect(0, 119296, '\P{^Blk= Music}', "");
Error('\p{Is_Block=:= _Musical_symbols}');
Error('\P{Is_Block=:= _Musical_symbols}');
Expect(1, 119295, '\p{Is_Block=musicalsymbols}', "");
Expect(0, 119295, '\p{^Is_Block=musicalsymbols}', "");
Expect(0, 119295, '\P{Is_Block=musicalsymbols}', "");
Expect(1, 119295, '\P{^Is_Block=musicalsymbols}', "");
Expect(0, 119296, '\p{Is_Block=musicalsymbols}', "");
Expect(1, 119296, '\p{^Is_Block=musicalsymbols}', "");
Expect(1, 119296, '\P{Is_Block=musicalsymbols}', "");
Expect(0, 119296, '\P{^Is_Block=musicalsymbols}', "");
Expect(1, 119295, '\p{Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(0, 119295, '\p{^Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(0, 119295, '\P{Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(1, 119295, '\P{^Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(0, 119296, '\p{Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(1, 119296, '\p{^Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(1, 119296, '\P{Is_Block=_-MUSICAL_SYMBOLS}', "");
Expect(0, 119296, '\P{^Is_Block=_-MUSICAL_SYMBOLS}', "");
Error('\p{Is_Blk=Music:=}');
Error('\P{Is_Blk=Music:=}');
Expect(1, 119295, '\p{Is_Blk: music}', "");
Expect(0, 119295, '\p{^Is_Blk: music}', "");
Expect(0, 119295, '\P{Is_Blk: music}', "");
Expect(1, 119295, '\P{^Is_Blk: music}', "");
Expect(0, 119296, '\p{Is_Blk: music}', "");
Expect(1, 119296, '\p{^Is_Blk: music}', "");
Expect(1, 119296, '\P{Is_Blk: music}', "");
Expect(0, 119296, '\P{^Is_Blk: music}', "");
Expect(1, 119295, '\p{Is_Blk=  Music}', "");
Expect(0, 119295, '\p{^Is_Blk=  Music}', "");
Expect(0, 119295, '\P{Is_Blk=  Music}', "");
Expect(1, 119295, '\P{^Is_Blk=  Music}', "");
Expect(0, 119296, '\p{Is_Blk=  Music}', "");
Expect(1, 119296, '\p{^Is_Blk=  Music}', "");
Expect(1, 119296, '\P{Is_Blk=  Music}', "");
Expect(0, 119296, '\P{^Is_Blk=  Music}', "");
Error('\p{Block=	Myanmar:=}');
Error('\P{Block=	Myanmar:=}');
Expect(1, 4255, '\p{Block=myanmar}', "");
Expect(0, 4255, '\p{^Block=myanmar}', "");
Expect(0, 4255, '\P{Block=myanmar}', "");
Expect(1, 4255, '\P{^Block=myanmar}', "");
Expect(0, 4256, '\p{Block=myanmar}', "");
Expect(1, 4256, '\p{^Block=myanmar}', "");
Expect(1, 4256, '\P{Block=myanmar}', "");
Expect(0, 4256, '\P{^Block=myanmar}', "");
Expect(1, 4255, '\p{Block=--myanmar}', "");
Expect(0, 4255, '\p{^Block=--myanmar}', "");
Expect(0, 4255, '\P{Block=--myanmar}', "");
Expect(1, 4255, '\P{^Block=--myanmar}', "");
Expect(0, 4256, '\p{Block=--myanmar}', "");
Expect(1, 4256, '\p{^Block=--myanmar}', "");
Expect(1, 4256, '\P{Block=--myanmar}', "");
Expect(0, 4256, '\P{^Block=--myanmar}', "");
Error('\p{Blk=  myanmar/a/}');
Error('\P{Blk=  myanmar/a/}');
Expect(1, 4255, '\p{Blk=myanmar}', "");
Expect(0, 4255, '\p{^Blk=myanmar}', "");
Expect(0, 4255, '\P{Blk=myanmar}', "");
Expect(1, 4255, '\P{^Blk=myanmar}', "");
Expect(0, 4256, '\p{Blk=myanmar}', "");
Expect(1, 4256, '\p{^Blk=myanmar}', "");
Expect(1, 4256, '\P{Blk=myanmar}', "");
Expect(0, 4256, '\P{^Blk=myanmar}', "");
Expect(1, 4255, '\p{Blk=_	Myanmar}', "");
Expect(0, 4255, '\p{^Blk=_	Myanmar}', "");
Expect(0, 4255, '\P{Blk=_	Myanmar}', "");
Expect(1, 4255, '\P{^Blk=_	Myanmar}', "");
Expect(0, 4256, '\p{Blk=_	Myanmar}', "");
Expect(1, 4256, '\p{^Blk=_	Myanmar}', "");
Expect(1, 4256, '\P{Blk=_	Myanmar}', "");
Expect(0, 4256, '\P{^Blk=_	Myanmar}', "");
Error('\p{Is_Block=_:=MYANMAR}');
Error('\P{Is_Block=_:=MYANMAR}');
Expect(1, 4255, '\p{Is_Block=myanmar}', "");
Expect(0, 4255, '\p{^Is_Block=myanmar}', "");
Expect(0, 4255, '\P{Is_Block=myanmar}', "");
Expect(1, 4255, '\P{^Is_Block=myanmar}', "");
Expect(0, 4256, '\p{Is_Block=myanmar}', "");
Expect(1, 4256, '\p{^Is_Block=myanmar}', "");
Expect(1, 4256, '\P{Is_Block=myanmar}', "");
Expect(0, 4256, '\P{^Is_Block=myanmar}', "");
Expect(1, 4255, '\p{Is_Block= -Myanmar}', "");
Expect(0, 4255, '\p{^Is_Block= -Myanmar}', "");
Expect(0, 4255, '\P{Is_Block= -Myanmar}', "");
Expect(1, 4255, '\P{^Is_Block= -Myanmar}', "");
Expect(0, 4256, '\p{Is_Block= -Myanmar}', "");
Expect(1, 4256, '\p{^Is_Block= -Myanmar}', "");
Expect(1, 4256, '\P{Is_Block= -Myanmar}', "");
Expect(0, 4256, '\P{^Is_Block= -Myanmar}', "");
Error('\p{Is_Blk=		Myanmar/a/}');
Error('\P{Is_Blk=		Myanmar/a/}');
Expect(1, 4255, '\p{Is_Blk=myanmar}', "");
Expect(0, 4255, '\p{^Is_Blk=myanmar}', "");
Expect(0, 4255, '\P{Is_Blk=myanmar}', "");
Expect(1, 4255, '\P{^Is_Blk=myanmar}', "");
Expect(0, 4256, '\p{Is_Blk=myanmar}', "");
Expect(1, 4256, '\p{^Is_Blk=myanmar}', "");
Expect(1, 4256, '\P{Is_Blk=myanmar}', "");
Expect(0, 4256, '\P{^Is_Blk=myanmar}', "");
Expect(1, 4255, '\p{Is_Blk= 	myanmar}', "");
Expect(0, 4255, '\p{^Is_Blk= 	myanmar}', "");
Expect(0, 4255, '\P{Is_Blk= 	myanmar}', "");
Expect(1, 4255, '\P{^Is_Blk= 	myanmar}', "");
Expect(0, 4256, '\p{Is_Blk= 	myanmar}', "");
Expect(1, 4256, '\p{^Is_Blk= 	myanmar}', "");
Expect(1, 4256, '\P{Is_Blk= 	myanmar}', "");
Expect(0, 4256, '\P{^Is_Blk= 	myanmar}', "");
Error('\p{Block=/a/_Myanmar_EXTENDED_A}');
Error('\P{Block=/a/_Myanmar_EXTENDED_A}');
Expect(1, 43647, '\p{Block=myanmarextendeda}', "");
Expect(0, 43647, '\p{^Block=myanmarextendeda}', "");
Expect(0, 43647, '\P{Block=myanmarextendeda}', "");
Expect(1, 43647, '\P{^Block=myanmarextendeda}', "");
Expect(0, 43648, '\p{Block=myanmarextendeda}', "");
Expect(1, 43648, '\p{^Block=myanmarextendeda}', "");
Expect(1, 43648, '\P{Block=myanmarextendeda}', "");
Expect(0, 43648, '\P{^Block=myanmarextendeda}', "");
Expect(1, 43647, '\p{Block=-Myanmar_Extended_A}', "");
Expect(0, 43647, '\p{^Block=-Myanmar_Extended_A}', "");
Expect(0, 43647, '\P{Block=-Myanmar_Extended_A}', "");
Expect(1, 43647, '\P{^Block=-Myanmar_Extended_A}', "");
Expect(0, 43648, '\p{Block=-Myanmar_Extended_A}', "");
Expect(1, 43648, '\p{^Block=-Myanmar_Extended_A}', "");
Expect(1, 43648, '\P{Block=-Myanmar_Extended_A}', "");
Expect(0, 43648, '\P{^Block=-Myanmar_Extended_A}', "");
Error('\p{Blk=/a/  myanmar_Ext_A}');
Error('\P{Blk=/a/  myanmar_Ext_A}');
Expect(1, 43647, '\p{Blk=myanmarexta}', "");
Expect(0, 43647, '\p{^Blk=myanmarexta}', "");
Expect(0, 43647, '\P{Blk=myanmarexta}', "");
Expect(1, 43647, '\P{^Blk=myanmarexta}', "");
Expect(0, 43648, '\p{Blk=myanmarexta}', "");
Expect(1, 43648, '\p{^Blk=myanmarexta}', "");
Expect(1, 43648, '\P{Blk=myanmarexta}', "");
Expect(0, 43648, '\P{^Blk=myanmarexta}', "");
Expect(1, 43647, '\p{Blk=	_MYANMAR_Ext_a}', "");
Expect(0, 43647, '\p{^Blk=	_MYANMAR_Ext_a}', "");
Expect(0, 43647, '\P{Blk=	_MYANMAR_Ext_a}', "");
Expect(1, 43647, '\P{^Blk=	_MYANMAR_Ext_a}', "");
Expect(0, 43648, '\p{Blk=	_MYANMAR_Ext_a}', "");
Expect(1, 43648, '\p{^Blk=	_MYANMAR_Ext_a}', "");
Expect(1, 43648, '\P{Blk=	_MYANMAR_Ext_a}', "");
Expect(0, 43648, '\P{^Blk=	_MYANMAR_Ext_a}', "");
Error('\p{Is_Block=-/a/MYANMAR_EXTENDED_A}');
Error('\P{Is_Block=-/a/MYANMAR_EXTENDED_A}');
Expect(1, 43647, '\p{Is_Block=myanmarextendeda}', "");
Expect(0, 43647, '\p{^Is_Block=myanmarextendeda}', "");
Expect(0, 43647, '\P{Is_Block=myanmarextendeda}', "");
Expect(1, 43647, '\P{^Is_Block=myanmarextendeda}', "");
Expect(0, 43648, '\p{Is_Block=myanmarextendeda}', "");
Expect(1, 43648, '\p{^Is_Block=myanmarextendeda}', "");
Expect(1, 43648, '\P{Is_Block=myanmarextendeda}', "");
Expect(0, 43648, '\P{^Is_Block=myanmarextendeda}', "");
Expect(1, 43647, '\p{Is_Block=_myanmar_extended_a}', "");
Expect(0, 43647, '\p{^Is_Block=_myanmar_extended_a}', "");
Expect(0, 43647, '\P{Is_Block=_myanmar_extended_a}', "");
Expect(1, 43647, '\P{^Is_Block=_myanmar_extended_a}', "");
Expect(0, 43648, '\p{Is_Block=_myanmar_extended_a}', "");
Expect(1, 43648, '\p{^Is_Block=_myanmar_extended_a}', "");
Expect(1, 43648, '\P{Is_Block=_myanmar_extended_a}', "");
Expect(0, 43648, '\P{^Is_Block=_myanmar_extended_a}', "");
Error('\p{Is_Blk=:= -myanmar_EXT_A}');
Error('\P{Is_Blk=:= -myanmar_EXT_A}');
Expect(1, 43647, '\p{Is_Blk=myanmarexta}', "");
Expect(0, 43647, '\p{^Is_Blk=myanmarexta}', "");
Expect(0, 43647, '\P{Is_Blk=myanmarexta}', "");
Expect(1, 43647, '\P{^Is_Blk=myanmarexta}', "");
Expect(0, 43648, '\p{Is_Blk=myanmarexta}', "");
Expect(1, 43648, '\p{^Is_Blk=myanmarexta}', "");
Expect(1, 43648, '\P{Is_Blk=myanmarexta}', "");
Expect(0, 43648, '\P{^Is_Blk=myanmarexta}', "");
Expect(1, 43647, '\p{Is_Blk:-_Myanmar_EXT_a}', "");
Expect(0, 43647, '\p{^Is_Blk:-_Myanmar_EXT_a}', "");
Expect(0, 43647, '\P{Is_Blk:-_Myanmar_EXT_a}', "");
Expect(1, 43647, '\P{^Is_Blk:-_Myanmar_EXT_a}', "");
Expect(0, 43648, '\p{Is_Blk:-_Myanmar_EXT_a}', "");
Expect(1, 43648, '\p{^Is_Blk:-_Myanmar_EXT_a}', "");
Expect(1, 43648, '\P{Is_Blk:-_Myanmar_EXT_a}', "");
Expect(0, 43648, '\P{^Is_Blk:-_Myanmar_EXT_a}', "");
Error('\p{Block=  no_BLOCK:=}');
Error('\P{Block=  no_BLOCK:=}');
Expect(1, 918000, '\p{Block: noblock}', "");
Expect(0, 918000, '\p{^Block: noblock}', "");
Expect(0, 918000, '\P{Block: noblock}', "");
Expect(1, 918000, '\P{^Block: noblock}', "");
Expect(0, 983040, '\p{Block: noblock}', "");
Expect(1, 983040, '\p{^Block: noblock}', "");
Expect(1, 983040, '\P{Block: noblock}', "");
Expect(0, 983040, '\P{^Block: noblock}', "");
Expect(1, 918000, '\p{Block=__No_BLOCK}', "");
Expect(0, 918000, '\p{^Block=__No_BLOCK}', "");
Expect(0, 918000, '\P{Block=__No_BLOCK}', "");
Expect(1, 918000, '\P{^Block=__No_BLOCK}', "");
Expect(0, 983040, '\p{Block=__No_BLOCK}', "");
Expect(1, 983040, '\p{^Block=__No_BLOCK}', "");
Expect(1, 983040, '\P{Block=__No_BLOCK}', "");
Expect(0, 983040, '\P{^Block=__No_BLOCK}', "");
Error('\p{Blk=:=-nb}');
Error('\P{Blk=:=-nb}');
Expect(1, 918000, '\p{Blk=nb}', "");
Expect(0, 918000, '\p{^Blk=nb}', "");
Expect(0, 918000, '\P{Blk=nb}', "");
Expect(1, 918000, '\P{^Blk=nb}', "");
Expect(0, 983040, '\p{Blk=nb}', "");
Expect(1, 983040, '\p{^Blk=nb}', "");
Expect(1, 983040, '\P{Blk=nb}', "");
Expect(0, 983040, '\P{^Blk=nb}', "");
Expect(1, 918000, '\p{Blk=  NB}', "");
Expect(0, 918000, '\p{^Blk=  NB}', "");
Expect(0, 918000, '\P{Blk=  NB}', "");
Expect(1, 918000, '\P{^Blk=  NB}', "");
Expect(0, 983040, '\p{Blk=  NB}', "");
Expect(1, 983040, '\p{^Blk=  NB}', "");
Expect(1, 983040, '\P{Blk=  NB}', "");
Expect(0, 983040, '\P{^Blk=  NB}', "");
Error('\p{Is_Block: /a/_No_Block}');
Error('\P{Is_Block: /a/_No_Block}');
Expect(1, 918000, '\p{Is_Block=noblock}', "");
Expect(0, 918000, '\p{^Is_Block=noblock}', "");
Expect(0, 918000, '\P{Is_Block=noblock}', "");
Expect(1, 918000, '\P{^Is_Block=noblock}', "");
Expect(0, 983040, '\p{Is_Block=noblock}', "");
Expect(1, 983040, '\p{^Is_Block=noblock}', "");
Expect(1, 983040, '\P{Is_Block=noblock}', "");
Expect(0, 983040, '\P{^Is_Block=noblock}', "");
Expect(1, 918000, '\p{Is_Block: _NO_BLOCK}', "");
Expect(0, 918000, '\p{^Is_Block: _NO_BLOCK}', "");
Expect(0, 918000, '\P{Is_Block: _NO_BLOCK}', "");
Expect(1, 918000, '\P{^Is_Block: _NO_BLOCK}', "");
Expect(0, 983040, '\p{Is_Block: _NO_BLOCK}', "");
Expect(1, 983040, '\p{^Is_Block: _NO_BLOCK}', "");
Expect(1, 983040, '\P{Is_Block: _NO_BLOCK}', "");
Expect(0, 983040, '\P{^Is_Block: _NO_BLOCK}', "");
Error('\p{Is_Blk=--NB/a/}');
Error('\P{Is_Blk=--NB/a/}');
Expect(1, 918000, '\p{Is_Blk=nb}', "");
Expect(0, 918000, '\p{^Is_Blk=nb}', "");
Expect(0, 918000, '\P{Is_Blk=nb}', "");
Expect(1, 918000, '\P{^Is_Blk=nb}', "");
Expect(0, 983040, '\p{Is_Blk=nb}', "");
Expect(1, 983040, '\p{^Is_Blk=nb}', "");
Expect(1, 983040, '\P{Is_Blk=nb}', "");
Expect(0, 983040, '\P{^Is_Blk=nb}', "");
Expect(1, 918000, '\p{Is_Blk=	-NB}', "");
Expect(0, 918000, '\p{^Is_Blk=	-NB}', "");
Expect(0, 918000, '\P{Is_Blk=	-NB}', "");
Expect(1, 918000, '\P{^Is_Blk=	-NB}', "");
Expect(0, 983040, '\p{Is_Blk=	-NB}', "");
Expect(1, 983040, '\p{^Is_Blk=	-NB}', "");
Expect(1, 983040, '\P{Is_Blk=	-NB}', "");
Expect(0, 983040, '\P{^Is_Blk=	-NB}', "");
Error('\p{Block:   :=	nko}');
Error('\P{Block:   :=	nko}');
Expect(1, 2047, '\p{Block=nko}', "");
Expect(0, 2047, '\p{^Block=nko}', "");
Expect(0, 2047, '\P{Block=nko}', "");
Expect(1, 2047, '\P{^Block=nko}', "");
Expect(0, 2048, '\p{Block=nko}', "");
Expect(1, 2048, '\p{^Block=nko}', "");
Expect(1, 2048, '\P{Block=nko}', "");
Expect(0, 2048, '\P{^Block=nko}', "");
Expect(1, 2047, '\p{Block= NKO}', "");
Expect(0, 2047, '\p{^Block= NKO}', "");
Expect(0, 2047, '\P{Block= NKO}', "");
Expect(1, 2047, '\P{^Block= NKO}', "");
Expect(0, 2048, '\p{Block= NKO}', "");
Expect(1, 2048, '\p{^Block= NKO}', "");
Expect(1, 2048, '\P{Block= NKO}', "");
Expect(0, 2048, '\P{^Block= NKO}', "");
Error('\p{Blk:		nko:=}');
Error('\P{Blk:		nko:=}');
Expect(1, 2047, '\p{Blk=nko}', "");
Expect(0, 2047, '\p{^Blk=nko}', "");
Expect(0, 2047, '\P{Blk=nko}', "");
Expect(1, 2047, '\P{^Blk=nko}', "");
Expect(0, 2048, '\p{Blk=nko}', "");
Expect(1, 2048, '\p{^Blk=nko}', "");
Expect(1, 2048, '\P{Blk=nko}', "");
Expect(0, 2048, '\P{^Blk=nko}', "");
Expect(1, 2047, '\p{Blk=--nko}', "");
Expect(0, 2047, '\p{^Blk=--nko}', "");
Expect(0, 2047, '\P{Blk=--nko}', "");
Expect(1, 2047, '\P{^Blk=--nko}', "");
Expect(0, 2048, '\p{Blk=--nko}', "");
Expect(1, 2048, '\p{^Blk=--nko}', "");
Expect(1, 2048, '\P{Blk=--nko}', "");
Expect(0, 2048, '\P{^Blk=--nko}', "");
Error('\p{Is_Block:	-nko/a/}');
Error('\P{Is_Block:	-nko/a/}');
Expect(1, 2047, '\p{Is_Block=nko}', "");
Expect(0, 2047, '\p{^Is_Block=nko}', "");
Expect(0, 2047, '\P{Is_Block=nko}', "");
Expect(1, 2047, '\P{^Is_Block=nko}', "");
Expect(0, 2048, '\p{Is_Block=nko}', "");
Expect(1, 2048, '\p{^Is_Block=nko}', "");
Expect(1, 2048, '\P{Is_Block=nko}', "");
Expect(0, 2048, '\P{^Is_Block=nko}', "");
Expect(1, 2047, '\p{Is_Block=_	nko}', "");
Expect(0, 2047, '\p{^Is_Block=_	nko}', "");
Expect(0, 2047, '\P{Is_Block=_	nko}', "");
Expect(1, 2047, '\P{^Is_Block=_	nko}', "");
Expect(0, 2048, '\p{Is_Block=_	nko}', "");
Expect(1, 2048, '\p{^Is_Block=_	nko}', "");
Expect(1, 2048, '\P{Is_Block=_	nko}', "");
Expect(0, 2048, '\P{^Is_Block=_	nko}', "");
Error('\p{Is_Blk=NKo:=}');
Error('\P{Is_Blk=NKo:=}');
Expect(1, 2047, '\p{Is_Blk=nko}', "");
Expect(0, 2047, '\p{^Is_Blk=nko}', "");
Expect(0, 2047, '\P{Is_Blk=nko}', "");
Expect(1, 2047, '\P{^Is_Blk=nko}', "");
Expect(0, 2048, '\p{Is_Blk=nko}', "");
Expect(1, 2048, '\p{^Is_Blk=nko}', "");
Expect(1, 2048, '\P{Is_Blk=nko}', "");
Expect(0, 2048, '\P{^Is_Blk=nko}', "");
Expect(1, 2047, '\p{Is_Blk=__NKo}', "");
Expect(0, 2047, '\p{^Is_Blk=__NKo}', "");
Expect(0, 2047, '\P{Is_Blk=__NKo}', "");
Expect(1, 2047, '\P{^Is_Blk=__NKo}', "");
Expect(0, 2048, '\p{Is_Blk=__NKo}', "");
Expect(1, 2048, '\p{^Is_Blk=__NKo}', "");
Expect(1, 2048, '\P{Is_Blk=__NKo}', "");
Expect(0, 2048, '\P{^Is_Blk=__NKo}', "");
Error('\p{Block=/a/_-New_Tai_Lue}');
Error('\P{Block=/a/_-New_Tai_Lue}');
Expect(1, 6623, '\p{Block=newtailue}', "");
Expect(0, 6623, '\p{^Block=newtailue}', "");
Expect(0, 6623, '\P{Block=newtailue}', "");
Expect(1, 6623, '\P{^Block=newtailue}', "");
Expect(0, 6624, '\p{Block=newtailue}', "");
Expect(1, 6624, '\p{^Block=newtailue}', "");
Expect(1, 6624, '\P{Block=newtailue}', "");
Expect(0, 6624, '\P{^Block=newtailue}', "");
Expect(1, 6623, '\p{Block=_NEW_Tai_LUE}', "");
Expect(0, 6623, '\p{^Block=_NEW_Tai_LUE}', "");
Expect(0, 6623, '\P{Block=_NEW_Tai_LUE}', "");
Expect(1, 6623, '\P{^Block=_NEW_Tai_LUE}', "");
Expect(0, 6624, '\p{Block=_NEW_Tai_LUE}', "");
Expect(1, 6624, '\p{^Block=_NEW_Tai_LUE}', "");
Expect(1, 6624, '\P{Block=_NEW_Tai_LUE}', "");
Expect(0, 6624, '\P{^Block=_NEW_Tai_LUE}', "");
Error('\p{Blk: NEW_tai_lue/a/}');
Error('\P{Blk: NEW_tai_lue/a/}');
Expect(1, 6623, '\p{Blk=newtailue}', "");
Expect(0, 6623, '\p{^Blk=newtailue}', "");
Expect(0, 6623, '\P{Blk=newtailue}', "");
Expect(1, 6623, '\P{^Blk=newtailue}', "");
Expect(0, 6624, '\p{Blk=newtailue}', "");
Expect(1, 6624, '\p{^Blk=newtailue}', "");
Expect(1, 6624, '\P{Blk=newtailue}', "");
Expect(0, 6624, '\P{^Blk=newtailue}', "");
Expect(1, 6623, '\p{Blk=		new_Tai_lue}', "");
Expect(0, 6623, '\p{^Blk=		new_Tai_lue}', "");
Expect(0, 6623, '\P{Blk=		new_Tai_lue}', "");
Expect(1, 6623, '\P{^Blk=		new_Tai_lue}', "");
Expect(0, 6624, '\p{Blk=		new_Tai_lue}', "");
Expect(1, 6624, '\p{^Blk=		new_Tai_lue}', "");
Expect(1, 6624, '\P{Blk=		new_Tai_lue}', "");
Expect(0, 6624, '\P{^Blk=		new_Tai_lue}', "");
Error('\p{Is_Block= :=New_TAI_lue}');
Error('\P{Is_Block= :=New_TAI_lue}');
Expect(1, 6623, '\p{Is_Block=newtailue}', "");
Expect(0, 6623, '\p{^Is_Block=newtailue}', "");
Expect(0, 6623, '\P{Is_Block=newtailue}', "");
Expect(1, 6623, '\P{^Is_Block=newtailue}', "");
Expect(0, 6624, '\p{Is_Block=newtailue}', "");
Expect(1, 6624, '\p{^Is_Block=newtailue}', "");
Expect(1, 6624, '\P{Is_Block=newtailue}', "");
Expect(0, 6624, '\P{^Is_Block=newtailue}', "");
Expect(1, 6623, '\p{Is_Block=	_new_tai_Lue}', "");
Expect(0, 6623, '\p{^Is_Block=	_new_tai_Lue}', "");
Expect(0, 6623, '\P{Is_Block=	_new_tai_Lue}', "");
Expect(1, 6623, '\P{^Is_Block=	_new_tai_Lue}', "");
Expect(0, 6624, '\p{Is_Block=	_new_tai_Lue}', "");
Expect(1, 6624, '\p{^Is_Block=	_new_tai_Lue}', "");
Expect(1, 6624, '\P{Is_Block=	_new_tai_Lue}', "");
Expect(0, 6624, '\P{^Is_Block=	_new_tai_Lue}', "");
Error('\p{Is_Blk=-/a/new_Tai_Lue}');
Error('\P{Is_Blk=-/a/new_Tai_Lue}');
Expect(1, 6623, '\p{Is_Blk=newtailue}', "");
Expect(0, 6623, '\p{^Is_Blk=newtailue}', "");
Expect(0, 6623, '\P{Is_Blk=newtailue}', "");
Expect(1, 6623, '\P{^Is_Blk=newtailue}', "");
Expect(0, 6624, '\p{Is_Blk=newtailue}', "");
Expect(1, 6624, '\p{^Is_Blk=newtailue}', "");
Expect(1, 6624, '\P{Is_Blk=newtailue}', "");
Expect(0, 6624, '\P{^Is_Blk=newtailue}', "");
Expect(1, 6623, '\p{Is_Blk:   -New_TAI_lue}', "");
Expect(0, 6623, '\p{^Is_Blk:   -New_TAI_lue}', "");
Expect(0, 6623, '\P{Is_Blk:   -New_TAI_lue}', "");
Expect(1, 6623, '\P{^Is_Blk:   -New_TAI_lue}', "");
Expect(0, 6624, '\p{Is_Blk:   -New_TAI_lue}', "");
Expect(1, 6624, '\p{^Is_Blk:   -New_TAI_lue}', "");
Expect(1, 6624, '\P{Is_Blk:   -New_TAI_lue}', "");
Expect(0, 6624, '\P{^Is_Blk:   -New_TAI_lue}', "");
Error('\p{Block=	_Number_forms:=}');
Error('\P{Block=	_Number_forms:=}');
Expect(1, 8591, '\p{Block:   numberforms}', "");
Expect(0, 8591, '\p{^Block:   numberforms}', "");
Expect(0, 8591, '\P{Block:   numberforms}', "");
Expect(1, 8591, '\P{^Block:   numberforms}', "");
Expect(0, 8592, '\p{Block:   numberforms}', "");
Expect(1, 8592, '\p{^Block:   numberforms}', "");
Expect(1, 8592, '\P{Block:   numberforms}', "");
Expect(0, 8592, '\P{^Block:   numberforms}', "");
Expect(1, 8591, '\p{Block=-	Number_Forms}', "");
Expect(0, 8591, '\p{^Block=-	Number_Forms}', "");
Expect(0, 8591, '\P{Block=-	Number_Forms}', "");
Expect(1, 8591, '\P{^Block=-	Number_Forms}', "");
Expect(0, 8592, '\p{Block=-	Number_Forms}', "");
Expect(1, 8592, '\p{^Block=-	Number_Forms}', "");
Expect(1, 8592, '\P{Block=-	Number_Forms}', "");
Expect(0, 8592, '\P{^Block=-	Number_Forms}', "");
Error('\p{Blk= -Number_FORMS:=}');
Error('\P{Blk= -Number_FORMS:=}');
Expect(1, 8591, '\p{Blk=numberforms}', "");
Expect(0, 8591, '\p{^Blk=numberforms}', "");
Expect(0, 8591, '\P{Blk=numberforms}', "");
Expect(1, 8591, '\P{^Blk=numberforms}', "");
Expect(0, 8592, '\p{Blk=numberforms}', "");
Expect(1, 8592, '\p{^Blk=numberforms}', "");
Expect(1, 8592, '\P{Blk=numberforms}', "");
Expect(0, 8592, '\P{^Blk=numberforms}', "");
Expect(1, 8591, '\p{Blk=_-Number_Forms}', "");
Expect(0, 8591, '\p{^Blk=_-Number_Forms}', "");
Expect(0, 8591, '\P{Blk=_-Number_Forms}', "");
Expect(1, 8591, '\P{^Blk=_-Number_Forms}', "");
Expect(0, 8592, '\p{Blk=_-Number_Forms}', "");
Expect(1, 8592, '\p{^Blk=_-Number_Forms}', "");
Expect(1, 8592, '\P{Blk=_-Number_Forms}', "");
Expect(0, 8592, '\P{^Blk=_-Number_Forms}', "");
Error('\p{Is_Block=/a/ Number_forms}');
Error('\P{Is_Block=/a/ Number_forms}');
Expect(1, 8591, '\p{Is_Block=numberforms}', "");
Expect(0, 8591, '\p{^Is_Block=numberforms}', "");
Expect(0, 8591, '\P{Is_Block=numberforms}', "");
Expect(1, 8591, '\P{^Is_Block=numberforms}', "");
Expect(0, 8592, '\p{Is_Block=numberforms}', "");
Expect(1, 8592, '\p{^Is_Block=numberforms}', "");
Expect(1, 8592, '\P{Is_Block=numberforms}', "");
Expect(0, 8592, '\P{^Is_Block=numberforms}', "");
Expect(1, 8591, '\p{Is_Block= -NUMBER_Forms}', "");
Expect(0, 8591, '\p{^Is_Block= -NUMBER_Forms}', "");
Expect(0, 8591, '\P{Is_Block= -NUMBER_Forms}', "");
Expect(1, 8591, '\P{^Is_Block= -NUMBER_Forms}', "");
Expect(0, 8592, '\p{Is_Block= -NUMBER_Forms}', "");
Expect(1, 8592, '\p{^Is_Block= -NUMBER_Forms}', "");
Expect(1, 8592, '\P{Is_Block= -NUMBER_Forms}', "");
Expect(0, 8592, '\P{^Is_Block= -NUMBER_Forms}', "");
Error('\p{Is_Blk=:=		number_FORMS}');
Error('\P{Is_Blk=:=		number_FORMS}');
Expect(1, 8591, '\p{Is_Blk=numberforms}', "");
Expect(0, 8591, '\p{^Is_Blk=numberforms}', "");
Expect(0, 8591, '\P{Is_Blk=numberforms}', "");
Expect(1, 8591, '\P{^Is_Blk=numberforms}', "");
Expect(0, 8592, '\p{Is_Blk=numberforms}', "");
Expect(1, 8592, '\p{^Is_Blk=numberforms}', "");
Expect(1, 8592, '\P{Is_Blk=numberforms}', "");
Expect(0, 8592, '\P{^Is_Blk=numberforms}', "");
Expect(1, 8591, '\p{Is_Blk:	-	Number_FORMS}', "");
Expect(0, 8591, '\p{^Is_Blk:	-	Number_FORMS}', "");
Expect(0, 8591, '\P{Is_Blk:	-	Number_FORMS}', "");
Expect(1, 8591, '\P{^Is_Blk:	-	Number_FORMS}', "");
Expect(0, 8592, '\p{Is_Blk:	-	Number_FORMS}', "");
Expect(1, 8592, '\p{^Is_Blk:	-	Number_FORMS}', "");
Expect(1, 8592, '\P{Is_Blk:	-	Number_FORMS}', "");
Expect(0, 8592, '\P{^Is_Blk:	-	Number_FORMS}', "");
Error('\p{Block=:=	 Optical_Character_Recognition}');
Error('\P{Block=:=	 Optical_Character_Recognition}');
Expect(1, 9311, '\p{Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\P{Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\p{Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\P{Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\p{Block:	_Optical_Character_recognition}', "");
Expect(0, 9311, '\p{^Block:	_Optical_Character_recognition}', "");
Expect(0, 9311, '\P{Block:	_Optical_Character_recognition}', "");
Expect(1, 9311, '\P{^Block:	_Optical_Character_recognition}', "");
Expect(0, 9312, '\p{Block:	_Optical_Character_recognition}', "");
Expect(1, 9312, '\p{^Block:	_Optical_Character_recognition}', "");
Expect(1, 9312, '\P{Block:	_Optical_Character_recognition}', "");
Expect(0, 9312, '\P{^Block:	_Optical_Character_recognition}', "");
Error('\p{Blk=	:=OCR}');
Error('\P{Blk=	:=OCR}');
Expect(1, 9311, '\p{Blk=ocr}', "");
Expect(0, 9311, '\p{^Blk=ocr}', "");
Expect(0, 9311, '\P{Blk=ocr}', "");
Expect(1, 9311, '\P{^Blk=ocr}', "");
Expect(0, 9312, '\p{Blk=ocr}', "");
Expect(1, 9312, '\p{^Blk=ocr}', "");
Expect(1, 9312, '\P{Blk=ocr}', "");
Expect(0, 9312, '\P{^Blk=ocr}', "");
Expect(1, 9311, '\p{Blk=_OCR}', "");
Expect(0, 9311, '\p{^Blk=_OCR}', "");
Expect(0, 9311, '\P{Blk=_OCR}', "");
Expect(1, 9311, '\P{^Blk=_OCR}', "");
Expect(0, 9312, '\p{Blk=_OCR}', "");
Expect(1, 9312, '\p{^Blk=_OCR}', "");
Expect(1, 9312, '\P{Blk=_OCR}', "");
Expect(0, 9312, '\P{^Blk=_OCR}', "");
Error('\p{Is_Block= /a/Optical_character_Recognition}');
Error('\P{Is_Block= /a/Optical_character_Recognition}');
Expect(1, 9311, '\p{Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9311, '\P{Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\p{Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9312, '\P{Is_Block=opticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^Is_Block=opticalcharacterrecognition}', "");
Expect(1, 9311, '\p{Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(0, 9311, '\p{^Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(0, 9311, '\P{Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(1, 9311, '\P{^Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(0, 9312, '\p{Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(1, 9312, '\p{^Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(1, 9312, '\P{Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Expect(0, 9312, '\P{^Is_Block=-optical_CHARACTER_RECOGNITION}', "");
Error('\p{Is_Blk= :=OCR}');
Error('\P{Is_Blk= :=OCR}');
Expect(1, 9311, '\p{Is_Blk=ocr}', "");
Expect(0, 9311, '\p{^Is_Blk=ocr}', "");
Expect(0, 9311, '\P{Is_Blk=ocr}', "");
Expect(1, 9311, '\P{^Is_Blk=ocr}', "");
Expect(0, 9312, '\p{Is_Blk=ocr}', "");
Expect(1, 9312, '\p{^Is_Blk=ocr}', "");
Expect(1, 9312, '\P{Is_Blk=ocr}', "");
Expect(0, 9312, '\P{^Is_Blk=ocr}', "");
Error('\p{Block=_Ogham/a/}');
Error('\P{Block=_Ogham/a/}');
Expect(1, 5791, '\p{Block=ogham}', "");
Expect(0, 5791, '\p{^Block=ogham}', "");
Expect(0, 5791, '\P{Block=ogham}', "");
Expect(1, 5791, '\P{^Block=ogham}', "");
Expect(0, 5792, '\p{Block=ogham}', "");
Expect(1, 5792, '\p{^Block=ogham}', "");
Expect(1, 5792, '\P{Block=ogham}', "");
Expect(0, 5792, '\P{^Block=ogham}', "");
Expect(1, 5791, '\p{Block=__Ogham}', "");
Expect(0, 5791, '\p{^Block=__Ogham}', "");
Expect(0, 5791, '\P{Block=__Ogham}', "");
Expect(1, 5791, '\P{^Block=__Ogham}', "");
Expect(0, 5792, '\p{Block=__Ogham}', "");
Expect(1, 5792, '\p{^Block=__Ogham}', "");
Expect(1, 5792, '\P{Block=__Ogham}', "");
Expect(0, 5792, '\P{^Block=__Ogham}', "");
Error('\p{Blk=/a/-_ogham}');
Error('\P{Blk=/a/-_ogham}');
Expect(1, 5791, '\p{Blk=ogham}', "");
Expect(0, 5791, '\p{^Blk=ogham}', "");
Expect(0, 5791, '\P{Blk=ogham}', "");
Expect(1, 5791, '\P{^Blk=ogham}', "");
Expect(0, 5792, '\p{Blk=ogham}', "");
Expect(1, 5792, '\p{^Blk=ogham}', "");
Expect(1, 5792, '\P{Blk=ogham}', "");
Expect(0, 5792, '\P{^Blk=ogham}', "");
Expect(1, 5791, '\p{Blk=_ Ogham}', "");
Expect(0, 5791, '\p{^Blk=_ Ogham}', "");
Expect(0, 5791, '\P{Blk=_ Ogham}', "");
Expect(1, 5791, '\P{^Blk=_ Ogham}', "");
Expect(0, 5792, '\p{Blk=_ Ogham}', "");
Expect(1, 5792, '\p{^Blk=_ Ogham}', "");
Expect(1, 5792, '\P{Blk=_ Ogham}', "");
Expect(0, 5792, '\P{^Blk=_ Ogham}', "");
Error('\p{Is_Block=/a/ 	OGHAM}');
Error('\P{Is_Block=/a/ 	OGHAM}');
Expect(1, 5791, '\p{Is_Block=ogham}', "");
Expect(0, 5791, '\p{^Is_Block=ogham}', "");
Expect(0, 5791, '\P{Is_Block=ogham}', "");
Expect(1, 5791, '\P{^Is_Block=ogham}', "");
Expect(0, 5792, '\p{Is_Block=ogham}', "");
Expect(1, 5792, '\p{^Is_Block=ogham}', "");
Expect(1, 5792, '\P{Is_Block=ogham}', "");
Expect(0, 5792, '\P{^Is_Block=ogham}', "");
Expect(1, 5791, '\p{Is_Block=- Ogham}', "");
Expect(0, 5791, '\p{^Is_Block=- Ogham}', "");
Expect(0, 5791, '\P{Is_Block=- Ogham}', "");
Expect(1, 5791, '\P{^Is_Block=- Ogham}', "");
Expect(0, 5792, '\p{Is_Block=- Ogham}', "");
Expect(1, 5792, '\p{^Is_Block=- Ogham}', "");
Expect(1, 5792, '\P{Is_Block=- Ogham}', "");
Expect(0, 5792, '\P{^Is_Block=- Ogham}', "");
Error('\p{Is_Blk=  ogham:=}');
Error('\P{Is_Blk=  ogham:=}');
Expect(1, 5791, '\p{Is_Blk=ogham}', "");
Expect(0, 5791, '\p{^Is_Blk=ogham}', "");
Expect(0, 5791, '\P{Is_Blk=ogham}', "");
Expect(1, 5791, '\P{^Is_Blk=ogham}', "");
Expect(0, 5792, '\p{Is_Blk=ogham}', "");
Expect(1, 5792, '\p{^Is_Blk=ogham}', "");
Expect(1, 5792, '\P{Is_Blk=ogham}', "");
Expect(0, 5792, '\P{^Is_Blk=ogham}', "");
Expect(1, 5791, '\p{Is_Blk=	 OGHAM}', "");
Expect(0, 5791, '\p{^Is_Blk=	 OGHAM}', "");
Expect(0, 5791, '\P{Is_Blk=	 OGHAM}', "");
Expect(1, 5791, '\P{^Is_Blk=	 OGHAM}', "");
Expect(0, 5792, '\p{Is_Blk=	 OGHAM}', "");
Expect(1, 5792, '\p{^Is_Blk=	 OGHAM}', "");
Expect(1, 5792, '\P{Is_Blk=	 OGHAM}', "");
Expect(0, 5792, '\P{^Is_Blk=	 OGHAM}', "");
Error('\p{Block=_/a/ol_Chiki}');
Error('\P{Block=_/a/ol_Chiki}');
Expect(1, 7295, '\p{Block:   olchiki}', "");
Expect(0, 7295, '\p{^Block:   olchiki}', "");
Expect(0, 7295, '\P{Block:   olchiki}', "");
Expect(1, 7295, '\P{^Block:   olchiki}', "");
Expect(0, 7296, '\p{Block:   olchiki}', "");
Expect(1, 7296, '\p{^Block:   olchiki}', "");
Expect(1, 7296, '\P{Block:   olchiki}', "");
Expect(0, 7296, '\P{^Block:   olchiki}', "");
Expect(1, 7295, '\p{Block=	 Ol_CHIKI}', "");
Expect(0, 7295, '\p{^Block=	 Ol_CHIKI}', "");
Expect(0, 7295, '\P{Block=	 Ol_CHIKI}', "");
Expect(1, 7295, '\P{^Block=	 Ol_CHIKI}', "");
Expect(0, 7296, '\p{Block=	 Ol_CHIKI}', "");
Expect(1, 7296, '\p{^Block=	 Ol_CHIKI}', "");
Expect(1, 7296, '\P{Block=	 Ol_CHIKI}', "");
Expect(0, 7296, '\P{^Block=	 Ol_CHIKI}', "");
Error('\p{Blk= /a/Ol_Chiki}');
Error('\P{Blk= /a/Ol_Chiki}');
Expect(1, 7295, '\p{Blk=olchiki}', "");
Expect(0, 7295, '\p{^Blk=olchiki}', "");
Expect(0, 7295, '\P{Blk=olchiki}', "");
Expect(1, 7295, '\P{^Blk=olchiki}', "");
Expect(0, 7296, '\p{Blk=olchiki}', "");
Expect(1, 7296, '\p{^Blk=olchiki}', "");
Expect(1, 7296, '\P{Blk=olchiki}', "");
Expect(0, 7296, '\P{^Blk=olchiki}', "");
Expect(1, 7295, '\p{Blk=__OL_CHIKI}', "");
Expect(0, 7295, '\p{^Blk=__OL_CHIKI}', "");
Expect(0, 7295, '\P{Blk=__OL_CHIKI}', "");
Expect(1, 7295, '\P{^Blk=__OL_CHIKI}', "");
Expect(0, 7296, '\p{Blk=__OL_CHIKI}', "");
Expect(1, 7296, '\p{^Blk=__OL_CHIKI}', "");
Expect(1, 7296, '\P{Blk=__OL_CHIKI}', "");
Expect(0, 7296, '\P{^Blk=__OL_CHIKI}', "");
Error('\p{Is_Block=:=-_Ol_chiki}');
Error('\P{Is_Block=:=-_Ol_chiki}');
Expect(1, 7295, '\p{Is_Block=olchiki}', "");
Expect(0, 7295, '\p{^Is_Block=olchiki}', "");
Expect(0, 7295, '\P{Is_Block=olchiki}', "");
Expect(1, 7295, '\P{^Is_Block=olchiki}', "");
Expect(0, 7296, '\p{Is_Block=olchiki}', "");
Expect(1, 7296, '\p{^Is_Block=olchiki}', "");
Expect(1, 7296, '\P{Is_Block=olchiki}', "");
Expect(0, 7296, '\P{^Is_Block=olchiki}', "");
Expect(1, 7295, '\p{Is_Block=		ol_CHIKI}', "");
Expect(0, 7295, '\p{^Is_Block=		ol_CHIKI}', "");
Expect(0, 7295, '\P{Is_Block=		ol_CHIKI}', "");
Expect(1, 7295, '\P{^Is_Block=		ol_CHIKI}', "");
Expect(0, 7296, '\p{Is_Block=		ol_CHIKI}', "");
Expect(1, 7296, '\p{^Is_Block=		ol_CHIKI}', "");
Expect(1, 7296, '\P{Is_Block=		ol_CHIKI}', "");
Expect(0, 7296, '\P{^Is_Block=		ol_CHIKI}', "");
Error('\p{Is_Blk=_Ol_Chiki/a/}');
Error('\P{Is_Blk=_Ol_Chiki/a/}');
Expect(1, 7295, '\p{Is_Blk:olchiki}', "");
Expect(0, 7295, '\p{^Is_Blk:olchiki}', "");
Expect(0, 7295, '\P{Is_Blk:olchiki}', "");
Expect(1, 7295, '\P{^Is_Blk:olchiki}', "");
Expect(0, 7296, '\p{Is_Blk:olchiki}', "");
Expect(1, 7296, '\p{^Is_Blk:olchiki}', "");
Expect(1, 7296, '\P{Is_Blk:olchiki}', "");
Expect(0, 7296, '\P{^Is_Blk:olchiki}', "");
Expect(1, 7295, '\p{Is_Blk=_	Ol_Chiki}', "");
Expect(0, 7295, '\p{^Is_Blk=_	Ol_Chiki}', "");
Expect(0, 7295, '\P{Is_Blk=_	Ol_Chiki}', "");
Expect(1, 7295, '\P{^Is_Blk=_	Ol_Chiki}', "");
Expect(0, 7296, '\p{Is_Blk=_	Ol_Chiki}', "");
Expect(1, 7296, '\p{^Is_Blk=_	Ol_Chiki}', "");
Expect(1, 7296, '\P{Is_Blk=_	Ol_Chiki}', "");
Expect(0, 7296, '\P{^Is_Blk=_	Ol_Chiki}', "");
Error('\p{Block=	 Old_italic/a/}');
Error('\P{Block=	 Old_italic/a/}');
Expect(1, 66351, '\p{Block=olditalic}', "");
Expect(0, 66351, '\p{^Block=olditalic}', "");
Expect(0, 66351, '\P{Block=olditalic}', "");
Expect(1, 66351, '\P{^Block=olditalic}', "");
Expect(0, 66352, '\p{Block=olditalic}', "");
Expect(1, 66352, '\p{^Block=olditalic}', "");
Expect(1, 66352, '\P{Block=olditalic}', "");
Expect(0, 66352, '\P{^Block=olditalic}', "");
Expect(1, 66351, '\p{Block:   _old_Italic}', "");
Expect(0, 66351, '\p{^Block:   _old_Italic}', "");
Expect(0, 66351, '\P{Block:   _old_Italic}', "");
Expect(1, 66351, '\P{^Block:   _old_Italic}', "");
Expect(0, 66352, '\p{Block:   _old_Italic}', "");
Expect(1, 66352, '\p{^Block:   _old_Italic}', "");
Expect(1, 66352, '\P{Block:   _old_Italic}', "");
Expect(0, 66352, '\P{^Block:   _old_Italic}', "");
Error('\p{Blk=/a/	-Old_Italic}');
Error('\P{Blk=/a/	-Old_Italic}');
Expect(1, 66351, '\p{Blk=olditalic}', "");
Expect(0, 66351, '\p{^Blk=olditalic}', "");
Expect(0, 66351, '\P{Blk=olditalic}', "");
Expect(1, 66351, '\P{^Blk=olditalic}', "");
Expect(0, 66352, '\p{Blk=olditalic}', "");
Expect(1, 66352, '\p{^Blk=olditalic}', "");
Expect(1, 66352, '\P{Blk=olditalic}', "");
Expect(0, 66352, '\P{^Blk=olditalic}', "");
Expect(1, 66351, '\p{Blk= 	Old_Italic}', "");
Expect(0, 66351, '\p{^Blk= 	Old_Italic}', "");
Expect(0, 66351, '\P{Blk= 	Old_Italic}', "");
Expect(1, 66351, '\P{^Blk= 	Old_Italic}', "");
Expect(0, 66352, '\p{Blk= 	Old_Italic}', "");
Expect(1, 66352, '\p{^Blk= 	Old_Italic}', "");
Expect(1, 66352, '\P{Blk= 	Old_Italic}', "");
Expect(0, 66352, '\P{^Blk= 	Old_Italic}', "");
Error('\p{Is_Block=	/a/OLD_italic}');
Error('\P{Is_Block=	/a/OLD_italic}');
Expect(1, 66351, '\p{Is_Block=olditalic}', "");
Expect(0, 66351, '\p{^Is_Block=olditalic}', "");
Expect(0, 66351, '\P{Is_Block=olditalic}', "");
Expect(1, 66351, '\P{^Is_Block=olditalic}', "");
Expect(0, 66352, '\p{Is_Block=olditalic}', "");
Expect(1, 66352, '\p{^Is_Block=olditalic}', "");
Expect(1, 66352, '\P{Is_Block=olditalic}', "");
Expect(0, 66352, '\P{^Is_Block=olditalic}', "");
Expect(1, 66351, '\p{Is_Block:		old_Italic}', "");
Expect(0, 66351, '\p{^Is_Block:		old_Italic}', "");
Expect(0, 66351, '\P{Is_Block:		old_Italic}', "");
Expect(1, 66351, '\P{^Is_Block:		old_Italic}', "");
Expect(0, 66352, '\p{Is_Block:		old_Italic}', "");
Expect(1, 66352, '\p{^Is_Block:		old_Italic}', "");
Expect(1, 66352, '\P{Is_Block:		old_Italic}', "");
Expect(0, 66352, '\P{^Is_Block:		old_Italic}', "");
Error('\p{Is_Blk:   /a/Old_Italic}');
Error('\P{Is_Blk:   /a/Old_Italic}');
Expect(1, 66351, '\p{Is_Blk=olditalic}', "");
Expect(0, 66351, '\p{^Is_Blk=olditalic}', "");
Expect(0, 66351, '\P{Is_Blk=olditalic}', "");
Expect(1, 66351, '\P{^Is_Blk=olditalic}', "");
Expect(0, 66352, '\p{Is_Blk=olditalic}', "");
Expect(1, 66352, '\p{^Is_Blk=olditalic}', "");
Expect(1, 66352, '\P{Is_Blk=olditalic}', "");
Expect(0, 66352, '\P{^Is_Blk=olditalic}', "");
Expect(1, 66351, '\p{Is_Blk= -Old_ITALIC}', "");
Expect(0, 66351, '\p{^Is_Blk= -Old_ITALIC}', "");
Expect(0, 66351, '\P{Is_Blk= -Old_ITALIC}', "");
Expect(1, 66351, '\P{^Is_Blk= -Old_ITALIC}', "");
Expect(0, 66352, '\p{Is_Blk= -Old_ITALIC}', "");
Expect(1, 66352, '\p{^Is_Blk= -Old_ITALIC}', "");
Expect(1, 66352, '\P{Is_Blk= -Old_ITALIC}', "");
Expect(0, 66352, '\P{^Is_Blk= -Old_ITALIC}', "");
Error('\p{Block=:= 	old_persian}');
Error('\P{Block=:= 	old_persian}');
Expect(1, 66527, '\p{Block=oldpersian}', "");
Expect(0, 66527, '\p{^Block=oldpersian}', "");
Expect(0, 66527, '\P{Block=oldpersian}', "");
Expect(1, 66527, '\P{^Block=oldpersian}', "");
Expect(0, 66528, '\p{Block=oldpersian}', "");
Expect(1, 66528, '\p{^Block=oldpersian}', "");
Expect(1, 66528, '\P{Block=oldpersian}', "");
Expect(0, 66528, '\P{^Block=oldpersian}', "");
Expect(1, 66527, '\p{Block=-Old_Persian}', "");
Expect(0, 66527, '\p{^Block=-Old_Persian}', "");
Expect(0, 66527, '\P{Block=-Old_Persian}', "");
Expect(1, 66527, '\P{^Block=-Old_Persian}', "");
Expect(0, 66528, '\p{Block=-Old_Persian}', "");
Expect(1, 66528, '\p{^Block=-Old_Persian}', "");
Expect(1, 66528, '\P{Block=-Old_Persian}', "");
Expect(0, 66528, '\P{^Block=-Old_Persian}', "");
Error('\p{Blk:   /a/-_Old_Persian}');
Error('\P{Blk:   /a/-_Old_Persian}');
Expect(1, 66527, '\p{Blk:   oldpersian}', "");
Expect(0, 66527, '\p{^Blk:   oldpersian}', "");
Expect(0, 66527, '\P{Blk:   oldpersian}', "");
Expect(1, 66527, '\P{^Blk:   oldpersian}', "");
Expect(0, 66528, '\p{Blk:   oldpersian}', "");
Expect(1, 66528, '\p{^Blk:   oldpersian}', "");
Expect(1, 66528, '\P{Blk:   oldpersian}', "");
Expect(0, 66528, '\P{^Blk:   oldpersian}', "");
Expect(1, 66527, '\p{Blk: -Old_persian}', "");
Expect(0, 66527, '\p{^Blk: -Old_persian}', "");
Expect(0, 66527, '\P{Blk: -Old_persian}', "");
Expect(1, 66527, '\P{^Blk: -Old_persian}', "");
Expect(0, 66528, '\p{Blk: -Old_persian}', "");
Expect(1, 66528, '\p{^Blk: -Old_persian}', "");
Expect(1, 66528, '\P{Blk: -Old_persian}', "");
Expect(0, 66528, '\P{^Blk: -Old_persian}', "");
Error('\p{Is_Block=/a/ -old_Persian}');
Error('\P{Is_Block=/a/ -old_Persian}');
Expect(1, 66527, '\p{Is_Block=oldpersian}', "");
Expect(0, 66527, '\p{^Is_Block=oldpersian}', "");
Expect(0, 66527, '\P{Is_Block=oldpersian}', "");
Expect(1, 66527, '\P{^Is_Block=oldpersian}', "");
Expect(0, 66528, '\p{Is_Block=oldpersian}', "");
Expect(1, 66528, '\p{^Is_Block=oldpersian}', "");
Expect(1, 66528, '\P{Is_Block=oldpersian}', "");
Expect(0, 66528, '\P{^Is_Block=oldpersian}', "");
Expect(1, 66527, '\p{Is_Block= Old_persian}', "");
Expect(0, 66527, '\p{^Is_Block= Old_persian}', "");
Expect(0, 66527, '\P{Is_Block= Old_persian}', "");
Expect(1, 66527, '\P{^Is_Block= Old_persian}', "");
Expect(0, 66528, '\p{Is_Block= Old_persian}', "");
Expect(1, 66528, '\p{^Is_Block= Old_persian}', "");
Expect(1, 66528, '\P{Is_Block= Old_persian}', "");
Expect(0, 66528, '\P{^Is_Block= Old_persian}', "");
Error('\p{Is_Blk= -Old_persian:=}');
Error('\P{Is_Blk= -Old_persian:=}');
Expect(1, 66527, '\p{Is_Blk=oldpersian}', "");
Expect(0, 66527, '\p{^Is_Blk=oldpersian}', "");
Expect(0, 66527, '\P{Is_Blk=oldpersian}', "");
Expect(1, 66527, '\P{^Is_Blk=oldpersian}', "");
Expect(0, 66528, '\p{Is_Blk=oldpersian}', "");
Expect(1, 66528, '\p{^Is_Blk=oldpersian}', "");
Expect(1, 66528, '\P{Is_Blk=oldpersian}', "");
Expect(0, 66528, '\P{^Is_Blk=oldpersian}', "");
Expect(1, 66527, '\p{Is_Blk=_Old_Persian}', "");
Expect(0, 66527, '\p{^Is_Blk=_Old_Persian}', "");
Expect(0, 66527, '\P{Is_Blk=_Old_Persian}', "");
Expect(1, 66527, '\P{^Is_Blk=_Old_Persian}', "");
Expect(0, 66528, '\p{Is_Blk=_Old_Persian}', "");
Expect(1, 66528, '\p{^Is_Blk=_Old_Persian}', "");
Expect(1, 66528, '\P{Is_Blk=_Old_Persian}', "");
Expect(0, 66528, '\P{^Is_Blk=_Old_Persian}', "");
Error('\p{Block= :=OLD_South_ARABIAN}');
Error('\P{Block= :=OLD_South_ARABIAN}');
Expect(1, 68223, '\p{Block=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Block=oldsoutharabian}', "");
Expect(0, 68223, '\P{Block=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Block=oldsoutharabian}', "");
Expect(0, 68224, '\p{Block=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Block=oldsoutharabian}', "");
Expect(1, 68224, '\P{Block=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Block=oldsoutharabian}', "");
Expect(1, 68223, '\p{Block= 	old_south_Arabian}', "");
Expect(0, 68223, '\p{^Block= 	old_south_Arabian}', "");
Expect(0, 68223, '\P{Block= 	old_south_Arabian}', "");
Expect(1, 68223, '\P{^Block= 	old_south_Arabian}', "");
Expect(0, 68224, '\p{Block= 	old_south_Arabian}', "");
Expect(1, 68224, '\p{^Block= 	old_south_Arabian}', "");
Expect(1, 68224, '\P{Block= 	old_south_Arabian}', "");
Expect(0, 68224, '\P{^Block= 	old_south_Arabian}', "");
Error('\p{Blk= -old_south_arabian:=}');
Error('\P{Blk= -old_south_arabian:=}');
Expect(1, 68223, '\p{Blk=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Blk=oldsoutharabian}', "");
Expect(0, 68223, '\P{Blk=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Blk=oldsoutharabian}', "");
Expect(0, 68224, '\p{Blk=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Blk=oldsoutharabian}', "");
Expect(1, 68224, '\P{Blk=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Blk=oldsoutharabian}', "");
Expect(1, 68223, '\p{Blk=-OLD_South_Arabian}', "");
Expect(0, 68223, '\p{^Blk=-OLD_South_Arabian}', "");
Expect(0, 68223, '\P{Blk=-OLD_South_Arabian}', "");
Expect(1, 68223, '\P{^Blk=-OLD_South_Arabian}', "");
Expect(0, 68224, '\p{Blk=-OLD_South_Arabian}', "");
Expect(1, 68224, '\p{^Blk=-OLD_South_Arabian}', "");
Expect(1, 68224, '\P{Blk=-OLD_South_Arabian}', "");
Expect(0, 68224, '\P{^Blk=-OLD_South_Arabian}', "");
Error('\p{Is_Block=/a/	-old_SOUTH_arabian}');
Error('\P{Is_Block=/a/	-old_SOUTH_arabian}');
Expect(1, 68223, '\p{Is_Block=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Block=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Block=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Block=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Block=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Block=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Block=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Block=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Block=_OLD_South_Arabian}', "");
Expect(0, 68223, '\p{^Is_Block=_OLD_South_Arabian}', "");
Expect(0, 68223, '\P{Is_Block=_OLD_South_Arabian}', "");
Expect(1, 68223, '\P{^Is_Block=_OLD_South_Arabian}', "");
Expect(0, 68224, '\p{Is_Block=_OLD_South_Arabian}', "");
Expect(1, 68224, '\p{^Is_Block=_OLD_South_Arabian}', "");
Expect(1, 68224, '\P{Is_Block=_OLD_South_Arabian}', "");
Expect(0, 68224, '\P{^Is_Block=_OLD_South_Arabian}', "");
Error('\p{Is_Blk= :=OLD_south_ARABIAN}');
Error('\P{Is_Blk= :=OLD_south_ARABIAN}');
Expect(1, 68223, '\p{Is_Blk:oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Blk:oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Blk:oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Blk:oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Blk:oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Blk:oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Blk:oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Blk:oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Blk=- OLD_south_ARABIAN}', "");
Expect(0, 68223, '\p{^Is_Blk=- OLD_south_ARABIAN}', "");
Expect(0, 68223, '\P{Is_Blk=- OLD_south_ARABIAN}', "");
Expect(1, 68223, '\P{^Is_Blk=- OLD_south_ARABIAN}', "");
Expect(0, 68224, '\p{Is_Blk=- OLD_south_ARABIAN}', "");
Expect(1, 68224, '\p{^Is_Blk=- OLD_south_ARABIAN}', "");
Expect(1, 68224, '\P{Is_Blk=- OLD_south_ARABIAN}', "");
Expect(0, 68224, '\P{^Is_Blk=- OLD_south_ARABIAN}', "");
Error('\p{Block=:=-old_Turkic}');
Error('\P{Block=:=-old_Turkic}');
Expect(1, 68687, '\p{Block:	oldturkic}', "");
Expect(0, 68687, '\p{^Block:	oldturkic}', "");
Expect(0, 68687, '\P{Block:	oldturkic}', "");
Expect(1, 68687, '\P{^Block:	oldturkic}', "");
Expect(0, 68688, '\p{Block:	oldturkic}', "");
Expect(1, 68688, '\p{^Block:	oldturkic}', "");
Expect(1, 68688, '\P{Block:	oldturkic}', "");
Expect(0, 68688, '\P{^Block:	oldturkic}', "");
Expect(1, 68687, '\p{Block:   _	Old_TURKIC}', "");
Expect(0, 68687, '\p{^Block:   _	Old_TURKIC}', "");
Expect(0, 68687, '\P{Block:   _	Old_TURKIC}', "");
Expect(1, 68687, '\P{^Block:   _	Old_TURKIC}', "");
Expect(0, 68688, '\p{Block:   _	Old_TURKIC}', "");
Expect(1, 68688, '\p{^Block:   _	Old_TURKIC}', "");
Expect(1, 68688, '\P{Block:   _	Old_TURKIC}', "");
Expect(0, 68688, '\P{^Block:   _	Old_TURKIC}', "");
Error('\p{Blk=/a/old_Turkic}');
Error('\P{Blk=/a/old_Turkic}');
Expect(1, 68687, '\p{Blk=oldturkic}', "");
Expect(0, 68687, '\p{^Blk=oldturkic}', "");
Expect(0, 68687, '\P{Blk=oldturkic}', "");
Expect(1, 68687, '\P{^Blk=oldturkic}', "");
Expect(0, 68688, '\p{Blk=oldturkic}', "");
Expect(1, 68688, '\p{^Blk=oldturkic}', "");
Expect(1, 68688, '\P{Blk=oldturkic}', "");
Expect(0, 68688, '\P{^Blk=oldturkic}', "");
Expect(1, 68687, '\p{Blk=	old_Turkic}', "");
Expect(0, 68687, '\p{^Blk=	old_Turkic}', "");
Expect(0, 68687, '\P{Blk=	old_Turkic}', "");
Expect(1, 68687, '\P{^Blk=	old_Turkic}', "");
Expect(0, 68688, '\p{Blk=	old_Turkic}', "");
Expect(1, 68688, '\p{^Blk=	old_Turkic}', "");
Expect(1, 68688, '\P{Blk=	old_Turkic}', "");
Expect(0, 68688, '\P{^Blk=	old_Turkic}', "");
Error('\p{Is_Block=/a/ -OLD_Turkic}');
Error('\P{Is_Block=/a/ -OLD_Turkic}');
Expect(1, 68687, '\p{Is_Block=oldturkic}', "");
Expect(0, 68687, '\p{^Is_Block=oldturkic}', "");
Expect(0, 68687, '\P{Is_Block=oldturkic}', "");
Expect(1, 68687, '\P{^Is_Block=oldturkic}', "");
Expect(0, 68688, '\p{Is_Block=oldturkic}', "");
Expect(1, 68688, '\p{^Is_Block=oldturkic}', "");
Expect(1, 68688, '\P{Is_Block=oldturkic}', "");
Expect(0, 68688, '\P{^Is_Block=oldturkic}', "");
Expect(1, 68687, '\p{Is_Block:		old_Turkic}', "");
Expect(0, 68687, '\p{^Is_Block:		old_Turkic}', "");
Expect(0, 68687, '\P{Is_Block:		old_Turkic}', "");
Expect(1, 68687, '\P{^Is_Block:		old_Turkic}', "");
Expect(0, 68688, '\p{Is_Block:		old_Turkic}', "");
Expect(1, 68688, '\p{^Is_Block:		old_Turkic}', "");
Expect(1, 68688, '\P{Is_Block:		old_Turkic}', "");
Expect(0, 68688, '\P{^Is_Block:		old_Turkic}', "");
Error('\p{Is_Blk=Old_Turkic/a/}');
Error('\P{Is_Blk=Old_Turkic/a/}');
Expect(1, 68687, '\p{Is_Blk=oldturkic}', "");
Expect(0, 68687, '\p{^Is_Blk=oldturkic}', "");
Expect(0, 68687, '\P{Is_Blk=oldturkic}', "");
Expect(1, 68687, '\P{^Is_Blk=oldturkic}', "");
Expect(0, 68688, '\p{Is_Blk=oldturkic}', "");
Expect(1, 68688, '\p{^Is_Blk=oldturkic}', "");
Expect(1, 68688, '\P{Is_Blk=oldturkic}', "");
Expect(0, 68688, '\P{^Is_Blk=oldturkic}', "");
Expect(1, 68687, '\p{Is_Blk=		Old_turkic}', "");
Expect(0, 68687, '\p{^Is_Blk=		Old_turkic}', "");
Expect(0, 68687, '\P{Is_Blk=		Old_turkic}', "");
Expect(1, 68687, '\P{^Is_Blk=		Old_turkic}', "");
Expect(0, 68688, '\p{Is_Blk=		Old_turkic}', "");
Expect(1, 68688, '\p{^Is_Blk=		Old_turkic}', "");
Expect(1, 68688, '\P{Is_Blk=		Old_turkic}', "");
Expect(0, 68688, '\P{^Is_Blk=		Old_turkic}', "");
Error('\p{Block=-:=Oriya}');
Error('\P{Block=-:=Oriya}');
Expect(1, 2943, '\p{Block=oriya}', "");
Expect(0, 2943, '\p{^Block=oriya}', "");
Expect(0, 2943, '\P{Block=oriya}', "");
Expect(1, 2943, '\P{^Block=oriya}', "");
Expect(0, 2944, '\p{Block=oriya}', "");
Expect(1, 2944, '\p{^Block=oriya}', "");
Expect(1, 2944, '\P{Block=oriya}', "");
Expect(0, 2944, '\P{^Block=oriya}', "");
Expect(1, 2943, '\p{Block=-Oriya}', "");
Expect(0, 2943, '\p{^Block=-Oriya}', "");
Expect(0, 2943, '\P{Block=-Oriya}', "");
Expect(1, 2943, '\P{^Block=-Oriya}', "");
Expect(0, 2944, '\p{Block=-Oriya}', "");
Expect(1, 2944, '\p{^Block=-Oriya}', "");
Expect(1, 2944, '\P{Block=-Oriya}', "");
Expect(0, 2944, '\P{^Block=-Oriya}', "");
Error('\p{Blk=:=_	ORIYA}');
Error('\P{Blk=:=_	ORIYA}');
Expect(1, 2943, '\p{Blk=oriya}', "");
Expect(0, 2943, '\p{^Blk=oriya}', "");
Expect(0, 2943, '\P{Blk=oriya}', "");
Expect(1, 2943, '\P{^Blk=oriya}', "");
Expect(0, 2944, '\p{Blk=oriya}', "");
Expect(1, 2944, '\p{^Blk=oriya}', "");
Expect(1, 2944, '\P{Blk=oriya}', "");
Expect(0, 2944, '\P{^Blk=oriya}', "");
Expect(1, 2943, '\p{Blk=- ORIYA}', "");
Expect(0, 2943, '\p{^Blk=- ORIYA}', "");
Expect(0, 2943, '\P{Blk=- ORIYA}', "");
Expect(1, 2943, '\P{^Blk=- ORIYA}', "");
Expect(0, 2944, '\p{Blk=- ORIYA}', "");
Expect(1, 2944, '\p{^Blk=- ORIYA}', "");
Expect(1, 2944, '\P{Blk=- ORIYA}', "");
Expect(0, 2944, '\P{^Blk=- ORIYA}', "");
Error('\p{Is_Block=--Oriya/a/}');
Error('\P{Is_Block=--Oriya/a/}');
Expect(1, 2943, '\p{Is_Block=oriya}', "");
Expect(0, 2943, '\p{^Is_Block=oriya}', "");
Expect(0, 2943, '\P{Is_Block=oriya}', "");
Expect(1, 2943, '\P{^Is_Block=oriya}', "");
Expect(0, 2944, '\p{Is_Block=oriya}', "");
Expect(1, 2944, '\p{^Is_Block=oriya}', "");
Expect(1, 2944, '\P{Is_Block=oriya}', "");
Expect(0, 2944, '\P{^Is_Block=oriya}', "");
Expect(1, 2943, '\p{Is_Block: -_Oriya}', "");
Expect(0, 2943, '\p{^Is_Block: -_Oriya}', "");
Expect(0, 2943, '\P{Is_Block: -_Oriya}', "");
Expect(1, 2943, '\P{^Is_Block: -_Oriya}', "");
Expect(0, 2944, '\p{Is_Block: -_Oriya}', "");
Expect(1, 2944, '\p{^Is_Block: -_Oriya}', "");
Expect(1, 2944, '\P{Is_Block: -_Oriya}', "");
Expect(0, 2944, '\P{^Is_Block: -_Oriya}', "");
Error('\p{Is_Blk=:=- ORIYA}');
Error('\P{Is_Blk=:=- ORIYA}');
Expect(1, 2943, '\p{Is_Blk=oriya}', "");
Expect(0, 2943, '\p{^Is_Blk=oriya}', "");
Expect(0, 2943, '\P{Is_Blk=oriya}', "");
Expect(1, 2943, '\P{^Is_Blk=oriya}', "");
Expect(0, 2944, '\p{Is_Blk=oriya}', "");
Expect(1, 2944, '\p{^Is_Blk=oriya}', "");
Expect(1, 2944, '\P{Is_Blk=oriya}', "");
Expect(0, 2944, '\P{^Is_Blk=oriya}', "");
Expect(1, 2943, '\p{Is_Blk=_Oriya}', "");
Expect(0, 2943, '\p{^Is_Blk=_Oriya}', "");
Expect(0, 2943, '\P{Is_Blk=_Oriya}', "");
Expect(1, 2943, '\P{^Is_Blk=_Oriya}', "");
Expect(0, 2944, '\p{Is_Blk=_Oriya}', "");
Expect(1, 2944, '\p{^Is_Blk=_Oriya}', "");
Expect(1, 2944, '\P{Is_Blk=_Oriya}', "");
Expect(0, 2944, '\P{^Is_Blk=_Oriya}', "");
Error('\p{Block=	-osmanya:=}');
Error('\P{Block=	-osmanya:=}');
Expect(1, 66735, '\p{Block=osmanya}', "");
Expect(0, 66735, '\p{^Block=osmanya}', "");
Expect(0, 66735, '\P{Block=osmanya}', "");
Expect(1, 66735, '\P{^Block=osmanya}', "");
Expect(0, 66736, '\p{Block=osmanya}', "");
Expect(1, 66736, '\p{^Block=osmanya}', "");
Expect(1, 66736, '\P{Block=osmanya}', "");
Expect(0, 66736, '\P{^Block=osmanya}', "");
Expect(1, 66735, '\p{Block= -OSMANYA}', "");
Expect(0, 66735, '\p{^Block= -OSMANYA}', "");
Expect(0, 66735, '\P{Block= -OSMANYA}', "");
Expect(1, 66735, '\P{^Block= -OSMANYA}', "");
Expect(0, 66736, '\p{Block= -OSMANYA}', "");
Expect(1, 66736, '\p{^Block= -OSMANYA}', "");
Expect(1, 66736, '\P{Block= -OSMANYA}', "");
Expect(0, 66736, '\P{^Block= -OSMANYA}', "");
Error('\p{Blk=_/a/Osmanya}');
Error('\P{Blk=_/a/Osmanya}');
Expect(1, 66735, '\p{Blk=osmanya}', "");
Expect(0, 66735, '\p{^Blk=osmanya}', "");
Expect(0, 66735, '\P{Blk=osmanya}', "");
Expect(1, 66735, '\P{^Blk=osmanya}', "");
Expect(0, 66736, '\p{Blk=osmanya}', "");
Expect(1, 66736, '\p{^Blk=osmanya}', "");
Expect(1, 66736, '\P{Blk=osmanya}', "");
Expect(0, 66736, '\P{^Blk=osmanya}', "");
Expect(1, 66735, '\p{Blk=_	Osmanya}', "");
Expect(0, 66735, '\p{^Blk=_	Osmanya}', "");
Expect(0, 66735, '\P{Blk=_	Osmanya}', "");
Expect(1, 66735, '\P{^Blk=_	Osmanya}', "");
Expect(0, 66736, '\p{Blk=_	Osmanya}', "");
Expect(1, 66736, '\p{^Blk=_	Osmanya}', "");
Expect(1, 66736, '\P{Blk=_	Osmanya}', "");
Expect(0, 66736, '\P{^Blk=_	Osmanya}', "");
Error('\p{Is_Block=_/a/Osmanya}');
Error('\P{Is_Block=_/a/Osmanya}');
Expect(1, 66735, '\p{Is_Block=osmanya}', "");
Expect(0, 66735, '\p{^Is_Block=osmanya}', "");
Expect(0, 66735, '\P{Is_Block=osmanya}', "");
Expect(1, 66735, '\P{^Is_Block=osmanya}', "");
Expect(0, 66736, '\p{Is_Block=osmanya}', "");
Expect(1, 66736, '\p{^Is_Block=osmanya}', "");
Expect(1, 66736, '\P{Is_Block=osmanya}', "");
Expect(0, 66736, '\P{^Is_Block=osmanya}', "");
Expect(1, 66735, '\p{Is_Block=_-OSMANYA}', "");
Expect(0, 66735, '\p{^Is_Block=_-OSMANYA}', "");
Expect(0, 66735, '\P{Is_Block=_-OSMANYA}', "");
Expect(1, 66735, '\P{^Is_Block=_-OSMANYA}', "");
Expect(0, 66736, '\p{Is_Block=_-OSMANYA}', "");
Expect(1, 66736, '\p{^Is_Block=_-OSMANYA}', "");
Expect(1, 66736, '\P{Is_Block=_-OSMANYA}', "");
Expect(0, 66736, '\P{^Is_Block=_-OSMANYA}', "");
Error('\p{Is_Blk=/a/Osmanya}');
Error('\P{Is_Blk=/a/Osmanya}');
Expect(1, 66735, '\p{Is_Blk=osmanya}', "");
Expect(0, 66735, '\p{^Is_Blk=osmanya}', "");
Expect(0, 66735, '\P{Is_Blk=osmanya}', "");
Expect(1, 66735, '\P{^Is_Blk=osmanya}', "");
Expect(0, 66736, '\p{Is_Blk=osmanya}', "");
Expect(1, 66736, '\p{^Is_Blk=osmanya}', "");
Expect(1, 66736, '\P{Is_Blk=osmanya}', "");
Expect(0, 66736, '\P{^Is_Blk=osmanya}', "");
Expect(1, 66735, '\p{Is_Blk=-	Osmanya}', "");
Expect(0, 66735, '\p{^Is_Blk=-	Osmanya}', "");
Expect(0, 66735, '\P{Is_Blk=-	Osmanya}', "");
Expect(1, 66735, '\P{^Is_Blk=-	Osmanya}', "");
Expect(0, 66736, '\p{Is_Blk=-	Osmanya}', "");
Expect(1, 66736, '\p{^Is_Blk=-	Osmanya}', "");
Expect(1, 66736, '\P{Is_Blk=-	Osmanya}', "");
Expect(0, 66736, '\P{^Is_Blk=-	Osmanya}', "");
Error('\p{Block=-	Private_Use_Area/a/}');
Error('\P{Block=-	Private_Use_Area/a/}');
Expect(1, 63743, '\p{Block=privateusearea}', "");
Expect(0, 63743, '\p{^Block=privateusearea}', "");
Expect(0, 63743, '\P{Block=privateusearea}', "");
Expect(1, 63743, '\P{^Block=privateusearea}', "");
Expect(0, 63744, '\p{Block=privateusearea}', "");
Expect(1, 63744, '\p{^Block=privateusearea}', "");
Expect(1, 63744, '\P{Block=privateusearea}', "");
Expect(0, 63744, '\P{^Block=privateusearea}', "");
Expect(1, 63743, '\p{Block=	-Private_Use_Area}', "");
Expect(0, 63743, '\p{^Block=	-Private_Use_Area}', "");
Expect(0, 63743, '\P{Block=	-Private_Use_Area}', "");
Expect(1, 63743, '\P{^Block=	-Private_Use_Area}', "");
Expect(0, 63744, '\p{Block=	-Private_Use_Area}', "");
Expect(1, 63744, '\p{^Block=	-Private_Use_Area}', "");
Expect(1, 63744, '\P{Block=	-Private_Use_Area}', "");
Expect(0, 63744, '\P{^Block=	-Private_Use_Area}', "");
Error('\p{Blk=	/a/PUA}');
Error('\P{Blk=	/a/PUA}');
Expect(1, 63743, '\p{Blk=pua}', "");
Expect(0, 63743, '\p{^Blk=pua}', "");
Expect(0, 63743, '\P{Blk=pua}', "");
Expect(1, 63743, '\P{^Blk=pua}', "");
Expect(0, 63744, '\p{Blk=pua}', "");
Expect(1, 63744, '\p{^Blk=pua}', "");
Expect(1, 63744, '\P{Blk=pua}', "");
Expect(0, 63744, '\P{^Blk=pua}', "");
Expect(1, 63743, '\p{Blk=_-PUA}', "");
Expect(0, 63743, '\p{^Blk=_-PUA}', "");
Expect(0, 63743, '\P{Blk=_-PUA}', "");
Expect(1, 63743, '\P{^Blk=_-PUA}', "");
Expect(0, 63744, '\p{Blk=_-PUA}', "");
Expect(1, 63744, '\p{^Blk=_-PUA}', "");
Expect(1, 63744, '\P{Blk=_-PUA}', "");
Expect(0, 63744, '\P{^Blk=_-PUA}', "");
Error('\p{Is_Block=_/a/Private_Use}');
Error('\P{Is_Block=_/a/Private_Use}');
Expect(1, 63743, '\p{Is_Block=privateuse}', "");
Expect(0, 63743, '\p{^Is_Block=privateuse}', "");
Expect(0, 63743, '\P{Is_Block=privateuse}', "");
Expect(1, 63743, '\P{^Is_Block=privateuse}', "");
Expect(0, 63744, '\p{Is_Block=privateuse}', "");
Expect(1, 63744, '\p{^Is_Block=privateuse}', "");
Expect(1, 63744, '\P{Is_Block=privateuse}', "");
Expect(0, 63744, '\P{^Is_Block=privateuse}', "");
Expect(1, 63743, '\p{Is_Block=Private_USE}', "");
Expect(0, 63743, '\p{^Is_Block=Private_USE}', "");
Expect(0, 63743, '\P{Is_Block=Private_USE}', "");
Expect(1, 63743, '\P{^Is_Block=Private_USE}', "");
Expect(0, 63744, '\p{Is_Block=Private_USE}', "");
Expect(1, 63744, '\p{^Is_Block=Private_USE}', "");
Expect(1, 63744, '\P{Is_Block=Private_USE}', "");
Expect(0, 63744, '\P{^Is_Block=Private_USE}', "");
Error('\p{Is_Blk= Private_Use_AREA/a/}');
Error('\P{Is_Blk= Private_Use_AREA/a/}');
Expect(1, 63743, '\p{Is_Blk=privateusearea}', "");
Expect(0, 63743, '\p{^Is_Blk=privateusearea}', "");
Expect(0, 63743, '\P{Is_Blk=privateusearea}', "");
Expect(1, 63743, '\P{^Is_Blk=privateusearea}', "");
Expect(0, 63744, '\p{Is_Blk=privateusearea}', "");
Expect(1, 63744, '\p{^Is_Blk=privateusearea}', "");
Expect(1, 63744, '\P{Is_Blk=privateusearea}', "");
Expect(0, 63744, '\P{^Is_Blk=privateusearea}', "");
Expect(1, 63743, '\p{Is_Blk= _Private_Use_area}', "");
Expect(0, 63743, '\p{^Is_Blk= _Private_Use_area}', "");
Expect(0, 63743, '\P{Is_Blk= _Private_Use_area}', "");
Expect(1, 63743, '\P{^Is_Blk= _Private_Use_area}', "");
Expect(0, 63744, '\p{Is_Blk= _Private_Use_area}', "");
Expect(1, 63744, '\p{^Is_Blk= _Private_Use_area}', "");
Expect(1, 63744, '\P{Is_Blk= _Private_Use_area}', "");
Expect(0, 63744, '\P{^Is_Blk= _Private_Use_area}', "");
Error('\p{Block=-:=Phags_Pa}');
Error('\P{Block=-:=Phags_Pa}');
Expect(1, 43135, '\p{Block=phagspa}', "");
Expect(0, 43135, '\p{^Block=phagspa}', "");
Expect(0, 43135, '\P{Block=phagspa}', "");
Expect(1, 43135, '\P{^Block=phagspa}', "");
Expect(0, 43136, '\p{Block=phagspa}', "");
Expect(1, 43136, '\p{^Block=phagspa}', "");
Expect(1, 43136, '\P{Block=phagspa}', "");
Expect(0, 43136, '\P{^Block=phagspa}', "");
Expect(1, 43135, '\p{Block=Phags_pa}', "");
Expect(0, 43135, '\p{^Block=Phags_pa}', "");
Expect(0, 43135, '\P{Block=Phags_pa}', "");
Expect(1, 43135, '\P{^Block=Phags_pa}', "");
Expect(0, 43136, '\p{Block=Phags_pa}', "");
Expect(1, 43136, '\p{^Block=Phags_pa}', "");
Expect(1, 43136, '\P{Block=Phags_pa}', "");
Expect(0, 43136, '\P{^Block=Phags_pa}', "");
Error('\p{Blk= 	PHAGS_Pa:=}');
Error('\P{Blk= 	PHAGS_Pa:=}');
Expect(1, 43135, '\p{Blk=phagspa}', "");
Expect(0, 43135, '\p{^Blk=phagspa}', "");
Expect(0, 43135, '\P{Blk=phagspa}', "");
Expect(1, 43135, '\P{^Blk=phagspa}', "");
Expect(0, 43136, '\p{Blk=phagspa}', "");
Expect(1, 43136, '\p{^Blk=phagspa}', "");
Expect(1, 43136, '\P{Blk=phagspa}', "");
Expect(0, 43136, '\P{^Blk=phagspa}', "");
Expect(1, 43135, '\p{Blk=__Phags_Pa}', "");
Expect(0, 43135, '\p{^Blk=__Phags_Pa}', "");
Expect(0, 43135, '\P{Blk=__Phags_Pa}', "");
Expect(1, 43135, '\P{^Blk=__Phags_Pa}', "");
Expect(0, 43136, '\p{Blk=__Phags_Pa}', "");
Expect(1, 43136, '\p{^Blk=__Phags_Pa}', "");
Expect(1, 43136, '\P{Blk=__Phags_Pa}', "");
Expect(0, 43136, '\P{^Blk=__Phags_Pa}', "");
Error('\p{Is_Block=-:=Phags_Pa}');
Error('\P{Is_Block=-:=Phags_Pa}');
Expect(1, 43135, '\p{Is_Block=phagspa}', "");
Expect(0, 43135, '\p{^Is_Block=phagspa}', "");
Expect(0, 43135, '\P{Is_Block=phagspa}', "");
Expect(1, 43135, '\P{^Is_Block=phagspa}', "");
Expect(0, 43136, '\p{Is_Block=phagspa}', "");
Expect(1, 43136, '\p{^Is_Block=phagspa}', "");
Expect(1, 43136, '\P{Is_Block=phagspa}', "");
Expect(0, 43136, '\P{^Is_Block=phagspa}', "");
Expect(1, 43135, '\p{Is_Block: Phags_Pa}', "");
Expect(0, 43135, '\p{^Is_Block: Phags_Pa}', "");
Expect(0, 43135, '\P{Is_Block: Phags_Pa}', "");
Expect(1, 43135, '\P{^Is_Block: Phags_Pa}', "");
Expect(0, 43136, '\p{Is_Block: Phags_Pa}', "");
Expect(1, 43136, '\p{^Is_Block: Phags_Pa}', "");
Expect(1, 43136, '\P{Is_Block: Phags_Pa}', "");
Expect(0, 43136, '\P{^Is_Block: Phags_Pa}', "");
Error('\p{Is_Blk::=Phags_Pa}');
Error('\P{Is_Blk::=Phags_Pa}');
Expect(1, 43135, '\p{Is_Blk:	phagspa}', "");
Expect(0, 43135, '\p{^Is_Blk:	phagspa}', "");
Expect(0, 43135, '\P{Is_Blk:	phagspa}', "");
Expect(1, 43135, '\P{^Is_Blk:	phagspa}', "");
Expect(0, 43136, '\p{Is_Blk:	phagspa}', "");
Expect(1, 43136, '\p{^Is_Blk:	phagspa}', "");
Expect(1, 43136, '\P{Is_Blk:	phagspa}', "");
Expect(0, 43136, '\P{^Is_Blk:	phagspa}', "");
Expect(1, 43135, '\p{Is_Blk=		PHAGS_PA}', "");
Expect(0, 43135, '\p{^Is_Blk=		PHAGS_PA}', "");
Expect(0, 43135, '\P{Is_Blk=		PHAGS_PA}', "");
Expect(1, 43135, '\P{^Is_Blk=		PHAGS_PA}', "");
Expect(0, 43136, '\p{Is_Blk=		PHAGS_PA}', "");
Expect(1, 43136, '\p{^Is_Blk=		PHAGS_PA}', "");
Expect(1, 43136, '\P{Is_Blk=		PHAGS_PA}', "");
Expect(0, 43136, '\P{^Is_Blk=		PHAGS_PA}', "");
Error('\p{Block:_/a/Phaistos_DISC}');
Error('\P{Block:_/a/Phaistos_DISC}');
Expect(1, 66047, '\p{Block=phaistosdisc}', "");
Expect(0, 66047, '\p{^Block=phaistosdisc}', "");
Expect(0, 66047, '\P{Block=phaistosdisc}', "");
Expect(1, 66047, '\P{^Block=phaistosdisc}', "");
Expect(0, 66048, '\p{Block=phaistosdisc}', "");
Expect(1, 66048, '\p{^Block=phaistosdisc}', "");
Expect(1, 66048, '\P{Block=phaistosdisc}', "");
Expect(0, 66048, '\P{^Block=phaistosdisc}', "");
Expect(1, 66047, '\p{Block:	-	PHAISTOS_DISC}', "");
Expect(0, 66047, '\p{^Block:	-	PHAISTOS_DISC}', "");
Expect(0, 66047, '\P{Block:	-	PHAISTOS_DISC}', "");
Expect(1, 66047, '\P{^Block:	-	PHAISTOS_DISC}', "");
Expect(0, 66048, '\p{Block:	-	PHAISTOS_DISC}', "");
Expect(1, 66048, '\p{^Block:	-	PHAISTOS_DISC}', "");
Expect(1, 66048, '\P{Block:	-	PHAISTOS_DISC}', "");
Expect(0, 66048, '\P{^Block:	-	PHAISTOS_DISC}', "");
Error('\p{Blk= :=Phaistos}');
Error('\P{Blk= :=Phaistos}');
Expect(1, 66047, '\p{Blk=phaistos}', "");
Expect(0, 66047, '\p{^Blk=phaistos}', "");
Expect(0, 66047, '\P{Blk=phaistos}', "");
Expect(1, 66047, '\P{^Blk=phaistos}', "");
Expect(0, 66048, '\p{Blk=phaistos}', "");
Expect(1, 66048, '\p{^Blk=phaistos}', "");
Expect(1, 66048, '\P{Blk=phaistos}', "");
Expect(0, 66048, '\P{^Blk=phaistos}', "");
Expect(1, 66047, '\p{Blk:   --Phaistos}', "");
Expect(0, 66047, '\p{^Blk:   --Phaistos}', "");
Expect(0, 66047, '\P{Blk:   --Phaistos}', "");
Expect(1, 66047, '\P{^Blk:   --Phaistos}', "");
Expect(0, 66048, '\p{Blk:   --Phaistos}', "");
Expect(1, 66048, '\p{^Blk:   --Phaistos}', "");
Expect(1, 66048, '\P{Blk:   --Phaistos}', "");
Expect(0, 66048, '\P{^Blk:   --Phaistos}', "");
Error('\p{Is_Block=--Phaistos_Disc/a/}');
Error('\P{Is_Block=--Phaistos_Disc/a/}');
Expect(1, 66047, '\p{Is_Block: phaistosdisc}', "");
Expect(0, 66047, '\p{^Is_Block: phaistosdisc}', "");
Expect(0, 66047, '\P{Is_Block: phaistosdisc}', "");
Expect(1, 66047, '\P{^Is_Block: phaistosdisc}', "");
Expect(0, 66048, '\p{Is_Block: phaistosdisc}', "");
Expect(1, 66048, '\p{^Is_Block: phaistosdisc}', "");
Expect(1, 66048, '\P{Is_Block: phaistosdisc}', "");
Expect(0, 66048, '\P{^Is_Block: phaistosdisc}', "");
Expect(1, 66047, '\p{Is_Block=_	phaistos_Disc}', "");
Expect(0, 66047, '\p{^Is_Block=_	phaistos_Disc}', "");
Expect(0, 66047, '\P{Is_Block=_	phaistos_Disc}', "");
Expect(1, 66047, '\P{^Is_Block=_	phaistos_Disc}', "");
Expect(0, 66048, '\p{Is_Block=_	phaistos_Disc}', "");
Expect(1, 66048, '\p{^Is_Block=_	phaistos_Disc}', "");
Expect(1, 66048, '\P{Is_Block=_	phaistos_Disc}', "");
Expect(0, 66048, '\P{^Is_Block=_	phaistos_Disc}', "");
Error('\p{Is_Blk=/a/	Phaistos}');
Error('\P{Is_Blk=/a/	Phaistos}');
Expect(1, 66047, '\p{Is_Blk=phaistos}', "");
Expect(0, 66047, '\p{^Is_Blk=phaistos}', "");
Expect(0, 66047, '\P{Is_Blk=phaistos}', "");
Expect(1, 66047, '\P{^Is_Blk=phaistos}', "");
Expect(0, 66048, '\p{Is_Blk=phaistos}', "");
Expect(1, 66048, '\p{^Is_Blk=phaistos}', "");
Expect(1, 66048, '\P{Is_Blk=phaistos}', "");
Expect(0, 66048, '\P{^Is_Blk=phaistos}', "");
Expect(1, 66047, '\p{Is_Blk=-_PHAISTOS}', "");
Expect(0, 66047, '\p{^Is_Blk=-_PHAISTOS}', "");
Expect(0, 66047, '\P{Is_Blk=-_PHAISTOS}', "");
Expect(1, 66047, '\P{^Is_Blk=-_PHAISTOS}', "");
Expect(0, 66048, '\p{Is_Blk=-_PHAISTOS}', "");
Expect(1, 66048, '\p{^Is_Blk=-_PHAISTOS}', "");
Expect(1, 66048, '\P{Is_Blk=-_PHAISTOS}', "");
Expect(0, 66048, '\P{^Is_Blk=-_PHAISTOS}', "");
Error('\p{Block=_Phoenician/a/}');
Error('\P{Block=_Phoenician/a/}');
Expect(1, 67871, '\p{Block=phoenician}', "");
Expect(0, 67871, '\p{^Block=phoenician}', "");
Expect(0, 67871, '\P{Block=phoenician}', "");
Expect(1, 67871, '\P{^Block=phoenician}', "");
Expect(0, 67872, '\p{Block=phoenician}', "");
Expect(1, 67872, '\p{^Block=phoenician}', "");
Expect(1, 67872, '\P{Block=phoenician}', "");
Expect(0, 67872, '\P{^Block=phoenician}', "");
Expect(1, 67871, '\p{Block=-PHOENICIAN}', "");
Expect(0, 67871, '\p{^Block=-PHOENICIAN}', "");
Expect(0, 67871, '\P{Block=-PHOENICIAN}', "");
Expect(1, 67871, '\P{^Block=-PHOENICIAN}', "");
Expect(0, 67872, '\p{Block=-PHOENICIAN}', "");
Expect(1, 67872, '\p{^Block=-PHOENICIAN}', "");
Expect(1, 67872, '\P{Block=-PHOENICIAN}', "");
Expect(0, 67872, '\P{^Block=-PHOENICIAN}', "");
Error('\p{Blk=/a/-Phoenician}');
Error('\P{Blk=/a/-Phoenician}');
Expect(1, 67871, '\p{Blk=phoenician}', "");
Expect(0, 67871, '\p{^Blk=phoenician}', "");
Expect(0, 67871, '\P{Blk=phoenician}', "");
Expect(1, 67871, '\P{^Blk=phoenician}', "");
Expect(0, 67872, '\p{Blk=phoenician}', "");
Expect(1, 67872, '\p{^Blk=phoenician}', "");
Expect(1, 67872, '\P{Blk=phoenician}', "");
Expect(0, 67872, '\P{^Blk=phoenician}', "");
Expect(1, 67871, '\p{Blk=	Phoenician}', "");
Expect(0, 67871, '\p{^Blk=	Phoenician}', "");
Expect(0, 67871, '\P{Blk=	Phoenician}', "");
Expect(1, 67871, '\P{^Blk=	Phoenician}', "");
Expect(0, 67872, '\p{Blk=	Phoenician}', "");
Expect(1, 67872, '\p{^Blk=	Phoenician}', "");
Expect(1, 67872, '\P{Blk=	Phoenician}', "");
Expect(0, 67872, '\P{^Blk=	Phoenician}', "");
Error('\p{Is_Block=-/a/PHOENICIAN}');
Error('\P{Is_Block=-/a/PHOENICIAN}');
Expect(1, 67871, '\p{Is_Block=phoenician}', "");
Expect(0, 67871, '\p{^Is_Block=phoenician}', "");
Expect(0, 67871, '\P{Is_Block=phoenician}', "");
Expect(1, 67871, '\P{^Is_Block=phoenician}', "");
Expect(0, 67872, '\p{Is_Block=phoenician}', "");
Expect(1, 67872, '\p{^Is_Block=phoenician}', "");
Expect(1, 67872, '\P{Is_Block=phoenician}', "");
Expect(0, 67872, '\P{^Is_Block=phoenician}', "");
Expect(1, 67871, '\p{Is_Block= 	Phoenician}', "");
Expect(0, 67871, '\p{^Is_Block= 	Phoenician}', "");
Expect(0, 67871, '\P{Is_Block= 	Phoenician}', "");
Expect(1, 67871, '\P{^Is_Block= 	Phoenician}', "");
Expect(0, 67872, '\p{Is_Block= 	Phoenician}', "");
Expect(1, 67872, '\p{^Is_Block= 	Phoenician}', "");
Expect(1, 67872, '\P{Is_Block= 	Phoenician}', "");
Expect(0, 67872, '\P{^Is_Block= 	Phoenician}', "");
Error('\p{Is_Blk=:=  Phoenician}');
Error('\P{Is_Blk=:=  Phoenician}');
Expect(1, 67871, '\p{Is_Blk:phoenician}', "");
Expect(0, 67871, '\p{^Is_Blk:phoenician}', "");
Expect(0, 67871, '\P{Is_Blk:phoenician}', "");
Expect(1, 67871, '\P{^Is_Blk:phoenician}', "");
Expect(0, 67872, '\p{Is_Blk:phoenician}', "");
Expect(1, 67872, '\p{^Is_Blk:phoenician}', "");
Expect(1, 67872, '\P{Is_Blk:phoenician}', "");
Expect(0, 67872, '\P{^Is_Blk:phoenician}', "");
Expect(1, 67871, '\p{Is_Blk:	-_PHOENICIAN}', "");
Expect(0, 67871, '\p{^Is_Blk:	-_PHOENICIAN}', "");
Expect(0, 67871, '\P{Is_Blk:	-_PHOENICIAN}', "");
Expect(1, 67871, '\P{^Is_Blk:	-_PHOENICIAN}', "");
Expect(0, 67872, '\p{Is_Blk:	-_PHOENICIAN}', "");
Expect(1, 67872, '\p{^Is_Blk:	-_PHOENICIAN}', "");
Expect(1, 67872, '\P{Is_Blk:	-_PHOENICIAN}', "");
Expect(0, 67872, '\P{^Is_Blk:	-_PHOENICIAN}', "");
Error('\p{Block=/a/ _Phonetic_Extensions}');
Error('\P{Block=/a/ _Phonetic_Extensions}');
Expect(1, 7551, '\p{Block=phoneticextensions}', "");
Expect(0, 7551, '\p{^Block=phoneticextensions}', "");
Expect(0, 7551, '\P{Block=phoneticextensions}', "");
Expect(1, 7551, '\P{^Block=phoneticextensions}', "");
Expect(0, 7552, '\p{Block=phoneticextensions}', "");
Expect(1, 7552, '\p{^Block=phoneticextensions}', "");
Expect(1, 7552, '\P{Block=phoneticextensions}', "");
Expect(0, 7552, '\P{^Block=phoneticextensions}', "");
Expect(1, 7551, '\p{Block=__Phonetic_EXTENSIONS}', "");
Expect(0, 7551, '\p{^Block=__Phonetic_EXTENSIONS}', "");
Expect(0, 7551, '\P{Block=__Phonetic_EXTENSIONS}', "");
Expect(1, 7551, '\P{^Block=__Phonetic_EXTENSIONS}', "");
Expect(0, 7552, '\p{Block=__Phonetic_EXTENSIONS}', "");
Expect(1, 7552, '\p{^Block=__Phonetic_EXTENSIONS}', "");
Expect(1, 7552, '\P{Block=__Phonetic_EXTENSIONS}', "");
Expect(0, 7552, '\P{^Block=__Phonetic_EXTENSIONS}', "");
Error('\p{Blk=/a/ -Phonetic_EXT}');
Error('\P{Blk=/a/ -Phonetic_EXT}');
Expect(1, 7551, '\p{Blk=phoneticext}', "");
Expect(0, 7551, '\p{^Blk=phoneticext}', "");
Expect(0, 7551, '\P{Blk=phoneticext}', "");
Expect(1, 7551, '\P{^Blk=phoneticext}', "");
Expect(0, 7552, '\p{Blk=phoneticext}', "");
Expect(1, 7552, '\p{^Blk=phoneticext}', "");
Expect(1, 7552, '\P{Blk=phoneticext}', "");
Expect(0, 7552, '\P{^Blk=phoneticext}', "");
Expect(1, 7551, '\p{Blk=__PHONETIC_ext}', "");
Expect(0, 7551, '\p{^Blk=__PHONETIC_ext}', "");
Expect(0, 7551, '\P{Blk=__PHONETIC_ext}', "");
Expect(1, 7551, '\P{^Blk=__PHONETIC_ext}', "");
Expect(0, 7552, '\p{Blk=__PHONETIC_ext}', "");
Expect(1, 7552, '\p{^Blk=__PHONETIC_ext}', "");
Expect(1, 7552, '\P{Blk=__PHONETIC_ext}', "");
Expect(0, 7552, '\P{^Blk=__PHONETIC_ext}', "");
Error('\p{Is_Block=	Phonetic_EXTENSIONS:=}');
Error('\P{Is_Block=	Phonetic_EXTENSIONS:=}');
Expect(1, 7551, '\p{Is_Block=phoneticextensions}', "");
Expect(0, 7551, '\p{^Is_Block=phoneticextensions}', "");
Expect(0, 7551, '\P{Is_Block=phoneticextensions}', "");
Expect(1, 7551, '\P{^Is_Block=phoneticextensions}', "");
Expect(0, 7552, '\p{Is_Block=phoneticextensions}', "");
Expect(1, 7552, '\p{^Is_Block=phoneticextensions}', "");
Expect(1, 7552, '\P{Is_Block=phoneticextensions}', "");
Expect(0, 7552, '\P{^Is_Block=phoneticextensions}', "");
Expect(1, 7551, '\p{Is_Block=		Phonetic_extensions}', "");
Expect(0, 7551, '\p{^Is_Block=		Phonetic_extensions}', "");
Expect(0, 7551, '\P{Is_Block=		Phonetic_extensions}', "");
Expect(1, 7551, '\P{^Is_Block=		Phonetic_extensions}', "");
Expect(0, 7552, '\p{Is_Block=		Phonetic_extensions}', "");
Expect(1, 7552, '\p{^Is_Block=		Phonetic_extensions}', "");
Expect(1, 7552, '\P{Is_Block=		Phonetic_extensions}', "");
Expect(0, 7552, '\P{^Is_Block=		Phonetic_extensions}', "");
Error('\p{Is_Blk=-	Phonetic_ext:=}');
Error('\P{Is_Blk=-	Phonetic_ext:=}');
Expect(1, 7551, '\p{Is_Blk=phoneticext}', "");
Expect(0, 7551, '\p{^Is_Blk=phoneticext}', "");
Expect(0, 7551, '\P{Is_Blk=phoneticext}', "");
Expect(1, 7551, '\P{^Is_Blk=phoneticext}', "");
Expect(0, 7552, '\p{Is_Blk=phoneticext}', "");
Expect(1, 7552, '\p{^Is_Blk=phoneticext}', "");
Expect(1, 7552, '\P{Is_Blk=phoneticext}', "");
Expect(0, 7552, '\P{^Is_Blk=phoneticext}', "");
Expect(1, 7551, '\p{Is_Blk=	PHONETIC_Ext}', "");
Expect(0, 7551, '\p{^Is_Blk=	PHONETIC_Ext}', "");
Expect(0, 7551, '\P{Is_Blk=	PHONETIC_Ext}', "");
Expect(1, 7551, '\P{^Is_Blk=	PHONETIC_Ext}', "");
Expect(0, 7552, '\p{Is_Blk=	PHONETIC_Ext}', "");
Expect(1, 7552, '\p{^Is_Blk=	PHONETIC_Ext}', "");
Expect(1, 7552, '\P{Is_Blk=	PHONETIC_Ext}', "");
Expect(0, 7552, '\P{^Is_Blk=	PHONETIC_Ext}', "");
Error('\p{Block=_-Phonetic_Extensions_Supplement:=}');
Error('\P{Block=_-Phonetic_Extensions_Supplement:=}');
Expect(1, 7615, '\p{Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\P{Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\p{Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\P{Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\p{Block=  phonetic_Extensions_Supplement}', "");
Expect(0, 7615, '\p{^Block=  phonetic_Extensions_Supplement}', "");
Expect(0, 7615, '\P{Block=  phonetic_Extensions_Supplement}', "");
Expect(1, 7615, '\P{^Block=  phonetic_Extensions_Supplement}', "");
Expect(0, 7616, '\p{Block=  phonetic_Extensions_Supplement}', "");
Expect(1, 7616, '\p{^Block=  phonetic_Extensions_Supplement}', "");
Expect(1, 7616, '\P{Block=  phonetic_Extensions_Supplement}', "");
Expect(0, 7616, '\P{^Block=  phonetic_Extensions_Supplement}', "");
Error('\p{Blk=:=__phonetic_Ext_sup}');
Error('\P{Blk=:=__phonetic_Ext_sup}');
Expect(1, 7615, '\p{Blk=phoneticextsup}', "");
Expect(0, 7615, '\p{^Blk=phoneticextsup}', "");
Expect(0, 7615, '\P{Blk=phoneticextsup}', "");
Expect(1, 7615, '\P{^Blk=phoneticextsup}', "");
Expect(0, 7616, '\p{Blk=phoneticextsup}', "");
Expect(1, 7616, '\p{^Blk=phoneticextsup}', "");
Expect(1, 7616, '\P{Blk=phoneticextsup}', "");
Expect(0, 7616, '\P{^Blk=phoneticextsup}', "");
Expect(1, 7615, '\p{Blk= PHONETIC_ext_Sup}', "");
Expect(0, 7615, '\p{^Blk= PHONETIC_ext_Sup}', "");
Expect(0, 7615, '\P{Blk= PHONETIC_ext_Sup}', "");
Expect(1, 7615, '\P{^Blk= PHONETIC_ext_Sup}', "");
Expect(0, 7616, '\p{Blk= PHONETIC_ext_Sup}', "");
Expect(1, 7616, '\p{^Blk= PHONETIC_ext_Sup}', "");
Expect(1, 7616, '\P{Blk= PHONETIC_ext_Sup}', "");
Expect(0, 7616, '\P{^Blk= PHONETIC_ext_Sup}', "");
Error('\p{Is_Block=-PHONETIC_extensions_Supplement/a/}');
Error('\P{Is_Block=-PHONETIC_extensions_Supplement/a/}');
Expect(1, 7615, '\p{Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7615, '\P{Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\p{Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7616, '\P{Is_Block=phoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^Is_Block=phoneticextensionssupplement}', "");
Expect(1, 7615, '\p{Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7615, '\p{^Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7615, '\P{Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(1, 7615, '\P{^Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7616, '\p{Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(1, 7616, '\p{^Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(1, 7616, '\P{Is_Block=_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7616, '\P{^Is_Block=_PHONETIC_Extensions_Supplement}', "");
Error('\p{Is_Blk= /a/phonetic_ext_SUP}');
Error('\P{Is_Blk= /a/phonetic_ext_SUP}');
Expect(1, 7615, '\p{Is_Blk=phoneticextsup}', "");
Expect(0, 7615, '\p{^Is_Blk=phoneticextsup}', "");
Expect(0, 7615, '\P{Is_Blk=phoneticextsup}', "");
Expect(1, 7615, '\P{^Is_Blk=phoneticextsup}', "");
Expect(0, 7616, '\p{Is_Blk=phoneticextsup}', "");
Expect(1, 7616, '\p{^Is_Blk=phoneticextsup}', "");
Expect(1, 7616, '\P{Is_Blk=phoneticextsup}', "");
Expect(0, 7616, '\P{^Is_Blk=phoneticextsup}', "");
Expect(1, 7615, '\p{Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(0, 7615, '\p{^Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(0, 7615, '\P{Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(1, 7615, '\P{^Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(0, 7616, '\p{Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(1, 7616, '\p{^Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(1, 7616, '\P{Is_Blk=	PHONETIC_EXT_SUP}', "");
Expect(0, 7616, '\P{^Is_Blk=	PHONETIC_EXT_SUP}', "");
Error('\p{Block=- Playing_Cards:=}');
Error('\P{Block=- Playing_Cards:=}');
Expect(1, 127231, '\p{Block=playingcards}', "");
Expect(0, 127231, '\p{^Block=playingcards}', "");
Expect(0, 127231, '\P{Block=playingcards}', "");
Expect(1, 127231, '\P{^Block=playingcards}', "");
Expect(0, 127232, '\p{Block=playingcards}', "");
Expect(1, 127232, '\p{^Block=playingcards}', "");
Expect(1, 127232, '\P{Block=playingcards}', "");
Expect(0, 127232, '\P{^Block=playingcards}', "");
Expect(1, 127231, '\p{Block: _-PLAYING_Cards}', "");
Expect(0, 127231, '\p{^Block: _-PLAYING_Cards}', "");
Expect(0, 127231, '\P{Block: _-PLAYING_Cards}', "");
Expect(1, 127231, '\P{^Block: _-PLAYING_Cards}', "");
Expect(0, 127232, '\p{Block: _-PLAYING_Cards}', "");
Expect(1, 127232, '\p{^Block: _-PLAYING_Cards}', "");
Expect(1, 127232, '\P{Block: _-PLAYING_Cards}', "");
Expect(0, 127232, '\P{^Block: _-PLAYING_Cards}', "");
Error('\p{Blk=:=		playing_CARDS}');
Error('\P{Blk=:=		playing_CARDS}');
Expect(1, 127231, '\p{Blk=playingcards}', "");
Expect(0, 127231, '\p{^Blk=playingcards}', "");
Expect(0, 127231, '\P{Blk=playingcards}', "");
Expect(1, 127231, '\P{^Blk=playingcards}', "");
Expect(0, 127232, '\p{Blk=playingcards}', "");
Expect(1, 127232, '\p{^Blk=playingcards}', "");
Expect(1, 127232, '\P{Blk=playingcards}', "");
Expect(0, 127232, '\P{^Blk=playingcards}', "");
Expect(1, 127231, '\p{Blk=	playing_CARDS}', "");
Expect(0, 127231, '\p{^Blk=	playing_CARDS}', "");
Expect(0, 127231, '\P{Blk=	playing_CARDS}', "");
Expect(1, 127231, '\P{^Blk=	playing_CARDS}', "");
Expect(0, 127232, '\p{Blk=	playing_CARDS}', "");
Expect(1, 127232, '\p{^Blk=	playing_CARDS}', "");
Expect(1, 127232, '\P{Blk=	playing_CARDS}', "");
Expect(0, 127232, '\P{^Blk=	playing_CARDS}', "");
Error('\p{Is_Block=/a/_playing_Cards}');
Error('\P{Is_Block=/a/_playing_Cards}');
Expect(1, 127231, '\p{Is_Block=playingcards}', "");
Expect(0, 127231, '\p{^Is_Block=playingcards}', "");
Expect(0, 127231, '\P{Is_Block=playingcards}', "");
Expect(1, 127231, '\P{^Is_Block=playingcards}', "");
Expect(0, 127232, '\p{Is_Block=playingcards}', "");
Expect(1, 127232, '\p{^Is_Block=playingcards}', "");
Expect(1, 127232, '\P{Is_Block=playingcards}', "");
Expect(0, 127232, '\P{^Is_Block=playingcards}', "");
Expect(1, 127231, '\p{Is_Block=-	Playing_Cards}', "");
Expect(0, 127231, '\p{^Is_Block=-	Playing_Cards}', "");
Expect(0, 127231, '\P{Is_Block=-	Playing_Cards}', "");
Expect(1, 127231, '\P{^Is_Block=-	Playing_Cards}', "");
Expect(0, 127232, '\p{Is_Block=-	Playing_Cards}', "");
Expect(1, 127232, '\p{^Is_Block=-	Playing_Cards}', "");
Expect(1, 127232, '\P{Is_Block=-	Playing_Cards}', "");
Expect(0, 127232, '\P{^Is_Block=-	Playing_Cards}', "");
Error('\p{Is_Blk:   _Playing_Cards:=}');
Error('\P{Is_Blk:   _Playing_Cards:=}');
Expect(1, 127231, '\p{Is_Blk=playingcards}', "");
Expect(0, 127231, '\p{^Is_Blk=playingcards}', "");
Expect(0, 127231, '\P{Is_Blk=playingcards}', "");
Expect(1, 127231, '\P{^Is_Blk=playingcards}', "");
Expect(0, 127232, '\p{Is_Blk=playingcards}', "");
Expect(1, 127232, '\p{^Is_Blk=playingcards}', "");
Expect(1, 127232, '\P{Is_Blk=playingcards}', "");
Expect(0, 127232, '\P{^Is_Blk=playingcards}', "");
Expect(1, 127231, '\p{Is_Blk= Playing_CARDS}', "");
Expect(0, 127231, '\p{^Is_Blk= Playing_CARDS}', "");
Expect(0, 127231, '\P{Is_Blk= Playing_CARDS}', "");
Expect(1, 127231, '\P{^Is_Blk= Playing_CARDS}', "");
Expect(0, 127232, '\p{Is_Blk= Playing_CARDS}', "");
Expect(1, 127232, '\p{^Is_Blk= Playing_CARDS}', "");
Expect(1, 127232, '\P{Is_Blk= Playing_CARDS}', "");
Expect(0, 127232, '\P{^Is_Blk= Playing_CARDS}', "");
Error('\p{Block=	:=general_punctuation}');
Error('\P{Block=	:=general_punctuation}');
Expect(1, 8303, '\p{Block=generalpunctuation}', "");
Expect(0, 8303, '\p{^Block=generalpunctuation}', "");
Expect(0, 8303, '\P{Block=generalpunctuation}', "");
Expect(1, 8303, '\P{^Block=generalpunctuation}', "");
Expect(0, 8304, '\p{Block=generalpunctuation}', "");
Expect(1, 8304, '\p{^Block=generalpunctuation}', "");
Expect(1, 8304, '\P{Block=generalpunctuation}', "");
Expect(0, 8304, '\P{^Block=generalpunctuation}', "");
Expect(1, 8303, '\p{Block= GENERAL_Punctuation}', "");
Expect(0, 8303, '\p{^Block= GENERAL_Punctuation}', "");
Expect(0, 8303, '\P{Block= GENERAL_Punctuation}', "");
Expect(1, 8303, '\P{^Block= GENERAL_Punctuation}', "");
Expect(0, 8304, '\p{Block= GENERAL_Punctuation}', "");
Expect(1, 8304, '\p{^Block= GENERAL_Punctuation}', "");
Expect(1, 8304, '\P{Block= GENERAL_Punctuation}', "");
Expect(0, 8304, '\P{^Block= GENERAL_Punctuation}', "");
Error('\p{Blk= -Punctuation:=}');
Error('\P{Blk= -Punctuation:=}');
Expect(1, 8303, '\p{Blk=punctuation}', "");
Expect(0, 8303, '\p{^Blk=punctuation}', "");
Expect(0, 8303, '\P{Blk=punctuation}', "");
Expect(1, 8303, '\P{^Blk=punctuation}', "");
Expect(0, 8304, '\p{Blk=punctuation}', "");
Expect(1, 8304, '\p{^Blk=punctuation}', "");
Expect(1, 8304, '\P{Blk=punctuation}', "");
Expect(0, 8304, '\P{^Blk=punctuation}', "");
Expect(1, 8303, '\p{Blk=_-Punctuation}', "");
Expect(0, 8303, '\p{^Blk=_-Punctuation}', "");
Expect(0, 8303, '\P{Blk=_-Punctuation}', "");
Expect(1, 8303, '\P{^Blk=_-Punctuation}', "");
Expect(0, 8304, '\p{Blk=_-Punctuation}', "");
Expect(1, 8304, '\p{^Blk=_-Punctuation}', "");
Expect(1, 8304, '\P{Blk=_-Punctuation}', "");
Expect(0, 8304, '\P{^Blk=_-Punctuation}', "");
Error('\p{Is_Block=_/a/General_punctuation}');
Error('\P{Is_Block=_/a/General_punctuation}');
Expect(1, 8303, '\p{Is_Block=generalpunctuation}', "");
Expect(0, 8303, '\p{^Is_Block=generalpunctuation}', "");
Expect(0, 8303, '\P{Is_Block=generalpunctuation}', "");
Expect(1, 8303, '\P{^Is_Block=generalpunctuation}', "");
Expect(0, 8304, '\p{Is_Block=generalpunctuation}', "");
Expect(1, 8304, '\p{^Is_Block=generalpunctuation}', "");
Expect(1, 8304, '\P{Is_Block=generalpunctuation}', "");
Expect(0, 8304, '\P{^Is_Block=generalpunctuation}', "");
Expect(1, 8303, '\p{Is_Block=General_Punctuation}', "");
Expect(0, 8303, '\p{^Is_Block=General_Punctuation}', "");
Expect(0, 8303, '\P{Is_Block=General_Punctuation}', "");
Expect(1, 8303, '\P{^Is_Block=General_Punctuation}', "");
Expect(0, 8304, '\p{Is_Block=General_Punctuation}', "");
Expect(1, 8304, '\p{^Is_Block=General_Punctuation}', "");
Expect(1, 8304, '\P{Is_Block=General_Punctuation}', "");
Expect(0, 8304, '\P{^Is_Block=General_Punctuation}', "");
Error('\p{Is_Blk=-:=Punctuation}');
Error('\P{Is_Blk=-:=Punctuation}');
Expect(1, 8303, '\p{Is_Blk:   punctuation}', "");
Expect(0, 8303, '\p{^Is_Blk:   punctuation}', "");
Expect(0, 8303, '\P{Is_Blk:   punctuation}', "");
Expect(1, 8303, '\P{^Is_Blk:   punctuation}', "");
Expect(0, 8304, '\p{Is_Blk:   punctuation}', "");
Expect(1, 8304, '\p{^Is_Blk:   punctuation}', "");
Expect(1, 8304, '\P{Is_Blk:   punctuation}', "");
Expect(0, 8304, '\P{^Is_Blk:   punctuation}', "");
Expect(1, 8303, '\p{Is_Blk: -Punctuation}', "");
Expect(0, 8303, '\p{^Is_Blk: -Punctuation}', "");
Expect(0, 8303, '\P{Is_Blk: -Punctuation}', "");
Expect(1, 8303, '\P{^Is_Blk: -Punctuation}', "");
Expect(0, 8304, '\p{Is_Blk: -Punctuation}', "");
Expect(1, 8304, '\p{^Is_Blk: -Punctuation}', "");
Expect(1, 8304, '\P{Is_Blk: -Punctuation}', "");
Expect(0, 8304, '\P{^Is_Blk: -Punctuation}', "");
Error('\p{Block=/a/- REJANG}');
Error('\P{Block=/a/- REJANG}');
Expect(1, 43359, '\p{Block=rejang}', "");
Expect(0, 43359, '\p{^Block=rejang}', "");
Expect(0, 43359, '\P{Block=rejang}', "");
Expect(1, 43359, '\P{^Block=rejang}', "");
Expect(0, 43360, '\p{Block=rejang}', "");
Expect(1, 43360, '\p{^Block=rejang}', "");
Expect(1, 43360, '\P{Block=rejang}', "");
Expect(0, 43360, '\P{^Block=rejang}', "");
Expect(1, 43359, '\p{Block:	  Rejang}', "");
Expect(0, 43359, '\p{^Block:	  Rejang}', "");
Expect(0, 43359, '\P{Block:	  Rejang}', "");
Expect(1, 43359, '\P{^Block:	  Rejang}', "");
Expect(0, 43360, '\p{Block:	  Rejang}', "");
Expect(1, 43360, '\p{^Block:	  Rejang}', "");
Expect(1, 43360, '\P{Block:	  Rejang}', "");
Expect(0, 43360, '\P{^Block:	  Rejang}', "");
Error('\p{Blk=_:=rejang}');
Error('\P{Blk=_:=rejang}');
Expect(1, 43359, '\p{Blk=rejang}', "");
Expect(0, 43359, '\p{^Blk=rejang}', "");
Expect(0, 43359, '\P{Blk=rejang}', "");
Expect(1, 43359, '\P{^Blk=rejang}', "");
Expect(0, 43360, '\p{Blk=rejang}', "");
Expect(1, 43360, '\p{^Blk=rejang}', "");
Expect(1, 43360, '\P{Blk=rejang}', "");
Expect(0, 43360, '\P{^Blk=rejang}', "");
Error('\p{Is_Block=:=-_Rejang}');
Error('\P{Is_Block=:=-_Rejang}');
Expect(1, 43359, '\p{Is_Block:rejang}', "");
Expect(0, 43359, '\p{^Is_Block:rejang}', "");
Expect(0, 43359, '\P{Is_Block:rejang}', "");
Expect(1, 43359, '\P{^Is_Block:rejang}', "");
Expect(0, 43360, '\p{Is_Block:rejang}', "");
Expect(1, 43360, '\p{^Is_Block:rejang}', "");
Expect(1, 43360, '\P{Is_Block:rejang}', "");
Expect(0, 43360, '\P{^Is_Block:rejang}', "");
Expect(1, 43359, '\p{Is_Block=_rejang}', "");
Expect(0, 43359, '\p{^Is_Block=_rejang}', "");
Expect(0, 43359, '\P{Is_Block=_rejang}', "");
Expect(1, 43359, '\P{^Is_Block=_rejang}', "");
Expect(0, 43360, '\p{Is_Block=_rejang}', "");
Expect(1, 43360, '\p{^Is_Block=_rejang}', "");
Expect(1, 43360, '\P{Is_Block=_rejang}', "");
Expect(0, 43360, '\P{^Is_Block=_rejang}', "");
Error('\p{Is_Blk:	_	rejang:=}');
Error('\P{Is_Blk:	_	rejang:=}');
Expect(1, 43359, '\p{Is_Blk=rejang}', "");
Expect(0, 43359, '\p{^Is_Blk=rejang}', "");
Expect(0, 43359, '\P{Is_Blk=rejang}', "");
Expect(1, 43359, '\P{^Is_Blk=rejang}', "");
Expect(0, 43360, '\p{Is_Blk=rejang}', "");
Expect(1, 43360, '\p{^Is_Blk=rejang}', "");
Expect(1, 43360, '\P{Is_Blk=rejang}', "");
Expect(0, 43360, '\P{^Is_Blk=rejang}', "");
Expect(1, 43359, '\p{Is_Blk=__Rejang}', "");
Expect(0, 43359, '\p{^Is_Blk=__Rejang}', "");
Expect(0, 43359, '\P{Is_Blk=__Rejang}', "");
Expect(1, 43359, '\P{^Is_Blk=__Rejang}', "");
Expect(0, 43360, '\p{Is_Blk=__Rejang}', "");
Expect(1, 43360, '\p{^Is_Blk=__Rejang}', "");
Expect(1, 43360, '\P{Is_Blk=__Rejang}', "");
Expect(0, 43360, '\P{^Is_Blk=__Rejang}', "");
Error('\p{Block=:=	-RUMI_Numeral_Symbols}');
Error('\P{Block=:=	-RUMI_Numeral_Symbols}');
Expect(1, 69247, '\p{Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\p{^Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\P{Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\P{^Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\p{Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\p{^Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\P{Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\P{^Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\p{Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(0, 69247, '\p{^Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(0, 69247, '\P{Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(1, 69247, '\P{^Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(0, 69248, '\p{Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(1, 69248, '\p{^Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(1, 69248, '\P{Block:_ Rumi_NUMERAL_Symbols}', "");
Expect(0, 69248, '\P{^Block:_ Rumi_NUMERAL_Symbols}', "");
Error('\p{Blk=_/a/rumi}');
Error('\P{Blk=_/a/rumi}');
Expect(1, 69247, '\p{Blk=rumi}', "");
Expect(0, 69247, '\p{^Blk=rumi}', "");
Expect(0, 69247, '\P{Blk=rumi}', "");
Expect(1, 69247, '\P{^Blk=rumi}', "");
Expect(0, 69248, '\p{Blk=rumi}', "");
Expect(1, 69248, '\p{^Blk=rumi}', "");
Expect(1, 69248, '\P{Blk=rumi}', "");
Expect(0, 69248, '\P{^Blk=rumi}', "");
Expect(1, 69247, '\p{Blk=	Rumi}', "");
Expect(0, 69247, '\p{^Blk=	Rumi}', "");
Expect(0, 69247, '\P{Blk=	Rumi}', "");
Expect(1, 69247, '\P{^Blk=	Rumi}', "");
Expect(0, 69248, '\p{Blk=	Rumi}', "");
Expect(1, 69248, '\p{^Blk=	Rumi}', "");
Expect(1, 69248, '\P{Blk=	Rumi}', "");
Expect(0, 69248, '\P{^Blk=	Rumi}', "");
Error('\p{Is_Block:   /a/_rumi_Numeral_SYMBOLS}');
Error('\P{Is_Block:   /a/_rumi_Numeral_SYMBOLS}');
Expect(1, 69247, '\p{Is_Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\p{^Is_Block=ruminumeralsymbols}', "");
Expect(0, 69247, '\P{Is_Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\P{^Is_Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\p{Is_Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\p{^Is_Block=ruminumeralsymbols}', "");
Expect(1, 69248, '\P{Is_Block=ruminumeralsymbols}', "");
Expect(0, 69248, '\P{^Is_Block=ruminumeralsymbols}', "");
Expect(1, 69247, '\p{Is_Block= _Rumi_numeral_symbols}', "");
Expect(0, 69247, '\p{^Is_Block= _Rumi_numeral_symbols}', "");
Expect(0, 69247, '\P{Is_Block= _Rumi_numeral_symbols}', "");
Expect(1, 69247, '\P{^Is_Block= _Rumi_numeral_symbols}', "");
Expect(0, 69248, '\p{Is_Block= _Rumi_numeral_symbols}', "");
Expect(1, 69248, '\p{^Is_Block= _Rumi_numeral_symbols}', "");
Expect(1, 69248, '\P{Is_Block= _Rumi_numeral_symbols}', "");
Expect(0, 69248, '\P{^Is_Block= _Rumi_numeral_symbols}', "");
Error('\p{Is_Blk=	_RUMI/a/}');
Error('\P{Is_Blk=	_RUMI/a/}');
Expect(1, 69247, '\p{Is_Blk=rumi}', "");
Expect(0, 69247, '\p{^Is_Blk=rumi}', "");
Expect(0, 69247, '\P{Is_Blk=rumi}', "");
Expect(1, 69247, '\P{^Is_Blk=rumi}', "");
Expect(0, 69248, '\p{Is_Blk=rumi}', "");
Expect(1, 69248, '\p{^Is_Blk=rumi}', "");
Expect(1, 69248, '\P{Is_Blk=rumi}', "");
Expect(0, 69248, '\P{^Is_Blk=rumi}', "");
Expect(1, 69247, '\p{Is_Blk= RUMI}', "");
Expect(0, 69247, '\p{^Is_Blk= RUMI}', "");
Expect(0, 69247, '\P{Is_Blk= RUMI}', "");
Expect(1, 69247, '\P{^Is_Blk= RUMI}', "");
Expect(0, 69248, '\p{Is_Blk= RUMI}', "");
Expect(1, 69248, '\p{^Is_Blk= RUMI}', "");
Expect(1, 69248, '\P{Is_Blk= RUMI}', "");
Expect(0, 69248, '\P{^Is_Blk= RUMI}', "");
Error('\p{Block=_ runic:=}');
Error('\P{Block=_ runic:=}');
Expect(1, 5887, '\p{Block:runic}', "");
Expect(0, 5887, '\p{^Block:runic}', "");
Expect(0, 5887, '\P{Block:runic}', "");
Expect(1, 5887, '\P{^Block:runic}', "");
Expect(0, 5888, '\p{Block:runic}', "");
Expect(1, 5888, '\p{^Block:runic}', "");
Expect(1, 5888, '\P{Block:runic}', "");
Expect(0, 5888, '\P{^Block:runic}', "");
Expect(1, 5887, '\p{Block=  RUNIC}', "");
Expect(0, 5887, '\p{^Block=  RUNIC}', "");
Expect(0, 5887, '\P{Block=  RUNIC}', "");
Expect(1, 5887, '\P{^Block=  RUNIC}', "");
Expect(0, 5888, '\p{Block=  RUNIC}', "");
Expect(1, 5888, '\p{^Block=  RUNIC}', "");
Expect(1, 5888, '\P{Block=  RUNIC}', "");
Expect(0, 5888, '\P{^Block=  RUNIC}', "");
Error('\p{Blk=/a/ Runic}');
Error('\P{Blk=/a/ Runic}');
Expect(1, 5887, '\p{Blk=runic}', "");
Expect(0, 5887, '\p{^Blk=runic}', "");
Expect(0, 5887, '\P{Blk=runic}', "");
Expect(1, 5887, '\P{^Blk=runic}', "");
Expect(0, 5888, '\p{Blk=runic}', "");
Expect(1, 5888, '\p{^Blk=runic}', "");
Expect(1, 5888, '\P{Blk=runic}', "");
Expect(0, 5888, '\P{^Blk=runic}', "");
Expect(1, 5887, '\p{Blk=	runic}', "");
Expect(0, 5887, '\p{^Blk=	runic}', "");
Expect(0, 5887, '\P{Blk=	runic}', "");
Expect(1, 5887, '\P{^Blk=	runic}', "");
Expect(0, 5888, '\p{Blk=	runic}', "");
Expect(1, 5888, '\p{^Blk=	runic}', "");
Expect(1, 5888, '\P{Blk=	runic}', "");
Expect(0, 5888, '\P{^Blk=	runic}', "");
Error('\p{Is_Block=:=-runic}');
Error('\P{Is_Block=:=-runic}');
Expect(1, 5887, '\p{Is_Block=runic}', "");
Expect(0, 5887, '\p{^Is_Block=runic}', "");
Expect(0, 5887, '\P{Is_Block=runic}', "");
Expect(1, 5887, '\P{^Is_Block=runic}', "");
Expect(0, 5888, '\p{Is_Block=runic}', "");
Expect(1, 5888, '\p{^Is_Block=runic}', "");
Expect(1, 5888, '\P{Is_Block=runic}', "");
Expect(0, 5888, '\P{^Is_Block=runic}', "");
Expect(1, 5887, '\p{Is_Block=-runic}', "");
Expect(0, 5887, '\p{^Is_Block=-runic}', "");
Expect(0, 5887, '\P{Is_Block=-runic}', "");
Expect(1, 5887, '\P{^Is_Block=-runic}', "");
Expect(0, 5888, '\p{Is_Block=-runic}', "");
Expect(1, 5888, '\p{^Is_Block=-runic}', "");
Expect(1, 5888, '\P{Is_Block=-runic}', "");
Expect(0, 5888, '\P{^Is_Block=-runic}', "");
Error('\p{Is_Blk=-RUNIC:=}');
Error('\P{Is_Blk=-RUNIC:=}');
Expect(1, 5887, '\p{Is_Blk=runic}', "");
Expect(0, 5887, '\p{^Is_Blk=runic}', "");
Expect(0, 5887, '\P{Is_Blk=runic}', "");
Expect(1, 5887, '\P{^Is_Blk=runic}', "");
Expect(0, 5888, '\p{Is_Blk=runic}', "");
Expect(1, 5888, '\p{^Is_Blk=runic}', "");
Expect(1, 5888, '\P{Is_Blk=runic}', "");
Expect(0, 5888, '\P{^Is_Blk=runic}', "");
Expect(1, 5887, '\p{Is_Blk: --Runic}', "");
Expect(0, 5887, '\p{^Is_Blk: --Runic}', "");
Expect(0, 5887, '\P{Is_Blk: --Runic}', "");
Expect(1, 5887, '\P{^Is_Blk: --Runic}', "");
Expect(0, 5888, '\p{Is_Blk: --Runic}', "");
Expect(1, 5888, '\p{^Is_Blk: --Runic}', "");
Expect(1, 5888, '\P{Is_Blk: --Runic}', "");
Expect(0, 5888, '\P{^Is_Blk: --Runic}', "");
Error('\p{Block=-Samaritan/a/}');
Error('\P{Block=-Samaritan/a/}');
Expect(1, 2111, '\p{Block=samaritan}', "");
Expect(0, 2111, '\p{^Block=samaritan}', "");
Expect(0, 2111, '\P{Block=samaritan}', "");
Expect(1, 2111, '\P{^Block=samaritan}', "");
Expect(0, 2112, '\p{Block=samaritan}', "");
Expect(1, 2112, '\p{^Block=samaritan}', "");
Expect(1, 2112, '\P{Block=samaritan}', "");
Expect(0, 2112, '\P{^Block=samaritan}', "");
Expect(1, 2111, '\p{Block=	samaritan}', "");
Expect(0, 2111, '\p{^Block=	samaritan}', "");
Expect(0, 2111, '\P{Block=	samaritan}', "");
Expect(1, 2111, '\P{^Block=	samaritan}', "");
Expect(0, 2112, '\p{Block=	samaritan}', "");
Expect(1, 2112, '\p{^Block=	samaritan}', "");
Expect(1, 2112, '\P{Block=	samaritan}', "");
Expect(0, 2112, '\P{^Block=	samaritan}', "");
Error('\p{Blk=:=_-Samaritan}');
Error('\P{Blk=:=_-Samaritan}');
Expect(1, 2111, '\p{Blk=samaritan}', "");
Expect(0, 2111, '\p{^Blk=samaritan}', "");
Expect(0, 2111, '\P{Blk=samaritan}', "");
Expect(1, 2111, '\P{^Blk=samaritan}', "");
Expect(0, 2112, '\p{Blk=samaritan}', "");
Expect(1, 2112, '\p{^Blk=samaritan}', "");
Expect(1, 2112, '\P{Blk=samaritan}', "");
Expect(0, 2112, '\P{^Blk=samaritan}', "");
Expect(1, 2111, '\p{Blk: - samaritan}', "");
Expect(0, 2111, '\p{^Blk: - samaritan}', "");
Expect(0, 2111, '\P{Blk: - samaritan}', "");
Expect(1, 2111, '\P{^Blk: - samaritan}', "");
Expect(0, 2112, '\p{Blk: - samaritan}', "");
Expect(1, 2112, '\p{^Blk: - samaritan}', "");
Expect(1, 2112, '\P{Blk: - samaritan}', "");
Expect(0, 2112, '\P{^Blk: - samaritan}', "");
Error('\p{Is_Block= /a/Samaritan}');
Error('\P{Is_Block= /a/Samaritan}');
Expect(1, 2111, '\p{Is_Block=samaritan}', "");
Expect(0, 2111, '\p{^Is_Block=samaritan}', "");
Expect(0, 2111, '\P{Is_Block=samaritan}', "");
Expect(1, 2111, '\P{^Is_Block=samaritan}', "");
Expect(0, 2112, '\p{Is_Block=samaritan}', "");
Expect(1, 2112, '\p{^Is_Block=samaritan}', "");
Expect(1, 2112, '\P{Is_Block=samaritan}', "");
Expect(0, 2112, '\P{^Is_Block=samaritan}', "");
Expect(1, 2111, '\p{Is_Block=--SAMARITAN}', "");
Expect(0, 2111, '\p{^Is_Block=--SAMARITAN}', "");
Expect(0, 2111, '\P{Is_Block=--SAMARITAN}', "");
Expect(1, 2111, '\P{^Is_Block=--SAMARITAN}', "");
Expect(0, 2112, '\p{Is_Block=--SAMARITAN}', "");
Expect(1, 2112, '\p{^Is_Block=--SAMARITAN}', "");
Expect(1, 2112, '\P{Is_Block=--SAMARITAN}', "");
Expect(0, 2112, '\P{^Is_Block=--SAMARITAN}', "");
Error('\p{Is_Blk=:=  SAMARITAN}');
Error('\P{Is_Blk=:=  SAMARITAN}');
Expect(1, 2111, '\p{Is_Blk=samaritan}', "");
Expect(0, 2111, '\p{^Is_Blk=samaritan}', "");
Expect(0, 2111, '\P{Is_Blk=samaritan}', "");
Expect(1, 2111, '\P{^Is_Blk=samaritan}', "");
Expect(0, 2112, '\p{Is_Blk=samaritan}', "");
Expect(1, 2112, '\p{^Is_Blk=samaritan}', "");
Expect(1, 2112, '\P{Is_Blk=samaritan}', "");
Expect(0, 2112, '\P{^Is_Blk=samaritan}', "");
Expect(1, 2111, '\p{Is_Blk= _Samaritan}', "");
Expect(0, 2111, '\p{^Is_Blk= _Samaritan}', "");
Expect(0, 2111, '\P{Is_Blk= _Samaritan}', "");
Expect(1, 2111, '\P{^Is_Blk= _Samaritan}', "");
Expect(0, 2112, '\p{Is_Blk= _Samaritan}', "");
Expect(1, 2112, '\p{^Is_Blk= _Samaritan}', "");
Expect(1, 2112, '\P{Is_Blk= _Samaritan}', "");
Expect(0, 2112, '\P{^Is_Blk= _Samaritan}', "");
Error('\p{Block= :=saurashtra}');
Error('\P{Block= :=saurashtra}');
Expect(1, 43231, '\p{Block=saurashtra}', "");
Expect(0, 43231, '\p{^Block=saurashtra}', "");
Expect(0, 43231, '\P{Block=saurashtra}', "");
Expect(1, 43231, '\P{^Block=saurashtra}', "");
Expect(0, 43232, '\p{Block=saurashtra}', "");
Expect(1, 43232, '\p{^Block=saurashtra}', "");
Expect(1, 43232, '\P{Block=saurashtra}', "");
Expect(0, 43232, '\P{^Block=saurashtra}', "");
Expect(1, 43231, '\p{Block=	_SAURASHTRA}', "");
Expect(0, 43231, '\p{^Block=	_SAURASHTRA}', "");
Expect(0, 43231, '\P{Block=	_SAURASHTRA}', "");
Expect(1, 43231, '\P{^Block=	_SAURASHTRA}', "");
Expect(0, 43232, '\p{Block=	_SAURASHTRA}', "");
Expect(1, 43232, '\p{^Block=	_SAURASHTRA}', "");
Expect(1, 43232, '\P{Block=	_SAURASHTRA}', "");
Expect(0, 43232, '\P{^Block=	_SAURASHTRA}', "");
Error('\p{Blk=/a/	 Saurashtra}');
Error('\P{Blk=/a/	 Saurashtra}');
Expect(1, 43231, '\p{Blk=saurashtra}', "");
Expect(0, 43231, '\p{^Blk=saurashtra}', "");
Expect(0, 43231, '\P{Blk=saurashtra}', "");
Expect(1, 43231, '\P{^Blk=saurashtra}', "");
Expect(0, 43232, '\p{Blk=saurashtra}', "");
Expect(1, 43232, '\p{^Blk=saurashtra}', "");
Expect(1, 43232, '\P{Blk=saurashtra}', "");
Expect(0, 43232, '\P{^Blk=saurashtra}', "");
Expect(1, 43231, '\p{Blk=_Saurashtra}', "");
Expect(0, 43231, '\p{^Blk=_Saurashtra}', "");
Expect(0, 43231, '\P{Blk=_Saurashtra}', "");
Expect(1, 43231, '\P{^Blk=_Saurashtra}', "");
Expect(0, 43232, '\p{Blk=_Saurashtra}', "");
Expect(1, 43232, '\p{^Blk=_Saurashtra}', "");
Expect(1, 43232, '\P{Blk=_Saurashtra}', "");
Expect(0, 43232, '\P{^Blk=_Saurashtra}', "");
Error('\p{Is_Block=:=SAURASHTRA}');
Error('\P{Is_Block=:=SAURASHTRA}');
Expect(1, 43231, '\p{Is_Block=saurashtra}', "");
Expect(0, 43231, '\p{^Is_Block=saurashtra}', "");
Expect(0, 43231, '\P{Is_Block=saurashtra}', "");
Expect(1, 43231, '\P{^Is_Block=saurashtra}', "");
Expect(0, 43232, '\p{Is_Block=saurashtra}', "");
Expect(1, 43232, '\p{^Is_Block=saurashtra}', "");
Expect(1, 43232, '\P{Is_Block=saurashtra}', "");
Expect(0, 43232, '\P{^Is_Block=saurashtra}', "");
Expect(1, 43231, '\p{Is_Block=	 SAURASHTRA}', "");
Expect(0, 43231, '\p{^Is_Block=	 SAURASHTRA}', "");
Expect(0, 43231, '\P{Is_Block=	 SAURASHTRA}', "");
Expect(1, 43231, '\P{^Is_Block=	 SAURASHTRA}', "");
Expect(0, 43232, '\p{Is_Block=	 SAURASHTRA}', "");
Expect(1, 43232, '\p{^Is_Block=	 SAURASHTRA}', "");
Expect(1, 43232, '\P{Is_Block=	 SAURASHTRA}', "");
Expect(0, 43232, '\P{^Is_Block=	 SAURASHTRA}', "");
Error('\p{Is_Blk= SAURASHTRA/a/}');
Error('\P{Is_Blk= SAURASHTRA/a/}');
Expect(1, 43231, '\p{Is_Blk=saurashtra}', "");
Expect(0, 43231, '\p{^Is_Blk=saurashtra}', "");
Expect(0, 43231, '\P{Is_Blk=saurashtra}', "");
Expect(1, 43231, '\P{^Is_Blk=saurashtra}', "");
Expect(0, 43232, '\p{Is_Blk=saurashtra}', "");
Expect(1, 43232, '\p{^Is_Blk=saurashtra}', "");
Expect(1, 43232, '\P{Is_Blk=saurashtra}', "");
Expect(0, 43232, '\P{^Is_Blk=saurashtra}', "");
Expect(1, 43231, '\p{Is_Blk:	- SAURASHTRA}', "");
Expect(0, 43231, '\p{^Is_Blk:	- SAURASHTRA}', "");
Expect(0, 43231, '\P{Is_Blk:	- SAURASHTRA}', "");
Expect(1, 43231, '\P{^Is_Blk:	- SAURASHTRA}', "");
Expect(0, 43232, '\p{Is_Blk:	- SAURASHTRA}', "");
Expect(1, 43232, '\p{^Is_Blk:	- SAURASHTRA}', "");
Expect(1, 43232, '\P{Is_Blk:	- SAURASHTRA}', "");
Expect(0, 43232, '\P{^Is_Blk:	- SAURASHTRA}', "");
Error('\p{Block=__Sharada/a/}');
Error('\P{Block=__Sharada/a/}');
Expect(1, 70111, '\p{Block=sharada}', "");
Expect(0, 70111, '\p{^Block=sharada}', "");
Expect(0, 70111, '\P{Block=sharada}', "");
Expect(1, 70111, '\P{^Block=sharada}', "");
Expect(0, 70112, '\p{Block=sharada}', "");
Expect(1, 70112, '\p{^Block=sharada}', "");
Expect(1, 70112, '\P{Block=sharada}', "");
Expect(0, 70112, '\P{^Block=sharada}', "");
Expect(1, 70111, '\p{Block= Sharada}', "");
Expect(0, 70111, '\p{^Block= Sharada}', "");
Expect(0, 70111, '\P{Block= Sharada}', "");
Expect(1, 70111, '\P{^Block= Sharada}', "");
Expect(0, 70112, '\p{Block= Sharada}', "");
Expect(1, 70112, '\p{^Block= Sharada}', "");
Expect(1, 70112, '\P{Block= Sharada}', "");
Expect(0, 70112, '\P{^Block= Sharada}', "");
Error('\p{Blk= :=Sharada}');
Error('\P{Blk= :=Sharada}');
Expect(1, 70111, '\p{Blk=sharada}', "");
Expect(0, 70111, '\p{^Blk=sharada}', "");
Expect(0, 70111, '\P{Blk=sharada}', "");
Expect(1, 70111, '\P{^Blk=sharada}', "");
Expect(0, 70112, '\p{Blk=sharada}', "");
Expect(1, 70112, '\p{^Blk=sharada}', "");
Expect(1, 70112, '\P{Blk=sharada}', "");
Expect(0, 70112, '\P{^Blk=sharada}', "");
Expect(1, 70111, '\p{Blk=- SHARADA}', "");
Expect(0, 70111, '\p{^Blk=- SHARADA}', "");
Expect(0, 70111, '\P{Blk=- SHARADA}', "");
Expect(1, 70111, '\P{^Blk=- SHARADA}', "");
Expect(0, 70112, '\p{Blk=- SHARADA}', "");
Expect(1, 70112, '\p{^Blk=- SHARADA}', "");
Expect(1, 70112, '\P{Blk=- SHARADA}', "");
Expect(0, 70112, '\P{^Blk=- SHARADA}', "");
Error('\p{Is_Block=:=  Sharada}');
Error('\P{Is_Block=:=  Sharada}');
Expect(1, 70111, '\p{Is_Block=sharada}', "");
Expect(0, 70111, '\p{^Is_Block=sharada}', "");
Expect(0, 70111, '\P{Is_Block=sharada}', "");
Expect(1, 70111, '\P{^Is_Block=sharada}', "");
Expect(0, 70112, '\p{Is_Block=sharada}', "");
Expect(1, 70112, '\p{^Is_Block=sharada}', "");
Expect(1, 70112, '\P{Is_Block=sharada}', "");
Expect(0, 70112, '\P{^Is_Block=sharada}', "");
Expect(1, 70111, '\p{Is_Block= Sharada}', "");
Expect(0, 70111, '\p{^Is_Block= Sharada}', "");
Expect(0, 70111, '\P{Is_Block= Sharada}', "");
Expect(1, 70111, '\P{^Is_Block= Sharada}', "");
Expect(0, 70112, '\p{Is_Block= Sharada}', "");
Expect(1, 70112, '\p{^Is_Block= Sharada}', "");
Expect(1, 70112, '\P{Is_Block= Sharada}', "");
Expect(0, 70112, '\P{^Is_Block= Sharada}', "");
Error('\p{Is_Blk=-Sharada:=}');
Error('\P{Is_Blk=-Sharada:=}');
Expect(1, 70111, '\p{Is_Blk=sharada}', "");
Expect(0, 70111, '\p{^Is_Blk=sharada}', "");
Expect(0, 70111, '\P{Is_Blk=sharada}', "");
Expect(1, 70111, '\P{^Is_Blk=sharada}', "");
Expect(0, 70112, '\p{Is_Blk=sharada}', "");
Expect(1, 70112, '\p{^Is_Blk=sharada}', "");
Expect(1, 70112, '\P{Is_Blk=sharada}', "");
Expect(0, 70112, '\P{^Is_Blk=sharada}', "");
Expect(1, 70111, '\p{Is_Blk= 	SHARADA}', "");
Expect(0, 70111, '\p{^Is_Blk= 	SHARADA}', "");
Expect(0, 70111, '\P{Is_Blk= 	SHARADA}', "");
Expect(1, 70111, '\P{^Is_Blk= 	SHARADA}', "");
Expect(0, 70112, '\p{Is_Blk= 	SHARADA}', "");
Expect(1, 70112, '\p{^Is_Blk= 	SHARADA}', "");
Expect(1, 70112, '\P{Is_Blk= 	SHARADA}', "");
Expect(0, 70112, '\P{^Is_Blk= 	SHARADA}', "");
Error('\p{Block=/a/shavian}');
Error('\P{Block=/a/shavian}');
Expect(1, 66687, '\p{Block=shavian}', "");
Expect(0, 66687, '\p{^Block=shavian}', "");
Expect(0, 66687, '\P{Block=shavian}', "");
Expect(1, 66687, '\P{^Block=shavian}', "");
Expect(0, 66688, '\p{Block=shavian}', "");
Expect(1, 66688, '\p{^Block=shavian}', "");
Expect(1, 66688, '\P{Block=shavian}', "");
Expect(0, 66688, '\P{^Block=shavian}', "");
Expect(1, 66687, '\p{Block:	_	SHAVIAN}', "");
Expect(0, 66687, '\p{^Block:	_	SHAVIAN}', "");
Expect(0, 66687, '\P{Block:	_	SHAVIAN}', "");
Expect(1, 66687, '\P{^Block:	_	SHAVIAN}', "");
Expect(0, 66688, '\p{Block:	_	SHAVIAN}', "");
Expect(1, 66688, '\p{^Block:	_	SHAVIAN}', "");
Expect(1, 66688, '\P{Block:	_	SHAVIAN}', "");
Expect(0, 66688, '\P{^Block:	_	SHAVIAN}', "");
Error('\p{Blk=_Shavian:=}');
Error('\P{Blk=_Shavian:=}');
Expect(1, 66687, '\p{Blk=shavian}', "");
Expect(0, 66687, '\p{^Blk=shavian}', "");
Expect(0, 66687, '\P{Blk=shavian}', "");
Expect(1, 66687, '\P{^Blk=shavian}', "");
Expect(0, 66688, '\p{Blk=shavian}', "");
Expect(1, 66688, '\p{^Blk=shavian}', "");
Expect(1, 66688, '\P{Blk=shavian}', "");
Expect(0, 66688, '\P{^Blk=shavian}', "");
Expect(1, 66687, '\p{Blk=-Shavian}', "");
Expect(0, 66687, '\p{^Blk=-Shavian}', "");
Expect(0, 66687, '\P{Blk=-Shavian}', "");
Expect(1, 66687, '\P{^Blk=-Shavian}', "");
Expect(0, 66688, '\p{Blk=-Shavian}', "");
Expect(1, 66688, '\p{^Blk=-Shavian}', "");
Expect(1, 66688, '\P{Blk=-Shavian}', "");
Expect(0, 66688, '\P{^Blk=-Shavian}', "");
Error('\p{Is_Block= 	SHAVIAN:=}');
Error('\P{Is_Block= 	SHAVIAN:=}');
Expect(1, 66687, '\p{Is_Block=shavian}', "");
Expect(0, 66687, '\p{^Is_Block=shavian}', "");
Expect(0, 66687, '\P{Is_Block=shavian}', "");
Expect(1, 66687, '\P{^Is_Block=shavian}', "");
Expect(0, 66688, '\p{Is_Block=shavian}', "");
Expect(1, 66688, '\p{^Is_Block=shavian}', "");
Expect(1, 66688, '\P{Is_Block=shavian}', "");
Expect(0, 66688, '\P{^Is_Block=shavian}', "");
Expect(1, 66687, '\p{Is_Block=_shavian}', "");
Expect(0, 66687, '\p{^Is_Block=_shavian}', "");
Expect(0, 66687, '\P{Is_Block=_shavian}', "");
Expect(1, 66687, '\P{^Is_Block=_shavian}', "");
Expect(0, 66688, '\p{Is_Block=_shavian}', "");
Expect(1, 66688, '\p{^Is_Block=_shavian}', "");
Expect(1, 66688, '\P{Is_Block=_shavian}', "");
Expect(0, 66688, '\P{^Is_Block=_shavian}', "");
Error('\p{Is_Blk=-	shavian:=}');
Error('\P{Is_Blk=-	shavian:=}');
Expect(1, 66687, '\p{Is_Blk=shavian}', "");
Expect(0, 66687, '\p{^Is_Blk=shavian}', "");
Expect(0, 66687, '\P{Is_Blk=shavian}', "");
Expect(1, 66687, '\P{^Is_Blk=shavian}', "");
Expect(0, 66688, '\p{Is_Blk=shavian}', "");
Expect(1, 66688, '\p{^Is_Blk=shavian}', "");
Expect(1, 66688, '\P{Is_Blk=shavian}', "");
Expect(0, 66688, '\P{^Is_Blk=shavian}', "");
Expect(1, 66687, '\p{Is_Blk: Shavian}', "");
Expect(0, 66687, '\p{^Is_Blk: Shavian}', "");
Expect(0, 66687, '\P{Is_Blk: Shavian}', "");
Expect(1, 66687, '\P{^Is_Blk: Shavian}', "");
Expect(0, 66688, '\p{Is_Blk: Shavian}', "");
Expect(1, 66688, '\p{^Is_Blk: Shavian}', "");
Expect(1, 66688, '\P{Is_Blk: Shavian}', "");
Expect(0, 66688, '\P{^Is_Blk: Shavian}', "");
Error('\p{Block:    :=Sinhala}');
Error('\P{Block:    :=Sinhala}');
Expect(1, 3583, '\p{Block=sinhala}', "");
Expect(0, 3583, '\p{^Block=sinhala}', "");
Expect(0, 3583, '\P{Block=sinhala}', "");
Expect(1, 3583, '\P{^Block=sinhala}', "");
Expect(0, 3584, '\p{Block=sinhala}', "");
Expect(1, 3584, '\p{^Block=sinhala}', "");
Expect(1, 3584, '\P{Block=sinhala}', "");
Expect(0, 3584, '\P{^Block=sinhala}', "");
Expect(1, 3583, '\p{Block=--sinhala}', "");
Expect(0, 3583, '\p{^Block=--sinhala}', "");
Expect(0, 3583, '\P{Block=--sinhala}', "");
Expect(1, 3583, '\P{^Block=--sinhala}', "");
Expect(0, 3584, '\p{Block=--sinhala}', "");
Expect(1, 3584, '\p{^Block=--sinhala}', "");
Expect(1, 3584, '\P{Block=--sinhala}', "");
Expect(0, 3584, '\P{^Block=--sinhala}', "");
Error('\p{Blk=_:=Sinhala}');
Error('\P{Blk=_:=Sinhala}');
Expect(1, 3583, '\p{Blk=sinhala}', "");
Expect(0, 3583, '\p{^Blk=sinhala}', "");
Expect(0, 3583, '\P{Blk=sinhala}', "");
Expect(1, 3583, '\P{^Blk=sinhala}', "");
Expect(0, 3584, '\p{Blk=sinhala}', "");
Expect(1, 3584, '\p{^Blk=sinhala}', "");
Expect(1, 3584, '\P{Blk=sinhala}', "");
Expect(0, 3584, '\P{^Blk=sinhala}', "");
Expect(1, 3583, '\p{Blk= Sinhala}', "");
Expect(0, 3583, '\p{^Blk= Sinhala}', "");
Expect(0, 3583, '\P{Blk= Sinhala}', "");
Expect(1, 3583, '\P{^Blk= Sinhala}', "");
Expect(0, 3584, '\p{Blk= Sinhala}', "");
Expect(1, 3584, '\p{^Blk= Sinhala}', "");
Expect(1, 3584, '\P{Blk= Sinhala}', "");
Expect(0, 3584, '\P{^Blk= Sinhala}', "");
Error('\p{Is_Block: :=sinhala}');
Error('\P{Is_Block: :=sinhala}');
Expect(1, 3583, '\p{Is_Block=sinhala}', "");
Expect(0, 3583, '\p{^Is_Block=sinhala}', "");
Expect(0, 3583, '\P{Is_Block=sinhala}', "");
Expect(1, 3583, '\P{^Is_Block=sinhala}', "");
Expect(0, 3584, '\p{Is_Block=sinhala}', "");
Expect(1, 3584, '\p{^Is_Block=sinhala}', "");
Expect(1, 3584, '\P{Is_Block=sinhala}', "");
Expect(0, 3584, '\P{^Is_Block=sinhala}', "");
Expect(1, 3583, '\p{Is_Block=- SINHALA}', "");
Expect(0, 3583, '\p{^Is_Block=- SINHALA}', "");
Expect(0, 3583, '\P{Is_Block=- SINHALA}', "");
Expect(1, 3583, '\P{^Is_Block=- SINHALA}', "");
Expect(0, 3584, '\p{Is_Block=- SINHALA}', "");
Expect(1, 3584, '\p{^Is_Block=- SINHALA}', "");
Expect(1, 3584, '\P{Is_Block=- SINHALA}', "");
Expect(0, 3584, '\P{^Is_Block=- SINHALA}', "");
Error('\p{Is_Blk=:=- Sinhala}');
Error('\P{Is_Blk=:=- Sinhala}');
Expect(1, 3583, '\p{Is_Blk=sinhala}', "");
Expect(0, 3583, '\p{^Is_Blk=sinhala}', "");
Expect(0, 3583, '\P{Is_Blk=sinhala}', "");
Expect(1, 3583, '\P{^Is_Blk=sinhala}', "");
Expect(0, 3584, '\p{Is_Blk=sinhala}', "");
Expect(1, 3584, '\p{^Is_Blk=sinhala}', "");
Expect(1, 3584, '\P{Is_Blk=sinhala}', "");
Expect(0, 3584, '\P{^Is_Blk=sinhala}', "");
Expect(1, 3583, '\p{Is_Blk= Sinhala}', "");
Expect(0, 3583, '\p{^Is_Blk= Sinhala}', "");
Expect(0, 3583, '\P{Is_Blk= Sinhala}', "");
Expect(1, 3583, '\P{^Is_Blk= Sinhala}', "");
Expect(0, 3584, '\p{Is_Blk= Sinhala}', "");
Expect(1, 3584, '\p{^Is_Blk= Sinhala}', "");
Expect(1, 3584, '\P{Is_Blk= Sinhala}', "");
Expect(0, 3584, '\P{^Is_Blk= Sinhala}', "");
Error('\p{Block=_:=Small_Form_variants}');
Error('\P{Block=_:=Small_Form_variants}');
Expect(1, 65135, '\p{Block=smallformvariants}', "");
Expect(0, 65135, '\p{^Block=smallformvariants}', "");
Expect(0, 65135, '\P{Block=smallformvariants}', "");
Expect(1, 65135, '\P{^Block=smallformvariants}', "");
Expect(0, 65136, '\p{Block=smallformvariants}', "");
Expect(1, 65136, '\p{^Block=smallformvariants}', "");
Expect(1, 65136, '\P{Block=smallformvariants}', "");
Expect(0, 65136, '\P{^Block=smallformvariants}', "");
Expect(1, 65135, '\p{Block= 	Small_form_variants}', "");
Expect(0, 65135, '\p{^Block= 	Small_form_variants}', "");
Expect(0, 65135, '\P{Block= 	Small_form_variants}', "");
Expect(1, 65135, '\P{^Block= 	Small_form_variants}', "");
Expect(0, 65136, '\p{Block= 	Small_form_variants}', "");
Expect(1, 65136, '\p{^Block= 	Small_form_variants}', "");
Expect(1, 65136, '\P{Block= 	Small_form_variants}', "");
Expect(0, 65136, '\P{^Block= 	Small_form_variants}', "");
Error('\p{Blk=/a/_-Small_Forms}');
Error('\P{Blk=/a/_-Small_Forms}');
Expect(1, 65135, '\p{Blk=smallforms}', "");
Expect(0, 65135, '\p{^Blk=smallforms}', "");
Expect(0, 65135, '\P{Blk=smallforms}', "");
Expect(1, 65135, '\P{^Blk=smallforms}', "");
Expect(0, 65136, '\p{Blk=smallforms}', "");
Expect(1, 65136, '\p{^Blk=smallforms}', "");
Expect(1, 65136, '\P{Blk=smallforms}', "");
Expect(0, 65136, '\P{^Blk=smallforms}', "");
Expect(1, 65135, '\p{Blk=- SMALL_Forms}', "");
Expect(0, 65135, '\p{^Blk=- SMALL_Forms}', "");
Expect(0, 65135, '\P{Blk=- SMALL_Forms}', "");
Expect(1, 65135, '\P{^Blk=- SMALL_Forms}', "");
Expect(0, 65136, '\p{Blk=- SMALL_Forms}', "");
Expect(1, 65136, '\p{^Blk=- SMALL_Forms}', "");
Expect(1, 65136, '\P{Blk=- SMALL_Forms}', "");
Expect(0, 65136, '\P{^Blk=- SMALL_Forms}', "");
Error('\p{Is_Block=-:=Small_FORM_Variants}');
Error('\P{Is_Block=-:=Small_FORM_Variants}');
Expect(1, 65135, '\p{Is_Block=smallformvariants}', "");
Expect(0, 65135, '\p{^Is_Block=smallformvariants}', "");
Expect(0, 65135, '\P{Is_Block=smallformvariants}', "");
Expect(1, 65135, '\P{^Is_Block=smallformvariants}', "");
Expect(0, 65136, '\p{Is_Block=smallformvariants}', "");
Expect(1, 65136, '\p{^Is_Block=smallformvariants}', "");
Expect(1, 65136, '\P{Is_Block=smallformvariants}', "");
Expect(0, 65136, '\P{^Is_Block=smallformvariants}', "");
Expect(1, 65135, '\p{Is_Block=-_SMALL_FORM_Variants}', "");
Expect(0, 65135, '\p{^Is_Block=-_SMALL_FORM_Variants}', "");
Expect(0, 65135, '\P{Is_Block=-_SMALL_FORM_Variants}', "");
Expect(1, 65135, '\P{^Is_Block=-_SMALL_FORM_Variants}', "");
Expect(0, 65136, '\p{Is_Block=-_SMALL_FORM_Variants}', "");
Expect(1, 65136, '\p{^Is_Block=-_SMALL_FORM_Variants}', "");
Expect(1, 65136, '\P{Is_Block=-_SMALL_FORM_Variants}', "");
Expect(0, 65136, '\P{^Is_Block=-_SMALL_FORM_Variants}', "");
Error('\p{Is_Blk=/a/_	small_forms}');
Error('\P{Is_Blk=/a/_	small_forms}');
Expect(1, 65135, '\p{Is_Blk=smallforms}', "");
Expect(0, 65135, '\p{^Is_Blk=smallforms}', "");
Expect(0, 65135, '\P{Is_Blk=smallforms}', "");
Expect(1, 65135, '\P{^Is_Blk=smallforms}', "");
Expect(0, 65136, '\p{Is_Blk=smallforms}', "");
Expect(1, 65136, '\p{^Is_Blk=smallforms}', "");
Expect(1, 65136, '\P{Is_Blk=smallforms}', "");
Expect(0, 65136, '\P{^Is_Blk=smallforms}', "");
Expect(1, 65135, '\p{Is_Blk:		_Small_forms}', "");
Expect(0, 65135, '\p{^Is_Blk:		_Small_forms}', "");
Expect(0, 65135, '\P{Is_Blk:		_Small_forms}', "");
Expect(1, 65135, '\P{^Is_Blk:		_Small_forms}', "");
Expect(0, 65136, '\p{Is_Blk:		_Small_forms}', "");
Expect(1, 65136, '\p{^Is_Blk:		_Small_forms}', "");
Expect(1, 65136, '\P{Is_Blk:		_Small_forms}', "");
Expect(0, 65136, '\P{^Is_Blk:		_Small_forms}', "");
Error('\p{Block=_SORA_sompeng:=}');
Error('\P{Block=_SORA_sompeng:=}');
Expect(1, 69887, '\p{Block=sorasompeng}', "");
Expect(0, 69887, '\p{^Block=sorasompeng}', "");
Expect(0, 69887, '\P{Block=sorasompeng}', "");
Expect(1, 69887, '\P{^Block=sorasompeng}', "");
Expect(0, 69888, '\p{Block=sorasompeng}', "");
Expect(1, 69888, '\p{^Block=sorasompeng}', "");
Expect(1, 69888, '\P{Block=sorasompeng}', "");
Expect(0, 69888, '\P{^Block=sorasompeng}', "");
Expect(1, 69887, '\p{Block=__SORA_Sompeng}', "");
Expect(0, 69887, '\p{^Block=__SORA_Sompeng}', "");
Expect(0, 69887, '\P{Block=__SORA_Sompeng}', "");
Expect(1, 69887, '\P{^Block=__SORA_Sompeng}', "");
Expect(0, 69888, '\p{Block=__SORA_Sompeng}', "");
Expect(1, 69888, '\p{^Block=__SORA_Sompeng}', "");
Expect(1, 69888, '\P{Block=__SORA_Sompeng}', "");
Expect(0, 69888, '\P{^Block=__SORA_Sompeng}', "");
Error('\p{Blk=	/a/sora_Sompeng}');
Error('\P{Blk=	/a/sora_Sompeng}');
Expect(1, 69887, '\p{Blk=sorasompeng}', "");
Expect(0, 69887, '\p{^Blk=sorasompeng}', "");
Expect(0, 69887, '\P{Blk=sorasompeng}', "");
Expect(1, 69887, '\P{^Blk=sorasompeng}', "");
Expect(0, 69888, '\p{Blk=sorasompeng}', "");
Expect(1, 69888, '\p{^Blk=sorasompeng}', "");
Expect(1, 69888, '\P{Blk=sorasompeng}', "");
Expect(0, 69888, '\P{^Blk=sorasompeng}', "");
Expect(1, 69887, '\p{Blk=-SORA_Sompeng}', "");
Expect(0, 69887, '\p{^Blk=-SORA_Sompeng}', "");
Expect(0, 69887, '\P{Blk=-SORA_Sompeng}', "");
Expect(1, 69887, '\P{^Blk=-SORA_Sompeng}', "");
Expect(0, 69888, '\p{Blk=-SORA_Sompeng}', "");
Expect(1, 69888, '\p{^Blk=-SORA_Sompeng}', "");
Expect(1, 69888, '\P{Blk=-SORA_Sompeng}', "");
Expect(0, 69888, '\P{^Blk=-SORA_Sompeng}', "");
Error('\p{Is_Block=	/a/sora_Sompeng}');
Error('\P{Is_Block=	/a/sora_Sompeng}');
Expect(1, 69887, '\p{Is_Block=sorasompeng}', "");
Expect(0, 69887, '\p{^Is_Block=sorasompeng}', "");
Expect(0, 69887, '\P{Is_Block=sorasompeng}', "");
Expect(1, 69887, '\P{^Is_Block=sorasompeng}', "");
Expect(0, 69888, '\p{Is_Block=sorasompeng}', "");
Expect(1, 69888, '\p{^Is_Block=sorasompeng}', "");
Expect(1, 69888, '\P{Is_Block=sorasompeng}', "");
Expect(0, 69888, '\P{^Is_Block=sorasompeng}', "");
Expect(1, 69887, '\p{Is_Block=	_sora_Sompeng}', "");
Expect(0, 69887, '\p{^Is_Block=	_sora_Sompeng}', "");
Expect(0, 69887, '\P{Is_Block=	_sora_Sompeng}', "");
Expect(1, 69887, '\P{^Is_Block=	_sora_Sompeng}', "");
Expect(0, 69888, '\p{Is_Block=	_sora_Sompeng}', "");
Expect(1, 69888, '\p{^Is_Block=	_sora_Sompeng}', "");
Expect(1, 69888, '\P{Is_Block=	_sora_Sompeng}', "");
Expect(0, 69888, '\P{^Is_Block=	_sora_Sompeng}', "");
Error('\p{Is_Blk= Sora_Sompeng:=}');
Error('\P{Is_Blk= Sora_Sompeng:=}');
Expect(1, 69887, '\p{Is_Blk=sorasompeng}', "");
Expect(0, 69887, '\p{^Is_Blk=sorasompeng}', "");
Expect(0, 69887, '\P{Is_Blk=sorasompeng}', "");
Expect(1, 69887, '\P{^Is_Blk=sorasompeng}', "");
Expect(0, 69888, '\p{Is_Blk=sorasompeng}', "");
Expect(1, 69888, '\p{^Is_Blk=sorasompeng}', "");
Expect(1, 69888, '\P{Is_Blk=sorasompeng}', "");
Expect(0, 69888, '\P{^Is_Blk=sorasompeng}', "");
Expect(1, 69887, '\p{Is_Blk=	sora_sompeng}', "");
Expect(0, 69887, '\p{^Is_Blk=	sora_sompeng}', "");
Expect(0, 69887, '\P{Is_Blk=	sora_sompeng}', "");
Expect(1, 69887, '\P{^Is_Blk=	sora_sompeng}', "");
Expect(0, 69888, '\p{Is_Blk=	sora_sompeng}', "");
Expect(1, 69888, '\p{^Is_Blk=	sora_sompeng}', "");
Expect(1, 69888, '\P{Is_Blk=	sora_sompeng}', "");
Expect(0, 69888, '\P{^Is_Blk=	sora_sompeng}', "");
Error('\p{Block=	_SPECIALS/a/}');
Error('\P{Block=	_SPECIALS/a/}');
Expect(1, 65520, '\p{Block: specials}', "");
Expect(0, 65520, '\p{^Block: specials}', "");
Expect(0, 65520, '\P{Block: specials}', "");
Expect(1, 65520, '\P{^Block: specials}', "");
Expect(0, 65536, '\p{Block: specials}', "");
Expect(1, 65536, '\p{^Block: specials}', "");
Expect(1, 65536, '\P{Block: specials}', "");
Expect(0, 65536, '\P{^Block: specials}', "");
Expect(1, 65520, '\p{Block:   	-specials}', "");
Expect(0, 65520, '\p{^Block:   	-specials}', "");
Expect(0, 65520, '\P{Block:   	-specials}', "");
Expect(1, 65520, '\P{^Block:   	-specials}', "");
Expect(0, 65536, '\p{Block:   	-specials}', "");
Expect(1, 65536, '\p{^Block:   	-specials}', "");
Expect(1, 65536, '\P{Block:   	-specials}', "");
Expect(0, 65536, '\P{^Block:   	-specials}', "");
Error('\p{Blk:	_:=SPECIALS}');
Error('\P{Blk:	_:=SPECIALS}');
Expect(1, 65520, '\p{Blk=specials}', "");
Expect(0, 65520, '\p{^Blk=specials}', "");
Expect(0, 65520, '\P{Blk=specials}', "");
Expect(1, 65520, '\P{^Blk=specials}', "");
Expect(0, 65536, '\p{Blk=specials}', "");
Expect(1, 65536, '\p{^Blk=specials}', "");
Expect(1, 65536, '\P{Blk=specials}', "");
Expect(0, 65536, '\P{^Blk=specials}', "");
Expect(1, 65520, '\p{Blk=- Specials}', "");
Expect(0, 65520, '\p{^Blk=- Specials}', "");
Expect(0, 65520, '\P{Blk=- Specials}', "");
Expect(1, 65520, '\P{^Blk=- Specials}', "");
Expect(0, 65536, '\p{Blk=- Specials}', "");
Expect(1, 65536, '\p{^Blk=- Specials}', "");
Expect(1, 65536, '\P{Blk=- Specials}', "");
Expect(0, 65536, '\P{^Blk=- Specials}', "");
Error('\p{Is_Block=:=- Specials}');
Error('\P{Is_Block=:=- Specials}');
Expect(1, 65520, '\p{Is_Block=specials}', "");
Expect(0, 65520, '\p{^Is_Block=specials}', "");
Expect(0, 65520, '\P{Is_Block=specials}', "");
Expect(1, 65520, '\P{^Is_Block=specials}', "");
Expect(0, 65536, '\p{Is_Block=specials}', "");
Expect(1, 65536, '\p{^Is_Block=specials}', "");
Expect(1, 65536, '\P{Is_Block=specials}', "");
Expect(0, 65536, '\P{^Is_Block=specials}', "");
Expect(1, 65520, '\p{Is_Block=_ Specials}', "");
Expect(0, 65520, '\p{^Is_Block=_ Specials}', "");
Expect(0, 65520, '\P{Is_Block=_ Specials}', "");
Expect(1, 65520, '\P{^Is_Block=_ Specials}', "");
Expect(0, 65536, '\p{Is_Block=_ Specials}', "");
Expect(1, 65536, '\p{^Is_Block=_ Specials}', "");
Expect(1, 65536, '\P{Is_Block=_ Specials}', "");
Expect(0, 65536, '\P{^Is_Block=_ Specials}', "");
Error('\p{Is_Blk=:=	Specials}');
Error('\P{Is_Blk=:=	Specials}');
Expect(1, 65520, '\p{Is_Blk=specials}', "");
Expect(0, 65520, '\p{^Is_Blk=specials}', "");
Expect(0, 65520, '\P{Is_Blk=specials}', "");
Expect(1, 65520, '\P{^Is_Blk=specials}', "");
Expect(0, 65536, '\p{Is_Blk=specials}', "");
Expect(1, 65536, '\p{^Is_Blk=specials}', "");
Expect(1, 65536, '\P{Is_Blk=specials}', "");
Expect(0, 65536, '\P{^Is_Blk=specials}', "");
Expect(1, 65520, '\p{Is_Blk=_-Specials}', "");
Expect(0, 65520, '\p{^Is_Blk=_-Specials}', "");
Expect(0, 65520, '\P{Is_Blk=_-Specials}', "");
Expect(1, 65520, '\P{^Is_Blk=_-Specials}', "");
Expect(0, 65536, '\p{Is_Blk=_-Specials}', "");
Expect(1, 65536, '\p{^Is_Blk=_-Specials}', "");
Expect(1, 65536, '\P{Is_Blk=_-Specials}', "");
Expect(0, 65536, '\P{^Is_Blk=_-Specials}', "");
Error('\p{Block=-/a/SUNDANESE}');
Error('\P{Block=-/a/SUNDANESE}');
Expect(1, 7103, '\p{Block=sundanese}', "");
Expect(0, 7103, '\p{^Block=sundanese}', "");
Expect(0, 7103, '\P{Block=sundanese}', "");
Expect(1, 7103, '\P{^Block=sundanese}', "");
Expect(0, 7104, '\p{Block=sundanese}', "");
Expect(1, 7104, '\p{^Block=sundanese}', "");
Expect(1, 7104, '\P{Block=sundanese}', "");
Expect(0, 7104, '\P{^Block=sundanese}', "");
Expect(1, 7103, '\p{Block=- sundanese}', "");
Expect(0, 7103, '\p{^Block=- sundanese}', "");
Expect(0, 7103, '\P{Block=- sundanese}', "");
Expect(1, 7103, '\P{^Block=- sundanese}', "");
Expect(0, 7104, '\p{Block=- sundanese}', "");
Expect(1, 7104, '\p{^Block=- sundanese}', "");
Expect(1, 7104, '\P{Block=- sundanese}', "");
Expect(0, 7104, '\P{^Block=- sundanese}', "");
Error('\p{Blk=sundanese/a/}');
Error('\P{Blk=sundanese/a/}');
Expect(1, 7103, '\p{Blk=sundanese}', "");
Expect(0, 7103, '\p{^Blk=sundanese}', "");
Expect(0, 7103, '\P{Blk=sundanese}', "");
Expect(1, 7103, '\P{^Blk=sundanese}', "");
Expect(0, 7104, '\p{Blk=sundanese}', "");
Expect(1, 7104, '\p{^Blk=sundanese}', "");
Expect(1, 7104, '\P{Blk=sundanese}', "");
Expect(0, 7104, '\P{^Blk=sundanese}', "");
Expect(1, 7103, '\p{Blk=	 sundanese}', "");
Expect(0, 7103, '\p{^Blk=	 sundanese}', "");
Expect(0, 7103, '\P{Blk=	 sundanese}', "");
Expect(1, 7103, '\P{^Blk=	 sundanese}', "");
Expect(0, 7104, '\p{Blk=	 sundanese}', "");
Expect(1, 7104, '\p{^Blk=	 sundanese}', "");
Expect(1, 7104, '\P{Blk=	 sundanese}', "");
Expect(0, 7104, '\P{^Blk=	 sundanese}', "");
Error('\p{Is_Block=/a/_	sundanese}');
Error('\P{Is_Block=/a/_	sundanese}');
Expect(1, 7103, '\p{Is_Block=sundanese}', "");
Expect(0, 7103, '\p{^Is_Block=sundanese}', "");
Expect(0, 7103, '\P{Is_Block=sundanese}', "");
Expect(1, 7103, '\P{^Is_Block=sundanese}', "");
Expect(0, 7104, '\p{Is_Block=sundanese}', "");
Expect(1, 7104, '\p{^Is_Block=sundanese}', "");
Expect(1, 7104, '\P{Is_Block=sundanese}', "");
Expect(0, 7104, '\P{^Is_Block=sundanese}', "");
Expect(1, 7103, '\p{Is_Block=_-Sundanese}', "");
Expect(0, 7103, '\p{^Is_Block=_-Sundanese}', "");
Expect(0, 7103, '\P{Is_Block=_-Sundanese}', "");
Expect(1, 7103, '\P{^Is_Block=_-Sundanese}', "");
Expect(0, 7104, '\p{Is_Block=_-Sundanese}', "");
Expect(1, 7104, '\p{^Is_Block=_-Sundanese}', "");
Expect(1, 7104, '\P{Is_Block=_-Sundanese}', "");
Expect(0, 7104, '\P{^Is_Block=_-Sundanese}', "");
Error('\p{Is_Blk= :=sundanese}');
Error('\P{Is_Blk= :=sundanese}');
Expect(1, 7103, '\p{Is_Blk=sundanese}', "");
Expect(0, 7103, '\p{^Is_Blk=sundanese}', "");
Expect(0, 7103, '\P{Is_Blk=sundanese}', "");
Expect(1, 7103, '\P{^Is_Blk=sundanese}', "");
Expect(0, 7104, '\p{Is_Blk=sundanese}', "");
Expect(1, 7104, '\p{^Is_Blk=sundanese}', "");
Expect(1, 7104, '\P{Is_Blk=sundanese}', "");
Expect(0, 7104, '\P{^Is_Blk=sundanese}', "");
Expect(1, 7103, '\p{Is_Blk=	-SUNDANESE}', "");
Expect(0, 7103, '\p{^Is_Blk=	-SUNDANESE}', "");
Expect(0, 7103, '\P{Is_Blk=	-SUNDANESE}', "");
Expect(1, 7103, '\P{^Is_Blk=	-SUNDANESE}', "");
Expect(0, 7104, '\p{Is_Blk=	-SUNDANESE}', "");
Expect(1, 7104, '\p{^Is_Blk=	-SUNDANESE}', "");
Expect(1, 7104, '\P{Is_Blk=	-SUNDANESE}', "");
Expect(0, 7104, '\P{^Is_Blk=	-SUNDANESE}', "");
Error('\p{Block=	:=Sundanese_supplement}');
Error('\P{Block=	:=Sundanese_supplement}');
Expect(1, 7375, '\p{Block=sundanesesupplement}', "");
Expect(0, 7375, '\p{^Block=sundanesesupplement}', "");
Expect(0, 7375, '\P{Block=sundanesesupplement}', "");
Expect(1, 7375, '\P{^Block=sundanesesupplement}', "");
Expect(0, 7376, '\p{Block=sundanesesupplement}', "");
Expect(1, 7376, '\p{^Block=sundanesesupplement}', "");
Expect(1, 7376, '\P{Block=sundanesesupplement}', "");
Expect(0, 7376, '\P{^Block=sundanesesupplement}', "");
Expect(1, 7375, '\p{Block=_sundanese_SUPPLEMENT}', "");
Expect(0, 7375, '\p{^Block=_sundanese_SUPPLEMENT}', "");
Expect(0, 7375, '\P{Block=_sundanese_SUPPLEMENT}', "");
Expect(1, 7375, '\P{^Block=_sundanese_SUPPLEMENT}', "");
Expect(0, 7376, '\p{Block=_sundanese_SUPPLEMENT}', "");
Expect(1, 7376, '\p{^Block=_sundanese_SUPPLEMENT}', "");
Expect(1, 7376, '\P{Block=_sundanese_SUPPLEMENT}', "");
Expect(0, 7376, '\P{^Block=_sundanese_SUPPLEMENT}', "");
Error('\p{Blk=-/a/sundanese_SUP}');
Error('\P{Blk=-/a/sundanese_SUP}');
Expect(1, 7375, '\p{Blk=sundanesesup}', "");
Expect(0, 7375, '\p{^Blk=sundanesesup}', "");
Expect(0, 7375, '\P{Blk=sundanesesup}', "");
Expect(1, 7375, '\P{^Blk=sundanesesup}', "");
Expect(0, 7376, '\p{Blk=sundanesesup}', "");
Expect(1, 7376, '\p{^Blk=sundanesesup}', "");
Expect(1, 7376, '\P{Blk=sundanesesup}', "");
Expect(0, 7376, '\P{^Blk=sundanesesup}', "");
Expect(1, 7375, '\p{Blk= -Sundanese_Sup}', "");
Expect(0, 7375, '\p{^Blk= -Sundanese_Sup}', "");
Expect(0, 7375, '\P{Blk= -Sundanese_Sup}', "");
Expect(1, 7375, '\P{^Blk= -Sundanese_Sup}', "");
Expect(0, 7376, '\p{Blk= -Sundanese_Sup}', "");
Expect(1, 7376, '\p{^Blk= -Sundanese_Sup}', "");
Expect(1, 7376, '\P{Blk= -Sundanese_Sup}', "");
Expect(0, 7376, '\P{^Blk= -Sundanese_Sup}', "");
Error('\p{Is_Block=-Sundanese_supplement:=}');
Error('\P{Is_Block=-Sundanese_supplement:=}');
Expect(1, 7375, '\p{Is_Block=sundanesesupplement}', "");
Expect(0, 7375, '\p{^Is_Block=sundanesesupplement}', "");
Expect(0, 7375, '\P{Is_Block=sundanesesupplement}', "");
Expect(1, 7375, '\P{^Is_Block=sundanesesupplement}', "");
Expect(0, 7376, '\p{Is_Block=sundanesesupplement}', "");
Expect(1, 7376, '\p{^Is_Block=sundanesesupplement}', "");
Expect(1, 7376, '\P{Is_Block=sundanesesupplement}', "");
Expect(0, 7376, '\P{^Is_Block=sundanesesupplement}', "");
Expect(1, 7375, '\p{Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(0, 7375, '\p{^Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(0, 7375, '\P{Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(1, 7375, '\P{^Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(0, 7376, '\p{Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(1, 7376, '\p{^Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(1, 7376, '\P{Is_Block=  Sundanese_SUPPLEMENT}', "");
Expect(0, 7376, '\P{^Is_Block=  Sundanese_SUPPLEMENT}', "");
Error('\p{Is_Blk=	/a/SUNDANESE_SUP}');
Error('\P{Is_Blk=	/a/SUNDANESE_SUP}');
Expect(1, 7375, '\p{Is_Blk=sundanesesup}', "");
Expect(0, 7375, '\p{^Is_Blk=sundanesesup}', "");
Expect(0, 7375, '\P{Is_Blk=sundanesesup}', "");
Expect(1, 7375, '\P{^Is_Blk=sundanesesup}', "");
Expect(0, 7376, '\p{Is_Blk=sundanesesup}', "");
Expect(1, 7376, '\p{^Is_Blk=sundanesesup}', "");
Expect(1, 7376, '\P{Is_Blk=sundanesesup}', "");
Expect(0, 7376, '\P{^Is_Blk=sundanesesup}', "");
Expect(1, 7375, '\p{Is_Blk=	SUNDANESE_Sup}', "");
Expect(0, 7375, '\p{^Is_Blk=	SUNDANESE_Sup}', "");
Expect(0, 7375, '\P{Is_Blk=	SUNDANESE_Sup}', "");
Expect(1, 7375, '\P{^Is_Blk=	SUNDANESE_Sup}', "");
Expect(0, 7376, '\p{Is_Blk=	SUNDANESE_Sup}', "");
Expect(1, 7376, '\p{^Is_Blk=	SUNDANESE_Sup}', "");
Expect(1, 7376, '\P{Is_Blk=	SUNDANESE_Sup}', "");
Expect(0, 7376, '\P{^Is_Blk=	SUNDANESE_Sup}', "");
Error('\p{Block=:=	Supplemental_arrows_A}');
Error('\P{Block=:=	Supplemental_arrows_A}');
Expect(1, 10239, '\p{Block:	supplementalarrowsa}', "");
Expect(0, 10239, '\p{^Block:	supplementalarrowsa}', "");
Expect(0, 10239, '\P{Block:	supplementalarrowsa}', "");
Expect(1, 10239, '\P{^Block:	supplementalarrowsa}', "");
Expect(0, 10240, '\p{Block:	supplementalarrowsa}', "");
Expect(1, 10240, '\p{^Block:	supplementalarrowsa}', "");
Expect(1, 10240, '\P{Block:	supplementalarrowsa}', "");
Expect(0, 10240, '\P{^Block:	supplementalarrowsa}', "");
Expect(1, 10239, '\p{Block= 	Supplemental_Arrows_a}', "");
Expect(0, 10239, '\p{^Block= 	Supplemental_Arrows_a}', "");
Expect(0, 10239, '\P{Block= 	Supplemental_Arrows_a}', "");
Expect(1, 10239, '\P{^Block= 	Supplemental_Arrows_a}', "");
Expect(0, 10240, '\p{Block= 	Supplemental_Arrows_a}', "");
Expect(1, 10240, '\p{^Block= 	Supplemental_Arrows_a}', "");
Expect(1, 10240, '\P{Block= 	Supplemental_Arrows_a}', "");
Expect(0, 10240, '\P{^Block= 	Supplemental_Arrows_a}', "");
Error('\p{Blk=/a/- Sup_arrows_a}');
Error('\P{Blk=/a/- Sup_arrows_a}');
Expect(1, 10239, '\p{Blk=suparrowsa}', "");
Expect(0, 10239, '\p{^Blk=suparrowsa}', "");
Expect(0, 10239, '\P{Blk=suparrowsa}', "");
Expect(1, 10239, '\P{^Blk=suparrowsa}', "");
Expect(0, 10240, '\p{Blk=suparrowsa}', "");
Expect(1, 10240, '\p{^Blk=suparrowsa}', "");
Expect(1, 10240, '\P{Blk=suparrowsa}', "");
Expect(0, 10240, '\P{^Blk=suparrowsa}', "");
Expect(1, 10239, '\p{Blk=_ Sup_Arrows_a}', "");
Expect(0, 10239, '\p{^Blk=_ Sup_Arrows_a}', "");
Expect(0, 10239, '\P{Blk=_ Sup_Arrows_a}', "");
Expect(1, 10239, '\P{^Blk=_ Sup_Arrows_a}', "");
Expect(0, 10240, '\p{Blk=_ Sup_Arrows_a}', "");
Expect(1, 10240, '\p{^Blk=_ Sup_Arrows_a}', "");
Expect(1, 10240, '\P{Blk=_ Sup_Arrows_a}', "");
Expect(0, 10240, '\P{^Blk=_ Sup_Arrows_a}', "");
Error('\p{Is_Block= :=SUPPLEMENTAL_ARROWS_A}');
Error('\P{Is_Block= :=SUPPLEMENTAL_ARROWS_A}');
Expect(1, 10239, '\p{Is_Block:   supplementalarrowsa}', "");
Expect(0, 10239, '\p{^Is_Block:   supplementalarrowsa}', "");
Expect(0, 10239, '\P{Is_Block:   supplementalarrowsa}', "");
Expect(1, 10239, '\P{^Is_Block:   supplementalarrowsa}', "");
Expect(0, 10240, '\p{Is_Block:   supplementalarrowsa}', "");
Expect(1, 10240, '\p{^Is_Block:   supplementalarrowsa}', "");
Expect(1, 10240, '\P{Is_Block:   supplementalarrowsa}', "");
Expect(0, 10240, '\P{^Is_Block:   supplementalarrowsa}', "");
Expect(1, 10239, '\p{Is_Block=	supplemental_ARROWS_A}', "");
Expect(0, 10239, '\p{^Is_Block=	supplemental_ARROWS_A}', "");
Expect(0, 10239, '\P{Is_Block=	supplemental_ARROWS_A}', "");
Expect(1, 10239, '\P{^Is_Block=	supplemental_ARROWS_A}', "");
Expect(0, 10240, '\p{Is_Block=	supplemental_ARROWS_A}', "");
Expect(1, 10240, '\p{^Is_Block=	supplemental_ARROWS_A}', "");
Expect(1, 10240, '\P{Is_Block=	supplemental_ARROWS_A}', "");
Expect(0, 10240, '\P{^Is_Block=	supplemental_ARROWS_A}', "");
Error('\p{Is_Blk=-Sup_ARROWS_A:=}');
Error('\P{Is_Blk=-Sup_ARROWS_A:=}');
Expect(1, 10239, '\p{Is_Blk:   suparrowsa}', "");
Expect(0, 10239, '\p{^Is_Blk:   suparrowsa}', "");
Expect(0, 10239, '\P{Is_Blk:   suparrowsa}', "");
Expect(1, 10239, '\P{^Is_Blk:   suparrowsa}', "");
Expect(0, 10240, '\p{Is_Blk:   suparrowsa}', "");
Expect(1, 10240, '\p{^Is_Blk:   suparrowsa}', "");
Expect(1, 10240, '\P{Is_Blk:   suparrowsa}', "");
Expect(0, 10240, '\P{^Is_Blk:   suparrowsa}', "");
Expect(1, 10239, '\p{Is_Blk=	 sup_Arrows_A}', "");
Expect(0, 10239, '\p{^Is_Blk=	 sup_Arrows_A}', "");
Expect(0, 10239, '\P{Is_Blk=	 sup_Arrows_A}', "");
Expect(1, 10239, '\P{^Is_Blk=	 sup_Arrows_A}', "");
Expect(0, 10240, '\p{Is_Blk=	 sup_Arrows_A}', "");
Expect(1, 10240, '\p{^Is_Blk=	 sup_Arrows_A}', "");
Expect(1, 10240, '\P{Is_Blk=	 sup_Arrows_A}', "");
Expect(0, 10240, '\P{^Is_Blk=	 sup_Arrows_A}', "");
Error('\p{Block=:=-SUPPLEMENTAL_Arrows_B}');
Error('\P{Block=:=-SUPPLEMENTAL_Arrows_B}');
Expect(1, 10623, '\p{Block=supplementalarrowsb}', "");
Expect(0, 10623, '\p{^Block=supplementalarrowsb}', "");
Expect(0, 10623, '\P{Block=supplementalarrowsb}', "");
Expect(1, 10623, '\P{^Block=supplementalarrowsb}', "");
Expect(0, 10624, '\p{Block=supplementalarrowsb}', "");
Expect(1, 10624, '\p{^Block=supplementalarrowsb}', "");
Expect(1, 10624, '\P{Block=supplementalarrowsb}', "");
Expect(0, 10624, '\P{^Block=supplementalarrowsb}', "");
Expect(1, 10623, '\p{Block=_	Supplemental_Arrows_B}', "");
Expect(0, 10623, '\p{^Block=_	Supplemental_Arrows_B}', "");
Expect(0, 10623, '\P{Block=_	Supplemental_Arrows_B}', "");
Expect(1, 10623, '\P{^Block=_	Supplemental_Arrows_B}', "");
Expect(0, 10624, '\p{Block=_	Supplemental_Arrows_B}', "");
Expect(1, 10624, '\p{^Block=_	Supplemental_Arrows_B}', "");
Expect(1, 10624, '\P{Block=_	Supplemental_Arrows_B}', "");
Expect(0, 10624, '\P{^Block=_	Supplemental_Arrows_B}', "");
Error('\p{Blk: := 	SUP_Arrows_B}');
Error('\P{Blk: := 	SUP_Arrows_B}');
Expect(1, 10623, '\p{Blk=suparrowsb}', "");
Expect(0, 10623, '\p{^Blk=suparrowsb}', "");
Expect(0, 10623, '\P{Blk=suparrowsb}', "");
Expect(1, 10623, '\P{^Blk=suparrowsb}', "");
Expect(0, 10624, '\p{Blk=suparrowsb}', "");
Expect(1, 10624, '\p{^Blk=suparrowsb}', "");
Expect(1, 10624, '\P{Blk=suparrowsb}', "");
Expect(0, 10624, '\P{^Blk=suparrowsb}', "");
Expect(1, 10623, '\p{Blk=-Sup_Arrows_B}', "");
Expect(0, 10623, '\p{^Blk=-Sup_Arrows_B}', "");
Expect(0, 10623, '\P{Blk=-Sup_Arrows_B}', "");
Expect(1, 10623, '\P{^Blk=-Sup_Arrows_B}', "");
Expect(0, 10624, '\p{Blk=-Sup_Arrows_B}', "");
Expect(1, 10624, '\p{^Blk=-Sup_Arrows_B}', "");
Expect(1, 10624, '\P{Blk=-Sup_Arrows_B}', "");
Expect(0, 10624, '\P{^Blk=-Sup_Arrows_B}', "");
Error('\p{Is_Block=		SUPPLEMENTAL_arrows_B:=}');
Error('\P{Is_Block=		SUPPLEMENTAL_arrows_B:=}');
Expect(1, 10623, '\p{Is_Block=supplementalarrowsb}', "");
Expect(0, 10623, '\p{^Is_Block=supplementalarrowsb}', "");
Expect(0, 10623, '\P{Is_Block=supplementalarrowsb}', "");
Expect(1, 10623, '\P{^Is_Block=supplementalarrowsb}', "");
Expect(0, 10624, '\p{Is_Block=supplementalarrowsb}', "");
Expect(1, 10624, '\p{^Is_Block=supplementalarrowsb}', "");
Expect(1, 10624, '\P{Is_Block=supplementalarrowsb}', "");
Expect(0, 10624, '\P{^Is_Block=supplementalarrowsb}', "");
Expect(1, 10623, '\p{Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10623, '\p{^Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10623, '\P{Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(1, 10623, '\P{^Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10624, '\p{Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(1, 10624, '\p{^Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(1, 10624, '\P{Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10624, '\P{^Is_Block=	SUPPLEMENTAL_Arrows_B}', "");
Error('\p{Is_Blk=	SUP_arrows_B/a/}');
Error('\P{Is_Blk=	SUP_arrows_B/a/}');
Expect(1, 10623, '\p{Is_Blk=suparrowsb}', "");
Expect(0, 10623, '\p{^Is_Blk=suparrowsb}', "");
Expect(0, 10623, '\P{Is_Blk=suparrowsb}', "");
Expect(1, 10623, '\P{^Is_Blk=suparrowsb}', "");
Expect(0, 10624, '\p{Is_Blk=suparrowsb}', "");
Expect(1, 10624, '\p{^Is_Blk=suparrowsb}', "");
Expect(1, 10624, '\P{Is_Blk=suparrowsb}', "");
Expect(0, 10624, '\P{^Is_Blk=suparrowsb}', "");
Expect(1, 10623, '\p{Is_Blk=	SUP_Arrows_B}', "");
Expect(0, 10623, '\p{^Is_Blk=	SUP_Arrows_B}', "");
Expect(0, 10623, '\P{Is_Blk=	SUP_Arrows_B}', "");
Expect(1, 10623, '\P{^Is_Blk=	SUP_Arrows_B}', "");
Expect(0, 10624, '\p{Is_Blk=	SUP_Arrows_B}', "");
Expect(1, 10624, '\p{^Is_Blk=	SUP_Arrows_B}', "");
Expect(1, 10624, '\P{Is_Blk=	SUP_Arrows_B}', "");
Expect(0, 10624, '\P{^Is_Blk=	SUP_Arrows_B}', "");
Error('\p{Block:	-_SUPPLEMENTAL_mathematical_operators/a/}');
Error('\P{Block:	-_SUPPLEMENTAL_mathematical_operators/a/}');
Expect(1, 11007, '\p{Block=supplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^Block=supplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{Block=supplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^Block=supplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{Block=supplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^Block=supplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{Block=supplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^Block=supplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(0, 11007, '\p{^Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(0, 11007, '\P{Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(1, 11007, '\P{^Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(0, 11008, '\p{Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(1, 11008, '\p{^Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(1, 11008, '\P{Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Expect(0, 11008, '\P{^Block=__SUPPLEMENTAL_Mathematical_Operators}', "");
Error('\p{Blk=:=	SUP_Math_OPERATORS}');
Error('\P{Blk=:=	SUP_Math_OPERATORS}');
Expect(1, 11007, '\p{Blk=supmathoperators}', "");
Expect(0, 11007, '\p{^Blk=supmathoperators}', "");
Expect(0, 11007, '\P{Blk=supmathoperators}', "");
Expect(1, 11007, '\P{^Blk=supmathoperators}', "");
Expect(0, 11008, '\p{Blk=supmathoperators}', "");
Expect(1, 11008, '\p{^Blk=supmathoperators}', "");
Expect(1, 11008, '\P{Blk=supmathoperators}', "");
Expect(0, 11008, '\P{^Blk=supmathoperators}', "");
Expect(1, 11007, '\p{Blk= SUP_Math_Operators}', "");
Expect(0, 11007, '\p{^Blk= SUP_Math_Operators}', "");
Expect(0, 11007, '\P{Blk= SUP_Math_Operators}', "");
Expect(1, 11007, '\P{^Blk= SUP_Math_Operators}', "");
Expect(0, 11008, '\p{Blk= SUP_Math_Operators}', "");
Expect(1, 11008, '\p{^Blk= SUP_Math_Operators}', "");
Expect(1, 11008, '\P{Blk= SUP_Math_Operators}', "");
Expect(0, 11008, '\P{^Blk= SUP_Math_Operators}', "");
Error('\p{Is_Block=_supplemental_MATHEMATICAL_OPERATORS/a/}');
Error('\P{Is_Block=_supplemental_MATHEMATICAL_OPERATORS/a/}');
Expect(1, 11007, '\p{Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{Is_Block=supplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^Is_Block=supplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(0, 11007, '\p{^Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(0, 11007, '\P{Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(1, 11007, '\P{^Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(0, 11008, '\p{Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(1, 11008, '\p{^Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(1, 11008, '\P{Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Expect(0, 11008, '\P{^Is_Block:  	Supplemental_MATHEMATICAL_operators}', "");
Error('\p{Is_Blk=/a/		Sup_Math_Operators}');
Error('\P{Is_Blk=/a/		Sup_Math_Operators}');
Expect(1, 11007, '\p{Is_Blk=supmathoperators}', "");
Expect(0, 11007, '\p{^Is_Blk=supmathoperators}', "");
Expect(0, 11007, '\P{Is_Blk=supmathoperators}', "");
Expect(1, 11007, '\P{^Is_Blk=supmathoperators}', "");
Expect(0, 11008, '\p{Is_Blk=supmathoperators}', "");
Expect(1, 11008, '\p{^Is_Blk=supmathoperators}', "");
Expect(1, 11008, '\P{Is_Blk=supmathoperators}', "");
Expect(0, 11008, '\P{^Is_Blk=supmathoperators}', "");
Expect(1, 11007, '\p{Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(0, 11007, '\p{^Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(0, 11007, '\P{Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(1, 11007, '\P{^Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(0, 11008, '\p{Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(1, 11008, '\p{^Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(1, 11008, '\P{Is_Blk=		Sup_Math_OPERATORS}', "");
Expect(0, 11008, '\P{^Is_Blk=		Sup_Math_OPERATORS}', "");
Error('\p{Block=__supplementary_Private_Use_Area_A/a/}');
Error('\P{Block=__supplementary_Private_Use_Area_A/a/}');
Expect(1, 983040, '\p{Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(0, 983040, '\p{^Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(0, 983040, '\P{Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(1, 983040, '\P{^Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(0, 1048576, '\p{Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(1, 1048576, '\p{^Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(1, 1048576, '\P{Block=	-Supplementary_private_Use_AREA_A}', "");
Expect(0, 1048576, '\P{^Block=	-Supplementary_private_Use_AREA_A}', "");
Error('\p{Blk=/a/	 SUP_PUA_A}');
Error('\P{Blk=/a/	 SUP_PUA_A}');
Expect(1, 983040, '\p{Blk=suppuaa}', "");
Expect(0, 983040, '\p{^Blk=suppuaa}', "");
Expect(0, 983040, '\P{Blk=suppuaa}', "");
Expect(1, 983040, '\P{^Blk=suppuaa}', "");
Expect(0, 1048576, '\p{Blk=suppuaa}', "");
Expect(1, 1048576, '\p{^Blk=suppuaa}', "");
Expect(1, 1048576, '\P{Blk=suppuaa}', "");
Expect(0, 1048576, '\P{^Blk=suppuaa}', "");
Expect(1, 983040, '\p{Blk=	 sup_PUA_A}', "");
Expect(0, 983040, '\p{^Blk=	 sup_PUA_A}', "");
Expect(0, 983040, '\P{Blk=	 sup_PUA_A}', "");
Expect(1, 983040, '\P{^Blk=	 sup_PUA_A}', "");
Expect(0, 1048576, '\p{Blk=	 sup_PUA_A}', "");
Expect(1, 1048576, '\p{^Blk=	 sup_PUA_A}', "");
Expect(1, 1048576, '\P{Blk=	 sup_PUA_A}', "");
Expect(0, 1048576, '\P{^Blk=	 sup_PUA_A}', "");
Error('\p{Is_Block=-/a/Supplementary_Private_Use_area_a}');
Error('\P{Is_Block=-/a/Supplementary_Private_Use_area_a}');
Expect(1, 983040, '\p{Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{Is_Block=supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^Is_Block=supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(0, 983040, '\p{^Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(0, 983040, '\P{Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(1, 983040, '\P{^Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(0, 1048576, '\p{Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(1, 1048576, '\p{^Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(1, 1048576, '\P{Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Expect(0, 1048576, '\P{^Is_Block=	_SUPPLEMENTARY_PRIVATE_USE_area_A}', "");
Error('\p{Is_Blk=	/a/SUP_PUA_A}');
Error('\P{Is_Blk=	/a/SUP_PUA_A}');
Expect(1, 983040, '\p{Is_Blk=suppuaa}', "");
Expect(0, 983040, '\p{^Is_Blk=suppuaa}', "");
Expect(0, 983040, '\P{Is_Blk=suppuaa}', "");
Expect(1, 983040, '\P{^Is_Blk=suppuaa}', "");
Expect(0, 1048576, '\p{Is_Blk=suppuaa}', "");
Expect(1, 1048576, '\p{^Is_Blk=suppuaa}', "");
Expect(1, 1048576, '\P{Is_Blk=suppuaa}', "");
Expect(0, 1048576, '\P{^Is_Blk=suppuaa}', "");
Expect(1, 983040, '\p{Is_Blk=_SUP_PUA_a}', "");
Expect(0, 983040, '\p{^Is_Blk=_SUP_PUA_a}', "");
Expect(0, 983040, '\P{Is_Blk=_SUP_PUA_a}', "");
Expect(1, 983040, '\P{^Is_Blk=_SUP_PUA_a}', "");
Expect(0, 1048576, '\p{Is_Blk=_SUP_PUA_a}', "");
Expect(1, 1048576, '\p{^Is_Blk=_SUP_PUA_a}', "");
Expect(1, 1048576, '\P{Is_Blk=_SUP_PUA_a}', "");
Expect(0, 1048576, '\P{^Is_Blk=_SUP_PUA_a}', "");
Error('\p{Block=_-supplementary_private_use_AREA_B/a/}');
Error('\P{Block=_-supplementary_private_use_AREA_B/a/}');
Expect(1, 1048576, '\p{Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\p{Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\P{Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{Block=	_supplementary_private_Use_Area_B}', "");
Expect(0, 1048576, '\p{^Block=	_supplementary_private_Use_Area_B}', "");
Expect(0, 1048576, '\P{Block=	_supplementary_private_Use_Area_B}', "");
Expect(1, 1048576, '\P{^Block=	_supplementary_private_Use_Area_B}', "");
Expect(0, 1, '\p{Block=	_supplementary_private_Use_Area_B}', "");
Expect(1, 1, '\p{^Block=	_supplementary_private_Use_Area_B}', "");
Expect(1, 1, '\P{Block=	_supplementary_private_Use_Area_B}', "");
Expect(0, 1, '\P{^Block=	_supplementary_private_Use_Area_B}', "");
Error('\p{Blk=:=- Sup_pua_B}');
Error('\P{Blk=:=- Sup_pua_B}');
Expect(1, 1048576, '\p{Blk=suppuab}', "");
Expect(0, 1048576, '\p{^Blk=suppuab}', "");
Expect(0, 1048576, '\P{Blk=suppuab}', "");
Expect(1, 1048576, '\P{^Blk=suppuab}', "");
Expect(0, 1, '\p{Blk=suppuab}', "");
Expect(1, 1, '\p{^Blk=suppuab}', "");
Expect(1, 1, '\P{Blk=suppuab}', "");
Expect(0, 1, '\P{^Blk=suppuab}', "");
Expect(1, 1048576, '\p{Blk=-Sup_PUA_B}', "");
Expect(0, 1048576, '\p{^Blk=-Sup_PUA_B}', "");
Expect(0, 1048576, '\P{Blk=-Sup_PUA_B}', "");
Expect(1, 1048576, '\P{^Blk=-Sup_PUA_B}', "");
Expect(0, 1, '\p{Blk=-Sup_PUA_B}', "");
Expect(1, 1, '\p{^Blk=-Sup_PUA_B}', "");
Expect(1, 1, '\P{Blk=-Sup_PUA_B}', "");
Expect(0, 1, '\P{^Blk=-Sup_PUA_B}', "");
Error('\p{Is_Block=-Supplementary_Private_use_Area_B/a/}');
Error('\P{Is_Block=-Supplementary_Private_use_Area_B/a/}');
Expect(1, 1048576, '\p{Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\p{Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1, '\P{Is_Block=supplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^Is_Block=supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(0, 1048576, '\p{^Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(0, 1048576, '\P{Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(1, 1048576, '\P{^Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(0, 1, '\p{Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(1, 1, '\p{^Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(1, 1, '\P{Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Expect(0, 1, '\P{^Is_Block=--Supplementary_PRIVATE_Use_Area_B}', "");
Error('\p{Is_Blk:	 SUP_PUA_B:=}');
Error('\P{Is_Blk:	 SUP_PUA_B:=}');
Expect(1, 1048576, '\p{Is_Blk=suppuab}', "");
Expect(0, 1048576, '\p{^Is_Blk=suppuab}', "");
Expect(0, 1048576, '\P{Is_Blk=suppuab}', "");
Expect(1, 1048576, '\P{^Is_Blk=suppuab}', "");
Expect(0, 1, '\p{Is_Blk=suppuab}', "");
Expect(1, 1, '\p{^Is_Blk=suppuab}', "");
Expect(1, 1, '\P{Is_Blk=suppuab}', "");
Expect(0, 1, '\P{^Is_Blk=suppuab}', "");
Expect(1, 1048576, '\p{Is_Blk= 	Sup_pua_b}', "");
Expect(0, 1048576, '\p{^Is_Blk= 	Sup_pua_b}', "");
Expect(0, 1048576, '\P{Is_Blk= 	Sup_pua_b}', "");
Expect(1, 1048576, '\P{^Is_Blk= 	Sup_pua_b}', "");
Expect(0, 1, '\p{Is_Blk= 	Sup_pua_b}', "");
Expect(1, 1, '\p{^Is_Blk= 	Sup_pua_b}', "");
Expect(1, 1, '\P{Is_Blk= 	Sup_pua_b}', "");
Expect(0, 1, '\P{^Is_Blk= 	Sup_pua_b}', "");
Error('\p{Block=_/a/Supplemental_punctuation}');
Error('\P{Block=_/a/Supplemental_punctuation}');
Expect(1, 11903, '\p{Block=supplementalpunctuation}', "");
Expect(0, 11903, '\p{^Block=supplementalpunctuation}', "");
Expect(0, 11903, '\P{Block=supplementalpunctuation}', "");
Expect(1, 11903, '\P{^Block=supplementalpunctuation}', "");
Expect(0, 11904, '\p{Block=supplementalpunctuation}', "");
Expect(1, 11904, '\p{^Block=supplementalpunctuation}', "");
Expect(1, 11904, '\P{Block=supplementalpunctuation}', "");
Expect(0, 11904, '\P{^Block=supplementalpunctuation}', "");
Expect(1, 11903, '\p{Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(0, 11903, '\p{^Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(0, 11903, '\P{Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(1, 11903, '\P{^Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(0, 11904, '\p{Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(1, 11904, '\p{^Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(1, 11904, '\P{Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Expect(0, 11904, '\P{^Block=-SUPPLEMENTAL_PUNCTUATION}', "");
Error('\p{Blk=	-sup_Punctuation:=}');
Error('\P{Blk=	-sup_Punctuation:=}');
Expect(1, 11903, '\p{Blk=suppunctuation}', "");
Expect(0, 11903, '\p{^Blk=suppunctuation}', "");
Expect(0, 11903, '\P{Blk=suppunctuation}', "");
Expect(1, 11903, '\P{^Blk=suppunctuation}', "");
Expect(0, 11904, '\p{Blk=suppunctuation}', "");
Expect(1, 11904, '\p{^Blk=suppunctuation}', "");
Expect(1, 11904, '\P{Blk=suppunctuation}', "");
Expect(0, 11904, '\P{^Blk=suppunctuation}', "");
Expect(1, 11903, '\p{Blk= Sup_PUNCTUATION}', "");
Expect(0, 11903, '\p{^Blk= Sup_PUNCTUATION}', "");
Expect(0, 11903, '\P{Blk= Sup_PUNCTUATION}', "");
Expect(1, 11903, '\P{^Blk= Sup_PUNCTUATION}', "");
Expect(0, 11904, '\p{Blk= Sup_PUNCTUATION}', "");
Expect(1, 11904, '\p{^Blk= Sup_PUNCTUATION}', "");
Expect(1, 11904, '\P{Blk= Sup_PUNCTUATION}', "");
Expect(0, 11904, '\P{^Blk= Sup_PUNCTUATION}', "");
Error('\p{Is_Block=	Supplemental_Punctuation:=}');
Error('\P{Is_Block=	Supplemental_Punctuation:=}');
Expect(1, 11903, '\p{Is_Block=supplementalpunctuation}', "");
Expect(0, 11903, '\p{^Is_Block=supplementalpunctuation}', "");
Expect(0, 11903, '\P{Is_Block=supplementalpunctuation}', "");
Expect(1, 11903, '\P{^Is_Block=supplementalpunctuation}', "");
Expect(0, 11904, '\p{Is_Block=supplementalpunctuation}', "");
Expect(1, 11904, '\p{^Is_Block=supplementalpunctuation}', "");
Expect(1, 11904, '\P{Is_Block=supplementalpunctuation}', "");
Expect(0, 11904, '\P{^Is_Block=supplementalpunctuation}', "");
Expect(1, 11903, '\p{Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11903, '\p{^Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11903, '\P{Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(1, 11903, '\P{^Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11904, '\p{Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(1, 11904, '\p{^Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(1, 11904, '\P{Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Expect(0, 11904, '\P{^Is_Block=-	SUPPLEMENTAL_Punctuation}', "");
Error('\p{Is_Blk=_	Sup_PUNCTUATION/a/}');
Error('\P{Is_Blk=_	Sup_PUNCTUATION/a/}');
Expect(1, 11903, '\p{Is_Blk=suppunctuation}', "");
Expect(0, 11903, '\p{^Is_Blk=suppunctuation}', "");
Expect(0, 11903, '\P{Is_Blk=suppunctuation}', "");
Expect(1, 11903, '\P{^Is_Blk=suppunctuation}', "");
Expect(0, 11904, '\p{Is_Blk=suppunctuation}', "");
Expect(1, 11904, '\p{^Is_Blk=suppunctuation}', "");
Expect(1, 11904, '\P{Is_Blk=suppunctuation}', "");
Expect(0, 11904, '\P{^Is_Blk=suppunctuation}', "");
Expect(1, 11903, '\p{Is_Blk:		 sup_punctuation}', "");
Expect(0, 11903, '\p{^Is_Blk:		 sup_punctuation}', "");
Expect(0, 11903, '\P{Is_Blk:		 sup_punctuation}', "");
Expect(1, 11903, '\P{^Is_Blk:		 sup_punctuation}', "");
Expect(0, 11904, '\p{Is_Blk:		 sup_punctuation}', "");
Expect(1, 11904, '\p{^Is_Blk:		 sup_punctuation}', "");
Expect(1, 11904, '\P{Is_Blk:		 sup_punctuation}', "");
Expect(0, 11904, '\P{^Is_Blk:		 sup_punctuation}', "");
Error('\p{Block=:=_Superscripts_and_Subscripts}');
Error('\P{Block=:=_Superscripts_and_Subscripts}');
Expect(1, 8351, '\p{Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\P{Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\p{Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\P{Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\p{Block=_Superscripts_And_subscripts}', "");
Expect(0, 8351, '\p{^Block=_Superscripts_And_subscripts}', "");
Expect(0, 8351, '\P{Block=_Superscripts_And_subscripts}', "");
Expect(1, 8351, '\P{^Block=_Superscripts_And_subscripts}', "");
Expect(0, 8352, '\p{Block=_Superscripts_And_subscripts}', "");
Expect(1, 8352, '\p{^Block=_Superscripts_And_subscripts}', "");
Expect(1, 8352, '\P{Block=_Superscripts_And_subscripts}', "");
Expect(0, 8352, '\P{^Block=_Superscripts_And_subscripts}', "");
Error('\p{Blk=/a/		SUPER_And_SUB}');
Error('\P{Blk=/a/		SUPER_And_SUB}');
Expect(1, 8351, '\p{Blk=superandsub}', "");
Expect(0, 8351, '\p{^Blk=superandsub}', "");
Expect(0, 8351, '\P{Blk=superandsub}', "");
Expect(1, 8351, '\P{^Blk=superandsub}', "");
Expect(0, 8352, '\p{Blk=superandsub}', "");
Expect(1, 8352, '\p{^Blk=superandsub}', "");
Expect(1, 8352, '\P{Blk=superandsub}', "");
Expect(0, 8352, '\P{^Blk=superandsub}', "");
Expect(1, 8351, '\p{Blk=-	Super_AND_SUB}', "");
Expect(0, 8351, '\p{^Blk=-	Super_AND_SUB}', "");
Expect(0, 8351, '\P{Blk=-	Super_AND_SUB}', "");
Expect(1, 8351, '\P{^Blk=-	Super_AND_SUB}', "");
Expect(0, 8352, '\p{Blk=-	Super_AND_SUB}', "");
Expect(1, 8352, '\p{^Blk=-	Super_AND_SUB}', "");
Expect(1, 8352, '\P{Blk=-	Super_AND_SUB}', "");
Expect(0, 8352, '\P{^Blk=-	Super_AND_SUB}', "");
Error('\p{Is_Block=-SUPERSCRIPTS_AND_SUBSCRIPTS:=}');
Error('\P{Is_Block=-SUPERSCRIPTS_AND_SUBSCRIPTS:=}');
Expect(1, 8351, '\p{Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8351, '\P{Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\p{Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8352, '\P{Is_Block=superscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^Is_Block=superscriptsandsubscripts}', "");
Expect(1, 8351, '\p{Is_Block=--Superscripts_And_Subscripts}', "");
Expect(0, 8351, '\p{^Is_Block=--Superscripts_And_Subscripts}', "");
Expect(0, 8351, '\P{Is_Block=--Superscripts_And_Subscripts}', "");
Expect(1, 8351, '\P{^Is_Block=--Superscripts_And_Subscripts}', "");
Expect(0, 8352, '\p{Is_Block=--Superscripts_And_Subscripts}', "");
Expect(1, 8352, '\p{^Is_Block=--Superscripts_And_Subscripts}', "");
Expect(1, 8352, '\P{Is_Block=--Superscripts_And_Subscripts}', "");
Expect(0, 8352, '\P{^Is_Block=--Superscripts_And_Subscripts}', "");
Error('\p{Is_Blk=_Super_AND_sub:=}');
Error('\P{Is_Blk=_Super_AND_sub:=}');
Expect(1, 8351, '\p{Is_Blk=superandsub}', "");
Expect(0, 8351, '\p{^Is_Blk=superandsub}', "");
Expect(0, 8351, '\P{Is_Blk=superandsub}', "");
Expect(1, 8351, '\P{^Is_Blk=superandsub}', "");
Expect(0, 8352, '\p{Is_Blk=superandsub}', "");
Expect(1, 8352, '\p{^Is_Blk=superandsub}', "");
Expect(1, 8352, '\P{Is_Blk=superandsub}', "");
Expect(0, 8352, '\P{^Is_Blk=superandsub}', "");
Expect(1, 8351, '\p{Is_Blk=  Super_AND_sub}', "");
Expect(0, 8351, '\p{^Is_Blk=  Super_AND_sub}', "");
Expect(0, 8351, '\P{Is_Blk=  Super_AND_sub}', "");
Expect(1, 8351, '\P{^Is_Blk=  Super_AND_sub}', "");
Expect(0, 8352, '\p{Is_Blk=  Super_AND_sub}', "");
Expect(1, 8352, '\p{^Is_Blk=  Super_AND_sub}', "");
Expect(1, 8352, '\P{Is_Blk=  Super_AND_sub}', "");
Expect(0, 8352, '\P{^Is_Blk=  Super_AND_sub}', "");
Error('\p{Block=-/a/Syloti_Nagri}');
Error('\P{Block=-/a/Syloti_Nagri}');
Expect(1, 43055, '\p{Block=sylotinagri}', "");
Expect(0, 43055, '\p{^Block=sylotinagri}', "");
Expect(0, 43055, '\P{Block=sylotinagri}', "");
Expect(1, 43055, '\P{^Block=sylotinagri}', "");
Expect(0, 43056, '\p{Block=sylotinagri}', "");
Expect(1, 43056, '\p{^Block=sylotinagri}', "");
Expect(1, 43056, '\P{Block=sylotinagri}', "");
Expect(0, 43056, '\P{^Block=sylotinagri}', "");
Expect(1, 43055, '\p{Block:	_-syloti_nagri}', "");
Expect(0, 43055, '\p{^Block:	_-syloti_nagri}', "");
Expect(0, 43055, '\P{Block:	_-syloti_nagri}', "");
Expect(1, 43055, '\P{^Block:	_-syloti_nagri}', "");
Expect(0, 43056, '\p{Block:	_-syloti_nagri}', "");
Expect(1, 43056, '\p{^Block:	_-syloti_nagri}', "");
Expect(1, 43056, '\P{Block:	_-syloti_nagri}', "");
Expect(0, 43056, '\P{^Block:	_-syloti_nagri}', "");
Error('\p{Blk=:=Syloti_NAGRI}');
Error('\P{Blk=:=Syloti_NAGRI}');
Expect(1, 43055, '\p{Blk=sylotinagri}', "");
Expect(0, 43055, '\p{^Blk=sylotinagri}', "");
Expect(0, 43055, '\P{Blk=sylotinagri}', "");
Expect(1, 43055, '\P{^Blk=sylotinagri}', "");
Expect(0, 43056, '\p{Blk=sylotinagri}', "");
Expect(1, 43056, '\p{^Blk=sylotinagri}', "");
Expect(1, 43056, '\P{Blk=sylotinagri}', "");
Expect(0, 43056, '\P{^Blk=sylotinagri}', "");
Expect(1, 43055, '\p{Blk=	 SYLOTI_NAGRI}', "");
Expect(0, 43055, '\p{^Blk=	 SYLOTI_NAGRI}', "");
Expect(0, 43055, '\P{Blk=	 SYLOTI_NAGRI}', "");
Expect(1, 43055, '\P{^Blk=	 SYLOTI_NAGRI}', "");
Expect(0, 43056, '\p{Blk=	 SYLOTI_NAGRI}', "");
Expect(1, 43056, '\p{^Blk=	 SYLOTI_NAGRI}', "");
Expect(1, 43056, '\P{Blk=	 SYLOTI_NAGRI}', "");
Expect(0, 43056, '\P{^Blk=	 SYLOTI_NAGRI}', "");
Error('\p{Is_Block=_Syloti_NAGRI:=}');
Error('\P{Is_Block=_Syloti_NAGRI:=}');
Expect(1, 43055, '\p{Is_Block=sylotinagri}', "");
Expect(0, 43055, '\p{^Is_Block=sylotinagri}', "");
Expect(0, 43055, '\P{Is_Block=sylotinagri}', "");
Expect(1, 43055, '\P{^Is_Block=sylotinagri}', "");
Expect(0, 43056, '\p{Is_Block=sylotinagri}', "");
Expect(1, 43056, '\p{^Is_Block=sylotinagri}', "");
Expect(1, 43056, '\P{Is_Block=sylotinagri}', "");
Expect(0, 43056, '\P{^Is_Block=sylotinagri}', "");
Expect(1, 43055, '\p{Is_Block=	Syloti_Nagri}', "");
Expect(0, 43055, '\p{^Is_Block=	Syloti_Nagri}', "");
Expect(0, 43055, '\P{Is_Block=	Syloti_Nagri}', "");
Expect(1, 43055, '\P{^Is_Block=	Syloti_Nagri}', "");
Expect(0, 43056, '\p{Is_Block=	Syloti_Nagri}', "");
Expect(1, 43056, '\p{^Is_Block=	Syloti_Nagri}', "");
Expect(1, 43056, '\P{Is_Block=	Syloti_Nagri}', "");
Expect(0, 43056, '\P{^Is_Block=	Syloti_Nagri}', "");
Error('\p{Is_Blk=:=--syloti_Nagri}');
Error('\P{Is_Blk=:=--syloti_Nagri}');
Expect(1, 43055, '\p{Is_Blk=sylotinagri}', "");
Expect(0, 43055, '\p{^Is_Blk=sylotinagri}', "");
Expect(0, 43055, '\P{Is_Blk=sylotinagri}', "");
Expect(1, 43055, '\P{^Is_Blk=sylotinagri}', "");
Expect(0, 43056, '\p{Is_Blk=sylotinagri}', "");
Expect(1, 43056, '\p{^Is_Blk=sylotinagri}', "");
Expect(1, 43056, '\P{Is_Blk=sylotinagri}', "");
Expect(0, 43056, '\P{^Is_Blk=sylotinagri}', "");
Expect(1, 43055, '\p{Is_Blk=_	Syloti_NAGRI}', "");
Expect(0, 43055, '\p{^Is_Blk=_	Syloti_NAGRI}', "");
Expect(0, 43055, '\P{Is_Blk=_	Syloti_NAGRI}', "");
Expect(1, 43055, '\P{^Is_Blk=_	Syloti_NAGRI}', "");
Expect(0, 43056, '\p{Is_Blk=_	Syloti_NAGRI}', "");
Expect(1, 43056, '\p{^Is_Blk=_	Syloti_NAGRI}', "");
Expect(1, 43056, '\P{Is_Blk=_	Syloti_NAGRI}', "");
Expect(0, 43056, '\P{^Is_Blk=_	Syloti_NAGRI}', "");
Error('\p{Block= 	Syriac:=}');
Error('\P{Block= 	Syriac:=}');
Expect(1, 1871, '\p{Block=syriac}', "");
Expect(0, 1871, '\p{^Block=syriac}', "");
Expect(0, 1871, '\P{Block=syriac}', "");
Expect(1, 1871, '\P{^Block=syriac}', "");
Expect(0, 1872, '\p{Block=syriac}', "");
Expect(1, 1872, '\p{^Block=syriac}', "");
Expect(1, 1872, '\P{Block=syriac}', "");
Expect(0, 1872, '\P{^Block=syriac}', "");
Expect(1, 1871, '\p{Block=- Syriac}', "");
Expect(0, 1871, '\p{^Block=- Syriac}', "");
Expect(0, 1871, '\P{Block=- Syriac}', "");
Expect(1, 1871, '\P{^Block=- Syriac}', "");
Expect(0, 1872, '\p{Block=- Syriac}', "");
Expect(1, 1872, '\p{^Block=- Syriac}', "");
Expect(1, 1872, '\P{Block=- Syriac}', "");
Expect(0, 1872, '\P{^Block=- Syriac}', "");
Error('\p{Blk=_Syriac:=}');
Error('\P{Blk=_Syriac:=}');
Expect(1, 1871, '\p{Blk:syriac}', "");
Expect(0, 1871, '\p{^Blk:syriac}', "");
Expect(0, 1871, '\P{Blk:syriac}', "");
Expect(1, 1871, '\P{^Blk:syriac}', "");
Expect(0, 1872, '\p{Blk:syriac}', "");
Expect(1, 1872, '\p{^Blk:syriac}', "");
Expect(1, 1872, '\P{Blk:syriac}', "");
Expect(0, 1872, '\P{^Blk:syriac}', "");
Expect(1, 1871, '\p{Blk= _Syriac}', "");
Expect(0, 1871, '\p{^Blk= _Syriac}', "");
Expect(0, 1871, '\P{Blk= _Syriac}', "");
Expect(1, 1871, '\P{^Blk= _Syriac}', "");
Expect(0, 1872, '\p{Blk= _Syriac}', "");
Expect(1, 1872, '\p{^Blk= _Syriac}', "");
Expect(1, 1872, '\P{Blk= _Syriac}', "");
Expect(0, 1872, '\P{^Blk= _Syriac}', "");
Error('\p{Is_Block=/a/_ Syriac}');
Error('\P{Is_Block=/a/_ Syriac}');
Expect(1, 1871, '\p{Is_Block=syriac}', "");
Expect(0, 1871, '\p{^Is_Block=syriac}', "");
Expect(0, 1871, '\P{Is_Block=syriac}', "");
Expect(1, 1871, '\P{^Is_Block=syriac}', "");
Expect(0, 1872, '\p{Is_Block=syriac}', "");
Expect(1, 1872, '\p{^Is_Block=syriac}', "");
Expect(1, 1872, '\P{Is_Block=syriac}', "");
Expect(0, 1872, '\P{^Is_Block=syriac}', "");
Expect(1, 1871, '\p{Is_Block=_ Syriac}', "");
Expect(0, 1871, '\p{^Is_Block=_ Syriac}', "");
Expect(0, 1871, '\P{Is_Block=_ Syriac}', "");
Expect(1, 1871, '\P{^Is_Block=_ Syriac}', "");
Expect(0, 1872, '\p{Is_Block=_ Syriac}', "");
Expect(1, 1872, '\p{^Is_Block=_ Syriac}', "");
Expect(1, 1872, '\P{Is_Block=_ Syriac}', "");
Expect(0, 1872, '\P{^Is_Block=_ Syriac}', "");
Error('\p{Is_Blk=	/a/Syriac}');
Error('\P{Is_Blk=	/a/Syriac}');
Expect(1, 1871, '\p{Is_Blk=syriac}', "");
Expect(0, 1871, '\p{^Is_Blk=syriac}', "");
Expect(0, 1871, '\P{Is_Blk=syriac}', "");
Expect(1, 1871, '\P{^Is_Blk=syriac}', "");
Expect(0, 1872, '\p{Is_Blk=syriac}', "");
Expect(1, 1872, '\p{^Is_Blk=syriac}', "");
Expect(1, 1872, '\P{Is_Blk=syriac}', "");
Expect(0, 1872, '\P{^Is_Blk=syriac}', "");
Expect(1, 1871, '\p{Is_Blk:   -	syriac}', "");
Expect(0, 1871, '\p{^Is_Blk:   -	syriac}', "");
Expect(0, 1871, '\P{Is_Blk:   -	syriac}', "");
Expect(1, 1871, '\P{^Is_Blk:   -	syriac}', "");
Expect(0, 1872, '\p{Is_Blk:   -	syriac}', "");
Expect(1, 1872, '\p{^Is_Blk:   -	syriac}', "");
Expect(1, 1872, '\P{Is_Blk:   -	syriac}', "");
Expect(0, 1872, '\P{^Is_Blk:   -	syriac}', "");
Error('\p{Block=-:=Tagalog}');
Error('\P{Block=-:=Tagalog}');
Expect(1, 5919, '\p{Block=tagalog}', "");
Expect(0, 5919, '\p{^Block=tagalog}', "");
Expect(0, 5919, '\P{Block=tagalog}', "");
Expect(1, 5919, '\P{^Block=tagalog}', "");
Expect(0, 5920, '\p{Block=tagalog}', "");
Expect(1, 5920, '\p{^Block=tagalog}', "");
Expect(1, 5920, '\P{Block=tagalog}', "");
Expect(0, 5920, '\P{^Block=tagalog}', "");
Expect(1, 5919, '\p{Block:--Tagalog}', "");
Expect(0, 5919, '\p{^Block:--Tagalog}', "");
Expect(0, 5919, '\P{Block:--Tagalog}', "");
Expect(1, 5919, '\P{^Block:--Tagalog}', "");
Expect(0, 5920, '\p{Block:--Tagalog}', "");
Expect(1, 5920, '\p{^Block:--Tagalog}', "");
Expect(1, 5920, '\P{Block:--Tagalog}', "");
Expect(0, 5920, '\P{^Block:--Tagalog}', "");
Error('\p{Blk=	:=TAGALOG}');
Error('\P{Blk=	:=TAGALOG}');
Expect(1, 5919, '\p{Blk:tagalog}', "");
Expect(0, 5919, '\p{^Blk:tagalog}', "");
Expect(0, 5919, '\P{Blk:tagalog}', "");
Expect(1, 5919, '\P{^Blk:tagalog}', "");
Expect(0, 5920, '\p{Blk:tagalog}', "");
Expect(1, 5920, '\p{^Blk:tagalog}', "");
Expect(1, 5920, '\P{Blk:tagalog}', "");
Expect(0, 5920, '\P{^Blk:tagalog}', "");
Expect(1, 5919, '\p{Blk=	-TAGALOG}', "");
Expect(0, 5919, '\p{^Blk=	-TAGALOG}', "");
Expect(0, 5919, '\P{Blk=	-TAGALOG}', "");
Expect(1, 5919, '\P{^Blk=	-TAGALOG}', "");
Expect(0, 5920, '\p{Blk=	-TAGALOG}', "");
Expect(1, 5920, '\p{^Blk=	-TAGALOG}', "");
Expect(1, 5920, '\P{Blk=	-TAGALOG}', "");
Expect(0, 5920, '\P{^Blk=	-TAGALOG}', "");
Error('\p{Is_Block=-_TAGALOG/a/}');
Error('\P{Is_Block=-_TAGALOG/a/}');
Expect(1, 5919, '\p{Is_Block=tagalog}', "");
Expect(0, 5919, '\p{^Is_Block=tagalog}', "");
Expect(0, 5919, '\P{Is_Block=tagalog}', "");
Expect(1, 5919, '\P{^Is_Block=tagalog}', "");
Expect(0, 5920, '\p{Is_Block=tagalog}', "");
Expect(1, 5920, '\p{^Is_Block=tagalog}', "");
Expect(1, 5920, '\P{Is_Block=tagalog}', "");
Expect(0, 5920, '\P{^Is_Block=tagalog}', "");
Expect(1, 5919, '\p{Is_Block=		tagalog}', "");
Expect(0, 5919, '\p{^Is_Block=		tagalog}', "");
Expect(0, 5919, '\P{Is_Block=		tagalog}', "");
Expect(1, 5919, '\P{^Is_Block=		tagalog}', "");
Expect(0, 5920, '\p{Is_Block=		tagalog}', "");
Expect(1, 5920, '\p{^Is_Block=		tagalog}', "");
Expect(1, 5920, '\P{Is_Block=		tagalog}', "");
Expect(0, 5920, '\P{^Is_Block=		tagalog}', "");
Error('\p{Is_Blk=/a/Tagalog}');
Error('\P{Is_Blk=/a/Tagalog}');
Expect(1, 5919, '\p{Is_Blk=tagalog}', "");
Expect(0, 5919, '\p{^Is_Blk=tagalog}', "");
Expect(0, 5919, '\P{Is_Blk=tagalog}', "");
Expect(1, 5919, '\P{^Is_Blk=tagalog}', "");
Expect(0, 5920, '\p{Is_Blk=tagalog}', "");
Expect(1, 5920, '\p{^Is_Blk=tagalog}', "");
Expect(1, 5920, '\P{Is_Blk=tagalog}', "");
Expect(0, 5920, '\P{^Is_Blk=tagalog}', "");
Expect(1, 5919, '\p{Is_Blk=_ TAGALOG}', "");
Expect(0, 5919, '\p{^Is_Blk=_ TAGALOG}', "");
Expect(0, 5919, '\P{Is_Blk=_ TAGALOG}', "");
Expect(1, 5919, '\P{^Is_Blk=_ TAGALOG}', "");
Expect(0, 5920, '\p{Is_Blk=_ TAGALOG}', "");
Expect(1, 5920, '\p{^Is_Blk=_ TAGALOG}', "");
Expect(1, 5920, '\P{Is_Blk=_ TAGALOG}', "");
Expect(0, 5920, '\P{^Is_Blk=_ TAGALOG}', "");
Error('\p{Block=	:=tagbanwa}');
Error('\P{Block=	:=tagbanwa}');
Expect(1, 6015, '\p{Block=tagbanwa}', "");
Expect(0, 6015, '\p{^Block=tagbanwa}', "");
Expect(0, 6015, '\P{Block=tagbanwa}', "");
Expect(1, 6015, '\P{^Block=tagbanwa}', "");
Expect(0, 6016, '\p{Block=tagbanwa}', "");
Expect(1, 6016, '\p{^Block=tagbanwa}', "");
Expect(1, 6016, '\P{Block=tagbanwa}', "");
Expect(0, 6016, '\P{^Block=tagbanwa}', "");
Expect(1, 6015, '\p{Block= -tagbanwa}', "");
Expect(0, 6015, '\p{^Block= -tagbanwa}', "");
Expect(0, 6015, '\P{Block= -tagbanwa}', "");
Expect(1, 6015, '\P{^Block= -tagbanwa}', "");
Expect(0, 6016, '\p{Block= -tagbanwa}', "");
Expect(1, 6016, '\p{^Block= -tagbanwa}', "");
Expect(1, 6016, '\P{Block= -tagbanwa}', "");
Expect(0, 6016, '\P{^Block= -tagbanwa}', "");
Error('\p{Blk:   	:=Tagbanwa}');
Error('\P{Blk:   	:=Tagbanwa}');
Expect(1, 6015, '\p{Blk:   tagbanwa}', "");
Expect(0, 6015, '\p{^Blk:   tagbanwa}', "");
Expect(0, 6015, '\P{Blk:   tagbanwa}', "");
Expect(1, 6015, '\P{^Blk:   tagbanwa}', "");
Expect(0, 6016, '\p{Blk:   tagbanwa}', "");
Expect(1, 6016, '\p{^Blk:   tagbanwa}', "");
Expect(1, 6016, '\P{Blk:   tagbanwa}', "");
Expect(0, 6016, '\P{^Blk:   tagbanwa}', "");
Expect(1, 6015, '\p{Blk= 	Tagbanwa}', "");
Expect(0, 6015, '\p{^Blk= 	Tagbanwa}', "");
Expect(0, 6015, '\P{Blk= 	Tagbanwa}', "");
Expect(1, 6015, '\P{^Blk= 	Tagbanwa}', "");
Expect(0, 6016, '\p{Blk= 	Tagbanwa}', "");
Expect(1, 6016, '\p{^Blk= 	Tagbanwa}', "");
Expect(1, 6016, '\P{Blk= 	Tagbanwa}', "");
Expect(0, 6016, '\P{^Blk= 	Tagbanwa}', "");
Error('\p{Is_Block=:=-Tagbanwa}');
Error('\P{Is_Block=:=-Tagbanwa}');
Expect(1, 6015, '\p{Is_Block=tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Block=tagbanwa}', "");
Expect(0, 6015, '\P{Is_Block=tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Block=tagbanwa}', "");
Expect(0, 6016, '\p{Is_Block=tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Block=tagbanwa}', "");
Expect(1, 6016, '\P{Is_Block=tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Block=tagbanwa}', "");
Expect(1, 6015, '\p{Is_Block=-_TAGBANWA}', "");
Expect(0, 6015, '\p{^Is_Block=-_TAGBANWA}', "");
Expect(0, 6015, '\P{Is_Block=-_TAGBANWA}', "");
Expect(1, 6015, '\P{^Is_Block=-_TAGBANWA}', "");
Expect(0, 6016, '\p{Is_Block=-_TAGBANWA}', "");
Expect(1, 6016, '\p{^Is_Block=-_TAGBANWA}', "");
Expect(1, 6016, '\P{Is_Block=-_TAGBANWA}', "");
Expect(0, 6016, '\P{^Is_Block=-_TAGBANWA}', "");
Error('\p{Is_Blk=	 Tagbanwa:=}');
Error('\P{Is_Blk=	 Tagbanwa:=}');
Expect(1, 6015, '\p{Is_Blk:   tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Blk:   tagbanwa}', "");
Expect(0, 6015, '\P{Is_Blk:   tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Blk:   tagbanwa}', "");
Expect(0, 6016, '\p{Is_Blk:   tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Blk:   tagbanwa}', "");
Expect(1, 6016, '\P{Is_Blk:   tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Blk:   tagbanwa}', "");
Expect(1, 6015, '\p{Is_Blk=  tagbanwa}', "");
Expect(0, 6015, '\p{^Is_Blk=  tagbanwa}', "");
Expect(0, 6015, '\P{Is_Blk=  tagbanwa}', "");
Expect(1, 6015, '\P{^Is_Blk=  tagbanwa}', "");
Expect(0, 6016, '\p{Is_Blk=  tagbanwa}', "");
Expect(1, 6016, '\p{^Is_Blk=  tagbanwa}', "");
Expect(1, 6016, '\P{Is_Blk=  tagbanwa}', "");
Expect(0, 6016, '\P{^Is_Blk=  tagbanwa}', "");
Error('\p{Block=		Tags/a/}');
Error('\P{Block=		Tags/a/}');
Expect(1, 917631, '\p{Block=tags}', "");
Expect(0, 917631, '\p{^Block=tags}', "");
Expect(0, 917631, '\P{Block=tags}', "");
Expect(1, 917631, '\P{^Block=tags}', "");
Expect(0, 917632, '\p{Block=tags}', "");
Expect(1, 917632, '\p{^Block=tags}', "");
Expect(1, 917632, '\P{Block=tags}', "");
Expect(0, 917632, '\P{^Block=tags}', "");
Expect(1, 917631, '\p{Block=	_tags}', "");
Expect(0, 917631, '\p{^Block=	_tags}', "");
Expect(0, 917631, '\P{Block=	_tags}', "");
Expect(1, 917631, '\P{^Block=	_tags}', "");
Expect(0, 917632, '\p{Block=	_tags}', "");
Expect(1, 917632, '\p{^Block=	_tags}', "");
Expect(1, 917632, '\P{Block=	_tags}', "");
Expect(0, 917632, '\P{^Block=	_tags}', "");
Error('\p{Blk=/a/	-Tags}');
Error('\P{Blk=/a/	-Tags}');
Expect(1, 917631, '\p{Blk=tags}', "");
Expect(0, 917631, '\p{^Blk=tags}', "");
Expect(0, 917631, '\P{Blk=tags}', "");
Expect(1, 917631, '\P{^Blk=tags}', "");
Expect(0, 917632, '\p{Blk=tags}', "");
Expect(1, 917632, '\p{^Blk=tags}', "");
Expect(1, 917632, '\P{Blk=tags}', "");
Expect(0, 917632, '\P{^Blk=tags}', "");
Expect(1, 917631, '\p{Blk=_Tags}', "");
Expect(0, 917631, '\p{^Blk=_Tags}', "");
Expect(0, 917631, '\P{Blk=_Tags}', "");
Expect(1, 917631, '\P{^Blk=_Tags}', "");
Expect(0, 917632, '\p{Blk=_Tags}', "");
Expect(1, 917632, '\p{^Blk=_Tags}', "");
Expect(1, 917632, '\P{Blk=_Tags}', "");
Expect(0, 917632, '\P{^Blk=_Tags}', "");
Error('\p{Is_Block:   	/a/tags}');
Error('\P{Is_Block:   	/a/tags}');
Expect(1, 917631, '\p{Is_Block=tags}', "");
Expect(0, 917631, '\p{^Is_Block=tags}', "");
Expect(0, 917631, '\P{Is_Block=tags}', "");
Expect(1, 917631, '\P{^Is_Block=tags}', "");
Expect(0, 917632, '\p{Is_Block=tags}', "");
Expect(1, 917632, '\p{^Is_Block=tags}', "");
Expect(1, 917632, '\P{Is_Block=tags}', "");
Expect(0, 917632, '\P{^Is_Block=tags}', "");
Expect(1, 917631, '\p{Is_Block=	TAGS}', "");
Expect(0, 917631, '\p{^Is_Block=	TAGS}', "");
Expect(0, 917631, '\P{Is_Block=	TAGS}', "");
Expect(1, 917631, '\P{^Is_Block=	TAGS}', "");
Expect(0, 917632, '\p{Is_Block=	TAGS}', "");
Expect(1, 917632, '\p{^Is_Block=	TAGS}', "");
Expect(1, 917632, '\P{Is_Block=	TAGS}', "");
Expect(0, 917632, '\P{^Is_Block=	TAGS}', "");
Error('\p{Is_Blk=/a/-Tags}');
Error('\P{Is_Blk=/a/-Tags}');
Expect(1, 917631, '\p{Is_Blk=tags}', "");
Expect(0, 917631, '\p{^Is_Blk=tags}', "");
Expect(0, 917631, '\P{Is_Blk=tags}', "");
Expect(1, 917631, '\P{^Is_Blk=tags}', "");
Expect(0, 917632, '\p{Is_Blk=tags}', "");
Expect(1, 917632, '\p{^Is_Blk=tags}', "");
Expect(1, 917632, '\P{Is_Blk=tags}', "");
Expect(0, 917632, '\P{^Is_Blk=tags}', "");
Expect(1, 917631, '\p{Is_Blk= _tags}', "");
Expect(0, 917631, '\p{^Is_Blk= _tags}', "");
Expect(0, 917631, '\P{Is_Blk= _tags}', "");
Expect(1, 917631, '\P{^Is_Blk= _tags}', "");
Expect(0, 917632, '\p{Is_Blk= _tags}', "");
Expect(1, 917632, '\p{^Is_Blk= _tags}', "");
Expect(1, 917632, '\P{Is_Blk= _tags}', "");
Expect(0, 917632, '\P{^Is_Blk= _tags}', "");
Error('\p{Block:   Tai_LE/a/}');
Error('\P{Block:   Tai_LE/a/}');
Expect(1, 6527, '\p{Block=taile}', "");
Expect(0, 6527, '\p{^Block=taile}', "");
Expect(0, 6527, '\P{Block=taile}', "");
Expect(1, 6527, '\P{^Block=taile}', "");
Expect(0, 6528, '\p{Block=taile}', "");
Expect(1, 6528, '\p{^Block=taile}', "");
Expect(1, 6528, '\P{Block=taile}', "");
Expect(0, 6528, '\P{^Block=taile}', "");
Expect(1, 6527, '\p{Block=	Tai_LE}', "");
Expect(0, 6527, '\p{^Block=	Tai_LE}', "");
Expect(0, 6527, '\P{Block=	Tai_LE}', "");
Expect(1, 6527, '\P{^Block=	Tai_LE}', "");
Expect(0, 6528, '\p{Block=	Tai_LE}', "");
Expect(1, 6528, '\p{^Block=	Tai_LE}', "");
Expect(1, 6528, '\P{Block=	Tai_LE}', "");
Expect(0, 6528, '\P{^Block=	Tai_LE}', "");
Error('\p{Blk=_/a/tai_Le}');
Error('\P{Blk=_/a/tai_Le}');
Expect(1, 6527, '\p{Blk=taile}', "");
Expect(0, 6527, '\p{^Blk=taile}', "");
Expect(0, 6527, '\P{Blk=taile}', "");
Expect(1, 6527, '\P{^Blk=taile}', "");
Expect(0, 6528, '\p{Blk=taile}', "");
Expect(1, 6528, '\p{^Blk=taile}', "");
Expect(1, 6528, '\P{Blk=taile}', "");
Expect(0, 6528, '\P{^Blk=taile}', "");
Expect(1, 6527, '\p{Blk=__Tai_LE}', "");
Expect(0, 6527, '\p{^Blk=__Tai_LE}', "");
Expect(0, 6527, '\P{Blk=__Tai_LE}', "");
Expect(1, 6527, '\P{^Blk=__Tai_LE}', "");
Expect(0, 6528, '\p{Blk=__Tai_LE}', "");
Expect(1, 6528, '\p{^Blk=__Tai_LE}', "");
Expect(1, 6528, '\P{Blk=__Tai_LE}', "");
Expect(0, 6528, '\P{^Blk=__Tai_LE}', "");
Error('\p{Is_Block=_:=Tai_Le}');
Error('\P{Is_Block=_:=Tai_Le}');
Expect(1, 6527, '\p{Is_Block=taile}', "");
Expect(0, 6527, '\p{^Is_Block=taile}', "");
Expect(0, 6527, '\P{Is_Block=taile}', "");
Expect(1, 6527, '\P{^Is_Block=taile}', "");
Expect(0, 6528, '\p{Is_Block=taile}', "");
Expect(1, 6528, '\p{^Is_Block=taile}', "");
Expect(1, 6528, '\P{Is_Block=taile}', "");
Expect(0, 6528, '\P{^Is_Block=taile}', "");
Expect(1, 6527, '\p{Is_Block=		TAI_le}', "");
Expect(0, 6527, '\p{^Is_Block=		TAI_le}', "");
Expect(0, 6527, '\P{Is_Block=		TAI_le}', "");
Expect(1, 6527, '\P{^Is_Block=		TAI_le}', "");
Expect(0, 6528, '\p{Is_Block=		TAI_le}', "");
Expect(1, 6528, '\p{^Is_Block=		TAI_le}', "");
Expect(1, 6528, '\P{Is_Block=		TAI_le}', "");
Expect(0, 6528, '\P{^Is_Block=		TAI_le}', "");
Error('\p{Is_Blk=	tai_LE:=}');
Error('\P{Is_Blk=	tai_LE:=}');
Expect(1, 6527, '\p{Is_Blk=taile}', "");
Expect(0, 6527, '\p{^Is_Blk=taile}', "");
Expect(0, 6527, '\P{Is_Blk=taile}', "");
Expect(1, 6527, '\P{^Is_Blk=taile}', "");
Expect(0, 6528, '\p{Is_Blk=taile}', "");
Expect(1, 6528, '\p{^Is_Blk=taile}', "");
Expect(1, 6528, '\P{Is_Blk=taile}', "");
Expect(0, 6528, '\P{^Is_Blk=taile}', "");
Expect(1, 6527, '\p{Is_Blk:   _	TAI_Le}', "");
Expect(0, 6527, '\p{^Is_Blk:   _	TAI_Le}', "");
Expect(0, 6527, '\P{Is_Blk:   _	TAI_Le}', "");
Expect(1, 6527, '\P{^Is_Blk:   _	TAI_Le}', "");
Expect(0, 6528, '\p{Is_Blk:   _	TAI_Le}', "");
Expect(1, 6528, '\p{^Is_Blk:   _	TAI_Le}', "");
Expect(1, 6528, '\P{Is_Blk:   _	TAI_Le}', "");
Expect(0, 6528, '\P{^Is_Blk:   _	TAI_Le}', "");
Error('\p{Block=_	TAI_Tham/a/}');
Error('\P{Block=_	TAI_Tham/a/}');
Expect(1, 6831, '\p{Block=taitham}', "");
Expect(0, 6831, '\p{^Block=taitham}', "");
Expect(0, 6831, '\P{Block=taitham}', "");
Expect(1, 6831, '\P{^Block=taitham}', "");
Expect(0, 6832, '\p{Block=taitham}', "");
Expect(1, 6832, '\p{^Block=taitham}', "");
Expect(1, 6832, '\P{Block=taitham}', "");
Expect(0, 6832, '\P{^Block=taitham}', "");
Expect(1, 6831, '\p{Block= Tai_Tham}', "");
Expect(0, 6831, '\p{^Block= Tai_Tham}', "");
Expect(0, 6831, '\P{Block= Tai_Tham}', "");
Expect(1, 6831, '\P{^Block= Tai_Tham}', "");
Expect(0, 6832, '\p{Block= Tai_Tham}', "");
Expect(1, 6832, '\p{^Block= Tai_Tham}', "");
Expect(1, 6832, '\P{Block= Tai_Tham}', "");
Expect(0, 6832, '\P{^Block= Tai_Tham}', "");
Error('\p{Blk=/a/-_Tai_Tham}');
Error('\P{Blk=/a/-_Tai_Tham}');
Expect(1, 6831, '\p{Blk=taitham}', "");
Expect(0, 6831, '\p{^Blk=taitham}', "");
Expect(0, 6831, '\P{Blk=taitham}', "");
Expect(1, 6831, '\P{^Blk=taitham}', "");
Expect(0, 6832, '\p{Blk=taitham}', "");
Expect(1, 6832, '\p{^Blk=taitham}', "");
Expect(1, 6832, '\P{Blk=taitham}', "");
Expect(0, 6832, '\P{^Blk=taitham}', "");
Expect(1, 6831, '\p{Blk=--Tai_Tham}', "");
Expect(0, 6831, '\p{^Blk=--Tai_Tham}', "");
Expect(0, 6831, '\P{Blk=--Tai_Tham}', "");
Expect(1, 6831, '\P{^Blk=--Tai_Tham}', "");
Expect(0, 6832, '\p{Blk=--Tai_Tham}', "");
Expect(1, 6832, '\p{^Blk=--Tai_Tham}', "");
Expect(1, 6832, '\P{Blk=--Tai_Tham}', "");
Expect(0, 6832, '\P{^Blk=--Tai_Tham}', "");
Error('\p{Is_Block=-Tai_Tham/a/}');
Error('\P{Is_Block=-Tai_Tham/a/}');
Expect(1, 6831, '\p{Is_Block:   taitham}', "");
Expect(0, 6831, '\p{^Is_Block:   taitham}', "");
Expect(0, 6831, '\P{Is_Block:   taitham}', "");
Expect(1, 6831, '\P{^Is_Block:   taitham}', "");
Expect(0, 6832, '\p{Is_Block:   taitham}', "");
Expect(1, 6832, '\p{^Is_Block:   taitham}', "");
Expect(1, 6832, '\P{Is_Block:   taitham}', "");
Expect(0, 6832, '\P{^Is_Block:   taitham}', "");
Expect(1, 6831, '\p{Is_Block=TAI_Tham}', "");
Expect(0, 6831, '\p{^Is_Block=TAI_Tham}', "");
Expect(0, 6831, '\P{Is_Block=TAI_Tham}', "");
Expect(1, 6831, '\P{^Is_Block=TAI_Tham}', "");
Expect(0, 6832, '\p{Is_Block=TAI_Tham}', "");
Expect(1, 6832, '\p{^Is_Block=TAI_Tham}', "");
Expect(1, 6832, '\P{Is_Block=TAI_Tham}', "");
Expect(0, 6832, '\P{^Is_Block=TAI_Tham}', "");
Error('\p{Is_Blk=	_Tai_Tham/a/}');
Error('\P{Is_Blk=	_Tai_Tham/a/}');
Expect(1, 6831, '\p{Is_Blk=taitham}', "");
Expect(0, 6831, '\p{^Is_Blk=taitham}', "");
Expect(0, 6831, '\P{Is_Blk=taitham}', "");
Expect(1, 6831, '\P{^Is_Blk=taitham}', "");
Expect(0, 6832, '\p{Is_Blk=taitham}', "");
Expect(1, 6832, '\p{^Is_Blk=taitham}', "");
Expect(1, 6832, '\P{Is_Blk=taitham}', "");
Expect(0, 6832, '\P{^Is_Blk=taitham}', "");
Expect(1, 6831, '\p{Is_Blk=-Tai_Tham}', "");
Expect(0, 6831, '\p{^Is_Blk=-Tai_Tham}', "");
Expect(0, 6831, '\P{Is_Blk=-Tai_Tham}', "");
Expect(1, 6831, '\P{^Is_Blk=-Tai_Tham}', "");
Expect(0, 6832, '\p{Is_Blk=-Tai_Tham}', "");
Expect(1, 6832, '\p{^Is_Blk=-Tai_Tham}', "");
Expect(1, 6832, '\P{Is_Blk=-Tai_Tham}', "");
Expect(0, 6832, '\P{^Is_Blk=-Tai_Tham}', "");
Error('\p{Block=-_Tai_VIET/a/}');
Error('\P{Block=-_Tai_VIET/a/}');
Expect(1, 43743, '\p{Block=taiviet}', "");
Expect(0, 43743, '\p{^Block=taiviet}', "");
Expect(0, 43743, '\P{Block=taiviet}', "");
Expect(1, 43743, '\P{^Block=taiviet}', "");
Expect(0, 43744, '\p{Block=taiviet}', "");
Expect(1, 43744, '\p{^Block=taiviet}', "");
Expect(1, 43744, '\P{Block=taiviet}', "");
Expect(0, 43744, '\P{^Block=taiviet}', "");
Expect(1, 43743, '\p{Block=_-TAI_viet}', "");
Expect(0, 43743, '\p{^Block=_-TAI_viet}', "");
Expect(0, 43743, '\P{Block=_-TAI_viet}', "");
Expect(1, 43743, '\P{^Block=_-TAI_viet}', "");
Expect(0, 43744, '\p{Block=_-TAI_viet}', "");
Expect(1, 43744, '\p{^Block=_-TAI_viet}', "");
Expect(1, 43744, '\P{Block=_-TAI_viet}', "");
Expect(0, 43744, '\P{^Block=_-TAI_viet}', "");
Error('\p{Blk=/a/Tai_viet}');
Error('\P{Blk=/a/Tai_viet}');
Expect(1, 43743, '\p{Blk=taiviet}', "");
Expect(0, 43743, '\p{^Blk=taiviet}', "");
Expect(0, 43743, '\P{Blk=taiviet}', "");
Expect(1, 43743, '\P{^Blk=taiviet}', "");
Expect(0, 43744, '\p{Blk=taiviet}', "");
Expect(1, 43744, '\p{^Blk=taiviet}', "");
Expect(1, 43744, '\P{Blk=taiviet}', "");
Expect(0, 43744, '\P{^Blk=taiviet}', "");
Expect(1, 43743, '\p{Blk=_tai_Viet}', "");
Expect(0, 43743, '\p{^Blk=_tai_Viet}', "");
Expect(0, 43743, '\P{Blk=_tai_Viet}', "");
Expect(1, 43743, '\P{^Blk=_tai_Viet}', "");
Expect(0, 43744, '\p{Blk=_tai_Viet}', "");
Expect(1, 43744, '\p{^Blk=_tai_Viet}', "");
Expect(1, 43744, '\P{Blk=_tai_Viet}', "");
Expect(0, 43744, '\P{^Blk=_tai_Viet}', "");
Error('\p{Is_Block=-:=tai_viet}');
Error('\P{Is_Block=-:=tai_viet}');
Expect(1, 43743, '\p{Is_Block=taiviet}', "");
Expect(0, 43743, '\p{^Is_Block=taiviet}', "");
Expect(0, 43743, '\P{Is_Block=taiviet}', "");
Expect(1, 43743, '\P{^Is_Block=taiviet}', "");
Expect(0, 43744, '\p{Is_Block=taiviet}', "");
Expect(1, 43744, '\p{^Is_Block=taiviet}', "");
Expect(1, 43744, '\P{Is_Block=taiviet}', "");
Expect(0, 43744, '\P{^Is_Block=taiviet}', "");
Expect(1, 43743, '\p{Is_Block=_-Tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Block=_-Tai_Viet}', "");
Expect(0, 43743, '\P{Is_Block=_-Tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Block=_-Tai_Viet}', "");
Expect(0, 43744, '\p{Is_Block=_-Tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Block=_-Tai_Viet}', "");
Expect(1, 43744, '\P{Is_Block=_-Tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Block=_-Tai_Viet}', "");
Error('\p{Is_Blk=:=- tai_Viet}');
Error('\P{Is_Blk=:=- tai_Viet}');
Expect(1, 43743, '\p{Is_Blk=taiviet}', "");
Expect(0, 43743, '\p{^Is_Blk=taiviet}', "");
Expect(0, 43743, '\P{Is_Blk=taiviet}', "");
Expect(1, 43743, '\P{^Is_Blk=taiviet}', "");
Expect(0, 43744, '\p{Is_Blk=taiviet}', "");
Expect(1, 43744, '\p{^Is_Blk=taiviet}', "");
Expect(1, 43744, '\P{Is_Blk=taiviet}', "");
Expect(0, 43744, '\P{^Is_Blk=taiviet}', "");
Expect(1, 43743, '\p{Is_Blk=	_TAI_viet}', "");
Expect(0, 43743, '\p{^Is_Blk=	_TAI_viet}', "");
Expect(0, 43743, '\P{Is_Blk=	_TAI_viet}', "");
Expect(1, 43743, '\P{^Is_Blk=	_TAI_viet}', "");
Expect(0, 43744, '\p{Is_Blk=	_TAI_viet}', "");
Expect(1, 43744, '\p{^Is_Blk=	_TAI_viet}', "");
Expect(1, 43744, '\P{Is_Blk=	_TAI_viet}', "");
Expect(0, 43744, '\P{^Is_Blk=	_TAI_viet}', "");
Error('\p{Block:_/a/Tai_XUAN_jing_Symbols}');
Error('\P{Block:_/a/Tai_XUAN_jing_Symbols}');
Expect(1, 119647, '\p{Block=taixuanjingsymbols}', "");
Expect(0, 119647, '\p{^Block=taixuanjingsymbols}', "");
Expect(0, 119647, '\P{Block=taixuanjingsymbols}', "");
Expect(1, 119647, '\P{^Block=taixuanjingsymbols}', "");
Expect(0, 119648, '\p{Block=taixuanjingsymbols}', "");
Expect(1, 119648, '\p{^Block=taixuanjingsymbols}', "");
Expect(1, 119648, '\P{Block=taixuanjingsymbols}', "");
Expect(0, 119648, '\P{^Block=taixuanjingsymbols}', "");
Expect(1, 119647, '\p{Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(0, 119647, '\p{^Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(0, 119647, '\P{Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(1, 119647, '\P{^Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(0, 119648, '\p{Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(1, 119648, '\p{^Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(1, 119648, '\P{Block=-Tai_Xuan_jing_SYMBOLS}', "");
Expect(0, 119648, '\P{^Block=-Tai_Xuan_jing_SYMBOLS}', "");
Error('\p{Blk=  Tai_XUAN_JING:=}');
Error('\P{Blk=  Tai_XUAN_JING:=}');
Expect(1, 119647, '\p{Blk=taixuanjing}', "");
Expect(0, 119647, '\p{^Blk=taixuanjing}', "");
Expect(0, 119647, '\P{Blk=taixuanjing}', "");
Expect(1, 119647, '\P{^Blk=taixuanjing}', "");
Expect(0, 119648, '\p{Blk=taixuanjing}', "");
Expect(1, 119648, '\p{^Blk=taixuanjing}', "");
Expect(1, 119648, '\P{Blk=taixuanjing}', "");
Expect(0, 119648, '\P{^Blk=taixuanjing}', "");
Expect(1, 119647, '\p{Blk:	 Tai_Xuan_Jing}', "");
Expect(0, 119647, '\p{^Blk:	 Tai_Xuan_Jing}', "");
Expect(0, 119647, '\P{Blk:	 Tai_Xuan_Jing}', "");
Expect(1, 119647, '\P{^Blk:	 Tai_Xuan_Jing}', "");
Expect(0, 119648, '\p{Blk:	 Tai_Xuan_Jing}', "");
Expect(1, 119648, '\p{^Blk:	 Tai_Xuan_Jing}', "");
Expect(1, 119648, '\P{Blk:	 Tai_Xuan_Jing}', "");
Expect(0, 119648, '\P{^Blk:	 Tai_Xuan_Jing}', "");
Error('\p{Is_Block=-:=Tai_Xuan_Jing_Symbols}');
Error('\P{Is_Block=-:=Tai_Xuan_Jing_Symbols}');
Expect(1, 119647, '\p{Is_Block: taixuanjingsymbols}', "");
Expect(0, 119647, '\p{^Is_Block: taixuanjingsymbols}', "");
Expect(0, 119647, '\P{Is_Block: taixuanjingsymbols}', "");
Expect(1, 119647, '\P{^Is_Block: taixuanjingsymbols}', "");
Expect(0, 119648, '\p{Is_Block: taixuanjingsymbols}', "");
Expect(1, 119648, '\p{^Is_Block: taixuanjingsymbols}', "");
Expect(1, 119648, '\P{Is_Block: taixuanjingsymbols}', "");
Expect(0, 119648, '\P{^Is_Block: taixuanjingsymbols}', "");
Expect(1, 119647, '\p{Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(0, 119647, '\p{^Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(0, 119647, '\P{Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(1, 119647, '\P{^Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(0, 119648, '\p{Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(1, 119648, '\p{^Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(1, 119648, '\P{Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Expect(0, 119648, '\P{^Is_Block=_ tai_Xuan_Jing_Symbols}', "");
Error('\p{Is_Blk=:=	-tai_Xuan_jing}');
Error('\P{Is_Blk=:=	-tai_Xuan_jing}');
Expect(1, 119647, '\p{Is_Blk=taixuanjing}', "");
Expect(0, 119647, '\p{^Is_Blk=taixuanjing}', "");
Expect(0, 119647, '\P{Is_Blk=taixuanjing}', "");
Expect(1, 119647, '\P{^Is_Blk=taixuanjing}', "");
Expect(0, 119648, '\p{Is_Blk=taixuanjing}', "");
Expect(1, 119648, '\p{^Is_Blk=taixuanjing}', "");
Expect(1, 119648, '\P{Is_Blk=taixuanjing}', "");
Expect(0, 119648, '\P{^Is_Blk=taixuanjing}', "");
Expect(1, 119647, '\p{Is_Blk=	 Tai_Xuan_jing}', "");
Expect(0, 119647, '\p{^Is_Blk=	 Tai_Xuan_jing}', "");
Expect(0, 119647, '\P{Is_Blk=	 Tai_Xuan_jing}', "");
Expect(1, 119647, '\P{^Is_Blk=	 Tai_Xuan_jing}', "");
Expect(0, 119648, '\p{Is_Blk=	 Tai_Xuan_jing}', "");
Expect(1, 119648, '\p{^Is_Blk=	 Tai_Xuan_jing}', "");
Expect(1, 119648, '\P{Is_Blk=	 Tai_Xuan_jing}', "");
Expect(0, 119648, '\P{^Is_Blk=	 Tai_Xuan_jing}', "");
Error('\p{Block=  Takri:=}');
Error('\P{Block=  Takri:=}');
Expect(1, 71375, '\p{Block=takri}', "");
Expect(0, 71375, '\p{^Block=takri}', "");
Expect(0, 71375, '\P{Block=takri}', "");
Expect(1, 71375, '\P{^Block=takri}', "");
Expect(0, 71376, '\p{Block=takri}', "");
Expect(1, 71376, '\p{^Block=takri}', "");
Expect(1, 71376, '\P{Block=takri}', "");
Expect(0, 71376, '\P{^Block=takri}', "");
Expect(1, 71375, '\p{Block=__TAKRI}', "");
Expect(0, 71375, '\p{^Block=__TAKRI}', "");
Expect(0, 71375, '\P{Block=__TAKRI}', "");
Expect(1, 71375, '\P{^Block=__TAKRI}', "");
Expect(0, 71376, '\p{Block=__TAKRI}', "");
Expect(1, 71376, '\p{^Block=__TAKRI}', "");
Expect(1, 71376, '\P{Block=__TAKRI}', "");
Expect(0, 71376, '\P{^Block=__TAKRI}', "");
Error('\p{Blk=	:=Takri}');
Error('\P{Blk=	:=Takri}');
Expect(1, 71375, '\p{Blk: takri}', "");
Expect(0, 71375, '\p{^Blk: takri}', "");
Expect(0, 71375, '\P{Blk: takri}', "");
Expect(1, 71375, '\P{^Blk: takri}', "");
Expect(0, 71376, '\p{Blk: takri}', "");
Expect(1, 71376, '\p{^Blk: takri}', "");
Expect(1, 71376, '\P{Blk: takri}', "");
Expect(0, 71376, '\P{^Blk: takri}', "");
Expect(1, 71375, '\p{Blk=	TAKRI}', "");
Expect(0, 71375, '\p{^Blk=	TAKRI}', "");
Expect(0, 71375, '\P{Blk=	TAKRI}', "");
Expect(1, 71375, '\P{^Blk=	TAKRI}', "");
Expect(0, 71376, '\p{Blk=	TAKRI}', "");
Expect(1, 71376, '\p{^Blk=	TAKRI}', "");
Expect(1, 71376, '\P{Blk=	TAKRI}', "");
Expect(0, 71376, '\P{^Blk=	TAKRI}', "");
Error('\p{Is_Block=/a/_ Takri}');
Error('\P{Is_Block=/a/_ Takri}');
Expect(1, 71375, '\p{Is_Block=takri}', "");
Expect(0, 71375, '\p{^Is_Block=takri}', "");
Expect(0, 71375, '\P{Is_Block=takri}', "");
Expect(1, 71375, '\P{^Is_Block=takri}', "");
Expect(0, 71376, '\p{Is_Block=takri}', "");
Expect(1, 71376, '\p{^Is_Block=takri}', "");
Expect(1, 71376, '\P{Is_Block=takri}', "");
Expect(0, 71376, '\P{^Is_Block=takri}', "");
Expect(1, 71375, '\p{Is_Block=TAKRI}', "");
Expect(0, 71375, '\p{^Is_Block=TAKRI}', "");
Expect(0, 71375, '\P{Is_Block=TAKRI}', "");
Expect(1, 71375, '\P{^Is_Block=TAKRI}', "");
Expect(0, 71376, '\p{Is_Block=TAKRI}', "");
Expect(1, 71376, '\p{^Is_Block=TAKRI}', "");
Expect(1, 71376, '\P{Is_Block=TAKRI}', "");
Expect(0, 71376, '\P{^Is_Block=TAKRI}', "");
Error('\p{Is_Blk=:=_TAKRI}');
Error('\P{Is_Blk=:=_TAKRI}');
Expect(1, 71375, '\p{Is_Blk=takri}', "");
Expect(0, 71375, '\p{^Is_Blk=takri}', "");
Expect(0, 71375, '\P{Is_Blk=takri}', "");
Expect(1, 71375, '\P{^Is_Blk=takri}', "");
Expect(0, 71376, '\p{Is_Blk=takri}', "");
Expect(1, 71376, '\p{^Is_Blk=takri}', "");
Expect(1, 71376, '\P{Is_Blk=takri}', "");
Expect(0, 71376, '\P{^Is_Blk=takri}', "");
Expect(1, 71375, '\p{Is_Blk=_takri}', "");
Expect(0, 71375, '\p{^Is_Blk=_takri}', "");
Expect(0, 71375, '\P{Is_Blk=_takri}', "");
Expect(1, 71375, '\P{^Is_Blk=_takri}', "");
Expect(0, 71376, '\p{Is_Blk=_takri}', "");
Expect(1, 71376, '\p{^Is_Blk=_takri}', "");
Expect(1, 71376, '\P{Is_Blk=_takri}', "");
Expect(0, 71376, '\P{^Is_Blk=_takri}', "");
Error('\p{Block=-_Tamil/a/}');
Error('\P{Block=-_Tamil/a/}');
Expect(1, 3071, '\p{Block=tamil}', "");
Expect(0, 3071, '\p{^Block=tamil}', "");
Expect(0, 3071, '\P{Block=tamil}', "");
Expect(1, 3071, '\P{^Block=tamil}', "");
Expect(0, 3072, '\p{Block=tamil}', "");
Expect(1, 3072, '\p{^Block=tamil}', "");
Expect(1, 3072, '\P{Block=tamil}', "");
Expect(0, 3072, '\P{^Block=tamil}', "");
Expect(1, 3071, '\p{Block=__TAMIL}', "");
Expect(0, 3071, '\p{^Block=__TAMIL}', "");
Expect(0, 3071, '\P{Block=__TAMIL}', "");
Expect(1, 3071, '\P{^Block=__TAMIL}', "");
Expect(0, 3072, '\p{Block=__TAMIL}', "");
Expect(1, 3072, '\p{^Block=__TAMIL}', "");
Expect(1, 3072, '\P{Block=__TAMIL}', "");
Expect(0, 3072, '\P{^Block=__TAMIL}', "");
Error('\p{Blk=_:=Tamil}');
Error('\P{Blk=_:=Tamil}');
Expect(1, 3071, '\p{Blk=tamil}', "");
Expect(0, 3071, '\p{^Blk=tamil}', "");
Expect(0, 3071, '\P{Blk=tamil}', "");
Expect(1, 3071, '\P{^Blk=tamil}', "");
Expect(0, 3072, '\p{Blk=tamil}', "");
Expect(1, 3072, '\p{^Blk=tamil}', "");
Expect(1, 3072, '\P{Blk=tamil}', "");
Expect(0, 3072, '\P{^Blk=tamil}', "");
Expect(1, 3071, '\p{Blk:		Tamil}', "");
Expect(0, 3071, '\p{^Blk:		Tamil}', "");
Expect(0, 3071, '\P{Blk:		Tamil}', "");
Expect(1, 3071, '\P{^Blk:		Tamil}', "");
Expect(0, 3072, '\p{Blk:		Tamil}', "");
Expect(1, 3072, '\p{^Blk:		Tamil}', "");
Expect(1, 3072, '\P{Blk:		Tamil}', "");
Expect(0, 3072, '\P{^Blk:		Tamil}', "");
Error('\p{Is_Block=	-TAMIL:=}');
Error('\P{Is_Block=	-TAMIL:=}');
Expect(1, 3071, '\p{Is_Block=tamil}', "");
Expect(0, 3071, '\p{^Is_Block=tamil}', "");
Expect(0, 3071, '\P{Is_Block=tamil}', "");
Expect(1, 3071, '\P{^Is_Block=tamil}', "");
Expect(0, 3072, '\p{Is_Block=tamil}', "");
Expect(1, 3072, '\p{^Is_Block=tamil}', "");
Expect(1, 3072, '\P{Is_Block=tamil}', "");
Expect(0, 3072, '\P{^Is_Block=tamil}', "");
Expect(1, 3071, '\p{Is_Block=-_tamil}', "");
Expect(0, 3071, '\p{^Is_Block=-_tamil}', "");
Expect(0, 3071, '\P{Is_Block=-_tamil}', "");
Expect(1, 3071, '\P{^Is_Block=-_tamil}', "");
Expect(0, 3072, '\p{Is_Block=-_tamil}', "");
Expect(1, 3072, '\p{^Is_Block=-_tamil}', "");
Expect(1, 3072, '\P{Is_Block=-_tamil}', "");
Expect(0, 3072, '\P{^Is_Block=-_tamil}', "");
Error('\p{Is_Blk=:=Tamil}');
Error('\P{Is_Blk=:=Tamil}');
Expect(1, 3071, '\p{Is_Blk=tamil}', "");
Expect(0, 3071, '\p{^Is_Blk=tamil}', "");
Expect(0, 3071, '\P{Is_Blk=tamil}', "");
Expect(1, 3071, '\P{^Is_Blk=tamil}', "");
Expect(0, 3072, '\p{Is_Blk=tamil}', "");
Expect(1, 3072, '\p{^Is_Blk=tamil}', "");
Expect(1, 3072, '\P{Is_Blk=tamil}', "");
Expect(0, 3072, '\P{^Is_Blk=tamil}', "");
Expect(1, 3071, '\p{Is_Blk=-	Tamil}', "");
Expect(0, 3071, '\p{^Is_Blk=-	Tamil}', "");
Expect(0, 3071, '\P{Is_Blk=-	Tamil}', "");
Expect(1, 3071, '\P{^Is_Blk=-	Tamil}', "");
Expect(0, 3072, '\p{Is_Blk=-	Tamil}', "");
Expect(1, 3072, '\p{^Is_Blk=-	Tamil}', "");
Expect(1, 3072, '\P{Is_Blk=-	Tamil}', "");
Expect(0, 3072, '\P{^Is_Blk=-	Tamil}', "");
Error('\p{Block=:=	Telugu}');
Error('\P{Block=:=	Telugu}');
Expect(1, 3199, '\p{Block=telugu}', "");
Expect(0, 3199, '\p{^Block=telugu}', "");
Expect(0, 3199, '\P{Block=telugu}', "");
Expect(1, 3199, '\P{^Block=telugu}', "");
Expect(0, 3200, '\p{Block=telugu}', "");
Expect(1, 3200, '\p{^Block=telugu}', "");
Expect(1, 3200, '\P{Block=telugu}', "");
Expect(0, 3200, '\P{^Block=telugu}', "");
Expect(1, 3199, '\p{Block= -Telugu}', "");
Expect(0, 3199, '\p{^Block= -Telugu}', "");
Expect(0, 3199, '\P{Block= -Telugu}', "");
Expect(1, 3199, '\P{^Block= -Telugu}', "");
Expect(0, 3200, '\p{Block= -Telugu}', "");
Expect(1, 3200, '\p{^Block= -Telugu}', "");
Expect(1, 3200, '\P{Block= -Telugu}', "");
Expect(0, 3200, '\P{^Block= -Telugu}', "");
Error('\p{Blk=-/a/Telugu}');
Error('\P{Blk=-/a/Telugu}');
Expect(1, 3199, '\p{Blk=telugu}', "");
Expect(0, 3199, '\p{^Blk=telugu}', "");
Expect(0, 3199, '\P{Blk=telugu}', "");
Expect(1, 3199, '\P{^Blk=telugu}', "");
Expect(0, 3200, '\p{Blk=telugu}', "");
Expect(1, 3200, '\p{^Blk=telugu}', "");
Expect(1, 3200, '\P{Blk=telugu}', "");
Expect(0, 3200, '\P{^Blk=telugu}', "");
Expect(1, 3199, '\p{Blk=	_TELUGU}', "");
Expect(0, 3199, '\p{^Blk=	_TELUGU}', "");
Expect(0, 3199, '\P{Blk=	_TELUGU}', "");
Expect(1, 3199, '\P{^Blk=	_TELUGU}', "");
Expect(0, 3200, '\p{Blk=	_TELUGU}', "");
Expect(1, 3200, '\p{^Blk=	_TELUGU}', "");
Expect(1, 3200, '\P{Blk=	_TELUGU}', "");
Expect(0, 3200, '\P{^Blk=	_TELUGU}', "");
Error('\p{Is_Block=  Telugu:=}');
Error('\P{Is_Block=  Telugu:=}');
Expect(1, 3199, '\p{Is_Block=telugu}', "");
Expect(0, 3199, '\p{^Is_Block=telugu}', "");
Expect(0, 3199, '\P{Is_Block=telugu}', "");
Expect(1, 3199, '\P{^Is_Block=telugu}', "");
Expect(0, 3200, '\p{Is_Block=telugu}', "");
Expect(1, 3200, '\p{^Is_Block=telugu}', "");
Expect(1, 3200, '\P{Is_Block=telugu}', "");
Expect(0, 3200, '\P{^Is_Block=telugu}', "");
Expect(1, 3199, '\p{Is_Block=_telugu}', "");
Expect(0, 3199, '\p{^Is_Block=_telugu}', "");
Expect(0, 3199, '\P{Is_Block=_telugu}', "");
Expect(1, 3199, '\P{^Is_Block=_telugu}', "");
Expect(0, 3200, '\p{Is_Block=_telugu}', "");
Expect(1, 3200, '\p{^Is_Block=_telugu}', "");
Expect(1, 3200, '\P{Is_Block=_telugu}', "");
Expect(0, 3200, '\P{^Is_Block=_telugu}', "");
Error('\p{Is_Blk=-/a/TELUGU}');
Error('\P{Is_Blk=-/a/TELUGU}');
Expect(1, 3199, '\p{Is_Blk=telugu}', "");
Expect(0, 3199, '\p{^Is_Blk=telugu}', "");
Expect(0, 3199, '\P{Is_Blk=telugu}', "");
Expect(1, 3199, '\P{^Is_Blk=telugu}', "");
Expect(0, 3200, '\p{Is_Blk=telugu}', "");
Expect(1, 3200, '\p{^Is_Blk=telugu}', "");
Expect(1, 3200, '\P{Is_Blk=telugu}', "");
Expect(0, 3200, '\P{^Is_Blk=telugu}', "");
Expect(1, 3199, '\p{Is_Blk=  Telugu}', "");
Expect(0, 3199, '\p{^Is_Blk=  Telugu}', "");
Expect(0, 3199, '\P{Is_Blk=  Telugu}', "");
Expect(1, 3199, '\P{^Is_Blk=  Telugu}', "");
Expect(0, 3200, '\p{Is_Blk=  Telugu}', "");
Expect(1, 3200, '\p{^Is_Blk=  Telugu}', "");
Expect(1, 3200, '\P{Is_Blk=  Telugu}', "");
Expect(0, 3200, '\P{^Is_Blk=  Telugu}', "");
Error('\p{Block=:=	Thaana}');
Error('\P{Block=:=	Thaana}');
Expect(1, 1983, '\p{Block=thaana}', "");
Expect(0, 1983, '\p{^Block=thaana}', "");
Expect(0, 1983, '\P{Block=thaana}', "");
Expect(1, 1983, '\P{^Block=thaana}', "");
Expect(0, 1984, '\p{Block=thaana}', "");
Expect(1, 1984, '\p{^Block=thaana}', "");
Expect(1, 1984, '\P{Block=thaana}', "");
Expect(0, 1984, '\P{^Block=thaana}', "");
Expect(1, 1983, '\p{Block=-THAANA}', "");
Expect(0, 1983, '\p{^Block=-THAANA}', "");
Expect(0, 1983, '\P{Block=-THAANA}', "");
Expect(1, 1983, '\P{^Block=-THAANA}', "");
Expect(0, 1984, '\p{Block=-THAANA}', "");
Expect(1, 1984, '\p{^Block=-THAANA}', "");
Expect(1, 1984, '\P{Block=-THAANA}', "");
Expect(0, 1984, '\P{^Block=-THAANA}', "");
Error('\p{Blk=:=  thaana}');
Error('\P{Blk=:=  thaana}');
Expect(1, 1983, '\p{Blk=thaana}', "");
Expect(0, 1983, '\p{^Blk=thaana}', "");
Expect(0, 1983, '\P{Blk=thaana}', "");
Expect(1, 1983, '\P{^Blk=thaana}', "");
Expect(0, 1984, '\p{Blk=thaana}', "");
Expect(1, 1984, '\p{^Blk=thaana}', "");
Expect(1, 1984, '\P{Blk=thaana}', "");
Expect(0, 1984, '\P{^Blk=thaana}', "");
Expect(1, 1983, '\p{Blk=_THAANA}', "");
Expect(0, 1983, '\p{^Blk=_THAANA}', "");
Expect(0, 1983, '\P{Blk=_THAANA}', "");
Expect(1, 1983, '\P{^Blk=_THAANA}', "");
Expect(0, 1984, '\p{Blk=_THAANA}', "");
Expect(1, 1984, '\p{^Blk=_THAANA}', "");
Expect(1, 1984, '\P{Blk=_THAANA}', "");
Expect(0, 1984, '\P{^Blk=_THAANA}', "");
Error('\p{Is_Block=/a/thaana}');
Error('\P{Is_Block=/a/thaana}');
Expect(1, 1983, '\p{Is_Block: thaana}', "");
Expect(0, 1983, '\p{^Is_Block: thaana}', "");
Expect(0, 1983, '\P{Is_Block: thaana}', "");
Expect(1, 1983, '\P{^Is_Block: thaana}', "");
Expect(0, 1984, '\p{Is_Block: thaana}', "");
Expect(1, 1984, '\p{^Is_Block: thaana}', "");
Expect(1, 1984, '\P{Is_Block: thaana}', "");
Expect(0, 1984, '\P{^Is_Block: thaana}', "");
Expect(1, 1983, '\p{Is_Block=__Thaana}', "");
Expect(0, 1983, '\p{^Is_Block=__Thaana}', "");
Expect(0, 1983, '\P{Is_Block=__Thaana}', "");
Expect(1, 1983, '\P{^Is_Block=__Thaana}', "");
Expect(0, 1984, '\p{Is_Block=__Thaana}', "");
Expect(1, 1984, '\p{^Is_Block=__Thaana}', "");
Expect(1, 1984, '\P{Is_Block=__Thaana}', "");
Expect(0, 1984, '\P{^Is_Block=__Thaana}', "");
Error('\p{Is_Blk=_THAANA/a/}');
Error('\P{Is_Blk=_THAANA/a/}');
Expect(1, 1983, '\p{Is_Blk=thaana}', "");
Expect(0, 1983, '\p{^Is_Blk=thaana}', "");
Expect(0, 1983, '\P{Is_Blk=thaana}', "");
Expect(1, 1983, '\P{^Is_Blk=thaana}', "");
Expect(0, 1984, '\p{Is_Blk=thaana}', "");
Expect(1, 1984, '\p{^Is_Blk=thaana}', "");
Expect(1, 1984, '\P{Is_Blk=thaana}', "");
Expect(0, 1984, '\P{^Is_Blk=thaana}', "");
Expect(1, 1983, '\p{Is_Blk=	THAANA}', "");
Expect(0, 1983, '\p{^Is_Blk=	THAANA}', "");
Expect(0, 1983, '\P{Is_Blk=	THAANA}', "");
Expect(1, 1983, '\P{^Is_Blk=	THAANA}', "");
Expect(0, 1984, '\p{Is_Blk=	THAANA}', "");
Expect(1, 1984, '\p{^Is_Blk=	THAANA}', "");
Expect(1, 1984, '\P{Is_Blk=	THAANA}', "");
Expect(0, 1984, '\P{^Is_Blk=	THAANA}', "");
Error('\p{Block=/a/_Thai}');
Error('\P{Block=/a/_Thai}');
Expect(1, 3711, '\p{Block=thai}', "");
Expect(0, 3711, '\p{^Block=thai}', "");
Expect(0, 3711, '\P{Block=thai}', "");
Expect(1, 3711, '\P{^Block=thai}', "");
Expect(0, 3712, '\p{Block=thai}', "");
Expect(1, 3712, '\p{^Block=thai}', "");
Expect(1, 3712, '\P{Block=thai}', "");
Expect(0, 3712, '\P{^Block=thai}', "");
Expect(1, 3711, '\p{Block: -Thai}', "");
Expect(0, 3711, '\p{^Block: -Thai}', "");
Expect(0, 3711, '\P{Block: -Thai}', "");
Expect(1, 3711, '\P{^Block: -Thai}', "");
Expect(0, 3712, '\p{Block: -Thai}', "");
Expect(1, 3712, '\p{^Block: -Thai}', "");
Expect(1, 3712, '\P{Block: -Thai}', "");
Expect(0, 3712, '\P{^Block: -Thai}', "");
Error('\p{Blk=/a/ _Thai}');
Error('\P{Blk=/a/ _Thai}');
Expect(1, 3711, '\p{Blk=thai}', "");
Expect(0, 3711, '\p{^Blk=thai}', "");
Expect(0, 3711, '\P{Blk=thai}', "");
Expect(1, 3711, '\P{^Blk=thai}', "");
Expect(0, 3712, '\p{Blk=thai}', "");
Expect(1, 3712, '\p{^Blk=thai}', "");
Expect(1, 3712, '\P{Blk=thai}', "");
Expect(0, 3712, '\P{^Blk=thai}', "");
Expect(1, 3711, '\p{Blk:    THAI}', "");
Expect(0, 3711, '\p{^Blk:    THAI}', "");
Expect(0, 3711, '\P{Blk:    THAI}', "");
Expect(1, 3711, '\P{^Blk:    THAI}', "");
Expect(0, 3712, '\p{Blk:    THAI}', "");
Expect(1, 3712, '\p{^Blk:    THAI}', "");
Expect(1, 3712, '\P{Blk:    THAI}', "");
Expect(0, 3712, '\P{^Blk:    THAI}', "");
Error('\p{Is_Block=_:=thai}');
Error('\P{Is_Block=_:=thai}');
Expect(1, 3711, '\p{Is_Block=thai}', "");
Expect(0, 3711, '\p{^Is_Block=thai}', "");
Expect(0, 3711, '\P{Is_Block=thai}', "");
Expect(1, 3711, '\P{^Is_Block=thai}', "");
Expect(0, 3712, '\p{Is_Block=thai}', "");
Expect(1, 3712, '\p{^Is_Block=thai}', "");
Expect(1, 3712, '\P{Is_Block=thai}', "");
Expect(0, 3712, '\P{^Is_Block=thai}', "");
Expect(1, 3711, '\p{Is_Block: 	Thai}', "");
Expect(0, 3711, '\p{^Is_Block: 	Thai}', "");
Expect(0, 3711, '\P{Is_Block: 	Thai}', "");
Expect(1, 3711, '\P{^Is_Block: 	Thai}', "");
Expect(0, 3712, '\p{Is_Block: 	Thai}', "");
Expect(1, 3712, '\p{^Is_Block: 	Thai}', "");
Expect(1, 3712, '\P{Is_Block: 	Thai}', "");
Expect(0, 3712, '\P{^Is_Block: 	Thai}', "");
Error('\p{Is_Blk= _thai/a/}');
Error('\P{Is_Blk= _thai/a/}');
Expect(1, 3711, '\p{Is_Blk=thai}', "");
Expect(0, 3711, '\p{^Is_Blk=thai}', "");
Expect(0, 3711, '\P{Is_Blk=thai}', "");
Expect(1, 3711, '\P{^Is_Blk=thai}', "");
Expect(0, 3712, '\p{Is_Blk=thai}', "");
Expect(1, 3712, '\p{^Is_Blk=thai}', "");
Expect(1, 3712, '\P{Is_Blk=thai}', "");
Expect(0, 3712, '\P{^Is_Blk=thai}', "");
Expect(1, 3711, '\p{Is_Blk=_THAI}', "");
Expect(0, 3711, '\p{^Is_Blk=_THAI}', "");
Expect(0, 3711, '\P{Is_Blk=_THAI}', "");
Expect(1, 3711, '\P{^Is_Blk=_THAI}', "");
Expect(0, 3712, '\p{Is_Blk=_THAI}', "");
Expect(1, 3712, '\p{^Is_Blk=_THAI}', "");
Expect(1, 3712, '\P{Is_Blk=_THAI}', "");
Expect(0, 3712, '\P{^Is_Blk=_THAI}', "");
Error('\p{Block:	/a/ -TIBETAN}');
Error('\P{Block:	/a/ -TIBETAN}');
Expect(1, 4095, '\p{Block=tibetan}', "");
Expect(0, 4095, '\p{^Block=tibetan}', "");
Expect(0, 4095, '\P{Block=tibetan}', "");
Expect(1, 4095, '\P{^Block=tibetan}', "");
Expect(0, 4096, '\p{Block=tibetan}', "");
Expect(1, 4096, '\p{^Block=tibetan}', "");
Expect(1, 4096, '\P{Block=tibetan}', "");
Expect(0, 4096, '\P{^Block=tibetan}', "");
Error('\p{Blk=/a/	_Tibetan}');
Error('\P{Blk=/a/	_Tibetan}');
Expect(1, 4095, '\p{Blk=tibetan}', "");
Expect(0, 4095, '\p{^Blk=tibetan}', "");
Expect(0, 4095, '\P{Blk=tibetan}', "");
Expect(1, 4095, '\P{^Blk=tibetan}', "");
Expect(0, 4096, '\p{Blk=tibetan}', "");
Expect(1, 4096, '\p{^Blk=tibetan}', "");
Expect(1, 4096, '\P{Blk=tibetan}', "");
Expect(0, 4096, '\P{^Blk=tibetan}', "");
Expect(1, 4095, '\p{Blk:	_Tibetan}', "");
Expect(0, 4095, '\p{^Blk:	_Tibetan}', "");
Expect(0, 4095, '\P{Blk:	_Tibetan}', "");
Expect(1, 4095, '\P{^Blk:	_Tibetan}', "");
Expect(0, 4096, '\p{Blk:	_Tibetan}', "");
Expect(1, 4096, '\p{^Blk:	_Tibetan}', "");
Expect(1, 4096, '\P{Blk:	_Tibetan}', "");
Expect(0, 4096, '\P{^Blk:	_Tibetan}', "");
Error('\p{Is_Block=:=Tibetan}');
Error('\P{Is_Block=:=Tibetan}');
Expect(1, 4095, '\p{Is_Block=tibetan}', "");
Expect(0, 4095, '\p{^Is_Block=tibetan}', "");
Expect(0, 4095, '\P{Is_Block=tibetan}', "");
Expect(1, 4095, '\P{^Is_Block=tibetan}', "");
Expect(0, 4096, '\p{Is_Block=tibetan}', "");
Expect(1, 4096, '\p{^Is_Block=tibetan}', "");
Expect(1, 4096, '\P{Is_Block=tibetan}', "");
Expect(0, 4096, '\P{^Is_Block=tibetan}', "");
Expect(1, 4095, '\p{Is_Block=-Tibetan}', "");
Expect(0, 4095, '\p{^Is_Block=-Tibetan}', "");
Expect(0, 4095, '\P{Is_Block=-Tibetan}', "");
Expect(1, 4095, '\P{^Is_Block=-Tibetan}', "");
Expect(0, 4096, '\p{Is_Block=-Tibetan}', "");
Expect(1, 4096, '\p{^Is_Block=-Tibetan}', "");
Expect(1, 4096, '\P{Is_Block=-Tibetan}', "");
Expect(0, 4096, '\P{^Is_Block=-Tibetan}', "");
Error('\p{Is_Blk=:=--Tibetan}');
Error('\P{Is_Blk=:=--Tibetan}');
Expect(1, 4095, '\p{Is_Blk=tibetan}', "");
Expect(0, 4095, '\p{^Is_Blk=tibetan}', "");
Expect(0, 4095, '\P{Is_Blk=tibetan}', "");
Expect(1, 4095, '\P{^Is_Blk=tibetan}', "");
Expect(0, 4096, '\p{Is_Blk=tibetan}', "");
Expect(1, 4096, '\p{^Is_Blk=tibetan}', "");
Expect(1, 4096, '\P{Is_Blk=tibetan}', "");
Expect(0, 4096, '\P{^Is_Blk=tibetan}', "");
Expect(1, 4095, '\p{Is_Blk=TIBETAN}', "");
Expect(0, 4095, '\p{^Is_Blk=TIBETAN}', "");
Expect(0, 4095, '\P{Is_Blk=TIBETAN}', "");
Expect(1, 4095, '\P{^Is_Blk=TIBETAN}', "");
Expect(0, 4096, '\p{Is_Blk=TIBETAN}', "");
Expect(1, 4096, '\p{^Is_Blk=TIBETAN}', "");
Expect(1, 4096, '\P{Is_Blk=TIBETAN}', "");
Expect(0, 4096, '\P{^Is_Blk=TIBETAN}', "");
Error('\p{Block=		Tifinagh/a/}');
Error('\P{Block=		Tifinagh/a/}');
Expect(1, 11647, '\p{Block=tifinagh}', "");
Expect(0, 11647, '\p{^Block=tifinagh}', "");
Expect(0, 11647, '\P{Block=tifinagh}', "");
Expect(1, 11647, '\P{^Block=tifinagh}', "");
Expect(0, 11648, '\p{Block=tifinagh}', "");
Expect(1, 11648, '\p{^Block=tifinagh}', "");
Expect(1, 11648, '\P{Block=tifinagh}', "");
Expect(0, 11648, '\P{^Block=tifinagh}', "");
Expect(1, 11647, '\p{Block= -TIFINAGH}', "");
Expect(0, 11647, '\p{^Block= -TIFINAGH}', "");
Expect(0, 11647, '\P{Block= -TIFINAGH}', "");
Expect(1, 11647, '\P{^Block= -TIFINAGH}', "");
Expect(0, 11648, '\p{Block= -TIFINAGH}', "");
Expect(1, 11648, '\p{^Block= -TIFINAGH}', "");
Expect(1, 11648, '\P{Block= -TIFINAGH}', "");
Expect(0, 11648, '\P{^Block= -TIFINAGH}', "");
Error('\p{Blk=/a/-Tifinagh}');
Error('\P{Blk=/a/-Tifinagh}');
Expect(1, 11647, '\p{Blk=tifinagh}', "");
Expect(0, 11647, '\p{^Blk=tifinagh}', "");
Expect(0, 11647, '\P{Blk=tifinagh}', "");
Expect(1, 11647, '\P{^Blk=tifinagh}', "");
Expect(0, 11648, '\p{Blk=tifinagh}', "");
Expect(1, 11648, '\p{^Blk=tifinagh}', "");
Expect(1, 11648, '\P{Blk=tifinagh}', "");
Expect(0, 11648, '\P{^Blk=tifinagh}', "");
Expect(1, 11647, '\p{Blk:	--Tifinagh}', "");
Expect(0, 11647, '\p{^Blk:	--Tifinagh}', "");
Expect(0, 11647, '\P{Blk:	--Tifinagh}', "");
Expect(1, 11647, '\P{^Blk:	--Tifinagh}', "");
Expect(0, 11648, '\p{Blk:	--Tifinagh}', "");
Expect(1, 11648, '\p{^Blk:	--Tifinagh}', "");
Expect(1, 11648, '\P{Blk:	--Tifinagh}', "");
Expect(0, 11648, '\P{^Blk:	--Tifinagh}', "");
Error('\p{Is_Block=_/a/Tifinagh}');
Error('\P{Is_Block=_/a/Tifinagh}');
Expect(1, 11647, '\p{Is_Block=tifinagh}', "");
Expect(0, 11647, '\p{^Is_Block=tifinagh}', "");
Expect(0, 11647, '\P{Is_Block=tifinagh}', "");
Expect(1, 11647, '\P{^Is_Block=tifinagh}', "");
Expect(0, 11648, '\p{Is_Block=tifinagh}', "");
Expect(1, 11648, '\p{^Is_Block=tifinagh}', "");
Expect(1, 11648, '\P{Is_Block=tifinagh}', "");
Expect(0, 11648, '\P{^Is_Block=tifinagh}', "");
Expect(1, 11647, '\p{Is_Block:   _ TIFINAGH}', "");
Expect(0, 11647, '\p{^Is_Block:   _ TIFINAGH}', "");
Expect(0, 11647, '\P{Is_Block:   _ TIFINAGH}', "");
Expect(1, 11647, '\P{^Is_Block:   _ TIFINAGH}', "");
Expect(0, 11648, '\p{Is_Block:   _ TIFINAGH}', "");
Expect(1, 11648, '\p{^Is_Block:   _ TIFINAGH}', "");
Expect(1, 11648, '\P{Is_Block:   _ TIFINAGH}', "");
Expect(0, 11648, '\P{^Is_Block:   _ TIFINAGH}', "");
Error('\p{Is_Blk:/a/_	Tifinagh}');
Error('\P{Is_Blk:/a/_	Tifinagh}');
Expect(1, 11647, '\p{Is_Blk=tifinagh}', "");
Expect(0, 11647, '\p{^Is_Blk=tifinagh}', "");
Expect(0, 11647, '\P{Is_Blk=tifinagh}', "");
Expect(1, 11647, '\P{^Is_Blk=tifinagh}', "");
Expect(0, 11648, '\p{Is_Blk=tifinagh}', "");
Expect(1, 11648, '\p{^Is_Blk=tifinagh}', "");
Expect(1, 11648, '\P{Is_Blk=tifinagh}', "");
Expect(0, 11648, '\P{^Is_Blk=tifinagh}', "");
Expect(1, 11647, '\p{Is_Blk=_Tifinagh}', "");
Expect(0, 11647, '\p{^Is_Blk=_Tifinagh}', "");
Expect(0, 11647, '\P{Is_Blk=_Tifinagh}', "");
Expect(1, 11647, '\P{^Is_Blk=_Tifinagh}', "");
Expect(0, 11648, '\p{Is_Blk=_Tifinagh}', "");
Expect(1, 11648, '\p{^Is_Blk=_Tifinagh}', "");
Expect(1, 11648, '\P{Is_Blk=_Tifinagh}', "");
Expect(0, 11648, '\P{^Is_Blk=_Tifinagh}', "");
Error('\p{Block=	:=Transport_and_Map_symbols}');
Error('\P{Block=	:=Transport_and_Map_symbols}');
Expect(1, 128767, '\p{Block=transportandmapsymbols}', "");
Expect(0, 128767, '\p{^Block=transportandmapsymbols}', "");
Expect(0, 128767, '\P{Block=transportandmapsymbols}', "");
Expect(1, 128767, '\P{^Block=transportandmapsymbols}', "");
Expect(0, 128768, '\p{Block=transportandmapsymbols}', "");
Expect(1, 128768, '\p{^Block=transportandmapsymbols}', "");
Expect(1, 128768, '\P{Block=transportandmapsymbols}', "");
Expect(0, 128768, '\P{^Block=transportandmapsymbols}', "");
Expect(1, 128767, '\p{Block=	_transport_and_Map_symbols}', "");
Expect(0, 128767, '\p{^Block=	_transport_and_Map_symbols}', "");
Expect(0, 128767, '\P{Block=	_transport_and_Map_symbols}', "");
Expect(1, 128767, '\P{^Block=	_transport_and_Map_symbols}', "");
Expect(0, 128768, '\p{Block=	_transport_and_Map_symbols}', "");
Expect(1, 128768, '\p{^Block=	_transport_and_Map_symbols}', "");
Expect(1, 128768, '\P{Block=	_transport_and_Map_symbols}', "");
Expect(0, 128768, '\P{^Block=	_transport_and_Map_symbols}', "");
Error('\p{Blk=:= _transport_And_map}');
Error('\P{Blk=:= _transport_And_map}');
Expect(1, 128767, '\p{Blk=transportandmap}', "");
Expect(0, 128767, '\p{^Blk=transportandmap}', "");
Expect(0, 128767, '\P{Blk=transportandmap}', "");
Expect(1, 128767, '\P{^Blk=transportandmap}', "");
Expect(0, 128768, '\p{Blk=transportandmap}', "");
Expect(1, 128768, '\p{^Blk=transportandmap}', "");
Expect(1, 128768, '\P{Blk=transportandmap}', "");
Expect(0, 128768, '\P{^Blk=transportandmap}', "");
Expect(1, 128767, '\p{Blk=-Transport_and_Map}', "");
Expect(0, 128767, '\p{^Blk=-Transport_and_Map}', "");
Expect(0, 128767, '\P{Blk=-Transport_and_Map}', "");
Expect(1, 128767, '\P{^Blk=-Transport_and_Map}', "");
Expect(0, 128768, '\p{Blk=-Transport_and_Map}', "");
Expect(1, 128768, '\p{^Blk=-Transport_and_Map}', "");
Expect(1, 128768, '\P{Blk=-Transport_and_Map}', "");
Expect(0, 128768, '\P{^Blk=-Transport_and_Map}', "");
Error('\p{Is_Block= :=Transport_And_Map_symbols}');
Error('\P{Is_Block= :=Transport_And_Map_symbols}');
Expect(1, 128767, '\p{Is_Block:   transportandmapsymbols}', "");
Expect(0, 128767, '\p{^Is_Block:   transportandmapsymbols}', "");
Expect(0, 128767, '\P{Is_Block:   transportandmapsymbols}', "");
Expect(1, 128767, '\P{^Is_Block:   transportandmapsymbols}', "");
Expect(0, 128768, '\p{Is_Block:   transportandmapsymbols}', "");
Expect(1, 128768, '\p{^Is_Block:   transportandmapsymbols}', "");
Expect(1, 128768, '\P{Is_Block:   transportandmapsymbols}', "");
Expect(0, 128768, '\P{^Is_Block:   transportandmapsymbols}', "");
Expect(1, 128767, '\p{Is_Block=	_Transport_and_Map_symbols}', "");
Expect(0, 128767, '\p{^Is_Block=	_Transport_and_Map_symbols}', "");
Expect(0, 128767, '\P{Is_Block=	_Transport_and_Map_symbols}', "");
Expect(1, 128767, '\P{^Is_Block=	_Transport_and_Map_symbols}', "");
Expect(0, 128768, '\p{Is_Block=	_Transport_and_Map_symbols}', "");
Expect(1, 128768, '\p{^Is_Block=	_Transport_and_Map_symbols}', "");
Expect(1, 128768, '\P{Is_Block=	_Transport_and_Map_symbols}', "");
Expect(0, 128768, '\P{^Is_Block=	_Transport_and_Map_symbols}', "");
Error('\p{Is_Blk=/a/- Transport_AND_Map}');
Error('\P{Is_Blk=/a/- Transport_AND_Map}');
Expect(1, 128767, '\p{Is_Blk=transportandmap}', "");
Expect(0, 128767, '\p{^Is_Blk=transportandmap}', "");
Expect(0, 128767, '\P{Is_Blk=transportandmap}', "");
Expect(1, 128767, '\P{^Is_Blk=transportandmap}', "");
Expect(0, 128768, '\p{Is_Blk=transportandmap}', "");
Expect(1, 128768, '\p{^Is_Blk=transportandmap}', "");
Expect(1, 128768, '\P{Is_Blk=transportandmap}', "");
Expect(0, 128768, '\P{^Is_Blk=transportandmap}', "");
Expect(1, 128767, '\p{Is_Blk=- transport_AND_Map}', "");
Expect(0, 128767, '\p{^Is_Blk=- transport_AND_Map}', "");
Expect(0, 128767, '\P{Is_Blk=- transport_AND_Map}', "");
Expect(1, 128767, '\P{^Is_Blk=- transport_AND_Map}', "");
Expect(0, 128768, '\p{Is_Blk=- transport_AND_Map}', "");
Expect(1, 128768, '\p{^Is_Blk=- transport_AND_Map}', "");
Expect(1, 128768, '\P{Is_Blk=- transport_AND_Map}', "");
Expect(0, 128768, '\P{^Is_Blk=- transport_AND_Map}', "");
Error('\p{Block=	:=unified_Canadian_Aboriginal_Syllabics}');
Error('\P{Block=	:=unified_Canadian_Aboriginal_Syllabics}');
Expect(1, 5759, '\p{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^Block=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^Block= unified_CANADIAN_Aboriginal_Syllabics}', "");
Error('\p{Blk=/a/_ucas}');
Error('\P{Blk=/a/_ucas}');
Expect(1, 5759, '\p{Blk=ucas}', "");
Expect(0, 5759, '\p{^Blk=ucas}', "");
Expect(0, 5759, '\P{Blk=ucas}', "");
Expect(1, 5759, '\P{^Blk=ucas}', "");
Expect(0, 5760, '\p{Blk=ucas}', "");
Expect(1, 5760, '\p{^Blk=ucas}', "");
Expect(1, 5760, '\P{Blk=ucas}', "");
Expect(0, 5760, '\P{^Blk=ucas}', "");
Expect(1, 5759, '\p{Blk= 	UCAS}', "");
Expect(0, 5759, '\p{^Blk= 	UCAS}', "");
Expect(0, 5759, '\P{Blk= 	UCAS}', "");
Expect(1, 5759, '\P{^Blk= 	UCAS}', "");
Expect(0, 5760, '\p{Blk= 	UCAS}', "");
Expect(1, 5760, '\p{^Blk= 	UCAS}', "");
Expect(1, 5760, '\P{Blk= 	UCAS}', "");
Expect(0, 5760, '\P{^Blk= 	UCAS}', "");
Error('\p{Is_Block: /a/CANADIAN_SYLLABICS}');
Error('\P{Is_Block: /a/CANADIAN_SYLLABICS}');
Expect(1, 5759, '\p{Is_Block=canadiansyllabics}', "");
Expect(0, 5759, '\p{^Is_Block=canadiansyllabics}', "");
Expect(0, 5759, '\P{Is_Block=canadiansyllabics}', "");
Expect(1, 5759, '\P{^Is_Block=canadiansyllabics}', "");
Expect(0, 5760, '\p{Is_Block=canadiansyllabics}', "");
Expect(1, 5760, '\p{^Is_Block=canadiansyllabics}', "");
Expect(1, 5760, '\P{Is_Block=canadiansyllabics}', "");
Expect(0, 5760, '\P{^Is_Block=canadiansyllabics}', "");
Expect(1, 5759, '\p{Is_Block=_Canadian_Syllabics}', "");
Expect(0, 5759, '\p{^Is_Block=_Canadian_Syllabics}', "");
Expect(0, 5759, '\P{Is_Block=_Canadian_Syllabics}', "");
Expect(1, 5759, '\P{^Is_Block=_Canadian_Syllabics}', "");
Expect(0, 5760, '\p{Is_Block=_Canadian_Syllabics}', "");
Expect(1, 5760, '\p{^Is_Block=_Canadian_Syllabics}', "");
Expect(1, 5760, '\P{Is_Block=_Canadian_Syllabics}', "");
Expect(0, 5760, '\P{^Is_Block=_Canadian_Syllabics}', "");
Error('\p{Is_Blk: :=--UNIFIED_Canadian_ABORIGINAL_Syllabics}');
Error('\P{Is_Blk: :=--UNIFIED_Canadian_ABORIGINAL_Syllabics}');
Expect(1, 5759, '\p{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^Is_Blk=unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^Is_Blk=_	Unified_Canadian_Aboriginal_Syllabics}', "");
Error('\p{Block= -Unified_Canadian_aboriginal_Syllabics_Extended/a/}');
Error('\P{Block= -Unified_Canadian_aboriginal_Syllabics_Extended/a/}');
Expect(1, 6399, '\p{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(0, 6399, '\p{^Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(0, 6399, '\P{Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(1, 6399, '\P{^Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(0, 6400, '\p{Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(1, 6400, '\p{^Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(1, 6400, '\P{Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Expect(0, 6400, '\P{^Block=-unified_Canadian_Aboriginal_syllabics_extended}', "");
Error('\p{Blk=	 UCAS_Ext/a/}');
Error('\P{Blk=	 UCAS_Ext/a/}');
Expect(1, 6399, '\p{Blk:	ucasext}', "");
Expect(0, 6399, '\p{^Blk:	ucasext}', "");
Expect(0, 6399, '\P{Blk:	ucasext}', "");
Expect(1, 6399, '\P{^Blk:	ucasext}', "");
Expect(0, 6400, '\p{Blk:	ucasext}', "");
Expect(1, 6400, '\p{^Blk:	ucasext}', "");
Expect(1, 6400, '\P{Blk:	ucasext}', "");
Expect(0, 6400, '\P{^Blk:	ucasext}', "");
Expect(1, 6399, '\p{Blk=-ucas_ext}', "");
Expect(0, 6399, '\p{^Blk=-ucas_ext}', "");
Expect(0, 6399, '\P{Blk=-ucas_ext}', "");
Expect(1, 6399, '\P{^Blk=-ucas_ext}', "");
Expect(0, 6400, '\p{Blk=-ucas_ext}', "");
Expect(1, 6400, '\p{^Blk=-ucas_ext}', "");
Expect(1, 6400, '\P{Blk=-ucas_ext}', "");
Expect(0, 6400, '\P{^Blk=-ucas_ext}', "");
Error('\p{Is_Block=--UNIFIED_Canadian_ABORIGINAL_Syllabics_Extended:=}');
Error('\P{Is_Block=--UNIFIED_Canadian_ABORIGINAL_Syllabics_Extended:=}');
Expect(1, 6399, '\p{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^Is_Block=unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6399, '\p{^Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6399, '\P{Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(1, 6399, '\P{^Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6400, '\p{Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(1, 6400, '\p{^Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(1, 6400, '\P{Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Expect(0, 6400, '\P{^Is_Block=	-Unified_canadian_ABORIGINAL_syllabics_Extended}', "");
Error('\p{Is_Blk=	:=ucas_ext}');
Error('\P{Is_Blk=	:=ucas_ext}');
Expect(1, 6399, '\p{Is_Blk=ucasext}', "");
Expect(0, 6399, '\p{^Is_Blk=ucasext}', "");
Expect(0, 6399, '\P{Is_Blk=ucasext}', "");
Expect(1, 6399, '\P{^Is_Blk=ucasext}', "");
Expect(0, 6400, '\p{Is_Blk=ucasext}', "");
Expect(1, 6400, '\p{^Is_Blk=ucasext}', "");
Expect(1, 6400, '\P{Is_Blk=ucasext}', "");
Expect(0, 6400, '\P{^Is_Blk=ucasext}', "");
Expect(1, 6399, '\p{Is_Blk=	-UCAS_EXT}', "");
Expect(0, 6399, '\p{^Is_Blk=	-UCAS_EXT}', "");
Expect(0, 6399, '\P{Is_Blk=	-UCAS_EXT}', "");
Expect(1, 6399, '\P{^Is_Blk=	-UCAS_EXT}', "");
Expect(0, 6400, '\p{Is_Blk=	-UCAS_EXT}', "");
Expect(1, 6400, '\p{^Is_Blk=	-UCAS_EXT}', "");
Expect(1, 6400, '\P{Is_Blk=	-UCAS_EXT}', "");
Expect(0, 6400, '\P{^Is_Blk=	-UCAS_EXT}', "");
Error('\p{Block= -Ugaritic/a/}');
Error('\P{Block= -Ugaritic/a/}');
Expect(1, 66463, '\p{Block=ugaritic}', "");
Expect(0, 66463, '\p{^Block=ugaritic}', "");
Expect(0, 66463, '\P{Block=ugaritic}', "");
Expect(1, 66463, '\P{^Block=ugaritic}', "");
Expect(0, 66464, '\p{Block=ugaritic}', "");
Expect(1, 66464, '\p{^Block=ugaritic}', "");
Expect(1, 66464, '\P{Block=ugaritic}', "");
Expect(0, 66464, '\P{^Block=ugaritic}', "");
Expect(1, 66463, '\p{Block=	Ugaritic}', "");
Expect(0, 66463, '\p{^Block=	Ugaritic}', "");
Expect(0, 66463, '\P{Block=	Ugaritic}', "");
Expect(1, 66463, '\P{^Block=	Ugaritic}', "");
Expect(0, 66464, '\p{Block=	Ugaritic}', "");
Expect(1, 66464, '\p{^Block=	Ugaritic}', "");
Expect(1, 66464, '\P{Block=	Ugaritic}', "");
Expect(0, 66464, '\P{^Block=	Ugaritic}', "");
Error('\p{Blk=-:=Ugaritic}');
Error('\P{Blk=-:=Ugaritic}');
Expect(1, 66463, '\p{Blk:	ugaritic}', "");
Expect(0, 66463, '\p{^Blk:	ugaritic}', "");
Expect(0, 66463, '\P{Blk:	ugaritic}', "");
Expect(1, 66463, '\P{^Blk:	ugaritic}', "");
Expect(0, 66464, '\p{Blk:	ugaritic}', "");
Expect(1, 66464, '\p{^Blk:	ugaritic}', "");
Expect(1, 66464, '\P{Blk:	ugaritic}', "");
Expect(0, 66464, '\P{^Blk:	ugaritic}', "");
Expect(1, 66463, '\p{Blk=--Ugaritic}', "");
Expect(0, 66463, '\p{^Blk=--Ugaritic}', "");
Expect(0, 66463, '\P{Blk=--Ugaritic}', "");
Expect(1, 66463, '\P{^Blk=--Ugaritic}', "");
Expect(0, 66464, '\p{Blk=--Ugaritic}', "");
Expect(1, 66464, '\p{^Blk=--Ugaritic}', "");
Expect(1, 66464, '\P{Blk=--Ugaritic}', "");
Expect(0, 66464, '\P{^Blk=--Ugaritic}', "");
Error('\p{Is_Block=/a/  UGARITIC}');
Error('\P{Is_Block=/a/  UGARITIC}');
Expect(1, 66463, '\p{Is_Block=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Block=ugaritic}', "");
Expect(0, 66463, '\P{Is_Block=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Block=ugaritic}', "");
Expect(0, 66464, '\p{Is_Block=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Block=ugaritic}', "");
Expect(1, 66464, '\P{Is_Block=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Block=ugaritic}', "");
Expect(1, 66463, '\p{Is_Block=-Ugaritic}', "");
Expect(0, 66463, '\p{^Is_Block=-Ugaritic}', "");
Expect(0, 66463, '\P{Is_Block=-Ugaritic}', "");
Expect(1, 66463, '\P{^Is_Block=-Ugaritic}', "");
Expect(0, 66464, '\p{Is_Block=-Ugaritic}', "");
Expect(1, 66464, '\p{^Is_Block=-Ugaritic}', "");
Expect(1, 66464, '\P{Is_Block=-Ugaritic}', "");
Expect(0, 66464, '\P{^Is_Block=-Ugaritic}', "");
Error('\p{Is_Blk=_/a/ugaritic}');
Error('\P{Is_Blk=_/a/ugaritic}');
Expect(1, 66463, '\p{Is_Blk=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Blk=ugaritic}', "");
Expect(0, 66463, '\P{Is_Blk=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Blk=ugaritic}', "");
Expect(0, 66464, '\p{Is_Blk=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Blk=ugaritic}', "");
Expect(1, 66464, '\P{Is_Blk=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Blk=ugaritic}', "");
Expect(1, 66463, '\p{Is_Blk=  UGARITIC}', "");
Expect(0, 66463, '\p{^Is_Blk=  UGARITIC}', "");
Expect(0, 66463, '\P{Is_Blk=  UGARITIC}', "");
Expect(1, 66463, '\P{^Is_Blk=  UGARITIC}', "");
Expect(0, 66464, '\p{Is_Blk=  UGARITIC}', "");
Expect(1, 66464, '\p{^Is_Blk=  UGARITIC}', "");
Expect(1, 66464, '\P{Is_Blk=  UGARITIC}', "");
Expect(0, 66464, '\P{^Is_Blk=  UGARITIC}', "");
Error('\p{Block=-Variation_SELECTORS/a/}');
Error('\P{Block=-Variation_SELECTORS/a/}');
Expect(1, 65039, '\p{Block=variationselectors}', "");
Expect(0, 65039, '\p{^Block=variationselectors}', "");
Expect(0, 65039, '\P{Block=variationselectors}', "");
Expect(1, 65039, '\P{^Block=variationselectors}', "");
Expect(0, 65040, '\p{Block=variationselectors}', "");
Expect(1, 65040, '\p{^Block=variationselectors}', "");
Expect(1, 65040, '\P{Block=variationselectors}', "");
Expect(0, 65040, '\P{^Block=variationselectors}', "");
Expect(1, 65039, '\p{Block=_-Variation_Selectors}', "");
Expect(0, 65039, '\p{^Block=_-Variation_Selectors}', "");
Expect(0, 65039, '\P{Block=_-Variation_Selectors}', "");
Expect(1, 65039, '\P{^Block=_-Variation_Selectors}', "");
Expect(0, 65040, '\p{Block=_-Variation_Selectors}', "");
Expect(1, 65040, '\p{^Block=_-Variation_Selectors}', "");
Expect(1, 65040, '\P{Block=_-Variation_Selectors}', "");
Expect(0, 65040, '\P{^Block=_-Variation_Selectors}', "");
Error('\p{Blk= vs/a/}');
Error('\P{Blk= vs/a/}');
Expect(1, 65039, '\p{Blk:vs}', "");
Expect(0, 65039, '\p{^Blk:vs}', "");
Expect(0, 65039, '\P{Blk:vs}', "");
Expect(1, 65039, '\P{^Blk:vs}', "");
Expect(0, 65040, '\p{Blk:vs}', "");
Expect(1, 65040, '\p{^Blk:vs}', "");
Expect(1, 65040, '\P{Blk:vs}', "");
Expect(0, 65040, '\P{^Blk:vs}', "");
Expect(1, 65039, '\p{Blk=_-VS}', "");
Expect(0, 65039, '\p{^Blk=_-VS}', "");
Expect(0, 65039, '\P{Blk=_-VS}', "");
Expect(1, 65039, '\P{^Blk=_-VS}', "");
Expect(0, 65040, '\p{Blk=_-VS}', "");
Expect(1, 65040, '\p{^Blk=_-VS}', "");
Expect(1, 65040, '\P{Blk=_-VS}', "");
Expect(0, 65040, '\P{^Blk=_-VS}', "");
Error('\p{Is_Block=/a/__Variation_Selectors}');
Error('\P{Is_Block=/a/__Variation_Selectors}');
Expect(1, 65039, '\p{Is_Block=variationselectors}', "");
Expect(0, 65039, '\p{^Is_Block=variationselectors}', "");
Expect(0, 65039, '\P{Is_Block=variationselectors}', "");
Expect(1, 65039, '\P{^Is_Block=variationselectors}', "");
Expect(0, 65040, '\p{Is_Block=variationselectors}', "");
Expect(1, 65040, '\p{^Is_Block=variationselectors}', "");
Expect(1, 65040, '\P{Is_Block=variationselectors}', "");
Expect(0, 65040, '\P{^Is_Block=variationselectors}', "");
Expect(1, 65039, '\p{Is_Block=		variation_SELECTORS}', "");
Expect(0, 65039, '\p{^Is_Block=		variation_SELECTORS}', "");
Expect(0, 65039, '\P{Is_Block=		variation_SELECTORS}', "");
Expect(1, 65039, '\P{^Is_Block=		variation_SELECTORS}', "");
Expect(0, 65040, '\p{Is_Block=		variation_SELECTORS}', "");
Expect(1, 65040, '\p{^Is_Block=		variation_SELECTORS}', "");
Expect(1, 65040, '\P{Is_Block=		variation_SELECTORS}', "");
Expect(0, 65040, '\P{^Is_Block=		variation_SELECTORS}', "");
Error('\p{Is_Blk=_VS/a/}');
Error('\P{Is_Blk=_VS/a/}');
Expect(1, 65039, '\p{Is_Blk:   vs}', "");
Expect(0, 65039, '\p{^Is_Blk:   vs}', "");
Expect(0, 65039, '\P{Is_Blk:   vs}', "");
Expect(1, 65039, '\P{^Is_Blk:   vs}', "");
Expect(0, 65040, '\p{Is_Blk:   vs}', "");
Expect(1, 65040, '\p{^Is_Blk:   vs}', "");
Expect(1, 65040, '\P{Is_Blk:   vs}', "");
Expect(0, 65040, '\P{^Is_Blk:   vs}', "");
Expect(1, 65039, '\p{Is_Blk=--VS}', "");
Expect(0, 65039, '\p{^Is_Blk=--VS}', "");
Expect(0, 65039, '\P{Is_Blk=--VS}', "");
Expect(1, 65039, '\P{^Is_Blk=--VS}', "");
Expect(0, 65040, '\p{Is_Blk=--VS}', "");
Expect(1, 65040, '\p{^Is_Blk=--VS}', "");
Expect(1, 65040, '\P{Is_Blk=--VS}', "");
Expect(0, 65040, '\P{^Is_Blk=--VS}', "");
Error('\p{Block=	 VARIATION_selectors_Supplement/a/}');
Error('\P{Block=	 VARIATION_selectors_Supplement/a/}');
Expect(1, 917999, '\p{Block=variationselectorssupplement}', "");
Expect(0, 917999, '\p{^Block=variationselectorssupplement}', "");
Expect(0, 917999, '\P{Block=variationselectorssupplement}', "");
Expect(1, 917999, '\P{^Block=variationselectorssupplement}', "");
Expect(0, 918000, '\p{Block=variationselectorssupplement}', "");
Expect(1, 918000, '\p{^Block=variationselectorssupplement}', "");
Expect(1, 918000, '\P{Block=variationselectorssupplement}', "");
Expect(0, 918000, '\P{^Block=variationselectorssupplement}', "");
Expect(1, 917999, '\p{Block=Variation_Selectors_Supplement}', "");
Expect(0, 917999, '\p{^Block=Variation_Selectors_Supplement}', "");
Expect(0, 917999, '\P{Block=Variation_Selectors_Supplement}', "");
Expect(1, 917999, '\P{^Block=Variation_Selectors_Supplement}', "");
Expect(0, 918000, '\p{Block=Variation_Selectors_Supplement}', "");
Expect(1, 918000, '\p{^Block=Variation_Selectors_Supplement}', "");
Expect(1, 918000, '\P{Block=Variation_Selectors_Supplement}', "");
Expect(0, 918000, '\P{^Block=Variation_Selectors_Supplement}', "");
Error('\p{Blk=:=	VS_SUP}');
Error('\P{Blk=:=	VS_SUP}');
Expect(1, 917999, '\p{Blk=vssup}', "");
Expect(0, 917999, '\p{^Blk=vssup}', "");
Expect(0, 917999, '\P{Blk=vssup}', "");
Expect(1, 917999, '\P{^Blk=vssup}', "");
Expect(0, 918000, '\p{Blk=vssup}', "");
Expect(1, 918000, '\p{^Blk=vssup}', "");
Expect(1, 918000, '\P{Blk=vssup}', "");
Expect(0, 918000, '\P{^Blk=vssup}', "");
Expect(1, 917999, '\p{Blk=__VS_sup}', "");
Expect(0, 917999, '\p{^Blk=__VS_sup}', "");
Expect(0, 917999, '\P{Blk=__VS_sup}', "");
Expect(1, 917999, '\P{^Blk=__VS_sup}', "");
Expect(0, 918000, '\p{Blk=__VS_sup}', "");
Expect(1, 918000, '\p{^Blk=__VS_sup}', "");
Expect(1, 918000, '\P{Blk=__VS_sup}', "");
Expect(0, 918000, '\P{^Blk=__VS_sup}', "");
Error('\p{Is_Block=-:=Variation_Selectors_SUPPLEMENT}');
Error('\P{Is_Block=-:=Variation_Selectors_SUPPLEMENT}');
Expect(1, 917999, '\p{Is_Block=variationselectorssupplement}', "");
Expect(0, 917999, '\p{^Is_Block=variationselectorssupplement}', "");
Expect(0, 917999, '\P{Is_Block=variationselectorssupplement}', "");
Expect(1, 917999, '\P{^Is_Block=variationselectorssupplement}', "");
Expect(0, 918000, '\p{Is_Block=variationselectorssupplement}', "");
Expect(1, 918000, '\p{^Is_Block=variationselectorssupplement}', "");
Expect(1, 918000, '\P{Is_Block=variationselectorssupplement}', "");
Expect(0, 918000, '\P{^Is_Block=variationselectorssupplement}', "");
Expect(1, 917999, '\p{Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(0, 917999, '\p{^Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(0, 917999, '\P{Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(1, 917999, '\P{^Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(0, 918000, '\p{Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(1, 918000, '\p{^Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(1, 918000, '\P{Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Expect(0, 918000, '\P{^Is_Block= VARIATION_Selectors_SUPPLEMENT}', "");
Error('\p{Is_Blk=/a/	_vs_sup}');
Error('\P{Is_Blk=/a/	_vs_sup}');
Expect(1, 917999, '\p{Is_Blk:   vssup}', "");
Expect(0, 917999, '\p{^Is_Blk:   vssup}', "");
Expect(0, 917999, '\P{Is_Blk:   vssup}', "");
Expect(1, 917999, '\P{^Is_Blk:   vssup}', "");
Expect(0, 918000, '\p{Is_Blk:   vssup}', "");
Expect(1, 918000, '\p{^Is_Blk:   vssup}', "");
Expect(1, 918000, '\P{Is_Blk:   vssup}', "");
Expect(0, 918000, '\P{^Is_Blk:   vssup}', "");
Expect(1, 917999, '\p{Is_Blk=- VS_Sup}', "");
Expect(0, 917999, '\p{^Is_Blk=- VS_Sup}', "");
Expect(0, 917999, '\P{Is_Blk=- VS_Sup}', "");
Expect(1, 917999, '\P{^Is_Blk=- VS_Sup}', "");
Expect(0, 918000, '\p{Is_Blk=- VS_Sup}', "");
Expect(1, 918000, '\p{^Is_Blk=- VS_Sup}', "");
Expect(1, 918000, '\P{Is_Blk=- VS_Sup}', "");
Expect(0, 918000, '\P{^Is_Blk=- VS_Sup}', "");
Error('\p{Block=__Vai:=}');
Error('\P{Block=__Vai:=}');
Expect(1, 42559, '\p{Block:   vai}', "");
Expect(0, 42559, '\p{^Block:   vai}', "");
Expect(0, 42559, '\P{Block:   vai}', "");
Expect(1, 42559, '\P{^Block:   vai}', "");
Expect(0, 42560, '\p{Block:   vai}', "");
Expect(1, 42560, '\p{^Block:   vai}', "");
Expect(1, 42560, '\P{Block:   vai}', "");
Expect(0, 42560, '\P{^Block:   vai}', "");
Expect(1, 42559, '\p{Block=Vai}', "");
Expect(0, 42559, '\p{^Block=Vai}', "");
Expect(0, 42559, '\P{Block=Vai}', "");
Expect(1, 42559, '\P{^Block=Vai}', "");
Expect(0, 42560, '\p{Block=Vai}', "");
Expect(1, 42560, '\p{^Block=Vai}', "");
Expect(1, 42560, '\P{Block=Vai}', "");
Expect(0, 42560, '\P{^Block=Vai}', "");
Error('\p{Blk=:=--Vai}');
Error('\P{Blk=:=--Vai}');
Expect(1, 42559, '\p{Blk=vai}', "");
Expect(0, 42559, '\p{^Blk=vai}', "");
Expect(0, 42559, '\P{Blk=vai}', "");
Expect(1, 42559, '\P{^Blk=vai}', "");
Expect(0, 42560, '\p{Blk=vai}', "");
Expect(1, 42560, '\p{^Blk=vai}', "");
Expect(1, 42560, '\P{Blk=vai}', "");
Expect(0, 42560, '\P{^Blk=vai}', "");
Expect(1, 42559, '\p{Blk=	VAI}', "");
Expect(0, 42559, '\p{^Blk=	VAI}', "");
Expect(0, 42559, '\P{Blk=	VAI}', "");
Expect(1, 42559, '\P{^Blk=	VAI}', "");
Expect(0, 42560, '\p{Blk=	VAI}', "");
Expect(1, 42560, '\p{^Blk=	VAI}', "");
Expect(1, 42560, '\P{Blk=	VAI}', "");
Expect(0, 42560, '\P{^Blk=	VAI}', "");
Error('\p{Is_Block=  Vai:=}');
Error('\P{Is_Block=  Vai:=}');
Expect(1, 42559, '\p{Is_Block=vai}', "");
Expect(0, 42559, '\p{^Is_Block=vai}', "");
Expect(0, 42559, '\P{Is_Block=vai}', "");
Expect(1, 42559, '\P{^Is_Block=vai}', "");
Expect(0, 42560, '\p{Is_Block=vai}', "");
Expect(1, 42560, '\p{^Is_Block=vai}', "");
Expect(1, 42560, '\P{Is_Block=vai}', "");
Expect(0, 42560, '\P{^Is_Block=vai}', "");
Expect(1, 42559, '\p{Is_Block=-	VAI}', "");
Expect(0, 42559, '\p{^Is_Block=-	VAI}', "");
Expect(0, 42559, '\P{Is_Block=-	VAI}', "");
Expect(1, 42559, '\P{^Is_Block=-	VAI}', "");
Expect(0, 42560, '\p{Is_Block=-	VAI}', "");
Expect(1, 42560, '\p{^Is_Block=-	VAI}', "");
Expect(1, 42560, '\P{Is_Block=-	VAI}', "");
Expect(0, 42560, '\P{^Is_Block=-	VAI}', "");
Error('\p{Is_Blk=/a/		Vai}');
Error('\P{Is_Blk=/a/		Vai}');
Expect(1, 42559, '\p{Is_Blk:	vai}', "");
Expect(0, 42559, '\p{^Is_Blk:	vai}', "");
Expect(0, 42559, '\P{Is_Blk:	vai}', "");
Expect(1, 42559, '\P{^Is_Blk:	vai}', "");
Expect(0, 42560, '\p{Is_Blk:	vai}', "");
Expect(1, 42560, '\p{^Is_Blk:	vai}', "");
Expect(1, 42560, '\P{Is_Blk:	vai}', "");
Expect(0, 42560, '\P{^Is_Blk:	vai}', "");
Expect(1, 42559, '\p{Is_Blk=_	Vai}', "");
Expect(0, 42559, '\p{^Is_Blk=_	Vai}', "");
Expect(0, 42559, '\P{Is_Blk=_	Vai}', "");
Expect(1, 42559, '\P{^Is_Blk=_	Vai}', "");
Expect(0, 42560, '\p{Is_Blk=_	Vai}', "");
Expect(1, 42560, '\p{^Is_Blk=_	Vai}', "");
Expect(1, 42560, '\P{Is_Blk=_	Vai}', "");
Expect(0, 42560, '\P{^Is_Blk=_	Vai}', "");
Error('\p{Block=--vedic_Extensions:=}');
Error('\P{Block=--vedic_Extensions:=}');
Expect(1, 7423, '\p{Block=vedicextensions}', "");
Expect(0, 7423, '\p{^Block=vedicextensions}', "");
Expect(0, 7423, '\P{Block=vedicextensions}', "");
Expect(1, 7423, '\P{^Block=vedicextensions}', "");
Expect(0, 7424, '\p{Block=vedicextensions}', "");
Expect(1, 7424, '\p{^Block=vedicextensions}', "");
Expect(1, 7424, '\P{Block=vedicextensions}', "");
Expect(0, 7424, '\P{^Block=vedicextensions}', "");
Expect(1, 7423, '\p{Block=  vedic_Extensions}', "");
Expect(0, 7423, '\p{^Block=  vedic_Extensions}', "");
Expect(0, 7423, '\P{Block=  vedic_Extensions}', "");
Expect(1, 7423, '\P{^Block=  vedic_Extensions}', "");
Expect(0, 7424, '\p{Block=  vedic_Extensions}', "");
Expect(1, 7424, '\p{^Block=  vedic_Extensions}', "");
Expect(1, 7424, '\P{Block=  vedic_Extensions}', "");
Expect(0, 7424, '\P{^Block=  vedic_Extensions}', "");
Error('\p{Blk= /a/Vedic_Ext}');
Error('\P{Blk= /a/Vedic_Ext}');
Expect(1, 7423, '\p{Blk=vedicext}', "");
Expect(0, 7423, '\p{^Blk=vedicext}', "");
Expect(0, 7423, '\P{Blk=vedicext}', "");
Expect(1, 7423, '\P{^Blk=vedicext}', "");
Expect(0, 7424, '\p{Blk=vedicext}', "");
Expect(1, 7424, '\p{^Blk=vedicext}', "");
Expect(1, 7424, '\P{Blk=vedicext}', "");
Expect(0, 7424, '\P{^Blk=vedicext}', "");
Expect(1, 7423, '\p{Blk: 	_Vedic_Ext}', "");
Expect(0, 7423, '\p{^Blk: 	_Vedic_Ext}', "");
Expect(0, 7423, '\P{Blk: 	_Vedic_Ext}', "");
Expect(1, 7423, '\P{^Blk: 	_Vedic_Ext}', "");
Expect(0, 7424, '\p{Blk: 	_Vedic_Ext}', "");
Expect(1, 7424, '\p{^Blk: 	_Vedic_Ext}', "");
Expect(1, 7424, '\P{Blk: 	_Vedic_Ext}', "");
Expect(0, 7424, '\P{^Blk: 	_Vedic_Ext}', "");
Error('\p{Is_Block=/a/- Vedic_Extensions}');
Error('\P{Is_Block=/a/- Vedic_Extensions}');
Expect(1, 7423, '\p{Is_Block=vedicextensions}', "");
Expect(0, 7423, '\p{^Is_Block=vedicextensions}', "");
Expect(0, 7423, '\P{Is_Block=vedicextensions}', "");
Expect(1, 7423, '\P{^Is_Block=vedicextensions}', "");
Expect(0, 7424, '\p{Is_Block=vedicextensions}', "");
Expect(1, 7424, '\p{^Is_Block=vedicextensions}', "");
Expect(1, 7424, '\P{Is_Block=vedicextensions}', "");
Expect(0, 7424, '\P{^Is_Block=vedicextensions}', "");
Expect(1, 7423, '\p{Is_Block:    	vedic_extensions}', "");
Expect(0, 7423, '\p{^Is_Block:    	vedic_extensions}', "");
Expect(0, 7423, '\P{Is_Block:    	vedic_extensions}', "");
Expect(1, 7423, '\P{^Is_Block:    	vedic_extensions}', "");
Expect(0, 7424, '\p{Is_Block:    	vedic_extensions}', "");
Expect(1, 7424, '\p{^Is_Block:    	vedic_extensions}', "");
Expect(1, 7424, '\P{Is_Block:    	vedic_extensions}', "");
Expect(0, 7424, '\P{^Is_Block:    	vedic_extensions}', "");
Error('\p{Is_Blk= -Vedic_EXT:=}');
Error('\P{Is_Blk= -Vedic_EXT:=}');
Expect(1, 7423, '\p{Is_Blk=vedicext}', "");
Expect(0, 7423, '\p{^Is_Blk=vedicext}', "");
Expect(0, 7423, '\P{Is_Blk=vedicext}', "");
Expect(1, 7423, '\P{^Is_Blk=vedicext}', "");
Expect(0, 7424, '\p{Is_Blk=vedicext}', "");
Expect(1, 7424, '\p{^Is_Blk=vedicext}', "");
Expect(1, 7424, '\P{Is_Blk=vedicext}', "");
Expect(0, 7424, '\P{^Is_Blk=vedicext}', "");
Expect(1, 7423, '\p{Is_Blk=	Vedic_EXT}', "");
Expect(0, 7423, '\p{^Is_Blk=	Vedic_EXT}', "");
Expect(0, 7423, '\P{Is_Blk=	Vedic_EXT}', "");
Expect(1, 7423, '\P{^Is_Blk=	Vedic_EXT}', "");
Expect(0, 7424, '\p{Is_Blk=	Vedic_EXT}', "");
Expect(1, 7424, '\p{^Is_Blk=	Vedic_EXT}', "");
Expect(1, 7424, '\P{Is_Blk=	Vedic_EXT}', "");
Expect(0, 7424, '\P{^Is_Blk=	Vedic_EXT}', "");
Error('\p{Block: _/a/Vertical_FORMS}');
Error('\P{Block: _/a/Vertical_FORMS}');
Expect(1, 65055, '\p{Block=verticalforms}', "");
Expect(0, 65055, '\p{^Block=verticalforms}', "");
Expect(0, 65055, '\P{Block=verticalforms}', "");
Expect(1, 65055, '\P{^Block=verticalforms}', "");
Expect(0, 65056, '\p{Block=verticalforms}', "");
Expect(1, 65056, '\p{^Block=verticalforms}', "");
Expect(1, 65056, '\P{Block=verticalforms}', "");
Expect(0, 65056, '\P{^Block=verticalforms}', "");
Expect(1, 65055, '\p{Block=_Vertical_Forms}', "");
Expect(0, 65055, '\p{^Block=_Vertical_Forms}', "");
Expect(0, 65055, '\P{Block=_Vertical_Forms}', "");
Expect(1, 65055, '\P{^Block=_Vertical_Forms}', "");
Expect(0, 65056, '\p{Block=_Vertical_Forms}', "");
Expect(1, 65056, '\p{^Block=_Vertical_Forms}', "");
Expect(1, 65056, '\P{Block=_Vertical_Forms}', "");
Expect(0, 65056, '\P{^Block=_Vertical_Forms}', "");
Error('\p{Blk=_Vertical_Forms/a/}');
Error('\P{Blk=_Vertical_Forms/a/}');
Expect(1, 65055, '\p{Blk=verticalforms}', "");
Expect(0, 65055, '\p{^Blk=verticalforms}', "");
Expect(0, 65055, '\P{Blk=verticalforms}', "");
Expect(1, 65055, '\P{^Blk=verticalforms}', "");
Expect(0, 65056, '\p{Blk=verticalforms}', "");
Expect(1, 65056, '\p{^Blk=verticalforms}', "");
Expect(1, 65056, '\P{Blk=verticalforms}', "");
Expect(0, 65056, '\P{^Blk=verticalforms}', "");
Expect(1, 65055, '\p{Blk=-_Vertical_forms}', "");
Expect(0, 65055, '\p{^Blk=-_Vertical_forms}', "");
Expect(0, 65055, '\P{Blk=-_Vertical_forms}', "");
Expect(1, 65055, '\P{^Blk=-_Vertical_forms}', "");
Expect(0, 65056, '\p{Blk=-_Vertical_forms}', "");
Expect(1, 65056, '\p{^Blk=-_Vertical_forms}', "");
Expect(1, 65056, '\P{Blk=-_Vertical_forms}', "");
Expect(0, 65056, '\P{^Blk=-_Vertical_forms}', "");
Error('\p{Is_Block=	:=VERTICAL_Forms}');
Error('\P{Is_Block=	:=VERTICAL_Forms}');
Expect(1, 65055, '\p{Is_Block:	verticalforms}', "");
Expect(0, 65055, '\p{^Is_Block:	verticalforms}', "");
Expect(0, 65055, '\P{Is_Block:	verticalforms}', "");
Expect(1, 65055, '\P{^Is_Block:	verticalforms}', "");
Expect(0, 65056, '\p{Is_Block:	verticalforms}', "");
Expect(1, 65056, '\p{^Is_Block:	verticalforms}', "");
Expect(1, 65056, '\P{Is_Block:	verticalforms}', "");
Expect(0, 65056, '\P{^Is_Block:	verticalforms}', "");
Expect(1, 65055, '\p{Is_Block=	Vertical_Forms}', "");
Expect(0, 65055, '\p{^Is_Block=	Vertical_Forms}', "");
Expect(0, 65055, '\P{Is_Block=	Vertical_Forms}', "");
Expect(1, 65055, '\P{^Is_Block=	Vertical_Forms}', "");
Expect(0, 65056, '\p{Is_Block=	Vertical_Forms}', "");
Expect(1, 65056, '\p{^Is_Block=	Vertical_Forms}', "");
Expect(1, 65056, '\P{Is_Block=	Vertical_Forms}', "");
Expect(0, 65056, '\P{^Is_Block=	Vertical_Forms}', "");
Error('\p{Is_Blk=:=__VERTICAL_Forms}');
Error('\P{Is_Blk=:=__VERTICAL_Forms}');
Expect(1, 65055, '\p{Is_Blk=verticalforms}', "");
Expect(0, 65055, '\p{^Is_Blk=verticalforms}', "");
Expect(0, 65055, '\P{Is_Blk=verticalforms}', "");
Expect(1, 65055, '\P{^Is_Blk=verticalforms}', "");
Expect(0, 65056, '\p{Is_Blk=verticalforms}', "");
Expect(1, 65056, '\p{^Is_Blk=verticalforms}', "");
Expect(1, 65056, '\P{Is_Blk=verticalforms}', "");
Expect(0, 65056, '\P{^Is_Blk=verticalforms}', "");
Expect(1, 65055, '\p{Is_Blk=_	Vertical_Forms}', "");
Expect(0, 65055, '\p{^Is_Blk=_	Vertical_Forms}', "");
Expect(0, 65055, '\P{Is_Blk=_	Vertical_Forms}', "");
Expect(1, 65055, '\P{^Is_Blk=_	Vertical_Forms}', "");
Expect(0, 65056, '\p{Is_Blk=_	Vertical_Forms}', "");
Expect(1, 65056, '\p{^Is_Blk=_	Vertical_Forms}', "");
Expect(1, 65056, '\P{Is_Blk=_	Vertical_Forms}', "");
Expect(0, 65056, '\P{^Is_Blk=_	Vertical_Forms}', "");
Error('\p{Block=__yi_Radicals:=}');
Error('\P{Block=__yi_Radicals:=}');
Expect(1, 42191, '\p{Block=yiradicals}', "");
Expect(0, 42191, '\p{^Block=yiradicals}', "");
Expect(0, 42191, '\P{Block=yiradicals}', "");
Expect(1, 42191, '\P{^Block=yiradicals}', "");
Expect(0, 42192, '\p{Block=yiradicals}', "");
Expect(1, 42192, '\p{^Block=yiradicals}', "");
Expect(1, 42192, '\P{Block=yiradicals}', "");
Expect(0, 42192, '\P{^Block=yiradicals}', "");
Expect(1, 42191, '\p{Block=  YI_Radicals}', "");
Expect(0, 42191, '\p{^Block=  YI_Radicals}', "");
Expect(0, 42191, '\P{Block=  YI_Radicals}', "");
Expect(1, 42191, '\P{^Block=  YI_Radicals}', "");
Expect(0, 42192, '\p{Block=  YI_Radicals}', "");
Expect(1, 42192, '\p{^Block=  YI_Radicals}', "");
Expect(1, 42192, '\P{Block=  YI_Radicals}', "");
Expect(0, 42192, '\P{^Block=  YI_Radicals}', "");
Error('\p{Blk=/a/--Yi_radicals}');
Error('\P{Blk=/a/--Yi_radicals}');
Expect(1, 42191, '\p{Blk=yiradicals}', "");
Expect(0, 42191, '\p{^Blk=yiradicals}', "");
Expect(0, 42191, '\P{Blk=yiradicals}', "");
Expect(1, 42191, '\P{^Blk=yiradicals}', "");
Expect(0, 42192, '\p{Blk=yiradicals}', "");
Expect(1, 42192, '\p{^Blk=yiradicals}', "");
Expect(1, 42192, '\P{Blk=yiradicals}', "");
Expect(0, 42192, '\P{^Blk=yiradicals}', "");
Expect(1, 42191, '\p{Blk=		Yi_radicals}', "");
Expect(0, 42191, '\p{^Blk=		Yi_radicals}', "");
Expect(0, 42191, '\P{Blk=		Yi_radicals}', "");
Expect(1, 42191, '\P{^Blk=		Yi_radicals}', "");
Expect(0, 42192, '\p{Blk=		Yi_radicals}', "");
Expect(1, 42192, '\p{^Blk=		Yi_radicals}', "");
Expect(1, 42192, '\P{Blk=		Yi_radicals}', "");
Expect(0, 42192, '\P{^Blk=		Yi_radicals}', "");
Error('\p{Is_Block=/a/-Yi_RADICALS}');
Error('\P{Is_Block=/a/-Yi_RADICALS}');
Expect(1, 42191, '\p{Is_Block=yiradicals}', "");
Expect(0, 42191, '\p{^Is_Block=yiradicals}', "");
Expect(0, 42191, '\P{Is_Block=yiradicals}', "");
Expect(1, 42191, '\P{^Is_Block=yiradicals}', "");
Expect(0, 42192, '\p{Is_Block=yiradicals}', "");
Expect(1, 42192, '\p{^Is_Block=yiradicals}', "");
Expect(1, 42192, '\P{Is_Block=yiradicals}', "");
Expect(0, 42192, '\P{^Is_Block=yiradicals}', "");
Expect(1, 42191, '\p{Is_Block=	 YI_Radicals}', "");
Expect(0, 42191, '\p{^Is_Block=	 YI_Radicals}', "");
Expect(0, 42191, '\P{Is_Block=	 YI_Radicals}', "");
Expect(1, 42191, '\P{^Is_Block=	 YI_Radicals}', "");
Expect(0, 42192, '\p{Is_Block=	 YI_Radicals}', "");
Expect(1, 42192, '\p{^Is_Block=	 YI_Radicals}', "");
Expect(1, 42192, '\P{Is_Block=	 YI_Radicals}', "");
Expect(0, 42192, '\P{^Is_Block=	 YI_Radicals}', "");
Error('\p{Is_Blk:		/a/Yi_Radicals}');
Error('\P{Is_Blk:		/a/Yi_Radicals}');
Expect(1, 42191, '\p{Is_Blk=yiradicals}', "");
Expect(0, 42191, '\p{^Is_Blk=yiradicals}', "");
Expect(0, 42191, '\P{Is_Blk=yiradicals}', "");
Expect(1, 42191, '\P{^Is_Blk=yiradicals}', "");
Expect(0, 42192, '\p{Is_Blk=yiradicals}', "");
Expect(1, 42192, '\p{^Is_Blk=yiradicals}', "");
Expect(1, 42192, '\P{Is_Blk=yiradicals}', "");
Expect(0, 42192, '\P{^Is_Blk=yiradicals}', "");
Expect(1, 42191, '\p{Is_Blk=		Yi_Radicals}', "");
Expect(0, 42191, '\p{^Is_Blk=		Yi_Radicals}', "");
Expect(0, 42191, '\P{Is_Blk=		Yi_Radicals}', "");
Expect(1, 42191, '\P{^Is_Blk=		Yi_Radicals}', "");
Expect(0, 42192, '\p{Is_Blk=		Yi_Radicals}', "");
Expect(1, 42192, '\p{^Is_Blk=		Yi_Radicals}', "");
Expect(1, 42192, '\P{Is_Blk=		Yi_Radicals}', "");
Expect(0, 42192, '\P{^Is_Blk=		Yi_Radicals}', "");
Error('\p{Block=_YI_Syllables:=}');
Error('\P{Block=_YI_Syllables:=}');
Expect(1, 42127, '\p{Block=yisyllables}', "");
Expect(0, 42127, '\p{^Block=yisyllables}', "");
Expect(0, 42127, '\P{Block=yisyllables}', "");
Expect(1, 42127, '\P{^Block=yisyllables}', "");
Expect(0, 42128, '\p{Block=yisyllables}', "");
Expect(1, 42128, '\p{^Block=yisyllables}', "");
Expect(1, 42128, '\P{Block=yisyllables}', "");
Expect(0, 42128, '\P{^Block=yisyllables}', "");
Expect(1, 42127, '\p{Block=Yi_Syllables}', "");
Expect(0, 42127, '\p{^Block=Yi_Syllables}', "");
Expect(0, 42127, '\P{Block=Yi_Syllables}', "");
Expect(1, 42127, '\P{^Block=Yi_Syllables}', "");
Expect(0, 42128, '\p{Block=Yi_Syllables}', "");
Expect(1, 42128, '\p{^Block=Yi_Syllables}', "");
Expect(1, 42128, '\P{Block=Yi_Syllables}', "");
Expect(0, 42128, '\P{^Block=Yi_Syllables}', "");
Error('\p{Blk=/a/- yi_Syllables}');
Error('\P{Blk=/a/- yi_Syllables}');
Expect(1, 42127, '\p{Blk:yisyllables}', "");
Expect(0, 42127, '\p{^Blk:yisyllables}', "");
Expect(0, 42127, '\P{Blk:yisyllables}', "");
Expect(1, 42127, '\P{^Blk:yisyllables}', "");
Expect(0, 42128, '\p{Blk:yisyllables}', "");
Expect(1, 42128, '\p{^Blk:yisyllables}', "");
Expect(1, 42128, '\P{Blk:yisyllables}', "");
Expect(0, 42128, '\P{^Blk:yisyllables}', "");
Expect(1, 42127, '\p{Blk=	Yi_Syllables}', "");
Expect(0, 42127, '\p{^Blk=	Yi_Syllables}', "");
Expect(0, 42127, '\P{Blk=	Yi_Syllables}', "");
Expect(1, 42127, '\P{^Blk=	Yi_Syllables}', "");
Expect(0, 42128, '\p{Blk=	Yi_Syllables}', "");
Expect(1, 42128, '\p{^Blk=	Yi_Syllables}', "");
Expect(1, 42128, '\P{Blk=	Yi_Syllables}', "");
Expect(0, 42128, '\P{^Blk=	Yi_Syllables}', "");
Error('\p{Is_Block:	_YI_Syllables:=}');
Error('\P{Is_Block:	_YI_Syllables:=}');
Expect(1, 42127, '\p{Is_Block:yisyllables}', "");
Expect(0, 42127, '\p{^Is_Block:yisyllables}', "");
Expect(0, 42127, '\P{Is_Block:yisyllables}', "");
Expect(1, 42127, '\P{^Is_Block:yisyllables}', "");
Expect(0, 42128, '\p{Is_Block:yisyllables}', "");
Expect(1, 42128, '\p{^Is_Block:yisyllables}', "");
Expect(1, 42128, '\P{Is_Block:yisyllables}', "");
Expect(0, 42128, '\P{^Is_Block:yisyllables}', "");
Expect(1, 42127, '\p{Is_Block: -	YI_Syllables}', "");
Expect(0, 42127, '\p{^Is_Block: -	YI_Syllables}', "");
Expect(0, 42127, '\P{Is_Block: -	YI_Syllables}', "");
Expect(1, 42127, '\P{^Is_Block: -	YI_Syllables}', "");
Expect(0, 42128, '\p{Is_Block: -	YI_Syllables}', "");
Expect(1, 42128, '\p{^Is_Block: -	YI_Syllables}', "");
Expect(1, 42128, '\P{Is_Block: -	YI_Syllables}', "");
Expect(0, 42128, '\P{^Is_Block: -	YI_Syllables}', "");
Error('\p{Is_Blk=_/a/Yi_SYLLABLES}');
Error('\P{Is_Blk=_/a/Yi_SYLLABLES}');
Expect(1, 42127, '\p{Is_Blk=yisyllables}', "");
Expect(0, 42127, '\p{^Is_Blk=yisyllables}', "");
Expect(0, 42127, '\P{Is_Blk=yisyllables}', "");
Expect(1, 42127, '\P{^Is_Blk=yisyllables}', "");
Expect(0, 42128, '\p{Is_Blk=yisyllables}', "");
Expect(1, 42128, '\p{^Is_Blk=yisyllables}', "");
Expect(1, 42128, '\P{Is_Blk=yisyllables}', "");
Expect(0, 42128, '\P{^Is_Blk=yisyllables}', "");
Expect(1, 42127, '\p{Is_Blk=  Yi_SYLLABLES}', "");
Expect(0, 42127, '\p{^Is_Blk=  Yi_SYLLABLES}', "");
Expect(0, 42127, '\P{Is_Blk=  Yi_SYLLABLES}', "");
Expect(1, 42127, '\P{^Is_Blk=  Yi_SYLLABLES}', "");
Expect(0, 42128, '\p{Is_Blk=  Yi_SYLLABLES}', "");
Expect(1, 42128, '\p{^Is_Blk=  Yi_SYLLABLES}', "");
Expect(1, 42128, '\P{Is_Blk=  Yi_SYLLABLES}', "");
Expect(0, 42128, '\P{^Is_Blk=  Yi_SYLLABLES}', "");
Error('\p{Block=_Yijing_Hexagram_Symbols:=}');
Error('\P{Block=_Yijing_Hexagram_Symbols:=}');
Expect(1, 19967, '\p{Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\P{Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\p{Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\P{Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\p{Block=__yijing_Hexagram_symbols}', "");
Expect(0, 19967, '\p{^Block=__yijing_Hexagram_symbols}', "");
Expect(0, 19967, '\P{Block=__yijing_Hexagram_symbols}', "");
Expect(1, 19967, '\P{^Block=__yijing_Hexagram_symbols}', "");
Expect(0, 19968, '\p{Block=__yijing_Hexagram_symbols}', "");
Expect(1, 19968, '\p{^Block=__yijing_Hexagram_symbols}', "");
Expect(1, 19968, '\P{Block=__yijing_Hexagram_symbols}', "");
Expect(0, 19968, '\P{^Block=__yijing_Hexagram_symbols}', "");
Error('\p{Blk=_-Yijing/a/}');
Error('\P{Blk=_-Yijing/a/}');
Expect(1, 19967, '\p{Blk=yijing}', "");
Expect(0, 19967, '\p{^Blk=yijing}', "");
Expect(0, 19967, '\P{Blk=yijing}', "");
Expect(1, 19967, '\P{^Blk=yijing}', "");
Expect(0, 19968, '\p{Blk=yijing}', "");
Expect(1, 19968, '\p{^Blk=yijing}', "");
Expect(1, 19968, '\P{Blk=yijing}', "");
Expect(0, 19968, '\P{^Blk=yijing}', "");
Expect(1, 19967, '\p{Blk=-YIJING}', "");
Expect(0, 19967, '\p{^Blk=-YIJING}', "");
Expect(0, 19967, '\P{Blk=-YIJING}', "");
Expect(1, 19967, '\P{^Blk=-YIJING}', "");
Expect(0, 19968, '\p{Blk=-YIJING}', "");
Expect(1, 19968, '\p{^Blk=-YIJING}', "");
Expect(1, 19968, '\P{Blk=-YIJING}', "");
Expect(0, 19968, '\P{^Blk=-YIJING}', "");
Error('\p{Is_Block=	:=Yijing_HEXAGRAM_symbols}');
Error('\P{Is_Block=	:=Yijing_HEXAGRAM_symbols}');
Expect(1, 19967, '\p{Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19967, '\P{Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\p{Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19968, '\P{Is_Block=yijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^Is_Block=yijinghexagramsymbols}', "");
Expect(1, 19967, '\p{Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(0, 19967, '\p{^Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(0, 19967, '\P{Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(1, 19967, '\P{^Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(0, 19968, '\p{Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(1, 19968, '\p{^Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(1, 19968, '\P{Is_Block= Yijing_Hexagram_Symbols}', "");
Expect(0, 19968, '\P{^Is_Block= Yijing_Hexagram_Symbols}', "");
Error('\p{Is_Blk=_	Yijing:=}');
Error('\P{Is_Blk=_	Yijing:=}');
Expect(1, 19967, '\p{Is_Blk=yijing}', "");
Expect(0, 19967, '\p{^Is_Blk=yijing}', "");
Expect(0, 19967, '\P{Is_Blk=yijing}', "");
Expect(1, 19967, '\P{^Is_Blk=yijing}', "");
Expect(0, 19968, '\p{Is_Blk=yijing}', "");
Expect(1, 19968, '\p{^Is_Blk=yijing}', "");
Expect(1, 19968, '\P{Is_Blk=yijing}', "");
Expect(0, 19968, '\P{^Is_Blk=yijing}', "");
Expect(1, 19967, '\p{Is_Blk=_Yijing}', "");
Expect(0, 19967, '\p{^Is_Blk=_Yijing}', "");
Expect(0, 19967, '\P{Is_Blk=_Yijing}', "");
Expect(1, 19967, '\P{^Is_Blk=_Yijing}', "");
Expect(0, 19968, '\p{Is_Blk=_Yijing}', "");
Expect(1, 19968, '\p{^Is_Blk=_Yijing}', "");
Expect(1, 19968, '\P{Is_Blk=_Yijing}', "");
Expect(0, 19968, '\P{^Is_Blk=_Yijing}', "");
Error('\p{Canonical_Combining_Class=/a/_ above}');
Error('\P{Canonical_Combining_Class=/a/_ above}');
Expect(1, 119364, '\p{Canonical_Combining_Class=above}', "");
Expect(0, 119364, '\p{^Canonical_Combining_Class=above}', "");
Expect(0, 119364, '\P{Canonical_Combining_Class=above}', "");
Expect(1, 119364, '\P{^Canonical_Combining_Class=above}', "");
Expect(0, 119365, '\p{Canonical_Combining_Class=above}', "");
Expect(1, 119365, '\p{^Canonical_Combining_Class=above}', "");
Expect(1, 119365, '\P{Canonical_Combining_Class=above}', "");
Expect(0, 119365, '\P{^Canonical_Combining_Class=above}', "");
Expect(1, 119364, '\p{Canonical_Combining_Class=	 Above}', "");
Expect(0, 119364, '\p{^Canonical_Combining_Class=	 Above}', "");
Expect(0, 119364, '\P{Canonical_Combining_Class=	 Above}', "");
Expect(1, 119364, '\P{^Canonical_Combining_Class=	 Above}', "");
Expect(0, 119365, '\p{Canonical_Combining_Class=	 Above}', "");
Expect(1, 119365, '\p{^Canonical_Combining_Class=	 Above}', "");
Expect(1, 119365, '\P{Canonical_Combining_Class=	 Above}', "");
Expect(0, 119365, '\P{^Canonical_Combining_Class=	 Above}', "");
Error('\p{Ccc= /a/a}');
Error('\P{Ccc= /a/a}');
Expect(1, 119364, '\p{Ccc=a}', "");
Expect(0, 119364, '\p{^Ccc=a}', "");
Expect(0, 119364, '\P{Ccc=a}', "");
Expect(1, 119364, '\P{^Ccc=a}', "");
Expect(0, 119365, '\p{Ccc=a}', "");
Expect(1, 119365, '\p{^Ccc=a}', "");
Expect(1, 119365, '\P{Ccc=a}', "");
Expect(0, 119365, '\P{^Ccc=a}', "");
Expect(1, 119364, '\p{Ccc=	_A}', "");
Expect(0, 119364, '\p{^Ccc=	_A}', "");
Expect(0, 119364, '\P{Ccc=	_A}', "");
Expect(1, 119364, '\P{^Ccc=	_A}', "");
Expect(0, 119365, '\p{Ccc=	_A}', "");
Expect(1, 119365, '\p{^Ccc=	_A}', "");
Expect(1, 119365, '\P{Ccc=	_A}', "");
Expect(0, 119365, '\P{^Ccc=	_A}', "");
Error('\p{Is_Canonical_Combining_Class=:=- 00_00_00_00_0230}');
Error('\P{Is_Canonical_Combining_Class=:=- 00_00_00_00_0230}');
Expect(1, 119364, '\p{Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(0, 119364, '\p{^Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(0, 119364, '\P{Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(1, 119364, '\P{^Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(0, 119365, '\p{Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(1, 119365, '\p{^Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(1, 119365, '\P{Is_Canonical_Combining_Class=0000_0002_30}', "");
Expect(0, 119365, '\P{^Is_Canonical_Combining_Class=0000_0002_30}', "");
Error('\p{Is_Ccc=:=	-ABOVE}');
Error('\P{Is_Ccc=:=	-ABOVE}');
Expect(1, 119364, '\p{Is_Ccc=above}', "");
Expect(0, 119364, '\p{^Is_Ccc=above}', "");
Expect(0, 119364, '\P{Is_Ccc=above}', "");
Expect(1, 119364, '\P{^Is_Ccc=above}', "");
Expect(0, 119365, '\p{Is_Ccc=above}', "");
Expect(1, 119365, '\p{^Is_Ccc=above}', "");
Expect(1, 119365, '\P{Is_Ccc=above}', "");
Expect(0, 119365, '\P{^Is_Ccc=above}', "");
Expect(1, 119364, '\p{Is_Ccc=	Above}', "");
Expect(0, 119364, '\p{^Is_Ccc=	Above}', "");
Expect(0, 119364, '\P{Is_Ccc=	Above}', "");
Expect(1, 119364, '\P{^Is_Ccc=	Above}', "");
Expect(0, 119365, '\p{Is_Ccc=	Above}', "");
Expect(1, 119365, '\p{^Is_Ccc=	Above}', "");
Expect(1, 119365, '\P{Is_Ccc=	Above}', "");
Expect(0, 119365, '\P{^Is_Ccc=	Above}', "");
Error('\p{Canonical_Combining_Class= ABOVE_Left/a/}');
Error('\P{Canonical_Combining_Class= ABOVE_Left/a/}');
Expect(1, 12331, '\p{Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12331, '\p{^Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12331, '\P{Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12331, '\P{^Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12332, '\p{Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12332, '\p{^Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12332, '\P{Canonical_Combining_Class=aboveleft}', "");
Expect(0, 12332, '\P{^Canonical_Combining_Class=aboveleft}', "");
Expect(1, 12331, '\p{Canonical_Combining_Class=  Above_LEFT}', "");
Expect(0, 12331, '\p{^Canonical_Combining_Class=  Above_LEFT}', "");
Expect(0, 12331, '\P{Canonical_Combining_Class=  Above_LEFT}', "");
Expect(1, 12331, '\P{^Canonical_Combining_Class=  Above_LEFT}', "");
Expect(0, 12332, '\p{Canonical_Combining_Class=  Above_LEFT}', "");
Expect(1, 12332, '\p{^Canonical_Combining_Class=  Above_LEFT}', "");
Expect(1, 12332, '\P{Canonical_Combining_Class=  Above_LEFT}', "");
Expect(0, 12332, '\P{^Canonical_Combining_Class=  Above_LEFT}', "");
Error('\p{Ccc=:=-AL}');
Error('\P{Ccc=:=-AL}');
Expect(1, 12331, '\p{Ccc=al}', "");
Expect(0, 12331, '\p{^Ccc=al}', "");
Expect(0, 12331, '\P{Ccc=al}', "");
Expect(1, 12331, '\P{^Ccc=al}', "");
Expect(0, 12332, '\p{Ccc=al}', "");
Expect(1, 12332, '\p{^Ccc=al}', "");
Expect(1, 12332, '\P{Ccc=al}', "");
Expect(0, 12332, '\P{^Ccc=al}', "");
Expect(1, 12331, '\p{Ccc=--AL}', "");
Expect(0, 12331, '\p{^Ccc=--AL}', "");
Expect(0, 12331, '\P{Ccc=--AL}', "");
Expect(1, 12331, '\P{^Ccc=--AL}', "");
Expect(0, 12332, '\p{Ccc=--AL}', "");
Expect(1, 12332, '\p{^Ccc=--AL}', "");
Expect(1, 12332, '\P{Ccc=--AL}', "");
Expect(0, 12332, '\P{^Ccc=--AL}', "");
Error('\p{Is_Canonical_Combining_Class=:=	_00000228}');
Error('\P{Is_Canonical_Combining_Class=:=	_00000228}');
Expect(1, 12331, '\p{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(0, 12331, '\p{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(0, 12331, '\P{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(1, 12331, '\P{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(0, 12332, '\p{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(1, 12332, '\p{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(1, 12332, '\P{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Expect(0, 12332, '\P{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_0_228}', "");
Error('\p{Is_Ccc=:=__Above_left}');
Error('\P{Is_Ccc=:=__Above_left}');
Expect(1, 12331, '\p{Is_Ccc=aboveleft}', "");
Expect(0, 12331, '\p{^Is_Ccc=aboveleft}', "");
Expect(0, 12331, '\P{Is_Ccc=aboveleft}', "");
Expect(1, 12331, '\P{^Is_Ccc=aboveleft}', "");
Expect(0, 12332, '\p{Is_Ccc=aboveleft}', "");
Expect(1, 12332, '\p{^Is_Ccc=aboveleft}', "");
Expect(1, 12332, '\P{Is_Ccc=aboveleft}', "");
Expect(0, 12332, '\P{^Is_Ccc=aboveleft}', "");
Expect(1, 12331, '\p{Is_Ccc=_-ABOVE_LEFT}', "");
Expect(0, 12331, '\p{^Is_Ccc=_-ABOVE_LEFT}', "");
Expect(0, 12331, '\P{Is_Ccc=_-ABOVE_LEFT}', "");
Expect(1, 12331, '\P{^Is_Ccc=_-ABOVE_LEFT}', "");
Expect(0, 12332, '\p{Is_Ccc=_-ABOVE_LEFT}', "");
Expect(1, 12332, '\p{^Is_Ccc=_-ABOVE_LEFT}', "");
Expect(1, 12332, '\P{Is_Ccc=_-ABOVE_LEFT}', "");
Expect(0, 12332, '\P{^Is_Ccc=_-ABOVE_LEFT}', "");
Error('\p{Canonical_Combining_Class=-/a/ABOVE_RIGHT}');
Error('\P{Canonical_Combining_Class=-/a/ABOVE_RIGHT}');
Expect(1, 12332, '\p{Canonical_Combining_Class=aboveright}', "");
Expect(0, 12332, '\p{^Canonical_Combining_Class=aboveright}', "");
Expect(0, 12332, '\P{Canonical_Combining_Class=aboveright}', "");
Expect(1, 12332, '\P{^Canonical_Combining_Class=aboveright}', "");
Expect(0, 12333, '\p{Canonical_Combining_Class=aboveright}', "");
Expect(1, 12333, '\p{^Canonical_Combining_Class=aboveright}', "");
Expect(1, 12333, '\P{Canonical_Combining_Class=aboveright}', "");
Expect(0, 12333, '\P{^Canonical_Combining_Class=aboveright}', "");
Expect(1, 12332, '\p{Canonical_Combining_Class=-above_Right}', "");
Expect(0, 12332, '\p{^Canonical_Combining_Class=-above_Right}', "");
Expect(0, 12332, '\P{Canonical_Combining_Class=-above_Right}', "");
Expect(1, 12332, '\P{^Canonical_Combining_Class=-above_Right}', "");
Expect(0, 12333, '\p{Canonical_Combining_Class=-above_Right}', "");
Expect(1, 12333, '\p{^Canonical_Combining_Class=-above_Right}', "");
Expect(1, 12333, '\P{Canonical_Combining_Class=-above_Right}', "");
Expect(0, 12333, '\P{^Canonical_Combining_Class=-above_Right}', "");
Error('\p{Ccc=	:=AR}');
Error('\P{Ccc=	:=AR}');
Expect(1, 12332, '\p{Ccc=ar}', "");
Expect(0, 12332, '\p{^Ccc=ar}', "");
Expect(0, 12332, '\P{Ccc=ar}', "");
Expect(1, 12332, '\P{^Ccc=ar}', "");
Expect(0, 12333, '\p{Ccc=ar}', "");
Expect(1, 12333, '\p{^Ccc=ar}', "");
Expect(1, 12333, '\P{Ccc=ar}', "");
Expect(0, 12333, '\P{^Ccc=ar}', "");
Expect(1, 12332, '\p{Ccc:   _ AR}', "");
Expect(0, 12332, '\p{^Ccc:   _ AR}', "");
Expect(0, 12332, '\P{Ccc:   _ AR}', "");
Expect(1, 12332, '\P{^Ccc:   _ AR}', "");
Expect(0, 12333, '\p{Ccc:   _ AR}', "");
Expect(1, 12333, '\p{^Ccc:   _ AR}', "");
Expect(1, 12333, '\P{Ccc:   _ AR}', "");
Expect(0, 12333, '\P{^Ccc:   _ AR}', "");
Error('\p{Is_Canonical_Combining_Class= 	00_23_2:=}');
Error('\P{Is_Canonical_Combining_Class= 	00_23_2:=}');
Expect(1, 12332, '\p{Is_Canonical_Combining_Class=+000000232}', "");
Expect(0, 12332, '\p{^Is_Canonical_Combining_Class=+000000232}', "");
Expect(0, 12332, '\P{Is_Canonical_Combining_Class=+000000232}', "");
Expect(1, 12332, '\P{^Is_Canonical_Combining_Class=+000000232}', "");
Expect(0, 12333, '\p{Is_Canonical_Combining_Class=+000000232}', "");
Expect(1, 12333, '\p{^Is_Canonical_Combining_Class=+000000232}', "");
Expect(1, 12333, '\P{Is_Canonical_Combining_Class=+000000232}', "");
Expect(0, 12333, '\P{^Is_Canonical_Combining_Class=+000000232}', "");
Error('\p{Is_Ccc=-Above_right/a/}');
Error('\P{Is_Ccc=-Above_right/a/}');
Expect(1, 12332, '\p{Is_Ccc=aboveright}', "");
Expect(0, 12332, '\p{^Is_Ccc=aboveright}', "");
Expect(0, 12332, '\P{Is_Ccc=aboveright}', "");
Expect(1, 12332, '\P{^Is_Ccc=aboveright}', "");
Expect(0, 12333, '\p{Is_Ccc=aboveright}', "");
Expect(1, 12333, '\p{^Is_Ccc=aboveright}', "");
Expect(1, 12333, '\P{Is_Ccc=aboveright}', "");
Expect(0, 12333, '\P{^Is_Ccc=aboveright}', "");
Expect(1, 12332, '\p{Is_Ccc=_ ABOVE_right}', "");
Expect(0, 12332, '\p{^Is_Ccc=_ ABOVE_right}', "");
Expect(0, 12332, '\P{Is_Ccc=_ ABOVE_right}', "");
Expect(1, 12332, '\P{^Is_Ccc=_ ABOVE_right}', "");
Expect(0, 12333, '\p{Is_Ccc=_ ABOVE_right}', "");
Expect(1, 12333, '\p{^Is_Ccc=_ ABOVE_right}', "");
Expect(1, 12333, '\P{Is_Ccc=_ ABOVE_right}', "");
Expect(0, 12333, '\P{^Is_Ccc=_ ABOVE_right}', "");
Error('\p{Canonical_Combining_Class: _attached_Above:=}');
Error('\P{Canonical_Combining_Class: _attached_Above:=}');
Expect(1, 7630, '\p{Canonical_Combining_Class=attachedabove}', "");
Expect(0, 7630, '\p{^Canonical_Combining_Class=attachedabove}', "");
Expect(0, 7630, '\P{Canonical_Combining_Class=attachedabove}', "");
Expect(1, 7630, '\P{^Canonical_Combining_Class=attachedabove}', "");
Expect(0, 7631, '\p{Canonical_Combining_Class=attachedabove}', "");
Expect(1, 7631, '\p{^Canonical_Combining_Class=attachedabove}', "");
Expect(1, 7631, '\P{Canonical_Combining_Class=attachedabove}', "");
Expect(0, 7631, '\P{^Canonical_Combining_Class=attachedabove}', "");
Expect(1, 7630, '\p{Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(0, 7630, '\p{^Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(0, 7630, '\P{Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(1, 7630, '\P{^Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(0, 7631, '\p{Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(1, 7631, '\p{^Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(1, 7631, '\P{Canonical_Combining_Class:  Attached_ABOVE}', "");
Expect(0, 7631, '\P{^Canonical_Combining_Class:  Attached_ABOVE}', "");
Error('\p{Ccc=/a/-	ata}');
Error('\P{Ccc=/a/-	ata}');
Expect(1, 7630, '\p{Ccc=ata}', "");
Expect(0, 7630, '\p{^Ccc=ata}', "");
Expect(0, 7630, '\P{Ccc=ata}', "");
Expect(1, 7630, '\P{^Ccc=ata}', "");
Expect(0, 7631, '\p{Ccc=ata}', "");
Expect(1, 7631, '\p{^Ccc=ata}', "");
Expect(1, 7631, '\P{Ccc=ata}', "");
Expect(0, 7631, '\P{^Ccc=ata}', "");
Expect(1, 7630, '\p{Ccc=-ATA}', "");
Expect(0, 7630, '\p{^Ccc=-ATA}', "");
Expect(0, 7630, '\P{Ccc=-ATA}', "");
Expect(1, 7630, '\P{^Ccc=-ATA}', "");
Expect(0, 7631, '\p{Ccc=-ATA}', "");
Expect(1, 7631, '\p{^Ccc=-ATA}', "");
Expect(1, 7631, '\P{Ccc=-ATA}', "");
Expect(0, 7631, '\P{^Ccc=-ATA}', "");
Error('\p{Is_Canonical_Combining_Class=_00214/a/}');
Error('\P{Is_Canonical_Combining_Class=_00214/a/}');
Expect(1, 7630, '\p{Is_Canonical_Combining_Class=214}', "");
Expect(0, 7630, '\p{^Is_Canonical_Combining_Class=214}', "");
Expect(0, 7630, '\P{Is_Canonical_Combining_Class=214}', "");
Expect(1, 7630, '\P{^Is_Canonical_Combining_Class=214}', "");
Expect(0, 7631, '\p{Is_Canonical_Combining_Class=214}', "");
Expect(1, 7631, '\p{^Is_Canonical_Combining_Class=214}', "");
Expect(1, 7631, '\P{Is_Canonical_Combining_Class=214}', "");
Expect(0, 7631, '\P{^Is_Canonical_Combining_Class=214}', "");
Error('\p{Is_Ccc::=-	ATTACHED_ABOVE}');
Error('\P{Is_Ccc::=-	ATTACHED_ABOVE}');
Expect(1, 7630, '\p{Is_Ccc=attachedabove}', "");
Expect(0, 7630, '\p{^Is_Ccc=attachedabove}', "");
Expect(0, 7630, '\P{Is_Ccc=attachedabove}', "");
Expect(1, 7630, '\P{^Is_Ccc=attachedabove}', "");
Expect(0, 7631, '\p{Is_Ccc=attachedabove}', "");
Expect(1, 7631, '\p{^Is_Ccc=attachedabove}', "");
Expect(1, 7631, '\P{Is_Ccc=attachedabove}', "");
Expect(0, 7631, '\P{^Is_Ccc=attachedabove}', "");
Expect(1, 7630, '\p{Is_Ccc=-ATTACHED_Above}', "");
Expect(0, 7630, '\p{^Is_Ccc=-ATTACHED_Above}', "");
Expect(0, 7630, '\P{Is_Ccc=-ATTACHED_Above}', "");
Expect(1, 7630, '\P{^Is_Ccc=-ATTACHED_Above}', "");
Expect(0, 7631, '\p{Is_Ccc=-ATTACHED_Above}', "");
Expect(1, 7631, '\p{^Is_Ccc=-ATTACHED_Above}', "");
Expect(1, 7631, '\P{Is_Ccc=-ATTACHED_Above}', "");
Expect(0, 7631, '\P{^Is_Ccc=-ATTACHED_Above}', "");
Error('\p{Canonical_Combining_Class=-/a/attached_ABOVE_RIGHT}');
Error('\P{Canonical_Combining_Class=-/a/attached_ABOVE_RIGHT}');
Expect(1, 119154, '\p{Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119154, '\p{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119154, '\P{Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119154, '\P{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119155, '\p{Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119155, '\p{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119155, '\P{Canonical_Combining_Class=attachedaboveright}', "");
Expect(0, 119155, '\P{^Canonical_Combining_Class=attachedaboveright}', "");
Expect(1, 119154, '\p{Canonical_Combining_Class= -attached_Above_right}', "");
Expect(0, 119154, '\p{^Canonical_Combining_Class= -attached_Above_right}', "");
Expect(0, 119154, '\P{Canonical_Combining_Class= -attached_Above_right}', "");
Expect(1, 119154, '\P{^Canonical_Combining_Class= -attached_Above_right}', "");
Expect(0, 119155, '\p{Canonical_Combining_Class= -attached_Above_right}', "");
Expect(1, 119155, '\p{^Canonical_Combining_Class= -attached_Above_right}', "");
Expect(1, 119155, '\P{Canonical_Combining_Class= -attached_Above_right}', "");
Expect(0, 119155, '\P{^Canonical_Combining_Class= -attached_Above_right}', "");
Error('\p{Ccc=-/a/atar}');
Error('\P{Ccc=-/a/atar}');
Expect(1, 119154, '\p{Ccc=atar}', "");
Expect(0, 119154, '\p{^Ccc=atar}', "");
Expect(0, 119154, '\P{Ccc=atar}', "");
Expect(1, 119154, '\P{^Ccc=atar}', "");
Expect(0, 119155, '\p{Ccc=atar}', "");
Expect(1, 119155, '\p{^Ccc=atar}', "");
Expect(1, 119155, '\P{Ccc=atar}', "");
Expect(0, 119155, '\P{^Ccc=atar}', "");
Expect(1, 119154, '\p{Ccc:	ATAR}', "");
Expect(0, 119154, '\p{^Ccc:	ATAR}', "");
Expect(0, 119154, '\P{Ccc:	ATAR}', "");
Expect(1, 119154, '\P{^Ccc:	ATAR}', "");
Expect(0, 119155, '\p{Ccc:	ATAR}', "");
Expect(1, 119155, '\p{^Ccc:	ATAR}', "");
Expect(1, 119155, '\P{Ccc:	ATAR}', "");
Expect(0, 119155, '\P{^Ccc:	ATAR}', "");
Error('\p{Is_Canonical_Combining_Class:   _0_0_0_0_0216/a/}');
Error('\P{Is_Canonical_Combining_Class:   _0_0_0_0_0216/a/}');
Expect(1, 119154, '\p{Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(0, 119154, '\p{^Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(0, 119154, '\P{Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(1, 119154, '\P{^Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(0, 119155, '\p{Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(1, 119155, '\p{^Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(1, 119155, '\P{Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Expect(0, 119155, '\P{^Is_Canonical_Combining_Class=00_00_00_00_02_16}', "");
Error('\p{Is_Ccc=/a/-attached_Above_Right}');
Error('\P{Is_Ccc=/a/-attached_Above_Right}');
Expect(1, 119154, '\p{Is_Ccc=attachedaboveright}', "");
Expect(0, 119154, '\p{^Is_Ccc=attachedaboveright}', "");
Expect(0, 119154, '\P{Is_Ccc=attachedaboveright}', "");
Expect(1, 119154, '\P{^Is_Ccc=attachedaboveright}', "");
Expect(0, 119155, '\p{Is_Ccc=attachedaboveright}', "");
Expect(1, 119155, '\p{^Is_Ccc=attachedaboveright}', "");
Expect(1, 119155, '\P{Is_Ccc=attachedaboveright}', "");
Expect(0, 119155, '\P{^Is_Ccc=attachedaboveright}', "");
Expect(1, 119154, '\p{Is_Ccc=--attached_Above_Right}', "");
Expect(0, 119154, '\p{^Is_Ccc=--attached_Above_Right}', "");
Expect(0, 119154, '\P{Is_Ccc=--attached_Above_Right}', "");
Expect(1, 119154, '\P{^Is_Ccc=--attached_Above_Right}', "");
Expect(0, 119155, '\p{Is_Ccc=--attached_Above_Right}', "");
Expect(1, 119155, '\p{^Is_Ccc=--attached_Above_Right}', "");
Expect(1, 119155, '\P{Is_Ccc=--attached_Above_Right}', "");
Expect(0, 119155, '\P{^Is_Ccc=--attached_Above_Right}', "");
Error('\p{Canonical_Combining_Class=	:=ATTACHED_Below}');
Error('\P{Canonical_Combining_Class=	:=ATTACHED_Below}');
Expect(1, 7632, '\p{Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7632, '\p{^Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7632, '\P{Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7632, '\P{^Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7633, '\p{Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7633, '\p{^Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7633, '\P{Canonical_Combining_Class=attachedbelow}', "");
Expect(0, 7633, '\P{^Canonical_Combining_Class=attachedbelow}', "");
Expect(1, 7632, '\p{Canonical_Combining_Class=Attached_Below}', "");
Expect(0, 7632, '\p{^Canonical_Combining_Class=Attached_Below}', "");
Expect(0, 7632, '\P{Canonical_Combining_Class=Attached_Below}', "");
Expect(1, 7632, '\P{^Canonical_Combining_Class=Attached_Below}', "");
Expect(0, 7633, '\p{Canonical_Combining_Class=Attached_Below}', "");
Expect(1, 7633, '\p{^Canonical_Combining_Class=Attached_Below}', "");
Expect(1, 7633, '\P{Canonical_Combining_Class=Attached_Below}', "");
Expect(0, 7633, '\P{^Canonical_Combining_Class=Attached_Below}', "");
Error('\p{Ccc=/a/_-ATB}');
Error('\P{Ccc=/a/_-ATB}');
Expect(1, 7632, '\p{Ccc=atb}', "");
Expect(0, 7632, '\p{^Ccc=atb}', "");
Expect(0, 7632, '\P{Ccc=atb}', "");
Expect(1, 7632, '\P{^Ccc=atb}', "");
Expect(0, 7633, '\p{Ccc=atb}', "");
Expect(1, 7633, '\p{^Ccc=atb}', "");
Expect(1, 7633, '\P{Ccc=atb}', "");
Expect(0, 7633, '\P{^Ccc=atb}', "");
Expect(1, 7632, '\p{Ccc:- ATB}', "");
Expect(0, 7632, '\p{^Ccc:- ATB}', "");
Expect(0, 7632, '\P{Ccc:- ATB}', "");
Expect(1, 7632, '\P{^Ccc:- ATB}', "");
Expect(0, 7633, '\p{Ccc:- ATB}', "");
Expect(1, 7633, '\p{^Ccc:- ATB}', "");
Expect(1, 7633, '\P{Ccc:- ATB}', "");
Expect(0, 7633, '\P{^Ccc:- ATB}', "");
Error('\p{Is_Canonical_Combining_Class=	/a/0_0_0_0_2_02}');
Error('\P{Is_Canonical_Combining_Class=	/a/0_0_0_0_2_02}');
Expect(1, 7632, '\p{Is_Canonical_Combining_Class=000000202}', "");
Expect(0, 7632, '\p{^Is_Canonical_Combining_Class=000000202}', "");
Expect(0, 7632, '\P{Is_Canonical_Combining_Class=000000202}', "");
Expect(1, 7632, '\P{^Is_Canonical_Combining_Class=000000202}', "");
Expect(0, 7633, '\p{Is_Canonical_Combining_Class=000000202}', "");
Expect(1, 7633, '\p{^Is_Canonical_Combining_Class=000000202}', "");
Expect(1, 7633, '\P{Is_Canonical_Combining_Class=000000202}', "");
Expect(0, 7633, '\P{^Is_Canonical_Combining_Class=000000202}', "");
Error('\p{Is_Ccc=-:=Attached_Below}');
Error('\P{Is_Ccc=-:=Attached_Below}');
Expect(1, 7632, '\p{Is_Ccc=attachedbelow}', "");
Expect(0, 7632, '\p{^Is_Ccc=attachedbelow}', "");
Expect(0, 7632, '\P{Is_Ccc=attachedbelow}', "");
Expect(1, 7632, '\P{^Is_Ccc=attachedbelow}', "");
Expect(0, 7633, '\p{Is_Ccc=attachedbelow}', "");
Expect(1, 7633, '\p{^Is_Ccc=attachedbelow}', "");
Expect(1, 7633, '\P{Is_Ccc=attachedbelow}', "");
Expect(0, 7633, '\P{^Is_Ccc=attachedbelow}', "");
Expect(1, 7632, '\p{Is_Ccc=--attached_BELOW}', "");
Expect(0, 7632, '\p{^Is_Ccc=--attached_BELOW}', "");
Expect(0, 7632, '\P{Is_Ccc=--attached_BELOW}', "");
Expect(1, 7632, '\P{^Is_Ccc=--attached_BELOW}', "");
Expect(0, 7633, '\p{Is_Ccc=--attached_BELOW}', "");
Expect(1, 7633, '\p{^Is_Ccc=--attached_BELOW}', "");
Expect(1, 7633, '\P{Is_Ccc=--attached_BELOW}', "");
Expect(0, 7633, '\P{^Is_Ccc=--attached_BELOW}', "");
Error('\p{Canonical_Combining_Class=:=__Attached_Below_LEFT}');
Error('\P{Canonical_Combining_Class=:=__Attached_Below_LEFT}');
Expect(0, 1, '\p{Canonical_Combining_Class=attachedbelowleft}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class=attachedbelowleft}', "");
Expect(1, 1, '\P{Canonical_Combining_Class=attachedbelowleft}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class=attachedbelowleft}', "");
Expect(0, 1, '\p{Canonical_Combining_Class=_ ATTACHED_Below_left}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class=_ ATTACHED_Below_left}', "");
Expect(1, 1, '\P{Canonical_Combining_Class=_ ATTACHED_Below_left}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class=_ ATTACHED_Below_left}', "");
Error('\p{Ccc=:=atbl}');
Error('\P{Ccc=:=atbl}');
Expect(0, 1, '\p{Ccc=atbl}', "");
Expect(1, 1, '\p{^Ccc=atbl}', "");
Expect(1, 1, '\P{Ccc=atbl}', "");
Expect(0, 1, '\P{^Ccc=atbl}', "");
Expect(0, 1, '\p{Ccc:	-ATBL}', "");
Expect(1, 1, '\p{^Ccc:	-ATBL}', "");
Expect(1, 1, '\P{Ccc:	-ATBL}', "");
Expect(0, 1, '\P{^Ccc:	-ATBL}', "");
Error('\p{Is_Canonical_Combining_Class:		00020_0/a/}');
Error('\P{Is_Canonical_Combining_Class:		00020_0/a/}');
Expect(0, 1, '\p{Is_Canonical_Combining_Class=000200}', "");
Expect(1, 1, '\p{^Is_Canonical_Combining_Class=000200}', "");
Expect(1, 1, '\P{Is_Canonical_Combining_Class=000200}', "");
Expect(0, 1, '\P{^Is_Canonical_Combining_Class=000200}', "");
Error('\p{Is_Ccc=:=	_Attached_below_Left}');
Error('\P{Is_Ccc=:=	_Attached_below_Left}');
Expect(0, 1, '\p{Is_Ccc=attachedbelowleft}', "");
Expect(1, 1, '\p{^Is_Ccc=attachedbelowleft}', "");
Expect(1, 1, '\P{Is_Ccc=attachedbelowleft}', "");
Expect(0, 1, '\P{^Is_Ccc=attachedbelowleft}', "");
Expect(0, 1, '\p{Is_Ccc= ATTACHED_BELOW_Left}', "");
Expect(1, 1, '\p{^Is_Ccc= ATTACHED_BELOW_Left}', "");
Expect(1, 1, '\P{Is_Ccc= ATTACHED_BELOW_Left}', "");
Expect(0, 1, '\P{^Is_Ccc= ATTACHED_BELOW_Left}', "");
Error('\p{Canonical_Combining_Class=-	Below/a/}');
Error('\P{Canonical_Combining_Class=-	Below/a/}');
Expect(1, 119179, '\p{Canonical_Combining_Class=below}', "");
Expect(0, 119179, '\p{^Canonical_Combining_Class=below}', "");
Expect(0, 119179, '\P{Canonical_Combining_Class=below}', "");
Expect(1, 119179, '\P{^Canonical_Combining_Class=below}', "");
Expect(0, 119180, '\p{Canonical_Combining_Class=below}', "");
Expect(1, 119180, '\p{^Canonical_Combining_Class=below}', "");
Expect(1, 119180, '\P{Canonical_Combining_Class=below}', "");
Expect(0, 119180, '\P{^Canonical_Combining_Class=below}', "");
Expect(1, 119179, '\p{Canonical_Combining_Class= -Below}', "");
Expect(0, 119179, '\p{^Canonical_Combining_Class= -Below}', "");
Expect(0, 119179, '\P{Canonical_Combining_Class= -Below}', "");
Expect(1, 119179, '\P{^Canonical_Combining_Class= -Below}', "");
Expect(0, 119180, '\p{Canonical_Combining_Class= -Below}', "");
Expect(1, 119180, '\p{^Canonical_Combining_Class= -Below}', "");
Expect(1, 119180, '\P{Canonical_Combining_Class= -Below}', "");
Expect(0, 119180, '\P{^Canonical_Combining_Class= -Below}', "");
Error('\p{Ccc=:=--B}');
Error('\P{Ccc=:=--B}');
Expect(1, 119179, '\p{Ccc=b}', "");
Expect(0, 119179, '\p{^Ccc=b}', "");
Expect(0, 119179, '\P{Ccc=b}', "");
Expect(1, 119179, '\P{^Ccc=b}', "");
Expect(0, 119180, '\p{Ccc=b}', "");
Expect(1, 119180, '\p{^Ccc=b}', "");
Expect(1, 119180, '\P{Ccc=b}', "");
Expect(0, 119180, '\P{^Ccc=b}', "");
Expect(1, 119179, '\p{Ccc=_-B}', "");
Expect(0, 119179, '\p{^Ccc=_-B}', "");
Expect(0, 119179, '\P{Ccc=_-B}', "");
Expect(1, 119179, '\P{^Ccc=_-B}', "");
Expect(0, 119180, '\p{Ccc=_-B}', "");
Expect(1, 119180, '\p{^Ccc=_-B}', "");
Expect(1, 119180, '\P{Ccc=_-B}', "");
Expect(0, 119180, '\P{^Ccc=_-B}', "");
Error('\p{Is_Canonical_Combining_Class=- +0_2_20/a/}');
Error('\P{Is_Canonical_Combining_Class=- +0_2_20/a/}');
Expect(1, 119179, '\p{Is_Canonical_Combining_Class=+0022_0}', "");
Expect(0, 119179, '\p{^Is_Canonical_Combining_Class=+0022_0}', "");
Expect(0, 119179, '\P{Is_Canonical_Combining_Class=+0022_0}', "");
Expect(1, 119179, '\P{^Is_Canonical_Combining_Class=+0022_0}', "");
Expect(0, 119180, '\p{Is_Canonical_Combining_Class=+0022_0}', "");
Expect(1, 119180, '\p{^Is_Canonical_Combining_Class=+0022_0}', "");
Expect(1, 119180, '\P{Is_Canonical_Combining_Class=+0022_0}', "");
Expect(0, 119180, '\P{^Is_Canonical_Combining_Class=+0022_0}', "");
Error('\p{Is_Ccc=	/a/BELOW}');
Error('\P{Is_Ccc=	/a/BELOW}');
Expect(1, 119179, '\p{Is_Ccc=below}', "");
Expect(0, 119179, '\p{^Is_Ccc=below}', "");
Expect(0, 119179, '\P{Is_Ccc=below}', "");
Expect(1, 119179, '\P{^Is_Ccc=below}', "");
Expect(0, 119180, '\p{Is_Ccc=below}', "");
Expect(1, 119180, '\p{^Is_Ccc=below}', "");
Expect(1, 119180, '\P{Is_Ccc=below}', "");
Expect(0, 119180, '\P{^Is_Ccc=below}', "");
Expect(1, 119179, '\p{Is_Ccc=	Below}', "");
Expect(0, 119179, '\p{^Is_Ccc=	Below}', "");
Expect(0, 119179, '\P{Is_Ccc=	Below}', "");
Expect(1, 119179, '\P{^Is_Ccc=	Below}', "");
Expect(0, 119180, '\p{Is_Ccc=	Below}', "");
Expect(1, 119180, '\p{^Is_Ccc=	Below}', "");
Expect(1, 119180, '\P{Is_Ccc=	Below}', "");
Expect(0, 119180, '\P{^Is_Ccc=	Below}', "");
Error('\p{Canonical_Combining_Class= 	Below_Left:=}');
Error('\P{Canonical_Combining_Class= 	Below_Left:=}');
Expect(1, 12330, '\p{Canonical_Combining_Class: belowleft}', "");
Expect(0, 12330, '\p{^Canonical_Combining_Class: belowleft}', "");
Expect(0, 12330, '\P{Canonical_Combining_Class: belowleft}', "");
Expect(1, 12330, '\P{^Canonical_Combining_Class: belowleft}', "");
Expect(0, 12331, '\p{Canonical_Combining_Class: belowleft}', "");
Expect(1, 12331, '\p{^Canonical_Combining_Class: belowleft}', "");
Expect(1, 12331, '\P{Canonical_Combining_Class: belowleft}', "");
Expect(0, 12331, '\P{^Canonical_Combining_Class: belowleft}', "");
Expect(1, 12330, '\p{Canonical_Combining_Class=-Below_LEFT}', "");
Expect(0, 12330, '\p{^Canonical_Combining_Class=-Below_LEFT}', "");
Expect(0, 12330, '\P{Canonical_Combining_Class=-Below_LEFT}', "");
Expect(1, 12330, '\P{^Canonical_Combining_Class=-Below_LEFT}', "");
Expect(0, 12331, '\p{Canonical_Combining_Class=-Below_LEFT}', "");
Expect(1, 12331, '\p{^Canonical_Combining_Class=-Below_LEFT}', "");
Expect(1, 12331, '\P{Canonical_Combining_Class=-Below_LEFT}', "");
Expect(0, 12331, '\P{^Canonical_Combining_Class=-Below_LEFT}', "");
Error('\p{Ccc=-:=BL}');
Error('\P{Ccc=-:=BL}');
Expect(1, 12330, '\p{Ccc=bl}', "");
Expect(0, 12330, '\p{^Ccc=bl}', "");
Expect(0, 12330, '\P{Ccc=bl}', "");
Expect(1, 12330, '\P{^Ccc=bl}', "");
Expect(0, 12331, '\p{Ccc=bl}', "");
Expect(1, 12331, '\p{^Ccc=bl}', "");
Expect(1, 12331, '\P{Ccc=bl}', "");
Expect(0, 12331, '\P{^Ccc=bl}', "");
Expect(1, 12330, '\p{Ccc=-BL}', "");
Expect(0, 12330, '\p{^Ccc=-BL}', "");
Expect(0, 12330, '\P{Ccc=-BL}', "");
Expect(1, 12330, '\P{^Ccc=-BL}', "");
Expect(0, 12331, '\p{Ccc=-BL}', "");
Expect(1, 12331, '\p{^Ccc=-BL}', "");
Expect(1, 12331, '\P{Ccc=-BL}', "");
Expect(0, 12331, '\P{^Ccc=-BL}', "");
Error('\p{Is_Canonical_Combining_Class=- 000000218/a/}');
Error('\P{Is_Canonical_Combining_Class=- 000000218/a/}');
Expect(1, 12330, '\p{Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(0, 12330, '\p{^Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(0, 12330, '\P{Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(1, 12330, '\P{^Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(0, 12331, '\p{Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(1, 12331, '\p{^Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(1, 12331, '\P{Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Expect(0, 12331, '\P{^Is_Canonical_Combining_Class=0_0_0_2_18}', "");
Error('\p{Is_Ccc:   	Below_Left/a/}');
Error('\P{Is_Ccc:   	Below_Left/a/}');
Expect(1, 12330, '\p{Is_Ccc=belowleft}', "");
Expect(0, 12330, '\p{^Is_Ccc=belowleft}', "");
Expect(0, 12330, '\P{Is_Ccc=belowleft}', "");
Expect(1, 12330, '\P{^Is_Ccc=belowleft}', "");
Expect(0, 12331, '\p{Is_Ccc=belowleft}', "");
Expect(1, 12331, '\p{^Is_Ccc=belowleft}', "");
Expect(1, 12331, '\P{Is_Ccc=belowleft}', "");
Expect(0, 12331, '\P{^Is_Ccc=belowleft}', "");
Expect(1, 12330, '\p{Is_Ccc=_ Below_LEFT}', "");
Expect(0, 12330, '\p{^Is_Ccc=_ Below_LEFT}', "");
Expect(0, 12330, '\P{Is_Ccc=_ Below_LEFT}', "");
Expect(1, 12330, '\P{^Is_Ccc=_ Below_LEFT}', "");
Expect(0, 12331, '\p{Is_Ccc=_ Below_LEFT}', "");
Expect(1, 12331, '\p{^Is_Ccc=_ Below_LEFT}', "");
Expect(1, 12331, '\P{Is_Ccc=_ Below_LEFT}', "");
Expect(0, 12331, '\P{^Is_Ccc=_ Below_LEFT}', "");
Error('\p{Canonical_Combining_Class=  BELOW_RIGHT/a/}');
Error('\P{Canonical_Combining_Class=  BELOW_RIGHT/a/}');
Expect(1, 12333, '\p{Canonical_Combining_Class:   belowright}', "");
Expect(0, 12333, '\p{^Canonical_Combining_Class:   belowright}', "");
Expect(0, 12333, '\P{Canonical_Combining_Class:   belowright}', "");
Expect(1, 12333, '\P{^Canonical_Combining_Class:   belowright}', "");
Expect(0, 12334, '\p{Canonical_Combining_Class:   belowright}', "");
Expect(1, 12334, '\p{^Canonical_Combining_Class:   belowright}', "");
Expect(1, 12334, '\P{Canonical_Combining_Class:   belowright}', "");
Expect(0, 12334, '\P{^Canonical_Combining_Class:   belowright}', "");
Expect(1, 12333, '\p{Canonical_Combining_Class=		Below_Right}', "");
Expect(0, 12333, '\p{^Canonical_Combining_Class=		Below_Right}', "");
Expect(0, 12333, '\P{Canonical_Combining_Class=		Below_Right}', "");
Expect(1, 12333, '\P{^Canonical_Combining_Class=		Below_Right}', "");
Expect(0, 12334, '\p{Canonical_Combining_Class=		Below_Right}', "");
Expect(1, 12334, '\p{^Canonical_Combining_Class=		Below_Right}', "");
Expect(1, 12334, '\P{Canonical_Combining_Class=		Below_Right}', "");
Expect(0, 12334, '\P{^Canonical_Combining_Class=		Below_Right}', "");
Error('\p{Ccc=/a/	br}');
Error('\P{Ccc=/a/	br}');
Expect(1, 12333, '\p{Ccc=br}', "");
Expect(0, 12333, '\p{^Ccc=br}', "");
Expect(0, 12333, '\P{Ccc=br}', "");
Expect(1, 12333, '\P{^Ccc=br}', "");
Expect(0, 12334, '\p{Ccc=br}', "");
Expect(1, 12334, '\p{^Ccc=br}', "");
Expect(1, 12334, '\P{Ccc=br}', "");
Expect(0, 12334, '\P{^Ccc=br}', "");
Expect(1, 12333, '\p{Ccc= 	BR}', "");
Expect(0, 12333, '\p{^Ccc= 	BR}', "");
Expect(0, 12333, '\P{Ccc= 	BR}', "");
Expect(1, 12333, '\P{^Ccc= 	BR}', "");
Expect(0, 12334, '\p{Ccc= 	BR}', "");
Expect(1, 12334, '\p{^Ccc= 	BR}', "");
Expect(1, 12334, '\P{Ccc= 	BR}', "");
Expect(0, 12334, '\P{^Ccc= 	BR}', "");
Error('\p{Is_Canonical_Combining_Class=_00000_00022_2:=}');
Error('\P{Is_Canonical_Combining_Class=_00000_00022_2:=}');
Expect(1, 12333, '\p{Is_Canonical_Combining_Class=+222}', "");
Expect(0, 12333, '\p{^Is_Canonical_Combining_Class=+222}', "");
Expect(0, 12333, '\P{Is_Canonical_Combining_Class=+222}', "");
Expect(1, 12333, '\P{^Is_Canonical_Combining_Class=+222}', "");
Expect(0, 12334, '\p{Is_Canonical_Combining_Class=+222}', "");
Expect(1, 12334, '\p{^Is_Canonical_Combining_Class=+222}', "");
Expect(1, 12334, '\P{Is_Canonical_Combining_Class=+222}', "");
Expect(0, 12334, '\P{^Is_Canonical_Combining_Class=+222}', "");
Error('\p{Is_Ccc=:=__Below_RIGHT}');
Error('\P{Is_Ccc=:=__Below_RIGHT}');
Expect(1, 12333, '\p{Is_Ccc=belowright}', "");
Expect(0, 12333, '\p{^Is_Ccc=belowright}', "");
Expect(0, 12333, '\P{Is_Ccc=belowright}', "");
Expect(1, 12333, '\P{^Is_Ccc=belowright}', "");
Expect(0, 12334, '\p{Is_Ccc=belowright}', "");
Expect(1, 12334, '\p{^Is_Ccc=belowright}', "");
Expect(1, 12334, '\P{Is_Ccc=belowright}', "");
Expect(0, 12334, '\P{^Is_Ccc=belowright}', "");
Expect(1, 12333, '\p{Is_Ccc=__Below_right}', "");
Expect(0, 12333, '\p{^Is_Ccc=__Below_right}', "");
Expect(0, 12333, '\P{Is_Ccc=__Below_right}', "");
Expect(1, 12333, '\P{^Is_Ccc=__Below_right}', "");
Expect(0, 12334, '\p{Is_Ccc=__Below_right}', "");
Expect(1, 12334, '\p{^Is_Ccc=__Below_right}', "");
Expect(1, 12334, '\P{Is_Ccc=__Below_right}', "");
Expect(0, 12334, '\P{^Is_Ccc=__Below_right}', "");
Error('\p{Canonical_Combining_Class= :=ccc10}');
Error('\P{Canonical_Combining_Class= :=ccc10}');
Expect(1, 1456, '\p{Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\p{^Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\P{Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\P{^Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\p{Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\p{^Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\P{Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\P{^Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\p{Canonical_Combining_Class=-CCC10}', "");
Expect(0, 1456, '\p{^Canonical_Combining_Class=-CCC10}', "");
Expect(0, 1456, '\P{Canonical_Combining_Class=-CCC10}', "");
Expect(1, 1456, '\P{^Canonical_Combining_Class=-CCC10}', "");
Expect(0, 1457, '\p{Canonical_Combining_Class=-CCC10}', "");
Expect(1, 1457, '\p{^Canonical_Combining_Class=-CCC10}', "");
Expect(1, 1457, '\P{Canonical_Combining_Class=-CCC10}', "");
Expect(0, 1457, '\P{^Canonical_Combining_Class=-CCC10}', "");
Error('\p{Ccc= 	000000001_0:=}');
Error('\P{Ccc= 	000000001_0:=}');
Expect(1, 1456, '\p{Ccc=000001_0}', "");
Expect(0, 1456, '\p{^Ccc=000001_0}', "");
Expect(0, 1456, '\P{Ccc=000001_0}', "");
Expect(1, 1456, '\P{^Ccc=000001_0}', "");
Expect(0, 1457, '\p{Ccc=000001_0}', "");
Expect(1, 1457, '\p{^Ccc=000001_0}', "");
Expect(1, 1457, '\P{Ccc=000001_0}', "");
Expect(0, 1457, '\P{^Ccc=000001_0}', "");
Error('\p{Is_Canonical_Combining_Class= :=ccc10}');
Error('\P{Is_Canonical_Combining_Class= :=ccc10}');
Expect(1, 1456, '\p{Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\p{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1456, '\P{Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\P{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\p{Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\p{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1457, '\P{Is_Canonical_Combining_Class=ccc10}', "");
Expect(0, 1457, '\P{^Is_Canonical_Combining_Class=ccc10}', "");
Expect(1, 1456, '\p{Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(0, 1456, '\p{^Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(0, 1456, '\P{Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(1, 1456, '\P{^Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(0, 1457, '\p{Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(1, 1457, '\p{^Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(1, 1457, '\P{Is_Canonical_Combining_Class=	-ccc10}', "");
Expect(0, 1457, '\P{^Is_Canonical_Combining_Class=	-ccc10}', "");
Error('\p{Is_Ccc=:=1_0}');
Error('\P{Is_Ccc=:=1_0}');
Expect(1, 1456, '\p{Is_Ccc=0_0_0_10}', "");
Expect(0, 1456, '\p{^Is_Ccc=0_0_0_10}', "");
Expect(0, 1456, '\P{Is_Ccc=0_0_0_10}', "");
Expect(1, 1456, '\P{^Is_Ccc=0_0_0_10}', "");
Expect(0, 1457, '\p{Is_Ccc=0_0_0_10}', "");
Expect(1, 1457, '\p{^Is_Ccc=0_0_0_10}', "");
Expect(1, 1457, '\P{Is_Ccc=0_0_0_10}', "");
Expect(0, 1457, '\P{^Is_Ccc=0_0_0_10}', "");
Error('\p{Canonical_Combining_Class= /a/ccc103}');
Error('\P{Canonical_Combining_Class= /a/ccc103}');
Expect(1, 3641, '\p{Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\p{^Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\P{Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\P{^Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\p{Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\p{^Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\P{Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\P{^Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\p{Canonical_Combining_Class:	 	CCC103}', "");
Expect(0, 3641, '\p{^Canonical_Combining_Class:	 	CCC103}', "");
Expect(0, 3641, '\P{Canonical_Combining_Class:	 	CCC103}', "");
Expect(1, 3641, '\P{^Canonical_Combining_Class:	 	CCC103}', "");
Expect(0, 3642, '\p{Canonical_Combining_Class:	 	CCC103}', "");
Expect(1, 3642, '\p{^Canonical_Combining_Class:	 	CCC103}', "");
Expect(1, 3642, '\P{Canonical_Combining_Class:	 	CCC103}', "");
Expect(0, 3642, '\P{^Canonical_Combining_Class:	 	CCC103}', "");
Error('\p{Ccc=/a/	_+000000103}');
Error('\P{Ccc=/a/	_+000000103}');
Expect(1, 3641, '\p{Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(0, 3641, '\p{^Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(0, 3641, '\P{Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(1, 3641, '\P{^Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(0, 3642, '\p{Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(1, 3642, '\p{^Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(1, 3642, '\P{Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Expect(0, 3642, '\P{^Ccc=+0_0_0_0_0_0_0_0_0_103}', "");
Error('\p{Is_Canonical_Combining_Class=_ CCC103/a/}');
Error('\P{Is_Canonical_Combining_Class=_ CCC103/a/}');
Expect(1, 3641, '\p{Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\p{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3641, '\P{Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\P{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\p{Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\p{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3642, '\P{Is_Canonical_Combining_Class=ccc103}', "");
Expect(0, 3642, '\P{^Is_Canonical_Combining_Class=ccc103}', "");
Expect(1, 3641, '\p{Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(0, 3641, '\p{^Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(0, 3641, '\P{Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(1, 3641, '\P{^Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(0, 3642, '\p{Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(1, 3642, '\p{^Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(1, 3642, '\P{Is_Canonical_Combining_Class=	_CCC103}', "");
Expect(0, 3642, '\P{^Is_Canonical_Combining_Class=	_CCC103}', "");
Error('\p{Is_Ccc= 00000_00010_3/a/}');
Error('\P{Is_Ccc= 00000_00010_3/a/}');
Expect(1, 3641, '\p{Is_Ccc=0103}', "");
Expect(0, 3641, '\p{^Is_Ccc=0103}', "");
Expect(0, 3641, '\P{Is_Ccc=0103}', "");
Expect(1, 3641, '\P{^Is_Ccc=0103}', "");
Expect(0, 3642, '\p{Is_Ccc=0103}', "");
Expect(1, 3642, '\p{^Is_Ccc=0103}', "");
Expect(1, 3642, '\P{Is_Ccc=0103}', "");
Expect(0, 3642, '\P{^Is_Ccc=0103}', "");
Error('\p{Canonical_Combining_Class=		CCC107:=}');
Error('\P{Canonical_Combining_Class=		CCC107:=}');
Expect(1, 3659, '\p{Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\p{^Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\P{Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\P{^Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\p{Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\p{^Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\P{Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\P{^Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\p{Canonical_Combining_Class=-ccc107}', "");
Expect(0, 3659, '\p{^Canonical_Combining_Class=-ccc107}', "");
Expect(0, 3659, '\P{Canonical_Combining_Class=-ccc107}', "");
Expect(1, 3659, '\P{^Canonical_Combining_Class=-ccc107}', "");
Expect(0, 3660, '\p{Canonical_Combining_Class=-ccc107}', "");
Expect(1, 3660, '\p{^Canonical_Combining_Class=-ccc107}', "");
Expect(1, 3660, '\P{Canonical_Combining_Class=-ccc107}', "");
Expect(0, 3660, '\P{^Canonical_Combining_Class=-ccc107}', "");
Error('\p{Ccc:_:=107}');
Error('\P{Ccc:_:=107}');
Expect(1, 3659, '\p{Ccc=0_0_0_0_0_0_107}', "");
Expect(0, 3659, '\p{^Ccc=0_0_0_0_0_0_107}', "");
Expect(0, 3659, '\P{Ccc=0_0_0_0_0_0_107}', "");
Expect(1, 3659, '\P{^Ccc=0_0_0_0_0_0_107}', "");
Expect(0, 3660, '\p{Ccc=0_0_0_0_0_0_107}', "");
Expect(1, 3660, '\p{^Ccc=0_0_0_0_0_0_107}', "");
Expect(1, 3660, '\P{Ccc=0_0_0_0_0_0_107}', "");
Expect(0, 3660, '\P{^Ccc=0_0_0_0_0_0_107}', "");
Error('\p{Is_Canonical_Combining_Class=/a/  CCC107}');
Error('\P{Is_Canonical_Combining_Class=/a/  CCC107}');
Expect(1, 3659, '\p{Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\p{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3659, '\P{Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\P{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\p{Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\p{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3660, '\P{Is_Canonical_Combining_Class=ccc107}', "");
Expect(0, 3660, '\P{^Is_Canonical_Combining_Class=ccc107}', "");
Expect(1, 3659, '\p{Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(0, 3659, '\p{^Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(0, 3659, '\P{Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(1, 3659, '\P{^Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(0, 3660, '\p{Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(1, 3660, '\p{^Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(1, 3660, '\P{Is_Canonical_Combining_Class:   	CCC107}', "");
Expect(0, 3660, '\P{^Is_Canonical_Combining_Class:   	CCC107}', "");
Error('\p{Is_Ccc=-00000107:=}');
Error('\P{Is_Ccc=-00000107:=}');
Expect(1, 3659, '\p{Is_Ccc=107}', "");
Expect(0, 3659, '\p{^Is_Ccc=107}', "");
Expect(0, 3659, '\P{Is_Ccc=107}', "");
Expect(1, 3659, '\P{^Is_Ccc=107}', "");
Expect(0, 3660, '\p{Is_Ccc=107}', "");
Expect(1, 3660, '\p{^Is_Ccc=107}', "");
Expect(1, 3660, '\P{Is_Ccc=107}', "");
Expect(0, 3660, '\P{^Is_Ccc=107}', "");
Error('\p{Canonical_Combining_Class=	:=ccc11}');
Error('\P{Canonical_Combining_Class=	:=ccc11}');
Expect(1, 1457, '\p{Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\p{^Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\P{Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\P{^Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\p{Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\p{^Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\P{Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\P{^Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\p{Canonical_Combining_Class=_	CCC11}', "");
Expect(0, 1457, '\p{^Canonical_Combining_Class=_	CCC11}', "");
Expect(0, 1457, '\P{Canonical_Combining_Class=_	CCC11}', "");
Expect(1, 1457, '\P{^Canonical_Combining_Class=_	CCC11}', "");
Expect(0, 1458, '\p{Canonical_Combining_Class=_	CCC11}', "");
Expect(1, 1458, '\p{^Canonical_Combining_Class=_	CCC11}', "");
Expect(1, 1458, '\P{Canonical_Combining_Class=_	CCC11}', "");
Expect(0, 1458, '\P{^Canonical_Combining_Class=_	CCC11}', "");
Error('\p{Ccc=  0_0_0_0_011:=}');
Error('\P{Ccc=  0_0_0_0_011:=}');
Expect(1, 1457, '\p{Ccc=0000000011}', "");
Expect(0, 1457, '\p{^Ccc=0000000011}', "");
Expect(0, 1457, '\P{Ccc=0000000011}', "");
Expect(1, 1457, '\P{^Ccc=0000000011}', "");
Expect(0, 1458, '\p{Ccc=0000000011}', "");
Expect(1, 1458, '\p{^Ccc=0000000011}', "");
Expect(1, 1458, '\P{Ccc=0000000011}', "");
Expect(0, 1458, '\P{^Ccc=0000000011}', "");
Error('\p{Is_Canonical_Combining_Class=__CCC11/a/}');
Error('\P{Is_Canonical_Combining_Class=__CCC11/a/}');
Expect(1, 1457, '\p{Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\p{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1457, '\P{Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\P{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\p{Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\p{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1458, '\P{Is_Canonical_Combining_Class=ccc11}', "");
Expect(0, 1458, '\P{^Is_Canonical_Combining_Class=ccc11}', "");
Expect(1, 1457, '\p{Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(0, 1457, '\p{^Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(0, 1457, '\P{Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(1, 1457, '\P{^Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(0, 1458, '\p{Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(1, 1458, '\p{^Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(1, 1458, '\P{Is_Canonical_Combining_Class:   		CCC11}', "");
Expect(0, 1458, '\P{^Is_Canonical_Combining_Class:   		CCC11}', "");
Error('\p{Is_Ccc=:=--00_00_11}');
Error('\P{Is_Ccc=:=--00_00_11}');
Expect(1, 1457, '\p{Is_Ccc:00_01_1}', "");
Expect(0, 1457, '\p{^Is_Ccc:00_01_1}', "");
Expect(0, 1457, '\P{Is_Ccc:00_01_1}', "");
Expect(1, 1457, '\P{^Is_Ccc:00_01_1}', "");
Expect(0, 1458, '\p{Is_Ccc:00_01_1}', "");
Expect(1, 1458, '\p{^Is_Ccc:00_01_1}', "");
Expect(1, 1458, '\P{Is_Ccc:00_01_1}', "");
Expect(0, 1458, '\P{^Is_Ccc:00_01_1}', "");
Error('\p{Canonical_Combining_Class=:=	CCC118}');
Error('\P{Canonical_Combining_Class=:=	CCC118}');
Expect(1, 3769, '\p{Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\p{^Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\P{Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\P{^Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\p{Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\p{^Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\P{Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\P{^Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\p{Canonical_Combining_Class:__CCC118}', "");
Expect(0, 3769, '\p{^Canonical_Combining_Class:__CCC118}', "");
Expect(0, 3769, '\P{Canonical_Combining_Class:__CCC118}', "");
Expect(1, 3769, '\P{^Canonical_Combining_Class:__CCC118}', "");
Expect(0, 3770, '\p{Canonical_Combining_Class:__CCC118}', "");
Expect(1, 3770, '\p{^Canonical_Combining_Class:__CCC118}', "");
Expect(1, 3770, '\P{Canonical_Combining_Class:__CCC118}', "");
Expect(0, 3770, '\P{^Canonical_Combining_Class:__CCC118}', "");
Error('\p{Ccc=	0000118/a/}');
Error('\P{Ccc=	0000118/a/}');
Expect(1, 3769, '\p{Ccc=0_0_0_0_0_0118}', "");
Expect(0, 3769, '\p{^Ccc=0_0_0_0_0_0118}', "");
Expect(0, 3769, '\P{Ccc=0_0_0_0_0_0118}', "");
Expect(1, 3769, '\P{^Ccc=0_0_0_0_0_0118}', "");
Expect(0, 3770, '\p{Ccc=0_0_0_0_0_0118}', "");
Expect(1, 3770, '\p{^Ccc=0_0_0_0_0_0118}', "");
Expect(1, 3770, '\P{Ccc=0_0_0_0_0_0118}', "");
Expect(0, 3770, '\P{^Ccc=0_0_0_0_0_0118}', "");
Error('\p{Is_Canonical_Combining_Class=-/a/CCC118}');
Error('\P{Is_Canonical_Combining_Class=-/a/CCC118}');
Expect(1, 3769, '\p{Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\p{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3769, '\P{Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\P{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\p{Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\p{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3770, '\P{Is_Canonical_Combining_Class=ccc118}', "");
Expect(0, 3770, '\P{^Is_Canonical_Combining_Class=ccc118}', "");
Expect(1, 3769, '\p{Is_Canonical_Combining_Class=- CCC118}', "");
Expect(0, 3769, '\p{^Is_Canonical_Combining_Class=- CCC118}', "");
Expect(0, 3769, '\P{Is_Canonical_Combining_Class=- CCC118}', "");
Expect(1, 3769, '\P{^Is_Canonical_Combining_Class=- CCC118}', "");
Expect(0, 3770, '\p{Is_Canonical_Combining_Class=- CCC118}', "");
Expect(1, 3770, '\p{^Is_Canonical_Combining_Class=- CCC118}', "");
Expect(1, 3770, '\P{Is_Canonical_Combining_Class=- CCC118}', "");
Expect(0, 3770, '\P{^Is_Canonical_Combining_Class=- CCC118}', "");
Error('\p{Is_Ccc=:=		+0_0_0_0_0_0_0_0_0118}');
Error('\P{Is_Ccc=:=		+0_0_0_0_0_0_0_0_0118}');
Expect(1, 3769, '\p{Is_Ccc=+11_8}', "");
Expect(0, 3769, '\p{^Is_Ccc=+11_8}', "");
Expect(0, 3769, '\P{Is_Ccc=+11_8}', "");
Expect(1, 3769, '\P{^Is_Ccc=+11_8}', "");
Expect(0, 3770, '\p{Is_Ccc=+11_8}', "");
Expect(1, 3770, '\p{^Is_Ccc=+11_8}', "");
Expect(1, 3770, '\P{Is_Ccc=+11_8}', "");
Expect(0, 3770, '\P{^Is_Ccc=+11_8}', "");
Error('\p{Canonical_Combining_Class=/a/_ CCC12}');
Error('\P{Canonical_Combining_Class=/a/_ CCC12}');
Expect(1, 1458, '\p{Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\p{^Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\P{Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\P{^Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\p{Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\p{^Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\P{Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\P{^Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\p{Canonical_Combining_Class=	CCC12}', "");
Expect(0, 1458, '\p{^Canonical_Combining_Class=	CCC12}', "");
Expect(0, 1458, '\P{Canonical_Combining_Class=	CCC12}', "");
Expect(1, 1458, '\P{^Canonical_Combining_Class=	CCC12}', "");
Expect(0, 1459, '\p{Canonical_Combining_Class=	CCC12}', "");
Expect(1, 1459, '\p{^Canonical_Combining_Class=	CCC12}', "");
Expect(1, 1459, '\P{Canonical_Combining_Class=	CCC12}', "");
Expect(0, 1459, '\P{^Canonical_Combining_Class=	CCC12}', "");
Error('\p{Ccc=/a/	 1_2}');
Error('\P{Ccc=/a/	 1_2}');
Expect(1, 1458, '\p{Ccc=+0_0_0_12}', "");
Expect(0, 1458, '\p{^Ccc=+0_0_0_12}', "");
Expect(0, 1458, '\P{Ccc=+0_0_0_12}', "");
Expect(1, 1458, '\P{^Ccc=+0_0_0_12}', "");
Expect(0, 1459, '\p{Ccc=+0_0_0_12}', "");
Expect(1, 1459, '\p{^Ccc=+0_0_0_12}', "");
Expect(1, 1459, '\P{Ccc=+0_0_0_12}', "");
Expect(0, 1459, '\P{^Ccc=+0_0_0_12}', "");
Error('\p{Is_Canonical_Combining_Class=/a/_CCC12}');
Error('\P{Is_Canonical_Combining_Class=/a/_CCC12}');
Expect(1, 1458, '\p{Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\p{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1458, '\P{Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\P{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\p{Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\p{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1459, '\P{Is_Canonical_Combining_Class=ccc12}', "");
Expect(0, 1459, '\P{^Is_Canonical_Combining_Class=ccc12}', "");
Expect(1, 1458, '\p{Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(0, 1458, '\p{^Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(0, 1458, '\P{Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(1, 1458, '\P{^Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(0, 1459, '\p{Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(1, 1459, '\p{^Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(1, 1459, '\P{Is_Canonical_Combining_Class= 	CCC12}', "");
Expect(0, 1459, '\P{^Is_Canonical_Combining_Class= 	CCC12}', "");
Error('\p{Is_Ccc=/a/_ 0_0_0_0_0_0_0012}');
Error('\P{Is_Ccc=/a/_ 0_0_0_0_0_0_0012}');
Expect(1, 1458, '\p{Is_Ccc=0012}', "");
Expect(0, 1458, '\p{^Is_Ccc=0012}', "");
Expect(0, 1458, '\P{Is_Ccc=0012}', "");
Expect(1, 1458, '\P{^Is_Ccc=0012}', "");
Expect(0, 1459, '\p{Is_Ccc=0012}', "");
Expect(1, 1459, '\p{^Is_Ccc=0012}', "");
Expect(1, 1459, '\P{Is_Ccc=0012}', "");
Expect(0, 1459, '\P{^Is_Ccc=0012}', "");
Error('\p{Canonical_Combining_Class=:= CCC122}');
Error('\P{Canonical_Combining_Class=:= CCC122}');
Expect(1, 3787, '\p{Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\p{^Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\P{Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\P{^Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\p{Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\p{^Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\P{Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\P{^Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\p{Canonical_Combining_Class=- CCC122}', "");
Expect(0, 3787, '\p{^Canonical_Combining_Class=- CCC122}', "");
Expect(0, 3787, '\P{Canonical_Combining_Class=- CCC122}', "");
Expect(1, 3787, '\P{^Canonical_Combining_Class=- CCC122}', "");
Expect(0, 3788, '\p{Canonical_Combining_Class=- CCC122}', "");
Expect(1, 3788, '\p{^Canonical_Combining_Class=- CCC122}', "");
Expect(1, 3788, '\P{Canonical_Combining_Class=- CCC122}', "");
Expect(0, 3788, '\P{^Canonical_Combining_Class=- CCC122}', "");
Error('\p{Ccc=/a/_-0_0_0_0_0_0_0_122}');
Error('\P{Ccc=/a/_-0_0_0_0_0_0_0_122}');
Expect(1, 3787, '\p{Ccc=00122}', "");
Expect(0, 3787, '\p{^Ccc=00122}', "");
Expect(0, 3787, '\P{Ccc=00122}', "");
Expect(1, 3787, '\P{^Ccc=00122}', "");
Expect(0, 3788, '\p{Ccc=00122}', "");
Expect(1, 3788, '\p{^Ccc=00122}', "");
Expect(1, 3788, '\P{Ccc=00122}', "");
Expect(0, 3788, '\P{^Ccc=00122}', "");
Error('\p{Is_Canonical_Combining_Class=:=  CCC122}');
Error('\P{Is_Canonical_Combining_Class=:=  CCC122}');
Expect(1, 3787, '\p{Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\p{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3787, '\P{Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\P{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\p{Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\p{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3788, '\P{Is_Canonical_Combining_Class=ccc122}', "");
Expect(0, 3788, '\P{^Is_Canonical_Combining_Class=ccc122}', "");
Expect(1, 3787, '\p{Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(0, 3787, '\p{^Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(0, 3787, '\P{Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(1, 3787, '\P{^Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(0, 3788, '\p{Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(1, 3788, '\p{^Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(1, 3788, '\P{Is_Canonical_Combining_Class=	-CCC122}', "");
Expect(0, 3788, '\P{^Is_Canonical_Combining_Class=	-CCC122}', "");
Error('\p{Is_Ccc=_/a/0_0_0_0_0122}');
Error('\P{Is_Ccc=_/a/0_0_0_0_0122}');
Expect(1, 3787, '\p{Is_Ccc=+0_0_1_22}', "");
Expect(0, 3787, '\p{^Is_Ccc=+0_0_1_22}', "");
Expect(0, 3787, '\P{Is_Ccc=+0_0_1_22}', "");
Expect(1, 3787, '\P{^Is_Ccc=+0_0_1_22}', "");
Expect(0, 3788, '\p{Is_Ccc=+0_0_1_22}', "");
Expect(1, 3788, '\p{^Is_Ccc=+0_0_1_22}', "");
Expect(1, 3788, '\P{Is_Ccc=+0_0_1_22}', "");
Expect(0, 3788, '\P{^Is_Ccc=+0_0_1_22}', "");
Error('\p{Canonical_Combining_Class=	CCC129:=}');
Error('\P{Canonical_Combining_Class=	CCC129:=}');
Expect(1, 3953, '\p{Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\p{^Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\P{Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\P{^Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\p{Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\p{^Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\P{Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\P{^Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\p{Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3953, '\p{^Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3953, '\P{Canonical_Combining_Class=--CCC129}', "");
Expect(1, 3953, '\P{^Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3954, '\p{Canonical_Combining_Class=--CCC129}', "");
Expect(1, 3954, '\p{^Canonical_Combining_Class=--CCC129}', "");
Expect(1, 3954, '\P{Canonical_Combining_Class=--CCC129}', "");
Expect(0, 3954, '\P{^Canonical_Combining_Class=--CCC129}', "");
Error('\p{Ccc=:=	_000000129}');
Error('\P{Ccc=:=	_000000129}');
Expect(1, 3953, '\p{Ccc:0_0_0_129}', "");
Expect(0, 3953, '\p{^Ccc:0_0_0_129}', "");
Expect(0, 3953, '\P{Ccc:0_0_0_129}', "");
Expect(1, 3953, '\P{^Ccc:0_0_0_129}', "");
Expect(0, 3954, '\p{Ccc:0_0_0_129}', "");
Expect(1, 3954, '\p{^Ccc:0_0_0_129}', "");
Expect(1, 3954, '\P{Ccc:0_0_0_129}', "");
Expect(0, 3954, '\P{^Ccc:0_0_0_129}', "");
Error('\p{Is_Canonical_Combining_Class=_ CCC129/a/}');
Error('\P{Is_Canonical_Combining_Class=_ CCC129/a/}');
Expect(1, 3953, '\p{Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\p{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3953, '\P{Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\P{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\p{Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\p{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3954, '\P{Is_Canonical_Combining_Class=ccc129}', "");
Expect(0, 3954, '\P{^Is_Canonical_Combining_Class=ccc129}', "");
Expect(1, 3953, '\p{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3953, '\p{^Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3953, '\P{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(1, 3953, '\P{^Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3954, '\p{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(1, 3954, '\p{^Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(1, 3954, '\P{Is_Canonical_Combining_Class=-	CCC129}', "");
Expect(0, 3954, '\P{^Is_Canonical_Combining_Class=-	CCC129}', "");
Error('\p{Is_Ccc=:=-+00000000129}');
Error('\P{Is_Ccc=:=-+00000000129}');
Expect(1, 3953, '\p{Is_Ccc=00_00_00_00_129}', "");
Expect(0, 3953, '\p{^Is_Ccc=00_00_00_00_129}', "");
Expect(0, 3953, '\P{Is_Ccc=00_00_00_00_129}', "");
Expect(1, 3953, '\P{^Is_Ccc=00_00_00_00_129}', "");
Expect(0, 3954, '\p{Is_Ccc=00_00_00_00_129}', "");
Expect(1, 3954, '\p{^Is_Ccc=00_00_00_00_129}', "");
Expect(1, 3954, '\P{Is_Ccc=00_00_00_00_129}', "");
Expect(0, 3954, '\P{^Is_Ccc=00_00_00_00_129}', "");
Error('\p{Canonical_Combining_Class=/a/_CCC13}');
Error('\P{Canonical_Combining_Class=/a/_CCC13}');
Expect(1, 1459, '\p{Canonical_Combining_Class=ccc13}', "");
Expect(0, 1459, '\p{^Canonical_Combining_Class=ccc13}', "");
Expect(0, 1459, '\P{Canonical_Combining_Class=ccc13}', "");
Expect(1, 1459, '\P{^Canonical_Combining_Class=ccc13}', "");
Expect(0, 1460, '\p{Canonical_Combining_Class=ccc13}', "");
Expect(1, 1460, '\p{^Canonical_Combining_Class=ccc13}', "");
Expect(1, 1460, '\P{Canonical_Combining_Class=ccc13}', "");
Expect(0, 1460, '\P{^Canonical_Combining_Class=ccc13}', "");
Expect(1, 1459, '\p{Canonical_Combining_Class=__ccc13}', "");
Expect(0, 1459, '\p{^Canonical_Combining_Class=__ccc13}', "");
Expect(0, 1459, '\P{Canonical_Combining_Class=__ccc13}', "");
Expect(1, 1459, '\P{^Canonical_Combining_Class=__ccc13}', "");
Expect(0, 1460, '\p{Canonical_Combining_Class=__ccc13}', "");
Expect(1, 1460, '\p{^Canonical_Combining_Class=__ccc13}', "");
Expect(1, 1460, '\P{Canonical_Combining_Class=__ccc13}', "");
Expect(0, 1460, '\P{^Canonical_Combining_Class=__ccc13}', "");
Error('\p{Ccc=_ +0001_3:=}');
Error('\P{Ccc=_ +0001_3:=}');
Expect(1, 1459, '\p{Ccc=0013}', "");
Expect(0, 1459, '\p{^Ccc=0013}', "");
Expect(0, 1459, '\P{Ccc=0013}', "");
Expect(1, 1459, '\P{^Ccc=0013}', "");
Expect(0, 1460, '\p{Ccc=0013}', "");
Expect(1, 1460, '\p{^Ccc=0013}', "");
Expect(1, 1460, '\P{Ccc=0013}', "");
Expect(0, 1460, '\P{^Ccc=0013}', "");
Error('\p{Is_Canonical_Combining_Class=--CCC13:=}');
Error('\P{Is_Canonical_Combining_Class=--CCC13:=}');
Expect(1, 1459, '\p{Is_Canonical_Combining_Class:	ccc13}', "");
Expect(0, 1459, '\p{^Is_Canonical_Combining_Class:	ccc13}', "");
Expect(0, 1459, '\P{Is_Canonical_Combining_Class:	ccc13}', "");
Expect(1, 1459, '\P{^Is_Canonical_Combining_Class:	ccc13}', "");
Expect(0, 1460, '\p{Is_Canonical_Combining_Class:	ccc13}', "");
Expect(1, 1460, '\p{^Is_Canonical_Combining_Class:	ccc13}', "");
Expect(1, 1460, '\P{Is_Canonical_Combining_Class:	ccc13}', "");
Expect(0, 1460, '\P{^Is_Canonical_Combining_Class:	ccc13}', "");
Expect(1, 1459, '\p{Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(0, 1459, '\p{^Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(0, 1459, '\P{Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(1, 1459, '\P{^Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(0, 1460, '\p{Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(1, 1460, '\p{^Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(1, 1460, '\P{Is_Canonical_Combining_Class:   _-ccc13}', "");
Expect(0, 1460, '\P{^Is_Canonical_Combining_Class:   _-ccc13}', "");
Error('\p{Is_Ccc=:=000013}');
Error('\P{Is_Ccc=:=000013}');
Expect(1, 1459, '\p{Is_Ccc=0001_3}', "");
Expect(0, 1459, '\p{^Is_Ccc=0001_3}', "");
Expect(0, 1459, '\P{Is_Ccc=0001_3}', "");
Expect(1, 1459, '\P{^Is_Ccc=0001_3}', "");
Expect(0, 1460, '\p{Is_Ccc=0001_3}', "");
Expect(1, 1460, '\p{^Is_Ccc=0001_3}', "");
Expect(1, 1460, '\P{Is_Ccc=0001_3}', "");
Expect(0, 1460, '\P{^Is_Ccc=0001_3}', "");
Error('\p{Canonical_Combining_Class=  CCC130:=}');
Error('\P{Canonical_Combining_Class=  CCC130:=}');
Expect(1, 3968, '\p{Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\p{^Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\P{Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\P{^Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\p{Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\p{^Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\P{Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\P{^Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\p{Canonical_Combining_Class=- ccc130}', "");
Expect(0, 3968, '\p{^Canonical_Combining_Class=- ccc130}', "");
Expect(0, 3968, '\P{Canonical_Combining_Class=- ccc130}', "");
Expect(1, 3968, '\P{^Canonical_Combining_Class=- ccc130}', "");
Expect(0, 3969, '\p{Canonical_Combining_Class=- ccc130}', "");
Expect(1, 3969, '\p{^Canonical_Combining_Class=- ccc130}', "");
Expect(1, 3969, '\P{Canonical_Combining_Class=- ccc130}', "");
Expect(0, 3969, '\P{^Canonical_Combining_Class=- ccc130}', "");
Error('\p{Ccc=	00_00_00_00_01_30/a/}');
Error('\P{Ccc=	00_00_00_00_01_30/a/}');
Expect(1, 3968, '\p{Ccc=+00130}', "");
Expect(0, 3968, '\p{^Ccc=+00130}', "");
Expect(0, 3968, '\P{Ccc=+00130}', "");
Expect(1, 3968, '\P{^Ccc=+00130}', "");
Expect(0, 3969, '\p{Ccc=+00130}', "");
Expect(1, 3969, '\p{^Ccc=+00130}', "");
Expect(1, 3969, '\P{Ccc=+00130}', "");
Expect(0, 3969, '\P{^Ccc=+00130}', "");
Error('\p{Is_Canonical_Combining_Class=-/a/CCC130}');
Error('\P{Is_Canonical_Combining_Class=-/a/CCC130}');
Expect(1, 3968, '\p{Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\p{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3968, '\P{Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\P{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\p{Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\p{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3969, '\P{Is_Canonical_Combining_Class=ccc130}', "");
Expect(0, 3969, '\P{^Is_Canonical_Combining_Class=ccc130}', "");
Expect(1, 3968, '\p{Is_Canonical_Combining_Class:	ccc130}', "");
Expect(0, 3968, '\p{^Is_Canonical_Combining_Class:	ccc130}', "");
Expect(0, 3968, '\P{Is_Canonical_Combining_Class:	ccc130}', "");
Expect(1, 3968, '\P{^Is_Canonical_Combining_Class:	ccc130}', "");
Expect(0, 3969, '\p{Is_Canonical_Combining_Class:	ccc130}', "");
Expect(1, 3969, '\p{^Is_Canonical_Combining_Class:	ccc130}', "");
Expect(1, 3969, '\P{Is_Canonical_Combining_Class:	ccc130}', "");
Expect(0, 3969, '\P{^Is_Canonical_Combining_Class:	ccc130}', "");
Error('\p{Is_Ccc=-/a/00_01_30}');
Error('\P{Is_Ccc=-/a/00_01_30}');
Expect(1, 3968, '\p{Is_Ccc: 0130}', "");
Expect(0, 3968, '\p{^Is_Ccc: 0130}', "");
Expect(0, 3968, '\P{Is_Ccc: 0130}', "");
Expect(1, 3968, '\P{^Is_Ccc: 0130}', "");
Expect(0, 3969, '\p{Is_Ccc: 0130}', "");
Expect(1, 3969, '\p{^Is_Ccc: 0130}', "");
Expect(1, 3969, '\P{Is_Ccc: 0130}', "");
Expect(0, 3969, '\P{^Is_Ccc: 0130}', "");
Error('\p{Canonical_Combining_Class= /a/CCC132}');
Error('\P{Canonical_Combining_Class= /a/CCC132}');
Expect(1, 3956, '\p{Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\p{^Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\P{Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\P{^Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\p{Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\p{^Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\P{Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\P{^Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\p{Canonical_Combining_Class= ccc132}', "");
Expect(0, 3956, '\p{^Canonical_Combining_Class= ccc132}', "");
Expect(0, 3956, '\P{Canonical_Combining_Class= ccc132}', "");
Expect(1, 3956, '\P{^Canonical_Combining_Class= ccc132}', "");
Expect(0, 3957, '\p{Canonical_Combining_Class= ccc132}', "");
Expect(1, 3957, '\p{^Canonical_Combining_Class= ccc132}', "");
Expect(1, 3957, '\P{Canonical_Combining_Class= ccc132}', "");
Expect(0, 3957, '\P{^Canonical_Combining_Class= ccc132}', "");
Error('\p{Ccc= 000132/a/}');
Error('\P{Ccc= 000132/a/}');
Expect(1, 3956, '\p{Ccc=+00000000132}', "");
Expect(0, 3956, '\p{^Ccc=+00000000132}', "");
Expect(0, 3956, '\P{Ccc=+00000000132}', "");
Expect(1, 3956, '\P{^Ccc=+00000000132}', "");
Expect(0, 3957, '\p{Ccc=+00000000132}', "");
Expect(1, 3957, '\p{^Ccc=+00000000132}', "");
Expect(1, 3957, '\P{Ccc=+00000000132}', "");
Expect(0, 3957, '\P{^Ccc=+00000000132}', "");
Error('\p{Is_Canonical_Combining_Class= _ccc132/a/}');
Error('\P{Is_Canonical_Combining_Class= _ccc132/a/}');
Expect(1, 3956, '\p{Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\p{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3956, '\P{Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\P{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\p{Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\p{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3957, '\P{Is_Canonical_Combining_Class=ccc132}', "");
Expect(0, 3957, '\P{^Is_Canonical_Combining_Class=ccc132}', "");
Expect(1, 3956, '\p{Is_Canonical_Combining_Class=	CCC132}', "");
Expect(0, 3956, '\p{^Is_Canonical_Combining_Class=	CCC132}', "");
Expect(0, 3956, '\P{Is_Canonical_Combining_Class=	CCC132}', "");
Expect(1, 3956, '\P{^Is_Canonical_Combining_Class=	CCC132}', "");
Expect(0, 3957, '\p{Is_Canonical_Combining_Class=	CCC132}', "");
Expect(1, 3957, '\p{^Is_Canonical_Combining_Class=	CCC132}', "");
Expect(1, 3957, '\P{Is_Canonical_Combining_Class=	CCC132}', "");
Expect(0, 3957, '\P{^Is_Canonical_Combining_Class=	CCC132}', "");
Error('\p{Is_Ccc=_/a/13_2}');
Error('\P{Is_Ccc=_/a/13_2}');
Expect(1, 3956, '\p{Is_Ccc=0000132}', "");
Expect(0, 3956, '\p{^Is_Ccc=0000132}', "");
Expect(0, 3956, '\P{Is_Ccc=0000132}', "");
Expect(1, 3956, '\P{^Is_Ccc=0000132}', "");
Expect(0, 3957, '\p{Is_Ccc=0000132}', "");
Expect(1, 3957, '\p{^Is_Ccc=0000132}', "");
Expect(1, 3957, '\P{Is_Ccc=0000132}', "");
Expect(0, 3957, '\P{^Is_Ccc=0000132}', "");
Error('\p{Canonical_Combining_Class= CCC133/a/}');
Error('\P{Canonical_Combining_Class= CCC133/a/}');
Expect(0, 1, '\p{Canonical_Combining_Class=ccc133}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class=ccc133}', "");
Expect(1, 1, '\P{Canonical_Combining_Class=ccc133}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class=ccc133}', "");
Expect(0, 1, '\p{Canonical_Combining_Class=	-ccc133}', "");
Expect(1, 1, '\p{^Canonical_Combining_Class=	-ccc133}', "");
Expect(1, 1, '\P{Canonical_Combining_Class=	-ccc133}', "");
Expect(0, 1, '\P{^Canonical_Combining_Class=	-ccc133}', "");
Error('\p{Ccc= 	000000133:=}');
Error('\P{Ccc= 	000000133:=}');
Expect(0, 1, '\p{Ccc=00000_00001_33}', "");
Expect(1, 1, '\p{^Ccc=00000_00001_33}', "");
Expect(1, 1, '\P{Ccc=00000_00001_33}', "");
Expect(0, 1, '\P{^Ccc=00000_00001_33}', "");
Error('\p{Is_Canonical_Combining_Class=CCC133/a/}');
Error('\P{Is_Canonical_Combining_Class=CCC133/a/}');
Expect(0, 1, '\p{Is_Canonical_Combining_Class=ccc133}', "");
Expect(1, 1, '\p{^Is_Canonical_Combining_Class=ccc133}', "");
Expect(1, 1, '\P{Is_Canonical_Combining_Class=ccc133}', "");
Expect(0, 1, '\P{^Is_Canonical_Combining_Class=ccc133}', "");
Expect(0, 1, '\p{Is_Canonical_Combining_Class= CCC133}', "");
Expect(1, 1, '\p{^Is_Canonical_Combining_Class= CCC133}', "");
Expect(1, 1, '\P{Is_Canonical_Combining_Class= CCC133}', "");
Expect(0, 1, '\P{^Is_Canonical_Combining_Class= CCC133}', "");
Error('\p{Is_Ccc=	00000133:=}');
Error('\P{Is_Ccc=	00000133:=}');
Expect(0, 1, '\p{Is_Ccc=+0000000013_3}', "");
Expect(1, 1, '\p{^Is_Ccc=+0000000013_3}', "");
Expect(1, 1, '\P{Is_Ccc=+0000000013_3}', "");
Expect(0, 1, '\P{^Is_Ccc=+0000000013_3}', "");
Error('\p{Canonical_Combining_Class=:=	-CCC14}');
Error('\P{Canonical_Combining_Class=:=	-CCC14}');
Expect(1, 1460, '\p{Canonical_Combining_Class:   ccc14}', "");
Expect(0, 1460, '\p{^Canonical_Combining_Class:   ccc14}', "");
Expect(0, 1460, '\P{Canonical_Combining_Class:   ccc14}', "");
Expect(1, 1460, '\P{^Canonical_Combining_Class:   ccc14}', "");
Expect(0, 1461, '\p{Canonical_Combining_Class:   ccc14}', "");
Expect(1, 1461, '\p{^Canonical_Combining_Class:   ccc14}', "");
Expect(1, 1461, '\P{Canonical_Combining_Class:   ccc14}', "");
Expect(0, 1461, '\P{^Canonical_Combining_Class:   ccc14}', "");
Expect(1, 1460, '\p{Canonical_Combining_Class=	 CCC14}', "");
Expect(0, 1460, '\p{^Canonical_Combining_Class=	 CCC14}', "");
Expect(0, 1460, '\P{Canonical_Combining_Class=	 CCC14}', "");
Expect(1, 1460, '\P{^Canonical_Combining_Class=	 CCC14}', "");
Expect(0, 1461, '\p{Canonical_Combining_Class=	 CCC14}', "");
Expect(1, 1461, '\p{^Canonical_Combining_Class=	 CCC14}', "");
Expect(1, 1461, '\P{Canonical_Combining_Class=	 CCC14}', "");
Expect(0, 1461, '\P{^Canonical_Combining_Class=	 CCC14}', "");
Error('\p{Ccc=	/a/+00000000014}');
Error('\P{Ccc=	/a/+00000000014}');
Expect(1, 1460, '\p{Ccc:	001_4}', "");
Expect(0, 1460, '\p{^Ccc:	001_4}', "");
Expect(0, 1460, '\P{Ccc:	001_4}', "");
Expect(1, 1460, '\P{^Ccc:	001_4}', "");
Expect(0, 1461, '\p{Ccc:	001_4}', "");
Expect(1, 1461, '\p{^Ccc:	001_4}', "");
Expect(1, 1461, '\P{Ccc:	001_4}', "");
Expect(0, 1461, '\P{^Ccc:	001_4}', "");
Error('\p{Is_Canonical_Combining_Class=	:=ccc14}');
Error('\P{Is_Canonical_Combining_Class=	:=ccc14}');
Expect(1, 1460, '\p{Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1460, '\p{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1460, '\P{Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1460, '\P{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1461, '\p{Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1461, '\p{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1461, '\P{Is_Canonical_Combining_Class=ccc14}', "");
Expect(0, 1461, '\P{^Is_Canonical_Combining_Class=ccc14}', "");
Expect(1, 1460, '\p{Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(0, 1460, '\p{^Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(0, 1460, '\P{Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(1, 1460, '\P{^Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(0, 1461, '\p{Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(1, 1461, '\p{^Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(1, 1461, '\P{Is_Canonical_Combining_Class=-	ccc14}', "");
Expect(0, 1461, '\P{^Is_Canonical_Combining_Class=-	ccc14}', "");
Error('\p{Is_Ccc=_:=14}');
Error('\P{Is_Ccc=_:=14}');
Expect(1, 1460, '\p{Is_Ccc=+0000001_4}', "");
Expect(0, 1460, '\p{^Is_Ccc=+0000001_4}', "");
Expect(0, 1460, '\P{Is_Ccc=+0000001_4}', "");
Expect(1, 1460, '\P{^Is_Ccc=+0000001_4}', "");
Expect(0, 1461, '\p{Is_Ccc=+0000001_4}', "");
Expect(1, 1461, '\p{^Is_Ccc=+0000001_4}', "");
Expect(1, 1461, '\P{Is_Ccc=+0000001_4}', "");
Expect(0, 1461, '\P{^Is_Ccc=+0000001_4}', "");
Error('\p{Canonical_Combining_Class=/a/CCC15}');
Error('\P{Canonical_Combining_Class=/a/CCC15}');
Expect(1, 1461, '\p{Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\p{^Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\P{Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\P{^Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\p{Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\p{^Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\P{Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\P{^Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\p{Canonical_Combining_Class= CCC15}', "");
Expect(0, 1461, '\p{^Canonical_Combining_Class= CCC15}', "");
Expect(0, 1461, '\P{Canonical_Combining_Class= CCC15}', "");
Expect(1, 1461, '\P{^Canonical_Combining_Class= CCC15}', "");
Expect(0, 1462, '\p{Canonical_Combining_Class= CCC15}', "");
Expect(1, 1462, '\p{^Canonical_Combining_Class= CCC15}', "");
Expect(1, 1462, '\P{Canonical_Combining_Class= CCC15}', "");
Expect(0, 1462, '\P{^Canonical_Combining_Class= CCC15}', "");
Error('\p{Ccc=/a/-000000015}');
Error('\P{Ccc=/a/-000000015}');
Expect(1, 1461, '\p{Ccc=+15}', "");
Expect(0, 1461, '\p{^Ccc=+15}', "");
Expect(0, 1461, '\P{Ccc=+15}', "");
Expect(1, 1461, '\P{^Ccc=+15}', "");
Expect(0, 1462, '\p{Ccc=+15}', "");
Expect(1, 1462, '\p{^Ccc=+15}', "");
Expect(1, 1462, '\P{Ccc=+15}', "");
Expect(0, 1462, '\P{^Ccc=+15}', "");
Error('\p{Is_Canonical_Combining_Class= _ccc15:=}');
Error('\P{Is_Canonical_Combining_Class= _ccc15:=}');
Expect(1, 1461, '\p{Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\p{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1461, '\P{Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\P{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\p{Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\p{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1462, '\P{Is_Canonical_Combining_Class=ccc15}', "");
Expect(0, 1462, '\P{^Is_Canonical_Combining_Class=ccc15}', "");
Expect(1, 1461, '\p{Is_Canonical_Combining_Class=-ccc15}', "");
Expect(0, 1461, '\p{^Is_Canonical_Combining_Class=-ccc15}', "");
Expect(0, 1461, '\P{Is_Canonical_Combining_Class=-ccc15}', "");
Expect(1, 1461, '\P{^Is_Canonical_Combining_Class=-ccc15}', "");
Expect(0, 1462, '\p{Is_Canonical_Combining_Class=-ccc15}', "");
Expect(1, 1462, '\p{^Is_Canonical_Combining_Class=-ccc15}', "");
Expect(1, 1462, '\P{Is_Canonical_Combining_Class=-ccc15}', "");
Expect(0, 1462, '\P{^Is_Canonical_Combining_Class=-ccc15}', "");
Error('\p{Is_Ccc=__01_5:=}');
Error('\P{Is_Ccc=__01_5:=}');
Expect(1, 1461, '\p{Is_Ccc=0015}', "");
Expect(0, 1461, '\p{^Is_Ccc=0015}', "");
Expect(0, 1461, '\P{Is_Ccc=0015}', "");
Expect(1, 1461, '\P{^Is_Ccc=0015}', "");
Expect(0, 1462, '\p{Is_Ccc=0015}', "");
Expect(1, 1462, '\p{^Is_Ccc=0015}', "");
Expect(1, 1462, '\P{Is_Ccc=0015}', "");
Expect(0, 1462, '\P{^Is_Ccc=0015}', "");
Error('\p{Canonical_Combining_Class= :=CCC16}');
Error('\P{Canonical_Combining_Class= :=CCC16}');
Expect(1, 1462, '\p{Canonical_Combining_Class=ccc16}', "");
Expect(0, 1462, '\p{^Canonical_Combining_Class=ccc16}', "");
Expect(0, 1462, '\P{Canonical_Combining_Class=ccc16}', "");
Expect(1, 1462, '\P{^Canonical_Combining_Class=ccc16}', "");
Expect(0, 1463, '\p{Canonical_Combining_Class=ccc16}', "");
Expect(1, 1463, '\p{^Canonical_Combining_Class=ccc16}', "");
Expect(1, 1463, '\P{Canonical_Combining_Class=ccc16}', "");
Expect(0, 1463, '\P{^Canonical_Combining_Class=ccc16}', "");
Expect(1, 1462, '\p{Canonical_Combining_Class=-_CCC16}', "");
Expect(0, 1462, '\p{^Canonical_Combining_Class=-_CCC16}', "");
Expect(0, 1462, '\P{Canonical_Combining_Class=-_CCC16}', "");
Expect(1, 1462, '\P{^Canonical_Combining_Class=-_CCC16}', "");
Expect(0, 1463, '\p{Canonical_Combining_Class=-_CCC16}', "");
Expect(1, 1463, '\p{^Canonical_Combining_Class=-_CCC16}', "");
Expect(1, 1463, '\P{Canonical_Combining_Class=-_CCC16}', "");
Expect(0, 1463, '\P{^Canonical_Combining_Class=-_CCC16}', "");
Error('\p{Ccc=/a/000016}');
Error('\P{Ccc=/a/000016}');
Expect(1, 1462, '\p{Ccc:+16}', "");
Expect(0, 1462, '\p{^Ccc:+16}', "");
Expect(0, 1462, '\P{Ccc:+16}', "");
Expect(1, 1462, '\P{^Ccc:+16}', "");
Expect(0, 1463, '\p{Ccc:+16}', "");
Expect(1, 1463, '\p{^Ccc:+16}', "");
Expect(1, 1463, '\P{Ccc:+16}', "");
Expect(0, 1463, '\P{^Ccc:+16}', "");
Error('\p{Is_Canonical_Combining_Class=:=-	CCC16}');
Error('\P{Is_Canonical_Combining_Class=:=-	CCC16}');
Expect(1, 1462, '\p{Is_Canonical_Combining_Class: ccc16}', "");
Expect(0, 1462, '\p{^Is_Canonical_Combining_Class: ccc16}', "");
Expect(0, 1462, '\P{Is_Canonical_Combining_Class: ccc16}', "");
Expect(1, 1462, '\P{^Is_Canonical_Combining_Class: ccc16}', "");
Expect(0, 1463, '\p{Is_Canonical_Combining_Class: ccc16}', "");
Expect(1, 1463, '\p{^Is_Canonical_Combining_Class: ccc16}', "");
Expect(1, 1463, '\P{Is_Canonical_Combining_Class: ccc16}', "");
Expect(0, 1463, '\P{^Is_Canonical_Combining_Class: ccc16}', "");
Expect(1, 1462, '\p{Is_Canonical_Combining_Class= CCC16}', "");
Expect(0, 1462, '\p{^Is_Canonical_Combining_Class= CCC16}', "");
Expect(0, 1462, '\P{Is_Canonical_Combining_Class= CCC16}', "");
Expect(1, 1462, '\P{^Is_Canonical_Combining_Class= CCC16}', "");
Expect(0, 1463, '\p{Is_Canonical_Combining_Class= CCC16}', "");
Expect(1, 1463, '\p{^Is_Canonical_Combining_Class= CCC16}', "");
Expect(1, 1463, '\P{Is_Canonical_Combining_Class= CCC16}', "");
Expect(0, 1463, '\P{^Is_Canonical_Combining_Class= CCC16}', "");
Error('\p{Is_Ccc=/a/-0_0_0_16}');
Error('\P{Is_Ccc=/a/-0_0_0_16}');
Expect(1, 1462, '\p{Is_Ccc=+0000016}', "");
Expect(0, 1462, '\p{^Is_Ccc=+0000016}', "");
Expect(0, 1462, '\P{Is_Ccc=+0000016}', "");
Expect(1, 1462, '\P{^Is_Ccc=+0000016}', "");
Expect(0, 1463, '\p{Is_Ccc=+0000016}', "");
Expect(1, 1463, '\p{^Is_Ccc=+0000016}', "");
Expect(1, 1463, '\P{Is_Ccc=+0000016}', "");
Expect(0, 1463, '\P{^Is_Ccc=+0000016}', "");
Error('\p{Canonical_Combining_Class=:=	_ccc17}');
Error('\P{Canonical_Combining_Class=:=	_ccc17}');
Expect(1, 1463, '\p{Canonical_Combining_Class=ccc17}', "");
Expect(0, 1463, '\p{^Canonical_Combining_Class=ccc17}', "");
Expect(0, 1463, '\P{Canonical_Combining_Class=ccc17}', "");
Expect(1, 1463, '\P{^Canonical_Combining_Class=ccc17}', "");
Expect(0, 1464, '\p{Canonical_Combining_Class=ccc17}', "");
Expect(1, 1464, '\p{^Canonical_Combining_Class=ccc17}', "");
Expect(1, 1464, '\P{Canonical_Combining_Class=ccc17}', "");
Expect(0, 1464, '\P{^Canonical_Combining_Class=ccc17}', "");
Expect(1, 1463, '\p{Canonical_Combining_Class=-ccc17}', "");
Expect(0, 1463, '\p{^Canonical_Combining_Class=-ccc17}', "");
Expect(0, 1463, '\P{Canonical_Combining_Class=-ccc17}', "");
Expect(1, 1463, '\P{^Canonical_Combining_Class=-ccc17}', "");
Expect(0, 1464, '\p{Canonical_Combining_Class=-ccc17}', "");
Expect(1, 1464, '\p{^Canonical_Combining_Class=-ccc17}', "");
Expect(1, 1464, '\P{Canonical_Combining_Class=-ccc17}', "");
Expect(0, 1464, '\P{^Canonical_Combining_Class=-ccc17}', "");
Error('\p{Ccc=- 0_0_0_0_17/a/}');
Error('\P{Ccc=- 0_0_0_0_17/a/}');
Expect(1, 1463, '\p{Ccc=0_0_17}', "");
Expect(0, 1463, '\p{^Ccc=0_0_17}', "");
Expect(0, 1463, '\P{Ccc=0_0_17}', "");
Expect(1, 1463, '\P{^Ccc=0_0_17}', "");
Expect(0, 1464, '\p{Ccc=0_0_17}', "");
Expect(1, 1464, '\p{^Ccc=0_0_17}', "");
Expect(1, 1464, '\P{Ccc=0_0_17}', "");
Expect(0, 1464, '\P{^Ccc=0_0_17}', "");
Error('\p{Is_Canonical_Combining_Class:	 	CCC17/a/}');
Error('\P{Is_Canonical_Combining_Class:	 	CCC17/a/}');
Expect(1, 1463, '\p{Is_Canonical_Combining_Class: ccc17}', "");
Expect(0, 1463, '\p{^Is_Canonical_Combining_Class: ccc17}', "");
Expect(0, 1463, '\P{Is_Canonical_Combining_Class: ccc17}', "");
Expect(1, 1463, '\P{^Is_Canonical_Combining_Class: ccc17}', "");
Expect(0, 1464, '\p{Is_Canonical_Combining_Class: ccc17}', "");
Expect(1, 1464, '\p{^Is_Canonical_Combining_Class: ccc17}', "");
Expect(1, 1464, '\P{Is_Canonical_Combining_Class: ccc17}', "");
Expect(0, 1464, '\P{^Is_Canonical_Combining_Class: ccc17}', "");
Expect(1, 1463, '\p{Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(0, 1463, '\p{^Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(0, 1463, '\P{Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(1, 1463, '\P{^Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(0, 1464, '\p{Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(1, 1464, '\p{^Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(1, 1464, '\P{Is_Canonical_Combining_Class:   	CCC17}', "");
Expect(0, 1464, '\P{^Is_Canonical_Combining_Class:   	CCC17}', "");
Error('\p{Is_Ccc=-000000017:=}');
Error('\P{Is_Ccc=-000000017:=}');
Expect(1, 1463, '\p{Is_Ccc=00017}', "");
Expect(0, 1463, '\p{^Is_Ccc=00017}', "");
Expect(0, 1463, '\P{Is_Ccc=00017}', "");
Expect(1, 1463, '\P{^Is_Ccc=00017}', "");
Expect(0, 1464, '\p{Is_Ccc=00017}', "");
Expect(1, 1464, '\p{^Is_Ccc=00017}', "");
Expect(1, 1464, '\P{Is_Ccc=00017}', "");
Expect(0, 1464, '\P{^Is_Ccc=00017}', "");
Error('\p{Canonical_Combining_Class=:=-_CCC18}');
Error('\P{Canonical_Combining_Class=:=-_CCC18}');
Expect(1, 1479, '\p{Canonical_Combining_Class=ccc18}', "");
Expect(0, 1479, '\p{^Canonical_Combining_Class=ccc18}', "");
Expect(0, 1479, '\P{Canonical_Combining_Class=ccc18}', "");
Expect(1, 1479, '\P{^Canonical_Combining_Class=ccc18}', "");
Expect(0, 1480, '\p{Canonical_Combining_Class=ccc18}', "");
Expect(1, 1480, '\p{^Canonical_Combining_Class=ccc18}', "");
Expect(1, 1480, '\P{Canonical_Combining_Class=ccc18}', "");
Expect(0, 1480, '\P{^Canonical_Combining_Class=ccc18}', "");
Expect(1, 1479, '\p{Canonical_Combining_Class= 	CCC18}', "");
Expect(0, 1479, '\p{^Canonical_Combining_Class= 	CCC18}', "");
Expect(0, 1479, '\P{Canonical_Combining_Class= 	CCC18}', "");
Expect(1, 1479, '\P{^Canonical_Combining_Class= 	CCC18}', "");
Expect(0, 1480, '\p{Canonical_Combining_Class= 	CCC18}', "");
Expect(1, 1480, '\p{^Canonical_Combining_Class= 	CCC18}', "");
Expect(1, 1480, '\P{Canonical_Combining_Class= 	CCC18}', "");
Expect(0, 1480, '\P{^Canonical_Combining_Class= 	CCC18}', "");
Error('\p{Ccc=:=_ 000000018}');
Error('\P{Ccc=:=_ 000000018}');
Expect(1, 1479, '\p{Ccc=+0_0_0_0_18}', "");
Expect(0, 1479, '\p{^Ccc=+0_0_0_0_18}', "");
Expect(0, 1479, '\P{Ccc=+0_0_0_0_18}', "");
Expect(1, 1479, '\P{^Ccc=+0_0_0_0_18}', "");
Expect(0, 1480, '\p{Ccc=+0_0_0_0_18}', "");
Expect(1, 1480, '\p{^Ccc=+0_0_0_0_18}', "");
Expect(1, 1480, '\P{Ccc=+0_0_0_0_18}', "");
Expect(0, 1480, '\P{^Ccc=+0_0_0_0_18}', "");
Error('\p{Is_Canonical_Combining_Class=/a/--CCC18}');
Error('\P{Is_Canonical_Combining_Class=/a/--CCC18}');
Expect(1, 1479, '\p{Is_Canonical_Combining_Class: ccc18}', "");
Expect(0, 1479, '\p{^Is_Canonical_Combining_Class: ccc18}', "");
Expect(0, 1479, '\P{Is_Canonical_Combining_Class: ccc18}', "");
Expect(1, 1479, '\P{^Is_Canonical_Combining_Class: ccc18}', "");
Expect(0, 1480, '\p{Is_Canonical_Combining_Class: ccc18}', "");
Expect(1, 1480, '\p{^Is_Canonical_Combining_Class: ccc18}', "");
Expect(1, 1480, '\P{Is_Canonical_Combining_Class: ccc18}', "");
Expect(0, 1480, '\P{^Is_Canonical_Combining_Class: ccc18}', "");
Expect(1, 1479, '\p{Is_Canonical_Combining_Class=	ccc18}', "");
Expect(0, 1479, '\p{^Is_Canonical_Combining_Class=	ccc18}', "");
Expect(0, 1479, '\P{Is_Canonical_Combining_Class=	ccc18}', "");
Expect(1, 1479, '\P{^Is_Canonical_Combining_Class=	ccc18}', "");
Expect(0, 1480, '\p{Is_Canonical_Combining_Class=	ccc18}', "");
Expect(1, 1480, '\p{^Is_Canonical_Combining_Class=	ccc18}', "");
Expect(1, 1480, '\P{Is_Canonical_Combining_Class=	ccc18}', "");
Expect(0, 1480, '\P{^Is_Canonical_Combining_Class=	ccc18}', "");
Error('\p{Is_Ccc=	:=+01_8}');
Error('\P{Is_Ccc=	:=+01_8}');
Expect(1, 1479, '\p{Is_Ccc=+0000000001_8}', "");
Expect(0, 1479, '\p{^Is_Ccc=+0000000001_8}', "");
Expect(0, 1479, '\P{Is_Ccc=+0000000001_8}', "");
Expect(1, 1479, '\P{^Is_Ccc=+0000000001_8}', "");
Expect(0, 1480, '\p{Is_Ccc=+0000000001_8}', "");
Expect(1, 1480, '\p{^Is_Ccc=+0000000001_8}', "");
Expect(1, 1480, '\P{Is_Ccc=+0000000001_8}', "");
Expect(0, 1480, '\P{^Is_Ccc=+0000000001_8}', "");
Error('\p{Canonical_Combining_Class=-:=ccc19}');
Error('\P{Canonical_Combining_Class=-:=ccc19}');
Expect(1, 1466, '\p{Canonical_Combining_Class=ccc19}', "");
Expect(0, 1466, '\p{^Canonical_Combining_Class=ccc19}', "");
Expect(0, 1466, '\P{Canonical_Combining_Class=ccc19}', "");
Expect(1, 1466, '\P{^Canonical_Combining_Class=ccc19}', "");
Expect(0, 1467, '\p{Canonical_Combining_Class=ccc19}', "");
Expect(1, 1467, '\p{^Canonical_Combining_Class=ccc19}', "");
Expect(1, 1467, '\P{Canonical_Combining_Class=ccc19}', "");
Expect(0, 1467, '\P{^Canonical_Combining_Class=ccc19}', "");
Expect(1, 1466, '\p{Canonical_Combining_Class:	- ccc19}', "");
Expect(0, 1466, '\p{^Canonical_Combining_Class:	- ccc19}', "");
Expect(0, 1466, '\P{Canonical_Combining_Class:	- ccc19}', "");
Expect(1, 1466, '\P{^Canonical_Combining_Class:	- ccc19}', "");
Expect(0, 1467, '\p{Canonical_Combining_Class:	- ccc19}', "");
Expect(1, 1467, '\p{^Canonical_Combining_Class:	- ccc19}', "");
Expect(1, 1467, '\P{Canonical_Combining_Class:	- ccc19}', "");
Expect(0, 1467, '\P{^Canonical_Combining_Class:	- ccc19}', "");
Error('\p{Ccc=- 000_000_19:=}');
Error('\P{Ccc=- 000_000_19:=}');
Expect(1, 1466, '\p{Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(0, 1466, '\p{^Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(0, 1466, '\P{Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(1, 1466, '\P{^Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(0, 1467, '\p{Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(1, 1467, '\p{^Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(1, 1467, '\P{Ccc=+0_0_0_0_0_0_0_0_019}', "");
Expect(0, 1467, '\P{^Ccc=+0_0_0_0_0_0_0_0_019}', "");
Error('\p{Is_Canonical_Combining_Class=--CCC19/a/}');
Error('\P{Is_Canonical_Combining_Class=--CCC19/a/}');
Expect(1, 1466, '\p{Is_Canonical_Combining_Class:	ccc19}', "");
Expect(0, 1466, '\p{^Is_Canonical_Combining_Class:	ccc19}', "");
Expect(0, 1466, '\P{Is_Canonical_Combining_Class:	ccc19}', "");
Expect(1, 1466, '\P{^Is_Canonical_Combining_Class:	ccc19}', "");
Expect(0, 1467, '\p{Is_Canonical_Combining_Class:	ccc19}', "");
Expect(1, 1467, '\p{^Is_Canonical_Combining_Class:	ccc19}', "");
Expect(1, 1467, '\P{Is_Canonical_Combining_Class:	ccc19}', "");
Expect(0, 1467, '\P{^Is_Canonical_Combining_Class:	ccc19}', "");
Expect(1, 1466, '\p{Is_Canonical_Combining_Class=_CCC19}', "");
Expect(0, 1466, '\p{^Is_Canonical_Combining_Class=_CCC19}', "");
Expect(0, 1466, '\P{Is_Canonical_Combining_Class=_CCC19}', "");
Expect(1, 1466, '\P{^Is_Canonical_Combining_Class=_CCC19}', "");
Expect(0, 1467, '\p{Is_Canonical_Combining_Class=_CCC19}', "");
Expect(1, 1467, '\p{^Is_Canonical_Combining_Class=_CCC19}', "");
Expect(1, 1467, '\P{Is_Canonical_Combining_Class=_CCC19}', "");
Expect(0, 1467, '\P{^Is_Canonical_Combining_Class=_CCC19}', "");
Error('\p{Is_Ccc=/a/	_019}');
Error('\P{Is_Ccc=/a/	_019}');
Expect(1, 1466, '\p{Is_Ccc=0000019}', "");
Expect(0, 1466, '\p{^Is_Ccc=0000019}', "");
Expect(0, 1466, '\P{Is_Ccc=0000019}', "");
Expect(1, 1466, '\P{^Is_Ccc=0000019}', "");
Expect(0, 1467, '\p{Is_Ccc=0000019}', "");
Expect(1, 1467, '\p{^Is_Ccc=0000019}', "");
Expect(1, 1467, '\P{Is_Ccc=0000019}', "");
Expect(0, 1467, '\P{^Is_Ccc=0000019}', "");
Error('\p{Canonical_Combining_Class=-:=CCC20}');
Error('\P{Canonical_Combining_Class=-:=CCC20}');
Expect(1, 1467, '\p{Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\p{^Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\P{Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\P{^Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\p{Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\p{^Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\P{Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\P{^Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\p{Canonical_Combining_Class=- CCC20}', "");
Expect(0, 1467, '\p{^Canonical_Combining_Class=- CCC20}', "");
Expect(0, 1467, '\P{Canonical_Combining_Class=- CCC20}', "");
Expect(1, 1467, '\P{^Canonical_Combining_Class=- CCC20}', "");
Expect(0, 1468, '\p{Canonical_Combining_Class=- CCC20}', "");
Expect(1, 1468, '\p{^Canonical_Combining_Class=- CCC20}', "");
Expect(1, 1468, '\P{Canonical_Combining_Class=- CCC20}', "");
Expect(0, 1468, '\P{^Canonical_Combining_Class=- CCC20}', "");
Error('\p{Ccc=/a/ _000000020}');
Error('\P{Ccc=/a/ _000000020}');
Expect(1, 1467, '\p{Ccc=+0_0_0_0_0_0_020}', "");
Expect(0, 1467, '\p{^Ccc=+0_0_0_0_0_0_020}', "");
Expect(0, 1467, '\P{Ccc=+0_0_0_0_0_0_020}', "");
Expect(1, 1467, '\P{^Ccc=+0_0_0_0_0_0_020}', "");
Expect(0, 1468, '\p{Ccc=+0_0_0_0_0_0_020}', "");
Expect(1, 1468, '\p{^Ccc=+0_0_0_0_0_0_020}', "");
Expect(1, 1468, '\P{Ccc=+0_0_0_0_0_0_020}', "");
Expect(0, 1468, '\P{^Ccc=+0_0_0_0_0_0_020}', "");
Error('\p{Is_Canonical_Combining_Class=		CCC20:=}');
Error('\P{Is_Canonical_Combining_Class=		CCC20:=}');
Expect(1, 1467, '\p{Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\p{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1467, '\P{Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\P{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\p{Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\p{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1468, '\P{Is_Canonical_Combining_Class=ccc20}', "");
Expect(0, 1468, '\P{^Is_Canonical_Combining_Class=ccc20}', "");
Expect(1, 1467, '\p{Is_Canonical_Combining_Class= _CCC20}', "");
Expect(0, 1467, '\p{^Is_Canonical_Combining_Class= _CCC20}', "");
Expect(0, 1467, '\P{Is_Canonical_Combining_Class= _CCC20}', "");
Expect(1, 1467, '\P{^Is_Canonical_Combining_Class= _CCC20}', "");
Expect(0, 1468, '\p{Is_Canonical_Combining_Class= _CCC20}', "");
Expect(1, 1468, '\p{^Is_Canonical_Combining_Class= _CCC20}', "");
Expect(1, 1468, '\P{Is_Canonical_Combining_Class= _CCC20}', "");
Expect(0, 1468, '\P{^Is_Canonical_Combining_Class= _CCC20}', "");
Error('\p{Is_Ccc:	:=_00000020}');
Error('\P{Is_Ccc:	:=_00000020}');
Expect(1, 1467, '\p{Is_Ccc=02_0}', "");
Expect(0, 1467, '\p{^Is_Ccc=02_0}', "");
Expect(0, 1467, '\P{Is_Ccc=02_0}', "");
Expect(1, 1467, '\P{^Is_Ccc=02_0}', "");
Expect(0, 1468, '\p{Is_Ccc=02_0}', "");
Expect(1, 1468, '\p{^Is_Ccc=02_0}', "");
Expect(1, 1468, '\P{Is_Ccc=02_0}', "");
Expect(0, 1468, '\P{^Is_Ccc=02_0}', "");
Error('\p{Canonical_Combining_Class=:= _ccc21}');
Error('\P{Canonical_Combining_Class=:= _ccc21}');
Expect(1, 1468, '\p{Canonical_Combining_Class:	ccc21}', "");
Expect(0, 1468, '\p{^Canonical_Combining_Class:	ccc21}', "");
Expect(0, 1468, '\P{Canonical_Combining_Class:	ccc21}', "");
Expect(1, 1468, '\P{^Canonical_Combining_Class:	ccc21}', "");
Expect(0, 1469, '\p{Canonical_Combining_Class:	ccc21}', "");
Expect(1, 1469, '\p{^Canonical_Combining_Class:	ccc21}', "");
Expect(1, 1469, '\P{Canonical_Combining_Class:	ccc21}', "");
Expect(0, 1469, '\P{^Canonical_Combining_Class:	ccc21}', "");
Expect(1, 1468, '\p{Canonical_Combining_Class=	ccc21}', "");
Expect(0, 1468, '\p{^Canonical_Combining_Class=	ccc21}', "");
Expect(0, 1468, '\P{Canonical_Combining_Class=	ccc21}', "");
Expect(1, 1468, '\P{^Canonical_Combining_Class=	ccc21}', "");
Expect(0, 1469, '\p{Canonical_Combining_Class=	ccc21}', "");
Expect(1, 1469, '\p{^Canonical_Combining_Class=	ccc21}', "");
Expect(1, 1469, '\P{Canonical_Combining_Class=	ccc21}', "");
Expect(0, 1469, '\P{^Canonical_Combining_Class=	ccc21}', "");
Error('\p{Ccc=	:=00_00_00_021}');
Error('\P{Ccc=	:=00_00_00_021}');
Expect(1, 1468, '\p{Ccc=21}', "");
Expect(0, 1468, '\p{^Ccc=21}', "");
Expect(0, 1468, '\P{Ccc=21}', "");
Expect(1, 1468, '\P{^Ccc=21}', "");
Expect(0, 1469, '\p{Ccc=21}', "");
Expect(1, 1469, '\p{^Ccc=21}', "");
Expect(1, 1469, '\P{Ccc=21}', "");
Expect(0, 1469, '\P{^Ccc=21}', "");
Error('\p{Is_Canonical_Combining_Class=-_CCC21:=}');
Error('\P{Is_Canonical_Combining_Class=-_CCC21:=}');
Expect(1, 1468, '\p{Is_Canonical_Combining_Class=ccc21}', "");
Expect(0, 1468, '\p{^Is_Canonical_Combining_Class=ccc21}', "");
Expect(0, 1468, '\P{Is_Canonical_Combining_Class=ccc21}', "");
Expect(1, 1468, '\P{^Is_Canonical_Combining_Class=ccc21}', "");
Expect(0, 1469, '\p{Is_Canonical_Combining_Class=ccc21}', "");
Expect(1, 1469, '\p{^Is_Canonical_Combining_Class=ccc21}', "");
Expect(1, 1469, '\P{Is_Canonical_Combining_Class=ccc21}', "");
Expect(0, 1469, '\P{^Is_Canonical_Combining_Class=ccc21}', "");
Expect(1, 1468, '\p{Is_Canonical_Combining_Class=		CCC21}', "");
Expect(0, 1468, '\p{^Is_Canonical_Combining_Class=		CCC21}', "");
Expect(0, 1468, '\P{Is_Canonical_Combining_Class=		CCC21}', "");
Expect(1, 1468, '\P{^Is_Canonical_Combining_Class=		CCC21}', "");
Expect(0, 1469, '\p{Is_Canonical_Combining_Class=		CCC21}', "");
Expect(1, 1469, '\p{^Is_Canonical_Combining_Class=		CCC21}', "");
Expect(1, 1469, '\P{Is_Canonical_Combining_Class=		CCC21}', "");
Expect(0, 1469, '\P{^Is_Canonical_Combining_Class=		CCC21}', "");
Error('\p{Is_Ccc=:=	 000000021}');
Error('\P{Is_Ccc=:=	 000000021}');
Expect(1, 1468, '\p{Is_Ccc: 000021}', "");
Expect(0, 1468, '\p{^Is_Ccc: 000021}', "");
Expect(0, 1468, '\P{Is_Ccc: 000021}', "");
Expect(1, 1468, '\P{^Is_Ccc: 000021}', "");
Expect(0, 1469, '\p{Is_Ccc: 000021}', "");
Expect(1, 1469, '\p{^Is_Ccc: 000021}', "");
Expect(1, 1469, '\P{Is_Ccc: 000021}', "");
Expect(0, 1469, '\P{^Is_Ccc: 000021}', "");
Error('\p{Canonical_Combining_Class=_/a/ccc22}');
Error('\P{Canonical_Combining_Class=_/a/ccc22}');
Expect(1, 1469, '\p{Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\p{^Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\P{Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\P{^Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\p{Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\p{^Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\P{Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\P{^Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\p{Canonical_Combining_Class=_CCC22}', "");
Expect(0, 1469, '\p{^Canonical_Combining_Class=_CCC22}', "");
Expect(0, 1469, '\P{Canonical_Combining_Class=_CCC22}', "");
Expect(1, 1469, '\P{^Canonical_Combining_Class=_CCC22}', "");
Expect(0, 1470, '\p{Canonical_Combining_Class=_CCC22}', "");
Expect(1, 1470, '\p{^Canonical_Combining_Class=_CCC22}', "");
Expect(1, 1470, '\P{Canonical_Combining_Class=_CCC22}', "");
Expect(0, 1470, '\P{^Canonical_Combining_Class=_CCC22}', "");
Error('\p{Ccc=_:=0_0_22}');
Error('\P{Ccc=_:=0_0_22}');
Expect(1, 1469, '\p{Ccc=+00000000022}', "");
Expect(0, 1469, '\p{^Ccc=+00000000022}', "");
Expect(0, 1469, '\P{Ccc=+00000000022}', "");
Expect(1, 1469, '\P{^Ccc=+00000000022}', "");
Expect(0, 1470, '\p{Ccc=+00000000022}', "");
Expect(1, 1470, '\p{^Ccc=+00000000022}', "");
Expect(1, 1470, '\P{Ccc=+00000000022}', "");
Expect(0, 1470, '\P{^Ccc=+00000000022}', "");
Error('\p{Is_Canonical_Combining_Class:	:=	CCC22}');
Error('\P{Is_Canonical_Combining_Class:	:=	CCC22}');
Expect(1, 1469, '\p{Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\p{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1469, '\P{Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\P{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\p{Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\p{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1470, '\P{Is_Canonical_Combining_Class=ccc22}', "");
Expect(0, 1470, '\P{^Is_Canonical_Combining_Class=ccc22}', "");
Expect(1, 1469, '\p{Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(0, 1469, '\p{^Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(0, 1469, '\P{Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(1, 1469, '\P{^Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(0, 1470, '\p{Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(1, 1470, '\p{^Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(1, 1470, '\P{Is_Canonical_Combining_Class=_-CCC22}', "");
Expect(0, 1470, '\P{^Is_Canonical_Combining_Class=_-CCC22}', "");
Error('\p{Is_Ccc=-/a/000_000_000_22}');
Error('\P{Is_Ccc=-/a/000_000_000_22}');
Expect(1, 1469, '\p{Is_Ccc=00000022}', "");
Expect(0, 1469, '\p{^Is_Ccc=00000022}', "");
Expect(0, 1469, '\P{Is_Ccc=00000022}', "");
Expect(1, 1469, '\P{^Is_Ccc=00000022}', "");
Expect(0, 1470, '\p{Is_Ccc=00000022}', "");
Expect(1, 1470, '\p{^Is_Ccc=00000022}', "");
Expect(1, 1470, '\P{Is_Ccc=00000022}', "");
Expect(0, 1470, '\P{^Is_Ccc=00000022}', "");
Error('\p{Canonical_Combining_Class=_:=CCC23}');
Error('\P{Canonical_Combining_Class=_:=CCC23}');
Expect(1, 1471, '\p{Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\p{^Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\P{Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\P{^Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\p{Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\p{^Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\P{Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\P{^Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\p{Canonical_Combining_Class=	 CCC23}', "");
Expect(0, 1471, '\p{^Canonical_Combining_Class=	 CCC23}', "");
Expect(0, 1471, '\P{Canonical_Combining_Class=	 CCC23}', "");
Expect(1, 1471, '\P{^Canonical_Combining_Class=	 CCC23}', "");
Expect(0, 1472, '\p{Canonical_Combining_Class=	 CCC23}', "");
Expect(1, 1472, '\p{^Canonical_Combining_Class=	 CCC23}', "");
Expect(1, 1472, '\P{Canonical_Combining_Class=	 CCC23}', "");
Expect(0, 1472, '\P{^Canonical_Combining_Class=	 CCC23}', "");
Error('\p{Ccc=:=_+0000023}');
Error('\P{Ccc=:=_+0000023}');
Expect(1, 1471, '\p{Ccc=023}', "");
Expect(0, 1471, '\p{^Ccc=023}', "");
Expect(0, 1471, '\P{Ccc=023}', "");
Expect(1, 1471, '\P{^Ccc=023}', "");
Expect(0, 1472, '\p{Ccc=023}', "");
Expect(1, 1472, '\p{^Ccc=023}', "");
Expect(1, 1472, '\P{Ccc=023}', "");
Expect(0, 1472, '\P{^Ccc=023}', "");
Error('\p{Is_Canonical_Combining_Class:/a/ 	ccc23}');
Error('\P{Is_Canonical_Combining_Class:/a/ 	ccc23}');
Expect(1, 1471, '\p{Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\p{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1471, '\P{Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\P{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\p{Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\p{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1472, '\P{Is_Canonical_Combining_Class=ccc23}', "");
Expect(0, 1472, '\P{^Is_Canonical_Combining_Class=ccc23}', "");
Expect(1, 1471, '\p{Is_Canonical_Combining_Class=		CCC23}', "");
Expect(0, 1471, '\p{^Is_Canonical_Combining_Class=		CCC23}', "");
Expect(0, 1471, '\P{Is_Canonical_Combining_Class=		CCC23}', "");
Expect(1, 1471, '\P{^Is_Canonical_Combining_Class=		CCC23}', "");
Expect(0, 1472, '\p{Is_Canonical_Combining_Class=		CCC23}', "");
Expect(1, 1472, '\p{^Is_Canonical_Combining_Class=		CCC23}', "");
Expect(1, 1472, '\P{Is_Canonical_Combining_Class=		CCC23}', "");
Expect(0, 1472, '\P{^Is_Canonical_Combining_Class=		CCC23}', "");
Error('\p{Is_Ccc=_-+00_00_02_3:=}');
Error('\P{Is_Ccc=_-+00_00_02_3:=}');
Expect(1, 1471, '\p{Is_Ccc=00000000023}', "");
Expect(0, 1471, '\p{^Is_Ccc=00000000023}', "");
Expect(0, 1471, '\P{Is_Ccc=00000000023}', "");
Expect(1, 1471, '\P{^Is_Ccc=00000000023}', "");
Expect(0, 1472, '\p{Is_Ccc=00000000023}', "");
Expect(1, 1472, '\p{^Is_Ccc=00000000023}', "");
Expect(1, 1472, '\P{Is_Ccc=00000000023}', "");
Expect(0, 1472, '\P{^Is_Ccc=00000000023}', "");
Error('\p{Canonical_Combining_Class=_ccc24/a/}');
Error('\P{Canonical_Combining_Class=_ccc24/a/}');
Expect(1, 1473, '\p{Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\p{^Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\P{Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\P{^Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\p{Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\p{^Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\P{Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\P{^Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\p{Canonical_Combining_Class=- ccc24}', "");
Expect(0, 1473, '\p{^Canonical_Combining_Class=- ccc24}', "");
Expect(0, 1473, '\P{Canonical_Combining_Class=- ccc24}', "");
Expect(1, 1473, '\P{^Canonical_Combining_Class=- ccc24}', "");
Expect(0, 1474, '\p{Canonical_Combining_Class=- ccc24}', "");
Expect(1, 1474, '\p{^Canonical_Combining_Class=- ccc24}', "");
Expect(1, 1474, '\P{Canonical_Combining_Class=- ccc24}', "");
Expect(0, 1474, '\P{^Canonical_Combining_Class=- ccc24}', "");
Error('\p{Ccc=_/a/00000024}');
Error('\P{Ccc=_/a/00000024}');
Expect(1, 1473, '\p{Ccc=+00000024}', "");
Expect(0, 1473, '\p{^Ccc=+00000024}', "");
Expect(0, 1473, '\P{Ccc=+00000024}', "");
Expect(1, 1473, '\P{^Ccc=+00000024}', "");
Expect(0, 1474, '\p{Ccc=+00000024}', "");
Expect(1, 1474, '\p{^Ccc=+00000024}', "");
Expect(1, 1474, '\P{Ccc=+00000024}', "");
Expect(0, 1474, '\P{^Ccc=+00000024}', "");
Error('\p{Is_Canonical_Combining_Class: 	/a/CCC24}');
Error('\P{Is_Canonical_Combining_Class: 	/a/CCC24}');
Expect(1, 1473, '\p{Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\p{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1473, '\P{Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\P{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\p{Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\p{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1474, '\P{Is_Canonical_Combining_Class=ccc24}', "");
Expect(0, 1474, '\P{^Is_Canonical_Combining_Class=ccc24}', "");
Expect(1, 1473, '\p{Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(0, 1473, '\p{^Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(0, 1473, '\P{Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(1, 1473, '\P{^Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(0, 1474, '\p{Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(1, 1474, '\p{^Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(1, 1474, '\P{Is_Canonical_Combining_Class=_ CCC24}', "");
Expect(0, 1474, '\P{^Is_Canonical_Combining_Class=_ CCC24}', "");
Error('\p{Is_Ccc=	 +24:=}');
Error('\P{Is_Ccc=	 +24:=}');
Expect(1, 1473, '\p{Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(0, 1473, '\p{^Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(0, 1473, '\P{Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(1, 1473, '\P{^Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(0, 1474, '\p{Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(1, 1474, '\p{^Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(1, 1474, '\P{Is_Ccc=0_0_0_0_0_0_0024}', "");
Expect(0, 1474, '\P{^Is_Ccc=0_0_0_0_0_0_0024}', "");
Error('\p{Canonical_Combining_Class:	-:=CCC25}');
Error('\P{Canonical_Combining_Class:	-:=CCC25}');
Expect(1, 1474, '\p{Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\p{^Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\P{Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\P{^Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\p{Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\p{^Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\P{Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\P{^Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\p{Canonical_Combining_Class=CCC25}', "");
Expect(0, 1474, '\p{^Canonical_Combining_Class=CCC25}', "");
Expect(0, 1474, '\P{Canonical_Combining_Class=CCC25}', "");
Expect(1, 1474, '\P{^Canonical_Combining_Class=CCC25}', "");
Expect(0, 1475, '\p{Canonical_Combining_Class=CCC25}', "");
Expect(1, 1475, '\p{^Canonical_Combining_Class=CCC25}', "");
Expect(1, 1475, '\P{Canonical_Combining_Class=CCC25}', "");
Expect(0, 1475, '\P{^Canonical_Combining_Class=CCC25}', "");
Error('\p{Ccc:	_25:=}');
Error('\P{Ccc:	_25:=}');
Expect(1, 1474, '\p{Ccc=002_5}', "");
Expect(0, 1474, '\p{^Ccc=002_5}', "");
Expect(0, 1474, '\P{Ccc=002_5}', "");
Expect(1, 1474, '\P{^Ccc=002_5}', "");
Expect(0, 1475, '\p{Ccc=002_5}', "");
Expect(1, 1475, '\p{^Ccc=002_5}', "");
Expect(1, 1475, '\P{Ccc=002_5}', "");
Expect(0, 1475, '\P{^Ccc=002_5}', "");
Error('\p{Is_Canonical_Combining_Class=/a/__CCC25}');
Error('\P{Is_Canonical_Combining_Class=/a/__CCC25}');
Expect(1, 1474, '\p{Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\p{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1474, '\P{Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\P{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\p{Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\p{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1475, '\P{Is_Canonical_Combining_Class=ccc25}', "");
Expect(0, 1475, '\P{^Is_Canonical_Combining_Class=ccc25}', "");
Expect(1, 1474, '\p{Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(0, 1474, '\p{^Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(0, 1474, '\P{Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(1, 1474, '\P{^Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(0, 1475, '\p{Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(1, 1475, '\p{^Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(1, 1475, '\P{Is_Canonical_Combining_Class=-	CCC25}', "");
Expect(0, 1475, '\P{^Is_Canonical_Combining_Class=-	CCC25}', "");
Error('\p{Is_Ccc=_02_5/a/}');
Error('\P{Is_Ccc=_02_5/a/}');
Expect(1, 1474, '\p{Is_Ccc=+000_002_5}', "");
Expect(0, 1474, '\p{^Is_Ccc=+000_002_5}', "");
Expect(0, 1474, '\P{Is_Ccc=+000_002_5}', "");
Expect(1, 1474, '\P{^Is_Ccc=+000_002_5}', "");
Expect(0, 1475, '\p{Is_Ccc=+000_002_5}', "");
Expect(1, 1475, '\p{^Is_Ccc=+000_002_5}', "");
Expect(1, 1475, '\P{Is_Ccc=+000_002_5}', "");
Expect(0, 1475, '\P{^Is_Ccc=+000_002_5}', "");
Error('\p{Canonical_Combining_Class=-_CCC26:=}');
Error('\P{Canonical_Combining_Class=-_CCC26:=}');
Expect(1, 64286, '\p{Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\p{^Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\P{Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\P{^Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\p{Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\p{^Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\P{Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\P{^Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\p{Canonical_Combining_Class= _CCC26}', "");
Expect(0, 64286, '\p{^Canonical_Combining_Class= _CCC26}', "");
Expect(0, 64286, '\P{Canonical_Combining_Class= _CCC26}', "");
Expect(1, 64286, '\P{^Canonical_Combining_Class= _CCC26}', "");
Expect(0, 64287, '\p{Canonical_Combining_Class= _CCC26}', "");
Expect(1, 64287, '\p{^Canonical_Combining_Class= _CCC26}', "");
Expect(1, 64287, '\P{Canonical_Combining_Class= _CCC26}', "");
Expect(0, 64287, '\P{^Canonical_Combining_Class= _CCC26}', "");
Error('\p{Ccc=--+000000026:=}');
Error('\P{Ccc=--+000000026:=}');
Expect(1, 64286, '\p{Ccc=+0000000026}', "");
Expect(0, 64286, '\p{^Ccc=+0000000026}', "");
Expect(0, 64286, '\P{Ccc=+0000000026}', "");
Expect(1, 64286, '\P{^Ccc=+0000000026}', "");
Expect(0, 64287, '\p{Ccc=+0000000026}', "");
Expect(1, 64287, '\p{^Ccc=+0000000026}', "");
Expect(1, 64287, '\P{Ccc=+0000000026}', "");
Expect(0, 64287, '\P{^Ccc=+0000000026}', "");
Error('\p{Is_Canonical_Combining_Class: _/a/CCC26}');
Error('\P{Is_Canonical_Combining_Class: _/a/CCC26}');
Expect(1, 64286, '\p{Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\p{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64286, '\P{Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\P{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\p{Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\p{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64287, '\P{Is_Canonical_Combining_Class=ccc26}', "");
Expect(0, 64287, '\P{^Is_Canonical_Combining_Class=ccc26}', "");
Expect(1, 64286, '\p{Is_Canonical_Combining_Class=		CCC26}', "");
Expect(0, 64286, '\p{^Is_Canonical_Combining_Class=		CCC26}', "");
Expect(0, 64286, '\P{Is_Canonical_Combining_Class=		CCC26}', "");
Expect(1, 64286, '\P{^Is_Canonical_Combining_Class=		CCC26}', "");
Expect(0, 64287, '\p{Is_Canonical_Combining_Class=		CCC26}', "");
Expect(1, 64287, '\p{^Is_Canonical_Combining_Class=		CCC26}', "");
Expect(1, 64287, '\P{Is_Canonical_Combining_Class=		CCC26}', "");
Expect(0, 64287, '\P{^Is_Canonical_Combining_Class=		CCC26}', "");
Error('\p{Is_Ccc=_ 0002_6:=}');
Error('\P{Is_Ccc=_ 0002_6:=}');
Expect(1, 64286, '\p{Is_Ccc=2_6}', "");
Expect(0, 64286, '\p{^Is_Ccc=2_6}', "");
Expect(0, 64286, '\P{Is_Ccc=2_6}', "");
Expect(1, 64286, '\P{^Is_Ccc=2_6}', "");
Expect(0, 64287, '\p{Is_Ccc=2_6}', "");
Expect(1, 64287, '\p{^Is_Ccc=2_6}', "");
Expect(1, 64287, '\P{Is_Ccc=2_6}', "");
Expect(0, 64287, '\P{^Is_Ccc=2_6}', "");
Error('\p{Canonical_Combining_Class:   /a/__CCC27}');
Error('\P{Canonical_Combining_Class:   /a/__CCC27}');
Expect(1, 2288, '\p{Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\p{^Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\P{Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\P{^Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\p{Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\p{^Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\P{Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\P{^Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\p{Canonical_Combining_Class=-_CCC27}', "");
Expect(0, 2288, '\p{^Canonical_Combining_Class=-_CCC27}', "");
Expect(0, 2288, '\P{Canonical_Combining_Class=-_CCC27}', "");
Expect(1, 2288, '\P{^Canonical_Combining_Class=-_CCC27}', "");
Expect(0, 2289, '\p{Canonical_Combining_Class=-_CCC27}', "");
Expect(1, 2289, '\p{^Canonical_Combining_Class=-_CCC27}', "");
Expect(1, 2289, '\P{Canonical_Combining_Class=-_CCC27}', "");
Expect(0, 2289, '\P{^Canonical_Combining_Class=-_CCC27}', "");
Error('\p{Ccc=:=_00002_7}');
Error('\P{Ccc=:=_00002_7}');
Expect(1, 2288, '\p{Ccc=+000000027}', "");
Expect(0, 2288, '\p{^Ccc=+000000027}', "");
Expect(0, 2288, '\P{Ccc=+000000027}', "");
Expect(1, 2288, '\P{^Ccc=+000000027}', "");
Expect(0, 2289, '\p{Ccc=+000000027}', "");
Expect(1, 2289, '\p{^Ccc=+000000027}', "");
Expect(1, 2289, '\P{Ccc=+000000027}', "");
Expect(0, 2289, '\P{^Ccc=+000000027}', "");
Error('\p{Is_Canonical_Combining_Class=	:=CCC27}');
Error('\P{Is_Canonical_Combining_Class=	:=CCC27}');
Expect(1, 2288, '\p{Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\p{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2288, '\P{Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\P{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\p{Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\p{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2289, '\P{Is_Canonical_Combining_Class=ccc27}', "");
Expect(0, 2289, '\P{^Is_Canonical_Combining_Class=ccc27}', "");
Expect(1, 2288, '\p{Is_Canonical_Combining_Class= CCC27}', "");
Expect(0, 2288, '\p{^Is_Canonical_Combining_Class= CCC27}', "");
Expect(0, 2288, '\P{Is_Canonical_Combining_Class= CCC27}', "");
Expect(1, 2288, '\P{^Is_Canonical_Combining_Class= CCC27}', "");
Expect(0, 2289, '\p{Is_Canonical_Combining_Class= CCC27}', "");
Expect(1, 2289, '\p{^Is_Canonical_Combining_Class= CCC27}', "");
Expect(1, 2289, '\P{Is_Canonical_Combining_Class= CCC27}', "");
Expect(0, 2289, '\P{^Is_Canonical_Combining_Class= CCC27}', "");
Error('\p{Is_Ccc=	_0027:=}');
Error('\P{Is_Ccc=	_0027:=}');
Expect(1, 2288, '\p{Is_Ccc=0_0_0_0_0_27}', "");
Expect(0, 2288, '\p{^Is_Ccc=0_0_0_0_0_27}', "");
Expect(0, 2288, '\P{Is_Ccc=0_0_0_0_0_27}', "");
Expect(1, 2288, '\P{^Is_Ccc=0_0_0_0_0_27}', "");
Expect(0, 2289, '\p{Is_Ccc=0_0_0_0_0_27}', "");
Expect(1, 2289, '\p{^Is_Ccc=0_0_0_0_0_27}', "");
Expect(1, 2289, '\P{Is_Ccc=0_0_0_0_0_27}', "");
Expect(0, 2289, '\P{^Is_Ccc=0_0_0_0_0_27}', "");
Error('\p{Canonical_Combining_Class:   	:=CCC28}');
Error('\P{Canonical_Combining_Class:   	:=CCC28}');
Expect(1, 2289, '\p{Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\p{^Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\P{Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\P{^Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\p{Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\p{^Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\P{Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\P{^Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\p{Canonical_Combining_Class=	_CCC28}', "");
Expect(0, 2289, '\p{^Canonical_Combining_Class=	_CCC28}', "");
Expect(0, 2289, '\P{Canonical_Combining_Class=	_CCC28}', "");
Expect(1, 2289, '\P{^Canonical_Combining_Class=	_CCC28}', "");
Expect(0, 2290, '\p{Canonical_Combining_Class=	_CCC28}', "");
Expect(1, 2290, '\p{^Canonical_Combining_Class=	_CCC28}', "");
Expect(1, 2290, '\P{Canonical_Combining_Class=	_CCC28}', "");
Expect(0, 2290, '\P{^Canonical_Combining_Class=	_CCC28}', "");
Error('\p{Ccc::=		000000028}');
Error('\P{Ccc::=		000000028}');
Expect(1, 2289, '\p{Ccc=+002_8}', "");
Expect(0, 2289, '\p{^Ccc=+002_8}', "");
Expect(0, 2289, '\P{Ccc=+002_8}', "");
Expect(1, 2289, '\P{^Ccc=+002_8}', "");
Expect(0, 2290, '\p{Ccc=+002_8}', "");
Expect(1, 2290, '\p{^Ccc=+002_8}', "");
Expect(1, 2290, '\P{Ccc=+002_8}', "");
Expect(0, 2290, '\P{^Ccc=+002_8}', "");
Error('\p{Is_Canonical_Combining_Class=_CCC28/a/}');
Error('\P{Is_Canonical_Combining_Class=_CCC28/a/}');
Expect(1, 2289, '\p{Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\p{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2289, '\P{Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\P{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\p{Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\p{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2290, '\P{Is_Canonical_Combining_Class=ccc28}', "");
Expect(0, 2290, '\P{^Is_Canonical_Combining_Class=ccc28}', "");
Expect(1, 2289, '\p{Is_Canonical_Combining_Class= ccc28}', "");
Expect(0, 2289, '\p{^Is_Canonical_Combining_Class= ccc28}', "");
Expect(0, 2289, '\P{Is_Canonical_Combining_Class= ccc28}', "");
Expect(1, 2289, '\P{^Is_Canonical_Combining_Class= ccc28}', "");
Expect(0, 2290, '\p{Is_Canonical_Combining_Class= ccc28}', "");
Expect(1, 2290, '\p{^Is_Canonical_Combining_Class= ccc28}', "");
Expect(1, 2290, '\P{Is_Canonical_Combining_Class= ccc28}', "");
Expect(0, 2290, '\P{^Is_Canonical_Combining_Class= ccc28}', "");
Error('\p{Is_Ccc=_/a/+000000028}');
Error('\P{Is_Ccc=_/a/+000000028}');
Expect(1, 2289, '\p{Is_Ccc=00000028}', "");
Expect(0, 2289, '\p{^Is_Ccc=00000028}', "");
Expect(0, 2289, '\P{Is_Ccc=00000028}', "");
Expect(1, 2289, '\P{^Is_Ccc=00000028}', "");
Expect(0, 2290, '\p{Is_Ccc=00000028}', "");
Expect(1, 2290, '\p{^Is_Ccc=00000028}', "");
Expect(1, 2290, '\P{Is_Ccc=00000028}', "");
Expect(0, 2290, '\P{^Is_Ccc=00000028}', "");
Error('\p{Canonical_Combining_Class=/a/ _CCC29}');
Error('\P{Canonical_Combining_Class=/a/ _CCC29}');
Expect(1, 2290, '\p{Canonical_Combining_Class=ccc29}', "");
Expect(0, 2290, '\p{^Canonical_Combining_Class=ccc29}', "");
Expect(0, 2290, '\P{Canonical_Combining_Class=ccc29}', "");
Expect(1, 2290, '\P{^Canonical_Combining_Class=ccc29}', "");
Expect(0, 2291, '\p{Canonical_Combining_Class=ccc29}', "");
Expect(1, 2291, '\p{^Canonical_Combining_Class=ccc29}', "");
Expect(1, 2291, '\P{Canonical_Combining_Class=ccc29}', "");
Expect(0, 2291, '\P{^Canonical_Combining_Class=ccc29}', "");
Expect(1, 2290, '\p{Canonical_Combining_Class:		CCC29}', "");
Expect(0, 2290, '\p{^Canonical_Combining_Class:		CCC29}', "");
Expect(0, 2290, '\P{Canonical_Combining_Class:		CCC29}', "");
Expect(1, 2290, '\P{^Canonical_Combining_Class:		CCC29}', "");
Expect(0, 2291, '\p{Canonical_Combining_Class:		CCC29}', "");
Expect(1, 2291, '\p{^Canonical_Combining_Class:		CCC29}', "");
Expect(1, 2291, '\P{Canonical_Combining_Class:		CCC29}', "");
Expect(0, 2291, '\P{^Canonical_Combining_Class:		CCC29}', "");
Error('\p{Ccc=		02_9:=}');
Error('\P{Ccc=		02_9:=}');
Expect(1, 2290, '\p{Ccc=00_00_00_29}', "");
Expect(0, 2290, '\p{^Ccc=00_00_00_29}', "");
Expect(0, 2290, '\P{Ccc=00_00_00_29}', "");
Expect(1, 2290, '\P{^Ccc=00_00_00_29}', "");
Expect(0, 2291, '\p{Ccc=00_00_00_29}', "");
Expect(1, 2291, '\p{^Ccc=00_00_00_29}', "");
Expect(1, 2291, '\P{Ccc=00_00_00_29}', "");
Expect(0, 2291, '\P{^Ccc=00_00_00_29}', "");
Error('\p{Is_Canonical_Combining_Class=/a/	CCC29}');
Error('\P{Is_Canonical_Combining_Class=/a/	CCC29}');
Expect(1, 2290, '\p{Is_Canonical_Combining_Class=ccc29}', "");
Expect(0, 2290, '\p{^Is_Canonical_Combining_Class=ccc29}', "");
Expect(0, 2290, '\P{Is_Canonical_Combining_Class=ccc29}', "");
Expect(1, 2290, '\P{^Is_Canonical_Combining_Class=ccc29}', "");
Expect(0, 2291, '\p{Is_Canonical_Combining_Class=ccc29}', "");
Expect(1, 2291, '\p{^Is_Canonical_Combining_Class=ccc29}', "");
Expect(1, 2291, '\P{Is_Canonical_Combining_Class=ccc29}', "");
Expect(0, 2291, '\P{^Is_Canonical_Combining_Class=ccc29}', "");
Expect(1, 2290, '\p{Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(0, 2290, '\p{^Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(0, 2290, '\P{Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(1, 2290, '\P{^Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(0, 2291, '\p{Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(1, 2291, '\p{^Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(1, 2291, '\P{Is_Canonical_Combining_Class=-	CCC29}', "");
Expect(0, 2291, '\P{^Is_Canonical_Combining_Class=-	CCC29}', "");
Error('\p{Is_Ccc=	-00029/a/}');
Error('\P{Is_Ccc=	-00029/a/}');
Expect(1, 2290, '\p{Is_Ccc=00029}', "");
Expect(0, 2290, '\p{^Is_Ccc=00029}', "");
Expect(0, 2290, '\P{Is_Ccc=00029}', "");
Expect(1, 2290, '\P{^Is_Ccc=00029}', "");
Expect(0, 2291, '\p{Is_Ccc=00029}', "");
Expect(1, 2291, '\p{^Is_Ccc=00029}', "");
Expect(1, 2291, '\P{Is_Ccc=00029}', "");
Expect(0, 2291, '\P{^Is_Ccc=00029}', "");
Error('\p{Canonical_Combining_Class=	CCC30/a/}');
Error('\P{Canonical_Combining_Class=	CCC30/a/}');
Expect(1, 1614, '\p{Canonical_Combining_Class:	ccc30}', "");
Expect(0, 1614, '\p{^Canonical_Combining_Class:	ccc30}', "");
Expect(0, 1614, '\P{Canonical_Combining_Class:	ccc30}', "");
Expect(1, 1614, '\P{^Canonical_Combining_Class:	ccc30}', "");
Expect(0, 1615, '\p{Canonical_Combining_Class:	ccc30}', "");
Expect(1, 1615, '\p{^Canonical_Combining_Class:	ccc30}', "");
Expect(1, 1615, '\P{Canonical_Combining_Class:	ccc30}', "");
Expect(0, 1615, '\P{^Canonical_Combining_Class:	ccc30}', "");
Expect(1, 1614, '\p{Canonical_Combining_Class:	--CCC30}', "");
Expect(0, 1614, '\p{^Canonical_Combining_Class:	--CCC30}', "");
Expect(0, 1614, '\P{Canonical_Combining_Class:	--CCC30}', "");
Expect(1, 1614, '\P{^Canonical_Combining_Class:	--CCC30}', "");
Expect(0, 1615, '\p{Canonical_Combining_Class:	--CCC30}', "");
Expect(1, 1615, '\p{^Canonical_Combining_Class:	--CCC30}', "");
Expect(1, 1615, '\P{Canonical_Combining_Class:	--CCC30}', "");
Expect(0, 1615, '\P{^Canonical_Combining_Class:	--CCC30}', "");
Error('\p{Ccc= 	+00_00_00_03_0/a/}');
Error('\P{Ccc= 	+00_00_00_03_0/a/}');
Expect(1, 1614, '\p{Ccc=+00000030}', "");
Expect(0, 1614, '\p{^Ccc=+00000030}', "");
Expect(0, 1614, '\P{Ccc=+00000030}', "");
Expect(1, 1614, '\P{^Ccc=+00000030}', "");
Expect(0, 1615, '\p{Ccc=+00000030}', "");
Expect(1, 1615, '\p{^Ccc=+00000030}', "");
Expect(1, 1615, '\P{Ccc=+00000030}', "");
Expect(0, 1615, '\P{^Ccc=+00000030}', "");
Error('\p{Is_Canonical_Combining_Class=_:=CCC30}');
Error('\P{Is_Canonical_Combining_Class=_:=CCC30}');
Expect(1, 1614, '\p{Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1614, '\p{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1614, '\P{Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1614, '\P{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1615, '\p{Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1615, '\p{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1615, '\P{Is_Canonical_Combining_Class=ccc30}', "");
Expect(0, 1615, '\P{^Is_Canonical_Combining_Class=ccc30}', "");
Expect(1, 1614, '\p{Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(0, 1614, '\p{^Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(0, 1614, '\P{Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(1, 1614, '\P{^Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(0, 1615, '\p{Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(1, 1615, '\p{^Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(1, 1615, '\P{Is_Canonical_Combining_Class=_	CCC30}', "");
Expect(0, 1615, '\P{^Is_Canonical_Combining_Class=_	CCC30}', "");
Error('\p{Is_Ccc= _+0030/a/}');
Error('\P{Is_Ccc= _+0030/a/}');
Expect(1, 1614, '\p{Is_Ccc: +00030}', "");
Expect(0, 1614, '\p{^Is_Ccc: +00030}', "");
Expect(0, 1614, '\P{Is_Ccc: +00030}', "");
Expect(1, 1614, '\P{^Is_Ccc: +00030}', "");
Expect(0, 1615, '\p{Is_Ccc: +00030}', "");
Expect(1, 1615, '\p{^Is_Ccc: +00030}', "");
Expect(1, 1615, '\P{Is_Ccc: +00030}', "");
Expect(0, 1615, '\P{^Is_Ccc: +00030}', "");
Error('\p{Canonical_Combining_Class:   := _CCC31}');
Error('\P{Canonical_Combining_Class:   := _CCC31}');
Expect(1, 1615, '\p{Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\p{^Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\P{Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\P{^Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\p{Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\p{^Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\P{Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\P{^Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\p{Canonical_Combining_Class=_ CCC31}', "");
Expect(0, 1615, '\p{^Canonical_Combining_Class=_ CCC31}', "");
Expect(0, 1615, '\P{Canonical_Combining_Class=_ CCC31}', "");
Expect(1, 1615, '\P{^Canonical_Combining_Class=_ CCC31}', "");
Expect(0, 1616, '\p{Canonical_Combining_Class=_ CCC31}', "");
Expect(1, 1616, '\p{^Canonical_Combining_Class=_ CCC31}', "");
Expect(1, 1616, '\P{Canonical_Combining_Class=_ CCC31}', "");
Expect(0, 1616, '\P{^Canonical_Combining_Class=_ CCC31}', "");
Error('\p{Ccc=:=	 +00_03_1}');
Error('\P{Ccc=:=	 +00_03_1}');
Expect(1, 1615, '\p{Ccc=+03_1}', "");
Expect(0, 1615, '\p{^Ccc=+03_1}', "");
Expect(0, 1615, '\P{Ccc=+03_1}', "");
Expect(1, 1615, '\P{^Ccc=+03_1}', "");
Expect(0, 1616, '\p{Ccc=+03_1}', "");
Expect(1, 1616, '\p{^Ccc=+03_1}', "");
Expect(1, 1616, '\P{Ccc=+03_1}', "");
Expect(0, 1616, '\P{^Ccc=+03_1}', "");
Error('\p{Is_Canonical_Combining_Class=:= CCC31}');
Error('\P{Is_Canonical_Combining_Class=:= CCC31}');
Expect(1, 1615, '\p{Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\p{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1615, '\P{Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\P{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\p{Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\p{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1616, '\P{Is_Canonical_Combining_Class=ccc31}', "");
Expect(0, 1616, '\P{^Is_Canonical_Combining_Class=ccc31}', "");
Expect(1, 1615, '\p{Is_Canonical_Combining_Class= CCC31}', "");
Expect(0, 1615, '\p{^Is_Canonical_Combining_Class= CCC31}', "");
Expect(0, 1615, '\P{Is_Canonical_Combining_Class= CCC31}', "");
Expect(1, 1615, '\P{^Is_Canonical_Combining_Class= CCC31}', "");
Expect(0, 1616, '\p{Is_Canonical_Combining_Class= CCC31}', "");
Expect(1, 1616, '\p{^Is_Canonical_Combining_Class= CCC31}', "");
Expect(1, 1616, '\P{Is_Canonical_Combining_Class= CCC31}', "");
Expect(0, 1616, '\P{^Is_Canonical_Combining_Class= CCC31}', "");
Error('\p{Is_Ccc=-/a/00000000031}');
Error('\P{Is_Ccc=-/a/00000000031}');
Expect(1, 1615, '\p{Is_Ccc=00031}', "");
Expect(0, 1615, '\p{^Is_Ccc=00031}', "");
Expect(0, 1615, '\P{Is_Ccc=00031}', "");
Expect(1, 1615, '\P{^Is_Ccc=00031}', "");
Expect(0, 1616, '\p{Is_Ccc=00031}', "");
Expect(1, 1616, '\p{^Is_Ccc=00031}', "");
Expect(1, 1616, '\P{Is_Ccc=00031}', "");
Expect(0, 1616, '\P{^Is_Ccc=00031}', "");
Error('\p{Canonical_Combining_Class=:=- ccc32}');
Error('\P{Canonical_Combining_Class=:=- ccc32}');
Expect(1, 1616, '\p{Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\p{^Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\P{Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\P{^Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\p{Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\p{^Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\P{Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\P{^Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\p{Canonical_Combining_Class=		ccc32}', "");
Expect(0, 1616, '\p{^Canonical_Combining_Class=		ccc32}', "");
Expect(0, 1616, '\P{Canonical_Combining_Class=		ccc32}', "");
Expect(1, 1616, '\P{^Canonical_Combining_Class=		ccc32}', "");
Expect(0, 1617, '\p{Canonical_Combining_Class=		ccc32}', "");
Expect(1, 1617, '\p{^Canonical_Combining_Class=		ccc32}', "");
Expect(1, 1617, '\P{Canonical_Combining_Class=		ccc32}', "");
Expect(0, 1617, '\P{^Canonical_Combining_Class=		ccc32}', "");
Error('\p{Ccc= :=3_2}');
Error('\P{Ccc= :=3_2}');
Expect(1, 1616, '\p{Ccc=+0032}', "");
Expect(0, 1616, '\p{^Ccc=+0032}', "");
Expect(0, 1616, '\P{Ccc=+0032}', "");
Expect(1, 1616, '\P{^Ccc=+0032}', "");
Expect(0, 1617, '\p{Ccc=+0032}', "");
Expect(1, 1617, '\p{^Ccc=+0032}', "");
Expect(1, 1617, '\P{Ccc=+0032}', "");
Expect(0, 1617, '\P{^Ccc=+0032}', "");
Error('\p{Is_Canonical_Combining_Class=	 ccc32:=}');
Error('\P{Is_Canonical_Combining_Class=	 ccc32:=}');
Expect(1, 1616, '\p{Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\p{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1616, '\P{Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\P{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\p{Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\p{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1617, '\P{Is_Canonical_Combining_Class=ccc32}', "");
Expect(0, 1617, '\P{^Is_Canonical_Combining_Class=ccc32}', "");
Expect(1, 1616, '\p{Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(0, 1616, '\p{^Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(0, 1616, '\P{Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(1, 1616, '\P{^Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(0, 1617, '\p{Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(1, 1617, '\p{^Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(1, 1617, '\P{Is_Canonical_Combining_Class=	-CCC32}', "");
Expect(0, 1617, '\P{^Is_Canonical_Combining_Class=	-CCC32}', "");
Error('\p{Is_Ccc=_00_00_00_032:=}');
Error('\P{Is_Ccc=_00_00_00_032:=}');
Expect(1, 1616, '\p{Is_Ccc=+032}', "");
Expect(0, 1616, '\p{^Is_Ccc=+032}', "");
Expect(0, 1616, '\P{Is_Ccc=+032}', "");
Expect(1, 1616, '\P{^Is_Ccc=+032}', "");
Expect(0, 1617, '\p{Is_Ccc=+032}', "");
Expect(1, 1617, '\p{^Is_Ccc=+032}', "");
Expect(1, 1617, '\P{Is_Ccc=+032}', "");
Expect(0, 1617, '\P{^Is_Ccc=+032}', "");
Error('\p{Canonical_Combining_Class=_ CCC33/a/}');
Error('\P{Canonical_Combining_Class=_ CCC33/a/}');
Expect(1, 1617, '\p{Canonical_Combining_Class=ccc33}', "");
Expect(0, 1617, '\p{^Canonical_Combining_Class=ccc33}', "");
Expect(0, 1617, '\P{Canonical_Combining_Class=ccc33}', "");
Expect(1, 1617, '\P{^Canonical_Combining_Class=ccc33}', "");
Expect(0, 1618, '\p{Canonical_Combining_Class=ccc33}', "");
Expect(1, 1618, '\p{^Canonical_Combining_Class=ccc33}', "");
Expect(1, 1618, '\P{Canonical_Combining_Class=ccc33}', "");
Expect(0, 1618, '\P{^Canonical_Combining_Class=ccc33}', "");
Expect(1, 1617, '\p{Canonical_Combining_Class=	-ccc33}', "");
Expect(0, 1617, '\p{^Canonical_Combining_Class=	-ccc33}', "");
Expect(0, 1617, '\P{Canonical_Combining_Class=	-ccc33}', "");
Expect(1, 1617, '\P{^Canonical_Combining_Class=	-ccc33}', "");
Expect(0, 1618, '\p{Canonical_Combining_Class=	-ccc33}', "");
Expect(1, 1618, '\p{^Canonical_Combining_Class=	-ccc33}', "");
Expect(1, 1618, '\P{Canonical_Combining_Class=	-ccc33}', "");
Expect(0, 1618, '\P{^Canonical_Combining_Class=	-ccc33}', "");
Error('\p{Ccc=/a/--+0000000033}');
Error('\P{Ccc=/a/--+0000000033}');
Expect(1, 1617, '\p{Ccc=0033}', "");
Expect(0, 1617, '\p{^Ccc=0033}', "");
Expect(0, 1617, '\P{Ccc=0033}', "");
Expect(1, 1617, '\P{^Ccc=0033}', "");
Expect(0, 1618, '\p{Ccc=0033}', "");
Expect(1, 1618, '\p{^Ccc=0033}', "");
Expect(1, 1618, '\P{Ccc=0033}', "");
Expect(0, 1618, '\P{^Ccc=0033}', "");
Error('\p{Is_Canonical_Combining_Class=/a/__CCC33}');
Error('\P{Is_Canonical_Combining_Class=/a/__CCC33}');
Expect(1, 1617, '\p{Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1617, '\p{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1617, '\P{Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1617, '\P{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1618, '\p{Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1618, '\p{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1618, '\P{Is_Canonical_Combining_Class=ccc33}', "");
Expect(0, 1618, '\P{^Is_Canonical_Combining_Class=ccc33}', "");
Expect(1, 1617, '\p{Is_Canonical_Combining_Class=_CCC33}', "");
Expect(0, 1617, '\p{^Is_Canonical_Combining_Class=_CCC33}', "");
Expect(0, 1617, '\P{Is_Canonical_Combining_Class=_CCC33}', "");
Expect(1, 1617, '\P{^Is_Canonical_Combining_Class=_CCC33}', "");
Expect(0, 1618, '\p{Is_Canonical_Combining_Class=_CCC33}', "");
Expect(1, 1618, '\p{^Is_Canonical_Combining_Class=_CCC33}', "");
Expect(1, 1618, '\P{Is_Canonical_Combining_Class=_CCC33}', "");
Expect(0, 1618, '\P{^Is_Canonical_Combining_Class=_CCC33}', "");
Error('\p{Is_Ccc=/a/ _+00000000033}');
Error('\P{Is_Ccc=/a/ _+00000000033}');
Expect(1, 1617, '\p{Is_Ccc=0000000033}', "");
Expect(0, 1617, '\p{^Is_Ccc=0000000033}', "");
Expect(0, 1617, '\P{Is_Ccc=0000000033}', "");
Expect(1, 1617, '\P{^Is_Ccc=0000000033}', "");
Expect(0, 1618, '\p{Is_Ccc=0000000033}', "");
Expect(1, 1618, '\p{^Is_Ccc=0000000033}', "");
Expect(1, 1618, '\P{Is_Ccc=0000000033}', "");
Expect(0, 1618, '\P{^Is_Ccc=0000000033}', "");
Error('\p{Canonical_Combining_Class=_CCC34/a/}');
Error('\P{Canonical_Combining_Class=_CCC34/a/}');
Expect(1, 1618, '\p{Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\p{^Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\P{Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\P{^Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\p{Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\p{^Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\P{Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\P{^Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\p{Canonical_Combining_Class= ccc34}', "");
Expect(0, 1618, '\p{^Canonical_Combining_Class= ccc34}', "");
Expect(0, 1618, '\P{Canonical_Combining_Class= ccc34}', "");
Expect(1, 1618, '\P{^Canonical_Combining_Class= ccc34}', "");
Expect(0, 1619, '\p{Canonical_Combining_Class= ccc34}', "");
Expect(1, 1619, '\p{^Canonical_Combining_Class= ccc34}', "");
Expect(1, 1619, '\P{Canonical_Combining_Class= ccc34}', "");
Expect(0, 1619, '\P{^Canonical_Combining_Class= ccc34}', "");
Error('\p{Ccc=_:=00034}');
Error('\P{Ccc=_:=00034}');
Expect(1, 1618, '\p{Ccc=00_00_00_00_03_4}', "");
Expect(0, 1618, '\p{^Ccc=00_00_00_00_03_4}', "");
Expect(0, 1618, '\P{Ccc=00_00_00_00_03_4}', "");
Expect(1, 1618, '\P{^Ccc=00_00_00_00_03_4}', "");
Expect(0, 1619, '\p{Ccc=00_00_00_00_03_4}', "");
Expect(1, 1619, '\p{^Ccc=00_00_00_00_03_4}', "");
Expect(1, 1619, '\P{Ccc=00_00_00_00_03_4}', "");
Expect(0, 1619, '\P{^Ccc=00_00_00_00_03_4}', "");
Error('\p{Is_Canonical_Combining_Class: /a/  CCC34}');
Error('\P{Is_Canonical_Combining_Class: /a/  CCC34}');
Expect(1, 1618, '\p{Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\p{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1618, '\P{Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\P{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\p{Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\p{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1619, '\P{Is_Canonical_Combining_Class=ccc34}', "");
Expect(0, 1619, '\P{^Is_Canonical_Combining_Class=ccc34}', "");
Expect(1, 1618, '\p{Is_Canonical_Combining_Class= _ccc34}', "");
Expect(0, 1618, '\p{^Is_Canonical_Combining_Class= _ccc34}', "");
Expect(0, 1618, '\P{Is_Canonical_Combining_Class= _ccc34}', "");
Expect(1, 1618, '\P{^Is_Canonical_Combining_Class= _ccc34}', "");
Expect(0, 1619, '\p{Is_Canonical_Combining_Class= _ccc34}', "");
Expect(1, 1619, '\p{^Is_Canonical_Combining_Class= _ccc34}', "");
Expect(1, 1619, '\P{Is_Canonical_Combining_Class= _ccc34}', "");
Expect(0, 1619, '\P{^Is_Canonical_Combining_Class= _ccc34}', "");
Error('\p{Is_Ccc=	/a/+00_00_00_00_03_4}');
Error('\P{Is_Ccc=	/a/+00_00_00_00_03_4}');
Expect(1, 1618, '\p{Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(0, 1618, '\p{^Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(0, 1618, '\P{Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(1, 1618, '\P{^Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(0, 1619, '\p{Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(1, 1619, '\p{^Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(1, 1619, '\P{Is_Ccc=+0_0_0_0_0_0_034}', "");
Expect(0, 1619, '\P{^Is_Ccc=+0_0_0_0_0_0_034}', "");
Error('\p{Canonical_Combining_Class=-/a/CCC35}');
Error('\P{Canonical_Combining_Class=-/a/CCC35}');
Expect(1, 1648, '\p{Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\p{^Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\P{Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\P{^Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\p{Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\p{^Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\P{Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\P{^Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\p{Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1648, '\p{^Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1648, '\P{Canonical_Combining_Class=_CCC35}', "");
Expect(1, 1648, '\P{^Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1649, '\p{Canonical_Combining_Class=_CCC35}', "");
Expect(1, 1649, '\p{^Canonical_Combining_Class=_CCC35}', "");
Expect(1, 1649, '\P{Canonical_Combining_Class=_CCC35}', "");
Expect(0, 1649, '\P{^Canonical_Combining_Class=_CCC35}', "");
Error('\p{Ccc=/a/ 	035}');
Error('\P{Ccc=/a/ 	035}');
Expect(1, 1648, '\p{Ccc=00035}', "");
Expect(0, 1648, '\p{^Ccc=00035}', "");
Expect(0, 1648, '\P{Ccc=00035}', "");
Expect(1, 1648, '\P{^Ccc=00035}', "");
Expect(0, 1649, '\p{Ccc=00035}', "");
Expect(1, 1649, '\p{^Ccc=00035}', "");
Expect(1, 1649, '\P{Ccc=00035}', "");
Expect(0, 1649, '\P{^Ccc=00035}', "");
Error('\p{Is_Canonical_Combining_Class=:=-CCC35}');
Error('\P{Is_Canonical_Combining_Class=:=-CCC35}');
Expect(1, 1648, '\p{Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\p{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1648, '\P{Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\P{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\p{Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\p{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1649, '\P{Is_Canonical_Combining_Class=ccc35}', "");
Expect(0, 1649, '\P{^Is_Canonical_Combining_Class=ccc35}', "");
Expect(1, 1648, '\p{Is_Canonical_Combining_Class=--ccc35}', "");
Expect(0, 1648, '\p{^Is_Canonical_Combining_Class=--ccc35}', "");
Expect(0, 1648, '\P{Is_Canonical_Combining_Class=--ccc35}', "");
Expect(1, 1648, '\P{^Is_Canonical_Combining_Class=--ccc35}', "");
Expect(0, 1649, '\p{Is_Canonical_Combining_Class=--ccc35}', "");
Expect(1, 1649, '\p{^Is_Canonical_Combining_Class=--ccc35}', "");
Expect(1, 1649, '\P{Is_Canonical_Combining_Class=--ccc35}', "");
Expect(0, 1649, '\P{^Is_Canonical_Combining_Class=--ccc35}', "");
Error('\p{Is_Ccc= :=000035}');
Error('\P{Is_Ccc= :=000035}');
Expect(1, 1648, '\p{Is_Ccc=00035}', "");
Expect(0, 1648, '\p{^Is_Ccc=00035}', "");
Expect(0, 1648, '\P{Is_Ccc=00035}', "");
Expect(1, 1648, '\P{^Is_Ccc=00035}', "");
Expect(0, 1649, '\p{Is_Ccc=00035}', "");
Expect(1, 1649, '\p{^Is_Ccc=00035}', "");
Expect(1, 1649, '\P{Is_Ccc=00035}', "");
Expect(0, 1649, '\P{^Is_Ccc=00035}', "");
Error('\p{Canonical_Combining_Class=/a/ _CCC36}');
Error('\P{Canonical_Combining_Class=/a/ _CCC36}');
Expect(1, 1809, '\p{Canonical_Combining_Class=ccc36}', "");
Expect(0, 1809, '\p{^Canonical_Combining_Class=ccc36}', "");
Expect(0, 1809, '\P{Canonical_Combining_Class=ccc36}', "");
Expect(1, 1809, '\P{^Canonical_Combining_Class=ccc36}', "");
Expect(0, 1810, '\p{Canonical_Combining_Class=ccc36}', "");
Expect(1, 1810, '\p{^Canonical_Combining_Class=ccc36}', "");
Expect(1, 1810, '\P{Canonical_Combining_Class=ccc36}', "");
Expect(0, 1810, '\P{^Canonical_Combining_Class=ccc36}', "");
Expect(1, 1809, '\p{Canonical_Combining_Class:	__ccc36}', "");
Expect(0, 1809, '\p{^Canonical_Combining_Class:	__ccc36}', "");
Expect(0, 1809, '\P{Canonical_Combining_Class:	__ccc36}', "");
Expect(1, 1809, '\P{^Canonical_Combining_Class:	__ccc36}', "");
Expect(0, 1810, '\p{Canonical_Combining_Class:	__ccc36}', "");
Expect(1, 1810, '\p{^Canonical_Combining_Class:	__ccc36}', "");
Expect(1, 1810, '\P{Canonical_Combining_Class:	__ccc36}', "");
Expect(0, 1810, '\P{^Canonical_Combining_Class:	__ccc36}', "");
Error('\p{Ccc=	:=0036}');
Error('\P{Ccc=	:=0036}');
Expect(1, 1809, '\p{Ccc=036}', "");
Expect(0, 1809, '\p{^Ccc=036}', "");
Expect(0, 1809, '\P{Ccc=036}', "");
Expect(1, 1809, '\P{^Ccc=036}', "");
Expect(0, 1810, '\p{Ccc=036}', "");
Expect(1, 1810, '\p{^Ccc=036}', "");
Expect(1, 1810, '\P{Ccc=036}', "");
Expect(0, 1810, '\P{^Ccc=036}', "");
Error('\p{Is_Canonical_Combining_Class= CCC36:=}');
Error('\P{Is_Canonical_Combining_Class= CCC36:=}');
Expect(1, 1809, '\p{Is_Canonical_Combining_Class=ccc36}', "");
Expect(0, 1809, '\p{^Is_Canonical_Combining_Class=ccc36}', "");
Expect(0, 1809, '\P{Is_Canonical_Combining_Class=ccc36}', "");
Expect(1, 1809, '\P{^Is_Canonical_Combining_Class=ccc36}', "");
Expect(0, 1810, '\p{Is_Canonical_Combining_Class=ccc36}', "");
Expect(1, 1810, '\p{^Is_Canonical_Combining_Class=ccc36}', "");
Expect(1, 1810, '\P{Is_Canonical_Combining_Class=ccc36}', "");
Expect(0, 1810, '\P{^Is_Canonical_Combining_Class=ccc36}', "");
Expect(1, 1809, '\p{Is_Canonical_Combining_Class= ccc36}', "");
Expect(0, 1809, '\p{^Is_Canonical_Combining_Class= ccc36}', "");
Expect(0, 1809, '\P{Is_Canonical_Combining_Class= ccc36}', "");
Expect(1, 1809, '\P{^Is_Canonical_Combining_Class= ccc36}', "");
Expect(0, 1810, '\p{Is_Canonical_Combining_Class= ccc36}', "");
Expect(1, 1810, '\p{^Is_Canonical_Combining_Class= ccc36}', "");
Expect(1, 1810, '\P{Is_Canonical_Combining_Class= ccc36}', "");
Expect(0, 1810, '\P{^Is_Canonical_Combining_Class= ccc36}', "");
Error('\p{Is_Ccc=- +036:=}');
Error('\P{Is_Ccc=- +036:=}');
Expect(1, 1809, '\p{Is_Ccc=+00003_6}', "");
Expect(0, 1809, '\p{^Is_Ccc=+00003_6}', "");
Expect(0, 1809, '\P{Is_Ccc=+00003_6}', "");
Expect(1, 1809, '\P{^Is_Ccc=+00003_6}', "");
Expect(0, 1810, '\p{Is_Ccc=+00003_6}', "");
Expect(1, 1810, '\p{^Is_Ccc=+00003_6}', "");
Expect(1, 1810, '\P{Is_Ccc=+00003_6}', "");
Expect(0, 1810, '\P{^Is_Ccc=+00003_6}', "");
Error('\p{Canonical_Combining_Class=	_CCC84:=}');
Error('\P{Canonical_Combining_Class=	_CCC84:=}');
Expect(1, 3157, '\p{Canonical_Combining_Class=ccc84}', "");
Expect(0, 3157, '\p{^Canonical_Combining_Class=ccc84}', "");
Expect(0, 3157, '\P{Canonical_Combining_Class=ccc84}', "");
Expect(1, 3157, '\P{^Canonical_Combining_Class=ccc84}', "");
Expect(0, 3158, '\p{Canonical_Combining_Class=ccc84}', "");
Expect(1, 3158, '\p{^Canonical_Combining_Class=ccc84}', "");
Expect(1, 3158, '\P{Canonical_Combining_Class=ccc84}', "");
Expect(0, 3158, '\P{^Canonical_Combining_Class=ccc84}', "");
Expect(1, 3157, '\p{Canonical_Combining_Class=-	CCC84}', "");
Expect(0, 3157, '\p{^Canonical_Combining_Class=-	CCC84}', "");
Expect(0, 3157, '\P{Canonical_Combining_Class=-	CCC84}', "");
Expect(1, 3157, '\P{^Canonical_Combining_Class=-	CCC84}', "");
Expect(0, 3158, '\p{Canonical_Combining_Class=-	CCC84}', "");
Expect(1, 3158, '\p{^Canonical_Combining_Class=-	CCC84}', "");
Expect(1, 3158, '\P{Canonical_Combining_Class=-	CCC84}', "");
Expect(0, 3158, '\P{^Canonical_Combining_Class=-	CCC84}', "");
Error('\p{Ccc=-	000084:=}');
Error('\P{Ccc=-	000084:=}');
Expect(1, 3157, '\p{Ccc=+00008_4}', "");
Expect(0, 3157, '\p{^Ccc=+00008_4}', "");
Expect(0, 3157, '\P{Ccc=+00008_4}', "");
Expect(1, 3157, '\P{^Ccc=+00008_4}', "");
Expect(0, 3158, '\p{Ccc=+00008_4}', "");
Expect(1, 3158, '\p{^Ccc=+00008_4}', "");
Expect(1, 3158, '\P{Ccc=+00008_4}', "");
Expect(0, 3158, '\P{^Ccc=+00008_4}', "");
Error('\p{Is_Canonical_Combining_Class: /a/_-CCC84}');
Error('\P{Is_Canonical_Combining_Class: /a/_-CCC84}');
Expect(1, 3157, '\p{Is_Canonical_Combining_Class=ccc84}', "");
Expect(0, 3157, '\p{^Is_Canonical_Combining_Class=ccc84}', "");
Expect(0, 3157, '\P{Is_Canonical_Combining_Class=ccc84}', "");
Expect(1, 3157, '\P{^Is_Canonical_Combining_Class=ccc84}', "");
Expect(0, 3158, '\p{Is_Canonical_Combining_Class=ccc84}', "");
Expect(1, 3158, '\p{^Is_Canonical_Combining_Class=ccc84}', "");
Expect(1, 3158, '\P{Is_Canonical_Combining_Class=ccc84}', "");
Expect(0, 3158, '\P{^Is_Canonical_Combining_Class=ccc84}', "");
Expect(1, 3157, '\p{Is_Canonical_Combining_Class=_CCC84}', "");
Expect(0, 3157, '\p{^Is_Canonical_Combining_Class=_CCC84}', "");
Expect(0, 3157, '\P{Is_Canonical_Combining_Class=_CCC84}', "");
Expect(1, 3157, '\P{^Is_Canonical_Combining_Class=_CCC84}', "");
Expect(0, 3158, '\p{Is_Canonical_Combining_Class=_CCC84}', "");
Expect(1, 3158, '\p{^Is_Canonical_Combining_Class=_CCC84}', "");
Expect(1, 3158, '\P{Is_Canonical_Combining_Class=_CCC84}', "");
Expect(0, 3158, '\P{^Is_Canonical_Combining_Class=_CCC84}', "");
Error('\p{Is_Ccc=:=- 000000084}');
Error('\P{Is_Ccc=:=- 000000084}');
Expect(1, 3157, '\p{Is_Ccc=000_000_008_4}', "");
Expect(0, 3157, '\p{^Is_Ccc=000_000_008_4}', "");
Expect(0, 3157, '\P{Is_Ccc=000_000_008_4}', "");
Expect(1, 3157, '\P{^Is_Ccc=000_000_008_4}', "");
Expect(0, 3158, '\p{Is_Ccc=000_000_008_4}', "");
Expect(1, 3158, '\p{^Is_Ccc=000_000_008_4}', "");
Expect(1, 3158, '\P{Is_Ccc=000_000_008_4}', "");
Expect(0, 3158, '\P{^Is_Ccc=000_000_008_4}', "");
Error('\p{Canonical_Combining_Class=/a/ -CCC91}');
Error('\P{Canonical_Combining_Class=/a/ -CCC91}');
Expect(1, 3158, '\p{Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\p{^Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\P{Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\P{^Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\p{Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\p{^Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\P{Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\P{^Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\p{Canonical_Combining_Class= _CCC91}', "");
Expect(0, 3158, '\p{^Canonical_Combining_Class= _CCC91}', "");
Expect(0, 3158, '\P{Canonical_Combining_Class= _CCC91}', "");
Expect(1, 3158, '\P{^Canonical_Combining_Class= _CCC91}', "");
Expect(0, 3159, '\p{Canonical_Combining_Class= _CCC91}', "");
Expect(1, 3159, '\p{^Canonical_Combining_Class= _CCC91}', "");
Expect(1, 3159, '\P{Canonical_Combining_Class= _CCC91}', "");
Expect(0, 3159, '\P{^Canonical_Combining_Class= _CCC91}', "");
Error('\p{Ccc=-+00000000091/a/}');
Error('\P{Ccc=-+00000000091/a/}');
Expect(1, 3158, '\p{Ccc=0_0_0_0_0_091}', "");
Expect(0, 3158, '\p{^Ccc=0_0_0_0_0_091}', "");
Expect(0, 3158, '\P{Ccc=0_0_0_0_0_091}', "");
Expect(1, 3158, '\P{^Ccc=0_0_0_0_0_091}', "");
Expect(0, 3159, '\p{Ccc=0_0_0_0_0_091}', "");
Expect(1, 3159, '\p{^Ccc=0_0_0_0_0_091}', "");
Expect(1, 3159, '\P{Ccc=0_0_0_0_0_091}', "");
Expect(0, 3159, '\P{^Ccc=0_0_0_0_0_091}', "");
Error('\p{Is_Canonical_Combining_Class= _CCC91:=}');
Error('\P{Is_Canonical_Combining_Class= _CCC91:=}');
Expect(1, 3158, '\p{Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\p{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3158, '\P{Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3158, '\P{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\p{Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\p{^Is_Canonical_Combining_Class=ccc91}', "");
Expect(1, 3159, '\P{Is_Canonical_Combining_Class=ccc91}', "");
Expect(0, 3159, '\P{^Is_Canonical_Combining_Class=ccc91}', "");
Error('\p{Is_Ccc= -+91:=}');
Error('\P{Is_Ccc= -+91:=}');
Expect(1, 3158, '\p{Is_Ccc=+000000091}', "");
Expect(0, 3158, '\p{^Is_Ccc=+000000091}', "");
Expect(0, 3158, '\P{Is_Ccc=+000000091}', "");
Expect(1, 3158, '\P{^Is_Ccc=+000000091}', "");
Expect(0, 3159, '\p{Is_Ccc=+000000091}', "");
Expect(1, 3159, '\p{^Is_Ccc=+000000091}', "");
Expect(1, 3159, '\P{Is_Ccc=+000000091}', "");
Expect(0, 3159, '\P{^Is_Ccc=+000000091}', "");
Error('\p{Canonical_Combining_Class= :=double_Above}');
Error('\P{Canonical_Combining_Class= :=double_Above}');
Expect(1, 7629, '\p{Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7629, '\p{^Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7629, '\P{Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7629, '\P{^Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7630, '\p{Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7630, '\p{^Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7630, '\P{Canonical_Combining_Class=doubleabove}', "");
Expect(0, 7630, '\P{^Canonical_Combining_Class=doubleabove}', "");
Expect(1, 7629, '\p{Canonical_Combining_Class= _double_ABOVE}', "");
Expect(0, 7629, '\p{^Canonical_Combining_Class= _double_ABOVE}', "");
Expect(0, 7629, '\P{Canonical_Combining_Class= _double_ABOVE}', "");
Expect(1, 7629, '\P{^Canonical_Combining_Class= _double_ABOVE}', "");
Expect(0, 7630, '\p{Canonical_Combining_Class= _double_ABOVE}', "");
Expect(1, 7630, '\p{^Canonical_Combining_Class= _double_ABOVE}', "");
Expect(1, 7630, '\P{Canonical_Combining_Class= _double_ABOVE}', "");
Expect(0, 7630, '\P{^Canonical_Combining_Class= _double_ABOVE}', "");
Error('\p{Ccc=_DA:=}');
Error('\P{Ccc=_DA:=}');
Expect(1, 7629, '\p{Ccc:da}', "");
Expect(0, 7629, '\p{^Ccc:da}', "");
Expect(0, 7629, '\P{Ccc:da}', "");
Expect(1, 7629, '\P{^Ccc:da}', "");
Expect(0, 7630, '\p{Ccc:da}', "");
Expect(1, 7630, '\p{^Ccc:da}', "");
Expect(1, 7630, '\P{Ccc:da}', "");
Expect(0, 7630, '\P{^Ccc:da}', "");
Expect(1, 7629, '\p{Ccc=_-DA}', "");
Expect(0, 7629, '\p{^Ccc=_-DA}', "");
Expect(0, 7629, '\P{Ccc=_-DA}', "");
Expect(1, 7629, '\P{^Ccc=_-DA}', "");
Expect(0, 7630, '\p{Ccc=_-DA}', "");
Expect(1, 7630, '\p{^Ccc=_-DA}', "");
Expect(1, 7630, '\P{Ccc=_-DA}', "");
Expect(0, 7630, '\P{^Ccc=_-DA}', "");
Error('\p{Is_Canonical_Combining_Class: -_0000000234/a/}');
Error('\P{Is_Canonical_Combining_Class: -_0000000234/a/}');
Expect(1, 7629, '\p{Is_Canonical_Combining_Class:+000000000234}', "");
Expect(0, 7629, '\p{^Is_Canonical_Combining_Class:+000000000234}', "");
Expect(0, 7629, '\P{Is_Canonical_Combining_Class:+000000000234}', "");
Expect(1, 7629, '\P{^Is_Canonical_Combining_Class:+000000000234}', "");
Expect(0, 7630, '\p{Is_Canonical_Combining_Class:+000000000234}', "");
Expect(1, 7630, '\p{^Is_Canonical_Combining_Class:+000000000234}', "");
Expect(1, 7630, '\P{Is_Canonical_Combining_Class:+000000000234}', "");
Expect(0, 7630, '\P{^Is_Canonical_Combining_Class:+000000000234}', "");
Error('\p{Is_Ccc: :=	Double_above}');
Error('\P{Is_Ccc: :=	Double_above}');
Expect(1, 7629, '\p{Is_Ccc=doubleabove}', "");
Expect(0, 7629, '\p{^Is_Ccc=doubleabove}', "");
Expect(0, 7629, '\P{Is_Ccc=doubleabove}', "");
Expect(1, 7629, '\P{^Is_Ccc=doubleabove}', "");
Expect(0, 7630, '\p{Is_Ccc=doubleabove}', "");
Expect(1, 7630, '\p{^Is_Ccc=doubleabove}', "");
Expect(1, 7630, '\P{Is_Ccc=doubleabove}', "");
Expect(0, 7630, '\P{^Is_Ccc=doubleabove}', "");
Expect(1, 7629, '\p{Is_Ccc:_double_Above}', "");
Expect(0, 7629, '\p{^Is_Ccc:_double_Above}', "");
Expect(0, 7629, '\P{Is_Ccc:_double_Above}', "");
Expect(1, 7629, '\P{^Is_Ccc:_double_Above}', "");
Expect(0, 7630, '\p{Is_Ccc:_double_Above}', "");
Expect(1, 7630, '\p{^Is_Ccc:_double_Above}', "");
Expect(1, 7630, '\P{Is_Ccc:_double_Above}', "");
Expect(0, 7630, '\P{^Is_Ccc:_double_Above}', "");
Error('\p{Canonical_Combining_Class=_Double_Below/a/}');
Error('\P{Canonical_Combining_Class=_Double_Below/a/}');
Expect(1, 7676, '\p{Canonical_Combining_Class:	doublebelow}', "");
Expect(0, 7676, '\p{^Canonical_Combining_Class:	doublebelow}', "");
Expect(0, 7676, '\P{Canonical_Combining_Class:	doublebelow}', "");
Expect(1, 7676, '\P{^Canonical_Combining_Class:	doublebelow}', "");
Expect(0, 7677, '\p{Canonical_Combining_Class:	doublebelow}', "");
Expect(1, 7677, '\p{^Canonical_Combining_Class:	doublebelow}', "");
Expect(1, 7677, '\P{Canonical_Combining_Class:	doublebelow}', "");
Expect(0, 7677, '\P{^Canonical_Combining_Class:	doublebelow}', "");
Expect(1, 7676, '\p{Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(0, 7676, '\p{^Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(0, 7676, '\P{Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(1, 7676, '\P{^Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(0, 7677, '\p{Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(1, 7677, '\p{^Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(1, 7677, '\P{Canonical_Combining_Class:   	 DOUBLE_below}', "");
Expect(0, 7677, '\P{^Canonical_Combining_Class:   	 DOUBLE_below}', "");
Error('\p{Ccc=-:=DB}');
Error('\P{Ccc=-:=DB}');
Expect(1, 7676, '\p{Ccc=db}', "");
Expect(0, 7676, '\p{^Ccc=db}', "");
Expect(0, 7676, '\P{Ccc=db}', "");
Expect(1, 7676, '\P{^Ccc=db}', "");
Expect(0, 7677, '\p{Ccc=db}', "");
Expect(1, 7677, '\p{^Ccc=db}', "");
Expect(1, 7677, '\P{Ccc=db}', "");
Expect(0, 7677, '\P{^Ccc=db}', "");
Expect(1, 7676, '\p{Ccc= DB}', "");
Expect(0, 7676, '\p{^Ccc= DB}', "");
Expect(0, 7676, '\P{Ccc= DB}', "");
Expect(1, 7676, '\P{^Ccc= DB}', "");
Expect(0, 7677, '\p{Ccc= DB}', "");
Expect(1, 7677, '\p{^Ccc= DB}', "");
Expect(1, 7677, '\P{Ccc= DB}', "");
Expect(0, 7677, '\P{^Ccc= DB}', "");
Error('\p{Is_Canonical_Combining_Class=_:=+0_0_0_0_0233}');
Error('\P{Is_Canonical_Combining_Class=_:=+0_0_0_0_0233}');
Expect(1, 7676, '\p{Is_Canonical_Combining_Class=23_3}', "");
Expect(0, 7676, '\p{^Is_Canonical_Combining_Class=23_3}', "");
Expect(0, 7676, '\P{Is_Canonical_Combining_Class=23_3}', "");
Expect(1, 7676, '\P{^Is_Canonical_Combining_Class=23_3}', "");
Expect(0, 7677, '\p{Is_Canonical_Combining_Class=23_3}', "");
Expect(1, 7677, '\p{^Is_Canonical_Combining_Class=23_3}', "");
Expect(1, 7677, '\P{Is_Canonical_Combining_Class=23_3}', "");
Expect(0, 7677, '\P{^Is_Canonical_Combining_Class=23_3}', "");
Error('\p{Is_Ccc=:=  double_Below}');
Error('\P{Is_Ccc=:=  double_Below}');
Expect(1, 7676, '\p{Is_Ccc=doublebelow}', "");
Expect(0, 7676, '\p{^Is_Ccc=doublebelow}', "");
Expect(0, 7676, '\P{Is_Ccc=doublebelow}', "");
Expect(1, 7676, '\P{^Is_Ccc=doublebelow}', "");
Expect(0, 7677, '\p{Is_Ccc=doublebelow}', "");
Expect(1, 7677, '\p{^Is_Ccc=doublebelow}', "");
Expect(1, 7677, '\P{Is_Ccc=doublebelow}', "");
Expect(0, 7677, '\P{^Is_Ccc=doublebelow}', "");
Expect(1, 7676, '\p{Is_Ccc=	DOUBLE_BELOW}', "");
Expect(0, 7676, '\p{^Is_Ccc=	DOUBLE_BELOW}', "");
Expect(0, 7676, '\P{Is_Ccc=	DOUBLE_BELOW}', "");
Expect(1, 7676, '\P{^Is_Ccc=	DOUBLE_BELOW}', "");
Expect(0, 7677, '\p{Is_Ccc=	DOUBLE_BELOW}', "");
Expect(1, 7677, '\p{^Is_Ccc=	DOUBLE_BELOW}', "");
Expect(1, 7677, '\P{Is_Ccc=	DOUBLE_BELOW}', "");
Expect(0, 7677, '\P{^Is_Ccc=	DOUBLE_BELOW}', "");
Error('\p{Canonical_Combining_Class=-:=Iota_subscript}');
Error('\P{Canonical_Combining_Class=-:=Iota_subscript}');
Expect(1, 837, '\p{Canonical_Combining_Class: iotasubscript}', "");
Expect(0, 837, '\p{^Canonical_Combining_Class: iotasubscript}', "");
Expect(0, 837, '\P{Canonical_Combining_Class: iotasubscript}', "");
Expect(1, 837, '\P{^Canonical_Combining_Class: iotasubscript}', "");
Expect(0, 838, '\p{Canonical_Combining_Class: iotasubscript}', "");
Expect(1, 838, '\p{^Canonical_Combining_Class: iotasubscript}', "");
Expect(1, 838, '\P{Canonical_Combining_Class: iotasubscript}', "");
Expect(0, 838, '\P{^Canonical_Combining_Class: iotasubscript}', "");
Expect(1, 837, '\p{Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(0, 837, '\p{^Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(0, 837, '\P{Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(1, 837, '\P{^Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(0, 838, '\p{Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(1, 838, '\p{^Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(1, 838, '\P{Canonical_Combining_Class=_ iota_Subscript}', "");
Expect(0, 838, '\P{^Canonical_Combining_Class=_ iota_Subscript}', "");
Error('\p{Ccc=:=__IS}');
Error('\P{Ccc=:=__IS}');
Expect(1, 837, '\p{Ccc=is}', "");
Expect(0, 837, '\p{^Ccc=is}', "");
Expect(0, 837, '\P{Ccc=is}', "");
Expect(1, 837, '\P{^Ccc=is}', "");
Expect(0, 838, '\p{Ccc=is}', "");
Expect(1, 838, '\p{^Ccc=is}', "");
Expect(1, 838, '\P{Ccc=is}', "");
Expect(0, 838, '\P{^Ccc=is}', "");
Expect(1, 837, '\p{Ccc= 	IS}', "");
Expect(0, 837, '\p{^Ccc= 	IS}', "");
Expect(0, 837, '\P{Ccc= 	IS}', "");
Expect(1, 837, '\P{^Ccc= 	IS}', "");
Expect(0, 838, '\p{Ccc= 	IS}', "");
Expect(1, 838, '\p{^Ccc= 	IS}', "");
Expect(1, 838, '\P{Ccc= 	IS}', "");
Expect(0, 838, '\P{^Ccc= 	IS}', "");
Error('\p{Is_Canonical_Combining_Class:	_:=+0_0_0_0_0240}');
Error('\P{Is_Canonical_Combining_Class:	_:=+0_0_0_0_0240}');
Expect(1, 837, '\p{Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(0, 837, '\p{^Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(0, 837, '\P{Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(1, 837, '\P{^Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(0, 838, '\p{Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(1, 838, '\p{^Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(1, 838, '\P{Is_Canonical_Combining_Class=+0_2_40}', "");
Expect(0, 838, '\P{^Is_Canonical_Combining_Class=+0_2_40}', "");
Error('\p{Is_Ccc=/a/ iota_Subscript}');
Error('\P{Is_Ccc=/a/ iota_Subscript}');
Expect(1, 837, '\p{Is_Ccc=iotasubscript}', "");
Expect(0, 837, '\p{^Is_Ccc=iotasubscript}', "");
Expect(0, 837, '\P{Is_Ccc=iotasubscript}', "");
Expect(1, 837, '\P{^Is_Ccc=iotasubscript}', "");
Expect(0, 838, '\p{Is_Ccc=iotasubscript}', "");
Expect(1, 838, '\p{^Is_Ccc=iotasubscript}', "");
Expect(1, 838, '\P{Is_Ccc=iotasubscript}', "");
Expect(0, 838, '\P{^Is_Ccc=iotasubscript}', "");
Expect(1, 837, '\p{Is_Ccc=Iota_Subscript}', "");
Expect(0, 837, '\p{^Is_Ccc=Iota_Subscript}', "");
Expect(0, 837, '\P{Is_Ccc=Iota_Subscript}', "");
Expect(1, 837, '\P{^Is_Ccc=Iota_Subscript}', "");
Expect(0, 838, '\p{Is_Ccc=Iota_Subscript}', "");
Expect(1, 838, '\p{^Is_Ccc=Iota_Subscript}', "");
Expect(1, 838, '\P{Is_Ccc=Iota_Subscript}', "");
Expect(0, 838, '\P{^Is_Ccc=Iota_Subscript}', "");
Error('\p{Canonical_Combining_Class:   /a/_-Kana_Voicing}');
Error('\P{Canonical_Combining_Class:   /a/_-Kana_Voicing}');
Expect(1, 12442, '\p{Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12442, '\p{^Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12442, '\P{Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12442, '\P{^Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12443, '\p{Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12443, '\p{^Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12443, '\P{Canonical_Combining_Class=kanavoicing}', "");
Expect(0, 12443, '\P{^Canonical_Combining_Class=kanavoicing}', "");
Expect(1, 12442, '\p{Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(0, 12442, '\p{^Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(0, 12442, '\P{Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(1, 12442, '\P{^Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(0, 12443, '\p{Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(1, 12443, '\p{^Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(1, 12443, '\P{Canonical_Combining_Class=_KANA_VOICING}', "");
Expect(0, 12443, '\P{^Canonical_Combining_Class=_KANA_VOICING}', "");
Error('\p{Ccc=	/a/KV}');
Error('\P{Ccc=	/a/KV}');
Expect(1, 12442, '\p{Ccc=kv}', "");
Expect(0, 12442, '\p{^Ccc=kv}', "");
Expect(0, 12442, '\P{Ccc=kv}', "");
Expect(1, 12442, '\P{^Ccc=kv}', "");
Expect(0, 12443, '\p{Ccc=kv}', "");
Expect(1, 12443, '\p{^Ccc=kv}', "");
Expect(1, 12443, '\P{Ccc=kv}', "");
Expect(0, 12443, '\P{^Ccc=kv}', "");
Expect(1, 12442, '\p{Ccc=_KV}', "");
Expect(0, 12442, '\p{^Ccc=_KV}', "");
Expect(0, 12442, '\P{Ccc=_KV}', "");
Expect(1, 12442, '\P{^Ccc=_KV}', "");
Expect(0, 12443, '\p{Ccc=_KV}', "");
Expect(1, 12443, '\p{^Ccc=_KV}', "");
Expect(1, 12443, '\P{Ccc=_KV}', "");
Expect(0, 12443, '\P{^Ccc=_KV}', "");
Error('\p{Is_Canonical_Combining_Class=_00_00_00_00_8/a/}');
Error('\P{Is_Canonical_Combining_Class=_00_00_00_00_8/a/}');
Expect(1, 12442, '\p{Is_Canonical_Combining_Class=0008}', "");
Expect(0, 12442, '\p{^Is_Canonical_Combining_Class=0008}', "");
Expect(0, 12442, '\P{Is_Canonical_Combining_Class=0008}', "");
Expect(1, 12442, '\P{^Is_Canonical_Combining_Class=0008}', "");
Expect(0, 12443, '\p{Is_Canonical_Combining_Class=0008}', "");
Expect(1, 12443, '\p{^Is_Canonical_Combining_Class=0008}', "");
Expect(1, 12443, '\P{Is_Canonical_Combining_Class=0008}', "");
Expect(0, 12443, '\P{^Is_Canonical_Combining_Class=0008}', "");
Error('\p{Is_Ccc=/a/- KANA_voicing}');
Error('\P{Is_Ccc=/a/- KANA_voicing}');
Expect(1, 12442, '\p{Is_Ccc=kanavoicing}', "");
Expect(0, 12442, '\p{^Is_Ccc=kanavoicing}', "");
Expect(0, 12442, '\P{Is_Ccc=kanavoicing}', "");
Expect(1, 12442, '\P{^Is_Ccc=kanavoicing}', "");
Expect(0, 12443, '\p{Is_Ccc=kanavoicing}', "");
Expect(1, 12443, '\p{^Is_Ccc=kanavoicing}', "");
Expect(1, 12443, '\P{Is_Ccc=kanavoicing}', "");
Expect(0, 12443, '\P{^Is_Ccc=kanavoicing}', "");
Expect(1, 12442, '\p{Is_Ccc:   _ kana_VOICING}', "");
Expect(0, 12442, '\p{^Is_Ccc:   _ kana_VOICING}', "");
Expect(0, 12442, '\P{Is_Ccc:   _ kana_VOICING}', "");
Expect(1, 12442, '\P{^Is_Ccc:   _ kana_VOICING}', "");
Expect(0, 12443, '\p{Is_Ccc:   _ kana_VOICING}', "");
Expect(1, 12443, '\p{^Is_Ccc:   _ kana_VOICING}', "");
Expect(1, 12443, '\P{Is_Ccc:   _ kana_VOICING}', "");
Expect(0, 12443, '\P{^Is_Ccc:   _ kana_VOICING}', "");
Error('\p{Canonical_Combining_Class=	LEFT/a/}');
Error('\P{Canonical_Combining_Class=	LEFT/a/}');
Expect(1, 12335, '\p{Canonical_Combining_Class=left}', "");
Expect(0, 12335, '\p{^Canonical_Combining_Class=left}', "");
Expect(0, 12335, '\P{Canonical_Combining_Class=left}', "");
Expect(1, 12335, '\P{^Canonical_Combining_Class=left}', "");
Expect(0, 12336, '\p{Canonical_Combining_Class=left}', "");
Expect(1, 12336, '\p{^Canonical_Combining_Class=left}', "");
Expect(1, 12336, '\P{Canonical_Combining_Class=left}', "");
Expect(0, 12336, '\P{^Canonical_Combining_Class=left}', "");
Expect(1, 12335, '\p{Canonical_Combining_Class=--LEFT}', "");
Expect(0, 12335, '\p{^Canonical_Combining_Class=--LEFT}', "");
Expect(0, 12335, '\P{Canonical_Combining_Class=--LEFT}', "");
Expect(1, 12335, '\P{^Canonical_Combining_Class=--LEFT}', "");
Expect(0, 12336, '\p{Canonical_Combining_Class=--LEFT}', "");
Expect(1, 12336, '\p{^Canonical_Combining_Class=--LEFT}', "");
Expect(1, 12336, '\P{Canonical_Combining_Class=--LEFT}', "");
Expect(0, 12336, '\P{^Canonical_Combining_Class=--LEFT}', "");
Error('\p{Ccc=:=- l}');
Error('\P{Ccc=:=- l}');
Expect(1, 12335, '\p{Ccc=l}', "");
Expect(0, 12335, '\p{^Ccc=l}', "");
Expect(0, 12335, '\P{Ccc=l}', "");
Expect(1, 12335, '\P{^Ccc=l}', "");
Expect(0, 12336, '\p{Ccc=l}', "");
Expect(1, 12336, '\p{^Ccc=l}', "");
Expect(1, 12336, '\P{Ccc=l}', "");
Expect(0, 12336, '\P{^Ccc=l}', "");
Expect(1, 12335, '\p{Ccc=_-L}', "");
Expect(0, 12335, '\p{^Ccc=_-L}', "");
Expect(0, 12335, '\P{Ccc=_-L}', "");
Expect(1, 12335, '\P{^Ccc=_-L}', "");
Expect(0, 12336, '\p{Ccc=_-L}', "");
Expect(1, 12336, '\p{^Ccc=_-L}', "");
Expect(1, 12336, '\P{Ccc=_-L}', "");
Expect(0, 12336, '\P{^Ccc=_-L}', "");
Error('\p{Is_Canonical_Combining_Class=/a/0000000022_4}');
Error('\P{Is_Canonical_Combining_Class=/a/0000000022_4}');
Expect(1, 12335, '\p{Is_Canonical_Combining_Class=+0224}', "");
Expect(0, 12335, '\p{^Is_Canonical_Combining_Class=+0224}', "");
Expect(0, 12335, '\P{Is_Canonical_Combining_Class=+0224}', "");
Expect(1, 12335, '\P{^Is_Canonical_Combining_Class=+0224}', "");
Expect(0, 12336, '\p{Is_Canonical_Combining_Class=+0224}', "");
Expect(1, 12336, '\p{^Is_Canonical_Combining_Class=+0224}', "");
Expect(1, 12336, '\P{Is_Canonical_Combining_Class=+0224}', "");
Expect(0, 12336, '\P{^Is_Canonical_Combining_Class=+0224}', "");
Error('\p{Is_Ccc=-:=Left}');
Error('\P{Is_Ccc=-:=Left}');
Expect(1, 12335, '\p{Is_Ccc=left}', "");
Expect(0, 12335, '\p{^Is_Ccc=left}', "");
Expect(0, 12335, '\P{Is_Ccc=left}', "");
Expect(1, 12335, '\P{^Is_Ccc=left}', "");
Expect(0, 12336, '\p{Is_Ccc=left}', "");
Expect(1, 12336, '\p{^Is_Ccc=left}', "");
Expect(1, 12336, '\P{Is_Ccc=left}', "");
Expect(0, 12336, '\P{^Is_Ccc=left}', "");
Expect(1, 12335, '\p{Is_Ccc=_ left}', "");
Expect(0, 12335, '\p{^Is_Ccc=_ left}', "");
Expect(0, 12335, '\P{Is_Ccc=_ left}', "");
Expect(1, 12335, '\P{^Is_Ccc=_ left}', "");
Expect(0, 12336, '\p{Is_Ccc=_ left}', "");
Expect(1, 12336, '\p{^Is_Ccc=_ left}', "");
Expect(1, 12336, '\P{Is_Ccc=_ left}', "");
Expect(0, 12336, '\P{^Is_Ccc=_ left}', "");
Error('\p{Canonical_Combining_Class= NUKTA/a/}');
Error('\P{Canonical_Combining_Class= NUKTA/a/}');
Expect(1, 71351, '\p{Canonical_Combining_Class=nukta}', "");
Expect(0, 71351, '\p{^Canonical_Combining_Class=nukta}', "");
Expect(0, 71351, '\P{Canonical_Combining_Class=nukta}', "");
Expect(1, 71351, '\P{^Canonical_Combining_Class=nukta}', "");
Expect(0, 71352, '\p{Canonical_Combining_Class=nukta}', "");
Expect(1, 71352, '\p{^Canonical_Combining_Class=nukta}', "");
Expect(1, 71352, '\P{Canonical_Combining_Class=nukta}', "");
Expect(0, 71352, '\P{^Canonical_Combining_Class=nukta}', "");
Expect(1, 71351, '\p{Canonical_Combining_Class=NUKTA}', "");
Expect(0, 71351, '\p{^Canonical_Combining_Class=NUKTA}', "");
Expect(0, 71351, '\P{Canonical_Combining_Class=NUKTA}', "");
Expect(1, 71351, '\P{^Canonical_Combining_Class=NUKTA}', "");
Expect(0, 71352, '\p{Canonical_Combining_Class=NUKTA}', "");
Expect(1, 71352, '\p{^Canonical_Combining_Class=NUKTA}', "");
Expect(1, 71352, '\P{Canonical_Combining_Class=NUKTA}', "");
Expect(0, 71352, '\P{^Canonical_Combining_Class=NUKTA}', "");
Error('\p{Ccc=:=	 NK}');
Error('\P{Ccc=:=	 NK}');
Expect(1, 71351, '\p{Ccc=nk}', "");
Expect(0, 71351, '\p{^Ccc=nk}', "");
Expect(0, 71351, '\P{Ccc=nk}', "");
Expect(1, 71351, '\P{^Ccc=nk}', "");
Expect(0, 71352, '\p{Ccc=nk}', "");
Expect(1, 71352, '\p{^Ccc=nk}', "");
Expect(1, 71352, '\P{Ccc=nk}', "");
Expect(0, 71352, '\P{^Ccc=nk}', "");
Expect(1, 71351, '\p{Ccc=  nk}', "");
Expect(0, 71351, '\p{^Ccc=  nk}', "");
Expect(0, 71351, '\P{Ccc=  nk}', "");
Expect(1, 71351, '\P{^Ccc=  nk}', "");
Expect(0, 71352, '\p{Ccc=  nk}', "");
Expect(1, 71352, '\p{^Ccc=  nk}', "");
Expect(1, 71352, '\P{Ccc=  nk}', "");
Expect(0, 71352, '\P{^Ccc=  nk}', "");
Error('\p{Is_Canonical_Combining_Class=	/a/+000_7}');
Error('\P{Is_Canonical_Combining_Class=	/a/+000_7}');
Expect(1, 71351, '\p{Is_Canonical_Combining_Class=+0007}', "");
Expect(0, 71351, '\p{^Is_Canonical_Combining_Class=+0007}', "");
Expect(0, 71351, '\P{Is_Canonical_Combining_Class=+0007}', "");
Expect(1, 71351, '\P{^Is_Canonical_Combining_Class=+0007}', "");
Expect(0, 71352, '\p{Is_Canonical_Combining_Class=+0007}', "");
Expect(1, 71352, '\p{^Is_Canonical_Combining_Class=+0007}', "");
Expect(1, 71352, '\P{Is_Canonical_Combining_Class=+0007}', "");
Expect(0, 71352, '\P{^Is_Canonical_Combining_Class=+0007}', "");
Error('\p{Is_Ccc=_/a/nukta}');
Error('\P{Is_Ccc=_/a/nukta}');
Expect(1, 71351, '\p{Is_Ccc=nukta}', "");
Expect(0, 71351, '\p{^Is_Ccc=nukta}', "");
Expect(0, 71351, '\P{Is_Ccc=nukta}', "");
Expect(1, 71351, '\P{^Is_Ccc=nukta}', "");
Expect(0, 71352, '\p{Is_Ccc=nukta}', "");
Expect(1, 71352, '\p{^Is_Ccc=nukta}', "");
Expect(1, 71352, '\P{Is_Ccc=nukta}', "");
Expect(0, 71352, '\P{^Is_Ccc=nukta}', "");
Expect(1, 71351, '\p{Is_Ccc= -Nukta}', "");
Expect(0, 71351, '\p{^Is_Ccc= -Nukta}', "");
Expect(0, 71351, '\P{Is_Ccc= -Nukta}', "");
Expect(1, 71351, '\P{^Is_Ccc= -Nukta}', "");
Expect(0, 71352, '\p{Is_Ccc= -Nukta}', "");
Expect(1, 71352, '\p{^Is_Ccc= -Nukta}', "");
Expect(1, 71352, '\P{Is_Ccc= -Nukta}', "");
Expect(0, 71352, '\P{^Is_Ccc= -Nukta}', "");
Error('\p{Canonical_Combining_Class=/a/-NOT_Reordered}');
Error('\P{Canonical_Combining_Class=/a/-NOT_Reordered}');
Expect(1, 119365, '\p{Canonical_Combining_Class=notreordered}', "");
Expect(0, 119365, '\p{^Canonical_Combining_Class=notreordered}', "");
Expect(0, 119365, '\P{Canonical_Combining_Class=notreordered}', "");
Expect(1, 119365, '\P{^Canonical_Combining_Class=notreordered}', "");
Expect(0, 119364, '\p{Canonical_Combining_Class=notreordered}', "");
Expect(1, 119364, '\p{^Canonical_Combining_Class=notreordered}', "");
Expect(1, 119364, '\P{Canonical_Combining_Class=notreordered}', "");
Expect(0, 119364, '\P{^Canonical_Combining_Class=notreordered}', "");
Expect(1, 119365, '\p{Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(0, 119365, '\p{^Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(0, 119365, '\P{Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(1, 119365, '\P{^Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(0, 119364, '\p{Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(1, 119364, '\p{^Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(1, 119364, '\P{Canonical_Combining_Class=  NOT_REORDERED}', "");
Expect(0, 119364, '\P{^Canonical_Combining_Class=  NOT_REORDERED}', "");
Error('\p{Ccc:	  NR/a/}');
Error('\P{Ccc:	  NR/a/}');
Expect(1, 119365, '\p{Ccc=nr}', "");
Expect(0, 119365, '\p{^Ccc=nr}', "");
Expect(0, 119365, '\P{Ccc=nr}', "");
Expect(1, 119365, '\P{^Ccc=nr}', "");
Expect(0, 119364, '\p{Ccc=nr}', "");
Expect(1, 119364, '\p{^Ccc=nr}', "");
Expect(1, 119364, '\P{Ccc=nr}', "");
Expect(0, 119364, '\P{^Ccc=nr}', "");
Expect(1, 119365, '\p{Ccc:-NR}', "");
Expect(0, 119365, '\p{^Ccc:-NR}', "");
Expect(0, 119365, '\P{Ccc:-NR}', "");
Expect(1, 119365, '\P{^Ccc:-NR}', "");
Expect(0, 119364, '\p{Ccc:-NR}', "");
Expect(1, 119364, '\p{^Ccc:-NR}', "");
Expect(1, 119364, '\P{Ccc:-NR}', "");
Expect(0, 119364, '\P{^Ccc:-NR}', "");
Error('\p{Is_Canonical_Combining_Class:   :=_+0_0}');
Error('\P{Is_Canonical_Combining_Class:   :=_+0_0}');
Expect(1, 119365, '\p{Is_Canonical_Combining_Class=+00000}', "");
Expect(0, 119365, '\p{^Is_Canonical_Combining_Class=+00000}', "");
Expect(0, 119365, '\P{Is_Canonical_Combining_Class=+00000}', "");
Expect(1, 119365, '\P{^Is_Canonical_Combining_Class=+00000}', "");
Expect(0, 119364, '\p{Is_Canonical_Combining_Class=+00000}', "");
Expect(1, 119364, '\p{^Is_Canonical_Combining_Class=+00000}', "");
Expect(1, 119364, '\P{Is_Canonical_Combining_Class=+00000}', "");
Expect(0, 119364, '\P{^Is_Canonical_Combining_Class=+00000}', "");
Error('\p{Is_Ccc=:=-NOT_Reordered}');
Error('\P{Is_Ccc=:=-NOT_Reordered}');
Expect(1, 119365, '\p{Is_Ccc=notreordered}', "");
Expect(0, 119365, '\p{^Is_Ccc=notreordered}', "");
Expect(0, 119365, '\P{Is_Ccc=notreordered}', "");
Expect(1, 119365, '\P{^Is_Ccc=notreordered}', "");
Expect(0, 119364, '\p{Is_Ccc=notreordered}', "");
Expect(1, 119364, '\p{^Is_Ccc=notreordered}', "");
Expect(1, 119364, '\P{Is_Ccc=notreordered}', "");
Expect(0, 119364, '\P{^Is_Ccc=notreordered}', "");
Expect(1, 119365, '\p{Is_Ccc:	  not_REORDERED}', "");
Expect(0, 119365, '\p{^Is_Ccc:	  not_REORDERED}', "");
Expect(0, 119365, '\P{Is_Ccc:	  not_REORDERED}', "");
Expect(1, 119365, '\P{^Is_Ccc:	  not_REORDERED}', "");
Expect(0, 119364, '\p{Is_Ccc:	  not_REORDERED}', "");
Expect(1, 119364, '\p{^Is_Ccc:	  not_REORDERED}', "");
Expect(1, 119364, '\P{Is_Ccc:	  not_REORDERED}', "");
Expect(0, 119364, '\P{^Is_Ccc:	  not_REORDERED}', "");
Error('\p{Canonical_Combining_Class= :=Overlay}');
Error('\P{Canonical_Combining_Class= :=Overlay}');
Expect(1, 119145, '\p{Canonical_Combining_Class=overlay}', "");
Expect(0, 119145, '\p{^Canonical_Combining_Class=overlay}', "");
Expect(0, 119145, '\P{Canonical_Combining_Class=overlay}', "");
Expect(1, 119145, '\P{^Canonical_Combining_Class=overlay}', "");
Expect(0, 119146, '\p{Canonical_Combining_Class=overlay}', "");
Expect(1, 119146, '\p{^Canonical_Combining_Class=overlay}', "");
Expect(1, 119146, '\P{Canonical_Combining_Class=overlay}', "");
Expect(0, 119146, '\P{^Canonical_Combining_Class=overlay}', "");
Expect(1, 119145, '\p{Canonical_Combining_Class=	-OVERLAY}', "");
Expect(0, 119145, '\p{^Canonical_Combining_Class=	-OVERLAY}', "");
Expect(0, 119145, '\P{Canonical_Combining_Class=	-OVERLAY}', "");
Expect(1, 119145, '\P{^Canonical_Combining_Class=	-OVERLAY}', "");
Expect(0, 119146, '\p{Canonical_Combining_Class=	-OVERLAY}', "");
Expect(1, 119146, '\p{^Canonical_Combining_Class=	-OVERLAY}', "");
Expect(1, 119146, '\P{Canonical_Combining_Class=	-OVERLAY}', "");
Expect(0, 119146, '\P{^Canonical_Combining_Class=	-OVERLAY}', "");
Error('\p{Ccc=	/a/OV}');
Error('\P{Ccc=	/a/OV}');
Expect(1, 119145, '\p{Ccc=ov}', "");
Expect(0, 119145, '\p{^Ccc=ov}', "");
Expect(0, 119145, '\P{Ccc=ov}', "");
Expect(1, 119145, '\P{^Ccc=ov}', "");
Expect(0, 119146, '\p{Ccc=ov}', "");
Expect(1, 119146, '\p{^Ccc=ov}', "");
Expect(1, 119146, '\P{Ccc=ov}', "");
Expect(0, 119146, '\P{^Ccc=ov}', "");
Expect(1, 119145, '\p{Ccc=_ ov}', "");
Expect(0, 119145, '\p{^Ccc=_ ov}', "");
Expect(0, 119145, '\P{Ccc=_ ov}', "");
Expect(1, 119145, '\P{^Ccc=_ ov}', "");
Expect(0, 119146, '\p{Ccc=_ ov}', "");
Expect(1, 119146, '\p{^Ccc=_ ov}', "");
Expect(1, 119146, '\P{Ccc=_ ov}', "");
Expect(0, 119146, '\P{^Ccc=_ ov}', "");
Error('\p{Is_Canonical_Combining_Class=__+000_000_000_1:=}');
Error('\P{Is_Canonical_Combining_Class=__+000_000_000_1:=}');
Expect(1, 119145, '\p{Is_Canonical_Combining_Class=1}', "");
Expect(0, 119145, '\p{^Is_Canonical_Combining_Class=1}', "");
Expect(0, 119145, '\P{Is_Canonical_Combining_Class=1}', "");
Expect(1, 119145, '\P{^Is_Canonical_Combining_Class=1}', "");
Expect(0, 119146, '\p{Is_Canonical_Combining_Class=1}', "");
Expect(1, 119146, '\p{^Is_Canonical_Combining_Class=1}', "");
Expect(1, 119146, '\P{Is_Canonical_Combining_Class=1}', "");
Expect(0, 119146, '\P{^Is_Canonical_Combining_Class=1}', "");
Error('\p{Is_Ccc=:= overlay}');
Error('\P{Is_Ccc=:= overlay}');
Expect(1, 119145, '\p{Is_Ccc=overlay}', "");
Expect(0, 119145, '\p{^Is_Ccc=overlay}', "");
Expect(0, 119145, '\P{Is_Ccc=overlay}', "");
Expect(1, 119145, '\P{^Is_Ccc=overlay}', "");
Expect(0, 119146, '\p{Is_Ccc=overlay}', "");
Expect(1, 119146, '\p{^Is_Ccc=overlay}', "");
Expect(1, 119146, '\P{Is_Ccc=overlay}', "");
Expect(0, 119146, '\P{^Is_Ccc=overlay}', "");
Expect(1, 119145, '\p{Is_Ccc= 	overlay}', "");
Expect(0, 119145, '\p{^Is_Ccc= 	overlay}', "");
Expect(0, 119145, '\P{Is_Ccc= 	overlay}', "");
Expect(1, 119145, '\P{^Is_Ccc= 	overlay}', "");
Expect(0, 119146, '\p{Is_Ccc= 	overlay}', "");
Expect(1, 119146, '\p{^Is_Ccc= 	overlay}', "");
Expect(1, 119146, '\P{Is_Ccc= 	overlay}', "");
Expect(0, 119146, '\P{^Is_Ccc= 	overlay}', "");
Error('\p{Canonical_Combining_Class=/a/_RIGHT}');
Error('\P{Canonical_Combining_Class=/a/_RIGHT}');
Expect(1, 119149, '\p{Canonical_Combining_Class: right}', "");
Expect(0, 119149, '\p{^Canonical_Combining_Class: right}', "");
Expect(0, 119149, '\P{Canonical_Combining_Class: right}', "");
Expect(1, 119149, '\P{^Canonical_Combining_Class: right}', "");
Expect(0, 119150, '\p{Canonical_Combining_Class: right}', "");
Expect(1, 119150, '\p{^Canonical_Combining_Class: right}', "");
Expect(1, 119150, '\P{Canonical_Combining_Class: right}', "");
Expect(0, 119150, '\P{^Canonical_Combining_Class: right}', "");
Expect(1, 119149, '\p{Canonical_Combining_Class=--right}', "");
Expect(0, 119149, '\p{^Canonical_Combining_Class=--right}', "");
Expect(0, 119149, '\P{Canonical_Combining_Class=--right}', "");
Expect(1, 119149, '\P{^Canonical_Combining_Class=--right}', "");
Expect(0, 119150, '\p{Canonical_Combining_Class=--right}', "");
Expect(1, 119150, '\p{^Canonical_Combining_Class=--right}', "");
Expect(1, 119150, '\P{Canonical_Combining_Class=--right}', "");
Expect(0, 119150, '\P{^Canonical_Combining_Class=--right}', "");
Error('\p{Ccc= :=R}');
Error('\P{Ccc= :=R}');
Expect(1, 119149, '\p{Ccc=r}', "");
Expect(0, 119149, '\p{^Ccc=r}', "");
Expect(0, 119149, '\P{Ccc=r}', "");
Expect(1, 119149, '\P{^Ccc=r}', "");
Expect(0, 119150, '\p{Ccc=r}', "");
Expect(1, 119150, '\p{^Ccc=r}', "");
Expect(1, 119150, '\P{Ccc=r}', "");
Expect(0, 119150, '\P{^Ccc=r}', "");
Expect(1, 119149, '\p{Ccc=_ R}', "");
Expect(0, 119149, '\p{^Ccc=_ R}', "");
Expect(0, 119149, '\P{Ccc=_ R}', "");
Expect(1, 119149, '\P{^Ccc=_ R}', "");
Expect(0, 119150, '\p{Ccc=_ R}', "");
Expect(1, 119150, '\p{^Ccc=_ R}', "");
Expect(1, 119150, '\P{Ccc=_ R}', "");
Expect(0, 119150, '\P{^Ccc=_ R}', "");
Error('\p{Is_Canonical_Combining_Class=	000000000226/a/}');
Error('\P{Is_Canonical_Combining_Class=	000000000226/a/}');
Expect(1, 119149, '\p{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(0, 119149, '\p{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(0, 119149, '\P{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(1, 119149, '\P{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(0, 119150, '\p{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(1, 119150, '\p{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(1, 119150, '\P{Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Expect(0, 119150, '\P{^Is_Canonical_Combining_Class=0_0_0_0_0_0_0_226}', "");
Error('\p{Is_Ccc:  :=right}');
Error('\P{Is_Ccc:  :=right}');
Expect(1, 119149, '\p{Is_Ccc=right}', "");
Expect(0, 119149, '\p{^Is_Ccc=right}', "");
Expect(0, 119149, '\P{Is_Ccc=right}', "");
Expect(1, 119149, '\P{^Is_Ccc=right}', "");
Expect(0, 119150, '\p{Is_Ccc=right}', "");
Expect(1, 119150, '\p{^Is_Ccc=right}', "");
Expect(1, 119150, '\P{Is_Ccc=right}', "");
Expect(0, 119150, '\P{^Is_Ccc=right}', "");
Expect(1, 119149, '\p{Is_Ccc=- Right}', "");
Expect(0, 119149, '\p{^Is_Ccc=- Right}', "");
Expect(0, 119149, '\P{Is_Ccc=- Right}', "");
Expect(1, 119149, '\P{^Is_Ccc=- Right}', "");
Expect(0, 119150, '\p{Is_Ccc=- Right}', "");
Expect(1, 119150, '\p{^Is_Ccc=- Right}', "");
Expect(1, 119150, '\P{Is_Ccc=- Right}', "");
Expect(0, 119150, '\P{^Is_Ccc=- Right}', "");
Error('\p{Canonical_Combining_Class=	-Virama/a/}');
Error('\P{Canonical_Combining_Class=	-Virama/a/}');
Expect(1, 71350, '\p{Canonical_Combining_Class=virama}', "");
Expect(0, 71350, '\p{^Canonical_Combining_Class=virama}', "");
Expect(0, 71350, '\P{Canonical_Combining_Class=virama}', "");
Expect(1, 71350, '\P{^Canonical_Combining_Class=virama}', "");
Expect(0, 71351, '\p{Canonical_Combining_Class=virama}', "");
Expect(1, 71351, '\p{^Canonical_Combining_Class=virama}', "");
Expect(1, 71351, '\P{Canonical_Combining_Class=virama}', "");
Expect(0, 71351, '\P{^Canonical_Combining_Class=virama}', "");
Expect(1, 71350, '\p{Canonical_Combining_Class=_Virama}', "");
Expect(0, 71350, '\p{^Canonical_Combining_Class=_Virama}', "");
Expect(0, 71350, '\P{Canonical_Combining_Class=_Virama}', "");
Expect(1, 71350, '\P{^Canonical_Combining_Class=_Virama}', "");
Expect(0, 71351, '\p{Canonical_Combining_Class=_Virama}', "");
Expect(1, 71351, '\p{^Canonical_Combining_Class=_Virama}', "");
Expect(1, 71351, '\P{Canonical_Combining_Class=_Virama}', "");
Expect(0, 71351, '\P{^Canonical_Combining_Class=_Virama}', "");
Error('\p{Ccc=	-VR:=}');
Error('\P{Ccc=	-VR:=}');
Expect(1, 71350, '\p{Ccc=vr}', "");
Expect(0, 71350, '\p{^Ccc=vr}', "");
Expect(0, 71350, '\P{Ccc=vr}', "");
Expect(1, 71350, '\P{^Ccc=vr}', "");
Expect(0, 71351, '\p{Ccc=vr}', "");
Expect(1, 71351, '\p{^Ccc=vr}', "");
Expect(1, 71351, '\P{Ccc=vr}', "");
Expect(0, 71351, '\P{^Ccc=vr}', "");
Expect(1, 71350, '\p{Ccc=	 VR}', "");
Expect(0, 71350, '\p{^Ccc=	 VR}', "");
Expect(0, 71350, '\P{Ccc=	 VR}', "");
Expect(1, 71350, '\P{^Ccc=	 VR}', "");
Expect(0, 71351, '\p{Ccc=	 VR}', "");
Expect(1, 71351, '\p{^Ccc=	 VR}', "");
Expect(1, 71351, '\P{Ccc=	 VR}', "");
Expect(0, 71351, '\P{^Ccc=	 VR}', "");
Error('\p{Is_Canonical_Combining_Class=_-0009:=}');
Error('\P{Is_Canonical_Combining_Class=_-0009:=}');
Expect(1, 71350, '\p{Is_Canonical_Combining_Class=+0009}', "");
Expect(0, 71350, '\p{^Is_Canonical_Combining_Class=+0009}', "");
Expect(0, 71350, '\P{Is_Canonical_Combining_Class=+0009}', "");
Expect(1, 71350, '\P{^Is_Canonical_Combining_Class=+0009}', "");
Expect(0, 71351, '\p{Is_Canonical_Combining_Class=+0009}', "");
Expect(1, 71351, '\p{^Is_Canonical_Combining_Class=+0009}', "");
Expect(1, 71351, '\P{Is_Canonical_Combining_Class=+0009}', "");
Expect(0, 71351, '\P{^Is_Canonical_Combining_Class=+0009}', "");
Error('\p{Is_Ccc=-VIRAMA/a/}');
Error('\P{Is_Ccc=-VIRAMA/a/}');
Expect(1, 71350, '\p{Is_Ccc=virama}', "");
Expect(0, 71350, '\p{^Is_Ccc=virama}', "");
Expect(0, 71350, '\P{Is_Ccc=virama}', "");
Expect(1, 71350, '\P{^Is_Ccc=virama}', "");
Expect(0, 71351, '\p{Is_Ccc=virama}', "");
Expect(1, 71351, '\p{^Is_Ccc=virama}', "");
Expect(1, 71351, '\P{Is_Ccc=virama}', "");
Expect(0, 71351, '\P{^Is_Ccc=virama}', "");
Expect(1, 71350, '\p{Is_Ccc=__Virama}', "");
Expect(0, 71350, '\p{^Is_Ccc=__Virama}', "");
Expect(0, 71350, '\P{Is_Ccc=__Virama}', "");
Expect(1, 71350, '\P{^Is_Ccc=__Virama}', "");
Expect(0, 71351, '\p{Is_Ccc=__Virama}', "");
Expect(1, 71351, '\p{^Is_Ccc=__Virama}', "");
Expect(1, 71351, '\P{Is_Ccc=__Virama}', "");
Expect(0, 71351, '\P{^Is_Ccc=__Virama}', "");
Error('\p{Decomposition_Type=/a/canonical}');
Error('\P{Decomposition_Type=/a/canonical}');
Expect(1, 195101, '\p{Decomposition_Type=canonical}', "");
Expect(0, 195101, '\p{^Decomposition_Type=canonical}', "");
Expect(0, 195101, '\P{Decomposition_Type=canonical}', "");
Expect(1, 195101, '\P{^Decomposition_Type=canonical}', "");
Expect(0, 195102, '\p{Decomposition_Type=canonical}', "");
Expect(1, 195102, '\p{^Decomposition_Type=canonical}', "");
Expect(1, 195102, '\P{Decomposition_Type=canonical}', "");
Expect(0, 195102, '\P{^Decomposition_Type=canonical}', "");
Expect(1, 195101, '\p{Decomposition_Type=_ canonical}', "");
Expect(0, 195101, '\p{^Decomposition_Type=_ canonical}', "");
Expect(0, 195101, '\P{Decomposition_Type=_ canonical}', "");
Expect(1, 195101, '\P{^Decomposition_Type=_ canonical}', "");
Expect(0, 195102, '\p{Decomposition_Type=_ canonical}', "");
Expect(1, 195102, '\p{^Decomposition_Type=_ canonical}', "");
Expect(1, 195102, '\P{Decomposition_Type=_ canonical}', "");
Expect(0, 195102, '\P{^Decomposition_Type=_ canonical}', "");
Error('\p{Dt=/a/Can}');
Error('\P{Dt=/a/Can}');
Expect(1, 195101, '\p{Dt=can}', "");
Expect(0, 195101, '\p{^Dt=can}', "");
Expect(0, 195101, '\P{Dt=can}', "");
Expect(1, 195101, '\P{^Dt=can}', "");
Expect(0, 195102, '\p{Dt=can}', "");
Expect(1, 195102, '\p{^Dt=can}', "");
Expect(1, 195102, '\P{Dt=can}', "");
Expect(0, 195102, '\P{^Dt=can}', "");
Expect(1, 195101, '\p{Dt=-Can}', "");
Expect(0, 195101, '\p{^Dt=-Can}', "");
Expect(0, 195101, '\P{Dt=-Can}', "");
Expect(1, 195101, '\P{^Dt=-Can}', "");
Expect(0, 195102, '\p{Dt=-Can}', "");
Expect(1, 195102, '\p{^Dt=-Can}', "");
Expect(1, 195102, '\P{Dt=-Can}', "");
Expect(0, 195102, '\P{^Dt=-Can}', "");
Error('\p{Is_Decomposition_Type=:=__Canonical}');
Error('\P{Is_Decomposition_Type=:=__Canonical}');
Expect(1, 195101, '\p{Is_Decomposition_Type=canonical}', "");
Expect(0, 195101, '\p{^Is_Decomposition_Type=canonical}', "");
Expect(0, 195101, '\P{Is_Decomposition_Type=canonical}', "");
Expect(1, 195101, '\P{^Is_Decomposition_Type=canonical}', "");
Expect(0, 195102, '\p{Is_Decomposition_Type=canonical}', "");
Expect(1, 195102, '\p{^Is_Decomposition_Type=canonical}', "");
Expect(1, 195102, '\P{Is_Decomposition_Type=canonical}', "");
Expect(0, 195102, '\P{^Is_Decomposition_Type=canonical}', "");
Expect(1, 195101, '\p{Is_Decomposition_Type=--CANONICAL}', "");
Expect(0, 195101, '\p{^Is_Decomposition_Type=--CANONICAL}', "");
Expect(0, 195101, '\P{Is_Decomposition_Type=--CANONICAL}', "");
Expect(1, 195101, '\P{^Is_Decomposition_Type=--CANONICAL}', "");
Expect(0, 195102, '\p{Is_Decomposition_Type=--CANONICAL}', "");
Expect(1, 195102, '\p{^Is_Decomposition_Type=--CANONICAL}', "");
Expect(1, 195102, '\P{Is_Decomposition_Type=--CANONICAL}', "");
Expect(0, 195102, '\P{^Is_Decomposition_Type=--CANONICAL}', "");
Error('\p{Is_Dt: CAN/a/}');
Error('\P{Is_Dt: CAN/a/}');
Expect(1, 195101, '\p{Is_Dt=can}', "");
Expect(0, 195101, '\p{^Is_Dt=can}', "");
Expect(0, 195101, '\P{Is_Dt=can}', "");
Expect(1, 195101, '\P{^Is_Dt=can}', "");
Expect(0, 195102, '\p{Is_Dt=can}', "");
Expect(1, 195102, '\p{^Is_Dt=can}', "");
Expect(1, 195102, '\P{Is_Dt=can}', "");
Expect(0, 195102, '\P{^Is_Dt=can}', "");
Expect(1, 195101, '\p{Is_Dt=_	Can}', "");
Expect(0, 195101, '\p{^Is_Dt=_	Can}', "");
Expect(0, 195101, '\P{Is_Dt=_	Can}', "");
Expect(1, 195101, '\P{^Is_Dt=_	Can}', "");
Expect(0, 195102, '\p{Is_Dt=_	Can}', "");
Expect(1, 195102, '\p{^Is_Dt=_	Can}', "");
Expect(1, 195102, '\P{Is_Dt=_	Can}', "");
Expect(0, 195102, '\P{^Is_Dt=_	Can}', "");
Error('\p{Decomposition_Type=	/a/Compat}');
Error('\P{Decomposition_Type=	/a/Compat}');
Expect(1, 127560, '\p{Decomposition_Type=compat}', "");
Expect(0, 127560, '\p{^Decomposition_Type=compat}', "");
Expect(0, 127560, '\P{Decomposition_Type=compat}', "");
Expect(1, 127560, '\P{^Decomposition_Type=compat}', "");
Expect(0, 127561, '\p{Decomposition_Type=compat}', "");
Expect(1, 127561, '\p{^Decomposition_Type=compat}', "");
Expect(1, 127561, '\P{Decomposition_Type=compat}', "");
Expect(0, 127561, '\P{^Decomposition_Type=compat}', "");
Expect(1, 127560, '\p{Decomposition_Type= -COMPAT}', "");
Expect(0, 127560, '\p{^Decomposition_Type= -COMPAT}', "");
Expect(0, 127560, '\P{Decomposition_Type= -COMPAT}', "");
Expect(1, 127560, '\P{^Decomposition_Type= -COMPAT}', "");
Expect(0, 127561, '\p{Decomposition_Type= -COMPAT}', "");
Expect(1, 127561, '\p{^Decomposition_Type= -COMPAT}', "");
Expect(1, 127561, '\P{Decomposition_Type= -COMPAT}', "");
Expect(0, 127561, '\P{^Decomposition_Type= -COMPAT}', "");
Error('\p{Dt=:=-Com}');
Error('\P{Dt=:=-Com}');
Expect(1, 127560, '\p{Dt=com}', "");
Expect(0, 127560, '\p{^Dt=com}', "");
Expect(0, 127560, '\P{Dt=com}', "");
Expect(1, 127560, '\P{^Dt=com}', "");
Expect(0, 127561, '\p{Dt=com}', "");
Expect(1, 127561, '\p{^Dt=com}', "");
Expect(1, 127561, '\P{Dt=com}', "");
Expect(0, 127561, '\P{^Dt=com}', "");
Expect(1, 127560, '\p{Dt:   _-Com}', "");
Expect(0, 127560, '\p{^Dt:   _-Com}', "");
Expect(0, 127560, '\P{Dt:   _-Com}', "");
Expect(1, 127560, '\P{^Dt:   _-Com}', "");
Expect(0, 127561, '\p{Dt:   _-Com}', "");
Expect(1, 127561, '\p{^Dt:   _-Com}', "");
Expect(1, 127561, '\P{Dt:   _-Com}', "");
Expect(0, 127561, '\P{^Dt:   _-Com}', "");
Error('\p{Is_Decomposition_Type=:=	-compat}');
Error('\P{Is_Decomposition_Type=:=	-compat}');
Expect(1, 127560, '\p{Is_Decomposition_Type=compat}', "");
Expect(0, 127560, '\p{^Is_Decomposition_Type=compat}', "");
Expect(0, 127560, '\P{Is_Decomposition_Type=compat}', "");
Expect(1, 127560, '\P{^Is_Decomposition_Type=compat}', "");
Expect(0, 127561, '\p{Is_Decomposition_Type=compat}', "");
Expect(1, 127561, '\p{^Is_Decomposition_Type=compat}', "");
Expect(1, 127561, '\P{Is_Decomposition_Type=compat}', "");
Expect(0, 127561, '\P{^Is_Decomposition_Type=compat}', "");
Expect(1, 127560, '\p{Is_Decomposition_Type=-COMPAT}', "");
Expect(0, 127560, '\p{^Is_Decomposition_Type=-COMPAT}', "");
Expect(0, 127560, '\P{Is_Decomposition_Type=-COMPAT}', "");
Expect(1, 127560, '\P{^Is_Decomposition_Type=-COMPAT}', "");
Expect(0, 127561, '\p{Is_Decomposition_Type=-COMPAT}', "");
Expect(1, 127561, '\p{^Is_Decomposition_Type=-COMPAT}', "");
Expect(1, 127561, '\P{Is_Decomposition_Type=-COMPAT}', "");
Expect(0, 127561, '\P{^Is_Decomposition_Type=-COMPAT}', "");
Error('\p{Is_Dt=:=- Com}');
Error('\P{Is_Dt=:=- Com}');
Expect(1, 127560, '\p{Is_Dt=com}', "");
Expect(0, 127560, '\p{^Is_Dt=com}', "");
Expect(0, 127560, '\P{Is_Dt=com}', "");
Expect(1, 127560, '\P{^Is_Dt=com}', "");
Expect(0, 127561, '\p{Is_Dt=com}', "");
Expect(1, 127561, '\p{^Is_Dt=com}', "");
Expect(1, 127561, '\P{Is_Dt=com}', "");
Expect(0, 127561, '\P{^Is_Dt=com}', "");
Expect(1, 127560, '\p{Is_Dt= Com}', "");
Expect(0, 127560, '\p{^Is_Dt= Com}', "");
Expect(0, 127560, '\P{Is_Dt= Com}', "");
Expect(1, 127560, '\P{^Is_Dt= Com}', "");
Expect(0, 127561, '\p{Is_Dt= Com}', "");
Expect(1, 127561, '\p{^Is_Dt= Com}', "");
Expect(1, 127561, '\P{Is_Dt= Com}', "");
Expect(0, 127561, '\P{^Is_Dt= Com}', "");
Error('\p{Decomposition_Type=-	circle:=}');
Error('\P{Decomposition_Type=-	circle:=}');
Expect(1, 127569, '\p{Decomposition_Type=circle}', "");
Expect(0, 127569, '\p{^Decomposition_Type=circle}', "");
Expect(0, 127569, '\P{Decomposition_Type=circle}', "");
Expect(1, 127569, '\P{^Decomposition_Type=circle}', "");
Expect(0, 127570, '\p{Decomposition_Type=circle}', "");
Expect(1, 127570, '\p{^Decomposition_Type=circle}', "");
Expect(1, 127570, '\P{Decomposition_Type=circle}', "");
Expect(0, 127570, '\P{^Decomposition_Type=circle}', "");
Expect(1, 127569, '\p{Decomposition_Type= Circle}', "");
Expect(0, 127569, '\p{^Decomposition_Type= Circle}', "");
Expect(0, 127569, '\P{Decomposition_Type= Circle}', "");
Expect(1, 127569, '\P{^Decomposition_Type= Circle}', "");
Expect(0, 127570, '\p{Decomposition_Type= Circle}', "");
Expect(1, 127570, '\p{^Decomposition_Type= Circle}', "");
Expect(1, 127570, '\P{Decomposition_Type= Circle}', "");
Expect(0, 127570, '\P{^Decomposition_Type= Circle}', "");
Error('\p{Dt=/a/-	ENC}');
Error('\P{Dt=/a/-	ENC}');
Expect(1, 127569, '\p{Dt=enc}', "");
Expect(0, 127569, '\p{^Dt=enc}', "");
Expect(0, 127569, '\P{Dt=enc}', "");
Expect(1, 127569, '\P{^Dt=enc}', "");
Expect(0, 127570, '\p{Dt=enc}', "");
Expect(1, 127570, '\p{^Dt=enc}', "");
Expect(1, 127570, '\P{Dt=enc}', "");
Expect(0, 127570, '\P{^Dt=enc}', "");
Expect(1, 127569, '\p{Dt=-	enc}', "");
Expect(0, 127569, '\p{^Dt=-	enc}', "");
Expect(0, 127569, '\P{Dt=-	enc}', "");
Expect(1, 127569, '\P{^Dt=-	enc}', "");
Expect(0, 127570, '\p{Dt=-	enc}', "");
Expect(1, 127570, '\p{^Dt=-	enc}', "");
Expect(1, 127570, '\P{Dt=-	enc}', "");
Expect(0, 127570, '\P{^Dt=-	enc}', "");
Error('\p{Is_Decomposition_Type= /a/Circle}');
Error('\P{Is_Decomposition_Type= /a/Circle}');
Expect(1, 127569, '\p{Is_Decomposition_Type: circle}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type: circle}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type: circle}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type: circle}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type: circle}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type: circle}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type: circle}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type: circle}', "");
Expect(1, 127569, '\p{Is_Decomposition_Type=CIRCLE}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type=CIRCLE}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type=CIRCLE}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type=CIRCLE}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type=CIRCLE}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type=CIRCLE}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type=CIRCLE}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type=CIRCLE}', "");
Error('\p{Is_Dt= -Enc/a/}');
Error('\P{Is_Dt= -Enc/a/}');
Expect(1, 127569, '\p{Is_Dt=enc}', "");
Expect(0, 127569, '\p{^Is_Dt=enc}', "");
Expect(0, 127569, '\P{Is_Dt=enc}', "");
Expect(1, 127569, '\P{^Is_Dt=enc}', "");
Expect(0, 127570, '\p{Is_Dt=enc}', "");
Expect(1, 127570, '\p{^Is_Dt=enc}', "");
Expect(1, 127570, '\P{Is_Dt=enc}', "");
Expect(0, 127570, '\P{^Is_Dt=enc}', "");
Expect(1, 127569, '\p{Is_Dt:-_ENC}', "");
Expect(0, 127569, '\p{^Is_Dt:-_ENC}', "");
Expect(0, 127569, '\P{Is_Dt:-_ENC}', "");
Expect(1, 127569, '\P{^Is_Dt:-_ENC}', "");
Expect(0, 127570, '\p{Is_Dt:-_ENC}', "");
Expect(1, 127570, '\p{^Is_Dt:-_ENC}', "");
Expect(1, 127570, '\P{Is_Dt:-_ENC}', "");
Expect(0, 127570, '\P{^Is_Dt:-_ENC}', "");
Error('\p{Decomposition_Type= /a/final}');
Error('\P{Decomposition_Type= /a/final}');
Expect(1, 65276, '\p{Decomposition_Type=final}', "");
Expect(0, 65276, '\p{^Decomposition_Type=final}', "");
Expect(0, 65276, '\P{Decomposition_Type=final}', "");
Expect(1, 65276, '\P{^Decomposition_Type=final}', "");
Expect(0, 65277, '\p{Decomposition_Type=final}', "");
Expect(1, 65277, '\p{^Decomposition_Type=final}', "");
Expect(1, 65277, '\P{Decomposition_Type=final}', "");
Expect(0, 65277, '\P{^Decomposition_Type=final}', "");
Expect(1, 65276, '\p{Decomposition_Type=_ Final}', "");
Expect(0, 65276, '\p{^Decomposition_Type=_ Final}', "");
Expect(0, 65276, '\P{Decomposition_Type=_ Final}', "");
Expect(1, 65276, '\P{^Decomposition_Type=_ Final}', "");
Expect(0, 65277, '\p{Decomposition_Type=_ Final}', "");
Expect(1, 65277, '\p{^Decomposition_Type=_ Final}', "");
Expect(1, 65277, '\P{Decomposition_Type=_ Final}', "");
Expect(0, 65277, '\P{^Decomposition_Type=_ Final}', "");
Error('\p{Dt= /a/fin}');
Error('\P{Dt= /a/fin}');
Expect(1, 65276, '\p{Dt=fin}', "");
Expect(0, 65276, '\p{^Dt=fin}', "");
Expect(0, 65276, '\P{Dt=fin}', "");
Expect(1, 65276, '\P{^Dt=fin}', "");
Expect(0, 65277, '\p{Dt=fin}', "");
Expect(1, 65277, '\p{^Dt=fin}', "");
Expect(1, 65277, '\P{Dt=fin}', "");
Expect(0, 65277, '\P{^Dt=fin}', "");
Expect(1, 65276, '\p{Dt=	_Fin}', "");
Expect(0, 65276, '\p{^Dt=	_Fin}', "");
Expect(0, 65276, '\P{Dt=	_Fin}', "");
Expect(1, 65276, '\P{^Dt=	_Fin}', "");
Expect(0, 65277, '\p{Dt=	_Fin}', "");
Expect(1, 65277, '\p{^Dt=	_Fin}', "");
Expect(1, 65277, '\P{Dt=	_Fin}', "");
Expect(0, 65277, '\P{^Dt=	_Fin}', "");
Error('\p{Is_Decomposition_Type=:=__FINAL}');
Error('\P{Is_Decomposition_Type=:=__FINAL}');
Expect(1, 65276, '\p{Is_Decomposition_Type=final}', "");
Expect(0, 65276, '\p{^Is_Decomposition_Type=final}', "");
Expect(0, 65276, '\P{Is_Decomposition_Type=final}', "");
Expect(1, 65276, '\P{^Is_Decomposition_Type=final}', "");
Expect(0, 65277, '\p{Is_Decomposition_Type=final}', "");
Expect(1, 65277, '\p{^Is_Decomposition_Type=final}', "");
Expect(1, 65277, '\P{Is_Decomposition_Type=final}', "");
Expect(0, 65277, '\P{^Is_Decomposition_Type=final}', "");
Expect(1, 65276, '\p{Is_Decomposition_Type= -FINAL}', "");
Expect(0, 65276, '\p{^Is_Decomposition_Type= -FINAL}', "");
Expect(0, 65276, '\P{Is_Decomposition_Type= -FINAL}', "");
Expect(1, 65276, '\P{^Is_Decomposition_Type= -FINAL}', "");
Expect(0, 65277, '\p{Is_Decomposition_Type= -FINAL}', "");
Expect(1, 65277, '\p{^Is_Decomposition_Type= -FINAL}', "");
Expect(1, 65277, '\P{Is_Decomposition_Type= -FINAL}', "");
Expect(0, 65277, '\P{^Is_Decomposition_Type= -FINAL}', "");
Error('\p{Is_Dt=-:=fin}');
Error('\P{Is_Dt=-:=fin}');
Expect(1, 65276, '\p{Is_Dt: fin}', "");
Expect(0, 65276, '\p{^Is_Dt: fin}', "");
Expect(0, 65276, '\P{Is_Dt: fin}', "");
Expect(1, 65276, '\P{^Is_Dt: fin}', "");
Expect(0, 65277, '\p{Is_Dt: fin}', "");
Expect(1, 65277, '\p{^Is_Dt: fin}', "");
Expect(1, 65277, '\P{Is_Dt: fin}', "");
Expect(0, 65277, '\P{^Is_Dt: fin}', "");
Expect(1, 65276, '\p{Is_Dt:		fin}', "");
Expect(0, 65276, '\p{^Is_Dt:		fin}', "");
Expect(0, 65276, '\P{Is_Dt:		fin}', "");
Expect(1, 65276, '\P{^Is_Dt:		fin}', "");
Expect(0, 65277, '\p{Is_Dt:		fin}', "");
Expect(1, 65277, '\p{^Is_Dt:		fin}', "");
Expect(1, 65277, '\P{Is_Dt:		fin}', "");
Expect(0, 65277, '\P{^Is_Dt:		fin}', "");
Error('\p{Decomposition_Type=_:=FONT}');
Error('\P{Decomposition_Type=_:=FONT}');
Expect(1, 126651, '\p{Decomposition_Type=font}', "");
Expect(0, 126651, '\p{^Decomposition_Type=font}', "");
Expect(0, 126651, '\P{Decomposition_Type=font}', "");
Expect(1, 126651, '\P{^Decomposition_Type=font}', "");
Expect(0, 126652, '\p{Decomposition_Type=font}', "");
Expect(1, 126652, '\p{^Decomposition_Type=font}', "");
Expect(1, 126652, '\P{Decomposition_Type=font}', "");
Expect(0, 126652, '\P{^Decomposition_Type=font}', "");
Expect(1, 126651, '\p{Decomposition_Type=_font}', "");
Expect(0, 126651, '\p{^Decomposition_Type=_font}', "");
Expect(0, 126651, '\P{Decomposition_Type=_font}', "");
Expect(1, 126651, '\P{^Decomposition_Type=_font}', "");
Expect(0, 126652, '\p{Decomposition_Type=_font}', "");
Expect(1, 126652, '\p{^Decomposition_Type=_font}', "");
Expect(1, 126652, '\P{Decomposition_Type=_font}', "");
Expect(0, 126652, '\P{^Decomposition_Type=_font}', "");
Error('\p{Dt= _FONT/a/}');
Error('\P{Dt= _FONT/a/}');
Expect(1, 126651, '\p{Dt=font}', "");
Expect(0, 126651, '\p{^Dt=font}', "");
Expect(0, 126651, '\P{Dt=font}', "");
Expect(1, 126651, '\P{^Dt=font}', "");
Expect(0, 126652, '\p{Dt=font}', "");
Expect(1, 126652, '\p{^Dt=font}', "");
Expect(1, 126652, '\P{Dt=font}', "");
Expect(0, 126652, '\P{^Dt=font}', "");
Expect(1, 126651, '\p{Dt=	 Font}', "");
Expect(0, 126651, '\p{^Dt=	 Font}', "");
Expect(0, 126651, '\P{Dt=	 Font}', "");
Expect(1, 126651, '\P{^Dt=	 Font}', "");
Expect(0, 126652, '\p{Dt=	 Font}', "");
Expect(1, 126652, '\p{^Dt=	 Font}', "");
Expect(1, 126652, '\P{Dt=	 Font}', "");
Expect(0, 126652, '\P{^Dt=	 Font}', "");
Error('\p{Is_Decomposition_Type=	Font:=}');
Error('\P{Is_Decomposition_Type=	Font:=}');
Expect(1, 126651, '\p{Is_Decomposition_Type:   font}', "");
Expect(0, 126651, '\p{^Is_Decomposition_Type:   font}', "");
Expect(0, 126651, '\P{Is_Decomposition_Type:   font}', "");
Expect(1, 126651, '\P{^Is_Decomposition_Type:   font}', "");
Expect(0, 126652, '\p{Is_Decomposition_Type:   font}', "");
Expect(1, 126652, '\p{^Is_Decomposition_Type:   font}', "");
Expect(1, 126652, '\P{Is_Decomposition_Type:   font}', "");
Expect(0, 126652, '\P{^Is_Decomposition_Type:   font}', "");
Expect(1, 126651, '\p{Is_Decomposition_Type= FONT}', "");
Expect(0, 126651, '\p{^Is_Decomposition_Type= FONT}', "");
Expect(0, 126651, '\P{Is_Decomposition_Type= FONT}', "");
Expect(1, 126651, '\P{^Is_Decomposition_Type= FONT}', "");
Expect(0, 126652, '\p{Is_Decomposition_Type= FONT}', "");
Expect(1, 126652, '\p{^Is_Decomposition_Type= FONT}', "");
Expect(1, 126652, '\P{Is_Decomposition_Type= FONT}', "");
Expect(0, 126652, '\P{^Is_Decomposition_Type= FONT}', "");
Error('\p{Is_Dt=:=	 Font}');
Error('\P{Is_Dt=:=	 Font}');
Expect(1, 126651, '\p{Is_Dt=font}', "");
Expect(0, 126651, '\p{^Is_Dt=font}', "");
Expect(0, 126651, '\P{Is_Dt=font}', "");
Expect(1, 126651, '\P{^Is_Dt=font}', "");
Expect(0, 126652, '\p{Is_Dt=font}', "");
Expect(1, 126652, '\p{^Is_Dt=font}', "");
Expect(1, 126652, '\P{Is_Dt=font}', "");
Expect(0, 126652, '\P{^Is_Dt=font}', "");
Expect(1, 126651, '\p{Is_Dt:		_Font}', "");
Expect(0, 126651, '\p{^Is_Dt:		_Font}', "");
Expect(0, 126651, '\P{Is_Dt:		_Font}', "");
Expect(1, 126651, '\P{^Is_Dt:		_Font}', "");
Expect(0, 126652, '\p{Is_Dt:		_Font}', "");
Expect(1, 126652, '\p{^Is_Dt:		_Font}', "");
Expect(1, 126652, '\P{Is_Dt:		_Font}', "");
Expect(0, 126652, '\P{^Is_Dt:		_Font}', "");
Error('\p{Decomposition_Type:-_Fraction/a/}');
Error('\P{Decomposition_Type:-_Fraction/a/}');
Expect(1, 8585, '\p{Decomposition_Type=fraction}', "");
Expect(0, 8585, '\p{^Decomposition_Type=fraction}', "");
Expect(0, 8585, '\P{Decomposition_Type=fraction}', "");
Expect(1, 8585, '\P{^Decomposition_Type=fraction}', "");
Expect(0, 8586, '\p{Decomposition_Type=fraction}', "");
Expect(1, 8586, '\p{^Decomposition_Type=fraction}', "");
Expect(1, 8586, '\P{Decomposition_Type=fraction}', "");
Expect(0, 8586, '\P{^Decomposition_Type=fraction}', "");
Expect(1, 8585, '\p{Decomposition_Type=_	FRACTION}', "");
Expect(0, 8585, '\p{^Decomposition_Type=_	FRACTION}', "");
Expect(0, 8585, '\P{Decomposition_Type=_	FRACTION}', "");
Expect(1, 8585, '\P{^Decomposition_Type=_	FRACTION}', "");
Expect(0, 8586, '\p{Decomposition_Type=_	FRACTION}', "");
Expect(1, 8586, '\p{^Decomposition_Type=_	FRACTION}', "");
Expect(1, 8586, '\P{Decomposition_Type=_	FRACTION}', "");
Expect(0, 8586, '\P{^Decomposition_Type=_	FRACTION}', "");
Error('\p{Dt:   :=Fra}');
Error('\P{Dt:   :=Fra}');
Expect(1, 8585, '\p{Dt=fra}', "");
Expect(0, 8585, '\p{^Dt=fra}', "");
Expect(0, 8585, '\P{Dt=fra}', "");
Expect(1, 8585, '\P{^Dt=fra}', "");
Expect(0, 8586, '\p{Dt=fra}', "");
Expect(1, 8586, '\p{^Dt=fra}', "");
Expect(1, 8586, '\P{Dt=fra}', "");
Expect(0, 8586, '\P{^Dt=fra}', "");
Expect(1, 8585, '\p{Dt=	Fra}', "");
Expect(0, 8585, '\p{^Dt=	Fra}', "");
Expect(0, 8585, '\P{Dt=	Fra}', "");
Expect(1, 8585, '\P{^Dt=	Fra}', "");
Expect(0, 8586, '\p{Dt=	Fra}', "");
Expect(1, 8586, '\p{^Dt=	Fra}', "");
Expect(1, 8586, '\P{Dt=	Fra}', "");
Expect(0, 8586, '\P{^Dt=	Fra}', "");
Error('\p{Is_Decomposition_Type= Fraction:=}');
Error('\P{Is_Decomposition_Type= Fraction:=}');
Expect(1, 8585, '\p{Is_Decomposition_Type=fraction}', "");
Expect(0, 8585, '\p{^Is_Decomposition_Type=fraction}', "");
Expect(0, 8585, '\P{Is_Decomposition_Type=fraction}', "");
Expect(1, 8585, '\P{^Is_Decomposition_Type=fraction}', "");
Expect(0, 8586, '\p{Is_Decomposition_Type=fraction}', "");
Expect(1, 8586, '\p{^Is_Decomposition_Type=fraction}', "");
Expect(1, 8586, '\P{Is_Decomposition_Type=fraction}', "");
Expect(0, 8586, '\P{^Is_Decomposition_Type=fraction}', "");
Expect(1, 8585, '\p{Is_Decomposition_Type: 	-Fraction}', "");
Expect(0, 8585, '\p{^Is_Decomposition_Type: 	-Fraction}', "");
Expect(0, 8585, '\P{Is_Decomposition_Type: 	-Fraction}', "");
Expect(1, 8585, '\P{^Is_Decomposition_Type: 	-Fraction}', "");
Expect(0, 8586, '\p{Is_Decomposition_Type: 	-Fraction}', "");
Expect(1, 8586, '\p{^Is_Decomposition_Type: 	-Fraction}', "");
Expect(1, 8586, '\P{Is_Decomposition_Type: 	-Fraction}', "");
Expect(0, 8586, '\P{^Is_Decomposition_Type: 	-Fraction}', "");
Error('\p{Is_Dt= :=Fra}');
Error('\P{Is_Dt= :=Fra}');
Expect(1, 8585, '\p{Is_Dt=fra}', "");
Expect(0, 8585, '\p{^Is_Dt=fra}', "");
Expect(0, 8585, '\P{Is_Dt=fra}', "");
Expect(1, 8585, '\P{^Is_Dt=fra}', "");
Expect(0, 8586, '\p{Is_Dt=fra}', "");
Expect(1, 8586, '\p{^Is_Dt=fra}', "");
Expect(1, 8586, '\P{Is_Dt=fra}', "");
Expect(0, 8586, '\P{^Is_Dt=fra}', "");
Expect(1, 8585, '\p{Is_Dt=-	FRA}', "");
Expect(0, 8585, '\p{^Is_Dt=-	FRA}', "");
Expect(0, 8585, '\P{Is_Dt=-	FRA}', "");
Expect(1, 8585, '\P{^Is_Dt=-	FRA}', "");
Expect(0, 8586, '\p{Is_Dt=-	FRA}', "");
Expect(1, 8586, '\p{^Is_Dt=-	FRA}', "");
Expect(1, 8586, '\P{Is_Dt=-	FRA}', "");
Expect(0, 8586, '\P{^Is_Dt=-	FRA}', "");
Error('\p{Decomposition_Type=-initial/a/}');
Error('\P{Decomposition_Type=-initial/a/}');
Expect(1, 65267, '\p{Decomposition_Type=initial}', "");
Expect(0, 65267, '\p{^Decomposition_Type=initial}', "");
Expect(0, 65267, '\P{Decomposition_Type=initial}', "");
Expect(1, 65267, '\P{^Decomposition_Type=initial}', "");
Expect(0, 65268, '\p{Decomposition_Type=initial}', "");
Expect(1, 65268, '\p{^Decomposition_Type=initial}', "");
Expect(1, 65268, '\P{Decomposition_Type=initial}', "");
Expect(0, 65268, '\P{^Decomposition_Type=initial}', "");
Expect(1, 65267, '\p{Decomposition_Type= _INITIAL}', "");
Expect(0, 65267, '\p{^Decomposition_Type= _INITIAL}', "");
Expect(0, 65267, '\P{Decomposition_Type= _INITIAL}', "");
Expect(1, 65267, '\P{^Decomposition_Type= _INITIAL}', "");
Expect(0, 65268, '\p{Decomposition_Type= _INITIAL}', "");
Expect(1, 65268, '\p{^Decomposition_Type= _INITIAL}', "");
Expect(1, 65268, '\P{Decomposition_Type= _INITIAL}', "");
Expect(0, 65268, '\P{^Decomposition_Type= _INITIAL}', "");
Error('\p{Dt=:=-_Init}');
Error('\P{Dt=:=-_Init}');
Expect(1, 65267, '\p{Dt=init}', "");
Expect(0, 65267, '\p{^Dt=init}', "");
Expect(0, 65267, '\P{Dt=init}', "");
Expect(1, 65267, '\P{^Dt=init}', "");
Expect(0, 65268, '\p{Dt=init}', "");
Expect(1, 65268, '\p{^Dt=init}', "");
Expect(1, 65268, '\P{Dt=init}', "");
Expect(0, 65268, '\P{^Dt=init}', "");
Expect(1, 65267, '\p{Dt=  INIT}', "");
Expect(0, 65267, '\p{^Dt=  INIT}', "");
Expect(0, 65267, '\P{Dt=  INIT}', "");
Expect(1, 65267, '\P{^Dt=  INIT}', "");
Expect(0, 65268, '\p{Dt=  INIT}', "");
Expect(1, 65268, '\p{^Dt=  INIT}', "");
Expect(1, 65268, '\P{Dt=  INIT}', "");
Expect(0, 65268, '\P{^Dt=  INIT}', "");
Error('\p{Is_Decomposition_Type=-:=initial}');
Error('\P{Is_Decomposition_Type=-:=initial}');
Expect(1, 65267, '\p{Is_Decomposition_Type=initial}', "");
Expect(0, 65267, '\p{^Is_Decomposition_Type=initial}', "");
Expect(0, 65267, '\P{Is_Decomposition_Type=initial}', "");
Expect(1, 65267, '\P{^Is_Decomposition_Type=initial}', "");
Expect(0, 65268, '\p{Is_Decomposition_Type=initial}', "");
Expect(1, 65268, '\p{^Is_Decomposition_Type=initial}', "");
Expect(1, 65268, '\P{Is_Decomposition_Type=initial}', "");
Expect(0, 65268, '\P{^Is_Decomposition_Type=initial}', "");
Expect(1, 65267, '\p{Is_Decomposition_Type=__initial}', "");
Expect(0, 65267, '\p{^Is_Decomposition_Type=__initial}', "");
Expect(0, 65267, '\P{Is_Decomposition_Type=__initial}', "");
Expect(1, 65267, '\P{^Is_Decomposition_Type=__initial}', "");
Expect(0, 65268, '\p{Is_Decomposition_Type=__initial}', "");
Expect(1, 65268, '\p{^Is_Decomposition_Type=__initial}', "");
Expect(1, 65268, '\P{Is_Decomposition_Type=__initial}', "");
Expect(0, 65268, '\P{^Is_Decomposition_Type=__initial}', "");
Error('\p{Is_Dt=_/a/init}');
Error('\P{Is_Dt=_/a/init}');
Expect(1, 65267, '\p{Is_Dt=init}', "");
Expect(0, 65267, '\p{^Is_Dt=init}', "");
Expect(0, 65267, '\P{Is_Dt=init}', "");
Expect(1, 65267, '\P{^Is_Dt=init}', "");
Expect(0, 65268, '\p{Is_Dt=init}', "");
Expect(1, 65268, '\p{^Is_Dt=init}', "");
Expect(1, 65268, '\P{Is_Dt=init}', "");
Expect(0, 65268, '\P{^Is_Dt=init}', "");
Error('\p{Decomposition_Type=	isolated:=}');
Error('\P{Decomposition_Type=	isolated:=}');
Expect(1, 65275, '\p{Decomposition_Type=isolated}', "");
Expect(0, 65275, '\p{^Decomposition_Type=isolated}', "");
Expect(0, 65275, '\P{Decomposition_Type=isolated}', "");
Expect(1, 65275, '\P{^Decomposition_Type=isolated}', "");
Expect(0, 65276, '\p{Decomposition_Type=isolated}', "");
Expect(1, 65276, '\p{^Decomposition_Type=isolated}', "");
Expect(1, 65276, '\P{Decomposition_Type=isolated}', "");
Expect(0, 65276, '\P{^Decomposition_Type=isolated}', "");
Expect(1, 65275, '\p{Decomposition_Type=_-Isolated}', "");
Expect(0, 65275, '\p{^Decomposition_Type=_-Isolated}', "");
Expect(0, 65275, '\P{Decomposition_Type=_-Isolated}', "");
Expect(1, 65275, '\P{^Decomposition_Type=_-Isolated}', "");
Expect(0, 65276, '\p{Decomposition_Type=_-Isolated}', "");
Expect(1, 65276, '\p{^Decomposition_Type=_-Isolated}', "");
Expect(1, 65276, '\P{Decomposition_Type=_-Isolated}', "");
Expect(0, 65276, '\P{^Decomposition_Type=_-Isolated}', "");
Error('\p{Dt: -	ISO:=}');
Error('\P{Dt: -	ISO:=}');
Expect(1, 65275, '\p{Dt=iso}', "");
Expect(0, 65275, '\p{^Dt=iso}', "");
Expect(0, 65275, '\P{Dt=iso}', "");
Expect(1, 65275, '\P{^Dt=iso}', "");
Expect(0, 65276, '\p{Dt=iso}', "");
Expect(1, 65276, '\p{^Dt=iso}', "");
Expect(1, 65276, '\P{Dt=iso}', "");
Expect(0, 65276, '\P{^Dt=iso}', "");
Expect(1, 65275, '\p{Dt=	-ISO}', "");
Expect(0, 65275, '\p{^Dt=	-ISO}', "");
Expect(0, 65275, '\P{Dt=	-ISO}', "");
Expect(1, 65275, '\P{^Dt=	-ISO}', "");
Expect(0, 65276, '\p{Dt=	-ISO}', "");
Expect(1, 65276, '\p{^Dt=	-ISO}', "");
Expect(1, 65276, '\P{Dt=	-ISO}', "");
Expect(0, 65276, '\P{^Dt=	-ISO}', "");
Error('\p{Is_Decomposition_Type=:=_Isolated}');
Error('\P{Is_Decomposition_Type=:=_Isolated}');
Expect(1, 65275, '\p{Is_Decomposition_Type=isolated}', "");
Expect(0, 65275, '\p{^Is_Decomposition_Type=isolated}', "");
Expect(0, 65275, '\P{Is_Decomposition_Type=isolated}', "");
Expect(1, 65275, '\P{^Is_Decomposition_Type=isolated}', "");
Expect(0, 65276, '\p{Is_Decomposition_Type=isolated}', "");
Expect(1, 65276, '\p{^Is_Decomposition_Type=isolated}', "");
Expect(1, 65276, '\P{Is_Decomposition_Type=isolated}', "");
Expect(0, 65276, '\P{^Is_Decomposition_Type=isolated}', "");
Expect(1, 65275, '\p{Is_Decomposition_Type= -Isolated}', "");
Expect(0, 65275, '\p{^Is_Decomposition_Type= -Isolated}', "");
Expect(0, 65275, '\P{Is_Decomposition_Type= -Isolated}', "");
Expect(1, 65275, '\P{^Is_Decomposition_Type= -Isolated}', "");
Expect(0, 65276, '\p{Is_Decomposition_Type= -Isolated}', "");
Expect(1, 65276, '\p{^Is_Decomposition_Type= -Isolated}', "");
Expect(1, 65276, '\P{Is_Decomposition_Type= -Isolated}', "");
Expect(0, 65276, '\P{^Is_Decomposition_Type= -Isolated}', "");
Error('\p{Is_Dt=/a/	Iso}');
Error('\P{Is_Dt=/a/	Iso}');
Expect(1, 65275, '\p{Is_Dt=iso}', "");
Expect(0, 65275, '\p{^Is_Dt=iso}', "");
Expect(0, 65275, '\P{Is_Dt=iso}', "");
Expect(1, 65275, '\P{^Is_Dt=iso}', "");
Expect(0, 65276, '\p{Is_Dt=iso}', "");
Expect(1, 65276, '\p{^Is_Dt=iso}', "");
Expect(1, 65276, '\P{Is_Dt=iso}', "");
Expect(0, 65276, '\P{^Is_Dt=iso}', "");
Expect(1, 65275, '\p{Is_Dt=__ISO}', "");
Expect(0, 65275, '\p{^Is_Dt=__ISO}', "");
Expect(0, 65275, '\P{Is_Dt=__ISO}', "");
Expect(1, 65275, '\P{^Is_Dt=__ISO}', "");
Expect(0, 65276, '\p{Is_Dt=__ISO}', "");
Expect(1, 65276, '\p{^Is_Dt=__ISO}', "");
Expect(1, 65276, '\P{Is_Dt=__ISO}', "");
Expect(0, 65276, '\P{^Is_Dt=__ISO}', "");
Error('\p{Decomposition_Type=/a/_ Medial}');
Error('\P{Decomposition_Type=/a/_ Medial}');
Expect(1, 65268, '\p{Decomposition_Type=medial}', "");
Expect(0, 65268, '\p{^Decomposition_Type=medial}', "");
Expect(0, 65268, '\P{Decomposition_Type=medial}', "");
Expect(1, 65268, '\P{^Decomposition_Type=medial}', "");
Expect(0, 65269, '\p{Decomposition_Type=medial}', "");
Expect(1, 65269, '\p{^Decomposition_Type=medial}', "");
Expect(1, 65269, '\P{Decomposition_Type=medial}', "");
Expect(0, 65269, '\P{^Decomposition_Type=medial}', "");
Expect(1, 65268, '\p{Decomposition_Type=-MEDIAL}', "");
Expect(0, 65268, '\p{^Decomposition_Type=-MEDIAL}', "");
Expect(0, 65268, '\P{Decomposition_Type=-MEDIAL}', "");
Expect(1, 65268, '\P{^Decomposition_Type=-MEDIAL}', "");
Expect(0, 65269, '\p{Decomposition_Type=-MEDIAL}', "");
Expect(1, 65269, '\p{^Decomposition_Type=-MEDIAL}', "");
Expect(1, 65269, '\P{Decomposition_Type=-MEDIAL}', "");
Expect(0, 65269, '\P{^Decomposition_Type=-MEDIAL}', "");
Error('\p{Dt=:=_Med}');
Error('\P{Dt=:=_Med}');
Expect(1, 65268, '\p{Dt=med}', "");
Expect(0, 65268, '\p{^Dt=med}', "");
Expect(0, 65268, '\P{Dt=med}', "");
Expect(1, 65268, '\P{^Dt=med}', "");
Expect(0, 65269, '\p{Dt=med}', "");
Expect(1, 65269, '\p{^Dt=med}', "");
Expect(1, 65269, '\P{Dt=med}', "");
Expect(0, 65269, '\P{^Dt=med}', "");
Expect(1, 65268, '\p{Dt=Med}', "");
Expect(0, 65268, '\p{^Dt=Med}', "");
Expect(0, 65268, '\P{Dt=Med}', "");
Expect(1, 65268, '\P{^Dt=Med}', "");
Expect(0, 65269, '\p{Dt=Med}', "");
Expect(1, 65269, '\p{^Dt=Med}', "");
Expect(1, 65269, '\P{Dt=Med}', "");
Expect(0, 65269, '\P{^Dt=Med}', "");
Error('\p{Is_Decomposition_Type=_ medial:=}');
Error('\P{Is_Decomposition_Type=_ medial:=}');
Expect(1, 65268, '\p{Is_Decomposition_Type=medial}', "");
Expect(0, 65268, '\p{^Is_Decomposition_Type=medial}', "");
Expect(0, 65268, '\P{Is_Decomposition_Type=medial}', "");
Expect(1, 65268, '\P{^Is_Decomposition_Type=medial}', "");
Expect(0, 65269, '\p{Is_Decomposition_Type=medial}', "");
Expect(1, 65269, '\p{^Is_Decomposition_Type=medial}', "");
Expect(1, 65269, '\P{Is_Decomposition_Type=medial}', "");
Expect(0, 65269, '\P{^Is_Decomposition_Type=medial}', "");
Expect(1, 65268, '\p{Is_Decomposition_Type=__medial}', "");
Expect(0, 65268, '\p{^Is_Decomposition_Type=__medial}', "");
Expect(0, 65268, '\P{Is_Decomposition_Type=__medial}', "");
Expect(1, 65268, '\P{^Is_Decomposition_Type=__medial}', "");
Expect(0, 65269, '\p{Is_Decomposition_Type=__medial}', "");
Expect(1, 65269, '\p{^Is_Decomposition_Type=__medial}', "");
Expect(1, 65269, '\P{Is_Decomposition_Type=__medial}', "");
Expect(0, 65269, '\P{^Is_Decomposition_Type=__medial}', "");
Error('\p{Is_Dt=	:=MED}');
Error('\P{Is_Dt=	:=MED}');
Expect(1, 65268, '\p{Is_Dt=med}', "");
Expect(0, 65268, '\p{^Is_Dt=med}', "");
Expect(0, 65268, '\P{Is_Dt=med}', "");
Expect(1, 65268, '\P{^Is_Dt=med}', "");
Expect(0, 65269, '\p{Is_Dt=med}', "");
Expect(1, 65269, '\p{^Is_Dt=med}', "");
Expect(1, 65269, '\P{Is_Dt=med}', "");
Expect(0, 65269, '\P{^Is_Dt=med}', "");
Expect(1, 65268, '\p{Is_Dt=	MED}', "");
Expect(0, 65268, '\p{^Is_Dt=	MED}', "");
Expect(0, 65268, '\P{Is_Dt=	MED}', "");
Expect(1, 65268, '\P{^Is_Dt=	MED}', "");
Expect(0, 65269, '\p{Is_Dt=	MED}', "");
Expect(1, 65269, '\p{^Is_Dt=	MED}', "");
Expect(1, 65269, '\P{Is_Dt=	MED}', "");
Expect(0, 65269, '\P{^Is_Dt=	MED}', "");
Error('\p{Decomposition_Type= _Narrow:=}');
Error('\P{Decomposition_Type= _Narrow:=}');
Expect(1, 65518, '\p{Decomposition_Type=narrow}', "");
Expect(0, 65518, '\p{^Decomposition_Type=narrow}', "");
Expect(0, 65518, '\P{Decomposition_Type=narrow}', "");
Expect(1, 65518, '\P{^Decomposition_Type=narrow}', "");
Expect(0, 65519, '\p{Decomposition_Type=narrow}', "");
Expect(1, 65519, '\p{^Decomposition_Type=narrow}', "");
Expect(1, 65519, '\P{Decomposition_Type=narrow}', "");
Expect(0, 65519, '\P{^Decomposition_Type=narrow}', "");
Expect(1, 65518, '\p{Decomposition_Type=	Narrow}', "");
Expect(0, 65518, '\p{^Decomposition_Type=	Narrow}', "");
Expect(0, 65518, '\P{Decomposition_Type=	Narrow}', "");
Expect(1, 65518, '\P{^Decomposition_Type=	Narrow}', "");
Expect(0, 65519, '\p{Decomposition_Type=	Narrow}', "");
Expect(1, 65519, '\p{^Decomposition_Type=	Narrow}', "");
Expect(1, 65519, '\P{Decomposition_Type=	Narrow}', "");
Expect(0, 65519, '\P{^Decomposition_Type=	Narrow}', "");
Error('\p{Dt=-/a/nar}');
Error('\P{Dt=-/a/nar}');
Expect(1, 65518, '\p{Dt=nar}', "");
Expect(0, 65518, '\p{^Dt=nar}', "");
Expect(0, 65518, '\P{Dt=nar}', "");
Expect(1, 65518, '\P{^Dt=nar}', "");
Expect(0, 65519, '\p{Dt=nar}', "");
Expect(1, 65519, '\p{^Dt=nar}', "");
Expect(1, 65519, '\P{Dt=nar}', "");
Expect(0, 65519, '\P{^Dt=nar}', "");
Expect(1, 65518, '\p{Dt= Nar}', "");
Expect(0, 65518, '\p{^Dt= Nar}', "");
Expect(0, 65518, '\P{Dt= Nar}', "");
Expect(1, 65518, '\P{^Dt= Nar}', "");
Expect(0, 65519, '\p{Dt= Nar}', "");
Expect(1, 65519, '\p{^Dt= Nar}', "");
Expect(1, 65519, '\P{Dt= Nar}', "");
Expect(0, 65519, '\P{^Dt= Nar}', "");
Error('\p{Is_Decomposition_Type=/a/		Narrow}');
Error('\P{Is_Decomposition_Type=/a/		Narrow}');
Expect(1, 65518, '\p{Is_Decomposition_Type: narrow}', "");
Expect(0, 65518, '\p{^Is_Decomposition_Type: narrow}', "");
Expect(0, 65518, '\P{Is_Decomposition_Type: narrow}', "");
Expect(1, 65518, '\P{^Is_Decomposition_Type: narrow}', "");
Expect(0, 65519, '\p{Is_Decomposition_Type: narrow}', "");
Expect(1, 65519, '\p{^Is_Decomposition_Type: narrow}', "");
Expect(1, 65519, '\P{Is_Decomposition_Type: narrow}', "");
Expect(0, 65519, '\P{^Is_Decomposition_Type: narrow}', "");
Expect(1, 65518, '\p{Is_Decomposition_Type:__NARROW}', "");
Expect(0, 65518, '\p{^Is_Decomposition_Type:__NARROW}', "");
Expect(0, 65518, '\P{Is_Decomposition_Type:__NARROW}', "");
Expect(1, 65518, '\P{^Is_Decomposition_Type:__NARROW}', "");
Expect(0, 65519, '\p{Is_Decomposition_Type:__NARROW}', "");
Expect(1, 65519, '\p{^Is_Decomposition_Type:__NARROW}', "");
Expect(1, 65519, '\P{Is_Decomposition_Type:__NARROW}', "");
Expect(0, 65519, '\P{^Is_Decomposition_Type:__NARROW}', "");
Error('\p{Is_Dt=/a/ nar}');
Error('\P{Is_Dt=/a/ nar}');
Expect(1, 65518, '\p{Is_Dt=nar}', "");
Expect(0, 65518, '\p{^Is_Dt=nar}', "");
Expect(0, 65518, '\P{Is_Dt=nar}', "");
Expect(1, 65518, '\P{^Is_Dt=nar}', "");
Expect(0, 65519, '\p{Is_Dt=nar}', "");
Expect(1, 65519, '\p{^Is_Dt=nar}', "");
Expect(1, 65519, '\P{Is_Dt=nar}', "");
Expect(0, 65519, '\P{^Is_Dt=nar}', "");
Expect(1, 65518, '\p{Is_Dt:   _ Nar}', "");
Expect(0, 65518, '\p{^Is_Dt:   _ Nar}', "");
Expect(0, 65518, '\P{Is_Dt:   _ Nar}', "");
Expect(1, 65518, '\P{^Is_Dt:   _ Nar}', "");
Expect(0, 65519, '\p{Is_Dt:   _ Nar}', "");
Expect(1, 65519, '\p{^Is_Dt:   _ Nar}', "");
Expect(1, 65519, '\P{Is_Dt:   _ Nar}', "");
Expect(0, 65519, '\P{^Is_Dt:   _ Nar}', "");
Error('\p{Decomposition_Type=- Nobreak:=}');
Error('\P{Decomposition_Type=- Nobreak:=}');
Expect(1, 8239, '\p{Decomposition_Type:   nobreak}', "");
Expect(0, 8239, '\p{^Decomposition_Type:   nobreak}', "");
Expect(0, 8239, '\P{Decomposition_Type:   nobreak}', "");
Expect(1, 8239, '\P{^Decomposition_Type:   nobreak}', "");
Expect(0, 8240, '\p{Decomposition_Type:   nobreak}', "");
Expect(1, 8240, '\p{^Decomposition_Type:   nobreak}', "");
Expect(1, 8240, '\P{Decomposition_Type:   nobreak}', "");
Expect(0, 8240, '\P{^Decomposition_Type:   nobreak}', "");
Expect(1, 8239, '\p{Decomposition_Type= -Nobreak}', "");
Expect(0, 8239, '\p{^Decomposition_Type= -Nobreak}', "");
Expect(0, 8239, '\P{Decomposition_Type= -Nobreak}', "");
Expect(1, 8239, '\P{^Decomposition_Type= -Nobreak}', "");
Expect(0, 8240, '\p{Decomposition_Type= -Nobreak}', "");
Expect(1, 8240, '\p{^Decomposition_Type= -Nobreak}', "");
Expect(1, 8240, '\P{Decomposition_Type= -Nobreak}', "");
Expect(0, 8240, '\P{^Decomposition_Type= -Nobreak}', "");
Error('\p{Dt=-	Nb:=}');
Error('\P{Dt=-	Nb:=}');
Expect(1, 8239, '\p{Dt=nb}', "");
Expect(0, 8239, '\p{^Dt=nb}', "");
Expect(0, 8239, '\P{Dt=nb}', "");
Expect(1, 8239, '\P{^Dt=nb}', "");
Expect(0, 8240, '\p{Dt=nb}', "");
Expect(1, 8240, '\p{^Dt=nb}', "");
Expect(1, 8240, '\P{Dt=nb}', "");
Expect(0, 8240, '\P{^Dt=nb}', "");
Expect(1, 8239, '\p{Dt= NB}', "");
Expect(0, 8239, '\p{^Dt= NB}', "");
Expect(0, 8239, '\P{Dt= NB}', "");
Expect(1, 8239, '\P{^Dt= NB}', "");
Expect(0, 8240, '\p{Dt= NB}', "");
Expect(1, 8240, '\p{^Dt= NB}', "");
Expect(1, 8240, '\P{Dt= NB}', "");
Expect(0, 8240, '\P{^Dt= NB}', "");
Error('\p{Is_Decomposition_Type=/a/ 	nobreak}');
Error('\P{Is_Decomposition_Type=/a/ 	nobreak}');
Expect(1, 8239, '\p{Is_Decomposition_Type=nobreak}', "");
Expect(0, 8239, '\p{^Is_Decomposition_Type=nobreak}', "");
Expect(0, 8239, '\P{Is_Decomposition_Type=nobreak}', "");
Expect(1, 8239, '\P{^Is_Decomposition_Type=nobreak}', "");
Expect(0, 8240, '\p{Is_Decomposition_Type=nobreak}', "");
Expect(1, 8240, '\p{^Is_Decomposition_Type=nobreak}', "");
Expect(1, 8240, '\P{Is_Decomposition_Type=nobreak}', "");
Expect(0, 8240, '\P{^Is_Decomposition_Type=nobreak}', "");
Expect(1, 8239, '\p{Is_Decomposition_Type:   _	Nobreak}', "");
Expect(0, 8239, '\p{^Is_Decomposition_Type:   _	Nobreak}', "");
Expect(0, 8239, '\P{Is_Decomposition_Type:   _	Nobreak}', "");
Expect(1, 8239, '\P{^Is_Decomposition_Type:   _	Nobreak}', "");
Expect(0, 8240, '\p{Is_Decomposition_Type:   _	Nobreak}', "");
Expect(1, 8240, '\p{^Is_Decomposition_Type:   _	Nobreak}', "");
Expect(1, 8240, '\P{Is_Decomposition_Type:   _	Nobreak}', "");
Expect(0, 8240, '\P{^Is_Decomposition_Type:   _	Nobreak}', "");
Error('\p{Is_Dt=	 Nb/a/}');
Error('\P{Is_Dt=	 Nb/a/}');
Expect(1, 8239, '\p{Is_Dt=nb}', "");
Expect(0, 8239, '\p{^Is_Dt=nb}', "");
Expect(0, 8239, '\P{Is_Dt=nb}', "");
Expect(1, 8239, '\P{^Is_Dt=nb}', "");
Expect(0, 8240, '\p{Is_Dt=nb}', "");
Expect(1, 8240, '\p{^Is_Dt=nb}', "");
Expect(1, 8240, '\P{Is_Dt=nb}', "");
Expect(0, 8240, '\P{^Is_Dt=nb}', "");
Expect(1, 8239, '\p{Is_Dt=	_nb}', "");
Expect(0, 8239, '\p{^Is_Dt=	_nb}', "");
Expect(0, 8239, '\P{Is_Dt=	_nb}', "");
Expect(1, 8239, '\P{^Is_Dt=	_nb}', "");
Expect(0, 8240, '\p{Is_Dt=	_nb}', "");
Expect(1, 8240, '\p{^Is_Dt=	_nb}', "");
Expect(1, 8240, '\P{Is_Dt=	_nb}', "");
Expect(0, 8240, '\P{^Is_Dt=	_nb}', "");
Error('\p{Decomposition_Type=-:=Non_Canonical}');
Error('\P{Decomposition_Type=-:=Non_Canonical}');
Expect(1, 127569, '\p{Decomposition_Type=noncanonical}', "");
Expect(0, 127569, '\p{^Decomposition_Type=noncanonical}', "");
Expect(0, 127569, '\P{Decomposition_Type=noncanonical}', "");
Expect(1, 127569, '\P{^Decomposition_Type=noncanonical}', "");
Expect(0, 127570, '\p{Decomposition_Type=noncanonical}', "");
Expect(1, 127570, '\p{^Decomposition_Type=noncanonical}', "");
Expect(1, 127570, '\P{Decomposition_Type=noncanonical}', "");
Expect(0, 127570, '\P{^Decomposition_Type=noncanonical}', "");
Expect(1, 127569, '\p{Decomposition_Type=	Non_canonical}', "");
Expect(0, 127569, '\p{^Decomposition_Type=	Non_canonical}', "");
Expect(0, 127569, '\P{Decomposition_Type=	Non_canonical}', "");
Expect(1, 127569, '\P{^Decomposition_Type=	Non_canonical}', "");
Expect(0, 127570, '\p{Decomposition_Type=	Non_canonical}', "");
Expect(1, 127570, '\p{^Decomposition_Type=	Non_canonical}', "");
Expect(1, 127570, '\P{Decomposition_Type=	Non_canonical}', "");
Expect(0, 127570, '\P{^Decomposition_Type=	Non_canonical}', "");
Error('\p{Dt=_/a/Non_canon}');
Error('\P{Dt=_/a/Non_canon}');
Expect(1, 127569, '\p{Dt=noncanon}', "");
Expect(0, 127569, '\p{^Dt=noncanon}', "");
Expect(0, 127569, '\P{Dt=noncanon}', "");
Expect(1, 127569, '\P{^Dt=noncanon}', "");
Expect(0, 127570, '\p{Dt=noncanon}', "");
Expect(1, 127570, '\p{^Dt=noncanon}', "");
Expect(1, 127570, '\P{Dt=noncanon}', "");
Expect(0, 127570, '\P{^Dt=noncanon}', "");
Expect(1, 127569, '\p{Dt=__NON_Canon}', "");
Expect(0, 127569, '\p{^Dt=__NON_Canon}', "");
Expect(0, 127569, '\P{Dt=__NON_Canon}', "");
Expect(1, 127569, '\P{^Dt=__NON_Canon}', "");
Expect(0, 127570, '\p{Dt=__NON_Canon}', "");
Expect(1, 127570, '\p{^Dt=__NON_Canon}', "");
Expect(1, 127570, '\P{Dt=__NON_Canon}', "");
Expect(0, 127570, '\P{^Dt=__NON_Canon}', "");
Error('\p{Is_Decomposition_Type=_/a/Non_CANONICAL}');
Error('\P{Is_Decomposition_Type=_/a/Non_CANONICAL}');
Expect(1, 127569, '\p{Is_Decomposition_Type=noncanonical}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type=noncanonical}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type=noncanonical}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type=noncanonical}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type=noncanonical}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type=noncanonical}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type=noncanonical}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type=noncanonical}', "");
Expect(1, 127569, '\p{Is_Decomposition_Type=  Non_canonical}', "");
Expect(0, 127569, '\p{^Is_Decomposition_Type=  Non_canonical}', "");
Expect(0, 127569, '\P{Is_Decomposition_Type=  Non_canonical}', "");
Expect(1, 127569, '\P{^Is_Decomposition_Type=  Non_canonical}', "");
Expect(0, 127570, '\p{Is_Decomposition_Type=  Non_canonical}', "");
Expect(1, 127570, '\p{^Is_Decomposition_Type=  Non_canonical}', "");
Expect(1, 127570, '\P{Is_Decomposition_Type=  Non_canonical}', "");
Expect(0, 127570, '\P{^Is_Decomposition_Type=  Non_canonical}', "");
Error('\p{Is_Dt=:=NON_CANON}');
Error('\P{Is_Dt=:=NON_CANON}');
Expect(1, 127569, '\p{Is_Dt=noncanon}', "");
Expect(0, 127569, '\p{^Is_Dt=noncanon}', "");
Expect(0, 127569, '\P{Is_Dt=noncanon}', "");
Expect(1, 127569, '\P{^Is_Dt=noncanon}', "");
Expect(0, 127570, '\p{Is_Dt=noncanon}', "");
Expect(1, 127570, '\p{^Is_Dt=noncanon}', "");
Expect(1, 127570, '\P{Is_Dt=noncanon}', "");
Expect(0, 127570, '\P{^Is_Dt=noncanon}', "");
Expect(1, 127569, '\p{Is_Dt= NON_Canon}', "");
Expect(0, 127569, '\p{^Is_Dt= NON_Canon}', "");
Expect(0, 127569, '\P{Is_Dt= NON_Canon}', "");
Expect(1, 127569, '\P{^Is_Dt= NON_Canon}', "");
Expect(0, 127570, '\p{Is_Dt= NON_Canon}', "");
Expect(1, 127570, '\p{^Is_Dt= NON_Canon}', "");
Expect(1, 127570, '\P{Is_Dt= NON_Canon}', "");
Expect(0, 127570, '\P{^Is_Dt= NON_Canon}', "");
Error('\p{Decomposition_Type=-None:=}');
Error('\P{Decomposition_Type=-None:=}');
Expect(1, 195102, '\p{Decomposition_Type=none}', "");
Expect(0, 195102, '\p{^Decomposition_Type=none}', "");
Expect(0, 195102, '\P{Decomposition_Type=none}', "");
Expect(1, 195102, '\P{^Decomposition_Type=none}', "");
Expect(0, 195101, '\p{Decomposition_Type=none}', "");
Expect(1, 195101, '\p{^Decomposition_Type=none}', "");
Expect(1, 195101, '\P{Decomposition_Type=none}', "");
Expect(0, 195101, '\P{^Decomposition_Type=none}', "");
Expect(1, 195102, '\p{Decomposition_Type=		None}', "");
Expect(0, 195102, '\p{^Decomposition_Type=		None}', "");
Expect(0, 195102, '\P{Decomposition_Type=		None}', "");
Expect(1, 195102, '\P{^Decomposition_Type=		None}', "");
Expect(0, 195101, '\p{Decomposition_Type=		None}', "");
Expect(1, 195101, '\p{^Decomposition_Type=		None}', "");
Expect(1, 195101, '\P{Decomposition_Type=		None}', "");
Expect(0, 195101, '\P{^Decomposition_Type=		None}', "");
Error('\p{Dt=:=	 none}');
Error('\P{Dt=:=	 none}');
Expect(1, 195102, '\p{Dt=none}', "");
Expect(0, 195102, '\p{^Dt=none}', "");
Expect(0, 195102, '\P{Dt=none}', "");
Expect(1, 195102, '\P{^Dt=none}', "");
Expect(0, 195101, '\p{Dt=none}', "");
Expect(1, 195101, '\p{^Dt=none}', "");
Expect(1, 195101, '\P{Dt=none}', "");
Expect(0, 195101, '\P{^Dt=none}', "");
Expect(1, 195102, '\p{Dt=- NONE}', "");
Expect(0, 195102, '\p{^Dt=- NONE}', "");
Expect(0, 195102, '\P{Dt=- NONE}', "");
Expect(1, 195102, '\P{^Dt=- NONE}', "");
Expect(0, 195101, '\p{Dt=- NONE}', "");
Expect(1, 195101, '\p{^Dt=- NONE}', "");
Expect(1, 195101, '\P{Dt=- NONE}', "");
Expect(0, 195101, '\P{^Dt=- NONE}', "");
Error('\p{Is_Decomposition_Type:    -None/a/}');
Error('\P{Is_Decomposition_Type:    -None/a/}');
Expect(1, 195102, '\p{Is_Decomposition_Type=none}', "");
Expect(0, 195102, '\p{^Is_Decomposition_Type=none}', "");
Expect(0, 195102, '\P{Is_Decomposition_Type=none}', "");
Expect(1, 195102, '\P{^Is_Decomposition_Type=none}', "");
Expect(0, 195101, '\p{Is_Decomposition_Type=none}', "");
Expect(1, 195101, '\p{^Is_Decomposition_Type=none}', "");
Expect(1, 195101, '\P{Is_Decomposition_Type=none}', "");
Expect(0, 195101, '\P{^Is_Decomposition_Type=none}', "");
Expect(1, 195102, '\p{Is_Decomposition_Type=_ None}', "");
Expect(0, 195102, '\p{^Is_Decomposition_Type=_ None}', "");
Expect(0, 195102, '\P{Is_Decomposition_Type=_ None}', "");
Expect(1, 195102, '\P{^Is_Decomposition_Type=_ None}', "");
Expect(0, 195101, '\p{Is_Decomposition_Type=_ None}', "");
Expect(1, 195101, '\p{^Is_Decomposition_Type=_ None}', "");
Expect(1, 195101, '\P{Is_Decomposition_Type=_ None}', "");
Expect(0, 195101, '\P{^Is_Decomposition_Type=_ None}', "");
Error('\p{Is_Dt=:=none}');
Error('\P{Is_Dt=:=none}');
Expect(1, 195102, '\p{Is_Dt=none}', "");
Expect(0, 195102, '\p{^Is_Dt=none}', "");
Expect(0, 195102, '\P{Is_Dt=none}', "");
Expect(1, 195102, '\P{^Is_Dt=none}', "");
Expect(0, 195101, '\p{Is_Dt=none}', "");
Expect(1, 195101, '\p{^Is_Dt=none}', "");
Expect(1, 195101, '\P{Is_Dt=none}', "");
Expect(0, 195101, '\P{^Is_Dt=none}', "");
Expect(1, 195102, '\p{Is_Dt=__none}', "");
Expect(0, 195102, '\p{^Is_Dt=__none}', "");
Expect(0, 195102, '\P{Is_Dt=__none}', "");
Expect(1, 195102, '\P{^Is_Dt=__none}', "");
Expect(0, 195101, '\p{Is_Dt=__none}', "");
Expect(1, 195101, '\p{^Is_Dt=__none}', "");
Expect(1, 195101, '\P{Is_Dt=__none}', "");
Expect(0, 195101, '\P{^Is_Dt=__none}', "");
Error('\p{Decomposition_Type=-small/a/}');
Error('\P{Decomposition_Type=-small/a/}');
Expect(1, 65131, '\p{Decomposition_Type:	small}', "");
Expect(0, 65131, '\p{^Decomposition_Type:	small}', "");
Expect(0, 65131, '\P{Decomposition_Type:	small}', "");
Expect(1, 65131, '\P{^Decomposition_Type:	small}', "");
Expect(0, 65132, '\p{Decomposition_Type:	small}', "");
Expect(1, 65132, '\p{^Decomposition_Type:	small}', "");
Expect(1, 65132, '\P{Decomposition_Type:	small}', "");
Expect(0, 65132, '\P{^Decomposition_Type:	small}', "");
Expect(1, 65131, '\p{Decomposition_Type=	_small}', "");
Expect(0, 65131, '\p{^Decomposition_Type=	_small}', "");
Expect(0, 65131, '\P{Decomposition_Type=	_small}', "");
Expect(1, 65131, '\P{^Decomposition_Type=	_small}', "");
Expect(0, 65132, '\p{Decomposition_Type=	_small}', "");
Expect(1, 65132, '\p{^Decomposition_Type=	_small}', "");
Expect(1, 65132, '\P{Decomposition_Type=	_small}', "");
Expect(0, 65132, '\P{^Decomposition_Type=	_small}', "");
Error('\p{Dt=__Sml/a/}');
Error('\P{Dt=__Sml/a/}');
Expect(1, 65131, '\p{Dt=sml}', "");
Expect(0, 65131, '\p{^Dt=sml}', "");
Expect(0, 65131, '\P{Dt=sml}', "");
Expect(1, 65131, '\P{^Dt=sml}', "");
Expect(0, 65132, '\p{Dt=sml}', "");
Expect(1, 65132, '\p{^Dt=sml}', "");
Expect(1, 65132, '\P{Dt=sml}', "");
Expect(0, 65132, '\P{^Dt=sml}', "");
Expect(1, 65131, '\p{Dt:_-Sml}', "");
Expect(0, 65131, '\p{^Dt:_-Sml}', "");
Expect(0, 65131, '\P{Dt:_-Sml}', "");
Expect(1, 65131, '\P{^Dt:_-Sml}', "");
Expect(0, 65132, '\p{Dt:_-Sml}', "");
Expect(1, 65132, '\p{^Dt:_-Sml}', "");
Expect(1, 65132, '\P{Dt:_-Sml}', "");
Expect(0, 65132, '\P{^Dt:_-Sml}', "");
Error('\p{Is_Decomposition_Type=:=SMALL}');
Error('\P{Is_Decomposition_Type=:=SMALL}');
Expect(1, 65131, '\p{Is_Decomposition_Type=small}', "");
Expect(0, 65131, '\p{^Is_Decomposition_Type=small}', "");
Expect(0, 65131, '\P{Is_Decomposition_Type=small}', "");
Expect(1, 65131, '\P{^Is_Decomposition_Type=small}', "");
Expect(0, 65132, '\p{Is_Decomposition_Type=small}', "");
Expect(1, 65132, '\p{^Is_Decomposition_Type=small}', "");
Expect(1, 65132, '\P{Is_Decomposition_Type=small}', "");
Expect(0, 65132, '\P{^Is_Decomposition_Type=small}', "");
Expect(1, 65131, '\p{Is_Decomposition_Type= 	Small}', "");
Expect(0, 65131, '\p{^Is_Decomposition_Type= 	Small}', "");
Expect(0, 65131, '\P{Is_Decomposition_Type= 	Small}', "");
Expect(1, 65131, '\P{^Is_Decomposition_Type= 	Small}', "");
Expect(0, 65132, '\p{Is_Decomposition_Type= 	Small}', "");
Expect(1, 65132, '\p{^Is_Decomposition_Type= 	Small}', "");
Expect(1, 65132, '\P{Is_Decomposition_Type= 	Small}', "");
Expect(0, 65132, '\P{^Is_Decomposition_Type= 	Small}', "");
Error('\p{Is_Dt:	 Sml:=}');
Error('\P{Is_Dt:	 Sml:=}');
Expect(1, 65131, '\p{Is_Dt=sml}', "");
Expect(0, 65131, '\p{^Is_Dt=sml}', "");
Expect(0, 65131, '\P{Is_Dt=sml}', "");
Expect(1, 65131, '\P{^Is_Dt=sml}', "");
Expect(0, 65132, '\p{Is_Dt=sml}', "");
Expect(1, 65132, '\p{^Is_Dt=sml}', "");
Expect(1, 65132, '\P{Is_Dt=sml}', "");
Expect(0, 65132, '\P{^Is_Dt=sml}', "");
Expect(1, 65131, '\p{Is_Dt=-	SML}', "");
Expect(0, 65131, '\p{^Is_Dt=-	SML}', "");
Expect(0, 65131, '\P{Is_Dt=-	SML}', "");
Expect(1, 65131, '\P{^Is_Dt=-	SML}', "");
Expect(0, 65132, '\p{Is_Dt=-	SML}', "");
Expect(1, 65132, '\p{^Is_Dt=-	SML}', "");
Expect(1, 65132, '\P{Is_Dt=-	SML}', "");
Expect(0, 65132, '\P{^Is_Dt=-	SML}', "");
Error('\p{Decomposition_Type=	:=Square}');
Error('\P{Decomposition_Type=	:=Square}');
Expect(1, 127546, '\p{Decomposition_Type=square}', "");
Expect(0, 127546, '\p{^Decomposition_Type=square}', "");
Expect(0, 127546, '\P{Decomposition_Type=square}', "");
Expect(1, 127546, '\P{^Decomposition_Type=square}', "");
Expect(0, 127547, '\p{Decomposition_Type=square}', "");
Expect(1, 127547, '\p{^Decomposition_Type=square}', "");
Expect(1, 127547, '\P{Decomposition_Type=square}', "");
Expect(0, 127547, '\P{^Decomposition_Type=square}', "");
Expect(1, 127546, '\p{Decomposition_Type=_Square}', "");
Expect(0, 127546, '\p{^Decomposition_Type=_Square}', "");
Expect(0, 127546, '\P{Decomposition_Type=_Square}', "");
Expect(1, 127546, '\P{^Decomposition_Type=_Square}', "");
Expect(0, 127547, '\p{Decomposition_Type=_Square}', "");
Expect(1, 127547, '\p{^Decomposition_Type=_Square}', "");
Expect(1, 127547, '\P{Decomposition_Type=_Square}', "");
Expect(0, 127547, '\P{^Decomposition_Type=_Square}', "");
Error('\p{Dt= /a/Sqr}');
Error('\P{Dt= /a/Sqr}');
Expect(1, 127546, '\p{Dt=sqr}', "");
Expect(0, 127546, '\p{^Dt=sqr}', "");
Expect(0, 127546, '\P{Dt=sqr}', "");
Expect(1, 127546, '\P{^Dt=sqr}', "");
Expect(0, 127547, '\p{Dt=sqr}', "");
Expect(1, 127547, '\p{^Dt=sqr}', "");
Expect(1, 127547, '\P{Dt=sqr}', "");
Expect(0, 127547, '\P{^Dt=sqr}', "");
Expect(1, 127546, '\p{Dt=_	sqr}', "");
Expect(0, 127546, '\p{^Dt=_	sqr}', "");
Expect(0, 127546, '\P{Dt=_	sqr}', "");
Expect(1, 127546, '\P{^Dt=_	sqr}', "");
Expect(0, 127547, '\p{Dt=_	sqr}', "");
Expect(1, 127547, '\p{^Dt=_	sqr}', "");
Expect(1, 127547, '\P{Dt=_	sqr}', "");
Expect(0, 127547, '\P{^Dt=_	sqr}', "");
Error('\p{Is_Decomposition_Type=  Square/a/}');
Error('\P{Is_Decomposition_Type=  Square/a/}');
Expect(1, 127546, '\p{Is_Decomposition_Type=square}', "");
Expect(0, 127546, '\p{^Is_Decomposition_Type=square}', "");
Expect(0, 127546, '\P{Is_Decomposition_Type=square}', "");
Expect(1, 127546, '\P{^Is_Decomposition_Type=square}', "");
Expect(0, 127547, '\p{Is_Decomposition_Type=square}', "");
Expect(1, 127547, '\p{^Is_Decomposition_Type=square}', "");
Expect(1, 127547, '\P{Is_Decomposition_Type=square}', "");
Expect(0, 127547, '\P{^Is_Decomposition_Type=square}', "");
Expect(1, 127546, '\p{Is_Decomposition_Type=-Square}', "");
Expect(0, 127546, '\p{^Is_Decomposition_Type=-Square}', "");
Expect(0, 127546, '\P{Is_Decomposition_Type=-Square}', "");
Expect(1, 127546, '\P{^Is_Decomposition_Type=-Square}', "");
Expect(0, 127547, '\p{Is_Decomposition_Type=-Square}', "");
Expect(1, 127547, '\p{^Is_Decomposition_Type=-Square}', "");
Expect(1, 127547, '\P{Is_Decomposition_Type=-Square}', "");
Expect(0, 127547, '\P{^Is_Decomposition_Type=-Square}', "");
Error('\p{Is_Dt=:= -SQR}');
Error('\P{Is_Dt=:= -SQR}');
Expect(1, 127546, '\p{Is_Dt=sqr}', "");
Expect(0, 127546, '\p{^Is_Dt=sqr}', "");
Expect(0, 127546, '\P{Is_Dt=sqr}', "");
Expect(1, 127546, '\P{^Is_Dt=sqr}', "");
Expect(0, 127547, '\p{Is_Dt=sqr}', "");
Expect(1, 127547, '\p{^Is_Dt=sqr}', "");
Expect(1, 127547, '\P{Is_Dt=sqr}', "");
Expect(0, 127547, '\P{^Is_Dt=sqr}', "");
Expect(1, 127546, '\p{Is_Dt=	sqr}', "");
Expect(0, 127546, '\p{^Is_Dt=	sqr}', "");
Expect(0, 127546, '\P{Is_Dt=	sqr}', "");
Expect(1, 127546, '\P{^Is_Dt=	sqr}', "");
Expect(0, 127547, '\p{Is_Dt=	sqr}', "");
Expect(1, 127547, '\p{^Is_Dt=	sqr}', "");
Expect(1, 127547, '\P{Is_Dt=	sqr}', "");
Expect(0, 127547, '\P{^Is_Dt=	sqr}', "");
Error('\p{Decomposition_Type=:=	SUB}');
Error('\P{Decomposition_Type=:=	SUB}');
Expect(1, 11388, '\p{Decomposition_Type=sub}', "");
Expect(0, 11388, '\p{^Decomposition_Type=sub}', "");
Expect(0, 11388, '\P{Decomposition_Type=sub}', "");
Expect(1, 11388, '\P{^Decomposition_Type=sub}', "");
Expect(0, 11389, '\p{Decomposition_Type=sub}', "");
Expect(1, 11389, '\p{^Decomposition_Type=sub}', "");
Expect(1, 11389, '\P{Decomposition_Type=sub}', "");
Expect(0, 11389, '\P{^Decomposition_Type=sub}', "");
Expect(1, 11388, '\p{Decomposition_Type= Sub}', "");
Expect(0, 11388, '\p{^Decomposition_Type= Sub}', "");
Expect(0, 11388, '\P{Decomposition_Type= Sub}', "");
Expect(1, 11388, '\P{^Decomposition_Type= Sub}', "");
Expect(0, 11389, '\p{Decomposition_Type= Sub}', "");
Expect(1, 11389, '\p{^Decomposition_Type= Sub}', "");
Expect(1, 11389, '\P{Decomposition_Type= Sub}', "");
Expect(0, 11389, '\P{^Decomposition_Type= Sub}', "");
Error('\p{Dt=-_SUB/a/}');
Error('\P{Dt=-_SUB/a/}');
Expect(1, 11388, '\p{Dt=sub}', "");
Expect(0, 11388, '\p{^Dt=sub}', "");
Expect(0, 11388, '\P{Dt=sub}', "");
Expect(1, 11388, '\P{^Dt=sub}', "");
Expect(0, 11389, '\p{Dt=sub}', "");
Expect(1, 11389, '\p{^Dt=sub}', "");
Expect(1, 11389, '\P{Dt=sub}', "");
Expect(0, 11389, '\P{^Dt=sub}', "");
Expect(1, 11388, '\p{Dt=--sub}', "");
Expect(0, 11388, '\p{^Dt=--sub}', "");
Expect(0, 11388, '\P{Dt=--sub}', "");
Expect(1, 11388, '\P{^Dt=--sub}', "");
Expect(0, 11389, '\p{Dt=--sub}', "");
Expect(1, 11389, '\p{^Dt=--sub}', "");
Expect(1, 11389, '\P{Dt=--sub}', "");
Expect(0, 11389, '\P{^Dt=--sub}', "");
Error('\p{Is_Decomposition_Type= -SUB:=}');
Error('\P{Is_Decomposition_Type= -SUB:=}');
Expect(1, 11388, '\p{Is_Decomposition_Type:	sub}', "");
Expect(0, 11388, '\p{^Is_Decomposition_Type:	sub}', "");
Expect(0, 11388, '\P{Is_Decomposition_Type:	sub}', "");
Expect(1, 11388, '\P{^Is_Decomposition_Type:	sub}', "");
Expect(0, 11389, '\p{Is_Decomposition_Type:	sub}', "");
Expect(1, 11389, '\p{^Is_Decomposition_Type:	sub}', "");
Expect(1, 11389, '\P{Is_Decomposition_Type:	sub}', "");
Expect(0, 11389, '\P{^Is_Decomposition_Type:	sub}', "");
Expect(1, 11388, '\p{Is_Decomposition_Type=-_Sub}', "");
Expect(0, 11388, '\p{^Is_Decomposition_Type=-_Sub}', "");
Expect(0, 11388, '\P{Is_Decomposition_Type=-_Sub}', "");
Expect(1, 11388, '\P{^Is_Decomposition_Type=-_Sub}', "");
Expect(0, 11389, '\p{Is_Decomposition_Type=-_Sub}', "");
Expect(1, 11389, '\p{^Is_Decomposition_Type=-_Sub}', "");
Expect(1, 11389, '\P{Is_Decomposition_Type=-_Sub}', "");
Expect(0, 11389, '\P{^Is_Decomposition_Type=-_Sub}', "");
Error('\p{Is_Dt=-:=sub}');
Error('\P{Is_Dt=-:=sub}');
Expect(1, 11388, '\p{Is_Dt=sub}', "");
Expect(0, 11388, '\p{^Is_Dt=sub}', "");
Expect(0, 11388, '\P{Is_Dt=sub}', "");
Expect(1, 11388, '\P{^Is_Dt=sub}', "");
Expect(0, 11389, '\p{Is_Dt=sub}', "");
Expect(1, 11389, '\p{^Is_Dt=sub}', "");
Expect(1, 11389, '\P{Is_Dt=sub}', "");
Expect(0, 11389, '\P{^Is_Dt=sub}', "");
Expect(1, 11388, '\p{Is_Dt= Sub}', "");
Expect(0, 11388, '\p{^Is_Dt= Sub}', "");
Expect(0, 11388, '\P{Is_Dt= Sub}', "");
Expect(1, 11388, '\P{^Is_Dt= Sub}', "");
Expect(0, 11389, '\p{Is_Dt= Sub}', "");
Expect(1, 11389, '\p{^Is_Dt= Sub}', "");
Expect(1, 11389, '\P{Is_Dt= Sub}', "");
Expect(0, 11389, '\P{^Is_Dt= Sub}', "");
Error('\p{Decomposition_Type=/a/ 	SUPER}');
Error('\P{Decomposition_Type=/a/ 	SUPER}');
Expect(1, 127339, '\p{Decomposition_Type:	super}', "");
Expect(0, 127339, '\p{^Decomposition_Type:	super}', "");
Expect(0, 127339, '\P{Decomposition_Type:	super}', "");
Expect(1, 127339, '\P{^Decomposition_Type:	super}', "");
Expect(0, 127340, '\p{Decomposition_Type:	super}', "");
Expect(1, 127340, '\p{^Decomposition_Type:	super}', "");
Expect(1, 127340, '\P{Decomposition_Type:	super}', "");
Expect(0, 127340, '\P{^Decomposition_Type:	super}', "");
Expect(1, 127339, '\p{Decomposition_Type= SUPER}', "");
Expect(0, 127339, '\p{^Decomposition_Type= SUPER}', "");
Expect(0, 127339, '\P{Decomposition_Type= SUPER}', "");
Expect(1, 127339, '\P{^Decomposition_Type= SUPER}', "");
Expect(0, 127340, '\p{Decomposition_Type= SUPER}', "");
Expect(1, 127340, '\p{^Decomposition_Type= SUPER}', "");
Expect(1, 127340, '\P{Decomposition_Type= SUPER}', "");
Expect(0, 127340, '\P{^Decomposition_Type= SUPER}', "");
Error('\p{Dt=_:=Sup}');
Error('\P{Dt=_:=Sup}');
Expect(1, 127339, '\p{Dt=sup}', "");
Expect(0, 127339, '\p{^Dt=sup}', "");
Expect(0, 127339, '\P{Dt=sup}', "");
Expect(1, 127339, '\P{^Dt=sup}', "");
Expect(0, 127340, '\p{Dt=sup}', "");
Expect(1, 127340, '\p{^Dt=sup}', "");
Expect(1, 127340, '\P{Dt=sup}', "");
Expect(0, 127340, '\P{^Dt=sup}', "");
Expect(1, 127339, '\p{Dt=	_SUP}', "");
Expect(0, 127339, '\p{^Dt=	_SUP}', "");
Expect(0, 127339, '\P{Dt=	_SUP}', "");
Expect(1, 127339, '\P{^Dt=	_SUP}', "");
Expect(0, 127340, '\p{Dt=	_SUP}', "");
Expect(1, 127340, '\p{^Dt=	_SUP}', "");
Expect(1, 127340, '\P{Dt=	_SUP}', "");
Expect(0, 127340, '\P{^Dt=	_SUP}', "");
Error('\p{Is_Decomposition_Type=-Super:=}');
Error('\P{Is_Decomposition_Type=-Super:=}');
Expect(1, 127339, '\p{Is_Decomposition_Type=super}', "");
Expect(0, 127339, '\p{^Is_Decomposition_Type=super}', "");
Expect(0, 127339, '\P{Is_Decomposition_Type=super}', "");
Expect(1, 127339, '\P{^Is_Decomposition_Type=super}', "");
Expect(0, 127340, '\p{Is_Decomposition_Type=super}', "");
Expect(1, 127340, '\p{^Is_Decomposition_Type=super}', "");
Expect(1, 127340, '\P{Is_Decomposition_Type=super}', "");
Expect(0, 127340, '\P{^Is_Decomposition_Type=super}', "");
Expect(1, 127339, '\p{Is_Decomposition_Type:  _Super}', "");
Expect(0, 127339, '\p{^Is_Decomposition_Type:  _Super}', "");
Expect(0, 127339, '\P{Is_Decomposition_Type:  _Super}', "");
Expect(1, 127339, '\P{^Is_Decomposition_Type:  _Super}', "");
Expect(0, 127340, '\p{Is_Decomposition_Type:  _Super}', "");
Expect(1, 127340, '\p{^Is_Decomposition_Type:  _Super}', "");
Expect(1, 127340, '\P{Is_Decomposition_Type:  _Super}', "");
Expect(0, 127340, '\P{^Is_Decomposition_Type:  _Super}', "");
Error('\p{Is_Dt=:=Sup}');
Error('\P{Is_Dt=:=Sup}');
Expect(1, 127339, '\p{Is_Dt=sup}', "");
Expect(0, 127339, '\p{^Is_Dt=sup}', "");
Expect(0, 127339, '\P{Is_Dt=sup}', "");
Expect(1, 127339, '\P{^Is_Dt=sup}', "");
Expect(0, 127340, '\p{Is_Dt=sup}', "");
Expect(1, 127340, '\p{^Is_Dt=sup}', "");
Expect(1, 127340, '\P{Is_Dt=sup}', "");
Expect(0, 127340, '\P{^Is_Dt=sup}', "");
Expect(1, 127339, '\p{Is_Dt=_-Sup}', "");
Expect(0, 127339, '\p{^Is_Dt=_-Sup}', "");
Expect(0, 127339, '\P{Is_Dt=_-Sup}', "");
Expect(1, 127339, '\P{^Is_Dt=_-Sup}', "");
Expect(0, 127340, '\p{Is_Dt=_-Sup}', "");
Expect(1, 127340, '\p{^Is_Dt=_-Sup}', "");
Expect(1, 127340, '\P{Is_Dt=_-Sup}', "");
Expect(0, 127340, '\P{^Is_Dt=_-Sup}', "");
Error('\p{Decomposition_Type= Vertical/a/}');
Error('\P{Decomposition_Type= Vertical/a/}');
Expect(1, 65096, '\p{Decomposition_Type=vertical}', "");
Expect(0, 65096, '\p{^Decomposition_Type=vertical}', "");
Expect(0, 65096, '\P{Decomposition_Type=vertical}', "");
Expect(1, 65096, '\P{^Decomposition_Type=vertical}', "");
Expect(0, 65097, '\p{Decomposition_Type=vertical}', "");
Expect(1, 65097, '\p{^Decomposition_Type=vertical}', "");
Expect(1, 65097, '\P{Decomposition_Type=vertical}', "");
Expect(0, 65097, '\P{^Decomposition_Type=vertical}', "");
Expect(1, 65096, '\p{Decomposition_Type= 	vertical}', "");
Expect(0, 65096, '\p{^Decomposition_Type= 	vertical}', "");
Expect(0, 65096, '\P{Decomposition_Type= 	vertical}', "");
Expect(1, 65096, '\P{^Decomposition_Type= 	vertical}', "");
Expect(0, 65097, '\p{Decomposition_Type= 	vertical}', "");
Expect(1, 65097, '\p{^Decomposition_Type= 	vertical}', "");
Expect(1, 65097, '\P{Decomposition_Type= 	vertical}', "");
Expect(0, 65097, '\P{^Decomposition_Type= 	vertical}', "");
Error('\p{Dt= 	Vert:=}');
Error('\P{Dt= 	Vert:=}');
Expect(1, 65096, '\p{Dt: vert}', "");
Expect(0, 65096, '\p{^Dt: vert}', "");
Expect(0, 65096, '\P{Dt: vert}', "");
Expect(1, 65096, '\P{^Dt: vert}', "");
Expect(0, 65097, '\p{Dt: vert}', "");
Expect(1, 65097, '\p{^Dt: vert}', "");
Expect(1, 65097, '\P{Dt: vert}', "");
Expect(0, 65097, '\P{^Dt: vert}', "");
Expect(1, 65096, '\p{Dt=-Vert}', "");
Expect(0, 65096, '\p{^Dt=-Vert}', "");
Expect(0, 65096, '\P{Dt=-Vert}', "");
Expect(1, 65096, '\P{^Dt=-Vert}', "");
Expect(0, 65097, '\p{Dt=-Vert}', "");
Expect(1, 65097, '\p{^Dt=-Vert}', "");
Expect(1, 65097, '\P{Dt=-Vert}', "");
Expect(0, 65097, '\P{^Dt=-Vert}', "");
Error('\p{Is_Decomposition_Type: -VERTICAL/a/}');
Error('\P{Is_Decomposition_Type: -VERTICAL/a/}');
Expect(1, 65096, '\p{Is_Decomposition_Type=vertical}', "");
Expect(0, 65096, '\p{^Is_Decomposition_Type=vertical}', "");
Expect(0, 65096, '\P{Is_Decomposition_Type=vertical}', "");
Expect(1, 65096, '\P{^Is_Decomposition_Type=vertical}', "");
Expect(0, 65097, '\p{Is_Decomposition_Type=vertical}', "");
Expect(1, 65097, '\p{^Is_Decomposition_Type=vertical}', "");
Expect(1, 65097, '\P{Is_Decomposition_Type=vertical}', "");
Expect(0, 65097, '\P{^Is_Decomposition_Type=vertical}', "");
Expect(1, 65096, '\p{Is_Decomposition_Type= Vertical}', "");
Expect(0, 65096, '\p{^Is_Decomposition_Type= Vertical}', "");
Expect(0, 65096, '\P{Is_Decomposition_Type= Vertical}', "");
Expect(1, 65096, '\P{^Is_Decomposition_Type= Vertical}', "");
Expect(0, 65097, '\p{Is_Decomposition_Type= Vertical}', "");
Expect(1, 65097, '\p{^Is_Decomposition_Type= Vertical}', "");
Expect(1, 65097, '\P{Is_Decomposition_Type= Vertical}', "");
Expect(0, 65097, '\P{^Is_Decomposition_Type= Vertical}', "");
Error('\p{Is_Dt=/a/		Vert}');
Error('\P{Is_Dt=/a/		Vert}');
Expect(1, 65096, '\p{Is_Dt=vert}', "");
Expect(0, 65096, '\p{^Is_Dt=vert}', "");
Expect(0, 65096, '\P{Is_Dt=vert}', "");
Expect(1, 65096, '\P{^Is_Dt=vert}', "");
Expect(0, 65097, '\p{Is_Dt=vert}', "");
Expect(1, 65097, '\p{^Is_Dt=vert}', "");
Expect(1, 65097, '\P{Is_Dt=vert}', "");
Expect(0, 65097, '\P{^Is_Dt=vert}', "");
Expect(1, 65096, '\p{Is_Dt= vert}', "");
Expect(0, 65096, '\p{^Is_Dt= vert}', "");
Expect(0, 65096, '\P{Is_Dt= vert}', "");
Expect(1, 65096, '\P{^Is_Dt= vert}', "");
Expect(0, 65097, '\p{Is_Dt= vert}', "");
Expect(1, 65097, '\p{^Is_Dt= vert}', "");
Expect(1, 65097, '\P{Is_Dt= vert}', "");
Expect(0, 65097, '\P{^Is_Dt= vert}', "");
Error('\p{Decomposition_Type=:=_-WIDE}');
Error('\P{Decomposition_Type=:=_-WIDE}');
Expect(1, 65510, '\p{Decomposition_Type=wide}', "");
Expect(0, 65510, '\p{^Decomposition_Type=wide}', "");
Expect(0, 65510, '\P{Decomposition_Type=wide}', "");
Expect(1, 65510, '\P{^Decomposition_Type=wide}', "");
Expect(0, 65511, '\p{Decomposition_Type=wide}', "");
Expect(1, 65511, '\p{^Decomposition_Type=wide}', "");
Expect(1, 65511, '\P{Decomposition_Type=wide}', "");
Expect(0, 65511, '\P{^Decomposition_Type=wide}', "");
Expect(1, 65510, '\p{Decomposition_Type=-_wide}', "");
Expect(0, 65510, '\p{^Decomposition_Type=-_wide}', "");
Expect(0, 65510, '\P{Decomposition_Type=-_wide}', "");
Expect(1, 65510, '\P{^Decomposition_Type=-_wide}', "");
Expect(0, 65511, '\p{Decomposition_Type=-_wide}', "");
Expect(1, 65511, '\p{^Decomposition_Type=-_wide}', "");
Expect(1, 65511, '\P{Decomposition_Type=-_wide}', "");
Expect(0, 65511, '\P{^Decomposition_Type=-_wide}', "");
Error('\p{Dt=:=-Wide}');
Error('\P{Dt=:=-Wide}');
Expect(1, 65510, '\p{Dt=wide}', "");
Expect(0, 65510, '\p{^Dt=wide}', "");
Expect(0, 65510, '\P{Dt=wide}', "");
Expect(1, 65510, '\P{^Dt=wide}', "");
Expect(0, 65511, '\p{Dt=wide}', "");
Expect(1, 65511, '\p{^Dt=wide}', "");
Expect(1, 65511, '\P{Dt=wide}', "");
Expect(0, 65511, '\P{^Dt=wide}', "");
Expect(1, 65510, '\p{Dt:	_wide}', "");
Expect(0, 65510, '\p{^Dt:	_wide}', "");
Expect(0, 65510, '\P{Dt:	_wide}', "");
Expect(1, 65510, '\P{^Dt:	_wide}', "");
Expect(0, 65511, '\p{Dt:	_wide}', "");
Expect(1, 65511, '\p{^Dt:	_wide}', "");
Expect(1, 65511, '\P{Dt:	_wide}', "");
Expect(0, 65511, '\P{^Dt:	_wide}', "");
Error('\p{Is_Decomposition_Type=:= _Wide}');
Error('\P{Is_Decomposition_Type=:= _Wide}');
Expect(1, 65510, '\p{Is_Decomposition_Type=wide}', "");
Expect(0, 65510, '\p{^Is_Decomposition_Type=wide}', "");
Expect(0, 65510, '\P{Is_Decomposition_Type=wide}', "");
Expect(1, 65510, '\P{^Is_Decomposition_Type=wide}', "");
Expect(0, 65511, '\p{Is_Decomposition_Type=wide}', "");
Expect(1, 65511, '\p{^Is_Decomposition_Type=wide}', "");
Expect(1, 65511, '\P{Is_Decomposition_Type=wide}', "");
Expect(0, 65511, '\P{^Is_Decomposition_Type=wide}', "");
Expect(1, 65510, '\p{Is_Decomposition_Type= WIDE}', "");
Expect(0, 65510, '\p{^Is_Decomposition_Type= WIDE}', "");
Expect(0, 65510, '\P{Is_Decomposition_Type= WIDE}', "");
Expect(1, 65510, '\P{^Is_Decomposition_Type= WIDE}', "");
Expect(0, 65511, '\p{Is_Decomposition_Type= WIDE}', "");
Expect(1, 65511, '\p{^Is_Decomposition_Type= WIDE}', "");
Expect(1, 65511, '\P{Is_Decomposition_Type= WIDE}', "");
Expect(0, 65511, '\P{^Is_Decomposition_Type= WIDE}', "");
Error('\p{Is_Dt=_Wide/a/}');
Error('\P{Is_Dt=_Wide/a/}');
Expect(1, 65510, '\p{Is_Dt=wide}', "");
Expect(0, 65510, '\p{^Is_Dt=wide}', "");
Expect(0, 65510, '\P{Is_Dt=wide}', "");
Expect(1, 65510, '\P{^Is_Dt=wide}', "");
Expect(0, 65511, '\p{Is_Dt=wide}', "");
Expect(1, 65511, '\p{^Is_Dt=wide}', "");
Expect(1, 65511, '\P{Is_Dt=wide}', "");
Expect(0, 65511, '\P{^Is_Dt=wide}', "");
Expect(1, 65510, '\p{Is_Dt:_wide}', "");
Expect(0, 65510, '\p{^Is_Dt:_wide}', "");
Expect(0, 65510, '\P{Is_Dt:_wide}', "");
Expect(1, 65510, '\P{^Is_Dt:_wide}', "");
Expect(0, 65511, '\p{Is_Dt:_wide}', "");
Expect(1, 65511, '\p{^Is_Dt:_wide}', "");
Expect(1, 65511, '\P{Is_Dt:_wide}', "");
Expect(0, 65511, '\P{^Is_Dt:_wide}', "");
Error('\p{East_Asian_Width=/a/ _AMBIGUOUS}');
Error('\P{East_Asian_Width=/a/ _AMBIGUOUS}');
Expect(1, 1114109, '\p{East_Asian_Width=ambiguous}', "");
Expect(0, 1114109, '\p{^East_Asian_Width=ambiguous}', "");
Expect(0, 1114109, '\P{East_Asian_Width=ambiguous}', "");
Expect(1, 1114109, '\P{^East_Asian_Width=ambiguous}', "");
Expect(0, 918000, '\p{East_Asian_Width=ambiguous}', "");
Expect(1, 918000, '\p{^East_Asian_Width=ambiguous}', "");
Expect(1, 918000, '\P{East_Asian_Width=ambiguous}', "");
Expect(0, 918000, '\P{^East_Asian_Width=ambiguous}', "");
Expect(1, 1114109, '\p{East_Asian_Width=	_AMBIGUOUS}', "");
Expect(0, 1114109, '\p{^East_Asian_Width=	_AMBIGUOUS}', "");
Expect(0, 1114109, '\P{East_Asian_Width=	_AMBIGUOUS}', "");
Expect(1, 1114109, '\P{^East_Asian_Width=	_AMBIGUOUS}', "");
Expect(0, 918000, '\p{East_Asian_Width=	_AMBIGUOUS}', "");
Expect(1, 918000, '\p{^East_Asian_Width=	_AMBIGUOUS}', "");
Expect(1, 918000, '\P{East_Asian_Width=	_AMBIGUOUS}', "");
Expect(0, 918000, '\P{^East_Asian_Width=	_AMBIGUOUS}', "");
Error('\p{Ea= -a/a/}');
Error('\P{Ea= -a/a/}');
Expect(1, 1114109, '\p{Ea=a}', "");
Expect(0, 1114109, '\p{^Ea=a}', "");
Expect(0, 1114109, '\P{Ea=a}', "");
Expect(1, 1114109, '\P{^Ea=a}', "");
Expect(0, 918000, '\p{Ea=a}', "");
Expect(1, 918000, '\p{^Ea=a}', "");
Expect(1, 918000, '\P{Ea=a}', "");
Expect(0, 918000, '\P{^Ea=a}', "");
Expect(1, 1114109, '\p{Ea:    A}', "");
Expect(0, 1114109, '\p{^Ea:    A}', "");
Expect(0, 1114109, '\P{Ea:    A}', "");
Expect(1, 1114109, '\P{^Ea:    A}', "");
Expect(0, 918000, '\p{Ea:    A}', "");
Expect(1, 918000, '\p{^Ea:    A}', "");
Expect(1, 918000, '\P{Ea:    A}', "");
Expect(0, 918000, '\P{^Ea:    A}', "");
Error('\p{Is_East_Asian_Width=/a/-	ambiguous}');
Error('\P{Is_East_Asian_Width=/a/-	ambiguous}');
Expect(1, 1114109, '\p{Is_East_Asian_Width:ambiguous}', "");
Expect(0, 1114109, '\p{^Is_East_Asian_Width:ambiguous}', "");
Expect(0, 1114109, '\P{Is_East_Asian_Width:ambiguous}', "");
Expect(1, 1114109, '\P{^Is_East_Asian_Width:ambiguous}', "");
Expect(0, 918000, '\p{Is_East_Asian_Width:ambiguous}', "");
Expect(1, 918000, '\p{^Is_East_Asian_Width:ambiguous}', "");
Expect(1, 918000, '\P{Is_East_Asian_Width:ambiguous}', "");
Expect(0, 918000, '\P{^Is_East_Asian_Width:ambiguous}', "");
Expect(1, 1114109, '\p{Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(0, 1114109, '\p{^Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(0, 1114109, '\P{Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(1, 1114109, '\P{^Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(0, 918000, '\p{Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(1, 918000, '\p{^Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(1, 918000, '\P{Is_East_Asian_Width=	-AMBIGUOUS}', "");
Expect(0, 918000, '\P{^Is_East_Asian_Width=	-AMBIGUOUS}', "");
Error('\p{Is_Ea=:=_A}');
Error('\P{Is_Ea=:=_A}');
Expect(1, 1114109, '\p{Is_Ea=a}', "");
Expect(0, 1114109, '\p{^Is_Ea=a}', "");
Expect(0, 1114109, '\P{Is_Ea=a}', "");
Expect(1, 1114109, '\P{^Is_Ea=a}', "");
Expect(0, 918000, '\p{Is_Ea=a}', "");
Expect(1, 918000, '\p{^Is_Ea=a}', "");
Expect(1, 918000, '\P{Is_Ea=a}', "");
Expect(0, 918000, '\P{^Is_Ea=a}', "");
Expect(1, 1114109, '\p{Is_Ea=-	a}', "");
Expect(0, 1114109, '\p{^Is_Ea=-	a}', "");
Expect(0, 1114109, '\P{Is_Ea=-	a}', "");
Expect(1, 1114109, '\P{^Is_Ea=-	a}', "");
Expect(0, 918000, '\p{Is_Ea=-	a}', "");
Expect(1, 918000, '\p{^Is_Ea=-	a}', "");
Expect(1, 918000, '\P{Is_Ea=-	a}', "");
Expect(0, 918000, '\P{^Is_Ea=-	a}', "");
Error('\p{East_Asian_Width:   :=fullwidth}');
Error('\P{East_Asian_Width:   :=fullwidth}');
Expect(1, 65510, '\p{East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\p{^East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\P{East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\P{^East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\p{East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\p{^East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\P{East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\P{^East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\p{East_Asian_Width=-_fullwidth}', "");
Expect(0, 65510, '\p{^East_Asian_Width=-_fullwidth}', "");
Expect(0, 65510, '\P{East_Asian_Width=-_fullwidth}', "");
Expect(1, 65510, '\P{^East_Asian_Width=-_fullwidth}', "");
Expect(0, 65511, '\p{East_Asian_Width=-_fullwidth}', "");
Expect(1, 65511, '\p{^East_Asian_Width=-_fullwidth}', "");
Expect(1, 65511, '\P{East_Asian_Width=-_fullwidth}', "");
Expect(0, 65511, '\P{^East_Asian_Width=-_fullwidth}', "");
Error('\p{Ea=/a/  F}');
Error('\P{Ea=/a/  F}');
Expect(1, 65510, '\p{Ea=f}', "");
Expect(0, 65510, '\p{^Ea=f}', "");
Expect(0, 65510, '\P{Ea=f}', "");
Expect(1, 65510, '\P{^Ea=f}', "");
Expect(0, 65511, '\p{Ea=f}', "");
Expect(1, 65511, '\p{^Ea=f}', "");
Expect(1, 65511, '\P{Ea=f}', "");
Expect(0, 65511, '\P{^Ea=f}', "");
Expect(1, 65510, '\p{Ea=	F}', "");
Expect(0, 65510, '\p{^Ea=	F}', "");
Expect(0, 65510, '\P{Ea=	F}', "");
Expect(1, 65510, '\P{^Ea=	F}', "");
Expect(0, 65511, '\p{Ea=	F}', "");
Expect(1, 65511, '\p{^Ea=	F}', "");
Expect(1, 65511, '\P{Ea=	F}', "");
Expect(0, 65511, '\P{^Ea=	F}', "");
Error('\p{Is_East_Asian_Width= :=Fullwidth}');
Error('\P{Is_East_Asian_Width= :=Fullwidth}');
Expect(1, 65510, '\p{Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\p{^Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65510, '\P{Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65510, '\P{^Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\p{Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\p{^Is_East_Asian_Width=fullwidth}', "");
Expect(1, 65511, '\P{Is_East_Asian_Width=fullwidth}', "");
Expect(0, 65511, '\P{^Is_East_Asian_Width=fullwidth}', "");
Error('\p{Is_Ea=:=_F}');
Error('\P{Is_Ea=:=_F}');
Expect(1, 65510, '\p{Is_Ea=f}', "");
Expect(0, 65510, '\p{^Is_Ea=f}', "");
Expect(0, 65510, '\P{Is_Ea=f}', "");
Expect(1, 65510, '\P{^Is_Ea=f}', "");
Expect(0, 65511, '\p{Is_Ea=f}', "");
Expect(1, 65511, '\p{^Is_Ea=f}', "");
Expect(1, 65511, '\P{Is_Ea=f}', "");
Expect(0, 65511, '\P{^Is_Ea=f}', "");
Expect(1, 65510, '\p{Is_Ea=-_F}', "");
Expect(0, 65510, '\p{^Is_Ea=-_F}', "");
Expect(0, 65510, '\P{Is_Ea=-_F}', "");
Expect(1, 65510, '\P{^Is_Ea=-_F}', "");
Expect(0, 65511, '\p{Is_Ea=-_F}', "");
Expect(1, 65511, '\p{^Is_Ea=-_F}', "");
Expect(1, 65511, '\P{Is_Ea=-_F}', "");
Expect(0, 65511, '\P{^Is_Ea=-_F}', "");
Error('\p{East_Asian_Width= :=Halfwidth}');
Error('\P{East_Asian_Width= :=Halfwidth}');
Expect(1, 65518, '\p{East_Asian_Width=halfwidth}', "");
Expect(0, 65518, '\p{^East_Asian_Width=halfwidth}', "");
Expect(0, 65518, '\P{East_Asian_Width=halfwidth}', "");
Expect(1, 65518, '\P{^East_Asian_Width=halfwidth}', "");
Expect(0, 65519, '\p{East_Asian_Width=halfwidth}', "");
Expect(1, 65519, '\p{^East_Asian_Width=halfwidth}', "");
Expect(1, 65519, '\P{East_Asian_Width=halfwidth}', "");
Expect(0, 65519, '\P{^East_Asian_Width=halfwidth}', "");
Expect(1, 65518, '\p{East_Asian_Width= -halfwidth}', "");
Expect(0, 65518, '\p{^East_Asian_Width= -halfwidth}', "");
Expect(0, 65518, '\P{East_Asian_Width= -halfwidth}', "");
Expect(1, 65518, '\P{^East_Asian_Width= -halfwidth}', "");
Expect(0, 65519, '\p{East_Asian_Width= -halfwidth}', "");
Expect(1, 65519, '\p{^East_Asian_Width= -halfwidth}', "");
Expect(1, 65519, '\P{East_Asian_Width= -halfwidth}', "");
Expect(0, 65519, '\P{^East_Asian_Width= -halfwidth}', "");
Error('\p{Ea=:= H}');
Error('\P{Ea=:= H}');
Expect(1, 65518, '\p{Ea=h}', "");
Expect(0, 65518, '\p{^Ea=h}', "");
Expect(0, 65518, '\P{Ea=h}', "");
Expect(1, 65518, '\P{^Ea=h}', "");
Expect(0, 65519, '\p{Ea=h}', "");
Expect(1, 65519, '\p{^Ea=h}', "");
Expect(1, 65519, '\P{Ea=h}', "");
Expect(0, 65519, '\P{^Ea=h}', "");
Expect(1, 65518, '\p{Ea= -H}', "");
Expect(0, 65518, '\p{^Ea= -H}', "");
Expect(0, 65518, '\P{Ea= -H}', "");
Expect(1, 65518, '\P{^Ea= -H}', "");
Expect(0, 65519, '\p{Ea= -H}', "");
Expect(1, 65519, '\p{^Ea= -H}', "");
Expect(1, 65519, '\P{Ea= -H}', "");
Expect(0, 65519, '\P{^Ea= -H}', "");
Error('\p{Is_East_Asian_Width=_halfwidth/a/}');
Error('\P{Is_East_Asian_Width=_halfwidth/a/}');
Expect(1, 65518, '\p{Is_East_Asian_Width=halfwidth}', "");
Expect(0, 65518, '\p{^Is_East_Asian_Width=halfwidth}', "");
Expect(0, 65518, '\P{Is_East_Asian_Width=halfwidth}', "");
Expect(1, 65518, '\P{^Is_East_Asian_Width=halfwidth}', "");
Expect(0, 65519, '\p{Is_East_Asian_Width=halfwidth}', "");
Expect(1, 65519, '\p{^Is_East_Asian_Width=halfwidth}', "");
Expect(1, 65519, '\P{Is_East_Asian_Width=halfwidth}', "");
Expect(0, 65519, '\P{^Is_East_Asian_Width=halfwidth}', "");
Expect(1, 65518, '\p{Is_East_Asian_Width= Halfwidth}', "");
Expect(0, 65518, '\p{^Is_East_Asian_Width= Halfwidth}', "");
Expect(0, 65518, '\P{Is_East_Asian_Width= Halfwidth}', "");
Expect(1, 65518, '\P{^Is_East_Asian_Width= Halfwidth}', "");
Expect(0, 65519, '\p{Is_East_Asian_Width= Halfwidth}', "");
Expect(1, 65519, '\p{^Is_East_Asian_Width= Halfwidth}', "");
Expect(1, 65519, '\P{Is_East_Asian_Width= Halfwidth}', "");
Expect(0, 65519, '\P{^Is_East_Asian_Width= Halfwidth}', "");
Error('\p{Is_Ea: __H/a/}');
Error('\P{Is_Ea: __H/a/}');
Expect(1, 65518, '\p{Is_Ea=h}', "");
Expect(0, 65518, '\p{^Is_Ea=h}', "");
Expect(0, 65518, '\P{Is_Ea=h}', "");
Expect(1, 65518, '\P{^Is_Ea=h}', "");
Expect(0, 65519, '\p{Is_Ea=h}', "");
Expect(1, 65519, '\p{^Is_Ea=h}', "");
Expect(1, 65519, '\P{Is_Ea=h}', "");
Expect(0, 65519, '\P{^Is_Ea=h}', "");
Expect(1, 65518, '\p{Is_Ea: H}', "");
Expect(0, 65518, '\p{^Is_Ea: H}', "");
Expect(0, 65518, '\P{Is_Ea: H}', "");
Expect(1, 65518, '\P{^Is_Ea: H}', "");
Expect(0, 65519, '\p{Is_Ea: H}', "");
Expect(1, 65519, '\p{^Is_Ea: H}', "");
Expect(1, 65519, '\P{Is_Ea: H}', "");
Expect(0, 65519, '\P{^Is_Ea: H}', "");
Error('\p{East_Asian_Width=- NEUTRAL/a/}');
Error('\P{East_Asian_Width=- NEUTRAL/a/}');
Expect(1, 918000, '\p{East_Asian_Width=neutral}', "");
Expect(0, 918000, '\p{^East_Asian_Width=neutral}', "");
Expect(0, 918000, '\P{East_Asian_Width=neutral}', "");
Expect(1, 918000, '\P{^East_Asian_Width=neutral}', "");
Expect(0, 1114109, '\p{East_Asian_Width=neutral}', "");
Expect(1, 1114109, '\p{^East_Asian_Width=neutral}', "");
Expect(1, 1114109, '\P{East_Asian_Width=neutral}', "");
Expect(0, 1114109, '\P{^East_Asian_Width=neutral}', "");
Expect(1, 918000, '\p{East_Asian_Width=_NEUTRAL}', "");
Expect(0, 918000, '\p{^East_Asian_Width=_NEUTRAL}', "");
Expect(0, 918000, '\P{East_Asian_Width=_NEUTRAL}', "");
Expect(1, 918000, '\P{^East_Asian_Width=_NEUTRAL}', "");
Expect(0, 1114109, '\p{East_Asian_Width=_NEUTRAL}', "");
Expect(1, 1114109, '\p{^East_Asian_Width=_NEUTRAL}', "");
Expect(1, 1114109, '\P{East_Asian_Width=_NEUTRAL}', "");
Expect(0, 1114109, '\P{^East_Asian_Width=_NEUTRAL}', "");
Error('\p{Ea=:=		N}');
Error('\P{Ea=:=		N}');
Expect(1, 918000, '\p{Ea=n}', "");
Expect(0, 918000, '\p{^Ea=n}', "");
Expect(0, 918000, '\P{Ea=n}', "");
Expect(1, 918000, '\P{^Ea=n}', "");
Expect(0, 1114109, '\p{Ea=n}', "");
Expect(1, 1114109, '\p{^Ea=n}', "");
Expect(1, 1114109, '\P{Ea=n}', "");
Expect(0, 1114109, '\P{^Ea=n}', "");
Expect(1, 918000, '\p{Ea= _N}', "");
Expect(0, 918000, '\p{^Ea= _N}', "");
Expect(0, 918000, '\P{Ea= _N}', "");
Expect(1, 918000, '\P{^Ea= _N}', "");
Expect(0, 1114109, '\p{Ea= _N}', "");
Expect(1, 1114109, '\p{^Ea= _N}', "");
Expect(1, 1114109, '\P{Ea= _N}', "");
Expect(0, 1114109, '\P{^Ea= _N}', "");
Error('\p{Is_East_Asian_Width=:=Neutral}');
Error('\P{Is_East_Asian_Width=:=Neutral}');
Expect(1, 918000, '\p{Is_East_Asian_Width=neutral}', "");
Expect(0, 918000, '\p{^Is_East_Asian_Width=neutral}', "");
Expect(0, 918000, '\P{Is_East_Asian_Width=neutral}', "");
Expect(1, 918000, '\P{^Is_East_Asian_Width=neutral}', "");
Expect(0, 1114109, '\p{Is_East_Asian_Width=neutral}', "");
Expect(1, 1114109, '\p{^Is_East_Asian_Width=neutral}', "");
Expect(1, 1114109, '\P{Is_East_Asian_Width=neutral}', "");
Expect(0, 1114109, '\P{^Is_East_Asian_Width=neutral}', "");
Expect(1, 918000, '\p{Is_East_Asian_Width=_ Neutral}', "");
Expect(0, 918000, '\p{^Is_East_Asian_Width=_ Neutral}', "");
Expect(0, 918000, '\P{Is_East_Asian_Width=_ Neutral}', "");
Expect(1, 918000, '\P{^Is_East_Asian_Width=_ Neutral}', "");
Expect(0, 1114109, '\p{Is_East_Asian_Width=_ Neutral}', "");
Expect(1, 1114109, '\p{^Is_East_Asian_Width=_ Neutral}', "");
Expect(1, 1114109, '\P{Is_East_Asian_Width=_ Neutral}', "");
Expect(0, 1114109, '\P{^Is_East_Asian_Width=_ Neutral}', "");
Error('\p{Is_Ea:--N/a/}');
Error('\P{Is_Ea:--N/a/}');
Expect(1, 918000, '\p{Is_Ea=n}', "");
Expect(0, 918000, '\p{^Is_Ea=n}', "");
Expect(0, 918000, '\P{Is_Ea=n}', "");
Expect(1, 918000, '\P{^Is_Ea=n}', "");
Expect(0, 1114109, '\p{Is_Ea=n}', "");
Expect(1, 1114109, '\p{^Is_Ea=n}', "");
Expect(1, 1114109, '\P{Is_Ea=n}', "");
Expect(0, 1114109, '\P{^Is_Ea=n}', "");
Expect(1, 918000, '\p{Is_Ea=	N}', "");
Expect(0, 918000, '\p{^Is_Ea=	N}', "");
Expect(0, 918000, '\P{Is_Ea=	N}', "");
Expect(1, 918000, '\P{^Is_Ea=	N}', "");
Expect(0, 1114109, '\p{Is_Ea=	N}', "");
Expect(1, 1114109, '\p{^Is_Ea=	N}', "");
Expect(1, 1114109, '\P{Is_Ea=	N}', "");
Expect(0, 1114109, '\P{^Is_Ea=	N}', "");
Error('\p{East_Asian_Width=/a/ narrow}');
Error('\P{East_Asian_Width=/a/ narrow}');
Expect(1, 10630, '\p{East_Asian_Width=narrow}', "");
Expect(0, 10630, '\p{^East_Asian_Width=narrow}', "");
Expect(0, 10630, '\P{East_Asian_Width=narrow}', "");
Expect(1, 10630, '\P{^East_Asian_Width=narrow}', "");
Expect(0, 10631, '\p{East_Asian_Width=narrow}', "");
Expect(1, 10631, '\p{^East_Asian_Width=narrow}', "");
Expect(1, 10631, '\P{East_Asian_Width=narrow}', "");
Expect(0, 10631, '\P{^East_Asian_Width=narrow}', "");
Error('\p{Ea=		NA:=}');
Error('\P{Ea=		NA:=}');
Expect(1, 10630, '\p{Ea=na}', "");
Expect(0, 10630, '\p{^Ea=na}', "");
Expect(0, 10630, '\P{Ea=na}', "");
Expect(1, 10630, '\P{^Ea=na}', "");
Expect(0, 10631, '\p{Ea=na}', "");
Expect(1, 10631, '\p{^Ea=na}', "");
Expect(1, 10631, '\P{Ea=na}', "");
Expect(0, 10631, '\P{^Ea=na}', "");
Expect(1, 10630, '\p{Ea=	_Na}', "");
Expect(0, 10630, '\p{^Ea=	_Na}', "");
Expect(0, 10630, '\P{Ea=	_Na}', "");
Expect(1, 10630, '\P{^Ea=	_Na}', "");
Expect(0, 10631, '\p{Ea=	_Na}', "");
Expect(1, 10631, '\p{^Ea=	_Na}', "");
Expect(1, 10631, '\P{Ea=	_Na}', "");
Expect(0, 10631, '\P{^Ea=	_Na}', "");
Error('\p{Is_East_Asian_Width=/a/_Narrow}');
Error('\P{Is_East_Asian_Width=/a/_Narrow}');
Expect(1, 10630, '\p{Is_East_Asian_Width=narrow}', "");
Expect(0, 10630, '\p{^Is_East_Asian_Width=narrow}', "");
Expect(0, 10630, '\P{Is_East_Asian_Width=narrow}', "");
Expect(1, 10630, '\P{^Is_East_Asian_Width=narrow}', "");
Expect(0, 10631, '\p{Is_East_Asian_Width=narrow}', "");
Expect(1, 10631, '\p{^Is_East_Asian_Width=narrow}', "");
Expect(1, 10631, '\P{Is_East_Asian_Width=narrow}', "");
Expect(0, 10631, '\P{^Is_East_Asian_Width=narrow}', "");
Expect(1, 10630, '\p{Is_East_Asian_Width:	_-Narrow}', "");
Expect(0, 10630, '\p{^Is_East_Asian_Width:	_-Narrow}', "");
Expect(0, 10630, '\P{Is_East_Asian_Width:	_-Narrow}', "");
Expect(1, 10630, '\P{^Is_East_Asian_Width:	_-Narrow}', "");
Expect(0, 10631, '\p{Is_East_Asian_Width:	_-Narrow}', "");
Expect(1, 10631, '\p{^Is_East_Asian_Width:	_-Narrow}', "");
Expect(1, 10631, '\P{Is_East_Asian_Width:	_-Narrow}', "");
Expect(0, 10631, '\P{^Is_East_Asian_Width:	_-Narrow}', "");
Error('\p{Is_Ea: Na/a/}');
Error('\P{Is_Ea: Na/a/}');
Expect(1, 10630, '\p{Is_Ea:	na}', "");
Expect(0, 10630, '\p{^Is_Ea:	na}', "");
Expect(0, 10630, '\P{Is_Ea:	na}', "");
Expect(1, 10630, '\P{^Is_Ea:	na}', "");
Expect(0, 10631, '\p{Is_Ea:	na}', "");
Expect(1, 10631, '\p{^Is_Ea:	na}', "");
Expect(1, 10631, '\P{Is_Ea:	na}', "");
Expect(0, 10631, '\P{^Is_Ea:	na}', "");
Expect(1, 10630, '\p{Is_Ea=Na}', "");
Expect(0, 10630, '\p{^Is_Ea=Na}', "");
Expect(0, 10630, '\P{Is_Ea=Na}', "");
Expect(1, 10630, '\P{^Is_Ea=Na}', "");
Expect(0, 10631, '\p{Is_Ea=Na}', "");
Expect(1, 10631, '\p{^Is_Ea=Na}', "");
Expect(1, 10631, '\P{Is_Ea=Na}', "");
Expect(0, 10631, '\P{^Is_Ea=Na}', "");
Error('\p{East_Asian_Width:   :=_-Wide}');
Error('\P{East_Asian_Width:   :=_-Wide}');
Expect(1, 262141, '\p{East_Asian_Width=wide}', "");
Expect(0, 262141, '\p{^East_Asian_Width=wide}', "");
Expect(0, 262141, '\P{East_Asian_Width=wide}', "");
Expect(1, 262141, '\P{^East_Asian_Width=wide}', "");
Expect(0, 262144, '\p{East_Asian_Width=wide}', "");
Expect(1, 262144, '\p{^East_Asian_Width=wide}', "");
Expect(1, 262144, '\P{East_Asian_Width=wide}', "");
Expect(0, 262144, '\P{^East_Asian_Width=wide}', "");
Expect(1, 262141, '\p{East_Asian_Width: -Wide}', "");
Expect(0, 262141, '\p{^East_Asian_Width: -Wide}', "");
Expect(0, 262141, '\P{East_Asian_Width: -Wide}', "");
Expect(1, 262141, '\P{^East_Asian_Width: -Wide}', "");
Expect(0, 262144, '\p{East_Asian_Width: -Wide}', "");
Expect(1, 262144, '\p{^East_Asian_Width: -Wide}', "");
Expect(1, 262144, '\P{East_Asian_Width: -Wide}', "");
Expect(0, 262144, '\P{^East_Asian_Width: -Wide}', "");
Error('\p{Ea=/a/	_W}');
Error('\P{Ea=/a/	_W}');
Expect(1, 262141, '\p{Ea=w}', "");
Expect(0, 262141, '\p{^Ea=w}', "");
Expect(0, 262141, '\P{Ea=w}', "");
Expect(1, 262141, '\P{^Ea=w}', "");
Expect(0, 262144, '\p{Ea=w}', "");
Expect(1, 262144, '\p{^Ea=w}', "");
Expect(1, 262144, '\P{Ea=w}', "");
Expect(0, 262144, '\P{^Ea=w}', "");
Expect(1, 262141, '\p{Ea= -W}', "");
Expect(0, 262141, '\p{^Ea= -W}', "");
Expect(0, 262141, '\P{Ea= -W}', "");
Expect(1, 262141, '\P{^Ea= -W}', "");
Expect(0, 262144, '\p{Ea= -W}', "");
Expect(1, 262144, '\p{^Ea= -W}', "");
Expect(1, 262144, '\P{Ea= -W}', "");
Expect(0, 262144, '\P{^Ea= -W}', "");
Error('\p{Is_East_Asian_Width=-wide/a/}');
Error('\P{Is_East_Asian_Width=-wide/a/}');
Expect(1, 262141, '\p{Is_East_Asian_Width=wide}', "");
Expect(0, 262141, '\p{^Is_East_Asian_Width=wide}', "");
Expect(0, 262141, '\P{Is_East_Asian_Width=wide}', "");
Expect(1, 262141, '\P{^Is_East_Asian_Width=wide}', "");
Expect(0, 262144, '\p{Is_East_Asian_Width=wide}', "");
Expect(1, 262144, '\p{^Is_East_Asian_Width=wide}', "");
Expect(1, 262144, '\P{Is_East_Asian_Width=wide}', "");
Expect(0, 262144, '\P{^Is_East_Asian_Width=wide}', "");
Expect(1, 262141, '\p{Is_East_Asian_Width=- WIDE}', "");
Expect(0, 262141, '\p{^Is_East_Asian_Width=- WIDE}', "");
Expect(0, 262141, '\P{Is_East_Asian_Width=- WIDE}', "");
Expect(1, 262141, '\P{^Is_East_Asian_Width=- WIDE}', "");
Expect(0, 262144, '\p{Is_East_Asian_Width=- WIDE}', "");
Expect(1, 262144, '\p{^Is_East_Asian_Width=- WIDE}', "");
Expect(1, 262144, '\P{Is_East_Asian_Width=- WIDE}', "");
Expect(0, 262144, '\P{^Is_East_Asian_Width=- WIDE}', "");
Error('\p{Is_Ea=/a/ -W}');
Error('\P{Is_Ea=/a/ -W}');
Expect(1, 262141, '\p{Is_Ea=w}', "");
Expect(0, 262141, '\p{^Is_Ea=w}', "");
Expect(0, 262141, '\P{Is_Ea=w}', "");
Expect(1, 262141, '\P{^Is_Ea=w}', "");
Expect(0, 262144, '\p{Is_Ea=w}', "");
Expect(1, 262144, '\p{^Is_Ea=w}', "");
Expect(1, 262144, '\P{Is_Ea=w}', "");
Expect(0, 262144, '\P{^Is_Ea=w}', "");
Expect(1, 262141, '\p{Is_Ea=-	W}', "");
Expect(0, 262141, '\p{^Is_Ea=-	W}', "");
Expect(0, 262141, '\P{Is_Ea=-	W}', "");
Expect(1, 262141, '\P{^Is_Ea=-	W}', "");
Expect(0, 262144, '\p{Is_Ea=-	W}', "");
Expect(1, 262144, '\p{^Is_Ea=-	W}', "");
Expect(1, 262144, '\P{Is_Ea=-	W}', "");
Expect(0, 262144, '\P{^Is_Ea=-	W}', "");
Error('\p{General_Category=_	Other:=}');
Error('\P{General_Category=_	Other:=}');
Expect(1, 918000, '\p{General_Category=other}', "");
Expect(0, 918000, '\p{^General_Category=other}', "");
Expect(0, 918000, '\P{General_Category=other}', "");
Expect(1, 918000, '\P{^General_Category=other}', "");
Expect(0, 917999, '\p{General_Category=other}', "");
Expect(1, 917999, '\p{^General_Category=other}', "");
Expect(1, 917999, '\P{General_Category=other}', "");
Expect(0, 917999, '\P{^General_Category=other}', "");
Expect(1, 918000, '\p{General_Category:	OTHER}', "");
Expect(0, 918000, '\p{^General_Category:	OTHER}', "");
Expect(0, 918000, '\P{General_Category:	OTHER}', "");
Expect(1, 918000, '\P{^General_Category:	OTHER}', "");
Expect(0, 917999, '\p{General_Category:	OTHER}', "");
Expect(1, 917999, '\p{^General_Category:	OTHER}', "");
Expect(1, 917999, '\P{General_Category:	OTHER}', "");
Expect(0, 917999, '\P{^General_Category:	OTHER}', "");
Error('\p{Gc=/a/C}');
Error('\P{Gc=/a/C}');
Expect(1, 918000, '\p{Gc=c}', "");
Expect(0, 918000, '\p{^Gc=c}', "");
Expect(0, 918000, '\P{Gc=c}', "");
Expect(1, 918000, '\P{^Gc=c}', "");
Expect(0, 917999, '\p{Gc=c}', "");
Expect(1, 917999, '\p{^Gc=c}', "");
Expect(1, 917999, '\P{Gc=c}', "");
Expect(0, 917999, '\P{^Gc=c}', "");
Expect(1, 918000, '\p{Gc=_ C}', "");
Expect(0, 918000, '\p{^Gc=_ C}', "");
Expect(0, 918000, '\P{Gc=_ C}', "");
Expect(1, 918000, '\P{^Gc=_ C}', "");
Expect(0, 917999, '\p{Gc=_ C}', "");
Expect(1, 917999, '\p{^Gc=_ C}', "");
Expect(1, 917999, '\P{Gc=_ C}', "");
Expect(0, 917999, '\P{^Gc=_ C}', "");
Error('\p{Category=:=--Other}');
Error('\P{Category=:=--Other}');
Expect(1, 918000, '\p{Category=other}', "");
Expect(0, 918000, '\p{^Category=other}', "");
Expect(0, 918000, '\P{Category=other}', "");
Expect(1, 918000, '\P{^Category=other}', "");
Expect(0, 917999, '\p{Category=other}', "");
Expect(1, 917999, '\p{^Category=other}', "");
Expect(1, 917999, '\P{Category=other}', "");
Expect(0, 917999, '\P{^Category=other}', "");
Expect(1, 918000, '\p{Category=Other}', "");
Expect(0, 918000, '\p{^Category=Other}', "");
Expect(0, 918000, '\P{Category=Other}', "");
Expect(1, 918000, '\P{^Category=Other}', "");
Expect(0, 917999, '\p{Category=Other}', "");
Expect(1, 917999, '\p{^Category=Other}', "");
Expect(1, 917999, '\P{Category=Other}', "");
Expect(0, 917999, '\P{^Category=Other}', "");
Error('\p{Is_General_Category:	:=C}');
Error('\P{Is_General_Category:	:=C}');
Expect(1, 918000, '\p{Is_General_Category=c}', "");
Expect(0, 918000, '\p{^Is_General_Category=c}', "");
Expect(0, 918000, '\P{Is_General_Category=c}', "");
Expect(1, 918000, '\P{^Is_General_Category=c}', "");
Expect(0, 917999, '\p{Is_General_Category=c}', "");
Expect(1, 917999, '\p{^Is_General_Category=c}', "");
Expect(1, 917999, '\P{Is_General_Category=c}', "");
Expect(0, 917999, '\P{^Is_General_Category=c}', "");
Expect(1, 918000, '\p{Is_General_Category= -C}', "");
Expect(0, 918000, '\p{^Is_General_Category= -C}', "");
Expect(0, 918000, '\P{Is_General_Category= -C}', "");
Expect(1, 918000, '\P{^Is_General_Category= -C}', "");
Expect(0, 917999, '\p{Is_General_Category= -C}', "");
Expect(1, 917999, '\p{^Is_General_Category= -C}', "");
Expect(1, 917999, '\P{Is_General_Category= -C}', "");
Expect(0, 917999, '\P{^Is_General_Category= -C}', "");
Error('\p{Is_Gc:   	:=Other}');
Error('\P{Is_Gc:   	:=Other}');
Expect(1, 918000, '\p{Is_Gc=other}', "");
Expect(0, 918000, '\p{^Is_Gc=other}', "");
Expect(0, 918000, '\P{Is_Gc=other}', "");
Expect(1, 918000, '\P{^Is_Gc=other}', "");
Expect(0, 917999, '\p{Is_Gc=other}', "");
Expect(1, 917999, '\p{^Is_Gc=other}', "");
Expect(1, 917999, '\P{Is_Gc=other}', "");
Expect(0, 917999, '\P{^Is_Gc=other}', "");
Expect(1, 918000, '\p{Is_Gc=_Other}', "");
Expect(0, 918000, '\p{^Is_Gc=_Other}', "");
Expect(0, 918000, '\P{Is_Gc=_Other}', "");
Expect(1, 918000, '\P{^Is_Gc=_Other}', "");
Expect(0, 917999, '\p{Is_Gc=_Other}', "");
Expect(1, 917999, '\p{^Is_Gc=_Other}', "");
Expect(1, 917999, '\P{Is_Gc=_Other}', "");
Expect(0, 917999, '\P{^Is_Gc=_Other}', "");
Error('\p{Is_Category=/a/_C}');
Error('\P{Is_Category=/a/_C}');
Expect(1, 918000, '\p{Is_Category=c}', "");
Expect(0, 918000, '\p{^Is_Category=c}', "");
Expect(0, 918000, '\P{Is_Category=c}', "");
Expect(1, 918000, '\P{^Is_Category=c}', "");
Expect(0, 917999, '\p{Is_Category=c}', "");
Expect(1, 917999, '\p{^Is_Category=c}', "");
Expect(1, 917999, '\P{Is_Category=c}', "");
Expect(0, 917999, '\P{^Is_Category=c}', "");
Expect(1, 918000, '\p{Is_Category=_ C}', "");
Expect(0, 918000, '\p{^Is_Category=_ C}', "");
Expect(0, 918000, '\P{Is_Category=_ C}', "");
Expect(1, 918000, '\P{^Is_Category=_ C}', "");
Expect(0, 917999, '\p{Is_Category=_ C}', "");
Expect(1, 917999, '\p{^Is_Category=_ C}', "");
Expect(1, 917999, '\P{Is_Category=_ C}', "");
Expect(0, 917999, '\P{^Is_Category=_ C}', "");
Error('\p{General_Category=	 CONTROL/a/}');
Error('\P{General_Category=	 CONTROL/a/}');
Expect(1, 159, '\p{General_Category=control}', "");
Expect(0, 159, '\p{^General_Category=control}', "");
Expect(0, 159, '\P{General_Category=control}', "");
Expect(1, 159, '\P{^General_Category=control}', "");
Expect(0, 160, '\p{General_Category=control}', "");
Expect(1, 160, '\p{^General_Category=control}', "");
Expect(1, 160, '\P{General_Category=control}', "");
Expect(0, 160, '\P{^General_Category=control}', "");
Expect(1, 159, '\p{General_Category=	 CONTROL}', "");
Expect(0, 159, '\p{^General_Category=	 CONTROL}', "");
Expect(0, 159, '\P{General_Category=	 CONTROL}', "");
Expect(1, 159, '\P{^General_Category=	 CONTROL}', "");
Expect(0, 160, '\p{General_Category=	 CONTROL}', "");
Expect(1, 160, '\p{^General_Category=	 CONTROL}', "");
Expect(1, 160, '\P{General_Category=	 CONTROL}', "");
Expect(0, 160, '\P{^General_Category=	 CONTROL}', "");
Error('\p{Gc=__Cc/a/}');
Error('\P{Gc=__Cc/a/}');
Expect(1, 159, '\p{Gc:   cc}', "");
Expect(0, 159, '\p{^Gc:   cc}', "");
Expect(0, 159, '\P{Gc:   cc}', "");
Expect(1, 159, '\P{^Gc:   cc}', "");
Expect(0, 160, '\p{Gc:   cc}', "");
Expect(1, 160, '\p{^Gc:   cc}', "");
Expect(1, 160, '\P{Gc:   cc}', "");
Expect(0, 160, '\P{^Gc:   cc}', "");
Expect(1, 159, '\p{Gc:	 	Cc}', "");
Expect(0, 159, '\p{^Gc:	 	Cc}', "");
Expect(0, 159, '\P{Gc:	 	Cc}', "");
Expect(1, 159, '\P{^Gc:	 	Cc}', "");
Expect(0, 160, '\p{Gc:	 	Cc}', "");
Expect(1, 160, '\p{^Gc:	 	Cc}', "");
Expect(1, 160, '\P{Gc:	 	Cc}', "");
Expect(0, 160, '\P{^Gc:	 	Cc}', "");
Error('\p{Category=:=__Cntrl}');
Error('\P{Category=:=__Cntrl}');
Expect(1, 159, '\p{Category=cntrl}', "");
Expect(0, 159, '\p{^Category=cntrl}', "");
Expect(0, 159, '\P{Category=cntrl}', "");
Expect(1, 159, '\P{^Category=cntrl}', "");
Expect(0, 160, '\p{Category=cntrl}', "");
Expect(1, 160, '\p{^Category=cntrl}', "");
Expect(1, 160, '\P{Category=cntrl}', "");
Expect(0, 160, '\P{^Category=cntrl}', "");
Expect(1, 159, '\p{Category=	_cntrl}', "");
Expect(0, 159, '\p{^Category=	_cntrl}', "");
Expect(0, 159, '\P{Category=	_cntrl}', "");
Expect(1, 159, '\P{^Category=	_cntrl}', "");
Expect(0, 160, '\p{Category=	_cntrl}', "");
Expect(1, 160, '\p{^Category=	_cntrl}', "");
Expect(1, 160, '\P{Category=	_cntrl}', "");
Expect(0, 160, '\P{^Category=	_cntrl}', "");
Error('\p{Is_General_Category=/a/ -control}');
Error('\P{Is_General_Category=/a/ -control}');
Expect(1, 159, '\p{Is_General_Category=control}', "");
Expect(0, 159, '\p{^Is_General_Category=control}', "");
Expect(0, 159, '\P{Is_General_Category=control}', "");
Expect(1, 159, '\P{^Is_General_Category=control}', "");
Expect(0, 160, '\p{Is_General_Category=control}', "");
Expect(1, 160, '\p{^Is_General_Category=control}', "");
Expect(1, 160, '\P{Is_General_Category=control}', "");
Expect(0, 160, '\P{^Is_General_Category=control}', "");
Expect(1, 159, '\p{Is_General_Category=-Control}', "");
Expect(0, 159, '\p{^Is_General_Category=-Control}', "");
Expect(0, 159, '\P{Is_General_Category=-Control}', "");
Expect(1, 159, '\P{^Is_General_Category=-Control}', "");
Expect(0, 160, '\p{Is_General_Category=-Control}', "");
Expect(1, 160, '\p{^Is_General_Category=-Control}', "");
Expect(1, 160, '\P{Is_General_Category=-Control}', "");
Expect(0, 160, '\P{^Is_General_Category=-Control}', "");
Error('\p{Is_Gc=/a/_cc}');
Error('\P{Is_Gc=/a/_cc}');
Expect(1, 159, '\p{Is_Gc=cc}', "");
Expect(0, 159, '\p{^Is_Gc=cc}', "");
Expect(0, 159, '\P{Is_Gc=cc}', "");
Expect(1, 159, '\P{^Is_Gc=cc}', "");
Expect(0, 160, '\p{Is_Gc=cc}', "");
Expect(1, 160, '\p{^Is_Gc=cc}', "");
Expect(1, 160, '\P{Is_Gc=cc}', "");
Expect(0, 160, '\P{^Is_Gc=cc}', "");
Expect(1, 159, '\p{Is_Gc=--Cc}', "");
Expect(0, 159, '\p{^Is_Gc=--Cc}', "");
Expect(0, 159, '\P{Is_Gc=--Cc}', "");
Expect(1, 159, '\P{^Is_Gc=--Cc}', "");
Expect(0, 160, '\p{Is_Gc=--Cc}', "");
Expect(1, 160, '\p{^Is_Gc=--Cc}', "");
Expect(1, 160, '\P{Is_Gc=--Cc}', "");
Expect(0, 160, '\P{^Is_Gc=--Cc}', "");
Error('\p{Is_Category=-/a/cntrl}');
Error('\P{Is_Category=-/a/cntrl}');
Expect(1, 159, '\p{Is_Category: cntrl}', "");
Expect(0, 159, '\p{^Is_Category: cntrl}', "");
Expect(0, 159, '\P{Is_Category: cntrl}', "");
Expect(1, 159, '\P{^Is_Category: cntrl}', "");
Expect(0, 160, '\p{Is_Category: cntrl}', "");
Expect(1, 160, '\p{^Is_Category: cntrl}', "");
Expect(1, 160, '\P{Is_Category: cntrl}', "");
Expect(0, 160, '\P{^Is_Category: cntrl}', "");
Expect(1, 159, '\p{Is_Category= cntrl}', "");
Expect(0, 159, '\p{^Is_Category= cntrl}', "");
Expect(0, 159, '\P{Is_Category= cntrl}', "");
Expect(1, 159, '\P{^Is_Category= cntrl}', "");
Expect(0, 160, '\p{Is_Category= cntrl}', "");
Expect(1, 160, '\p{^Is_Category= cntrl}', "");
Expect(1, 160, '\P{Is_Category= cntrl}', "");
Expect(0, 160, '\P{^Is_Category= cntrl}', "");
Error('\p{General_Category= :=format}');
Error('\P{General_Category= :=format}');
Expect(1, 917631, '\p{General_Category=format}', "");
Expect(0, 917631, '\p{^General_Category=format}', "");
Expect(0, 917631, '\P{General_Category=format}', "");
Expect(1, 917631, '\P{^General_Category=format}', "");
Expect(0, 917632, '\p{General_Category=format}', "");
Expect(1, 917632, '\p{^General_Category=format}', "");
Expect(1, 917632, '\P{General_Category=format}', "");
Expect(0, 917632, '\P{^General_Category=format}', "");
Expect(1, 917631, '\p{General_Category=_Format}', "");
Expect(0, 917631, '\p{^General_Category=_Format}', "");
Expect(0, 917631, '\P{General_Category=_Format}', "");
Expect(1, 917631, '\P{^General_Category=_Format}', "");
Expect(0, 917632, '\p{General_Category=_Format}', "");
Expect(1, 917632, '\p{^General_Category=_Format}', "");
Expect(1, 917632, '\P{General_Category=_Format}', "");
Expect(0, 917632, '\P{^General_Category=_Format}', "");
Error('\p{Gc:   -:=Cf}');
Error('\P{Gc:   -:=Cf}');
Expect(1, 917631, '\p{Gc:   cf}', "");
Expect(0, 917631, '\p{^Gc:   cf}', "");
Expect(0, 917631, '\P{Gc:   cf}', "");
Expect(1, 917631, '\P{^Gc:   cf}', "");
Expect(0, 917632, '\p{Gc:   cf}', "");
Expect(1, 917632, '\p{^Gc:   cf}', "");
Expect(1, 917632, '\P{Gc:   cf}', "");
Expect(0, 917632, '\P{^Gc:   cf}', "");
Expect(1, 917631, '\p{Gc=_Cf}', "");
Expect(0, 917631, '\p{^Gc=_Cf}', "");
Expect(0, 917631, '\P{Gc=_Cf}', "");
Expect(1, 917631, '\P{^Gc=_Cf}', "");
Expect(0, 917632, '\p{Gc=_Cf}', "");
Expect(1, 917632, '\p{^Gc=_Cf}', "");
Expect(1, 917632, '\P{Gc=_Cf}', "");
Expect(0, 917632, '\P{^Gc=_Cf}', "");
Error('\p{Category= /a/Format}');
Error('\P{Category= /a/Format}');
Expect(1, 917631, '\p{Category=format}', "");
Expect(0, 917631, '\p{^Category=format}', "");
Expect(0, 917631, '\P{Category=format}', "");
Expect(1, 917631, '\P{^Category=format}', "");
Expect(0, 917632, '\p{Category=format}', "");
Expect(1, 917632, '\p{^Category=format}', "");
Expect(1, 917632, '\P{Category=format}', "");
Expect(0, 917632, '\P{^Category=format}', "");
Expect(1, 917631, '\p{Category=-_FORMAT}', "");
Expect(0, 917631, '\p{^Category=-_FORMAT}', "");
Expect(0, 917631, '\P{Category=-_FORMAT}', "");
Expect(1, 917631, '\P{^Category=-_FORMAT}', "");
Expect(0, 917632, '\p{Category=-_FORMAT}', "");
Expect(1, 917632, '\p{^Category=-_FORMAT}', "");
Expect(1, 917632, '\P{Category=-_FORMAT}', "");
Expect(0, 917632, '\P{^Category=-_FORMAT}', "");
Error('\p{Is_General_Category=_:=Cf}');
Error('\P{Is_General_Category=_:=Cf}');
Expect(1, 917631, '\p{Is_General_Category=cf}', "");
Expect(0, 917631, '\p{^Is_General_Category=cf}', "");
Expect(0, 917631, '\P{Is_General_Category=cf}', "");
Expect(1, 917631, '\P{^Is_General_Category=cf}', "");
Expect(0, 917632, '\p{Is_General_Category=cf}', "");
Expect(1, 917632, '\p{^Is_General_Category=cf}', "");
Expect(1, 917632, '\P{Is_General_Category=cf}', "");
Expect(0, 917632, '\P{^Is_General_Category=cf}', "");
Expect(1, 917631, '\p{Is_General_Category= Cf}', "");
Expect(0, 917631, '\p{^Is_General_Category= Cf}', "");
Expect(0, 917631, '\P{Is_General_Category= Cf}', "");
Expect(1, 917631, '\P{^Is_General_Category= Cf}', "");
Expect(0, 917632, '\p{Is_General_Category= Cf}', "");
Expect(1, 917632, '\p{^Is_General_Category= Cf}', "");
Expect(1, 917632, '\P{Is_General_Category= Cf}', "");
Expect(0, 917632, '\P{^Is_General_Category= Cf}', "");
Error('\p{Is_Gc=	Format:=}');
Error('\P{Is_Gc=	Format:=}');
Expect(1, 917631, '\p{Is_Gc=format}', "");
Expect(0, 917631, '\p{^Is_Gc=format}', "");
Expect(0, 917631, '\P{Is_Gc=format}', "");
Expect(1, 917631, '\P{^Is_Gc=format}', "");
Expect(0, 917632, '\p{Is_Gc=format}', "");
Expect(1, 917632, '\p{^Is_Gc=format}', "");
Expect(1, 917632, '\P{Is_Gc=format}', "");
Expect(0, 917632, '\P{^Is_Gc=format}', "");
Expect(1, 917631, '\p{Is_Gc=-	Format}', "");
Expect(0, 917631, '\p{^Is_Gc=-	Format}', "");
Expect(0, 917631, '\P{Is_Gc=-	Format}', "");
Expect(1, 917631, '\P{^Is_Gc=-	Format}', "");
Expect(0, 917632, '\p{Is_Gc=-	Format}', "");
Expect(1, 917632, '\p{^Is_Gc=-	Format}', "");
Expect(1, 917632, '\P{Is_Gc=-	Format}', "");
Expect(0, 917632, '\P{^Is_Gc=-	Format}', "");
Error('\p{Is_Category=:=		cf}');
Error('\P{Is_Category=:=		cf}');
Expect(1, 917631, '\p{Is_Category=cf}', "");
Expect(0, 917631, '\p{^Is_Category=cf}', "");
Expect(0, 917631, '\P{Is_Category=cf}', "");
Expect(1, 917631, '\P{^Is_Category=cf}', "");
Expect(0, 917632, '\p{Is_Category=cf}', "");
Expect(1, 917632, '\p{^Is_Category=cf}', "");
Expect(1, 917632, '\P{Is_Category=cf}', "");
Expect(0, 917632, '\P{^Is_Category=cf}', "");
Expect(1, 917631, '\p{Is_Category=-cf}', "");
Expect(0, 917631, '\p{^Is_Category=-cf}', "");
Expect(0, 917631, '\P{Is_Category=-cf}', "");
Expect(1, 917631, '\P{^Is_Category=-cf}', "");
Expect(0, 917632, '\p{Is_Category=-cf}', "");
Expect(1, 917632, '\p{^Is_Category=-cf}', "");
Expect(1, 917632, '\P{Is_Category=-cf}', "");
Expect(0, 917632, '\P{^Is_Category=-cf}', "");
Error('\p{General_Category=/a/_unassigned}');
Error('\P{General_Category=/a/_unassigned}');
Expect(1, 918000, '\p{General_Category=unassigned}', "");
Expect(0, 918000, '\p{^General_Category=unassigned}', "");
Expect(0, 918000, '\P{General_Category=unassigned}', "");
Expect(1, 918000, '\P{^General_Category=unassigned}', "");
Expect(0, 1114109, '\p{General_Category=unassigned}', "");
Expect(1, 1114109, '\p{^General_Category=unassigned}', "");
Expect(1, 1114109, '\P{General_Category=unassigned}', "");
Expect(0, 1114109, '\P{^General_Category=unassigned}', "");
Expect(1, 918000, '\p{General_Category=_Unassigned}', "");
Expect(0, 918000, '\p{^General_Category=_Unassigned}', "");
Expect(0, 918000, '\P{General_Category=_Unassigned}', "");
Expect(1, 918000, '\P{^General_Category=_Unassigned}', "");
Expect(0, 1114109, '\p{General_Category=_Unassigned}', "");
Expect(1, 1114109, '\p{^General_Category=_Unassigned}', "");
Expect(1, 1114109, '\P{General_Category=_Unassigned}', "");
Expect(0, 1114109, '\P{^General_Category=_Unassigned}', "");
Error('\p{Gc:  -CN:=}');
Error('\P{Gc:  -CN:=}');
Expect(1, 918000, '\p{Gc=cn}', "");
Expect(0, 918000, '\p{^Gc=cn}', "");
Expect(0, 918000, '\P{Gc=cn}', "");
Expect(1, 918000, '\P{^Gc=cn}', "");
Expect(0, 1114109, '\p{Gc=cn}', "");
Expect(1, 1114109, '\p{^Gc=cn}', "");
Expect(1, 1114109, '\P{Gc=cn}', "");
Expect(0, 1114109, '\P{^Gc=cn}', "");
Expect(1, 918000, '\p{Gc= -cn}', "");
Expect(0, 918000, '\p{^Gc= -cn}', "");
Expect(0, 918000, '\P{Gc= -cn}', "");
Expect(1, 918000, '\P{^Gc= -cn}', "");
Expect(0, 1114109, '\p{Gc= -cn}', "");
Expect(1, 1114109, '\p{^Gc= -cn}', "");
Expect(1, 1114109, '\P{Gc= -cn}', "");
Expect(0, 1114109, '\P{^Gc= -cn}', "");
Error('\p{Category=/a/-Unassigned}');
Error('\P{Category=/a/-Unassigned}');
Expect(1, 918000, '\p{Category=unassigned}', "");
Expect(0, 918000, '\p{^Category=unassigned}', "");
Expect(0, 918000, '\P{Category=unassigned}', "");
Expect(1, 918000, '\P{^Category=unassigned}', "");
Expect(0, 1114109, '\p{Category=unassigned}', "");
Expect(1, 1114109, '\p{^Category=unassigned}', "");
Expect(1, 1114109, '\P{Category=unassigned}', "");
Expect(0, 1114109, '\P{^Category=unassigned}', "");
Expect(1, 918000, '\p{Category=_-unassigned}', "");
Expect(0, 918000, '\p{^Category=_-unassigned}', "");
Expect(0, 918000, '\P{Category=_-unassigned}', "");
Expect(1, 918000, '\P{^Category=_-unassigned}', "");
Expect(0, 1114109, '\p{Category=_-unassigned}', "");
Expect(1, 1114109, '\p{^Category=_-unassigned}', "");
Expect(1, 1114109, '\P{Category=_-unassigned}', "");
Expect(0, 1114109, '\P{^Category=_-unassigned}', "");
Error('\p{Is_General_Category=/a/-Cn}');
Error('\P{Is_General_Category=/a/-Cn}');
Expect(1, 918000, '\p{Is_General_Category=cn}', "");
Expect(0, 918000, '\p{^Is_General_Category=cn}', "");
Expect(0, 918000, '\P{Is_General_Category=cn}', "");
Expect(1, 918000, '\P{^Is_General_Category=cn}', "");
Expect(0, 1114109, '\p{Is_General_Category=cn}', "");
Expect(1, 1114109, '\p{^Is_General_Category=cn}', "");
Expect(1, 1114109, '\P{Is_General_Category=cn}', "");
Expect(0, 1114109, '\P{^Is_General_Category=cn}', "");
Expect(1, 918000, '\p{Is_General_Category=-_Cn}', "");
Expect(0, 918000, '\p{^Is_General_Category=-_Cn}', "");
Expect(0, 918000, '\P{Is_General_Category=-_Cn}', "");
Expect(1, 918000, '\P{^Is_General_Category=-_Cn}', "");
Expect(0, 1114109, '\p{Is_General_Category=-_Cn}', "");
Expect(1, 1114109, '\p{^Is_General_Category=-_Cn}', "");
Expect(1, 1114109, '\P{Is_General_Category=-_Cn}', "");
Expect(0, 1114109, '\P{^Is_General_Category=-_Cn}', "");
Error('\p{Is_Gc: /a/_unassigned}');
Error('\P{Is_Gc: /a/_unassigned}');
Expect(1, 918000, '\p{Is_Gc=unassigned}', "");
Expect(0, 918000, '\p{^Is_Gc=unassigned}', "");
Expect(0, 918000, '\P{Is_Gc=unassigned}', "");
Expect(1, 918000, '\P{^Is_Gc=unassigned}', "");
Expect(0, 1114109, '\p{Is_Gc=unassigned}', "");
Expect(1, 1114109, '\p{^Is_Gc=unassigned}', "");
Expect(1, 1114109, '\P{Is_Gc=unassigned}', "");
Expect(0, 1114109, '\P{^Is_Gc=unassigned}', "");
Expect(1, 918000, '\p{Is_Gc=-UNASSIGNED}', "");
Expect(0, 918000, '\p{^Is_Gc=-UNASSIGNED}', "");
Expect(0, 918000, '\P{Is_Gc=-UNASSIGNED}', "");
Expect(1, 918000, '\P{^Is_Gc=-UNASSIGNED}', "");
Expect(0, 1114109, '\p{Is_Gc=-UNASSIGNED}', "");
Expect(1, 1114109, '\p{^Is_Gc=-UNASSIGNED}', "");
Expect(1, 1114109, '\P{Is_Gc=-UNASSIGNED}', "");
Expect(0, 1114109, '\P{^Is_Gc=-UNASSIGNED}', "");
Error('\p{Is_Category= Cn/a/}');
Error('\P{Is_Category= Cn/a/}');
Expect(1, 918000, '\p{Is_Category=cn}', "");
Expect(0, 918000, '\p{^Is_Category=cn}', "");
Expect(0, 918000, '\P{Is_Category=cn}', "");
Expect(1, 918000, '\P{^Is_Category=cn}', "");
Expect(0, 1114109, '\p{Is_Category=cn}', "");
Expect(1, 1114109, '\p{^Is_Category=cn}', "");
Expect(1, 1114109, '\P{Is_Category=cn}', "");
Expect(0, 1114109, '\P{^Is_Category=cn}', "");
Expect(1, 918000, '\p{Is_Category=	Cn}', "");
Expect(0, 918000, '\p{^Is_Category=	Cn}', "");
Expect(0, 918000, '\P{Is_Category=	Cn}', "");
Expect(1, 918000, '\P{^Is_Category=	Cn}', "");
Expect(0, 1114109, '\p{Is_Category=	Cn}', "");
Expect(1, 1114109, '\p{^Is_Category=	Cn}', "");
Expect(1, 1114109, '\P{Is_Category=	Cn}', "");
Expect(0, 1114109, '\P{^Is_Category=	Cn}', "");
Error('\p{General_Category=/a/ 	Private_USE}');
Error('\P{General_Category=/a/ 	Private_USE}');
Expect(1, 1114109, '\p{General_Category=privateuse}', "");
Expect(0, 1114109, '\p{^General_Category=privateuse}', "");
Expect(0, 1114109, '\P{General_Category=privateuse}', "");
Expect(1, 1114109, '\P{^General_Category=privateuse}', "");
Expect(0, 63744, '\p{General_Category=privateuse}', "");
Expect(1, 63744, '\p{^General_Category=privateuse}', "");
Expect(1, 63744, '\P{General_Category=privateuse}', "");
Expect(0, 63744, '\P{^General_Category=privateuse}', "");
Expect(1, 1114109, '\p{General_Category=- Private_use}', "");
Expect(0, 1114109, '\p{^General_Category=- Private_use}', "");
Expect(0, 1114109, '\P{General_Category=- Private_use}', "");
Expect(1, 1114109, '\P{^General_Category=- Private_use}', "");
Expect(0, 63744, '\p{General_Category=- Private_use}', "");
Expect(1, 63744, '\p{^General_Category=- Private_use}', "");
Expect(1, 63744, '\P{General_Category=- Private_use}', "");
Expect(0, 63744, '\P{^General_Category=- Private_use}', "");
Error('\p{Gc=:=_Co}');
Error('\P{Gc=:=_Co}');
Expect(1, 1114109, '\p{Gc=co}', "");
Expect(0, 1114109, '\p{^Gc=co}', "");
Expect(0, 1114109, '\P{Gc=co}', "");
Expect(1, 1114109, '\P{^Gc=co}', "");
Expect(0, 63744, '\p{Gc=co}', "");
Expect(1, 63744, '\p{^Gc=co}', "");
Expect(1, 63744, '\P{Gc=co}', "");
Expect(0, 63744, '\P{^Gc=co}', "");
Expect(1, 1114109, '\p{Gc=	Co}', "");
Expect(0, 1114109, '\p{^Gc=	Co}', "");
Expect(0, 1114109, '\P{Gc=	Co}', "");
Expect(1, 1114109, '\P{^Gc=	Co}', "");
Expect(0, 63744, '\p{Gc=	Co}', "");
Expect(1, 63744, '\p{^Gc=	Co}', "");
Expect(1, 63744, '\P{Gc=	Co}', "");
Expect(0, 63744, '\P{^Gc=	Co}', "");
Error('\p{Category=__private_Use/a/}');
Error('\P{Category=__private_Use/a/}');
Expect(1, 1114109, '\p{Category=privateuse}', "");
Expect(0, 1114109, '\p{^Category=privateuse}', "");
Expect(0, 1114109, '\P{Category=privateuse}', "");
Expect(1, 1114109, '\P{^Category=privateuse}', "");
Expect(0, 63744, '\p{Category=privateuse}', "");
Expect(1, 63744, '\p{^Category=privateuse}', "");
Expect(1, 63744, '\P{Category=privateuse}', "");
Expect(0, 63744, '\P{^Category=privateuse}', "");
Expect(1, 1114109, '\p{Category= private_USE}', "");
Expect(0, 1114109, '\p{^Category= private_USE}', "");
Expect(0, 1114109, '\P{Category= private_USE}', "");
Expect(1, 1114109, '\P{^Category= private_USE}', "");
Expect(0, 63744, '\p{Category= private_USE}', "");
Expect(1, 63744, '\p{^Category= private_USE}', "");
Expect(1, 63744, '\P{Category= private_USE}', "");
Expect(0, 63744, '\P{^Category= private_USE}', "");
Error('\p{Is_General_Category:   	 co/a/}');
Error('\P{Is_General_Category:   	 co/a/}');
Expect(1, 1114109, '\p{Is_General_Category=co}', "");
Expect(0, 1114109, '\p{^Is_General_Category=co}', "");
Expect(0, 1114109, '\P{Is_General_Category=co}', "");
Expect(1, 1114109, '\P{^Is_General_Category=co}', "");
Expect(0, 63744, '\p{Is_General_Category=co}', "");
Expect(1, 63744, '\p{^Is_General_Category=co}', "");
Expect(1, 63744, '\P{Is_General_Category=co}', "");
Expect(0, 63744, '\P{^Is_General_Category=co}', "");
Expect(1, 1114109, '\p{Is_General_Category= _Co}', "");
Expect(0, 1114109, '\p{^Is_General_Category= _Co}', "");
Expect(0, 1114109, '\P{Is_General_Category= _Co}', "");
Expect(1, 1114109, '\P{^Is_General_Category= _Co}', "");
Expect(0, 63744, '\p{Is_General_Category= _Co}', "");
Expect(1, 63744, '\p{^Is_General_Category= _Co}', "");
Expect(1, 63744, '\P{Is_General_Category= _Co}', "");
Expect(0, 63744, '\P{^Is_General_Category= _Co}', "");
Error('\p{Is_Gc=		private_USE:=}');
Error('\P{Is_Gc=		private_USE:=}');
Expect(1, 1114109, '\p{Is_Gc=privateuse}', "");
Expect(0, 1114109, '\p{^Is_Gc=privateuse}', "");
Expect(0, 1114109, '\P{Is_Gc=privateuse}', "");
Expect(1, 1114109, '\P{^Is_Gc=privateuse}', "");
Expect(0, 63744, '\p{Is_Gc=privateuse}', "");
Expect(1, 63744, '\p{^Is_Gc=privateuse}', "");
Expect(1, 63744, '\P{Is_Gc=privateuse}', "");
Expect(0, 63744, '\P{^Is_Gc=privateuse}', "");
Expect(1, 1114109, '\p{Is_Gc=-Private_use}', "");
Expect(0, 1114109, '\p{^Is_Gc=-Private_use}', "");
Expect(0, 1114109, '\P{Is_Gc=-Private_use}', "");
Expect(1, 1114109, '\P{^Is_Gc=-Private_use}', "");
Expect(0, 63744, '\p{Is_Gc=-Private_use}', "");
Expect(1, 63744, '\p{^Is_Gc=-Private_use}', "");
Expect(1, 63744, '\P{Is_Gc=-Private_use}', "");
Expect(0, 63744, '\P{^Is_Gc=-Private_use}', "");
Error('\p{Is_Category=		Co:=}');
Error('\P{Is_Category=		Co:=}');
Expect(1, 1114109, '\p{Is_Category=co}', "");
Expect(0, 1114109, '\p{^Is_Category=co}', "");
Expect(0, 1114109, '\P{Is_Category=co}', "");
Expect(1, 1114109, '\P{^Is_Category=co}', "");
Expect(0, 63744, '\p{Is_Category=co}', "");
Expect(1, 63744, '\p{^Is_Category=co}', "");
Expect(1, 63744, '\P{Is_Category=co}', "");
Expect(0, 63744, '\P{^Is_Category=co}', "");
Expect(1, 1114109, '\p{Is_Category= 	CO}', "");
Expect(0, 1114109, '\p{^Is_Category= 	CO}', "");
Expect(0, 1114109, '\P{Is_Category= 	CO}', "");
Expect(1, 1114109, '\P{^Is_Category= 	CO}', "");
Expect(0, 63744, '\p{Is_Category= 	CO}', "");
Expect(1, 63744, '\p{^Is_Category= 	CO}', "");
Expect(1, 63744, '\P{Is_Category= 	CO}', "");
Expect(0, 63744, '\P{^Is_Category= 	CO}', "");
Error('\p{General_Category=	Surrogate:=}');
Error('\P{General_Category=	Surrogate:=}');
Expect(1, 57343, '\p{General_Category=surrogate}', "");
Expect(0, 57343, '\p{^General_Category=surrogate}', "");
Expect(0, 57343, '\P{General_Category=surrogate}', "");
Expect(1, 57343, '\P{^General_Category=surrogate}', "");
Expect(0, 57344, '\p{General_Category=surrogate}', "");
Expect(1, 57344, '\p{^General_Category=surrogate}', "");
Expect(1, 57344, '\P{General_Category=surrogate}', "");
Expect(0, 57344, '\P{^General_Category=surrogate}', "");
Expect(1, 57343, '\p{General_Category=	Surrogate}', "");
Expect(0, 57343, '\p{^General_Category=	Surrogate}', "");
Expect(0, 57343, '\P{General_Category=	Surrogate}', "");
Expect(1, 57343, '\P{^General_Category=	Surrogate}', "");
Expect(0, 57344, '\p{General_Category=	Surrogate}', "");
Expect(1, 57344, '\p{^General_Category=	Surrogate}', "");
Expect(1, 57344, '\P{General_Category=	Surrogate}', "");
Expect(0, 57344, '\P{^General_Category=	Surrogate}', "");
Error('\p{Gc=-cs:=}');
Error('\P{Gc=-cs:=}');
Expect(1, 57343, '\p{Gc=cs}', "");
Expect(0, 57343, '\p{^Gc=cs}', "");
Expect(0, 57343, '\P{Gc=cs}', "");
Expect(1, 57343, '\P{^Gc=cs}', "");
Expect(0, 57344, '\p{Gc=cs}', "");
Expect(1, 57344, '\p{^Gc=cs}', "");
Expect(1, 57344, '\P{Gc=cs}', "");
Expect(0, 57344, '\P{^Gc=cs}', "");
Expect(1, 57343, '\p{Gc=-Cs}', "");
Expect(0, 57343, '\p{^Gc=-Cs}', "");
Expect(0, 57343, '\P{Gc=-Cs}', "");
Expect(1, 57343, '\P{^Gc=-Cs}', "");
Expect(0, 57344, '\p{Gc=-Cs}', "");
Expect(1, 57344, '\p{^Gc=-Cs}', "");
Expect(1, 57344, '\P{Gc=-Cs}', "");
Expect(0, 57344, '\P{^Gc=-Cs}', "");
Error('\p{Category:	_:=surrogate}');
Error('\P{Category:	_:=surrogate}');
Expect(1, 57343, '\p{Category=surrogate}', "");
Expect(0, 57343, '\p{^Category=surrogate}', "");
Expect(0, 57343, '\P{Category=surrogate}', "");
Expect(1, 57343, '\P{^Category=surrogate}', "");
Expect(0, 57344, '\p{Category=surrogate}', "");
Expect(1, 57344, '\p{^Category=surrogate}', "");
Expect(1, 57344, '\P{Category=surrogate}', "");
Expect(0, 57344, '\P{^Category=surrogate}', "");
Expect(1, 57343, '\p{Category= surrogate}', "");
Expect(0, 57343, '\p{^Category= surrogate}', "");
Expect(0, 57343, '\P{Category= surrogate}', "");
Expect(1, 57343, '\P{^Category= surrogate}', "");
Expect(0, 57344, '\p{Category= surrogate}', "");
Expect(1, 57344, '\p{^Category= surrogate}', "");
Expect(1, 57344, '\P{Category= surrogate}', "");
Expect(0, 57344, '\P{^Category= surrogate}', "");
Error('\p{Is_General_Category=:= Cs}');
Error('\P{Is_General_Category=:= Cs}');
Expect(1, 57343, '\p{Is_General_Category=cs}', "");
Expect(0, 57343, '\p{^Is_General_Category=cs}', "");
Expect(0, 57343, '\P{Is_General_Category=cs}', "");
Expect(1, 57343, '\P{^Is_General_Category=cs}', "");
Expect(0, 57344, '\p{Is_General_Category=cs}', "");
Expect(1, 57344, '\p{^Is_General_Category=cs}', "");
Expect(1, 57344, '\P{Is_General_Category=cs}', "");
Expect(0, 57344, '\P{^Is_General_Category=cs}', "");
Expect(1, 57343, '\p{Is_General_Category=	Cs}', "");
Expect(0, 57343, '\p{^Is_General_Category=	Cs}', "");
Expect(0, 57343, '\P{Is_General_Category=	Cs}', "");
Expect(1, 57343, '\P{^Is_General_Category=	Cs}', "");
Expect(0, 57344, '\p{Is_General_Category=	Cs}', "");
Expect(1, 57344, '\p{^Is_General_Category=	Cs}', "");
Expect(1, 57344, '\P{Is_General_Category=	Cs}', "");
Expect(0, 57344, '\P{^Is_General_Category=	Cs}', "");
Error('\p{Is_Gc=/a/--SURROGATE}');
Error('\P{Is_Gc=/a/--SURROGATE}');
Expect(1, 57343, '\p{Is_Gc=surrogate}', "");
Expect(0, 57343, '\p{^Is_Gc=surrogate}', "");
Expect(0, 57343, '\P{Is_Gc=surrogate}', "");
Expect(1, 57343, '\P{^Is_Gc=surrogate}', "");
Expect(0, 57344, '\p{Is_Gc=surrogate}', "");
Expect(1, 57344, '\p{^Is_Gc=surrogate}', "");
Expect(1, 57344, '\P{Is_Gc=surrogate}', "");
Expect(0, 57344, '\P{^Is_Gc=surrogate}', "");
Expect(1, 57343, '\p{Is_Gc= 	SURROGATE}', "");
Expect(0, 57343, '\p{^Is_Gc= 	SURROGATE}', "");
Expect(0, 57343, '\P{Is_Gc= 	SURROGATE}', "");
Expect(1, 57343, '\P{^Is_Gc= 	SURROGATE}', "");
Expect(0, 57344, '\p{Is_Gc= 	SURROGATE}', "");
Expect(1, 57344, '\p{^Is_Gc= 	SURROGATE}', "");
Expect(1, 57344, '\P{Is_Gc= 	SURROGATE}', "");
Expect(0, 57344, '\P{^Is_Gc= 	SURROGATE}', "");
Error('\p{Is_Category=:=_	CS}');
Error('\P{Is_Category=:=_	CS}');
Expect(1, 57343, '\p{Is_Category=cs}', "");
Expect(0, 57343, '\p{^Is_Category=cs}', "");
Expect(0, 57343, '\P{Is_Category=cs}', "");
Expect(1, 57343, '\P{^Is_Category=cs}', "");
Expect(0, 57344, '\p{Is_Category=cs}', "");
Expect(1, 57344, '\p{^Is_Category=cs}', "");
Expect(1, 57344, '\P{Is_Category=cs}', "");
Expect(0, 57344, '\P{^Is_Category=cs}', "");
Expect(1, 57343, '\p{Is_Category= Cs}', "");
Expect(0, 57343, '\p{^Is_Category= Cs}', "");
Expect(0, 57343, '\P{Is_Category= Cs}', "");
Expect(1, 57343, '\P{^Is_Category= Cs}', "");
Expect(0, 57344, '\p{Is_Category= Cs}', "");
Expect(1, 57344, '\p{^Is_Category= Cs}', "");
Expect(1, 57344, '\P{Is_Category= Cs}', "");
Expect(0, 57344, '\P{^Is_Category= Cs}', "");
Error('\p{General_Category=-_Letter/a/}');
Error('\P{General_Category=-_Letter/a/}');
Expect(1, 195101, '\p{General_Category=letter}', "");
Expect(0, 195101, '\p{^General_Category=letter}', "");
Expect(0, 195101, '\P{General_Category=letter}', "");
Expect(1, 195101, '\P{^General_Category=letter}', "");
Expect(0, 195102, '\p{General_Category=letter}', "");
Expect(1, 195102, '\p{^General_Category=letter}', "");
Expect(1, 195102, '\P{General_Category=letter}', "");
Expect(0, 195102, '\P{^General_Category=letter}', "");
Expect(1, 195101, '\p{General_Category:   	-Letter}', "");
Expect(0, 195101, '\p{^General_Category:   	-Letter}', "");
Expect(0, 195101, '\P{General_Category:   	-Letter}', "");
Expect(1, 195101, '\P{^General_Category:   	-Letter}', "");
Expect(0, 195102, '\p{General_Category:   	-Letter}', "");
Expect(1, 195102, '\p{^General_Category:   	-Letter}', "");
Expect(1, 195102, '\P{General_Category:   	-Letter}', "");
Expect(0, 195102, '\P{^General_Category:   	-Letter}', "");
Error('\p{Gc=_L:=}');
Error('\P{Gc=_L:=}');
Expect(1, 195101, '\p{Gc=l}', "");
Expect(0, 195101, '\p{^Gc=l}', "");
Expect(0, 195101, '\P{Gc=l}', "");
Expect(1, 195101, '\P{^Gc=l}', "");
Expect(0, 195102, '\p{Gc=l}', "");
Expect(1, 195102, '\p{^Gc=l}', "");
Expect(1, 195102, '\P{Gc=l}', "");
Expect(0, 195102, '\P{^Gc=l}', "");
Expect(1, 195101, '\p{Gc=__L}', "");
Expect(0, 195101, '\p{^Gc=__L}', "");
Expect(0, 195101, '\P{Gc=__L}', "");
Expect(1, 195101, '\P{^Gc=__L}', "");
Expect(0, 195102, '\p{Gc=__L}', "");
Expect(1, 195102, '\p{^Gc=__L}', "");
Expect(1, 195102, '\P{Gc=__L}', "");
Expect(0, 195102, '\P{^Gc=__L}', "");
Error('\p{Category=:=LETTER}');
Error('\P{Category=:=LETTER}');
Expect(1, 195101, '\p{Category=letter}', "");
Expect(0, 195101, '\p{^Category=letter}', "");
Expect(0, 195101, '\P{Category=letter}', "");
Expect(1, 195101, '\P{^Category=letter}', "");
Expect(0, 195102, '\p{Category=letter}', "");
Expect(1, 195102, '\p{^Category=letter}', "");
Expect(1, 195102, '\P{Category=letter}', "");
Expect(0, 195102, '\P{^Category=letter}', "");
Expect(1, 195101, '\p{Category=	Letter}', "");
Expect(0, 195101, '\p{^Category=	Letter}', "");
Expect(0, 195101, '\P{Category=	Letter}', "");
Expect(1, 195101, '\P{^Category=	Letter}', "");
Expect(0, 195102, '\p{Category=	Letter}', "");
Expect(1, 195102, '\p{^Category=	Letter}', "");
Expect(1, 195102, '\P{Category=	Letter}', "");
Expect(0, 195102, '\P{^Category=	Letter}', "");
Error('\p{Is_General_Category=/a/L}');
Error('\P{Is_General_Category=/a/L}');
Expect(1, 195101, '\p{Is_General_Category=l}', "");
Expect(0, 195101, '\p{^Is_General_Category=l}', "");
Expect(0, 195101, '\P{Is_General_Category=l}', "");
Expect(1, 195101, '\P{^Is_General_Category=l}', "");
Expect(0, 195102, '\p{Is_General_Category=l}', "");
Expect(1, 195102, '\p{^Is_General_Category=l}', "");
Expect(1, 195102, '\P{Is_General_Category=l}', "");
Expect(0, 195102, '\P{^Is_General_Category=l}', "");
Expect(1, 195101, '\p{Is_General_Category: --L}', "");
Expect(0, 195101, '\p{^Is_General_Category: --L}', "");
Expect(0, 195101, '\P{Is_General_Category: --L}', "");
Expect(1, 195101, '\P{^Is_General_Category: --L}', "");
Expect(0, 195102, '\p{Is_General_Category: --L}', "");
Expect(1, 195102, '\p{^Is_General_Category: --L}', "");
Expect(1, 195102, '\P{Is_General_Category: --L}', "");
Expect(0, 195102, '\P{^Is_General_Category: --L}', "");
Error('\p{Is_Gc=_Letter/a/}');
Error('\P{Is_Gc=_Letter/a/}');
Expect(1, 195101, '\p{Is_Gc=letter}', "");
Expect(0, 195101, '\p{^Is_Gc=letter}', "");
Expect(0, 195101, '\P{Is_Gc=letter}', "");
Expect(1, 195101, '\P{^Is_Gc=letter}', "");
Expect(0, 195102, '\p{Is_Gc=letter}', "");
Expect(1, 195102, '\p{^Is_Gc=letter}', "");
Expect(1, 195102, '\P{Is_Gc=letter}', "");
Expect(0, 195102, '\P{^Is_Gc=letter}', "");
Expect(1, 195101, '\p{Is_Gc=_-letter}', "");
Expect(0, 195101, '\p{^Is_Gc=_-letter}', "");
Expect(0, 195101, '\P{Is_Gc=_-letter}', "");
Expect(1, 195101, '\P{^Is_Gc=_-letter}', "");
Expect(0, 195102, '\p{Is_Gc=_-letter}', "");
Expect(1, 195102, '\p{^Is_Gc=_-letter}', "");
Expect(1, 195102, '\P{Is_Gc=_-letter}', "");
Expect(0, 195102, '\P{^Is_Gc=_-letter}', "");
Error('\p{Is_Category=	l/a/}');
Error('\P{Is_Category=	l/a/}');
Expect(1, 195101, '\p{Is_Category=l}', "");
Expect(0, 195101, '\p{^Is_Category=l}', "");
Expect(0, 195101, '\P{Is_Category=l}', "");
Expect(1, 195101, '\P{^Is_Category=l}', "");
Expect(0, 195102, '\p{Is_Category=l}', "");
Expect(1, 195102, '\p{^Is_Category=l}', "");
Expect(1, 195102, '\P{Is_Category=l}', "");
Expect(0, 195102, '\P{^Is_Category=l}', "");
Error('\p{General_Category=:=Cased_Letter}');
Error('\P{General_Category=:=Cased_Letter}');
Expect(1, 120779, '\p{General_Category=casedletter}', "");
Expect(0, 120779, '\p{^General_Category=casedletter}', "");
Expect(0, 120779, '\P{General_Category=casedletter}', "");
Expect(1, 120779, '\P{^General_Category=casedletter}', "");
Expect(0, 120780, '\p{General_Category=casedletter}', "");
Expect(1, 120780, '\p{^General_Category=casedletter}', "");
Expect(1, 120780, '\P{General_Category=casedletter}', "");
Expect(0, 120780, '\P{^General_Category=casedletter}', "");
Expect(1, 120779, '\p{General_Category= cased_Letter}', "");
Expect(0, 120779, '\p{^General_Category= cased_Letter}', "");
Expect(0, 120779, '\P{General_Category= cased_Letter}', "");
Expect(1, 120779, '\P{^General_Category= cased_Letter}', "");
Expect(0, 120780, '\p{General_Category= cased_Letter}', "");
Expect(1, 120780, '\p{^General_Category= cased_Letter}', "");
Expect(1, 120780, '\P{General_Category= cased_Letter}', "");
Expect(0, 120780, '\P{^General_Category= cased_Letter}', "");
Error('\p{Gc:  :=lc}');
Error('\P{Gc:  :=lc}');
Expect(1, 120779, '\p{Gc=lc}', "");
Expect(0, 120779, '\p{^Gc=lc}', "");
Expect(0, 120779, '\P{Gc=lc}', "");
Expect(1, 120779, '\P{^Gc=lc}', "");
Expect(0, 120780, '\p{Gc=lc}', "");
Expect(1, 120780, '\p{^Gc=lc}', "");
Expect(1, 120780, '\P{Gc=lc}', "");
Expect(0, 120780, '\P{^Gc=lc}', "");
Expect(1, 120779, '\p{Gc: -LC}', "");
Expect(0, 120779, '\p{^Gc: -LC}', "");
Expect(0, 120779, '\P{Gc: -LC}', "");
Expect(1, 120779, '\P{^Gc: -LC}', "");
Expect(0, 120780, '\p{Gc: -LC}', "");
Expect(1, 120780, '\p{^Gc: -LC}', "");
Expect(1, 120780, '\P{Gc: -LC}', "");
Expect(0, 120780, '\P{^Gc: -LC}', "");
Error('\p{Category:   _	l_:=}');
Error('\P{Category:   _	l_:=}');
Expect(1, 120779, '\p{Category=l_}', "");
Expect(0, 120779, '\p{^Category=l_}', "");
Expect(0, 120779, '\P{Category=l_}', "");
Expect(1, 120779, '\P{^Category=l_}', "");
Expect(0, 120780, '\p{Category=l_}', "");
Expect(1, 120780, '\p{^Category=l_}', "");
Expect(1, 120780, '\P{Category=l_}', "");
Expect(0, 120780, '\P{^Category=l_}', "");
Expect(1, 120779, '\p{Category=  L_}', "");
Expect(0, 120779, '\p{^Category=  L_}', "");
Expect(0, 120779, '\P{Category=  L_}', "");
Expect(1, 120779, '\P{^Category=  L_}', "");
Expect(0, 120780, '\p{Category=  L_}', "");
Expect(1, 120780, '\p{^Category=  L_}', "");
Expect(1, 120780, '\P{Category=  L_}', "");
Expect(0, 120780, '\P{^Category=  L_}', "");
Error('\p{Is_General_Category=:=	L&}');
Error('\P{Is_General_Category=:=	L&}');
Expect(1, 120779, '\p{Is_General_Category=l&}', "");
Expect(0, 120779, '\p{^Is_General_Category=l&}', "");
Expect(0, 120779, '\P{Is_General_Category=l&}', "");
Expect(1, 120779, '\P{^Is_General_Category=l&}', "");
Expect(0, 120780, '\p{Is_General_Category=l&}', "");
Expect(1, 120780, '\p{^Is_General_Category=l&}', "");
Expect(1, 120780, '\P{Is_General_Category=l&}', "");
Expect(0, 120780, '\P{^Is_General_Category=l&}', "");
Expect(1, 120779, '\p{Is_General_Category=_L&}', "");
Expect(0, 120779, '\p{^Is_General_Category=_L&}', "");
Expect(0, 120779, '\P{Is_General_Category=_L&}', "");
Expect(1, 120779, '\P{^Is_General_Category=_L&}', "");
Expect(0, 120780, '\p{Is_General_Category=_L&}', "");
Expect(1, 120780, '\p{^Is_General_Category=_L&}', "");
Expect(1, 120780, '\P{Is_General_Category=_L&}', "");
Expect(0, 120780, '\P{^Is_General_Category=_L&}', "");
Error('\p{Is_Gc=:=cased_LETTER}');
Error('\P{Is_Gc=:=cased_LETTER}');
Expect(1, 120779, '\p{Is_Gc=casedletter}', "");
Expect(0, 120779, '\p{^Is_Gc=casedletter}', "");
Expect(0, 120779, '\P{Is_Gc=casedletter}', "");
Expect(1, 120779, '\P{^Is_Gc=casedletter}', "");
Expect(0, 120780, '\p{Is_Gc=casedletter}', "");
Expect(1, 120780, '\p{^Is_Gc=casedletter}', "");
Expect(1, 120780, '\P{Is_Gc=casedletter}', "");
Expect(0, 120780, '\P{^Is_Gc=casedletter}', "");
Expect(1, 120779, '\p{Is_Gc=	CASED_letter}', "");
Expect(0, 120779, '\p{^Is_Gc=	CASED_letter}', "");
Expect(0, 120779, '\P{Is_Gc=	CASED_letter}', "");
Expect(1, 120779, '\P{^Is_Gc=	CASED_letter}', "");
Expect(0, 120780, '\p{Is_Gc=	CASED_letter}', "");
Expect(1, 120780, '\p{^Is_Gc=	CASED_letter}', "");
Expect(1, 120780, '\P{Is_Gc=	CASED_letter}', "");
Expect(0, 120780, '\P{^Is_Gc=	CASED_letter}', "");
Error('\p{Is_Category=_-LC:=}');
Error('\P{Is_Category=_-LC:=}');
Expect(1, 120779, '\p{Is_Category=lc}', "");
Expect(0, 120779, '\p{^Is_Category=lc}', "");
Expect(0, 120779, '\P{Is_Category=lc}', "");
Expect(1, 120779, '\P{^Is_Category=lc}', "");
Expect(0, 120780, '\p{Is_Category=lc}', "");
Expect(1, 120780, '\p{^Is_Category=lc}', "");
Expect(1, 120780, '\P{Is_Category=lc}', "");
Expect(0, 120780, '\P{^Is_Category=lc}', "");
Expect(1, 120779, '\p{Is_Category= LC}', "");
Expect(0, 120779, '\p{^Is_Category= LC}', "");
Expect(0, 120779, '\P{Is_Category= LC}', "");
Expect(1, 120779, '\P{^Is_Category= LC}', "");
Expect(0, 120780, '\p{Is_Category= LC}', "");
Expect(1, 120780, '\p{^Is_Category= LC}', "");
Expect(1, 120780, '\P{Is_Category= LC}', "");
Expect(0, 120780, '\P{^Is_Category= LC}', "");
Error('\p{General_Category: /a/LOWERCASE_Letter}');
Error('\P{General_Category: /a/LOWERCASE_Letter}');
Expect(1, 120779, '\p{General_Category=lowercaseletter}', "");
Expect(0, 120779, '\p{^General_Category=lowercaseletter}', "");
Expect(0, 120779, '\P{General_Category=lowercaseletter}', "");
Expect(1, 120779, '\P{^General_Category=lowercaseletter}', "");
Expect(0, 120780, '\p{General_Category=lowercaseletter}', "");
Expect(1, 120780, '\p{^General_Category=lowercaseletter}', "");
Expect(1, 120780, '\P{General_Category=lowercaseletter}', "");
Expect(0, 120780, '\P{^General_Category=lowercaseletter}', "");
Expect(1, 120779, '\p{General_Category= Lowercase_Letter}', "");
Expect(0, 120779, '\p{^General_Category= Lowercase_Letter}', "");
Expect(0, 120779, '\P{General_Category= Lowercase_Letter}', "");
Expect(1, 120779, '\P{^General_Category= Lowercase_Letter}', "");
Expect(0, 120780, '\p{General_Category= Lowercase_Letter}', "");
Expect(1, 120780, '\p{^General_Category= Lowercase_Letter}', "");
Expect(1, 120780, '\P{General_Category= Lowercase_Letter}', "");
Expect(0, 120780, '\P{^General_Category= Lowercase_Letter}', "");
Error('\p{Gc:/a/- ll}');
Error('\P{Gc:/a/- ll}');
Expect(1, 120779, '\p{Gc=ll}', "");
Expect(0, 120779, '\p{^Gc=ll}', "");
Expect(0, 120779, '\P{Gc=ll}', "");
Expect(1, 120779, '\P{^Gc=ll}', "");
Expect(0, 120780, '\p{Gc=ll}', "");
Expect(1, 120780, '\p{^Gc=ll}', "");
Expect(1, 120780, '\P{Gc=ll}', "");
Expect(0, 120780, '\P{^Gc=ll}', "");
Expect(1, 120779, '\p{Gc=	Ll}', "");
Expect(0, 120779, '\p{^Gc=	Ll}', "");
Expect(0, 120779, '\P{Gc=	Ll}', "");
Expect(1, 120779, '\P{^Gc=	Ll}', "");
Expect(0, 120780, '\p{Gc=	Ll}', "");
Expect(1, 120780, '\p{^Gc=	Ll}', "");
Expect(1, 120780, '\P{Gc=	Ll}', "");
Expect(0, 120780, '\P{^Gc=	Ll}', "");
Error('\p{Category=/a/LOWERCASE_letter}');
Error('\P{Category=/a/LOWERCASE_letter}');
Expect(1, 120779, '\p{Category=lowercaseletter}', "");
Expect(0, 120779, '\p{^Category=lowercaseletter}', "");
Expect(0, 120779, '\P{Category=lowercaseletter}', "");
Expect(1, 120779, '\P{^Category=lowercaseletter}', "");
Expect(0, 120780, '\p{Category=lowercaseletter}', "");
Expect(1, 120780, '\p{^Category=lowercaseletter}', "");
Expect(1, 120780, '\P{Category=lowercaseletter}', "");
Expect(0, 120780, '\P{^Category=lowercaseletter}', "");
Expect(1, 120779, '\p{Category=	 Lowercase_Letter}', "");
Expect(0, 120779, '\p{^Category=	 Lowercase_Letter}', "");
Expect(0, 120779, '\P{Category=	 Lowercase_Letter}', "");
Expect(1, 120779, '\P{^Category=	 Lowercase_Letter}', "");
Expect(0, 120780, '\p{Category=	 Lowercase_Letter}', "");
Expect(1, 120780, '\p{^Category=	 Lowercase_Letter}', "");
Expect(1, 120780, '\P{Category=	 Lowercase_Letter}', "");
Expect(0, 120780, '\P{^Category=	 Lowercase_Letter}', "");
Error('\p{Is_General_Category=:= LL}');
Error('\P{Is_General_Category=:= LL}');
Expect(1, 120779, '\p{Is_General_Category=ll}', "");
Expect(0, 120779, '\p{^Is_General_Category=ll}', "");
Expect(0, 120779, '\P{Is_General_Category=ll}', "");
Expect(1, 120779, '\P{^Is_General_Category=ll}', "");
Expect(0, 120780, '\p{Is_General_Category=ll}', "");
Expect(1, 120780, '\p{^Is_General_Category=ll}', "");
Expect(1, 120780, '\P{Is_General_Category=ll}', "");
Expect(0, 120780, '\P{^Is_General_Category=ll}', "");
Expect(1, 120779, '\p{Is_General_Category=_	Ll}', "");
Expect(0, 120779, '\p{^Is_General_Category=_	Ll}', "");
Expect(0, 120779, '\P{Is_General_Category=_	Ll}', "");
Expect(1, 120779, '\P{^Is_General_Category=_	Ll}', "");
Expect(0, 120780, '\p{Is_General_Category=_	Ll}', "");
Expect(1, 120780, '\p{^Is_General_Category=_	Ll}', "");
Expect(1, 120780, '\P{Is_General_Category=_	Ll}', "");
Expect(0, 120780, '\P{^Is_General_Category=_	Ll}', "");
Error('\p{Is_Gc=	-Lowercase_LETTER:=}');
Error('\P{Is_Gc=	-Lowercase_LETTER:=}');
Expect(1, 120779, '\p{Is_Gc=lowercaseletter}', "");
Expect(0, 120779, '\p{^Is_Gc=lowercaseletter}', "");
Expect(0, 120779, '\P{Is_Gc=lowercaseletter}', "");
Expect(1, 120779, '\P{^Is_Gc=lowercaseletter}', "");
Expect(0, 120780, '\p{Is_Gc=lowercaseletter}', "");
Expect(1, 120780, '\p{^Is_Gc=lowercaseletter}', "");
Expect(1, 120780, '\P{Is_Gc=lowercaseletter}', "");
Expect(0, 120780, '\P{^Is_Gc=lowercaseletter}', "");
Expect(1, 120779, '\p{Is_Gc= LOWERCASE_Letter}', "");
Expect(0, 120779, '\p{^Is_Gc= LOWERCASE_Letter}', "");
Expect(0, 120779, '\P{Is_Gc= LOWERCASE_Letter}', "");
Expect(1, 120779, '\P{^Is_Gc= LOWERCASE_Letter}', "");
Expect(0, 120780, '\p{Is_Gc= LOWERCASE_Letter}', "");
Expect(1, 120780, '\p{^Is_Gc= LOWERCASE_Letter}', "");
Expect(1, 120780, '\P{Is_Gc= LOWERCASE_Letter}', "");
Expect(0, 120780, '\P{^Is_Gc= LOWERCASE_Letter}', "");
Error('\p{Is_Category=_ll/a/}');
Error('\P{Is_Category=_ll/a/}');
Expect(1, 120779, '\p{Is_Category=ll}', "");
Expect(0, 120779, '\p{^Is_Category=ll}', "");
Expect(0, 120779, '\P{Is_Category=ll}', "");
Expect(1, 120779, '\P{^Is_Category=ll}', "");
Expect(0, 120780, '\p{Is_Category=ll}', "");
Expect(1, 120780, '\p{^Is_Category=ll}', "");
Expect(1, 120780, '\P{Is_Category=ll}', "");
Expect(0, 120780, '\P{^Is_Category=ll}', "");
Expect(1, 120779, '\p{Is_Category= 	Ll}', "");
Expect(0, 120779, '\p{^Is_Category= 	Ll}', "");
Expect(0, 120779, '\P{Is_Category= 	Ll}', "");
Expect(1, 120779, '\P{^Is_Category= 	Ll}', "");
Expect(0, 120780, '\p{Is_Category= 	Ll}', "");
Expect(1, 120780, '\p{^Is_Category= 	Ll}', "");
Expect(1, 120780, '\P{Is_Category= 	Ll}', "");
Expect(0, 120780, '\P{^Is_Category= 	Ll}', "");
Error('\p{General_Category= Modifier_LETTER/a/}');
Error('\P{General_Category= Modifier_LETTER/a/}');
Expect(1, 94111, '\p{General_Category=modifierletter}', "");
Expect(0, 94111, '\p{^General_Category=modifierletter}', "");
Expect(0, 94111, '\P{General_Category=modifierletter}', "");
Expect(1, 94111, '\P{^General_Category=modifierletter}', "");
Expect(0, 94112, '\p{General_Category=modifierletter}', "");
Expect(1, 94112, '\p{^General_Category=modifierletter}', "");
Expect(1, 94112, '\P{General_Category=modifierletter}', "");
Expect(0, 94112, '\P{^General_Category=modifierletter}', "");
Expect(1, 94111, '\p{General_Category:- Modifier_Letter}', "");
Expect(0, 94111, '\p{^General_Category:- Modifier_Letter}', "");
Expect(0, 94111, '\P{General_Category:- Modifier_Letter}', "");
Expect(1, 94111, '\P{^General_Category:- Modifier_Letter}', "");
Expect(0, 94112, '\p{General_Category:- Modifier_Letter}', "");
Expect(1, 94112, '\p{^General_Category:- Modifier_Letter}', "");
Expect(1, 94112, '\P{General_Category:- Modifier_Letter}', "");
Expect(0, 94112, '\P{^General_Category:- Modifier_Letter}', "");
Error('\p{Gc=_lm:=}');
Error('\P{Gc=_lm:=}');
Expect(1, 94111, '\p{Gc=lm}', "");
Expect(0, 94111, '\p{^Gc=lm}', "");
Expect(0, 94111, '\P{Gc=lm}', "");
Expect(1, 94111, '\P{^Gc=lm}', "");
Expect(0, 94112, '\p{Gc=lm}', "");
Expect(1, 94112, '\p{^Gc=lm}', "");
Expect(1, 94112, '\P{Gc=lm}', "");
Expect(0, 94112, '\P{^Gc=lm}', "");
Expect(1, 94111, '\p{Gc= 	Lm}', "");
Expect(0, 94111, '\p{^Gc= 	Lm}', "");
Expect(0, 94111, '\P{Gc= 	Lm}', "");
Expect(1, 94111, '\P{^Gc= 	Lm}', "");
Expect(0, 94112, '\p{Gc= 	Lm}', "");
Expect(1, 94112, '\p{^Gc= 	Lm}', "");
Expect(1, 94112, '\P{Gc= 	Lm}', "");
Expect(0, 94112, '\P{^Gc= 	Lm}', "");
Error('\p{Category= :=MODIFIER_letter}');
Error('\P{Category= :=MODIFIER_letter}');
Expect(1, 94111, '\p{Category=modifierletter}', "");
Expect(0, 94111, '\p{^Category=modifierletter}', "");
Expect(0, 94111, '\P{Category=modifierletter}', "");
Expect(1, 94111, '\P{^Category=modifierletter}', "");
Expect(0, 94112, '\p{Category=modifierletter}', "");
Expect(1, 94112, '\p{^Category=modifierletter}', "");
Expect(1, 94112, '\P{Category=modifierletter}', "");
Expect(0, 94112, '\P{^Category=modifierletter}', "");
Expect(1, 94111, '\p{Category=  modifier_Letter}', "");
Expect(0, 94111, '\p{^Category=  modifier_Letter}', "");
Expect(0, 94111, '\P{Category=  modifier_Letter}', "");
Expect(1, 94111, '\P{^Category=  modifier_Letter}', "");
Expect(0, 94112, '\p{Category=  modifier_Letter}', "");
Expect(1, 94112, '\p{^Category=  modifier_Letter}', "");
Expect(1, 94112, '\P{Category=  modifier_Letter}', "");
Expect(0, 94112, '\P{^Category=  modifier_Letter}', "");
Error('\p{Is_General_Category= /a/lm}');
Error('\P{Is_General_Category= /a/lm}');
Expect(1, 94111, '\p{Is_General_Category:lm}', "");
Expect(0, 94111, '\p{^Is_General_Category:lm}', "");
Expect(0, 94111, '\P{Is_General_Category:lm}', "");
Expect(1, 94111, '\P{^Is_General_Category:lm}', "");
Expect(0, 94112, '\p{Is_General_Category:lm}', "");
Expect(1, 94112, '\p{^Is_General_Category:lm}', "");
Expect(1, 94112, '\P{Is_General_Category:lm}', "");
Expect(0, 94112, '\P{^Is_General_Category:lm}', "");
Expect(1, 94111, '\p{Is_General_Category=-Lm}', "");
Expect(0, 94111, '\p{^Is_General_Category=-Lm}', "");
Expect(0, 94111, '\P{Is_General_Category=-Lm}', "");
Expect(1, 94111, '\P{^Is_General_Category=-Lm}', "");
Expect(0, 94112, '\p{Is_General_Category=-Lm}', "");
Expect(1, 94112, '\p{^Is_General_Category=-Lm}', "");
Expect(1, 94112, '\P{Is_General_Category=-Lm}', "");
Expect(0, 94112, '\P{^Is_General_Category=-Lm}', "");
Error('\p{Is_Gc=/a/_Modifier_LETTER}');
Error('\P{Is_Gc=/a/_Modifier_LETTER}');
Expect(1, 94111, '\p{Is_Gc=modifierletter}', "");
Expect(0, 94111, '\p{^Is_Gc=modifierletter}', "");
Expect(0, 94111, '\P{Is_Gc=modifierletter}', "");
Expect(1, 94111, '\P{^Is_Gc=modifierletter}', "");
Expect(0, 94112, '\p{Is_Gc=modifierletter}', "");
Expect(1, 94112, '\p{^Is_Gc=modifierletter}', "");
Expect(1, 94112, '\P{Is_Gc=modifierletter}', "");
Expect(0, 94112, '\P{^Is_Gc=modifierletter}', "");
Expect(1, 94111, '\p{Is_Gc= Modifier_letter}', "");
Expect(0, 94111, '\p{^Is_Gc= Modifier_letter}', "");
Expect(0, 94111, '\P{Is_Gc= Modifier_letter}', "");
Expect(1, 94111, '\P{^Is_Gc= Modifier_letter}', "");
Expect(0, 94112, '\p{Is_Gc= Modifier_letter}', "");
Expect(1, 94112, '\p{^Is_Gc= Modifier_letter}', "");
Expect(1, 94112, '\P{Is_Gc= Modifier_letter}', "");
Expect(0, 94112, '\P{^Is_Gc= Modifier_letter}', "");
Error('\p{Is_Category:	_:=lm}');
Error('\P{Is_Category:	_:=lm}');
Expect(1, 94111, '\p{Is_Category=lm}', "");
Expect(0, 94111, '\p{^Is_Category=lm}', "");
Expect(0, 94111, '\P{Is_Category=lm}', "");
Expect(1, 94111, '\P{^Is_Category=lm}', "");
Expect(0, 94112, '\p{Is_Category=lm}', "");
Expect(1, 94112, '\p{^Is_Category=lm}', "");
Expect(1, 94112, '\P{Is_Category=lm}', "");
Expect(0, 94112, '\P{^Is_Category=lm}', "");
Expect(1, 94111, '\p{Is_Category=_-Lm}', "");
Expect(0, 94111, '\p{^Is_Category=_-Lm}', "");
Expect(0, 94111, '\P{Is_Category=_-Lm}', "");
Expect(1, 94111, '\P{^Is_Category=_-Lm}', "");
Expect(0, 94112, '\p{Is_Category=_-Lm}', "");
Expect(1, 94112, '\p{^Is_Category=_-Lm}', "");
Expect(1, 94112, '\P{Is_Category=_-Lm}', "");
Expect(0, 94112, '\P{^Is_Category=_-Lm}', "");
Error('\p{General_Category:			Other_LETTER:=}');
Error('\P{General_Category:			Other_LETTER:=}');
Expect(1, 195101, '\p{General_Category=otherletter}', "");
Expect(0, 195101, '\p{^General_Category=otherletter}', "");
Expect(0, 195101, '\P{General_Category=otherletter}', "");
Expect(1, 195101, '\P{^General_Category=otherletter}', "");
Expect(0, 195102, '\p{General_Category=otherletter}', "");
Expect(1, 195102, '\p{^General_Category=otherletter}', "");
Expect(1, 195102, '\P{General_Category=otherletter}', "");
Expect(0, 195102, '\P{^General_Category=otherletter}', "");
Expect(1, 195101, '\p{General_Category=_-Other_LETTER}', "");
Expect(0, 195101, '\p{^General_Category=_-Other_LETTER}', "");
Expect(0, 195101, '\P{General_Category=_-Other_LETTER}', "");
Expect(1, 195101, '\P{^General_Category=_-Other_LETTER}', "");
Expect(0, 195102, '\p{General_Category=_-Other_LETTER}', "");
Expect(1, 195102, '\p{^General_Category=_-Other_LETTER}', "");
Expect(1, 195102, '\P{General_Category=_-Other_LETTER}', "");
Expect(0, 195102, '\P{^General_Category=_-Other_LETTER}', "");
Error('\p{Gc:/a/	Lo}');
Error('\P{Gc:/a/	Lo}');
Expect(1, 195101, '\p{Gc=lo}', "");
Expect(0, 195101, '\p{^Gc=lo}', "");
Expect(0, 195101, '\P{Gc=lo}', "");
Expect(1, 195101, '\P{^Gc=lo}', "");
Expect(0, 195102, '\p{Gc=lo}', "");
Expect(1, 195102, '\p{^Gc=lo}', "");
Expect(1, 195102, '\P{Gc=lo}', "");
Expect(0, 195102, '\P{^Gc=lo}', "");
Expect(1, 195101, '\p{Gc= Lo}', "");
Expect(0, 195101, '\p{^Gc= Lo}', "");
Expect(0, 195101, '\P{Gc= Lo}', "");
Expect(1, 195101, '\P{^Gc= Lo}', "");
Expect(0, 195102, '\p{Gc= Lo}', "");
Expect(1, 195102, '\p{^Gc= Lo}', "");
Expect(1, 195102, '\P{Gc= Lo}', "");
Expect(0, 195102, '\P{^Gc= Lo}', "");
Error('\p{Category= :=Other_Letter}');
Error('\P{Category= :=Other_Letter}');
Expect(1, 195101, '\p{Category=otherletter}', "");
Expect(0, 195101, '\p{^Category=otherletter}', "");
Expect(0, 195101, '\P{Category=otherletter}', "");
Expect(1, 195101, '\P{^Category=otherletter}', "");
Expect(0, 195102, '\p{Category=otherletter}', "");
Expect(1, 195102, '\p{^Category=otherletter}', "");
Expect(1, 195102, '\P{Category=otherletter}', "");
Expect(0, 195102, '\P{^Category=otherletter}', "");
Expect(1, 195101, '\p{Category=-other_Letter}', "");
Expect(0, 195101, '\p{^Category=-other_Letter}', "");
Expect(0, 195101, '\P{Category=-other_Letter}', "");
Expect(1, 195101, '\P{^Category=-other_Letter}', "");
Expect(0, 195102, '\p{Category=-other_Letter}', "");
Expect(1, 195102, '\p{^Category=-other_Letter}', "");
Expect(1, 195102, '\P{Category=-other_Letter}', "");
Expect(0, 195102, '\P{^Category=-other_Letter}', "");
Error('\p{Is_General_Category=/a/	lo}');
Error('\P{Is_General_Category=/a/	lo}');
Expect(1, 195101, '\p{Is_General_Category:   lo}', "");
Expect(0, 195101, '\p{^Is_General_Category:   lo}', "");
Expect(0, 195101, '\P{Is_General_Category:   lo}', "");
Expect(1, 195101, '\P{^Is_General_Category:   lo}', "");
Expect(0, 195102, '\p{Is_General_Category:   lo}', "");
Expect(1, 195102, '\p{^Is_General_Category:   lo}', "");
Expect(1, 195102, '\P{Is_General_Category:   lo}', "");
Expect(0, 195102, '\P{^Is_General_Category:   lo}', "");
Expect(1, 195101, '\p{Is_General_Category:   -	Lo}', "");
Expect(0, 195101, '\p{^Is_General_Category:   -	Lo}', "");
Expect(0, 195101, '\P{Is_General_Category:   -	Lo}', "");
Expect(1, 195101, '\P{^Is_General_Category:   -	Lo}', "");
Expect(0, 195102, '\p{Is_General_Category:   -	Lo}', "");
Expect(1, 195102, '\p{^Is_General_Category:   -	Lo}', "");
Expect(1, 195102, '\P{Is_General_Category:   -	Lo}', "");
Expect(0, 195102, '\P{^Is_General_Category:   -	Lo}', "");
Error('\p{Is_Gc=/a/other_LETTER}');
Error('\P{Is_Gc=/a/other_LETTER}');
Expect(1, 195101, '\p{Is_Gc=otherletter}', "");
Expect(0, 195101, '\p{^Is_Gc=otherletter}', "");
Expect(0, 195101, '\P{Is_Gc=otherletter}', "");
Expect(1, 195101, '\P{^Is_Gc=otherletter}', "");
Expect(0, 195102, '\p{Is_Gc=otherletter}', "");
Expect(1, 195102, '\p{^Is_Gc=otherletter}', "");
Expect(1, 195102, '\P{Is_Gc=otherletter}', "");
Expect(0, 195102, '\P{^Is_Gc=otherletter}', "");
Expect(1, 195101, '\p{Is_Gc:  	other_Letter}', "");
Expect(0, 195101, '\p{^Is_Gc:  	other_Letter}', "");
Expect(0, 195101, '\P{Is_Gc:  	other_Letter}', "");
Expect(1, 195101, '\P{^Is_Gc:  	other_Letter}', "");
Expect(0, 195102, '\p{Is_Gc:  	other_Letter}', "");
Expect(1, 195102, '\p{^Is_Gc:  	other_Letter}', "");
Expect(1, 195102, '\P{Is_Gc:  	other_Letter}', "");
Expect(0, 195102, '\P{^Is_Gc:  	other_Letter}', "");
Error('\p{Is_Category=	/a/LO}');
Error('\P{Is_Category=	/a/LO}');
Expect(1, 195101, '\p{Is_Category=lo}', "");
Expect(0, 195101, '\p{^Is_Category=lo}', "");
Expect(0, 195101, '\P{Is_Category=lo}', "");
Expect(1, 195101, '\P{^Is_Category=lo}', "");
Expect(0, 195102, '\p{Is_Category=lo}', "");
Expect(1, 195102, '\p{^Is_Category=lo}', "");
Expect(1, 195102, '\P{Is_Category=lo}', "");
Expect(0, 195102, '\P{^Is_Category=lo}', "");
Expect(1, 195101, '\p{Is_Category= Lo}', "");
Expect(0, 195101, '\p{^Is_Category= Lo}', "");
Expect(0, 195101, '\P{Is_Category= Lo}', "");
Expect(1, 195101, '\P{^Is_Category= Lo}', "");
Expect(0, 195102, '\p{Is_Category= Lo}', "");
Expect(1, 195102, '\p{^Is_Category= Lo}', "");
Expect(1, 195102, '\P{Is_Category= Lo}', "");
Expect(0, 195102, '\P{^Is_Category= Lo}', "");
Error('\p{General_Category: /a/TITLECASE_Letter}');
Error('\P{General_Category: /a/TITLECASE_Letter}');
Expect(1, 8188, '\p{General_Category=titlecaseletter}', "");
Expect(0, 8188, '\p{^General_Category=titlecaseletter}', "");
Expect(0, 8188, '\P{General_Category=titlecaseletter}', "");
Expect(1, 8188, '\P{^General_Category=titlecaseletter}', "");
Expect(0, 8189, '\p{General_Category=titlecaseletter}', "");
Expect(1, 8189, '\p{^General_Category=titlecaseletter}', "");
Expect(1, 8189, '\P{General_Category=titlecaseletter}', "");
Expect(0, 8189, '\P{^General_Category=titlecaseletter}', "");
Expect(1, 8188, '\p{General_Category=TITLECASE_Letter}', "");
Expect(0, 8188, '\p{^General_Category=TITLECASE_Letter}', "");
Expect(0, 8188, '\P{General_Category=TITLECASE_Letter}', "");
Expect(1, 8188, '\P{^General_Category=TITLECASE_Letter}', "");
Expect(0, 8189, '\p{General_Category=TITLECASE_Letter}', "");
Expect(1, 8189, '\p{^General_Category=TITLECASE_Letter}', "");
Expect(1, 8189, '\P{General_Category=TITLECASE_Letter}', "");
Expect(0, 8189, '\P{^General_Category=TITLECASE_Letter}', "");
Error('\p{Gc=- lt/a/}');
Error('\P{Gc=- lt/a/}');
Expect(1, 8188, '\p{Gc=lt}', "");
Expect(0, 8188, '\p{^Gc=lt}', "");
Expect(0, 8188, '\P{Gc=lt}', "");
Expect(1, 8188, '\P{^Gc=lt}', "");
Expect(0, 8189, '\p{Gc=lt}', "");
Expect(1, 8189, '\p{^Gc=lt}', "");
Expect(1, 8189, '\P{Gc=lt}', "");
Expect(0, 8189, '\P{^Gc=lt}', "");
Expect(1, 8188, '\p{Gc=		Lt}', "");
Expect(0, 8188, '\p{^Gc=		Lt}', "");
Expect(0, 8188, '\P{Gc=		Lt}', "");
Expect(1, 8188, '\P{^Gc=		Lt}', "");
Expect(0, 8189, '\p{Gc=		Lt}', "");
Expect(1, 8189, '\p{^Gc=		Lt}', "");
Expect(1, 8189, '\P{Gc=		Lt}', "");
Expect(0, 8189, '\P{^Gc=		Lt}', "");
Error('\p{Category=:=_Titlecase_LETTER}');
Error('\P{Category=:=_Titlecase_LETTER}');
Expect(1, 8188, '\p{Category=titlecaseletter}', "");
Expect(0, 8188, '\p{^Category=titlecaseletter}', "");
Expect(0, 8188, '\P{Category=titlecaseletter}', "");
Expect(1, 8188, '\P{^Category=titlecaseletter}', "");
Expect(0, 8189, '\p{Category=titlecaseletter}', "");
Expect(1, 8189, '\p{^Category=titlecaseletter}', "");
Expect(1, 8189, '\P{Category=titlecaseletter}', "");
Expect(0, 8189, '\P{^Category=titlecaseletter}', "");
Expect(1, 8188, '\p{Category:	__TITLECASE_Letter}', "");
Expect(0, 8188, '\p{^Category:	__TITLECASE_Letter}', "");
Expect(0, 8188, '\P{Category:	__TITLECASE_Letter}', "");
Expect(1, 8188, '\P{^Category:	__TITLECASE_Letter}', "");
Expect(0, 8189, '\p{Category:	__TITLECASE_Letter}', "");
Expect(1, 8189, '\p{^Category:	__TITLECASE_Letter}', "");
Expect(1, 8189, '\P{Category:	__TITLECASE_Letter}', "");
Expect(0, 8189, '\P{^Category:	__TITLECASE_Letter}', "");
Error('\p{Is_General_Category=/a/lt}');
Error('\P{Is_General_Category=/a/lt}');
Expect(1, 8188, '\p{Is_General_Category=lt}', "");
Expect(0, 8188, '\p{^Is_General_Category=lt}', "");
Expect(0, 8188, '\P{Is_General_Category=lt}', "");
Expect(1, 8188, '\P{^Is_General_Category=lt}', "");
Expect(0, 8189, '\p{Is_General_Category=lt}', "");
Expect(1, 8189, '\p{^Is_General_Category=lt}', "");
Expect(1, 8189, '\P{Is_General_Category=lt}', "");
Expect(0, 8189, '\P{^Is_General_Category=lt}', "");
Expect(1, 8188, '\p{Is_General_Category=_-LT}', "");
Expect(0, 8188, '\p{^Is_General_Category=_-LT}', "");
Expect(0, 8188, '\P{Is_General_Category=_-LT}', "");
Expect(1, 8188, '\P{^Is_General_Category=_-LT}', "");
Expect(0, 8189, '\p{Is_General_Category=_-LT}', "");
Expect(1, 8189, '\p{^Is_General_Category=_-LT}', "");
Expect(1, 8189, '\P{Is_General_Category=_-LT}', "");
Expect(0, 8189, '\P{^Is_General_Category=_-LT}', "");
Error('\p{Is_Gc: /a/_	Titlecase_Letter}');
Error('\P{Is_Gc: /a/_	Titlecase_Letter}');
Expect(1, 8188, '\p{Is_Gc=titlecaseletter}', "");
Expect(0, 8188, '\p{^Is_Gc=titlecaseletter}', "");
Expect(0, 8188, '\P{Is_Gc=titlecaseletter}', "");
Expect(1, 8188, '\P{^Is_Gc=titlecaseletter}', "");
Expect(0, 8189, '\p{Is_Gc=titlecaseletter}', "");
Expect(1, 8189, '\p{^Is_Gc=titlecaseletter}', "");
Expect(1, 8189, '\P{Is_Gc=titlecaseletter}', "");
Expect(0, 8189, '\P{^Is_Gc=titlecaseletter}', "");
Expect(1, 8188, '\p{Is_Gc:   	 TITLECASE_Letter}', "");
Expect(0, 8188, '\p{^Is_Gc:   	 TITLECASE_Letter}', "");
Expect(0, 8188, '\P{Is_Gc:   	 TITLECASE_Letter}', "");
Expect(1, 8188, '\P{^Is_Gc:   	 TITLECASE_Letter}', "");
Expect(0, 8189, '\p{Is_Gc:   	 TITLECASE_Letter}', "");
Expect(1, 8189, '\p{^Is_Gc:   	 TITLECASE_Letter}', "");
Expect(1, 8189, '\P{Is_Gc:   	 TITLECASE_Letter}', "");
Expect(0, 8189, '\P{^Is_Gc:   	 TITLECASE_Letter}', "");
Error('\p{Is_Category=:=_Lt}');
Error('\P{Is_Category=:=_Lt}');
Expect(1, 8188, '\p{Is_Category=lt}', "");
Expect(0, 8188, '\p{^Is_Category=lt}', "");
Expect(0, 8188, '\P{Is_Category=lt}', "");
Expect(1, 8188, '\P{^Is_Category=lt}', "");
Expect(0, 8189, '\p{Is_Category=lt}', "");
Expect(1, 8189, '\p{^Is_Category=lt}', "");
Expect(1, 8189, '\P{Is_Category=lt}', "");
Expect(0, 8189, '\P{^Is_Category=lt}', "");
Expect(1, 8188, '\p{Is_Category=LT}', "");
Expect(0, 8188, '\p{^Is_Category=LT}', "");
Expect(0, 8188, '\P{Is_Category=LT}', "");
Expect(1, 8188, '\P{^Is_Category=LT}', "");
Expect(0, 8189, '\p{Is_Category=LT}', "");
Expect(1, 8189, '\p{^Is_Category=LT}', "");
Expect(1, 8189, '\P{Is_Category=LT}', "");
Expect(0, 8189, '\P{^Is_Category=LT}', "");
Error('\p{General_Category=	 uppercase_Letter:=}');
Error('\P{General_Category=	 uppercase_Letter:=}');
Expect(1, 120778, '\p{General_Category=uppercaseletter}', "");
Expect(0, 120778, '\p{^General_Category=uppercaseletter}', "");
Expect(0, 120778, '\P{General_Category=uppercaseletter}', "");
Expect(1, 120778, '\P{^General_Category=uppercaseletter}', "");
Expect(0, 120779, '\p{General_Category=uppercaseletter}', "");
Expect(1, 120779, '\p{^General_Category=uppercaseletter}', "");
Expect(1, 120779, '\P{General_Category=uppercaseletter}', "");
Expect(0, 120779, '\P{^General_Category=uppercaseletter}', "");
Expect(1, 120778, '\p{General_Category:   	_Uppercase_letter}', "");
Expect(0, 120778, '\p{^General_Category:   	_Uppercase_letter}', "");
Expect(0, 120778, '\P{General_Category:   	_Uppercase_letter}', "");
Expect(1, 120778, '\P{^General_Category:   	_Uppercase_letter}', "");
Expect(0, 120779, '\p{General_Category:   	_Uppercase_letter}', "");
Expect(1, 120779, '\p{^General_Category:   	_Uppercase_letter}', "");
Expect(1, 120779, '\P{General_Category:   	_Uppercase_letter}', "");
Expect(0, 120779, '\P{^General_Category:   	_Uppercase_letter}', "");
Error('\p{Gc= :=Lu}');
Error('\P{Gc= :=Lu}');
Expect(1, 120778, '\p{Gc=lu}', "");
Expect(0, 120778, '\p{^Gc=lu}', "");
Expect(0, 120778, '\P{Gc=lu}', "");
Expect(1, 120778, '\P{^Gc=lu}', "");
Expect(0, 120779, '\p{Gc=lu}', "");
Expect(1, 120779, '\p{^Gc=lu}', "");
Expect(1, 120779, '\P{Gc=lu}', "");
Expect(0, 120779, '\P{^Gc=lu}', "");
Expect(1, 120778, '\p{Gc=_-lu}', "");
Expect(0, 120778, '\p{^Gc=_-lu}', "");
Expect(0, 120778, '\P{Gc=_-lu}', "");
Expect(1, 120778, '\P{^Gc=_-lu}', "");
Expect(0, 120779, '\p{Gc=_-lu}', "");
Expect(1, 120779, '\p{^Gc=_-lu}', "");
Expect(1, 120779, '\P{Gc=_-lu}', "");
Expect(0, 120779, '\P{^Gc=_-lu}', "");
Error('\p{Category:_uppercase_Letter:=}');
Error('\P{Category:_uppercase_Letter:=}');
Expect(1, 120778, '\p{Category:uppercaseletter}', "");
Expect(0, 120778, '\p{^Category:uppercaseletter}', "");
Expect(0, 120778, '\P{Category:uppercaseletter}', "");
Expect(1, 120778, '\P{^Category:uppercaseletter}', "");
Expect(0, 120779, '\p{Category:uppercaseletter}', "");
Expect(1, 120779, '\p{^Category:uppercaseletter}', "");
Expect(1, 120779, '\P{Category:uppercaseletter}', "");
Expect(0, 120779, '\P{^Category:uppercaseletter}', "");
Expect(1, 120778, '\p{Category=  Uppercase_letter}', "");
Expect(0, 120778, '\p{^Category=  Uppercase_letter}', "");
Expect(0, 120778, '\P{Category=  Uppercase_letter}', "");
Expect(1, 120778, '\P{^Category=  Uppercase_letter}', "");
Expect(0, 120779, '\p{Category=  Uppercase_letter}', "");
Expect(1, 120779, '\p{^Category=  Uppercase_letter}', "");
Expect(1, 120779, '\P{Category=  Uppercase_letter}', "");
Expect(0, 120779, '\P{^Category=  Uppercase_letter}', "");
Error('\p{Is_General_Category=	Lu/a/}');
Error('\P{Is_General_Category=	Lu/a/}');
Expect(1, 120778, '\p{Is_General_Category=lu}', "");
Expect(0, 120778, '\p{^Is_General_Category=lu}', "");
Expect(0, 120778, '\P{Is_General_Category=lu}', "");
Expect(1, 120778, '\P{^Is_General_Category=lu}', "");
Expect(0, 120779, '\p{Is_General_Category=lu}', "");
Expect(1, 120779, '\p{^Is_General_Category=lu}', "");
Expect(1, 120779, '\P{Is_General_Category=lu}', "");
Expect(0, 120779, '\P{^Is_General_Category=lu}', "");
Expect(1, 120778, '\p{Is_General_Category=		Lu}', "");
Expect(0, 120778, '\p{^Is_General_Category=		Lu}', "");
Expect(0, 120778, '\P{Is_General_Category=		Lu}', "");
Expect(1, 120778, '\P{^Is_General_Category=		Lu}', "");
Expect(0, 120779, '\p{Is_General_Category=		Lu}', "");
Expect(1, 120779, '\p{^Is_General_Category=		Lu}', "");
Expect(1, 120779, '\P{Is_General_Category=		Lu}', "");
Expect(0, 120779, '\P{^Is_General_Category=		Lu}', "");
Error('\p{Is_Gc=_/a/Uppercase_LETTER}');
Error('\P{Is_Gc=_/a/Uppercase_LETTER}');
Expect(1, 120778, '\p{Is_Gc=uppercaseletter}', "");
Expect(0, 120778, '\p{^Is_Gc=uppercaseletter}', "");
Expect(0, 120778, '\P{Is_Gc=uppercaseletter}', "");
Expect(1, 120778, '\P{^Is_Gc=uppercaseletter}', "");
Expect(0, 120779, '\p{Is_Gc=uppercaseletter}', "");
Expect(1, 120779, '\p{^Is_Gc=uppercaseletter}', "");
Expect(1, 120779, '\P{Is_Gc=uppercaseletter}', "");
Expect(0, 120779, '\P{^Is_Gc=uppercaseletter}', "");
Expect(1, 120778, '\p{Is_Gc=	uppercase_LETTER}', "");
Expect(0, 120778, '\p{^Is_Gc=	uppercase_LETTER}', "");
Expect(0, 120778, '\P{Is_Gc=	uppercase_LETTER}', "");
Expect(1, 120778, '\P{^Is_Gc=	uppercase_LETTER}', "");
Expect(0, 120779, '\p{Is_Gc=	uppercase_LETTER}', "");
Expect(1, 120779, '\p{^Is_Gc=	uppercase_LETTER}', "");
Expect(1, 120779, '\P{Is_Gc=	uppercase_LETTER}', "");
Expect(0, 120779, '\P{^Is_Gc=	uppercase_LETTER}', "");
Error('\p{Is_Category=:=LU}');
Error('\P{Is_Category=:=LU}');
Expect(1, 120778, '\p{Is_Category=lu}', "");
Expect(0, 120778, '\p{^Is_Category=lu}', "");
Expect(0, 120778, '\P{Is_Category=lu}', "");
Expect(1, 120778, '\P{^Is_Category=lu}', "");
Expect(0, 120779, '\p{Is_Category=lu}', "");
Expect(1, 120779, '\p{^Is_Category=lu}', "");
Expect(1, 120779, '\P{Is_Category=lu}', "");
Expect(0, 120779, '\P{^Is_Category=lu}', "");
Expect(1, 120778, '\p{Is_Category=		Lu}', "");
Expect(0, 120778, '\p{^Is_Category=		Lu}', "");
Expect(0, 120778, '\P{Is_Category=		Lu}', "");
Expect(1, 120778, '\P{^Is_Category=		Lu}', "");
Expect(0, 120779, '\p{Is_Category=		Lu}', "");
Expect(1, 120779, '\p{^Is_Category=		Lu}', "");
Expect(1, 120779, '\P{Is_Category=		Lu}', "");
Expect(0, 120779, '\P{^Is_Category=		Lu}', "");
Error('\p{General_Category= 	MARK/a/}');
Error('\P{General_Category= 	MARK/a/}');
Expect(1, 917999, '\p{General_Category=mark}', "");
Expect(0, 917999, '\p{^General_Category=mark}', "");
Expect(0, 917999, '\P{General_Category=mark}', "");
Expect(1, 917999, '\P{^General_Category=mark}', "");
Expect(0, 918000, '\p{General_Category=mark}', "");
Expect(1, 918000, '\p{^General_Category=mark}', "");
Expect(1, 918000, '\P{General_Category=mark}', "");
Expect(0, 918000, '\P{^General_Category=mark}', "");
Expect(1, 917999, '\p{General_Category=_Mark}', "");
Expect(0, 917999, '\p{^General_Category=_Mark}', "");
Expect(0, 917999, '\P{General_Category=_Mark}', "");
Expect(1, 917999, '\P{^General_Category=_Mark}', "");
Expect(0, 918000, '\p{General_Category=_Mark}', "");
Expect(1, 918000, '\p{^General_Category=_Mark}', "");
Expect(1, 918000, '\P{General_Category=_Mark}', "");
Expect(0, 918000, '\P{^General_Category=_Mark}', "");
Error('\p{Gc= :=M}');
Error('\P{Gc= :=M}');
Expect(1, 917999, '\p{Gc=m}', "");
Expect(0, 917999, '\p{^Gc=m}', "");
Expect(0, 917999, '\P{Gc=m}', "");
Expect(1, 917999, '\P{^Gc=m}', "");
Expect(0, 918000, '\p{Gc=m}', "");
Expect(1, 918000, '\p{^Gc=m}', "");
Expect(1, 918000, '\P{Gc=m}', "");
Expect(0, 918000, '\P{^Gc=m}', "");
Expect(1, 917999, '\p{Gc=	M}', "");
Expect(0, 917999, '\p{^Gc=	M}', "");
Expect(0, 917999, '\P{Gc=	M}', "");
Expect(1, 917999, '\P{^Gc=	M}', "");
Expect(0, 918000, '\p{Gc=	M}', "");
Expect(1, 918000, '\p{^Gc=	M}', "");
Expect(1, 918000, '\P{Gc=	M}', "");
Expect(0, 918000, '\P{^Gc=	M}', "");
Error('\p{Category=/a/_	COMBINING_MARK}');
Error('\P{Category=/a/_	COMBINING_MARK}');
Expect(1, 917999, '\p{Category=combiningmark}', "");
Expect(0, 917999, '\p{^Category=combiningmark}', "");
Expect(0, 917999, '\P{Category=combiningmark}', "");
Expect(1, 917999, '\P{^Category=combiningmark}', "");
Expect(0, 918000, '\p{Category=combiningmark}', "");
Expect(1, 918000, '\p{^Category=combiningmark}', "");
Expect(1, 918000, '\P{Category=combiningmark}', "");
Expect(0, 918000, '\P{^Category=combiningmark}', "");
Expect(1, 917999, '\p{Category=-	combining_MARK}', "");
Expect(0, 917999, '\p{^Category=-	combining_MARK}', "");
Expect(0, 917999, '\P{Category=-	combining_MARK}', "");
Expect(1, 917999, '\P{^Category=-	combining_MARK}', "");
Expect(0, 918000, '\p{Category=-	combining_MARK}', "");
Expect(1, 918000, '\p{^Category=-	combining_MARK}', "");
Expect(1, 918000, '\P{Category=-	combining_MARK}', "");
Expect(0, 918000, '\P{^Category=-	combining_MARK}', "");
Error('\p{Is_General_Category= :=Mark}');
Error('\P{Is_General_Category= :=Mark}');
Expect(1, 917999, '\p{Is_General_Category: mark}', "");
Expect(0, 917999, '\p{^Is_General_Category: mark}', "");
Expect(0, 917999, '\P{Is_General_Category: mark}', "");
Expect(1, 917999, '\P{^Is_General_Category: mark}', "");
Expect(0, 918000, '\p{Is_General_Category: mark}', "");
Expect(1, 918000, '\p{^Is_General_Category: mark}', "");
Expect(1, 918000, '\P{Is_General_Category: mark}', "");
Expect(0, 918000, '\P{^Is_General_Category: mark}', "");
Expect(1, 917999, '\p{Is_General_Category= MARK}', "");
Expect(0, 917999, '\p{^Is_General_Category= MARK}', "");
Expect(0, 917999, '\P{Is_General_Category= MARK}', "");
Expect(1, 917999, '\P{^Is_General_Category= MARK}', "");
Expect(0, 918000, '\p{Is_General_Category= MARK}', "");
Expect(1, 918000, '\p{^Is_General_Category= MARK}', "");
Expect(1, 918000, '\P{Is_General_Category= MARK}', "");
Expect(0, 918000, '\P{^Is_General_Category= MARK}', "");
Error('\p{Is_Gc: :=	-m}');
Error('\P{Is_Gc: :=	-m}');
Expect(1, 917999, '\p{Is_Gc=m}', "");
Expect(0, 917999, '\p{^Is_Gc=m}', "");
Expect(0, 917999, '\P{Is_Gc=m}', "");
Expect(1, 917999, '\P{^Is_Gc=m}', "");
Expect(0, 918000, '\p{Is_Gc=m}', "");
Expect(1, 918000, '\p{^Is_Gc=m}', "");
Expect(1, 918000, '\P{Is_Gc=m}', "");
Expect(0, 918000, '\P{^Is_Gc=m}', "");
Expect(1, 917999, '\p{Is_Gc=- M}', "");
Expect(0, 917999, '\p{^Is_Gc=- M}', "");
Expect(0, 917999, '\P{Is_Gc=- M}', "");
Expect(1, 917999, '\P{^Is_Gc=- M}', "");
Expect(0, 918000, '\p{Is_Gc=- M}', "");
Expect(1, 918000, '\p{^Is_Gc=- M}', "");
Expect(1, 918000, '\P{Is_Gc=- M}', "");
Expect(0, 918000, '\P{^Is_Gc=- M}', "");
Error('\p{Is_Category=_/a/COMBINING_MARK}');
Error('\P{Is_Category=_/a/COMBINING_MARK}');
Expect(1, 917999, '\p{Is_Category=combiningmark}', "");
Expect(0, 917999, '\p{^Is_Category=combiningmark}', "");
Expect(0, 917999, '\P{Is_Category=combiningmark}', "");
Expect(1, 917999, '\P{^Is_Category=combiningmark}', "");
Expect(0, 918000, '\p{Is_Category=combiningmark}', "");
Expect(1, 918000, '\p{^Is_Category=combiningmark}', "");
Expect(1, 918000, '\P{Is_Category=combiningmark}', "");
Expect(0, 918000, '\P{^Is_Category=combiningmark}', "");
Expect(1, 917999, '\p{Is_Category=_ combining_Mark}', "");
Expect(0, 917999, '\p{^Is_Category=_ combining_Mark}', "");
Expect(0, 917999, '\P{Is_Category=_ combining_Mark}', "");
Expect(1, 917999, '\P{^Is_Category=_ combining_Mark}', "");
Expect(0, 918000, '\p{Is_Category=_ combining_Mark}', "");
Expect(1, 918000, '\p{^Is_Category=_ combining_Mark}', "");
Expect(1, 918000, '\P{Is_Category=_ combining_Mark}', "");
Expect(0, 918000, '\P{^Is_Category=_ combining_Mark}', "");
Error('\p{General_Category:-/a/Spacing_Mark}');
Error('\P{General_Category:-/a/Spacing_Mark}');
Expect(1, 119154, '\p{General_Category=spacingmark}', "");
Expect(0, 119154, '\p{^General_Category=spacingmark}', "");
Expect(0, 119154, '\P{General_Category=spacingmark}', "");
Expect(1, 119154, '\P{^General_Category=spacingmark}', "");
Expect(0, 119155, '\p{General_Category=spacingmark}', "");
Expect(1, 119155, '\p{^General_Category=spacingmark}', "");
Expect(1, 119155, '\P{General_Category=spacingmark}', "");
Expect(0, 119155, '\P{^General_Category=spacingmark}', "");
Expect(1, 119154, '\p{General_Category: -Spacing_Mark}', "");
Expect(0, 119154, '\p{^General_Category: -Spacing_Mark}', "");
Expect(0, 119154, '\P{General_Category: -Spacing_Mark}', "");
Expect(1, 119154, '\P{^General_Category: -Spacing_Mark}', "");
Expect(0, 119155, '\p{General_Category: -Spacing_Mark}', "");
Expect(1, 119155, '\p{^General_Category: -Spacing_Mark}', "");
Expect(1, 119155, '\P{General_Category: -Spacing_Mark}', "");
Expect(0, 119155, '\P{^General_Category: -Spacing_Mark}', "");
Error('\p{Gc=:=-	Mc}');
Error('\P{Gc=:=-	Mc}');
Expect(1, 119154, '\p{Gc=mc}', "");
Expect(0, 119154, '\p{^Gc=mc}', "");
Expect(0, 119154, '\P{Gc=mc}', "");
Expect(1, 119154, '\P{^Gc=mc}', "");
Expect(0, 119155, '\p{Gc=mc}', "");
Expect(1, 119155, '\p{^Gc=mc}', "");
Expect(1, 119155, '\P{Gc=mc}', "");
Expect(0, 119155, '\P{^Gc=mc}', "");
Expect(1, 119154, '\p{Gc=	-Mc}', "");
Expect(0, 119154, '\p{^Gc=	-Mc}', "");
Expect(0, 119154, '\P{Gc=	-Mc}', "");
Expect(1, 119154, '\P{^Gc=	-Mc}', "");
Expect(0, 119155, '\p{Gc=	-Mc}', "");
Expect(1, 119155, '\p{^Gc=	-Mc}', "");
Expect(1, 119155, '\P{Gc=	-Mc}', "");
Expect(0, 119155, '\P{^Gc=	-Mc}', "");
Error('\p{Category=/a/ 	spacing_MARK}');
Error('\P{Category=/a/ 	spacing_MARK}');
Expect(1, 119154, '\p{Category=spacingmark}', "");
Expect(0, 119154, '\p{^Category=spacingmark}', "");
Expect(0, 119154, '\P{Category=spacingmark}', "");
Expect(1, 119154, '\P{^Category=spacingmark}', "");
Expect(0, 119155, '\p{Category=spacingmark}', "");
Expect(1, 119155, '\p{^Category=spacingmark}', "");
Expect(1, 119155, '\P{Category=spacingmark}', "");
Expect(0, 119155, '\P{^Category=spacingmark}', "");
Expect(1, 119154, '\p{Category=_spacing_MARK}', "");
Expect(0, 119154, '\p{^Category=_spacing_MARK}', "");
Expect(0, 119154, '\P{Category=_spacing_MARK}', "");
Expect(1, 119154, '\P{^Category=_spacing_MARK}', "");
Expect(0, 119155, '\p{Category=_spacing_MARK}', "");
Expect(1, 119155, '\p{^Category=_spacing_MARK}', "");
Expect(1, 119155, '\P{Category=_spacing_MARK}', "");
Expect(0, 119155, '\P{^Category=_spacing_MARK}', "");
Error('\p{Is_General_Category=:=- MC}');
Error('\P{Is_General_Category=:=- MC}');
Expect(1, 119154, '\p{Is_General_Category=mc}', "");
Expect(0, 119154, '\p{^Is_General_Category=mc}', "");
Expect(0, 119154, '\P{Is_General_Category=mc}', "");
Expect(1, 119154, '\P{^Is_General_Category=mc}', "");
Expect(0, 119155, '\p{Is_General_Category=mc}', "");
Expect(1, 119155, '\p{^Is_General_Category=mc}', "");
Expect(1, 119155, '\P{Is_General_Category=mc}', "");
Expect(0, 119155, '\P{^Is_General_Category=mc}', "");
Expect(1, 119154, '\p{Is_General_Category=_ mc}', "");
Expect(0, 119154, '\p{^Is_General_Category=_ mc}', "");
Expect(0, 119154, '\P{Is_General_Category=_ mc}', "");
Expect(1, 119154, '\P{^Is_General_Category=_ mc}', "");
Expect(0, 119155, '\p{Is_General_Category=_ mc}', "");
Expect(1, 119155, '\p{^Is_General_Category=_ mc}', "");
Expect(1, 119155, '\P{Is_General_Category=_ mc}', "");
Expect(0, 119155, '\P{^Is_General_Category=_ mc}', "");
Error('\p{Is_Gc=/a/ spacing_Mark}');
Error('\P{Is_Gc=/a/ spacing_Mark}');
Expect(1, 119154, '\p{Is_Gc:   spacingmark}', "");
Expect(0, 119154, '\p{^Is_Gc:   spacingmark}', "");
Expect(0, 119154, '\P{Is_Gc:   spacingmark}', "");
Expect(1, 119154, '\P{^Is_Gc:   spacingmark}', "");
Expect(0, 119155, '\p{Is_Gc:   spacingmark}', "");
Expect(1, 119155, '\p{^Is_Gc:   spacingmark}', "");
Expect(1, 119155, '\P{Is_Gc:   spacingmark}', "");
Expect(0, 119155, '\P{^Is_Gc:   spacingmark}', "");
Expect(1, 119154, '\p{Is_Gc=- SPACING_mark}', "");
Expect(0, 119154, '\p{^Is_Gc=- SPACING_mark}', "");
Expect(0, 119154, '\P{Is_Gc=- SPACING_mark}', "");
Expect(1, 119154, '\P{^Is_Gc=- SPACING_mark}', "");
Expect(0, 119155, '\p{Is_Gc=- SPACING_mark}', "");
Expect(1, 119155, '\p{^Is_Gc=- SPACING_mark}', "");
Expect(1, 119155, '\P{Is_Gc=- SPACING_mark}', "");
Expect(0, 119155, '\P{^Is_Gc=- SPACING_mark}', "");
Error('\p{Is_Category=_/a/mc}');
Error('\P{Is_Category=_/a/mc}');
Expect(1, 119154, '\p{Is_Category=mc}', "");
Expect(0, 119154, '\p{^Is_Category=mc}', "");
Expect(0, 119154, '\P{Is_Category=mc}', "");
Expect(1, 119154, '\P{^Is_Category=mc}', "");
Expect(0, 119155, '\p{Is_Category=mc}', "");
Expect(1, 119155, '\p{^Is_Category=mc}', "");
Expect(1, 119155, '\P{Is_Category=mc}', "");
Expect(0, 119155, '\P{^Is_Category=mc}', "");
Expect(1, 119154, '\p{Is_Category=__MC}', "");
Expect(0, 119154, '\p{^Is_Category=__MC}', "");
Expect(0, 119154, '\P{Is_Category=__MC}', "");
Expect(1, 119154, '\P{^Is_Category=__MC}', "");
Expect(0, 119155, '\p{Is_Category=__MC}', "");
Expect(1, 119155, '\p{^Is_Category=__MC}', "");
Expect(1, 119155, '\P{Is_Category=__MC}', "");
Expect(0, 119155, '\P{^Is_Category=__MC}', "");
Error('\p{General_Category=__Enclosing_Mark/a/}');
Error('\P{General_Category=__Enclosing_Mark/a/}');
Expect(1, 42610, '\p{General_Category: enclosingmark}', "");
Expect(0, 42610, '\p{^General_Category: enclosingmark}', "");
Expect(0, 42610, '\P{General_Category: enclosingmark}', "");
Expect(1, 42610, '\P{^General_Category: enclosingmark}', "");
Expect(0, 42611, '\p{General_Category: enclosingmark}', "");
Expect(1, 42611, '\p{^General_Category: enclosingmark}', "");
Expect(1, 42611, '\P{General_Category: enclosingmark}', "");
Expect(0, 42611, '\P{^General_Category: enclosingmark}', "");
Expect(1, 42610, '\p{General_Category=--ENCLOSING_Mark}', "");
Expect(0, 42610, '\p{^General_Category=--ENCLOSING_Mark}', "");
Expect(0, 42610, '\P{General_Category=--ENCLOSING_Mark}', "");
Expect(1, 42610, '\P{^General_Category=--ENCLOSING_Mark}', "");
Expect(0, 42611, '\p{General_Category=--ENCLOSING_Mark}', "");
Expect(1, 42611, '\p{^General_Category=--ENCLOSING_Mark}', "");
Expect(1, 42611, '\P{General_Category=--ENCLOSING_Mark}', "");
Expect(0, 42611, '\P{^General_Category=--ENCLOSING_Mark}', "");
Error('\p{Gc:/a/	_Me}');
Error('\P{Gc:/a/	_Me}');
Expect(1, 42610, '\p{Gc=me}', "");
Expect(0, 42610, '\p{^Gc=me}', "");
Expect(0, 42610, '\P{Gc=me}', "");
Expect(1, 42610, '\P{^Gc=me}', "");
Expect(0, 42611, '\p{Gc=me}', "");
Expect(1, 42611, '\p{^Gc=me}', "");
Expect(1, 42611, '\P{Gc=me}', "");
Expect(0, 42611, '\P{^Gc=me}', "");
Expect(1, 42610, '\p{Gc=Me}', "");
Expect(0, 42610, '\p{^Gc=Me}', "");
Expect(0, 42610, '\P{Gc=Me}', "");
Expect(1, 42610, '\P{^Gc=Me}', "");
Expect(0, 42611, '\p{Gc=Me}', "");
Expect(1, 42611, '\p{^Gc=Me}', "");
Expect(1, 42611, '\P{Gc=Me}', "");
Expect(0, 42611, '\P{^Gc=Me}', "");
Error('\p{Category=- ENCLOSING_Mark/a/}');
Error('\P{Category=- ENCLOSING_Mark/a/}');
Expect(1, 42610, '\p{Category=enclosingmark}', "");
Expect(0, 42610, '\p{^Category=enclosingmark}', "");
Expect(0, 42610, '\P{Category=enclosingmark}', "");
Expect(1, 42610, '\P{^Category=enclosingmark}', "");
Expect(0, 42611, '\p{Category=enclosingmark}', "");
Expect(1, 42611, '\p{^Category=enclosingmark}', "");
Expect(1, 42611, '\P{Category=enclosingmark}', "");
Expect(0, 42611, '\P{^Category=enclosingmark}', "");
Expect(1, 42610, '\p{Category=_ENCLOSING_Mark}', "");
Expect(0, 42610, '\p{^Category=_ENCLOSING_Mark}', "");
Expect(0, 42610, '\P{Category=_ENCLOSING_Mark}', "");
Expect(1, 42610, '\P{^Category=_ENCLOSING_Mark}', "");
Expect(0, 42611, '\p{Category=_ENCLOSING_Mark}', "");
Expect(1, 42611, '\p{^Category=_ENCLOSING_Mark}', "");
Expect(1, 42611, '\P{Category=_ENCLOSING_Mark}', "");
Expect(0, 42611, '\P{^Category=_ENCLOSING_Mark}', "");
Error('\p{Is_General_Category=_Me:=}');
Error('\P{Is_General_Category=_Me:=}');
Expect(1, 42610, '\p{Is_General_Category=me}', "");
Expect(0, 42610, '\p{^Is_General_Category=me}', "");
Expect(0, 42610, '\P{Is_General_Category=me}', "");
Expect(1, 42610, '\P{^Is_General_Category=me}', "");
Expect(0, 42611, '\p{Is_General_Category=me}', "");
Expect(1, 42611, '\p{^Is_General_Category=me}', "");
Expect(1, 42611, '\P{Is_General_Category=me}', "");
Expect(0, 42611, '\P{^Is_General_Category=me}', "");
Expect(1, 42610, '\p{Is_General_Category= -Me}', "");
Expect(0, 42610, '\p{^Is_General_Category= -Me}', "");
Expect(0, 42610, '\P{Is_General_Category= -Me}', "");
Expect(1, 42610, '\P{^Is_General_Category= -Me}', "");
Expect(0, 42611, '\p{Is_General_Category= -Me}', "");
Expect(1, 42611, '\p{^Is_General_Category= -Me}', "");
Expect(1, 42611, '\P{Is_General_Category= -Me}', "");
Expect(0, 42611, '\P{^Is_General_Category= -Me}', "");
Error('\p{Is_Gc=_Enclosing_Mark:=}');
Error('\P{Is_Gc=_Enclosing_Mark:=}');
Expect(1, 42610, '\p{Is_Gc=enclosingmark}', "");
Expect(0, 42610, '\p{^Is_Gc=enclosingmark}', "");
Expect(0, 42610, '\P{Is_Gc=enclosingmark}', "");
Expect(1, 42610, '\P{^Is_Gc=enclosingmark}', "");
Expect(0, 42611, '\p{Is_Gc=enclosingmark}', "");
Expect(1, 42611, '\p{^Is_Gc=enclosingmark}', "");
Expect(1, 42611, '\P{Is_Gc=enclosingmark}', "");
Expect(0, 42611, '\P{^Is_Gc=enclosingmark}', "");
Expect(1, 42610, '\p{Is_Gc:	 Enclosing_mark}', "");
Expect(0, 42610, '\p{^Is_Gc:	 Enclosing_mark}', "");
Expect(0, 42610, '\P{Is_Gc:	 Enclosing_mark}', "");
Expect(1, 42610, '\P{^Is_Gc:	 Enclosing_mark}', "");
Expect(0, 42611, '\p{Is_Gc:	 Enclosing_mark}', "");
Expect(1, 42611, '\p{^Is_Gc:	 Enclosing_mark}', "");
Expect(1, 42611, '\P{Is_Gc:	 Enclosing_mark}', "");
Expect(0, 42611, '\P{^Is_Gc:	 Enclosing_mark}', "");
Error('\p{Is_Category=:=	Me}');
Error('\P{Is_Category=:=	Me}');
Expect(1, 42610, '\p{Is_Category=me}', "");
Expect(0, 42610, '\p{^Is_Category=me}', "");
Expect(0, 42610, '\P{Is_Category=me}', "");
Expect(1, 42610, '\P{^Is_Category=me}', "");
Expect(0, 42611, '\p{Is_Category=me}', "");
Expect(1, 42611, '\p{^Is_Category=me}', "");
Expect(1, 42611, '\P{Is_Category=me}', "");
Expect(0, 42611, '\P{^Is_Category=me}', "");
Expect(1, 42610, '\p{Is_Category=_-ME}', "");
Expect(0, 42610, '\p{^Is_Category=_-ME}', "");
Expect(0, 42610, '\P{Is_Category=_-ME}', "");
Expect(1, 42610, '\P{^Is_Category=_-ME}', "");
Expect(0, 42611, '\p{Is_Category=_-ME}', "");
Expect(1, 42611, '\p{^Is_Category=_-ME}', "");
Expect(1, 42611, '\P{Is_Category=_-ME}', "");
Expect(0, 42611, '\P{^Is_Category=_-ME}', "");
Error('\p{General_Category= /a/Nonspacing_MARK}');
Error('\P{General_Category= /a/Nonspacing_MARK}');
Expect(1, 917999, '\p{General_Category=nonspacingmark}', "");
Expect(0, 917999, '\p{^General_Category=nonspacingmark}', "");
Expect(0, 917999, '\P{General_Category=nonspacingmark}', "");
Expect(1, 917999, '\P{^General_Category=nonspacingmark}', "");
Expect(0, 918000, '\p{General_Category=nonspacingmark}', "");
Expect(1, 918000, '\p{^General_Category=nonspacingmark}', "");
Expect(1, 918000, '\P{General_Category=nonspacingmark}', "");
Expect(0, 918000, '\P{^General_Category=nonspacingmark}', "");
Expect(1, 917999, '\p{General_Category= 	nonspacing_Mark}', "");
Expect(0, 917999, '\p{^General_Category= 	nonspacing_Mark}', "");
Expect(0, 917999, '\P{General_Category= 	nonspacing_Mark}', "");
Expect(1, 917999, '\P{^General_Category= 	nonspacing_Mark}', "");
Expect(0, 918000, '\p{General_Category= 	nonspacing_Mark}', "");
Expect(1, 918000, '\p{^General_Category= 	nonspacing_Mark}', "");
Expect(1, 918000, '\P{General_Category= 	nonspacing_Mark}', "");
Expect(0, 918000, '\P{^General_Category= 	nonspacing_Mark}', "");
Error('\p{Gc=	/a/mn}');
Error('\P{Gc=	/a/mn}');
Expect(1, 917999, '\p{Gc=mn}', "");
Expect(0, 917999, '\p{^Gc=mn}', "");
Expect(0, 917999, '\P{Gc=mn}', "");
Expect(1, 917999, '\P{^Gc=mn}', "");
Expect(0, 918000, '\p{Gc=mn}', "");
Expect(1, 918000, '\p{^Gc=mn}', "");
Expect(1, 918000, '\P{Gc=mn}', "");
Expect(0, 918000, '\P{^Gc=mn}', "");
Expect(1, 917999, '\p{Gc= Mn}', "");
Expect(0, 917999, '\p{^Gc= Mn}', "");
Expect(0, 917999, '\P{Gc= Mn}', "");
Expect(1, 917999, '\P{^Gc= Mn}', "");
Expect(0, 918000, '\p{Gc= Mn}', "");
Expect(1, 918000, '\p{^Gc= Mn}', "");
Expect(1, 918000, '\P{Gc= Mn}', "");
Expect(0, 918000, '\P{^Gc= Mn}', "");
Error('\p{Category=/a/_nonspacing_mark}');
Error('\P{Category=/a/_nonspacing_mark}');
Expect(1, 917999, '\p{Category=nonspacingmark}', "");
Expect(0, 917999, '\p{^Category=nonspacingmark}', "");
Expect(0, 917999, '\P{Category=nonspacingmark}', "");
Expect(1, 917999, '\P{^Category=nonspacingmark}', "");
Expect(0, 918000, '\p{Category=nonspacingmark}', "");
Expect(1, 918000, '\p{^Category=nonspacingmark}', "");
Expect(1, 918000, '\P{Category=nonspacingmark}', "");
Expect(0, 918000, '\P{^Category=nonspacingmark}', "");
Expect(1, 917999, '\p{Category: _Nonspacing_mark}', "");
Expect(0, 917999, '\p{^Category: _Nonspacing_mark}', "");
Expect(0, 917999, '\P{Category: _Nonspacing_mark}', "");
Expect(1, 917999, '\P{^Category: _Nonspacing_mark}', "");
Expect(0, 918000, '\p{Category: _Nonspacing_mark}', "");
Expect(1, 918000, '\p{^Category: _Nonspacing_mark}', "");
Expect(1, 918000, '\P{Category: _Nonspacing_mark}', "");
Expect(0, 918000, '\P{^Category: _Nonspacing_mark}', "");
Error('\p{Is_General_Category=:=	Mn}');
Error('\P{Is_General_Category=:=	Mn}');
Expect(1, 917999, '\p{Is_General_Category=mn}', "");
Expect(0, 917999, '\p{^Is_General_Category=mn}', "");
Expect(0, 917999, '\P{Is_General_Category=mn}', "");
Expect(1, 917999, '\P{^Is_General_Category=mn}', "");
Expect(0, 918000, '\p{Is_General_Category=mn}', "");
Expect(1, 918000, '\p{^Is_General_Category=mn}', "");
Expect(1, 918000, '\P{Is_General_Category=mn}', "");
Expect(0, 918000, '\P{^Is_General_Category=mn}', "");
Expect(1, 917999, '\p{Is_General_Category=--mn}', "");
Expect(0, 917999, '\p{^Is_General_Category=--mn}', "");
Expect(0, 917999, '\P{Is_General_Category=--mn}', "");
Expect(1, 917999, '\P{^Is_General_Category=--mn}', "");
Expect(0, 918000, '\p{Is_General_Category=--mn}', "");
Expect(1, 918000, '\p{^Is_General_Category=--mn}', "");
Expect(1, 918000, '\P{Is_General_Category=--mn}', "");
Expect(0, 918000, '\P{^Is_General_Category=--mn}', "");
Error('\p{Is_Gc:   	 NONSPACING_mark:=}');
Error('\P{Is_Gc:   	 NONSPACING_mark:=}');
Expect(1, 917999, '\p{Is_Gc=nonspacingmark}', "");
Expect(0, 917999, '\p{^Is_Gc=nonspacingmark}', "");
Expect(0, 917999, '\P{Is_Gc=nonspacingmark}', "");
Expect(1, 917999, '\P{^Is_Gc=nonspacingmark}', "");
Expect(0, 918000, '\p{Is_Gc=nonspacingmark}', "");
Expect(1, 918000, '\p{^Is_Gc=nonspacingmark}', "");
Expect(1, 918000, '\P{Is_Gc=nonspacingmark}', "");
Expect(0, 918000, '\P{^Is_Gc=nonspacingmark}', "");
Expect(1, 917999, '\p{Is_Gc=- Nonspacing_mark}', "");
Expect(0, 917999, '\p{^Is_Gc=- Nonspacing_mark}', "");
Expect(0, 917999, '\P{Is_Gc=- Nonspacing_mark}', "");
Expect(1, 917999, '\P{^Is_Gc=- Nonspacing_mark}', "");
Expect(0, 918000, '\p{Is_Gc=- Nonspacing_mark}', "");
Expect(1, 918000, '\p{^Is_Gc=- Nonspacing_mark}', "");
Expect(1, 918000, '\P{Is_Gc=- Nonspacing_mark}', "");
Expect(0, 918000, '\P{^Is_Gc=- Nonspacing_mark}', "");
Error('\p{Is_Category=_:=MN}');
Error('\P{Is_Category=_:=MN}');
Expect(1, 917999, '\p{Is_Category:mn}', "");
Expect(0, 917999, '\p{^Is_Category:mn}', "");
Expect(0, 917999, '\P{Is_Category:mn}', "");
Expect(1, 917999, '\P{^Is_Category:mn}', "");
Expect(0, 918000, '\p{Is_Category:mn}', "");
Expect(1, 918000, '\p{^Is_Category:mn}', "");
Expect(1, 918000, '\P{Is_Category:mn}', "");
Expect(0, 918000, '\P{^Is_Category:mn}', "");
Expect(1, 917999, '\p{Is_Category=	_mn}', "");
Expect(0, 917999, '\p{^Is_Category=	_mn}', "");
Expect(0, 917999, '\P{Is_Category=	_mn}', "");
Expect(1, 917999, '\P{^Is_Category=	_mn}', "");
Expect(0, 918000, '\p{Is_Category=	_mn}', "");
Expect(1, 918000, '\p{^Is_Category=	_mn}', "");
Expect(1, 918000, '\P{Is_Category=	_mn}', "");
Expect(0, 918000, '\P{^Is_Category=	_mn}', "");
Error('\p{General_Category=_-Number/a/}');
Error('\P{General_Category=_-Number/a/}');
Expect(1, 127242, '\p{General_Category=number}', "");
Expect(0, 127242, '\p{^General_Category=number}', "");
Expect(0, 127242, '\P{General_Category=number}', "");
Expect(1, 127242, '\P{^General_Category=number}', "");
Expect(0, 127243, '\p{General_Category=number}', "");
Expect(1, 127243, '\p{^General_Category=number}', "");
Expect(1, 127243, '\P{General_Category=number}', "");
Expect(0, 127243, '\P{^General_Category=number}', "");
Expect(1, 127242, '\p{General_Category=-NUMBER}', "");
Expect(0, 127242, '\p{^General_Category=-NUMBER}', "");
Expect(0, 127242, '\P{General_Category=-NUMBER}', "");
Expect(1, 127242, '\P{^General_Category=-NUMBER}', "");
Expect(0, 127243, '\p{General_Category=-NUMBER}', "");
Expect(1, 127243, '\p{^General_Category=-NUMBER}', "");
Expect(1, 127243, '\P{General_Category=-NUMBER}', "");
Expect(0, 127243, '\P{^General_Category=-NUMBER}', "");
Error('\p{Gc=/a/ -n}');
Error('\P{Gc=/a/ -n}');
Expect(1, 127242, '\p{Gc=n}', "");
Expect(0, 127242, '\p{^Gc=n}', "");
Expect(0, 127242, '\P{Gc=n}', "");
Expect(1, 127242, '\P{^Gc=n}', "");
Expect(0, 127243, '\p{Gc=n}', "");
Expect(1, 127243, '\p{^Gc=n}', "");
Expect(1, 127243, '\P{Gc=n}', "");
Expect(0, 127243, '\P{^Gc=n}', "");
Expect(1, 127242, '\p{Gc=__n}', "");
Expect(0, 127242, '\p{^Gc=__n}', "");
Expect(0, 127242, '\P{Gc=__n}', "");
Expect(1, 127242, '\P{^Gc=__n}', "");
Expect(0, 127243, '\p{Gc=__n}', "");
Expect(1, 127243, '\p{^Gc=__n}', "");
Expect(1, 127243, '\P{Gc=__n}', "");
Expect(0, 127243, '\P{^Gc=__n}', "");
Error('\p{Category=/a/ _number}');
Error('\P{Category=/a/ _number}');
Expect(1, 127242, '\p{Category=number}', "");
Expect(0, 127242, '\p{^Category=number}', "");
Expect(0, 127242, '\P{Category=number}', "");
Expect(1, 127242, '\P{^Category=number}', "");
Expect(0, 127243, '\p{Category=number}', "");
Expect(1, 127243, '\p{^Category=number}', "");
Expect(1, 127243, '\P{Category=number}', "");
Expect(0, 127243, '\P{^Category=number}', "");
Expect(1, 127242, '\p{Category=	 Number}', "");
Expect(0, 127242, '\p{^Category=	 Number}', "");
Expect(0, 127242, '\P{Category=	 Number}', "");
Expect(1, 127242, '\P{^Category=	 Number}', "");
Expect(0, 127243, '\p{Category=	 Number}', "");
Expect(1, 127243, '\p{^Category=	 Number}', "");
Expect(1, 127243, '\P{Category=	 Number}', "");
Expect(0, 127243, '\P{^Category=	 Number}', "");
Error('\p{Is_General_Category=_/a/n}');
Error('\P{Is_General_Category=_/a/n}');
Expect(1, 127242, '\p{Is_General_Category=n}', "");
Expect(0, 127242, '\p{^Is_General_Category=n}', "");
Expect(0, 127242, '\P{Is_General_Category=n}', "");
Expect(1, 127242, '\P{^Is_General_Category=n}', "");
Expect(0, 127243, '\p{Is_General_Category=n}', "");
Expect(1, 127243, '\p{^Is_General_Category=n}', "");
Expect(1, 127243, '\P{Is_General_Category=n}', "");
Expect(0, 127243, '\P{^Is_General_Category=n}', "");
Expect(1, 127242, '\p{Is_General_Category=	N}', "");
Expect(0, 127242, '\p{^Is_General_Category=	N}', "");
Expect(0, 127242, '\P{Is_General_Category=	N}', "");
Expect(1, 127242, '\P{^Is_General_Category=	N}', "");
Expect(0, 127243, '\p{Is_General_Category=	N}', "");
Expect(1, 127243, '\p{^Is_General_Category=	N}', "");
Expect(1, 127243, '\P{Is_General_Category=	N}', "");
Expect(0, 127243, '\P{^Is_General_Category=	N}', "");
Error('\p{Is_Gc=/a/	 Number}');
Error('\P{Is_Gc=/a/	 Number}');
Expect(1, 127242, '\p{Is_Gc=number}', "");
Expect(0, 127242, '\p{^Is_Gc=number}', "");
Expect(0, 127242, '\P{Is_Gc=number}', "");
Expect(1, 127242, '\P{^Is_Gc=number}', "");
Expect(0, 127243, '\p{Is_Gc=number}', "");
Expect(1, 127243, '\p{^Is_Gc=number}', "");
Expect(1, 127243, '\P{Is_Gc=number}', "");
Expect(0, 127243, '\P{^Is_Gc=number}', "");
Expect(1, 127242, '\p{Is_Gc:-_NUMBER}', "");
Expect(0, 127242, '\p{^Is_Gc:-_NUMBER}', "");
Expect(0, 127242, '\P{Is_Gc:-_NUMBER}', "");
Expect(1, 127242, '\P{^Is_Gc:-_NUMBER}', "");
Expect(0, 127243, '\p{Is_Gc:-_NUMBER}', "");
Expect(1, 127243, '\p{^Is_Gc:-_NUMBER}', "");
Expect(1, 127243, '\P{Is_Gc:-_NUMBER}', "");
Expect(0, 127243, '\P{^Is_Gc:-_NUMBER}', "");
Error('\p{Is_Category=:=_	n}');
Error('\P{Is_Category=:=_	n}');
Expect(1, 127242, '\p{Is_Category=n}', "");
Expect(0, 127242, '\p{^Is_Category=n}', "");
Expect(0, 127242, '\P{Is_Category=n}', "");
Expect(1, 127242, '\P{^Is_Category=n}', "");
Expect(0, 127243, '\p{Is_Category=n}', "");
Expect(1, 127243, '\p{^Is_Category=n}', "");
Expect(1, 127243, '\P{Is_Category=n}', "");
Expect(0, 127243, '\P{^Is_Category=n}', "");
Expect(1, 127242, '\p{Is_Category=- N}', "");
Expect(0, 127242, '\p{^Is_Category=- N}', "");
Expect(0, 127242, '\P{Is_Category=- N}', "");
Expect(1, 127242, '\P{^Is_Category=- N}', "");
Expect(0, 127243, '\p{Is_Category=- N}', "");
Expect(1, 127243, '\p{^Is_Category=- N}', "");
Expect(1, 127243, '\P{Is_Category=- N}', "");
Expect(0, 127243, '\P{^Is_Category=- N}', "");
Error('\p{General_Category= 	Decimal_NUMBER/a/}');
Error('\P{General_Category= 	Decimal_NUMBER/a/}');
Expect(1, 120831, '\p{General_Category=decimalnumber}', "");
Expect(0, 120831, '\p{^General_Category=decimalnumber}', "");
Expect(0, 120831, '\P{General_Category=decimalnumber}', "");
Expect(1, 120831, '\P{^General_Category=decimalnumber}', "");
Expect(0, 120832, '\p{General_Category=decimalnumber}', "");
Expect(1, 120832, '\p{^General_Category=decimalnumber}', "");
Expect(1, 120832, '\P{General_Category=decimalnumber}', "");
Expect(0, 120832, '\P{^General_Category=decimalnumber}', "");
Expect(1, 120831, '\p{General_Category=_	Decimal_number}', "");
Expect(0, 120831, '\p{^General_Category=_	Decimal_number}', "");
Expect(0, 120831, '\P{General_Category=_	Decimal_number}', "");
Expect(1, 120831, '\P{^General_Category=_	Decimal_number}', "");
Expect(0, 120832, '\p{General_Category=_	Decimal_number}', "");
Expect(1, 120832, '\p{^General_Category=_	Decimal_number}', "");
Expect(1, 120832, '\P{General_Category=_	Decimal_number}', "");
Expect(0, 120832, '\P{^General_Category=_	Decimal_number}', "");
Error('\p{Gc=	:=Nd}');
Error('\P{Gc=	:=Nd}');
Expect(1, 120831, '\p{Gc:nd}', "");
Expect(0, 120831, '\p{^Gc:nd}', "");
Expect(0, 120831, '\P{Gc:nd}', "");
Expect(1, 120831, '\P{^Gc:nd}', "");
Expect(0, 120832, '\p{Gc:nd}', "");
Expect(1, 120832, '\p{^Gc:nd}', "");
Expect(1, 120832, '\P{Gc:nd}', "");
Expect(0, 120832, '\P{^Gc:nd}', "");
Expect(1, 120831, '\p{Gc=_-Nd}', "");
Expect(0, 120831, '\p{^Gc=_-Nd}', "");
Expect(0, 120831, '\P{Gc=_-Nd}', "");
Expect(1, 120831, '\P{^Gc=_-Nd}', "");
Expect(0, 120832, '\p{Gc=_-Nd}', "");
Expect(1, 120832, '\p{^Gc=_-Nd}', "");
Expect(1, 120832, '\P{Gc=_-Nd}', "");
Expect(0, 120832, '\P{^Gc=_-Nd}', "");
Error('\p{Category: :=	digit}');
Error('\P{Category: :=	digit}');
Expect(1, 120831, '\p{Category=digit}', "");
Expect(0, 120831, '\p{^Category=digit}', "");
Expect(0, 120831, '\P{Category=digit}', "");
Expect(1, 120831, '\P{^Category=digit}', "");
Expect(0, 120832, '\p{Category=digit}', "");
Expect(1, 120832, '\p{^Category=digit}', "");
Expect(1, 120832, '\P{Category=digit}', "");
Expect(0, 120832, '\P{^Category=digit}', "");
Expect(1, 120831, '\p{Category=		Digit}', "");
Expect(0, 120831, '\p{^Category=		Digit}', "");
Expect(0, 120831, '\P{Category=		Digit}', "");
Expect(1, 120831, '\P{^Category=		Digit}', "");
Expect(0, 120832, '\p{Category=		Digit}', "");
Expect(1, 120832, '\p{^Category=		Digit}', "");
Expect(1, 120832, '\P{Category=		Digit}', "");
Expect(0, 120832, '\P{^Category=		Digit}', "");
Error('\p{Is_General_Category: /a/	Decimal_NUMBER}');
Error('\P{Is_General_Category: /a/	Decimal_NUMBER}');
Expect(1, 120831, '\p{Is_General_Category=decimalnumber}', "");
Expect(0, 120831, '\p{^Is_General_Category=decimalnumber}', "");
Expect(0, 120831, '\P{Is_General_Category=decimalnumber}', "");
Expect(1, 120831, '\P{^Is_General_Category=decimalnumber}', "");
Expect(0, 120832, '\p{Is_General_Category=decimalnumber}', "");
Expect(1, 120832, '\p{^Is_General_Category=decimalnumber}', "");
Expect(1, 120832, '\P{Is_General_Category=decimalnumber}', "");
Expect(0, 120832, '\P{^Is_General_Category=decimalnumber}', "");
Expect(1, 120831, '\p{Is_General_Category=__Decimal_Number}', "");
Expect(0, 120831, '\p{^Is_General_Category=__Decimal_Number}', "");
Expect(0, 120831, '\P{Is_General_Category=__Decimal_Number}', "");
Expect(1, 120831, '\P{^Is_General_Category=__Decimal_Number}', "");
Expect(0, 120832, '\p{Is_General_Category=__Decimal_Number}', "");
Expect(1, 120832, '\p{^Is_General_Category=__Decimal_Number}', "");
Expect(1, 120832, '\P{Is_General_Category=__Decimal_Number}', "");
Expect(0, 120832, '\P{^Is_General_Category=__Decimal_Number}', "");
Error('\p{Is_Gc=-:=Nd}');
Error('\P{Is_Gc=-:=Nd}');
Expect(1, 120831, '\p{Is_Gc=nd}', "");
Expect(0, 120831, '\p{^Is_Gc=nd}', "");
Expect(0, 120831, '\P{Is_Gc=nd}', "");
Expect(1, 120831, '\P{^Is_Gc=nd}', "");
Expect(0, 120832, '\p{Is_Gc=nd}', "");
Expect(1, 120832, '\p{^Is_Gc=nd}', "");
Expect(1, 120832, '\P{Is_Gc=nd}', "");
Expect(0, 120832, '\P{^Is_Gc=nd}', "");
Expect(1, 120831, '\p{Is_Gc=	-nd}', "");
Expect(0, 120831, '\p{^Is_Gc=	-nd}', "");
Expect(0, 120831, '\P{Is_Gc=	-nd}', "");
Expect(1, 120831, '\P{^Is_Gc=	-nd}', "");
Expect(0, 120832, '\p{Is_Gc=	-nd}', "");
Expect(1, 120832, '\p{^Is_Gc=	-nd}', "");
Expect(1, 120832, '\P{Is_Gc=	-nd}', "");
Expect(0, 120832, '\P{^Is_Gc=	-nd}', "");
Error('\p{Is_Category= -Digit/a/}');
Error('\P{Is_Category= -Digit/a/}');
Expect(1, 120831, '\p{Is_Category=digit}', "");
Expect(0, 120831, '\p{^Is_Category=digit}', "");
Expect(0, 120831, '\P{Is_Category=digit}', "");
Expect(1, 120831, '\P{^Is_Category=digit}', "");
Expect(0, 120832, '\p{Is_Category=digit}', "");
Expect(1, 120832, '\p{^Is_Category=digit}', "");
Expect(1, 120832, '\P{Is_Category=digit}', "");
Expect(0, 120832, '\P{^Is_Category=digit}', "");
Expect(1, 120831, '\p{Is_Category=	 Digit}', "");
Expect(0, 120831, '\p{^Is_Category=	 Digit}', "");
Expect(0, 120831, '\P{Is_Category=	 Digit}', "");
Expect(1, 120831, '\P{^Is_Category=	 Digit}', "");
Expect(0, 120832, '\p{Is_Category=	 Digit}', "");
Expect(1, 120832, '\p{^Is_Category=	 Digit}', "");
Expect(1, 120832, '\P{Is_Category=	 Digit}', "");
Expect(0, 120832, '\P{^Is_Category=	 Digit}', "");
Error('\p{General_Category=_-Letter_Number:=}');
Error('\P{General_Category=_-Letter_Number:=}');
Expect(1, 74850, '\p{General_Category=letternumber}', "");
Expect(0, 74850, '\p{^General_Category=letternumber}', "");
Expect(0, 74850, '\P{General_Category=letternumber}', "");
Expect(1, 74850, '\P{^General_Category=letternumber}', "");
Expect(0, 74851, '\p{General_Category=letternumber}', "");
Expect(1, 74851, '\p{^General_Category=letternumber}', "");
Expect(1, 74851, '\P{General_Category=letternumber}', "");
Expect(0, 74851, '\P{^General_Category=letternumber}', "");
Expect(1, 74850, '\p{General_Category=	_Letter_Number}', "");
Expect(0, 74850, '\p{^General_Category=	_Letter_Number}', "");
Expect(0, 74850, '\P{General_Category=	_Letter_Number}', "");
Expect(1, 74850, '\P{^General_Category=	_Letter_Number}', "");
Expect(0, 74851, '\p{General_Category=	_Letter_Number}', "");
Expect(1, 74851, '\p{^General_Category=	_Letter_Number}', "");
Expect(1, 74851, '\P{General_Category=	_Letter_Number}', "");
Expect(0, 74851, '\P{^General_Category=	_Letter_Number}', "");
Error('\p{Gc= /a/Nl}');
Error('\P{Gc= /a/Nl}');
Expect(1, 74850, '\p{Gc: nl}', "");
Expect(0, 74850, '\p{^Gc: nl}', "");
Expect(0, 74850, '\P{Gc: nl}', "");
Expect(1, 74850, '\P{^Gc: nl}', "");
Expect(0, 74851, '\p{Gc: nl}', "");
Expect(1, 74851, '\p{^Gc: nl}', "");
Expect(1, 74851, '\P{Gc: nl}', "");
Expect(0, 74851, '\P{^Gc: nl}', "");
Expect(1, 74850, '\p{Gc=__NL}', "");
Expect(0, 74850, '\p{^Gc=__NL}', "");
Expect(0, 74850, '\P{Gc=__NL}', "");
Expect(1, 74850, '\P{^Gc=__NL}', "");
Expect(0, 74851, '\p{Gc=__NL}', "");
Expect(1, 74851, '\p{^Gc=__NL}', "");
Expect(1, 74851, '\P{Gc=__NL}', "");
Expect(0, 74851, '\P{^Gc=__NL}', "");
Error('\p{Category:   -letter_Number:=}');
Error('\P{Category:   -letter_Number:=}');
Expect(1, 74850, '\p{Category=letternumber}', "");
Expect(0, 74850, '\p{^Category=letternumber}', "");
Expect(0, 74850, '\P{Category=letternumber}', "");
Expect(1, 74850, '\P{^Category=letternumber}', "");
Expect(0, 74851, '\p{Category=letternumber}', "");
Expect(1, 74851, '\p{^Category=letternumber}', "");
Expect(1, 74851, '\P{Category=letternumber}', "");
Expect(0, 74851, '\P{^Category=letternumber}', "");
Expect(1, 74850, '\p{Category=  Letter_number}', "");
Expect(0, 74850, '\p{^Category=  Letter_number}', "");
Expect(0, 74850, '\P{Category=  Letter_number}', "");
Expect(1, 74850, '\P{^Category=  Letter_number}', "");
Expect(0, 74851, '\p{Category=  Letter_number}', "");
Expect(1, 74851, '\p{^Category=  Letter_number}', "");
Expect(1, 74851, '\P{Category=  Letter_number}', "");
Expect(0, 74851, '\P{^Category=  Letter_number}', "");
Error('\p{Is_General_Category=:=Nl}');
Error('\P{Is_General_Category=:=Nl}');
Expect(1, 74850, '\p{Is_General_Category=nl}', "");
Expect(0, 74850, '\p{^Is_General_Category=nl}', "");
Expect(0, 74850, '\P{Is_General_Category=nl}', "");
Expect(1, 74850, '\P{^Is_General_Category=nl}', "");
Expect(0, 74851, '\p{Is_General_Category=nl}', "");
Expect(1, 74851, '\p{^Is_General_Category=nl}', "");
Expect(1, 74851, '\P{Is_General_Category=nl}', "");
Expect(0, 74851, '\P{^Is_General_Category=nl}', "");
Expect(1, 74850, '\p{Is_General_Category= 	NL}', "");
Expect(0, 74850, '\p{^Is_General_Category= 	NL}', "");
Expect(0, 74850, '\P{Is_General_Category= 	NL}', "");
Expect(1, 74850, '\P{^Is_General_Category= 	NL}', "");
Expect(0, 74851, '\p{Is_General_Category= 	NL}', "");
Expect(1, 74851, '\p{^Is_General_Category= 	NL}', "");
Expect(1, 74851, '\P{Is_General_Category= 	NL}', "");
Expect(0, 74851, '\P{^Is_General_Category= 	NL}', "");
Error('\p{Is_Gc:   __letter_Number/a/}');
Error('\P{Is_Gc:   __letter_Number/a/}');
Expect(1, 74850, '\p{Is_Gc=letternumber}', "");
Expect(0, 74850, '\p{^Is_Gc=letternumber}', "");
Expect(0, 74850, '\P{Is_Gc=letternumber}', "");
Expect(1, 74850, '\P{^Is_Gc=letternumber}', "");
Expect(0, 74851, '\p{Is_Gc=letternumber}', "");
Expect(1, 74851, '\p{^Is_Gc=letternumber}', "");
Expect(1, 74851, '\P{Is_Gc=letternumber}', "");
Expect(0, 74851, '\P{^Is_Gc=letternumber}', "");
Expect(1, 74850, '\p{Is_Gc=	Letter_NUMBER}', "");
Expect(0, 74850, '\p{^Is_Gc=	Letter_NUMBER}', "");
Expect(0, 74850, '\P{Is_Gc=	Letter_NUMBER}', "");
Expect(1, 74850, '\P{^Is_Gc=	Letter_NUMBER}', "");
Expect(0, 74851, '\p{Is_Gc=	Letter_NUMBER}', "");
Expect(1, 74851, '\p{^Is_Gc=	Letter_NUMBER}', "");
Expect(1, 74851, '\P{Is_Gc=	Letter_NUMBER}', "");
Expect(0, 74851, '\P{^Is_Gc=	Letter_NUMBER}', "");
Error('\p{Is_Category=-Nl/a/}');
Error('\P{Is_Category=-Nl/a/}');
Expect(1, 74850, '\p{Is_Category=nl}', "");
Expect(0, 74850, '\p{^Is_Category=nl}', "");
Expect(0, 74850, '\P{Is_Category=nl}', "");
Expect(1, 74850, '\P{^Is_Category=nl}', "");
Expect(0, 74851, '\p{Is_Category=nl}', "");
Expect(1, 74851, '\p{^Is_Category=nl}', "");
Expect(1, 74851, '\P{Is_Category=nl}', "");
Expect(0, 74851, '\P{^Is_Category=nl}', "");
Expect(1, 74850, '\p{Is_Category=-_Nl}', "");
Expect(0, 74850, '\p{^Is_Category=-_Nl}', "");
Expect(0, 74850, '\P{Is_Category=-_Nl}', "");
Expect(1, 74850, '\P{^Is_Category=-_Nl}', "");
Expect(0, 74851, '\p{Is_Category=-_Nl}', "");
Expect(1, 74851, '\p{^Is_Category=-_Nl}', "");
Expect(1, 74851, '\P{Is_Category=-_Nl}', "");
Expect(0, 74851, '\P{^Is_Category=-_Nl}', "");
Error('\p{General_Category= Other_Number:=}');
Error('\P{General_Category= Other_Number:=}');
Expect(1, 127242, '\p{General_Category=othernumber}', "");
Expect(0, 127242, '\p{^General_Category=othernumber}', "");
Expect(0, 127242, '\P{General_Category=othernumber}', "");
Expect(1, 127242, '\P{^General_Category=othernumber}', "");
Expect(0, 127243, '\p{General_Category=othernumber}', "");
Expect(1, 127243, '\p{^General_Category=othernumber}', "");
Expect(1, 127243, '\P{General_Category=othernumber}', "");
Expect(0, 127243, '\P{^General_Category=othernumber}', "");
Expect(1, 127242, '\p{General_Category=_ other_Number}', "");
Expect(0, 127242, '\p{^General_Category=_ other_Number}', "");
Expect(0, 127242, '\P{General_Category=_ other_Number}', "");
Expect(1, 127242, '\P{^General_Category=_ other_Number}', "");
Expect(0, 127243, '\p{General_Category=_ other_Number}', "");
Expect(1, 127243, '\p{^General_Category=_ other_Number}', "");
Expect(1, 127243, '\P{General_Category=_ other_Number}', "");
Expect(0, 127243, '\P{^General_Category=_ other_Number}', "");
Error('\p{Gc= 	no:=}');
Error('\P{Gc= 	no:=}');
Expect(1, 127242, '\p{Gc=no}', "");
Expect(0, 127242, '\p{^Gc=no}', "");
Expect(0, 127242, '\P{Gc=no}', "");
Expect(1, 127242, '\P{^Gc=no}', "");
Expect(0, 127243, '\p{Gc=no}', "");
Expect(1, 127243, '\p{^Gc=no}', "");
Expect(1, 127243, '\P{Gc=no}', "");
Expect(0, 127243, '\P{^Gc=no}', "");
Expect(1, 127242, '\p{Gc: 	 No}', "");
Expect(0, 127242, '\p{^Gc: 	 No}', "");
Expect(0, 127242, '\P{Gc: 	 No}', "");
Expect(1, 127242, '\P{^Gc: 	 No}', "");
Expect(0, 127243, '\p{Gc: 	 No}', "");
Expect(1, 127243, '\p{^Gc: 	 No}', "");
Expect(1, 127243, '\P{Gc: 	 No}', "");
Expect(0, 127243, '\P{^Gc: 	 No}', "");
Error('\p{Category=/a/-_other_Number}');
Error('\P{Category=/a/-_other_Number}');
Expect(1, 127242, '\p{Category=othernumber}', "");
Expect(0, 127242, '\p{^Category=othernumber}', "");
Expect(0, 127242, '\P{Category=othernumber}', "");
Expect(1, 127242, '\P{^Category=othernumber}', "");
Expect(0, 127243, '\p{Category=othernumber}', "");
Expect(1, 127243, '\p{^Category=othernumber}', "");
Expect(1, 127243, '\P{Category=othernumber}', "");
Expect(0, 127243, '\P{^Category=othernumber}', "");
Expect(1, 127242, '\p{Category=		other_Number}', "");
Expect(0, 127242, '\p{^Category=		other_Number}', "");
Expect(0, 127242, '\P{Category=		other_Number}', "");
Expect(1, 127242, '\P{^Category=		other_Number}', "");
Expect(0, 127243, '\p{Category=		other_Number}', "");
Expect(1, 127243, '\p{^Category=		other_Number}', "");
Expect(1, 127243, '\P{Category=		other_Number}', "");
Expect(0, 127243, '\P{^Category=		other_Number}', "");
Error('\p{Is_General_Category=_ no:=}');
Error('\P{Is_General_Category=_ no:=}');
Expect(1, 127242, '\p{Is_General_Category=no}', "");
Expect(0, 127242, '\p{^Is_General_Category=no}', "");
Expect(0, 127242, '\P{Is_General_Category=no}', "");
Expect(1, 127242, '\P{^Is_General_Category=no}', "");
Expect(0, 127243, '\p{Is_General_Category=no}', "");
Expect(1, 127243, '\p{^Is_General_Category=no}', "");
Expect(1, 127243, '\P{Is_General_Category=no}', "");
Expect(0, 127243, '\P{^Is_General_Category=no}', "");
Expect(1, 127242, '\p{Is_General_Category= -NO}', "");
Expect(0, 127242, '\p{^Is_General_Category= -NO}', "");
Expect(0, 127242, '\P{Is_General_Category= -NO}', "");
Expect(1, 127242, '\P{^Is_General_Category= -NO}', "");
Expect(0, 127243, '\p{Is_General_Category= -NO}', "");
Expect(1, 127243, '\p{^Is_General_Category= -NO}', "");
Expect(1, 127243, '\P{Is_General_Category= -NO}', "");
Expect(0, 127243, '\P{^Is_General_Category= -NO}', "");
Error('\p{Is_Gc=:=_OTHER_Number}');
Error('\P{Is_Gc=:=_OTHER_Number}');
Expect(1, 127242, '\p{Is_Gc=othernumber}', "");
Expect(0, 127242, '\p{^Is_Gc=othernumber}', "");
Expect(0, 127242, '\P{Is_Gc=othernumber}', "");
Expect(1, 127242, '\P{^Is_Gc=othernumber}', "");
Expect(0, 127243, '\p{Is_Gc=othernumber}', "");
Expect(1, 127243, '\p{^Is_Gc=othernumber}', "");
Expect(1, 127243, '\P{Is_Gc=othernumber}', "");
Expect(0, 127243, '\P{^Is_Gc=othernumber}', "");
Expect(1, 127242, '\p{Is_Gc=	Other_Number}', "");
Expect(0, 127242, '\p{^Is_Gc=	Other_Number}', "");
Expect(0, 127242, '\P{Is_Gc=	Other_Number}', "");
Expect(1, 127242, '\P{^Is_Gc=	Other_Number}', "");
Expect(0, 127243, '\p{Is_Gc=	Other_Number}', "");
Expect(1, 127243, '\p{^Is_Gc=	Other_Number}', "");
Expect(1, 127243, '\P{Is_Gc=	Other_Number}', "");
Expect(0, 127243, '\P{^Is_Gc=	Other_Number}', "");
Error('\p{Is_Category=/a/NO}');
Error('\P{Is_Category=/a/NO}');
Expect(1, 127242, '\p{Is_Category=no}', "");
Expect(0, 127242, '\p{^Is_Category=no}', "");
Expect(0, 127242, '\P{Is_Category=no}', "");
Expect(1, 127242, '\P{^Is_Category=no}', "");
Expect(0, 127243, '\p{Is_Category=no}', "");
Expect(1, 127243, '\p{^Is_Category=no}', "");
Expect(1, 127243, '\P{Is_Category=no}', "");
Expect(0, 127243, '\P{^Is_Category=no}', "");
Expect(1, 127242, '\p{Is_Category=-_No}', "");
Expect(0, 127242, '\p{^Is_Category=-_No}', "");
Expect(0, 127242, '\P{Is_Category=-_No}', "");
Expect(1, 127242, '\P{^Is_Category=-_No}', "");
Expect(0, 127243, '\p{Is_Category=-_No}', "");
Expect(1, 127243, '\p{^Is_Category=-_No}', "");
Expect(1, 127243, '\P{Is_Category=-_No}', "");
Expect(0, 127243, '\P{^Is_Category=-_No}', "");
Error('\p{General_Category=Punctuation/a/}');
Error('\P{General_Category=Punctuation/a/}');
Expect(1, 74867, '\p{General_Category=punctuation}', "");
Expect(0, 74867, '\p{^General_Category=punctuation}', "");
Expect(0, 74867, '\P{General_Category=punctuation}', "");
Expect(1, 74867, '\P{^General_Category=punctuation}', "");
Expect(0, 74868, '\p{General_Category=punctuation}', "");
Expect(1, 74868, '\p{^General_Category=punctuation}', "");
Expect(1, 74868, '\P{General_Category=punctuation}', "");
Expect(0, 74868, '\P{^General_Category=punctuation}', "");
Expect(1, 74867, '\p{General_Category=-punctuation}', "");
Expect(0, 74867, '\p{^General_Category=-punctuation}', "");
Expect(0, 74867, '\P{General_Category=-punctuation}', "");
Expect(1, 74867, '\P{^General_Category=-punctuation}', "");
Expect(0, 74868, '\p{General_Category=-punctuation}', "");
Expect(1, 74868, '\p{^General_Category=-punctuation}', "");
Expect(1, 74868, '\P{General_Category=-punctuation}', "");
Expect(0, 74868, '\P{^General_Category=-punctuation}', "");
Error('\p{Gc=_p:=}');
Error('\P{Gc=_p:=}');
Expect(1, 74867, '\p{Gc=p}', "");
Expect(0, 74867, '\p{^Gc=p}', "");
Expect(0, 74867, '\P{Gc=p}', "");
Expect(1, 74867, '\P{^Gc=p}', "");
Expect(0, 74868, '\p{Gc=p}', "");
Expect(1, 74868, '\p{^Gc=p}', "");
Expect(1, 74868, '\P{Gc=p}', "");
Expect(0, 74868, '\P{^Gc=p}', "");
Expect(1, 74867, '\p{Gc=	P}', "");
Expect(0, 74867, '\p{^Gc=	P}', "");
Expect(0, 74867, '\P{Gc=	P}', "");
Expect(1, 74867, '\P{^Gc=	P}', "");
Expect(0, 74868, '\p{Gc=	P}', "");
Expect(1, 74868, '\p{^Gc=	P}', "");
Expect(1, 74868, '\P{Gc=	P}', "");
Expect(0, 74868, '\P{^Gc=	P}', "");
Error('\p{Category:	:=		Punct}');
Error('\P{Category:	:=		Punct}');
Expect(1, 74867, '\p{Category=punct}', "");
Expect(0, 74867, '\p{^Category=punct}', "");
Expect(0, 74867, '\P{Category=punct}', "");
Expect(1, 74867, '\P{^Category=punct}', "");
Expect(0, 74868, '\p{Category=punct}', "");
Expect(1, 74868, '\p{^Category=punct}', "");
Expect(1, 74868, '\P{Category=punct}', "");
Expect(0, 74868, '\P{^Category=punct}', "");
Expect(1, 74867, '\p{Category=__Punct}', "");
Expect(0, 74867, '\p{^Category=__Punct}', "");
Expect(0, 74867, '\P{Category=__Punct}', "");
Expect(1, 74867, '\P{^Category=__Punct}', "");
Expect(0, 74868, '\p{Category=__Punct}', "");
Expect(1, 74868, '\p{^Category=__Punct}', "");
Expect(1, 74868, '\P{Category=__Punct}', "");
Expect(0, 74868, '\P{^Category=__Punct}', "");
Error('\p{Is_General_Category= PUNCTUATION/a/}');
Error('\P{Is_General_Category= PUNCTUATION/a/}');
Expect(1, 74867, '\p{Is_General_Category:   punctuation}', "");
Expect(0, 74867, '\p{^Is_General_Category:   punctuation}', "");
Expect(0, 74867, '\P{Is_General_Category:   punctuation}', "");
Expect(1, 74867, '\P{^Is_General_Category:   punctuation}', "");
Expect(0, 74868, '\p{Is_General_Category:   punctuation}', "");
Expect(1, 74868, '\p{^Is_General_Category:   punctuation}', "");
Expect(1, 74868, '\P{Is_General_Category:   punctuation}', "");
Expect(0, 74868, '\P{^Is_General_Category:   punctuation}', "");
Expect(1, 74867, '\p{Is_General_Category= -PUNCTUATION}', "");
Expect(0, 74867, '\p{^Is_General_Category= -PUNCTUATION}', "");
Expect(0, 74867, '\P{Is_General_Category= -PUNCTUATION}', "");
Expect(1, 74867, '\P{^Is_General_Category= -PUNCTUATION}', "");
Expect(0, 74868, '\p{Is_General_Category= -PUNCTUATION}', "");
Expect(1, 74868, '\p{^Is_General_Category= -PUNCTUATION}', "");
Expect(1, 74868, '\P{Is_General_Category= -PUNCTUATION}', "");
Expect(0, 74868, '\P{^Is_General_Category= -PUNCTUATION}', "");
Error('\p{Is_Gc:-/a/p}');
Error('\P{Is_Gc:-/a/p}');
Expect(1, 74867, '\p{Is_Gc=p}', "");
Expect(0, 74867, '\p{^Is_Gc=p}', "");
Expect(0, 74867, '\P{Is_Gc=p}', "");
Expect(1, 74867, '\P{^Is_Gc=p}', "");
Expect(0, 74868, '\p{Is_Gc=p}', "");
Expect(1, 74868, '\p{^Is_Gc=p}', "");
Expect(1, 74868, '\P{Is_Gc=p}', "");
Expect(0, 74868, '\P{^Is_Gc=p}', "");
Expect(1, 74867, '\p{Is_Gc=__p}', "");
Expect(0, 74867, '\p{^Is_Gc=__p}', "");
Expect(0, 74867, '\P{Is_Gc=__p}', "");
Expect(1, 74867, '\P{^Is_Gc=__p}', "");
Expect(0, 74868, '\p{Is_Gc=__p}', "");
Expect(1, 74868, '\p{^Is_Gc=__p}', "");
Expect(1, 74868, '\P{Is_Gc=__p}', "");
Expect(0, 74868, '\P{^Is_Gc=__p}', "");
Error('\p{Is_Category=-PUNCT:=}');
Error('\P{Is_Category=-PUNCT:=}');
Expect(1, 74867, '\p{Is_Category: punct}', "");
Expect(0, 74867, '\p{^Is_Category: punct}', "");
Expect(0, 74867, '\P{Is_Category: punct}', "");
Expect(1, 74867, '\P{^Is_Category: punct}', "");
Expect(0, 74868, '\p{Is_Category: punct}', "");
Expect(1, 74868, '\p{^Is_Category: punct}', "");
Expect(1, 74868, '\P{Is_Category: punct}', "");
Expect(0, 74868, '\P{^Is_Category: punct}', "");
Expect(1, 74867, '\p{Is_Category= Punct}', "");
Expect(0, 74867, '\p{^Is_Category= Punct}', "");
Expect(0, 74867, '\P{Is_Category= Punct}', "");
Expect(1, 74867, '\P{^Is_Category= Punct}', "");
Expect(0, 74868, '\p{Is_Category= Punct}', "");
Expect(1, 74868, '\p{^Is_Category= Punct}', "");
Expect(1, 74868, '\P{Is_Category= Punct}', "");
Expect(0, 74868, '\P{^Is_Category= Punct}', "");
Error('\p{General_Category=_:=Connector_Punctuation}');
Error('\P{General_Category=_:=Connector_Punctuation}');
Expect(1, 65343, '\p{General_Category=connectorpunctuation}', "");
Expect(0, 65343, '\p{^General_Category=connectorpunctuation}', "");
Expect(0, 65343, '\P{General_Category=connectorpunctuation}', "");
Expect(1, 65343, '\P{^General_Category=connectorpunctuation}', "");
Expect(0, 65344, '\p{General_Category=connectorpunctuation}', "");
Expect(1, 65344, '\p{^General_Category=connectorpunctuation}', "");
Expect(1, 65344, '\P{General_Category=connectorpunctuation}', "");
Expect(0, 65344, '\P{^General_Category=connectorpunctuation}', "");
Expect(1, 65343, '\p{General_Category:-	Connector_Punctuation}', "");
Expect(0, 65343, '\p{^General_Category:-	Connector_Punctuation}', "");
Expect(0, 65343, '\P{General_Category:-	Connector_Punctuation}', "");
Expect(1, 65343, '\P{^General_Category:-	Connector_Punctuation}', "");
Expect(0, 65344, '\p{General_Category:-	Connector_Punctuation}', "");
Expect(1, 65344, '\p{^General_Category:-	Connector_Punctuation}', "");
Expect(1, 65344, '\P{General_Category:-	Connector_Punctuation}', "");
Expect(0, 65344, '\P{^General_Category:-	Connector_Punctuation}', "");
Error('\p{Gc=-_PC/a/}');
Error('\P{Gc=-_PC/a/}');
Expect(1, 65343, '\p{Gc:	pc}', "");
Expect(0, 65343, '\p{^Gc:	pc}', "");
Expect(0, 65343, '\P{Gc:	pc}', "");
Expect(1, 65343, '\P{^Gc:	pc}', "");
Expect(0, 65344, '\p{Gc:	pc}', "");
Expect(1, 65344, '\p{^Gc:	pc}', "");
Expect(1, 65344, '\P{Gc:	pc}', "");
Expect(0, 65344, '\P{^Gc:	pc}', "");
Expect(1, 65343, '\p{Gc= PC}', "");
Expect(0, 65343, '\p{^Gc= PC}', "");
Expect(0, 65343, '\P{Gc= PC}', "");
Expect(1, 65343, '\P{^Gc= PC}', "");
Expect(0, 65344, '\p{Gc= PC}', "");
Expect(1, 65344, '\p{^Gc= PC}', "");
Expect(1, 65344, '\P{Gc= PC}', "");
Expect(0, 65344, '\P{^Gc= PC}', "");
Error('\p{Category=/a/CONNECTOR_punctuation}');
Error('\P{Category=/a/CONNECTOR_punctuation}');
Expect(1, 65343, '\p{Category=connectorpunctuation}', "");
Expect(0, 65343, '\p{^Category=connectorpunctuation}', "");
Expect(0, 65343, '\P{Category=connectorpunctuation}', "");
Expect(1, 65343, '\P{^Category=connectorpunctuation}', "");
Expect(0, 65344, '\p{Category=connectorpunctuation}', "");
Expect(1, 65344, '\p{^Category=connectorpunctuation}', "");
Expect(1, 65344, '\P{Category=connectorpunctuation}', "");
Expect(0, 65344, '\P{^Category=connectorpunctuation}', "");
Expect(1, 65343, '\p{Category:_-Connector_punctuation}', "");
Expect(0, 65343, '\p{^Category:_-Connector_punctuation}', "");
Expect(0, 65343, '\P{Category:_-Connector_punctuation}', "");
Expect(1, 65343, '\P{^Category:_-Connector_punctuation}', "");
Expect(0, 65344, '\p{Category:_-Connector_punctuation}', "");
Expect(1, 65344, '\p{^Category:_-Connector_punctuation}', "");
Expect(1, 65344, '\P{Category:_-Connector_punctuation}', "");
Expect(0, 65344, '\P{^Category:_-Connector_punctuation}', "");
Error('\p{Is_General_Category=-Pc/a/}');
Error('\P{Is_General_Category=-Pc/a/}');
Expect(1, 65343, '\p{Is_General_Category=pc}', "");
Expect(0, 65343, '\p{^Is_General_Category=pc}', "");
Expect(0, 65343, '\P{Is_General_Category=pc}', "");
Expect(1, 65343, '\P{^Is_General_Category=pc}', "");
Expect(0, 65344, '\p{Is_General_Category=pc}', "");
Expect(1, 65344, '\p{^Is_General_Category=pc}', "");
Expect(1, 65344, '\P{Is_General_Category=pc}', "");
Expect(0, 65344, '\P{^Is_General_Category=pc}', "");
Expect(1, 65343, '\p{Is_General_Category=- pc}', "");
Expect(0, 65343, '\p{^Is_General_Category=- pc}', "");
Expect(0, 65343, '\P{Is_General_Category=- pc}', "");
Expect(1, 65343, '\P{^Is_General_Category=- pc}', "");
Expect(0, 65344, '\p{Is_General_Category=- pc}', "");
Expect(1, 65344, '\p{^Is_General_Category=- pc}', "");
Expect(1, 65344, '\P{Is_General_Category=- pc}', "");
Expect(0, 65344, '\P{^Is_General_Category=- pc}', "");
Error('\p{Is_Gc= 	connector_Punctuation/a/}');
Error('\P{Is_Gc= 	connector_Punctuation/a/}');
Expect(1, 65343, '\p{Is_Gc=connectorpunctuation}', "");
Expect(0, 65343, '\p{^Is_Gc=connectorpunctuation}', "");
Expect(0, 65343, '\P{Is_Gc=connectorpunctuation}', "");
Expect(1, 65343, '\P{^Is_Gc=connectorpunctuation}', "");
Expect(0, 65344, '\p{Is_Gc=connectorpunctuation}', "");
Expect(1, 65344, '\p{^Is_Gc=connectorpunctuation}', "");
Expect(1, 65344, '\P{Is_Gc=connectorpunctuation}', "");
Expect(0, 65344, '\P{^Is_Gc=connectorpunctuation}', "");
Expect(1, 65343, '\p{Is_Gc=- Connector_Punctuation}', "");
Expect(0, 65343, '\p{^Is_Gc=- Connector_Punctuation}', "");
Expect(0, 65343, '\P{Is_Gc=- Connector_Punctuation}', "");
Expect(1, 65343, '\P{^Is_Gc=- Connector_Punctuation}', "");
Expect(0, 65344, '\p{Is_Gc=- Connector_Punctuation}', "");
Expect(1, 65344, '\p{^Is_Gc=- Connector_Punctuation}', "");
Expect(1, 65344, '\P{Is_Gc=- Connector_Punctuation}', "");
Expect(0, 65344, '\P{^Is_Gc=- Connector_Punctuation}', "");
Error('\p{Is_Category=--Pc/a/}');
Error('\P{Is_Category=--Pc/a/}');
Expect(1, 65343, '\p{Is_Category=pc}', "");
Expect(0, 65343, '\p{^Is_Category=pc}', "");
Expect(0, 65343, '\P{Is_Category=pc}', "");
Expect(1, 65343, '\P{^Is_Category=pc}', "");
Expect(0, 65344, '\p{Is_Category=pc}', "");
Expect(1, 65344, '\p{^Is_Category=pc}', "");
Expect(1, 65344, '\P{Is_Category=pc}', "");
Expect(0, 65344, '\P{^Is_Category=pc}', "");
Expect(1, 65343, '\p{Is_Category= pc}', "");
Expect(0, 65343, '\p{^Is_Category= pc}', "");
Expect(0, 65343, '\P{Is_Category= pc}', "");
Expect(1, 65343, '\P{^Is_Category= pc}', "");
Expect(0, 65344, '\p{Is_Category= pc}', "");
Expect(1, 65344, '\p{^Is_Category= pc}', "");
Expect(1, 65344, '\P{Is_Category= pc}', "");
Expect(0, 65344, '\P{^Is_Category= pc}', "");
Error('\p{General_Category=-:=DASH_Punctuation}');
Error('\P{General_Category=-:=DASH_Punctuation}');
Expect(1, 65293, '\p{General_Category=dashpunctuation}', "");
Expect(0, 65293, '\p{^General_Category=dashpunctuation}', "");
Expect(0, 65293, '\P{General_Category=dashpunctuation}', "");
Expect(1, 65293, '\P{^General_Category=dashpunctuation}', "");
Expect(0, 65294, '\p{General_Category=dashpunctuation}', "");
Expect(1, 65294, '\p{^General_Category=dashpunctuation}', "");
Expect(1, 65294, '\P{General_Category=dashpunctuation}', "");
Expect(0, 65294, '\P{^General_Category=dashpunctuation}', "");
Expect(1, 65293, '\p{General_Category=dash_Punctuation}', "");
Expect(0, 65293, '\p{^General_Category=dash_Punctuation}', "");
Expect(0, 65293, '\P{General_Category=dash_Punctuation}', "");
Expect(1, 65293, '\P{^General_Category=dash_Punctuation}', "");
Expect(0, 65294, '\p{General_Category=dash_Punctuation}', "");
Expect(1, 65294, '\p{^General_Category=dash_Punctuation}', "");
Expect(1, 65294, '\P{General_Category=dash_Punctuation}', "");
Expect(0, 65294, '\P{^General_Category=dash_Punctuation}', "");
Error('\p{Gc= -PD/a/}');
Error('\P{Gc= -PD/a/}');
Expect(1, 65293, '\p{Gc=pd}', "");
Expect(0, 65293, '\p{^Gc=pd}', "");
Expect(0, 65293, '\P{Gc=pd}', "");
Expect(1, 65293, '\P{^Gc=pd}', "");
Expect(0, 65294, '\p{Gc=pd}', "");
Expect(1, 65294, '\p{^Gc=pd}', "");
Expect(1, 65294, '\P{Gc=pd}', "");
Expect(0, 65294, '\P{^Gc=pd}', "");
Expect(1, 65293, '\p{Gc:		PD}', "");
Expect(0, 65293, '\p{^Gc:		PD}', "");
Expect(0, 65293, '\P{Gc:		PD}', "");
Expect(1, 65293, '\P{^Gc:		PD}', "");
Expect(0, 65294, '\p{Gc:		PD}', "");
Expect(1, 65294, '\p{^Gc:		PD}', "");
Expect(1, 65294, '\P{Gc:		PD}', "");
Expect(0, 65294, '\P{^Gc:		PD}', "");
Error('\p{Category: 	:=Dash_PUNCTUATION}');
Error('\P{Category: 	:=Dash_PUNCTUATION}');
Expect(1, 65293, '\p{Category=dashpunctuation}', "");
Expect(0, 65293, '\p{^Category=dashpunctuation}', "");
Expect(0, 65293, '\P{Category=dashpunctuation}', "");
Expect(1, 65293, '\P{^Category=dashpunctuation}', "");
Expect(0, 65294, '\p{Category=dashpunctuation}', "");
Expect(1, 65294, '\p{^Category=dashpunctuation}', "");
Expect(1, 65294, '\P{Category=dashpunctuation}', "");
Expect(0, 65294, '\P{^Category=dashpunctuation}', "");
Expect(1, 65293, '\p{Category=	-DASH_Punctuation}', "");
Expect(0, 65293, '\p{^Category=	-DASH_Punctuation}', "");
Expect(0, 65293, '\P{Category=	-DASH_Punctuation}', "");
Expect(1, 65293, '\P{^Category=	-DASH_Punctuation}', "");
Expect(0, 65294, '\p{Category=	-DASH_Punctuation}', "");
Expect(1, 65294, '\p{^Category=	-DASH_Punctuation}', "");
Expect(1, 65294, '\P{Category=	-DASH_Punctuation}', "");
Expect(0, 65294, '\P{^Category=	-DASH_Punctuation}', "");
Error('\p{Is_General_Category=-Pd:=}');
Error('\P{Is_General_Category=-Pd:=}');
Expect(1, 65293, '\p{Is_General_Category=pd}', "");
Expect(0, 65293, '\p{^Is_General_Category=pd}', "");
Expect(0, 65293, '\P{Is_General_Category=pd}', "");
Expect(1, 65293, '\P{^Is_General_Category=pd}', "");
Expect(0, 65294, '\p{Is_General_Category=pd}', "");
Expect(1, 65294, '\p{^Is_General_Category=pd}', "");
Expect(1, 65294, '\P{Is_General_Category=pd}', "");
Expect(0, 65294, '\P{^Is_General_Category=pd}', "");
Expect(1, 65293, '\p{Is_General_Category=	PD}', "");
Expect(0, 65293, '\p{^Is_General_Category=	PD}', "");
Expect(0, 65293, '\P{Is_General_Category=	PD}', "");
Expect(1, 65293, '\P{^Is_General_Category=	PD}', "");
Expect(0, 65294, '\p{Is_General_Category=	PD}', "");
Expect(1, 65294, '\p{^Is_General_Category=	PD}', "");
Expect(1, 65294, '\P{Is_General_Category=	PD}', "");
Expect(0, 65294, '\P{^Is_General_Category=	PD}', "");
Error('\p{Is_Gc=_dash_Punctuation/a/}');
Error('\P{Is_Gc=_dash_Punctuation/a/}');
Expect(1, 65293, '\p{Is_Gc=dashpunctuation}', "");
Expect(0, 65293, '\p{^Is_Gc=dashpunctuation}', "");
Expect(0, 65293, '\P{Is_Gc=dashpunctuation}', "");
Expect(1, 65293, '\P{^Is_Gc=dashpunctuation}', "");
Expect(0, 65294, '\p{Is_Gc=dashpunctuation}', "");
Expect(1, 65294, '\p{^Is_Gc=dashpunctuation}', "");
Expect(1, 65294, '\P{Is_Gc=dashpunctuation}', "");
Expect(0, 65294, '\P{^Is_Gc=dashpunctuation}', "");
Expect(1, 65293, '\p{Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(0, 65293, '\p{^Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(0, 65293, '\P{Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(1, 65293, '\P{^Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(0, 65294, '\p{Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(1, 65294, '\p{^Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(1, 65294, '\P{Is_Gc= 	Dash_PUNCTUATION}', "");
Expect(0, 65294, '\P{^Is_Gc= 	Dash_PUNCTUATION}', "");
Error('\p{Is_Category=/a/--PD}');
Error('\P{Is_Category=/a/--PD}');
Expect(1, 65293, '\p{Is_Category=pd}', "");
Expect(0, 65293, '\p{^Is_Category=pd}', "");
Expect(0, 65293, '\P{Is_Category=pd}', "");
Expect(1, 65293, '\P{^Is_Category=pd}', "");
Expect(0, 65294, '\p{Is_Category=pd}', "");
Expect(1, 65294, '\p{^Is_Category=pd}', "");
Expect(1, 65294, '\P{Is_Category=pd}', "");
Expect(0, 65294, '\P{^Is_Category=pd}', "");
Expect(1, 65293, '\p{Is_Category= -PD}', "");
Expect(0, 65293, '\p{^Is_Category= -PD}', "");
Expect(0, 65293, '\P{Is_Category= -PD}', "");
Expect(1, 65293, '\P{^Is_Category= -PD}', "");
Expect(0, 65294, '\p{Is_Category= -PD}', "");
Expect(1, 65294, '\p{^Is_Category= -PD}', "");
Expect(1, 65294, '\P{Is_Category= -PD}', "");
Expect(0, 65294, '\P{^Is_Category= -PD}', "");
Error('\p{General_Category:	-:=CLOSE_PUNCTUATION}');
Error('\P{General_Category:	-:=CLOSE_PUNCTUATION}');
Expect(1, 65379, '\p{General_Category=closepunctuation}', "");
Expect(0, 65379, '\p{^General_Category=closepunctuation}', "");
Expect(0, 65379, '\P{General_Category=closepunctuation}', "");
Expect(1, 65379, '\P{^General_Category=closepunctuation}', "");
Expect(0, 65380, '\p{General_Category=closepunctuation}', "");
Expect(1, 65380, '\p{^General_Category=closepunctuation}', "");
Expect(1, 65380, '\P{General_Category=closepunctuation}', "");
Expect(0, 65380, '\P{^General_Category=closepunctuation}', "");
Expect(1, 65379, '\p{General_Category:   	Close_punctuation}', "");
Expect(0, 65379, '\p{^General_Category:   	Close_punctuation}', "");
Expect(0, 65379, '\P{General_Category:   	Close_punctuation}', "");
Expect(1, 65379, '\P{^General_Category:   	Close_punctuation}', "");
Expect(0, 65380, '\p{General_Category:   	Close_punctuation}', "");
Expect(1, 65380, '\p{^General_Category:   	Close_punctuation}', "");
Expect(1, 65380, '\P{General_Category:   	Close_punctuation}', "");
Expect(0, 65380, '\P{^General_Category:   	Close_punctuation}', "");
Error('\p{Gc=:=Pe}');
Error('\P{Gc=:=Pe}');
Expect(1, 65379, '\p{Gc=pe}', "");
Expect(0, 65379, '\p{^Gc=pe}', "");
Expect(0, 65379, '\P{Gc=pe}', "");
Expect(1, 65379, '\P{^Gc=pe}', "");
Expect(0, 65380, '\p{Gc=pe}', "");
Expect(1, 65380, '\p{^Gc=pe}', "");
Expect(1, 65380, '\P{Gc=pe}', "");
Expect(0, 65380, '\P{^Gc=pe}', "");
Expect(1, 65379, '\p{Gc=-	PE}', "");
Expect(0, 65379, '\p{^Gc=-	PE}', "");
Expect(0, 65379, '\P{Gc=-	PE}', "");
Expect(1, 65379, '\P{^Gc=-	PE}', "");
Expect(0, 65380, '\p{Gc=-	PE}', "");
Expect(1, 65380, '\p{^Gc=-	PE}', "");
Expect(1, 65380, '\P{Gc=-	PE}', "");
Expect(0, 65380, '\P{^Gc=-	PE}', "");
Error('\p{Category=:=Close_Punctuation}');
Error('\P{Category=:=Close_Punctuation}');
Expect(1, 65379, '\p{Category: closepunctuation}', "");
Expect(0, 65379, '\p{^Category: closepunctuation}', "");
Expect(0, 65379, '\P{Category: closepunctuation}', "");
Expect(1, 65379, '\P{^Category: closepunctuation}', "");
Expect(0, 65380, '\p{Category: closepunctuation}', "");
Expect(1, 65380, '\p{^Category: closepunctuation}', "");
Expect(1, 65380, '\P{Category: closepunctuation}', "");
Expect(0, 65380, '\P{^Category: closepunctuation}', "");
Expect(1, 65379, '\p{Category:   _ CLOSE_Punctuation}', "");
Expect(0, 65379, '\p{^Category:   _ CLOSE_Punctuation}', "");
Expect(0, 65379, '\P{Category:   _ CLOSE_Punctuation}', "");
Expect(1, 65379, '\P{^Category:   _ CLOSE_Punctuation}', "");
Expect(0, 65380, '\p{Category:   _ CLOSE_Punctuation}', "");
Expect(1, 65380, '\p{^Category:   _ CLOSE_Punctuation}', "");
Expect(1, 65380, '\P{Category:   _ CLOSE_Punctuation}', "");
Expect(0, 65380, '\P{^Category:   _ CLOSE_Punctuation}', "");
Error('\p{Is_General_Category=	 Pe:=}');
Error('\P{Is_General_Category=	 Pe:=}');
Expect(1, 65379, '\p{Is_General_Category:pe}', "");
Expect(0, 65379, '\p{^Is_General_Category:pe}', "");
Expect(0, 65379, '\P{Is_General_Category:pe}', "");
Expect(1, 65379, '\P{^Is_General_Category:pe}', "");
Expect(0, 65380, '\p{Is_General_Category:pe}', "");
Expect(1, 65380, '\p{^Is_General_Category:pe}', "");
Expect(1, 65380, '\P{Is_General_Category:pe}', "");
Expect(0, 65380, '\P{^Is_General_Category:pe}', "");
Expect(1, 65379, '\p{Is_General_Category:  -Pe}', "");
Expect(0, 65379, '\p{^Is_General_Category:  -Pe}', "");
Expect(0, 65379, '\P{Is_General_Category:  -Pe}', "");
Expect(1, 65379, '\P{^Is_General_Category:  -Pe}', "");
Expect(0, 65380, '\p{Is_General_Category:  -Pe}', "");
Expect(1, 65380, '\p{^Is_General_Category:  -Pe}', "");
Expect(1, 65380, '\P{Is_General_Category:  -Pe}', "");
Expect(0, 65380, '\P{^Is_General_Category:  -Pe}', "");
Error('\p{Is_Gc=_-CLOSE_PUNCTUATION/a/}');
Error('\P{Is_Gc=_-CLOSE_PUNCTUATION/a/}');
Expect(1, 65379, '\p{Is_Gc=closepunctuation}', "");
Expect(0, 65379, '\p{^Is_Gc=closepunctuation}', "");
Expect(0, 65379, '\P{Is_Gc=closepunctuation}', "");
Expect(1, 65379, '\P{^Is_Gc=closepunctuation}', "");
Expect(0, 65380, '\p{Is_Gc=closepunctuation}', "");
Expect(1, 65380, '\p{^Is_Gc=closepunctuation}', "");
Expect(1, 65380, '\P{Is_Gc=closepunctuation}', "");
Expect(0, 65380, '\P{^Is_Gc=closepunctuation}', "");
Expect(1, 65379, '\p{Is_Gc= 	CLOSE_Punctuation}', "");
Expect(0, 65379, '\p{^Is_Gc= 	CLOSE_Punctuation}', "");
Expect(0, 65379, '\P{Is_Gc= 	CLOSE_Punctuation}', "");
Expect(1, 65379, '\P{^Is_Gc= 	CLOSE_Punctuation}', "");
Expect(0, 65380, '\p{Is_Gc= 	CLOSE_Punctuation}', "");
Expect(1, 65380, '\p{^Is_Gc= 	CLOSE_Punctuation}', "");
Expect(1, 65380, '\P{Is_Gc= 	CLOSE_Punctuation}', "");
Expect(0, 65380, '\P{^Is_Gc= 	CLOSE_Punctuation}', "");
Error('\p{Is_Category=	/a/PE}');
Error('\P{Is_Category=	/a/PE}');
Expect(1, 65379, '\p{Is_Category=pe}', "");
Expect(0, 65379, '\p{^Is_Category=pe}', "");
Expect(0, 65379, '\P{Is_Category=pe}', "");
Expect(1, 65379, '\P{^Is_Category=pe}', "");
Expect(0, 65380, '\p{Is_Category=pe}', "");
Expect(1, 65380, '\p{^Is_Category=pe}', "");
Expect(1, 65380, '\P{Is_Category=pe}', "");
Expect(0, 65380, '\P{^Is_Category=pe}', "");
Expect(1, 65379, '\p{Is_Category=_	Pe}', "");
Expect(0, 65379, '\p{^Is_Category=_	Pe}', "");
Expect(0, 65379, '\P{Is_Category=_	Pe}', "");
Expect(1, 65379, '\P{^Is_Category=_	Pe}', "");
Expect(0, 65380, '\p{Is_Category=_	Pe}', "");
Expect(1, 65380, '\p{^Is_Category=_	Pe}', "");
Expect(1, 65380, '\P{Is_Category=_	Pe}', "");
Expect(0, 65380, '\P{^Is_Category=_	Pe}', "");
Error('\p{General_Category=_:=Final_punctuation}');
Error('\P{General_Category=_:=Final_punctuation}');
Expect(1, 11809, '\p{General_Category:	finalpunctuation}', "");
Expect(0, 11809, '\p{^General_Category:	finalpunctuation}', "");
Expect(0, 11809, '\P{General_Category:	finalpunctuation}', "");
Expect(1, 11809, '\P{^General_Category:	finalpunctuation}', "");
Expect(0, 11810, '\p{General_Category:	finalpunctuation}', "");
Expect(1, 11810, '\p{^General_Category:	finalpunctuation}', "");
Expect(1, 11810, '\P{General_Category:	finalpunctuation}', "");
Expect(0, 11810, '\P{^General_Category:	finalpunctuation}', "");
Expect(1, 11809, '\p{General_Category=_	Final_Punctuation}', "");
Expect(0, 11809, '\p{^General_Category=_	Final_Punctuation}', "");
Expect(0, 11809, '\P{General_Category=_	Final_Punctuation}', "");
Expect(1, 11809, '\P{^General_Category=_	Final_Punctuation}', "");
Expect(0, 11810, '\p{General_Category=_	Final_Punctuation}', "");
Expect(1, 11810, '\p{^General_Category=_	Final_Punctuation}', "");
Expect(1, 11810, '\P{General_Category=_	Final_Punctuation}', "");
Expect(0, 11810, '\P{^General_Category=_	Final_Punctuation}', "");
Error('\p{Gc=_ Pf:=}');
Error('\P{Gc=_ Pf:=}');
Expect(1, 11809, '\p{Gc=pf}', "");
Expect(0, 11809, '\p{^Gc=pf}', "");
Expect(0, 11809, '\P{Gc=pf}', "");
Expect(1, 11809, '\P{^Gc=pf}', "");
Expect(0, 11810, '\p{Gc=pf}', "");
Expect(1, 11810, '\p{^Gc=pf}', "");
Expect(1, 11810, '\P{Gc=pf}', "");
Expect(0, 11810, '\P{^Gc=pf}', "");
Expect(1, 11809, '\p{Gc=_Pf}', "");
Expect(0, 11809, '\p{^Gc=_Pf}', "");
Expect(0, 11809, '\P{Gc=_Pf}', "");
Expect(1, 11809, '\P{^Gc=_Pf}', "");
Expect(0, 11810, '\p{Gc=_Pf}', "");
Expect(1, 11810, '\p{^Gc=_Pf}', "");
Expect(1, 11810, '\P{Gc=_Pf}', "");
Expect(0, 11810, '\P{^Gc=_Pf}', "");
Error('\p{Category=_:=final_Punctuation}');
Error('\P{Category=_:=final_Punctuation}');
Expect(1, 11809, '\p{Category=finalpunctuation}', "");
Expect(0, 11809, '\p{^Category=finalpunctuation}', "");
Expect(0, 11809, '\P{Category=finalpunctuation}', "");
Expect(1, 11809, '\P{^Category=finalpunctuation}', "");
Expect(0, 11810, '\p{Category=finalpunctuation}', "");
Expect(1, 11810, '\p{^Category=finalpunctuation}', "");
Expect(1, 11810, '\P{Category=finalpunctuation}', "");
Expect(0, 11810, '\P{^Category=finalpunctuation}', "");
Expect(1, 11809, '\p{Category=__final_punctuation}', "");
Expect(0, 11809, '\p{^Category=__final_punctuation}', "");
Expect(0, 11809, '\P{Category=__final_punctuation}', "");
Expect(1, 11809, '\P{^Category=__final_punctuation}', "");
Expect(0, 11810, '\p{Category=__final_punctuation}', "");
Expect(1, 11810, '\p{^Category=__final_punctuation}', "");
Expect(1, 11810, '\P{Category=__final_punctuation}', "");
Expect(0, 11810, '\P{^Category=__final_punctuation}', "");
Error('\p{Is_General_Category=-PF:=}');
Error('\P{Is_General_Category=-PF:=}');
Expect(1, 11809, '\p{Is_General_Category=pf}', "");
Expect(0, 11809, '\p{^Is_General_Category=pf}', "");
Expect(0, 11809, '\P{Is_General_Category=pf}', "");
Expect(1, 11809, '\P{^Is_General_Category=pf}', "");
Expect(0, 11810, '\p{Is_General_Category=pf}', "");
Expect(1, 11810, '\p{^Is_General_Category=pf}', "");
Expect(1, 11810, '\P{Is_General_Category=pf}', "");
Expect(0, 11810, '\P{^Is_General_Category=pf}', "");
Expect(1, 11809, '\p{Is_General_Category:   	 Pf}', "");
Expect(0, 11809, '\p{^Is_General_Category:   	 Pf}', "");
Expect(0, 11809, '\P{Is_General_Category:   	 Pf}', "");
Expect(1, 11809, '\P{^Is_General_Category:   	 Pf}', "");
Expect(0, 11810, '\p{Is_General_Category:   	 Pf}', "");
Expect(1, 11810, '\p{^Is_General_Category:   	 Pf}', "");
Expect(1, 11810, '\P{Is_General_Category:   	 Pf}', "");
Expect(0, 11810, '\P{^Is_General_Category:   	 Pf}', "");
Error('\p{Is_Gc: 	Final_Punctuation:=}');
Error('\P{Is_Gc: 	Final_Punctuation:=}');
Expect(1, 11809, '\p{Is_Gc=finalpunctuation}', "");
Expect(0, 11809, '\p{^Is_Gc=finalpunctuation}', "");
Expect(0, 11809, '\P{Is_Gc=finalpunctuation}', "");
Expect(1, 11809, '\P{^Is_Gc=finalpunctuation}', "");
Expect(0, 11810, '\p{Is_Gc=finalpunctuation}', "");
Expect(1, 11810, '\p{^Is_Gc=finalpunctuation}', "");
Expect(1, 11810, '\P{Is_Gc=finalpunctuation}', "");
Expect(0, 11810, '\P{^Is_Gc=finalpunctuation}', "");
Expect(1, 11809, '\p{Is_Gc=_	FINAL_punctuation}', "");
Expect(0, 11809, '\p{^Is_Gc=_	FINAL_punctuation}', "");
Expect(0, 11809, '\P{Is_Gc=_	FINAL_punctuation}', "");
Expect(1, 11809, '\P{^Is_Gc=_	FINAL_punctuation}', "");
Expect(0, 11810, '\p{Is_Gc=_	FINAL_punctuation}', "");
Expect(1, 11810, '\p{^Is_Gc=_	FINAL_punctuation}', "");
Expect(1, 11810, '\P{Is_Gc=_	FINAL_punctuation}', "");
Expect(0, 11810, '\P{^Is_Gc=_	FINAL_punctuation}', "");
Error('\p{Is_Category=:=Pf}');
Error('\P{Is_Category=:=Pf}');
Expect(1, 11809, '\p{Is_Category=pf}', "");
Expect(0, 11809, '\p{^Is_Category=pf}', "");
Expect(0, 11809, '\P{Is_Category=pf}', "");
Expect(1, 11809, '\P{^Is_Category=pf}', "");
Expect(0, 11810, '\p{Is_Category=pf}', "");
Expect(1, 11810, '\p{^Is_Category=pf}', "");
Expect(1, 11810, '\P{Is_Category=pf}', "");
Expect(0, 11810, '\P{^Is_Category=pf}', "");
Expect(1, 11809, '\p{Is_Category= pf}', "");
Expect(0, 11809, '\p{^Is_Category= pf}', "");
Expect(0, 11809, '\P{Is_Category= pf}', "");
Expect(1, 11809, '\P{^Is_Category= pf}', "");
Expect(0, 11810, '\p{Is_Category= pf}', "");
Expect(1, 11810, '\p{^Is_Category= pf}', "");
Expect(1, 11810, '\P{Is_Category= pf}', "");
Expect(0, 11810, '\P{^Is_Category= pf}', "");
Error('\p{General_Category=:=INITIAL_Punctuation}');
Error('\P{General_Category=:=INITIAL_Punctuation}');
Expect(1, 11808, '\p{General_Category=initialpunctuation}', "");
Expect(0, 11808, '\p{^General_Category=initialpunctuation}', "");
Expect(0, 11808, '\P{General_Category=initialpunctuation}', "");
Expect(1, 11808, '\P{^General_Category=initialpunctuation}', "");
Expect(0, 11809, '\p{General_Category=initialpunctuation}', "");
Expect(1, 11809, '\p{^General_Category=initialpunctuation}', "");
Expect(1, 11809, '\P{General_Category=initialpunctuation}', "");
Expect(0, 11809, '\P{^General_Category=initialpunctuation}', "");
Expect(1, 11808, '\p{General_Category=_	initial_Punctuation}', "");
Expect(0, 11808, '\p{^General_Category=_	initial_Punctuation}', "");
Expect(0, 11808, '\P{General_Category=_	initial_Punctuation}', "");
Expect(1, 11808, '\P{^General_Category=_	initial_Punctuation}', "");
Expect(0, 11809, '\p{General_Category=_	initial_Punctuation}', "");
Expect(1, 11809, '\p{^General_Category=_	initial_Punctuation}', "");
Expect(1, 11809, '\P{General_Category=_	initial_Punctuation}', "");
Expect(0, 11809, '\P{^General_Category=_	initial_Punctuation}', "");
Error('\p{Gc=/a/_Pi}');
Error('\P{Gc=/a/_Pi}');
Expect(1, 11808, '\p{Gc=pi}', "");
Expect(0, 11808, '\p{^Gc=pi}', "");
Expect(0, 11808, '\P{Gc=pi}', "");
Expect(1, 11808, '\P{^Gc=pi}', "");
Expect(0, 11809, '\p{Gc=pi}', "");
Expect(1, 11809, '\p{^Gc=pi}', "");
Expect(1, 11809, '\P{Gc=pi}', "");
Expect(0, 11809, '\P{^Gc=pi}', "");
Expect(1, 11808, '\p{Gc= 	Pi}', "");
Expect(0, 11808, '\p{^Gc= 	Pi}', "");
Expect(0, 11808, '\P{Gc= 	Pi}', "");
Expect(1, 11808, '\P{^Gc= 	Pi}', "");
Expect(0, 11809, '\p{Gc= 	Pi}', "");
Expect(1, 11809, '\p{^Gc= 	Pi}', "");
Expect(1, 11809, '\P{Gc= 	Pi}', "");
Expect(0, 11809, '\P{^Gc= 	Pi}', "");
Error('\p{Category=_-INITIAL_punctuation:=}');
Error('\P{Category=_-INITIAL_punctuation:=}');
Expect(1, 11808, '\p{Category=initialpunctuation}', "");
Expect(0, 11808, '\p{^Category=initialpunctuation}', "");
Expect(0, 11808, '\P{Category=initialpunctuation}', "");
Expect(1, 11808, '\P{^Category=initialpunctuation}', "");
Expect(0, 11809, '\p{Category=initialpunctuation}', "");
Expect(1, 11809, '\p{^Category=initialpunctuation}', "");
Expect(1, 11809, '\P{Category=initialpunctuation}', "");
Expect(0, 11809, '\P{^Category=initialpunctuation}', "");
Expect(1, 11808, '\p{Category=	 INITIAL_punctuation}', "");
Expect(0, 11808, '\p{^Category=	 INITIAL_punctuation}', "");
Expect(0, 11808, '\P{Category=	 INITIAL_punctuation}', "");
Expect(1, 11808, '\P{^Category=	 INITIAL_punctuation}', "");
Expect(0, 11809, '\p{Category=	 INITIAL_punctuation}', "");
Expect(1, 11809, '\p{^Category=	 INITIAL_punctuation}', "");
Expect(1, 11809, '\P{Category=	 INITIAL_punctuation}', "");
Expect(0, 11809, '\P{^Category=	 INITIAL_punctuation}', "");
Error('\p{Is_General_Category=/a/-Pi}');
Error('\P{Is_General_Category=/a/-Pi}');
Expect(1, 11808, '\p{Is_General_Category=pi}', "");
Expect(0, 11808, '\p{^Is_General_Category=pi}', "");
Expect(0, 11808, '\P{Is_General_Category=pi}', "");
Expect(1, 11808, '\P{^Is_General_Category=pi}', "");
Expect(0, 11809, '\p{Is_General_Category=pi}', "");
Expect(1, 11809, '\p{^Is_General_Category=pi}', "");
Expect(1, 11809, '\P{Is_General_Category=pi}', "");
Expect(0, 11809, '\P{^Is_General_Category=pi}', "");
Expect(1, 11808, '\p{Is_General_Category=	 PI}', "");
Expect(0, 11808, '\p{^Is_General_Category=	 PI}', "");
Expect(0, 11808, '\P{Is_General_Category=	 PI}', "");
Expect(1, 11808, '\P{^Is_General_Category=	 PI}', "");
Expect(0, 11809, '\p{Is_General_Category=	 PI}', "");
Expect(1, 11809, '\p{^Is_General_Category=	 PI}', "");
Expect(1, 11809, '\P{Is_General_Category=	 PI}', "");
Expect(0, 11809, '\P{^Is_General_Category=	 PI}', "");
Error('\p{Is_Gc= /a/Initial_Punctuation}');
Error('\P{Is_Gc= /a/Initial_Punctuation}');
Expect(1, 11808, '\p{Is_Gc=initialpunctuation}', "");
Expect(0, 11808, '\p{^Is_Gc=initialpunctuation}', "");
Expect(0, 11808, '\P{Is_Gc=initialpunctuation}', "");
Expect(1, 11808, '\P{^Is_Gc=initialpunctuation}', "");
Expect(0, 11809, '\p{Is_Gc=initialpunctuation}', "");
Expect(1, 11809, '\p{^Is_Gc=initialpunctuation}', "");
Expect(1, 11809, '\P{Is_Gc=initialpunctuation}', "");
Expect(0, 11809, '\P{^Is_Gc=initialpunctuation}', "");
Expect(1, 11808, '\p{Is_Gc:   		Initial_Punctuation}', "");
Expect(0, 11808, '\p{^Is_Gc:   		Initial_Punctuation}', "");
Expect(0, 11808, '\P{Is_Gc:   		Initial_Punctuation}', "");
Expect(1, 11808, '\P{^Is_Gc:   		Initial_Punctuation}', "");
Expect(0, 11809, '\p{Is_Gc:   		Initial_Punctuation}', "");
Expect(1, 11809, '\p{^Is_Gc:   		Initial_Punctuation}', "");
Expect(1, 11809, '\P{Is_Gc:   		Initial_Punctuation}', "");
Expect(0, 11809, '\P{^Is_Gc:   		Initial_Punctuation}', "");
Error('\p{Is_Category= Pi/a/}');
Error('\P{Is_Category= Pi/a/}');
Expect(1, 11808, '\p{Is_Category:   pi}', "");
Expect(0, 11808, '\p{^Is_Category:   pi}', "");
Expect(0, 11808, '\P{Is_Category:   pi}', "");
Expect(1, 11808, '\P{^Is_Category:   pi}', "");
Expect(0, 11809, '\p{Is_Category:   pi}', "");
Expect(1, 11809, '\p{^Is_Category:   pi}', "");
Expect(1, 11809, '\P{Is_Category:   pi}', "");
Expect(0, 11809, '\P{^Is_Category:   pi}', "");
Expect(1, 11808, '\p{Is_Category=-_Pi}', "");
Expect(0, 11808, '\p{^Is_Category=-_Pi}', "");
Expect(0, 11808, '\P{Is_Category=-_Pi}', "");
Expect(1, 11808, '\P{^Is_Category=-_Pi}', "");
Expect(0, 11809, '\p{Is_Category=-_Pi}', "");
Expect(1, 11809, '\p{^Is_Category=-_Pi}', "");
Expect(1, 11809, '\P{Is_Category=-_Pi}', "");
Expect(0, 11809, '\P{^Is_Category=-_Pi}', "");
Error('\p{General_Category:   :=other_punctuation}');
Error('\P{General_Category:   :=other_punctuation}');
Expect(1, 74867, '\p{General_Category=otherpunctuation}', "");
Expect(0, 74867, '\p{^General_Category=otherpunctuation}', "");
Expect(0, 74867, '\P{General_Category=otherpunctuation}', "");
Expect(1, 74867, '\P{^General_Category=otherpunctuation}', "");
Expect(0, 74868, '\p{General_Category=otherpunctuation}', "");
Expect(1, 74868, '\p{^General_Category=otherpunctuation}', "");
Expect(1, 74868, '\P{General_Category=otherpunctuation}', "");
Expect(0, 74868, '\P{^General_Category=otherpunctuation}', "");
Expect(1, 74867, '\p{General_Category=--OTHER_punctuation}', "");
Expect(0, 74867, '\p{^General_Category=--OTHER_punctuation}', "");
Expect(0, 74867, '\P{General_Category=--OTHER_punctuation}', "");
Expect(1, 74867, '\P{^General_Category=--OTHER_punctuation}', "");
Expect(0, 74868, '\p{General_Category=--OTHER_punctuation}', "");
Expect(1, 74868, '\p{^General_Category=--OTHER_punctuation}', "");
Expect(1, 74868, '\P{General_Category=--OTHER_punctuation}', "");
Expect(0, 74868, '\P{^General_Category=--OTHER_punctuation}', "");
Error('\p{Gc=-/a/Po}');
Error('\P{Gc=-/a/Po}');
Expect(1, 74867, '\p{Gc=po}', "");
Expect(0, 74867, '\p{^Gc=po}', "");
Expect(0, 74867, '\P{Gc=po}', "");
Expect(1, 74867, '\P{^Gc=po}', "");
Expect(0, 74868, '\p{Gc=po}', "");
Expect(1, 74868, '\p{^Gc=po}', "");
Expect(1, 74868, '\P{Gc=po}', "");
Expect(0, 74868, '\P{^Gc=po}', "");
Expect(1, 74867, '\p{Gc:			Po}', "");
Expect(0, 74867, '\p{^Gc:			Po}', "");
Expect(0, 74867, '\P{Gc:			Po}', "");
Expect(1, 74867, '\P{^Gc:			Po}', "");
Expect(0, 74868, '\p{Gc:			Po}', "");
Expect(1, 74868, '\p{^Gc:			Po}', "");
Expect(1, 74868, '\P{Gc:			Po}', "");
Expect(0, 74868, '\P{^Gc:			Po}', "");
Error('\p{Category=_ other_Punctuation:=}');
Error('\P{Category=_ other_Punctuation:=}');
Expect(1, 74867, '\p{Category: otherpunctuation}', "");
Expect(0, 74867, '\p{^Category: otherpunctuation}', "");
Expect(0, 74867, '\P{Category: otherpunctuation}', "");
Expect(1, 74867, '\P{^Category: otherpunctuation}', "");
Expect(0, 74868, '\p{Category: otherpunctuation}', "");
Expect(1, 74868, '\p{^Category: otherpunctuation}', "");
Expect(1, 74868, '\P{Category: otherpunctuation}', "");
Expect(0, 74868, '\P{^Category: otherpunctuation}', "");
Expect(1, 74867, '\p{Category=	Other_punctuation}', "");
Expect(0, 74867, '\p{^Category=	Other_punctuation}', "");
Expect(0, 74867, '\P{Category=	Other_punctuation}', "");
Expect(1, 74867, '\P{^Category=	Other_punctuation}', "");
Expect(0, 74868, '\p{Category=	Other_punctuation}', "");
Expect(1, 74868, '\p{^Category=	Other_punctuation}', "");
Expect(1, 74868, '\P{Category=	Other_punctuation}', "");
Expect(0, 74868, '\P{^Category=	Other_punctuation}', "");
Error('\p{Is_General_Category=/a/	 Po}');
Error('\P{Is_General_Category=/a/	 Po}');
Expect(1, 74867, '\p{Is_General_Category=po}', "");
Expect(0, 74867, '\p{^Is_General_Category=po}', "");
Expect(0, 74867, '\P{Is_General_Category=po}', "");
Expect(1, 74867, '\P{^Is_General_Category=po}', "");
Expect(0, 74868, '\p{Is_General_Category=po}', "");
Expect(1, 74868, '\p{^Is_General_Category=po}', "");
Expect(1, 74868, '\P{Is_General_Category=po}', "");
Expect(0, 74868, '\P{^Is_General_Category=po}', "");
Expect(1, 74867, '\p{Is_General_Category=-	Po}', "");
Expect(0, 74867, '\p{^Is_General_Category=-	Po}', "");
Expect(0, 74867, '\P{Is_General_Category=-	Po}', "");
Expect(1, 74867, '\P{^Is_General_Category=-	Po}', "");
Expect(0, 74868, '\p{Is_General_Category=-	Po}', "");
Expect(1, 74868, '\p{^Is_General_Category=-	Po}', "");
Expect(1, 74868, '\P{Is_General_Category=-	Po}', "");
Expect(0, 74868, '\P{^Is_General_Category=-	Po}', "");
Error('\p{Is_Gc=:=	Other_punctuation}');
Error('\P{Is_Gc=:=	Other_punctuation}');
Expect(1, 74867, '\p{Is_Gc=otherpunctuation}', "");
Expect(0, 74867, '\p{^Is_Gc=otherpunctuation}', "");
Expect(0, 74867, '\P{Is_Gc=otherpunctuation}', "");
Expect(1, 74867, '\P{^Is_Gc=otherpunctuation}', "");
Expect(0, 74868, '\p{Is_Gc=otherpunctuation}', "");
Expect(1, 74868, '\p{^Is_Gc=otherpunctuation}', "");
Expect(1, 74868, '\P{Is_Gc=otherpunctuation}', "");
Expect(0, 74868, '\P{^Is_Gc=otherpunctuation}', "");
Expect(1, 74867, '\p{Is_Gc=-_Other_punctuation}', "");
Expect(0, 74867, '\p{^Is_Gc=-_Other_punctuation}', "");
Expect(0, 74867, '\P{Is_Gc=-_Other_punctuation}', "");
Expect(1, 74867, '\P{^Is_Gc=-_Other_punctuation}', "");
Expect(0, 74868, '\p{Is_Gc=-_Other_punctuation}', "");
Expect(1, 74868, '\p{^Is_Gc=-_Other_punctuation}', "");
Expect(1, 74868, '\P{Is_Gc=-_Other_punctuation}', "");
Expect(0, 74868, '\P{^Is_Gc=-_Other_punctuation}', "");
Error('\p{Is_Category=:=-PO}');
Error('\P{Is_Category=:=-PO}');
Expect(1, 74867, '\p{Is_Category=po}', "");
Expect(0, 74867, '\p{^Is_Category=po}', "");
Expect(0, 74867, '\P{Is_Category=po}', "");
Expect(1, 74867, '\P{^Is_Category=po}', "");
Expect(0, 74868, '\p{Is_Category=po}', "");
Expect(1, 74868, '\p{^Is_Category=po}', "");
Expect(1, 74868, '\P{Is_Category=po}', "");
Expect(0, 74868, '\P{^Is_Category=po}', "");
Expect(1, 74867, '\p{Is_Category=_-Po}', "");
Expect(0, 74867, '\p{^Is_Category=_-Po}', "");
Expect(0, 74867, '\P{Is_Category=_-Po}', "");
Expect(1, 74867, '\P{^Is_Category=_-Po}', "");
Expect(0, 74868, '\p{Is_Category=_-Po}', "");
Expect(1, 74868, '\p{^Is_Category=_-Po}', "");
Expect(1, 74868, '\P{Is_Category=_-Po}', "");
Expect(0, 74868, '\P{^Is_Category=_-Po}', "");
Error('\p{General_Category= -OPEN_PUNCTUATION:=}');
Error('\P{General_Category= -OPEN_PUNCTUATION:=}');
Expect(1, 65378, '\p{General_Category=openpunctuation}', "");
Expect(0, 65378, '\p{^General_Category=openpunctuation}', "");
Expect(0, 65378, '\P{General_Category=openpunctuation}', "");
Expect(1, 65378, '\P{^General_Category=openpunctuation}', "");
Expect(0, 65379, '\p{General_Category=openpunctuation}', "");
Expect(1, 65379, '\p{^General_Category=openpunctuation}', "");
Expect(1, 65379, '\P{General_Category=openpunctuation}', "");
Expect(0, 65379, '\P{^General_Category=openpunctuation}', "");
Expect(1, 65378, '\p{General_Category=_	Open_Punctuation}', "");
Expect(0, 65378, '\p{^General_Category=_	Open_Punctuation}', "");
Expect(0, 65378, '\P{General_Category=_	Open_Punctuation}', "");
Expect(1, 65378, '\P{^General_Category=_	Open_Punctuation}', "");
Expect(0, 65379, '\p{General_Category=_	Open_Punctuation}', "");
Expect(1, 65379, '\p{^General_Category=_	Open_Punctuation}', "");
Expect(1, 65379, '\P{General_Category=_	Open_Punctuation}', "");
Expect(0, 65379, '\P{^General_Category=_	Open_Punctuation}', "");
Error('\p{Gc=	_ps/a/}');
Error('\P{Gc=	_ps/a/}');
Expect(1, 65378, '\p{Gc=ps}', "");
Expect(0, 65378, '\p{^Gc=ps}', "");
Expect(0, 65378, '\P{Gc=ps}', "");
Expect(1, 65378, '\P{^Gc=ps}', "");
Expect(0, 65379, '\p{Gc=ps}', "");
Expect(1, 65379, '\p{^Gc=ps}', "");
Expect(1, 65379, '\P{Gc=ps}', "");
Expect(0, 65379, '\P{^Gc=ps}', "");
Expect(1, 65378, '\p{Gc:   _PS}', "");
Expect(0, 65378, '\p{^Gc:   _PS}', "");
Expect(0, 65378, '\P{Gc:   _PS}', "");
Expect(1, 65378, '\P{^Gc:   _PS}', "");
Expect(0, 65379, '\p{Gc:   _PS}', "");
Expect(1, 65379, '\p{^Gc:   _PS}', "");
Expect(1, 65379, '\P{Gc:   _PS}', "");
Expect(0, 65379, '\P{^Gc:   _PS}', "");
Error('\p{Category=	/a/Open_PUNCTUATION}');
Error('\P{Category=	/a/Open_PUNCTUATION}');
Expect(1, 65378, '\p{Category=openpunctuation}', "");
Expect(0, 65378, '\p{^Category=openpunctuation}', "");
Expect(0, 65378, '\P{Category=openpunctuation}', "");
Expect(1, 65378, '\P{^Category=openpunctuation}', "");
Expect(0, 65379, '\p{Category=openpunctuation}', "");
Expect(1, 65379, '\p{^Category=openpunctuation}', "");
Expect(1, 65379, '\P{Category=openpunctuation}', "");
Expect(0, 65379, '\P{^Category=openpunctuation}', "");
Expect(1, 65378, '\p{Category=_ Open_PUNCTUATION}', "");
Expect(0, 65378, '\p{^Category=_ Open_PUNCTUATION}', "");
Expect(0, 65378, '\P{Category=_ Open_PUNCTUATION}', "");
Expect(1, 65378, '\P{^Category=_ Open_PUNCTUATION}', "");
Expect(0, 65379, '\p{Category=_ Open_PUNCTUATION}', "");
Expect(1, 65379, '\p{^Category=_ Open_PUNCTUATION}', "");
Expect(1, 65379, '\P{Category=_ Open_PUNCTUATION}', "");
Expect(0, 65379, '\P{^Category=_ Open_PUNCTUATION}', "");
Error('\p{Is_General_Category=:=-_PS}');
Error('\P{Is_General_Category=:=-_PS}');
Expect(1, 65378, '\p{Is_General_Category=ps}', "");
Expect(0, 65378, '\p{^Is_General_Category=ps}', "");
Expect(0, 65378, '\P{Is_General_Category=ps}', "");
Expect(1, 65378, '\P{^Is_General_Category=ps}', "");
Expect(0, 65379, '\p{Is_General_Category=ps}', "");
Expect(1, 65379, '\p{^Is_General_Category=ps}', "");
Expect(1, 65379, '\P{Is_General_Category=ps}', "");
Expect(0, 65379, '\P{^Is_General_Category=ps}', "");
Expect(1, 65378, '\p{Is_General_Category=__ps}', "");
Expect(0, 65378, '\p{^Is_General_Category=__ps}', "");
Expect(0, 65378, '\P{Is_General_Category=__ps}', "");
Expect(1, 65378, '\P{^Is_General_Category=__ps}', "");
Expect(0, 65379, '\p{Is_General_Category=__ps}', "");
Expect(1, 65379, '\p{^Is_General_Category=__ps}', "");
Expect(1, 65379, '\P{Is_General_Category=__ps}', "");
Expect(0, 65379, '\P{^Is_General_Category=__ps}', "");
Error('\p{Is_Gc= -Open_punctuation:=}');
Error('\P{Is_Gc= -Open_punctuation:=}');
Expect(1, 65378, '\p{Is_Gc=openpunctuation}', "");
Expect(0, 65378, '\p{^Is_Gc=openpunctuation}', "");
Expect(0, 65378, '\P{Is_Gc=openpunctuation}', "");
Expect(1, 65378, '\P{^Is_Gc=openpunctuation}', "");
Expect(0, 65379, '\p{Is_Gc=openpunctuation}', "");
Expect(1, 65379, '\p{^Is_Gc=openpunctuation}', "");
Expect(1, 65379, '\P{Is_Gc=openpunctuation}', "");
Expect(0, 65379, '\P{^Is_Gc=openpunctuation}', "");
Expect(1, 65378, '\p{Is_Gc=	 OPEN_Punctuation}', "");
Expect(0, 65378, '\p{^Is_Gc=	 OPEN_Punctuation}', "");
Expect(0, 65378, '\P{Is_Gc=	 OPEN_Punctuation}', "");
Expect(1, 65378, '\P{^Is_Gc=	 OPEN_Punctuation}', "");
Expect(0, 65379, '\p{Is_Gc=	 OPEN_Punctuation}', "");
Expect(1, 65379, '\p{^Is_Gc=	 OPEN_Punctuation}', "");
Expect(1, 65379, '\P{Is_Gc=	 OPEN_Punctuation}', "");
Expect(0, 65379, '\P{^Is_Gc=	 OPEN_Punctuation}', "");
Error('\p{Is_Category=	_PS/a/}');
Error('\P{Is_Category=	_PS/a/}');
Expect(1, 65378, '\p{Is_Category=ps}', "");
Expect(0, 65378, '\p{^Is_Category=ps}', "");
Expect(0, 65378, '\P{Is_Category=ps}', "");
Expect(1, 65378, '\P{^Is_Category=ps}', "");
Expect(0, 65379, '\p{Is_Category=ps}', "");
Expect(1, 65379, '\p{^Is_Category=ps}', "");
Expect(1, 65379, '\P{Is_Category=ps}', "");
Expect(0, 65379, '\P{^Is_Category=ps}', "");
Expect(1, 65378, '\p{Is_Category=	ps}', "");
Expect(0, 65378, '\p{^Is_Category=	ps}', "");
Expect(0, 65378, '\P{Is_Category=	ps}', "");
Expect(1, 65378, '\P{^Is_Category=	ps}', "");
Expect(0, 65379, '\p{Is_Category=	ps}', "");
Expect(1, 65379, '\p{^Is_Category=	ps}', "");
Expect(1, 65379, '\P{Is_Category=	ps}', "");
Expect(0, 65379, '\P{^Is_Category=	ps}', "");
Error('\p{General_Category=	Symbol/a/}');
Error('\P{General_Category=	Symbol/a/}');
Expect(1, 128883, '\p{General_Category=symbol}', "");
Expect(0, 128883, '\p{^General_Category=symbol}', "");
Expect(0, 128883, '\P{General_Category=symbol}', "");
Expect(1, 128883, '\P{^General_Category=symbol}', "");
Expect(0, 128884, '\p{General_Category=symbol}', "");
Expect(1, 128884, '\p{^General_Category=symbol}', "");
Expect(1, 128884, '\P{General_Category=symbol}', "");
Expect(0, 128884, '\P{^General_Category=symbol}', "");
Expect(1, 128883, '\p{General_Category=	_Symbol}', "");
Expect(0, 128883, '\p{^General_Category=	_Symbol}', "");
Expect(0, 128883, '\P{General_Category=	_Symbol}', "");
Expect(1, 128883, '\P{^General_Category=	_Symbol}', "");
Expect(0, 128884, '\p{General_Category=	_Symbol}', "");
Expect(1, 128884, '\p{^General_Category=	_Symbol}', "");
Expect(1, 128884, '\P{General_Category=	_Symbol}', "");
Expect(0, 128884, '\P{^General_Category=	_Symbol}', "");
Error('\p{Gc:  :=s}');
Error('\P{Gc:  :=s}');
Expect(1, 128883, '\p{Gc=s}', "");
Expect(0, 128883, '\p{^Gc=s}', "");
Expect(0, 128883, '\P{Gc=s}', "");
Expect(1, 128883, '\P{^Gc=s}', "");
Expect(0, 128884, '\p{Gc=s}', "");
Expect(1, 128884, '\p{^Gc=s}', "");
Expect(1, 128884, '\P{Gc=s}', "");
Expect(0, 128884, '\P{^Gc=s}', "");
Expect(1, 128883, '\p{Gc=--S}', "");
Expect(0, 128883, '\p{^Gc=--S}', "");
Expect(0, 128883, '\P{Gc=--S}', "");
Expect(1, 128883, '\P{^Gc=--S}', "");
Expect(0, 128884, '\p{Gc=--S}', "");
Expect(1, 128884, '\p{^Gc=--S}', "");
Expect(1, 128884, '\P{Gc=--S}', "");
Expect(0, 128884, '\P{^Gc=--S}', "");
Error('\p{Category=/a/Symbol}');
Error('\P{Category=/a/Symbol}');
Expect(1, 128883, '\p{Category=symbol}', "");
Expect(0, 128883, '\p{^Category=symbol}', "");
Expect(0, 128883, '\P{Category=symbol}', "");
Expect(1, 128883, '\P{^Category=symbol}', "");
Expect(0, 128884, '\p{Category=symbol}', "");
Expect(1, 128884, '\p{^Category=symbol}', "");
Expect(1, 128884, '\P{Category=symbol}', "");
Expect(0, 128884, '\P{^Category=symbol}', "");
Expect(1, 128883, '\p{Category:   Symbol}', "");
Expect(0, 128883, '\p{^Category:   Symbol}', "");
Expect(0, 128883, '\P{Category:   Symbol}', "");
Expect(1, 128883, '\P{^Category:   Symbol}', "");
Expect(0, 128884, '\p{Category:   Symbol}', "");
Expect(1, 128884, '\p{^Category:   Symbol}', "");
Expect(1, 128884, '\P{Category:   Symbol}', "");
Expect(0, 128884, '\P{^Category:   Symbol}', "");
Error('\p{Is_General_Category=_-s/a/}');
Error('\P{Is_General_Category=_-s/a/}');
Expect(1, 128883, '\p{Is_General_Category=s}', "");
Expect(0, 128883, '\p{^Is_General_Category=s}', "");
Expect(0, 128883, '\P{Is_General_Category=s}', "");
Expect(1, 128883, '\P{^Is_General_Category=s}', "");
Expect(0, 128884, '\p{Is_General_Category=s}', "");
Expect(1, 128884, '\p{^Is_General_Category=s}', "");
Expect(1, 128884, '\P{Is_General_Category=s}', "");
Expect(0, 128884, '\P{^Is_General_Category=s}', "");
Error('\p{Is_Gc=/a/Symbol}');
Error('\P{Is_Gc=/a/Symbol}');
Expect(1, 128883, '\p{Is_Gc:	symbol}', "");
Expect(0, 128883, '\p{^Is_Gc:	symbol}', "");
Expect(0, 128883, '\P{Is_Gc:	symbol}', "");
Expect(1, 128883, '\P{^Is_Gc:	symbol}', "");
Expect(0, 128884, '\p{Is_Gc:	symbol}', "");
Expect(1, 128884, '\p{^Is_Gc:	symbol}', "");
Expect(1, 128884, '\P{Is_Gc:	symbol}', "");
Expect(0, 128884, '\P{^Is_Gc:	symbol}', "");
Expect(1, 128883, '\p{Is_Gc=	 Symbol}', "");
Expect(0, 128883, '\p{^Is_Gc=	 Symbol}', "");
Expect(0, 128883, '\P{Is_Gc=	 Symbol}', "");
Expect(1, 128883, '\P{^Is_Gc=	 Symbol}', "");
Expect(0, 128884, '\p{Is_Gc=	 Symbol}', "");
Expect(1, 128884, '\p{^Is_Gc=	 Symbol}', "");
Expect(1, 128884, '\P{Is_Gc=	 Symbol}', "");
Expect(0, 128884, '\P{^Is_Gc=	 Symbol}', "");
Error('\p{Is_Category=:=-_S}');
Error('\P{Is_Category=:=-_S}');
Expect(1, 128883, '\p{Is_Category=s}', "");
Expect(0, 128883, '\p{^Is_Category=s}', "");
Expect(0, 128883, '\P{Is_Category=s}', "");
Expect(1, 128883, '\P{^Is_Category=s}', "");
Expect(0, 128884, '\p{Is_Category=s}', "");
Expect(1, 128884, '\p{^Is_Category=s}', "");
Expect(1, 128884, '\P{Is_Category=s}', "");
Expect(0, 128884, '\P{^Is_Category=s}', "");
Expect(1, 128883, '\p{Is_Category=- S}', "");
Expect(0, 128883, '\p{^Is_Category=- S}', "");
Expect(0, 128883, '\P{Is_Category=- S}', "");
Expect(1, 128883, '\P{^Is_Category=- S}', "");
Expect(0, 128884, '\p{Is_Category=- S}', "");
Expect(1, 128884, '\p{^Is_Category=- S}', "");
Expect(1, 128884, '\P{Is_Category=- S}', "");
Expect(0, 128884, '\P{^Is_Category=- S}', "");
Error('\p{General_Category=	/a/currency_symbol}');
Error('\P{General_Category=	/a/currency_symbol}');
Expect(1, 65510, '\p{General_Category=currencysymbol}', "");
Expect(0, 65510, '\p{^General_Category=currencysymbol}', "");
Expect(0, 65510, '\P{General_Category=currencysymbol}', "");
Expect(1, 65510, '\P{^General_Category=currencysymbol}', "");
Expect(0, 65511, '\p{General_Category=currencysymbol}', "");
Expect(1, 65511, '\p{^General_Category=currencysymbol}', "");
Expect(1, 65511, '\P{General_Category=currencysymbol}', "");
Expect(0, 65511, '\P{^General_Category=currencysymbol}', "");
Expect(1, 65510, '\p{General_Category=_ Currency_Symbol}', "");
Expect(0, 65510, '\p{^General_Category=_ Currency_Symbol}', "");
Expect(0, 65510, '\P{General_Category=_ Currency_Symbol}', "");
Expect(1, 65510, '\P{^General_Category=_ Currency_Symbol}', "");
Expect(0, 65511, '\p{General_Category=_ Currency_Symbol}', "");
Expect(1, 65511, '\p{^General_Category=_ Currency_Symbol}', "");
Expect(1, 65511, '\P{General_Category=_ Currency_Symbol}', "");
Expect(0, 65511, '\P{^General_Category=_ Currency_Symbol}', "");
Error('\p{Gc=-SC/a/}');
Error('\P{Gc=-SC/a/}');
Expect(1, 65510, '\p{Gc=sc}', "");
Expect(0, 65510, '\p{^Gc=sc}', "");
Expect(0, 65510, '\P{Gc=sc}', "");
Expect(1, 65510, '\P{^Gc=sc}', "");
Expect(0, 65511, '\p{Gc=sc}', "");
Expect(1, 65511, '\p{^Gc=sc}', "");
Expect(1, 65511, '\P{Gc=sc}', "");
Expect(0, 65511, '\P{^Gc=sc}', "");
Expect(1, 65510, '\p{Gc=_-Sc}', "");
Expect(0, 65510, '\p{^Gc=_-Sc}', "");
Expect(0, 65510, '\P{Gc=_-Sc}', "");
Expect(1, 65510, '\P{^Gc=_-Sc}', "");
Expect(0, 65511, '\p{Gc=_-Sc}', "");
Expect(1, 65511, '\p{^Gc=_-Sc}', "");
Expect(1, 65511, '\P{Gc=_-Sc}', "");
Expect(0, 65511, '\P{^Gc=_-Sc}', "");
Error('\p{Category=- Currency_Symbol/a/}');
Error('\P{Category=- Currency_Symbol/a/}');
Expect(1, 65510, '\p{Category=currencysymbol}', "");
Expect(0, 65510, '\p{^Category=currencysymbol}', "");
Expect(0, 65510, '\P{Category=currencysymbol}', "");
Expect(1, 65510, '\P{^Category=currencysymbol}', "");
Expect(0, 65511, '\p{Category=currencysymbol}', "");
Expect(1, 65511, '\p{^Category=currencysymbol}', "");
Expect(1, 65511, '\P{Category=currencysymbol}', "");
Expect(0, 65511, '\P{^Category=currencysymbol}', "");
Expect(1, 65510, '\p{Category=	CURRENCY_symbol}', "");
Expect(0, 65510, '\p{^Category=	CURRENCY_symbol}', "");
Expect(0, 65510, '\P{Category=	CURRENCY_symbol}', "");
Expect(1, 65510, '\P{^Category=	CURRENCY_symbol}', "");
Expect(0, 65511, '\p{Category=	CURRENCY_symbol}', "");
Expect(1, 65511, '\p{^Category=	CURRENCY_symbol}', "");
Expect(1, 65511, '\P{Category=	CURRENCY_symbol}', "");
Expect(0, 65511, '\P{^Category=	CURRENCY_symbol}', "");
Error('\p{Is_General_Category=/a/_SC}');
Error('\P{Is_General_Category=/a/_SC}');
Expect(1, 65510, '\p{Is_General_Category:	sc}', "");
Expect(0, 65510, '\p{^Is_General_Category:	sc}', "");
Expect(0, 65510, '\P{Is_General_Category:	sc}', "");
Expect(1, 65510, '\P{^Is_General_Category:	sc}', "");
Expect(0, 65511, '\p{Is_General_Category:	sc}', "");
Expect(1, 65511, '\p{^Is_General_Category:	sc}', "");
Expect(1, 65511, '\P{Is_General_Category:	sc}', "");
Expect(0, 65511, '\P{^Is_General_Category:	sc}', "");
Expect(1, 65510, '\p{Is_General_Category=_sc}', "");
Expect(0, 65510, '\p{^Is_General_Category=_sc}', "");
Expect(0, 65510, '\P{Is_General_Category=_sc}', "");
Expect(1, 65510, '\P{^Is_General_Category=_sc}', "");
Expect(0, 65511, '\p{Is_General_Category=_sc}', "");
Expect(1, 65511, '\p{^Is_General_Category=_sc}', "");
Expect(1, 65511, '\P{Is_General_Category=_sc}', "");
Expect(0, 65511, '\P{^Is_General_Category=_sc}', "");
Error('\p{Is_Gc= :=currency_symbol}');
Error('\P{Is_Gc= :=currency_symbol}');
Expect(1, 65510, '\p{Is_Gc=currencysymbol}', "");
Expect(0, 65510, '\p{^Is_Gc=currencysymbol}', "");
Expect(0, 65510, '\P{Is_Gc=currencysymbol}', "");
Expect(1, 65510, '\P{^Is_Gc=currencysymbol}', "");
Expect(0, 65511, '\p{Is_Gc=currencysymbol}', "");
Expect(1, 65511, '\p{^Is_Gc=currencysymbol}', "");
Expect(1, 65511, '\P{Is_Gc=currencysymbol}', "");
Expect(0, 65511, '\P{^Is_Gc=currencysymbol}', "");
Expect(1, 65510, '\p{Is_Gc=_ Currency_Symbol}', "");
Expect(0, 65510, '\p{^Is_Gc=_ Currency_Symbol}', "");
Expect(0, 65510, '\P{Is_Gc=_ Currency_Symbol}', "");
Expect(1, 65510, '\P{^Is_Gc=_ Currency_Symbol}', "");
Expect(0, 65511, '\p{Is_Gc=_ Currency_Symbol}', "");
Expect(1, 65511, '\p{^Is_Gc=_ Currency_Symbol}', "");
Expect(1, 65511, '\P{Is_Gc=_ Currency_Symbol}', "");
Expect(0, 65511, '\P{^Is_Gc=_ Currency_Symbol}', "");
Error('\p{Is_Category=:=-Sc}');
Error('\P{Is_Category=:=-Sc}');
Expect(1, 65510, '\p{Is_Category: sc}', "");
Expect(0, 65510, '\p{^Is_Category: sc}', "");
Expect(0, 65510, '\P{Is_Category: sc}', "");
Expect(1, 65510, '\P{^Is_Category: sc}', "");
Expect(0, 65511, '\p{Is_Category: sc}', "");
Expect(1, 65511, '\p{^Is_Category: sc}', "");
Expect(1, 65511, '\P{Is_Category: sc}', "");
Expect(0, 65511, '\P{^Is_Category: sc}', "");
Expect(1, 65510, '\p{Is_Category= _SC}', "");
Expect(0, 65510, '\p{^Is_Category= _SC}', "");
Expect(0, 65510, '\P{Is_Category= _SC}', "");
Expect(1, 65510, '\P{^Is_Category= _SC}', "");
Expect(0, 65511, '\p{Is_Category= _SC}', "");
Expect(1, 65511, '\p{^Is_Category= _SC}', "");
Expect(1, 65511, '\P{Is_Category= _SC}', "");
Expect(0, 65511, '\P{^Is_Category= _SC}', "");
Error('\p{General_Category=-Modifier_Symbol/a/}');
Error('\P{General_Category=-Modifier_Symbol/a/}');
Expect(1, 65507, '\p{General_Category=modifiersymbol}', "");
Expect(0, 65507, '\p{^General_Category=modifiersymbol}', "");
Expect(0, 65507, '\P{General_Category=modifiersymbol}', "");
Expect(1, 65507, '\P{^General_Category=modifiersymbol}', "");
Expect(0, 65508, '\p{General_Category=modifiersymbol}', "");
Expect(1, 65508, '\p{^General_Category=modifiersymbol}', "");
Expect(1, 65508, '\P{General_Category=modifiersymbol}', "");
Expect(0, 65508, '\P{^General_Category=modifiersymbol}', "");
Expect(1, 65507, '\p{General_Category=	-Modifier_Symbol}', "");
Expect(0, 65507, '\p{^General_Category=	-Modifier_Symbol}', "");
Expect(0, 65507, '\P{General_Category=	-Modifier_Symbol}', "");
Expect(1, 65507, '\P{^General_Category=	-Modifier_Symbol}', "");
Expect(0, 65508, '\p{General_Category=	-Modifier_Symbol}', "");
Expect(1, 65508, '\p{^General_Category=	-Modifier_Symbol}', "");
Expect(1, 65508, '\P{General_Category=	-Modifier_Symbol}', "");
Expect(0, 65508, '\P{^General_Category=	-Modifier_Symbol}', "");
Error('\p{Gc=:= Sk}');
Error('\P{Gc=:= Sk}');
Expect(1, 65507, '\p{Gc=sk}', "");
Expect(0, 65507, '\p{^Gc=sk}', "");
Expect(0, 65507, '\P{Gc=sk}', "");
Expect(1, 65507, '\P{^Gc=sk}', "");
Expect(0, 65508, '\p{Gc=sk}', "");
Expect(1, 65508, '\p{^Gc=sk}', "");
Expect(1, 65508, '\P{Gc=sk}', "");
Expect(0, 65508, '\P{^Gc=sk}', "");
Expect(1, 65507, '\p{Gc: 	 SK}', "");
Expect(0, 65507, '\p{^Gc: 	 SK}', "");
Expect(0, 65507, '\P{Gc: 	 SK}', "");
Expect(1, 65507, '\P{^Gc: 	 SK}', "");
Expect(0, 65508, '\p{Gc: 	 SK}', "");
Expect(1, 65508, '\p{^Gc: 	 SK}', "");
Expect(1, 65508, '\P{Gc: 	 SK}', "");
Expect(0, 65508, '\P{^Gc: 	 SK}', "");
Error('\p{Category=-:=Modifier_SYMBOL}');
Error('\P{Category=-:=Modifier_SYMBOL}');
Expect(1, 65507, '\p{Category=modifiersymbol}', "");
Expect(0, 65507, '\p{^Category=modifiersymbol}', "");
Expect(0, 65507, '\P{Category=modifiersymbol}', "");
Expect(1, 65507, '\P{^Category=modifiersymbol}', "");
Expect(0, 65508, '\p{Category=modifiersymbol}', "");
Expect(1, 65508, '\p{^Category=modifiersymbol}', "");
Expect(1, 65508, '\P{Category=modifiersymbol}', "");
Expect(0, 65508, '\P{^Category=modifiersymbol}', "");
Expect(1, 65507, '\p{Category=	 MODIFIER_Symbol}', "");
Expect(0, 65507, '\p{^Category=	 MODIFIER_Symbol}', "");
Expect(0, 65507, '\P{Category=	 MODIFIER_Symbol}', "");
Expect(1, 65507, '\P{^Category=	 MODIFIER_Symbol}', "");
Expect(0, 65508, '\p{Category=	 MODIFIER_Symbol}', "");
Expect(1, 65508, '\p{^Category=	 MODIFIER_Symbol}', "");
Expect(1, 65508, '\P{Category=	 MODIFIER_Symbol}', "");
Expect(0, 65508, '\P{^Category=	 MODIFIER_Symbol}', "");
Error('\p{Is_General_Category=:= _SK}');
Error('\P{Is_General_Category=:= _SK}');
Expect(1, 65507, '\p{Is_General_Category=sk}', "");
Expect(0, 65507, '\p{^Is_General_Category=sk}', "");
Expect(0, 65507, '\P{Is_General_Category=sk}', "");
Expect(1, 65507, '\P{^Is_General_Category=sk}', "");
Expect(0, 65508, '\p{Is_General_Category=sk}', "");
Expect(1, 65508, '\p{^Is_General_Category=sk}', "");
Expect(1, 65508, '\P{Is_General_Category=sk}', "");
Expect(0, 65508, '\P{^Is_General_Category=sk}', "");
Expect(1, 65507, '\p{Is_General_Category= 	Sk}', "");
Expect(0, 65507, '\p{^Is_General_Category= 	Sk}', "");
Expect(0, 65507, '\P{Is_General_Category= 	Sk}', "");
Expect(1, 65507, '\P{^Is_General_Category= 	Sk}', "");
Expect(0, 65508, '\p{Is_General_Category= 	Sk}', "");
Expect(1, 65508, '\p{^Is_General_Category= 	Sk}', "");
Expect(1, 65508, '\P{Is_General_Category= 	Sk}', "");
Expect(0, 65508, '\P{^Is_General_Category= 	Sk}', "");
Error('\p{Is_Gc=-/a/Modifier_symbol}');
Error('\P{Is_Gc=-/a/Modifier_symbol}');
Expect(1, 65507, '\p{Is_Gc=modifiersymbol}', "");
Expect(0, 65507, '\p{^Is_Gc=modifiersymbol}', "");
Expect(0, 65507, '\P{Is_Gc=modifiersymbol}', "");
Expect(1, 65507, '\P{^Is_Gc=modifiersymbol}', "");
Expect(0, 65508, '\p{Is_Gc=modifiersymbol}', "");
Expect(1, 65508, '\p{^Is_Gc=modifiersymbol}', "");
Expect(1, 65508, '\P{Is_Gc=modifiersymbol}', "");
Expect(0, 65508, '\P{^Is_Gc=modifiersymbol}', "");
Expect(1, 65507, '\p{Is_Gc=-_Modifier_SYMBOL}', "");
Expect(0, 65507, '\p{^Is_Gc=-_Modifier_SYMBOL}', "");
Expect(0, 65507, '\P{Is_Gc=-_Modifier_SYMBOL}', "");
Expect(1, 65507, '\P{^Is_Gc=-_Modifier_SYMBOL}', "");
Expect(0, 65508, '\p{Is_Gc=-_Modifier_SYMBOL}', "");
Expect(1, 65508, '\p{^Is_Gc=-_Modifier_SYMBOL}', "");
Expect(1, 65508, '\P{Is_Gc=-_Modifier_SYMBOL}', "");
Expect(0, 65508, '\P{^Is_Gc=-_Modifier_SYMBOL}', "");
Error('\p{Is_Category=/a/Sk}');
Error('\P{Is_Category=/a/Sk}');
Expect(1, 65507, '\p{Is_Category=sk}', "");
Expect(0, 65507, '\p{^Is_Category=sk}', "");
Expect(0, 65507, '\P{Is_Category=sk}', "");
Expect(1, 65507, '\P{^Is_Category=sk}', "");
Expect(0, 65508, '\p{Is_Category=sk}', "");
Expect(1, 65508, '\p{^Is_Category=sk}', "");
Expect(1, 65508, '\P{Is_Category=sk}', "");
Expect(0, 65508, '\P{^Is_Category=sk}', "");
Expect(1, 65507, '\p{Is_Category:-Sk}', "");
Expect(0, 65507, '\p{^Is_Category:-Sk}', "");
Expect(0, 65507, '\P{Is_Category:-Sk}', "");
Expect(1, 65507, '\P{^Is_Category:-Sk}', "");
Expect(0, 65508, '\p{Is_Category:-Sk}', "");
Expect(1, 65508, '\p{^Is_Category:-Sk}', "");
Expect(1, 65508, '\P{Is_Category:-Sk}', "");
Expect(0, 65508, '\P{^Is_Category:-Sk}', "");
Error('\p{General_Category=_	Math_symbol:=}');
Error('\P{General_Category=_	Math_symbol:=}');
Expect(1, 126705, '\p{General_Category=mathsymbol}', "");
Expect(0, 126705, '\p{^General_Category=mathsymbol}', "");
Expect(0, 126705, '\P{General_Category=mathsymbol}', "");
Expect(1, 126705, '\P{^General_Category=mathsymbol}', "");
Expect(0, 126706, '\p{General_Category=mathsymbol}', "");
Expect(1, 126706, '\p{^General_Category=mathsymbol}', "");
Expect(1, 126706, '\P{General_Category=mathsymbol}', "");
Expect(0, 126706, '\P{^General_Category=mathsymbol}', "");
Expect(1, 126705, '\p{General_Category=_MATH_Symbol}', "");
Expect(0, 126705, '\p{^General_Category=_MATH_Symbol}', "");
Expect(0, 126705, '\P{General_Category=_MATH_Symbol}', "");
Expect(1, 126705, '\P{^General_Category=_MATH_Symbol}', "");
Expect(0, 126706, '\p{General_Category=_MATH_Symbol}', "");
Expect(1, 126706, '\p{^General_Category=_MATH_Symbol}', "");
Expect(1, 126706, '\P{General_Category=_MATH_Symbol}', "");
Expect(0, 126706, '\P{^General_Category=_MATH_Symbol}', "");
Error('\p{Gc=/a/ 	Sm}');
Error('\P{Gc=/a/ 	Sm}');
Expect(1, 126705, '\p{Gc=sm}', "");
Expect(0, 126705, '\p{^Gc=sm}', "");
Expect(0, 126705, '\P{Gc=sm}', "");
Expect(1, 126705, '\P{^Gc=sm}', "");
Expect(0, 126706, '\p{Gc=sm}', "");
Expect(1, 126706, '\p{^Gc=sm}', "");
Expect(1, 126706, '\P{Gc=sm}', "");
Expect(0, 126706, '\P{^Gc=sm}', "");
Expect(1, 126705, '\p{Gc=__Sm}', "");
Expect(0, 126705, '\p{^Gc=__Sm}', "");
Expect(0, 126705, '\P{Gc=__Sm}', "");
Expect(1, 126705, '\P{^Gc=__Sm}', "");
Expect(0, 126706, '\p{Gc=__Sm}', "");
Expect(1, 126706, '\p{^Gc=__Sm}', "");
Expect(1, 126706, '\P{Gc=__Sm}', "");
Expect(0, 126706, '\P{^Gc=__Sm}', "");
Error('\p{Category=/a/_MATH_Symbol}');
Error('\P{Category=/a/_MATH_Symbol}');
Expect(1, 126705, '\p{Category=mathsymbol}', "");
Expect(0, 126705, '\p{^Category=mathsymbol}', "");
Expect(0, 126705, '\P{Category=mathsymbol}', "");
Expect(1, 126705, '\P{^Category=mathsymbol}', "");
Expect(0, 126706, '\p{Category=mathsymbol}', "");
Expect(1, 126706, '\p{^Category=mathsymbol}', "");
Expect(1, 126706, '\P{Category=mathsymbol}', "");
Expect(0, 126706, '\P{^Category=mathsymbol}', "");
Expect(1, 126705, '\p{Category= -Math_symbol}', "");
Expect(0, 126705, '\p{^Category= -Math_symbol}', "");
Expect(0, 126705, '\P{Category= -Math_symbol}', "");
Expect(1, 126705, '\P{^Category= -Math_symbol}', "");
Expect(0, 126706, '\p{Category= -Math_symbol}', "");
Expect(1, 126706, '\p{^Category= -Math_symbol}', "");
Expect(1, 126706, '\P{Category= -Math_symbol}', "");
Expect(0, 126706, '\P{^Category= -Math_symbol}', "");
Error('\p{Is_General_Category=-Sm:=}');
Error('\P{Is_General_Category=-Sm:=}');
Expect(1, 126705, '\p{Is_General_Category:sm}', "");
Expect(0, 126705, '\p{^Is_General_Category:sm}', "");
Expect(0, 126705, '\P{Is_General_Category:sm}', "");
Expect(1, 126705, '\P{^Is_General_Category:sm}', "");
Expect(0, 126706, '\p{Is_General_Category:sm}', "");
Expect(1, 126706, '\p{^Is_General_Category:sm}', "");
Expect(1, 126706, '\P{Is_General_Category:sm}', "");
Expect(0, 126706, '\P{^Is_General_Category:sm}', "");
Expect(1, 126705, '\p{Is_General_Category=-sm}', "");
Expect(0, 126705, '\p{^Is_General_Category=-sm}', "");
Expect(0, 126705, '\P{Is_General_Category=-sm}', "");
Expect(1, 126705, '\P{^Is_General_Category=-sm}', "");
Expect(0, 126706, '\p{Is_General_Category=-sm}', "");
Expect(1, 126706, '\p{^Is_General_Category=-sm}', "");
Expect(1, 126706, '\P{Is_General_Category=-sm}', "");
Expect(0, 126706, '\P{^Is_General_Category=-sm}', "");
Error('\p{Is_Gc=:=_ MATH_Symbol}');
Error('\P{Is_Gc=:=_ MATH_Symbol}');
Expect(1, 126705, '\p{Is_Gc=mathsymbol}', "");
Expect(0, 126705, '\p{^Is_Gc=mathsymbol}', "");
Expect(0, 126705, '\P{Is_Gc=mathsymbol}', "");
Expect(1, 126705, '\P{^Is_Gc=mathsymbol}', "");
Expect(0, 126706, '\p{Is_Gc=mathsymbol}', "");
Expect(1, 126706, '\p{^Is_Gc=mathsymbol}', "");
Expect(1, 126706, '\P{Is_Gc=mathsymbol}', "");
Expect(0, 126706, '\P{^Is_Gc=mathsymbol}', "");
Expect(1, 126705, '\p{Is_Gc= Math_symbol}', "");
Expect(0, 126705, '\p{^Is_Gc= Math_symbol}', "");
Expect(0, 126705, '\P{Is_Gc= Math_symbol}', "");
Expect(1, 126705, '\P{^Is_Gc= Math_symbol}', "");
Expect(0, 126706, '\p{Is_Gc= Math_symbol}', "");
Expect(1, 126706, '\p{^Is_Gc= Math_symbol}', "");
Expect(1, 126706, '\P{Is_Gc= Math_symbol}', "");
Expect(0, 126706, '\P{^Is_Gc= Math_symbol}', "");
Error('\p{Is_Category=	 sm:=}');
Error('\P{Is_Category=	 sm:=}');
Expect(1, 126705, '\p{Is_Category=sm}', "");
Expect(0, 126705, '\p{^Is_Category=sm}', "");
Expect(0, 126705, '\P{Is_Category=sm}', "");
Expect(1, 126705, '\P{^Is_Category=sm}', "");
Expect(0, 126706, '\p{Is_Category=sm}', "");
Expect(1, 126706, '\p{^Is_Category=sm}', "");
Expect(1, 126706, '\P{Is_Category=sm}', "");
Expect(0, 126706, '\P{^Is_Category=sm}', "");
Expect(1, 126705, '\p{Is_Category=--sm}', "");
Expect(0, 126705, '\p{^Is_Category=--sm}', "");
Expect(0, 126705, '\P{Is_Category=--sm}', "");
Expect(1, 126705, '\P{^Is_Category=--sm}', "");
Expect(0, 126706, '\p{Is_Category=--sm}', "");
Expect(1, 126706, '\p{^Is_Category=--sm}', "");
Expect(1, 126706, '\P{Is_Category=--sm}', "");
Expect(0, 126706, '\P{^Is_Category=--sm}', "");
Error('\p{General_Category=/a/Other_symbol}');
Error('\P{General_Category=/a/Other_symbol}');
Expect(1, 128883, '\p{General_Category=othersymbol}', "");
Expect(0, 128883, '\p{^General_Category=othersymbol}', "");
Expect(0, 128883, '\P{General_Category=othersymbol}', "");
Expect(1, 128883, '\P{^General_Category=othersymbol}', "");
Expect(0, 128884, '\p{General_Category=othersymbol}', "");
Expect(1, 128884, '\p{^General_Category=othersymbol}', "");
Expect(1, 128884, '\P{General_Category=othersymbol}', "");
Expect(0, 128884, '\P{^General_Category=othersymbol}', "");
Expect(1, 128883, '\p{General_Category=  Other_Symbol}', "");
Expect(0, 128883, '\p{^General_Category=  Other_Symbol}', "");
Expect(0, 128883, '\P{General_Category=  Other_Symbol}', "");
Expect(1, 128883, '\P{^General_Category=  Other_Symbol}', "");
Expect(0, 128884, '\p{General_Category=  Other_Symbol}', "");
Expect(1, 128884, '\p{^General_Category=  Other_Symbol}', "");
Expect(1, 128884, '\P{General_Category=  Other_Symbol}', "");
Expect(0, 128884, '\P{^General_Category=  Other_Symbol}', "");
Error('\p{Gc: :=so}');
Error('\P{Gc: :=so}');
Expect(1, 128883, '\p{Gc=so}', "");
Expect(0, 128883, '\p{^Gc=so}', "");
Expect(0, 128883, '\P{Gc=so}', "");
Expect(1, 128883, '\P{^Gc=so}', "");
Expect(0, 128884, '\p{Gc=so}', "");
Expect(1, 128884, '\p{^Gc=so}', "");
Expect(1, 128884, '\P{Gc=so}', "");
Expect(0, 128884, '\P{^Gc=so}', "");
Expect(1, 128883, '\p{Gc=-So}', "");
Expect(0, 128883, '\p{^Gc=-So}', "");
Expect(0, 128883, '\P{Gc=-So}', "");
Expect(1, 128883, '\P{^Gc=-So}', "");
Expect(0, 128884, '\p{Gc=-So}', "");
Expect(1, 128884, '\p{^Gc=-So}', "");
Expect(1, 128884, '\P{Gc=-So}', "");
Expect(0, 128884, '\P{^Gc=-So}', "");
Error('\p{Category= Other_SYMBOL/a/}');
Error('\P{Category= Other_SYMBOL/a/}');
Expect(1, 128883, '\p{Category:   othersymbol}', "");
Expect(0, 128883, '\p{^Category:   othersymbol}', "");
Expect(0, 128883, '\P{Category:   othersymbol}', "");
Expect(1, 128883, '\P{^Category:   othersymbol}', "");
Expect(0, 128884, '\p{Category:   othersymbol}', "");
Expect(1, 128884, '\p{^Category:   othersymbol}', "");
Expect(1, 128884, '\P{Category:   othersymbol}', "");
Expect(0, 128884, '\P{^Category:   othersymbol}', "");
Expect(1, 128883, '\p{Category=	 Other_Symbol}', "");
Expect(0, 128883, '\p{^Category=	 Other_Symbol}', "");
Expect(0, 128883, '\P{Category=	 Other_Symbol}', "");
Expect(1, 128883, '\P{^Category=	 Other_Symbol}', "");
Expect(0, 128884, '\p{Category=	 Other_Symbol}', "");
Expect(1, 128884, '\p{^Category=	 Other_Symbol}', "");
Expect(1, 128884, '\P{Category=	 Other_Symbol}', "");
Expect(0, 128884, '\P{^Category=	 Other_Symbol}', "");
Error('\p{Is_General_Category= so:=}');
Error('\P{Is_General_Category= so:=}');
Expect(1, 128883, '\p{Is_General_Category=so}', "");
Expect(0, 128883, '\p{^Is_General_Category=so}', "");
Expect(0, 128883, '\P{Is_General_Category=so}', "");
Expect(1, 128883, '\P{^Is_General_Category=so}', "");
Expect(0, 128884, '\p{Is_General_Category=so}', "");
Expect(1, 128884, '\p{^Is_General_Category=so}', "");
Expect(1, 128884, '\P{Is_General_Category=so}', "");
Expect(0, 128884, '\P{^Is_General_Category=so}', "");
Expect(1, 128883, '\p{Is_General_Category=	 So}', "");
Expect(0, 128883, '\p{^Is_General_Category=	 So}', "");
Expect(0, 128883, '\P{Is_General_Category=	 So}', "");
Expect(1, 128883, '\P{^Is_General_Category=	 So}', "");
Expect(0, 128884, '\p{Is_General_Category=	 So}', "");
Expect(1, 128884, '\p{^Is_General_Category=	 So}', "");
Expect(1, 128884, '\P{Is_General_Category=	 So}', "");
Expect(0, 128884, '\P{^Is_General_Category=	 So}', "");
Error('\p{Is_Gc=:=	OTHER_Symbol}');
Error('\P{Is_Gc=:=	OTHER_Symbol}');
Expect(1, 128883, '\p{Is_Gc=othersymbol}', "");
Expect(0, 128883, '\p{^Is_Gc=othersymbol}', "");
Expect(0, 128883, '\P{Is_Gc=othersymbol}', "");
Expect(1, 128883, '\P{^Is_Gc=othersymbol}', "");
Expect(0, 128884, '\p{Is_Gc=othersymbol}', "");
Expect(1, 128884, '\p{^Is_Gc=othersymbol}', "");
Expect(1, 128884, '\P{Is_Gc=othersymbol}', "");
Expect(0, 128884, '\P{^Is_Gc=othersymbol}', "");
Expect(1, 128883, '\p{Is_Gc= Other_SYMBOL}', "");
Expect(0, 128883, '\p{^Is_Gc= Other_SYMBOL}', "");
Expect(0, 128883, '\P{Is_Gc= Other_SYMBOL}', "");
Expect(1, 128883, '\P{^Is_Gc= Other_SYMBOL}', "");
Expect(0, 128884, '\p{Is_Gc= Other_SYMBOL}', "");
Expect(1, 128884, '\p{^Is_Gc= Other_SYMBOL}', "");
Expect(1, 128884, '\P{Is_Gc= Other_SYMBOL}', "");
Expect(0, 128884, '\P{^Is_Gc= Other_SYMBOL}', "");
Error('\p{Is_Category=  So:=}');
Error('\P{Is_Category=  So:=}');
Expect(1, 128883, '\p{Is_Category=so}', "");
Expect(0, 128883, '\p{^Is_Category=so}', "");
Expect(0, 128883, '\P{Is_Category=so}', "");
Expect(1, 128883, '\P{^Is_Category=so}', "");
Expect(0, 128884, '\p{Is_Category=so}', "");
Expect(1, 128884, '\p{^Is_Category=so}', "");
Expect(1, 128884, '\P{Is_Category=so}', "");
Expect(0, 128884, '\P{^Is_Category=so}', "");
Expect(1, 128883, '\p{Is_Category=-_So}', "");
Expect(0, 128883, '\p{^Is_Category=-_So}', "");
Expect(0, 128883, '\P{Is_Category=-_So}', "");
Expect(1, 128883, '\P{^Is_Category=-_So}', "");
Expect(0, 128884, '\p{Is_Category=-_So}', "");
Expect(1, 128884, '\p{^Is_Category=-_So}', "");
Expect(1, 128884, '\P{Is_Category=-_So}', "");
Expect(0, 128884, '\P{^Is_Category=-_So}', "");
Error('\p{General_Category=-separator:=}');
Error('\P{General_Category=-separator:=}');
Expect(1, 12288, '\p{General_Category=separator}', "");
Expect(0, 12288, '\p{^General_Category=separator}', "");
Expect(0, 12288, '\P{General_Category=separator}', "");
Expect(1, 12288, '\P{^General_Category=separator}', "");
Expect(0, 12289, '\p{General_Category=separator}', "");
Expect(1, 12289, '\p{^General_Category=separator}', "");
Expect(1, 12289, '\P{General_Category=separator}', "");
Expect(0, 12289, '\P{^General_Category=separator}', "");
Expect(1, 12288, '\p{General_Category=_	SEPARATOR}', "");
Expect(0, 12288, '\p{^General_Category=_	SEPARATOR}', "");
Expect(0, 12288, '\P{General_Category=_	SEPARATOR}', "");
Expect(1, 12288, '\P{^General_Category=_	SEPARATOR}', "");
Expect(0, 12289, '\p{General_Category=_	SEPARATOR}', "");
Expect(1, 12289, '\p{^General_Category=_	SEPARATOR}', "");
Expect(1, 12289, '\P{General_Category=_	SEPARATOR}', "");
Expect(0, 12289, '\P{^General_Category=_	SEPARATOR}', "");
Error('\p{Gc= -z:=}');
Error('\P{Gc= -z:=}');
Expect(1, 12288, '\p{Gc=z}', "");
Expect(0, 12288, '\p{^Gc=z}', "");
Expect(0, 12288, '\P{Gc=z}', "");
Expect(1, 12288, '\P{^Gc=z}', "");
Expect(0, 12289, '\p{Gc=z}', "");
Expect(1, 12289, '\p{^Gc=z}', "");
Expect(1, 12289, '\P{Gc=z}', "");
Expect(0, 12289, '\P{^Gc=z}', "");
Expect(1, 12288, '\p{Gc= 	Z}', "");
Expect(0, 12288, '\p{^Gc= 	Z}', "");
Expect(0, 12288, '\P{Gc= 	Z}', "");
Expect(1, 12288, '\P{^Gc= 	Z}', "");
Expect(0, 12289, '\p{Gc= 	Z}', "");
Expect(1, 12289, '\p{^Gc= 	Z}', "");
Expect(1, 12289, '\P{Gc= 	Z}', "");
Expect(0, 12289, '\P{^Gc= 	Z}', "");
Error('\p{Category:	-:=Separator}');
Error('\P{Category:	-:=Separator}');
Expect(1, 12288, '\p{Category=separator}', "");
Expect(0, 12288, '\p{^Category=separator}', "");
Expect(0, 12288, '\P{Category=separator}', "");
Expect(1, 12288, '\P{^Category=separator}', "");
Expect(0, 12289, '\p{Category=separator}', "");
Expect(1, 12289, '\p{^Category=separator}', "");
Expect(1, 12289, '\P{Category=separator}', "");
Expect(0, 12289, '\P{^Category=separator}', "");
Expect(1, 12288, '\p{Category=-separator}', "");
Expect(0, 12288, '\p{^Category=-separator}', "");
Expect(0, 12288, '\P{Category=-separator}', "");
Expect(1, 12288, '\P{^Category=-separator}', "");
Expect(0, 12289, '\p{Category=-separator}', "");
Expect(1, 12289, '\p{^Category=-separator}', "");
Expect(1, 12289, '\P{Category=-separator}', "");
Expect(0, 12289, '\P{^Category=-separator}', "");
Error('\p{Is_General_Category=-:=z}');
Error('\P{Is_General_Category=-:=z}');
Expect(1, 12288, '\p{Is_General_Category=z}', "");
Expect(0, 12288, '\p{^Is_General_Category=z}', "");
Expect(0, 12288, '\P{Is_General_Category=z}', "");
Expect(1, 12288, '\P{^Is_General_Category=z}', "");
Expect(0, 12289, '\p{Is_General_Category=z}', "");
Expect(1, 12289, '\p{^Is_General_Category=z}', "");
Expect(1, 12289, '\P{Is_General_Category=z}', "");
Expect(0, 12289, '\P{^Is_General_Category=z}', "");
Expect(1, 12288, '\p{Is_General_Category:-	Z}', "");
Expect(0, 12288, '\p{^Is_General_Category:-	Z}', "");
Expect(0, 12288, '\P{Is_General_Category:-	Z}', "");
Expect(1, 12288, '\P{^Is_General_Category:-	Z}', "");
Expect(0, 12289, '\p{Is_General_Category:-	Z}', "");
Expect(1, 12289, '\p{^Is_General_Category:-	Z}', "");
Expect(1, 12289, '\P{Is_General_Category:-	Z}', "");
Expect(0, 12289, '\P{^Is_General_Category:-	Z}', "");
Error('\p{Is_Gc: :=_SEPARATOR}');
Error('\P{Is_Gc: :=_SEPARATOR}');
Expect(1, 12288, '\p{Is_Gc:   separator}', "");
Expect(0, 12288, '\p{^Is_Gc:   separator}', "");
Expect(0, 12288, '\P{Is_Gc:   separator}', "");
Expect(1, 12288, '\P{^Is_Gc:   separator}', "");
Expect(0, 12289, '\p{Is_Gc:   separator}', "");
Expect(1, 12289, '\p{^Is_Gc:   separator}', "");
Expect(1, 12289, '\P{Is_Gc:   separator}', "");
Expect(0, 12289, '\P{^Is_Gc:   separator}', "");
Expect(1, 12288, '\p{Is_Gc=_Separator}', "");
Expect(0, 12288, '\p{^Is_Gc=_Separator}', "");
Expect(0, 12288, '\P{Is_Gc=_Separator}', "");
Expect(1, 12288, '\P{^Is_Gc=_Separator}', "");
Expect(0, 12289, '\p{Is_Gc=_Separator}', "");
Expect(1, 12289, '\p{^Is_Gc=_Separator}', "");
Expect(1, 12289, '\P{Is_Gc=_Separator}', "");
Expect(0, 12289, '\P{^Is_Gc=_Separator}', "");
Error('\p{Is_Category= Z:=}');
Error('\P{Is_Category= Z:=}');
Expect(1, 12288, '\p{Is_Category=z}', "");
Expect(0, 12288, '\p{^Is_Category=z}', "");
Expect(0, 12288, '\P{Is_Category=z}', "");
Expect(1, 12288, '\P{^Is_Category=z}', "");
Expect(0, 12289, '\p{Is_Category=z}', "");
Expect(1, 12289, '\p{^Is_Category=z}', "");
Expect(1, 12289, '\P{Is_Category=z}', "");
Expect(0, 12289, '\P{^Is_Category=z}', "");
Expect(1, 12288, '\p{Is_Category=	_Z}', "");
Expect(0, 12288, '\p{^Is_Category=	_Z}', "");
Expect(0, 12288, '\P{Is_Category=	_Z}', "");
Expect(1, 12288, '\P{^Is_Category=	_Z}', "");
Expect(0, 12289, '\p{Is_Category=	_Z}', "");
Expect(1, 12289, '\p{^Is_Category=	_Z}', "");
Expect(1, 12289, '\P{Is_Category=	_Z}', "");
Expect(0, 12289, '\P{^Is_Category=	_Z}', "");
Error('\p{General_Category: /a/-_line_Separator}');
Error('\P{General_Category: /a/-_line_Separator}');
Expect(1, 8232, '\p{General_Category=lineseparator}', "");
Expect(0, 8232, '\p{^General_Category=lineseparator}', "");
Expect(0, 8232, '\P{General_Category=lineseparator}', "");
Expect(1, 8232, '\P{^General_Category=lineseparator}', "");
Expect(0, 8233, '\p{General_Category=lineseparator}', "");
Expect(1, 8233, '\p{^General_Category=lineseparator}', "");
Expect(1, 8233, '\P{General_Category=lineseparator}', "");
Expect(0, 8233, '\P{^General_Category=lineseparator}', "");
Expect(1, 8232, '\p{General_Category=LINE_Separator}', "");
Expect(0, 8232, '\p{^General_Category=LINE_Separator}', "");
Expect(0, 8232, '\P{General_Category=LINE_Separator}', "");
Expect(1, 8232, '\P{^General_Category=LINE_Separator}', "");
Expect(0, 8233, '\p{General_Category=LINE_Separator}', "");
Expect(1, 8233, '\p{^General_Category=LINE_Separator}', "");
Expect(1, 8233, '\P{General_Category=LINE_Separator}', "");
Expect(0, 8233, '\P{^General_Category=LINE_Separator}', "");
Error('\p{Gc: ZL/a/}');
Error('\P{Gc: ZL/a/}');
Expect(1, 8232, '\p{Gc=zl}', "");
Expect(0, 8232, '\p{^Gc=zl}', "");
Expect(0, 8232, '\P{Gc=zl}', "");
Expect(1, 8232, '\P{^Gc=zl}', "");
Expect(0, 8233, '\p{Gc=zl}', "");
Expect(1, 8233, '\p{^Gc=zl}', "");
Expect(1, 8233, '\P{Gc=zl}', "");
Expect(0, 8233, '\P{^Gc=zl}', "");
Expect(1, 8232, '\p{Gc=_-Zl}', "");
Expect(0, 8232, '\p{^Gc=_-Zl}', "");
Expect(0, 8232, '\P{Gc=_-Zl}', "");
Expect(1, 8232, '\P{^Gc=_-Zl}', "");
Expect(0, 8233, '\p{Gc=_-Zl}', "");
Expect(1, 8233, '\p{^Gc=_-Zl}', "");
Expect(1, 8233, '\P{Gc=_-Zl}', "");
Expect(0, 8233, '\P{^Gc=_-Zl}', "");
Error('\p{Category= /a/Line_SEPARATOR}');
Error('\P{Category= /a/Line_SEPARATOR}');
Expect(1, 8232, '\p{Category=lineseparator}', "");
Expect(0, 8232, '\p{^Category=lineseparator}', "");
Expect(0, 8232, '\P{Category=lineseparator}', "");
Expect(1, 8232, '\P{^Category=lineseparator}', "");
Expect(0, 8233, '\p{Category=lineseparator}', "");
Expect(1, 8233, '\p{^Category=lineseparator}', "");
Expect(1, 8233, '\P{Category=lineseparator}', "");
Expect(0, 8233, '\P{^Category=lineseparator}', "");
Expect(1, 8232, '\p{Category= -LINE_SEPARATOR}', "");
Expect(0, 8232, '\p{^Category= -LINE_SEPARATOR}', "");
Expect(0, 8232, '\P{Category= -LINE_SEPARATOR}', "");
Expect(1, 8232, '\P{^Category= -LINE_SEPARATOR}', "");
Expect(0, 8233, '\p{Category= -LINE_SEPARATOR}', "");
Expect(1, 8233, '\p{^Category= -LINE_SEPARATOR}', "");
Expect(1, 8233, '\P{Category= -LINE_SEPARATOR}', "");
Expect(0, 8233, '\P{^Category= -LINE_SEPARATOR}', "");
Error('\p{Is_General_Category=:=zl}');
Error('\P{Is_General_Category=:=zl}');
Expect(1, 8232, '\p{Is_General_Category=zl}', "");
Expect(0, 8232, '\p{^Is_General_Category=zl}', "");
Expect(0, 8232, '\P{Is_General_Category=zl}', "");
Expect(1, 8232, '\P{^Is_General_Category=zl}', "");
Expect(0, 8233, '\p{Is_General_Category=zl}', "");
Expect(1, 8233, '\p{^Is_General_Category=zl}', "");
Expect(1, 8233, '\P{Is_General_Category=zl}', "");
Expect(0, 8233, '\P{^Is_General_Category=zl}', "");
Expect(1, 8232, '\p{Is_General_Category=	ZL}', "");
Expect(0, 8232, '\p{^Is_General_Category=	ZL}', "");
Expect(0, 8232, '\P{Is_General_Category=	ZL}', "");
Expect(1, 8232, '\P{^Is_General_Category=	ZL}', "");
Expect(0, 8233, '\p{Is_General_Category=	ZL}', "");
Expect(1, 8233, '\p{^Is_General_Category=	ZL}', "");
Expect(1, 8233, '\P{Is_General_Category=	ZL}', "");
Expect(0, 8233, '\P{^Is_General_Category=	ZL}', "");
Error('\p{Is_Gc:	:=-line_Separator}');
Error('\P{Is_Gc:	:=-line_Separator}');
Expect(1, 8232, '\p{Is_Gc=lineseparator}', "");
Expect(0, 8232, '\p{^Is_Gc=lineseparator}', "");
Expect(0, 8232, '\P{Is_Gc=lineseparator}', "");
Expect(1, 8232, '\P{^Is_Gc=lineseparator}', "");
Expect(0, 8233, '\p{Is_Gc=lineseparator}', "");
Expect(1, 8233, '\p{^Is_Gc=lineseparator}', "");
Expect(1, 8233, '\P{Is_Gc=lineseparator}', "");
Expect(0, 8233, '\P{^Is_Gc=lineseparator}', "");
Expect(1, 8232, '\p{Is_Gc:	_line_Separator}', "");
Expect(0, 8232, '\p{^Is_Gc:	_line_Separator}', "");
Expect(0, 8232, '\P{Is_Gc:	_line_Separator}', "");
Expect(1, 8232, '\P{^Is_Gc:	_line_Separator}', "");
Expect(0, 8233, '\p{Is_Gc:	_line_Separator}', "");
Expect(1, 8233, '\p{^Is_Gc:	_line_Separator}', "");
Expect(1, 8233, '\P{Is_Gc:	_line_Separator}', "");
Expect(0, 8233, '\P{^Is_Gc:	_line_Separator}', "");
Error('\p{Is_Category=_Zl:=}');
Error('\P{Is_Category=_Zl:=}');
Expect(1, 8232, '\p{Is_Category=zl}', "");
Expect(0, 8232, '\p{^Is_Category=zl}', "");
Expect(0, 8232, '\P{Is_Category=zl}', "");
Expect(1, 8232, '\P{^Is_Category=zl}', "");
Expect(0, 8233, '\p{Is_Category=zl}', "");
Expect(1, 8233, '\p{^Is_Category=zl}', "");
Expect(1, 8233, '\P{Is_Category=zl}', "");
Expect(0, 8233, '\P{^Is_Category=zl}', "");
Expect(1, 8232, '\p{Is_Category=		zl}', "");
Expect(0, 8232, '\p{^Is_Category=		zl}', "");
Expect(0, 8232, '\P{Is_Category=		zl}', "");
Expect(1, 8232, '\P{^Is_Category=		zl}', "");
Expect(0, 8233, '\p{Is_Category=		zl}', "");
Expect(1, 8233, '\p{^Is_Category=		zl}', "");
Expect(1, 8233, '\P{Is_Category=		zl}', "");
Expect(0, 8233, '\P{^Is_Category=		zl}', "");
Error('\p{General_Category=:=_ Paragraph_SEPARATOR}');
Error('\P{General_Category=:=_ Paragraph_SEPARATOR}');
Expect(1, 8233, '\p{General_Category=paragraphseparator}', "");
Expect(0, 8233, '\p{^General_Category=paragraphseparator}', "");
Expect(0, 8233, '\P{General_Category=paragraphseparator}', "");
Expect(1, 8233, '\P{^General_Category=paragraphseparator}', "");
Expect(0, 8234, '\p{General_Category=paragraphseparator}', "");
Expect(1, 8234, '\p{^General_Category=paragraphseparator}', "");
Expect(1, 8234, '\P{General_Category=paragraphseparator}', "");
Expect(0, 8234, '\P{^General_Category=paragraphseparator}', "");
Expect(1, 8233, '\p{General_Category:   Paragraph_Separator}', "");
Expect(0, 8233, '\p{^General_Category:   Paragraph_Separator}', "");
Expect(0, 8233, '\P{General_Category:   Paragraph_Separator}', "");
Expect(1, 8233, '\P{^General_Category:   Paragraph_Separator}', "");
Expect(0, 8234, '\p{General_Category:   Paragraph_Separator}', "");
Expect(1, 8234, '\p{^General_Category:   Paragraph_Separator}', "");
Expect(1, 8234, '\P{General_Category:   Paragraph_Separator}', "");
Expect(0, 8234, '\P{^General_Category:   Paragraph_Separator}', "");
Error('\p{Gc=:=_ Zp}');
Error('\P{Gc=:=_ Zp}');
Expect(1, 8233, '\p{Gc=zp}', "");
Expect(0, 8233, '\p{^Gc=zp}', "");
Expect(0, 8233, '\P{Gc=zp}', "");
Expect(1, 8233, '\P{^Gc=zp}', "");
Expect(0, 8234, '\p{Gc=zp}', "");
Expect(1, 8234, '\p{^Gc=zp}', "");
Expect(1, 8234, '\P{Gc=zp}', "");
Expect(0, 8234, '\P{^Gc=zp}', "");
Expect(1, 8233, '\p{Gc=_	ZP}', "");
Expect(0, 8233, '\p{^Gc=_	ZP}', "");
Expect(0, 8233, '\P{Gc=_	ZP}', "");
Expect(1, 8233, '\P{^Gc=_	ZP}', "");
Expect(0, 8234, '\p{Gc=_	ZP}', "");
Expect(1, 8234, '\p{^Gc=_	ZP}', "");
Expect(1, 8234, '\P{Gc=_	ZP}', "");
Expect(0, 8234, '\P{^Gc=_	ZP}', "");
Error('\p{Category:	_ paragraph_separator/a/}');
Error('\P{Category:	_ paragraph_separator/a/}');
Expect(1, 8233, '\p{Category=paragraphseparator}', "");
Expect(0, 8233, '\p{^Category=paragraphseparator}', "");
Expect(0, 8233, '\P{Category=paragraphseparator}', "");
Expect(1, 8233, '\P{^Category=paragraphseparator}', "");
Expect(0, 8234, '\p{Category=paragraphseparator}', "");
Expect(1, 8234, '\p{^Category=paragraphseparator}', "");
Expect(1, 8234, '\P{Category=paragraphseparator}', "");
Expect(0, 8234, '\P{^Category=paragraphseparator}', "");
Expect(1, 8233, '\p{Category=	paragraph_Separator}', "");
Expect(0, 8233, '\p{^Category=	paragraph_Separator}', "");
Expect(0, 8233, '\P{Category=	paragraph_Separator}', "");
Expect(1, 8233, '\P{^Category=	paragraph_Separator}', "");
Expect(0, 8234, '\p{Category=	paragraph_Separator}', "");
Expect(1, 8234, '\p{^Category=	paragraph_Separator}', "");
Expect(1, 8234, '\P{Category=	paragraph_Separator}', "");
Expect(0, 8234, '\P{^Category=	paragraph_Separator}', "");
Error('\p{Is_General_Category=_-Zp/a/}');
Error('\P{Is_General_Category=_-Zp/a/}');
Expect(1, 8233, '\p{Is_General_Category=zp}', "");
Expect(0, 8233, '\p{^Is_General_Category=zp}', "");
Expect(0, 8233, '\P{Is_General_Category=zp}', "");
Expect(1, 8233, '\P{^Is_General_Category=zp}', "");
Expect(0, 8234, '\p{Is_General_Category=zp}', "");
Expect(1, 8234, '\p{^Is_General_Category=zp}', "");
Expect(1, 8234, '\P{Is_General_Category=zp}', "");
Expect(0, 8234, '\P{^Is_General_Category=zp}', "");
Expect(1, 8233, '\p{Is_General_Category=Zp}', "");
Expect(0, 8233, '\p{^Is_General_Category=Zp}', "");
Expect(0, 8233, '\P{Is_General_Category=Zp}', "");
Expect(1, 8233, '\P{^Is_General_Category=Zp}', "");
Expect(0, 8234, '\p{Is_General_Category=Zp}', "");
Expect(1, 8234, '\p{^Is_General_Category=Zp}', "");
Expect(1, 8234, '\P{Is_General_Category=Zp}', "");
Expect(0, 8234, '\P{^Is_General_Category=Zp}', "");
Error('\p{Is_Gc=-PARAGRAPH_separator/a/}');
Error('\P{Is_Gc=-PARAGRAPH_separator/a/}');
Expect(1, 8233, '\p{Is_Gc=paragraphseparator}', "");
Expect(0, 8233, '\p{^Is_Gc=paragraphseparator}', "");
Expect(0, 8233, '\P{Is_Gc=paragraphseparator}', "");
Expect(1, 8233, '\P{^Is_Gc=paragraphseparator}', "");
Expect(0, 8234, '\p{Is_Gc=paragraphseparator}', "");
Expect(1, 8234, '\p{^Is_Gc=paragraphseparator}', "");
Expect(1, 8234, '\P{Is_Gc=paragraphseparator}', "");
Expect(0, 8234, '\P{^Is_Gc=paragraphseparator}', "");
Expect(1, 8233, '\p{Is_Gc=-paragraph_SEPARATOR}', "");
Expect(0, 8233, '\p{^Is_Gc=-paragraph_SEPARATOR}', "");
Expect(0, 8233, '\P{Is_Gc=-paragraph_SEPARATOR}', "");
Expect(1, 8233, '\P{^Is_Gc=-paragraph_SEPARATOR}', "");
Expect(0, 8234, '\p{Is_Gc=-paragraph_SEPARATOR}', "");
Expect(1, 8234, '\p{^Is_Gc=-paragraph_SEPARATOR}', "");
Expect(1, 8234, '\P{Is_Gc=-paragraph_SEPARATOR}', "");
Expect(0, 8234, '\P{^Is_Gc=-paragraph_SEPARATOR}', "");
Error('\p{Is_Category=:=Zp}');
Error('\P{Is_Category=:=Zp}');
Expect(1, 8233, '\p{Is_Category=zp}', "");
Expect(0, 8233, '\p{^Is_Category=zp}', "");
Expect(0, 8233, '\P{Is_Category=zp}', "");
Expect(1, 8233, '\P{^Is_Category=zp}', "");
Expect(0, 8234, '\p{Is_Category=zp}', "");
Expect(1, 8234, '\p{^Is_Category=zp}', "");
Expect(1, 8234, '\P{Is_Category=zp}', "");
Expect(0, 8234, '\P{^Is_Category=zp}', "");
Expect(1, 8233, '\p{Is_Category=_ zp}', "");
Expect(0, 8233, '\p{^Is_Category=_ zp}', "");
Expect(0, 8233, '\P{Is_Category=_ zp}', "");
Expect(1, 8233, '\P{^Is_Category=_ zp}', "");
Expect(0, 8234, '\p{Is_Category=_ zp}', "");
Expect(1, 8234, '\p{^Is_Category=_ zp}', "");
Expect(1, 8234, '\P{Is_Category=_ zp}', "");
Expect(0, 8234, '\P{^Is_Category=_ zp}', "");
Error('\p{General_Category=_	Space_Separator:=}');
Error('\P{General_Category=_	Space_Separator:=}');
Expect(1, 12288, '\p{General_Category:	spaceseparator}', "");
Expect(0, 12288, '\p{^General_Category:	spaceseparator}', "");
Expect(0, 12288, '\P{General_Category:	spaceseparator}', "");
Expect(1, 12288, '\P{^General_Category:	spaceseparator}', "");
Expect(0, 12289, '\p{General_Category:	spaceseparator}', "");
Expect(1, 12289, '\p{^General_Category:	spaceseparator}', "");
Expect(1, 12289, '\P{General_Category:	spaceseparator}', "");
Expect(0, 12289, '\P{^General_Category:	spaceseparator}', "");
Expect(1, 12288, '\p{General_Category:   	SPACE_Separator}', "");
Expect(0, 12288, '\p{^General_Category:   	SPACE_Separator}', "");
Expect(0, 12288, '\P{General_Category:   	SPACE_Separator}', "");
Expect(1, 12288, '\P{^General_Category:   	SPACE_Separator}', "");
Expect(0, 12289, '\p{General_Category:   	SPACE_Separator}', "");
Expect(1, 12289, '\p{^General_Category:   	SPACE_Separator}', "");
Expect(1, 12289, '\P{General_Category:   	SPACE_Separator}', "");
Expect(0, 12289, '\P{^General_Category:   	SPACE_Separator}', "");
Error('\p{Gc=_	Zs:=}');
Error('\P{Gc=_	Zs:=}');
Expect(1, 12288, '\p{Gc=zs}', "");
Expect(0, 12288, '\p{^Gc=zs}', "");
Expect(0, 12288, '\P{Gc=zs}', "");
Expect(1, 12288, '\P{^Gc=zs}', "");
Expect(0, 12289, '\p{Gc=zs}', "");
Expect(1, 12289, '\p{^Gc=zs}', "");
Expect(1, 12289, '\P{Gc=zs}', "");
Expect(0, 12289, '\P{^Gc=zs}', "");
Expect(1, 12288, '\p{Gc=_	zs}', "");
Expect(0, 12288, '\p{^Gc=_	zs}', "");
Expect(0, 12288, '\P{Gc=_	zs}', "");
Expect(1, 12288, '\P{^Gc=_	zs}', "");
Expect(0, 12289, '\p{Gc=_	zs}', "");
Expect(1, 12289, '\p{^Gc=_	zs}', "");
Expect(1, 12289, '\P{Gc=_	zs}', "");
Expect(0, 12289, '\P{^Gc=_	zs}', "");
Error('\p{Category=-/a/SPACE_Separator}');
Error('\P{Category=-/a/SPACE_Separator}');
Expect(1, 12288, '\p{Category=spaceseparator}', "");
Expect(0, 12288, '\p{^Category=spaceseparator}', "");
Expect(0, 12288, '\P{Category=spaceseparator}', "");
Expect(1, 12288, '\P{^Category=spaceseparator}', "");
Expect(0, 12289, '\p{Category=spaceseparator}', "");
Expect(1, 12289, '\p{^Category=spaceseparator}', "");
Expect(1, 12289, '\P{Category=spaceseparator}', "");
Expect(0, 12289, '\P{^Category=spaceseparator}', "");
Expect(1, 12288, '\p{Category=--Space_Separator}', "");
Expect(0, 12288, '\p{^Category=--Space_Separator}', "");
Expect(0, 12288, '\P{Category=--Space_Separator}', "");
Expect(1, 12288, '\P{^Category=--Space_Separator}', "");
Expect(0, 12289, '\p{Category=--Space_Separator}', "");
Expect(1, 12289, '\p{^Category=--Space_Separator}', "");
Expect(1, 12289, '\P{Category=--Space_Separator}', "");
Expect(0, 12289, '\P{^Category=--Space_Separator}', "");
Error('\p{Is_General_Category:    :=ZS}');
Error('\P{Is_General_Category:    :=ZS}');
Expect(1, 12288, '\p{Is_General_Category:	zs}', "");
Expect(0, 12288, '\p{^Is_General_Category:	zs}', "");
Expect(0, 12288, '\P{Is_General_Category:	zs}', "");
Expect(1, 12288, '\P{^Is_General_Category:	zs}', "");
Expect(0, 12289, '\p{Is_General_Category:	zs}', "");
Expect(1, 12289, '\p{^Is_General_Category:	zs}', "");
Expect(1, 12289, '\P{Is_General_Category:	zs}', "");
Expect(0, 12289, '\P{^Is_General_Category:	zs}', "");
Expect(1, 12288, '\p{Is_General_Category=-	Zs}', "");
Expect(0, 12288, '\p{^Is_General_Category=-	Zs}', "");
Expect(0, 12288, '\P{Is_General_Category=-	Zs}', "");
Expect(1, 12288, '\P{^Is_General_Category=-	Zs}', "");
Expect(0, 12289, '\p{Is_General_Category=-	Zs}', "");
Expect(1, 12289, '\p{^Is_General_Category=-	Zs}', "");
Expect(1, 12289, '\P{Is_General_Category=-	Zs}', "");
Expect(0, 12289, '\P{^Is_General_Category=-	Zs}', "");
Error('\p{Is_Gc=/a/ space_Separator}');
Error('\P{Is_Gc=/a/ space_Separator}');
Expect(1, 12288, '\p{Is_Gc=spaceseparator}', "");
Expect(0, 12288, '\p{^Is_Gc=spaceseparator}', "");
Expect(0, 12288, '\P{Is_Gc=spaceseparator}', "");
Expect(1, 12288, '\P{^Is_Gc=spaceseparator}', "");
Expect(0, 12289, '\p{Is_Gc=spaceseparator}', "");
Expect(1, 12289, '\p{^Is_Gc=spaceseparator}', "");
Expect(1, 12289, '\P{Is_Gc=spaceseparator}', "");
Expect(0, 12289, '\P{^Is_Gc=spaceseparator}', "");
Expect(1, 12288, '\p{Is_Gc=		space_Separator}', "");
Expect(0, 12288, '\p{^Is_Gc=		space_Separator}', "");
Expect(0, 12288, '\P{Is_Gc=		space_Separator}', "");
Expect(1, 12288, '\P{^Is_Gc=		space_Separator}', "");
Expect(0, 12289, '\p{Is_Gc=		space_Separator}', "");
Expect(1, 12289, '\p{^Is_Gc=		space_Separator}', "");
Expect(1, 12289, '\P{Is_Gc=		space_Separator}', "");
Expect(0, 12289, '\P{^Is_Gc=		space_Separator}', "");
Error('\p{Is_Category= 	Zs/a/}');
Error('\P{Is_Category= 	Zs/a/}');
Expect(1, 12288, '\p{Is_Category:	zs}', "");
Expect(0, 12288, '\p{^Is_Category:	zs}', "");
Expect(0, 12288, '\P{Is_Category:	zs}', "");
Expect(1, 12288, '\P{^Is_Category:	zs}', "");
Expect(0, 12289, '\p{Is_Category:	zs}', "");
Expect(1, 12289, '\p{^Is_Category:	zs}', "");
Expect(1, 12289, '\P{Is_Category:	zs}', "");
Expect(0, 12289, '\P{^Is_Category:	zs}', "");
Expect(1, 12288, '\p{Is_Category:	ZS}', "");
Expect(0, 12288, '\p{^Is_Category:	ZS}', "");
Expect(0, 12288, '\P{Is_Category:	ZS}', "");
Expect(1, 12288, '\P{^Is_Category:	ZS}', "");
Expect(0, 12289, '\p{Is_Category:	ZS}', "");
Expect(1, 12289, '\p{^Is_Category:	ZS}', "");
Expect(1, 12289, '\P{Is_Category:	ZS}', "");
Expect(0, 12289, '\P{^Is_Category:	ZS}', "");
Error('\p{Hangul_Syllable_Type=-/a/leading_Jamo}');
Error('\P{Hangul_Syllable_Type=-/a/leading_Jamo}');
Expect(1, 43388, '\p{Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43388, '\p{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43388, '\P{Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43388, '\P{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43389, '\p{Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43389, '\p{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43389, '\P{Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43389, '\P{^Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43388, '\p{Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(0, 43388, '\p{^Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(0, 43388, '\P{Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(1, 43388, '\P{^Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(0, 43389, '\p{Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(1, 43389, '\p{^Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(1, 43389, '\P{Hangul_Syllable_Type=Leading_Jamo}', "");
Expect(0, 43389, '\P{^Hangul_Syllable_Type=Leading_Jamo}', "");
Error('\p{Hst=-/a/L}');
Error('\P{Hst=-/a/L}');
Expect(1, 43388, '\p{Hst=l}', "");
Expect(0, 43388, '\p{^Hst=l}', "");
Expect(0, 43388, '\P{Hst=l}', "");
Expect(1, 43388, '\P{^Hst=l}', "");
Expect(0, 43389, '\p{Hst=l}', "");
Expect(1, 43389, '\p{^Hst=l}', "");
Expect(1, 43389, '\P{Hst=l}', "");
Expect(0, 43389, '\P{^Hst=l}', "");
Expect(1, 43388, '\p{Hst=_-L}', "");
Expect(0, 43388, '\p{^Hst=_-L}', "");
Expect(0, 43388, '\P{Hst=_-L}', "");
Expect(1, 43388, '\P{^Hst=_-L}', "");
Expect(0, 43389, '\p{Hst=_-L}', "");
Expect(1, 43389, '\p{^Hst=_-L}', "");
Expect(1, 43389, '\P{Hst=_-L}', "");
Expect(0, 43389, '\P{^Hst=_-L}', "");
Error('\p{Is_Hangul_Syllable_Type=/a/leading_jamo}');
Error('\P{Is_Hangul_Syllable_Type=/a/leading_jamo}');
Expect(1, 43388, '\p{Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43388, '\p{^Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43388, '\P{Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43388, '\P{^Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43389, '\p{Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43389, '\p{^Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43389, '\P{Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(0, 43389, '\P{^Is_Hangul_Syllable_Type=leadingjamo}', "");
Expect(1, 43388, '\p{Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(0, 43388, '\p{^Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(0, 43388, '\P{Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(1, 43388, '\P{^Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(0, 43389, '\p{Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(1, 43389, '\p{^Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(1, 43389, '\P{Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Expect(0, 43389, '\P{^Is_Hangul_Syllable_Type=		LEADING_Jamo}', "");
Error('\p{Is_Hst=/a/ 	L}');
Error('\P{Is_Hst=/a/ 	L}');
Expect(1, 43388, '\p{Is_Hst=l}', "");
Expect(0, 43388, '\p{^Is_Hst=l}', "");
Expect(0, 43388, '\P{Is_Hst=l}', "");
Expect(1, 43388, '\P{^Is_Hst=l}', "");
Expect(0, 43389, '\p{Is_Hst=l}', "");
Expect(1, 43389, '\p{^Is_Hst=l}', "");
Expect(1, 43389, '\P{Is_Hst=l}', "");
Expect(0, 43389, '\P{^Is_Hst=l}', "");
Expect(1, 43388, '\p{Is_Hst:	_-L}', "");
Expect(0, 43388, '\p{^Is_Hst:	_-L}', "");
Expect(0, 43388, '\P{Is_Hst:	_-L}', "");
Expect(1, 43388, '\P{^Is_Hst:	_-L}', "");
Expect(0, 43389, '\p{Is_Hst:	_-L}', "");
Expect(1, 43389, '\p{^Is_Hst:	_-L}', "");
Expect(1, 43389, '\P{Is_Hst:	_-L}', "");
Expect(0, 43389, '\P{^Is_Hst:	_-L}', "");
Error('\p{Hangul_Syllable_Type=-LV_Syllable/a/}');
Error('\P{Hangul_Syllable_Type=-LV_Syllable/a/}');
Expect(1, 55176, '\p{Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\p{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\P{Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\P{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\p{Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\p{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\P{Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\P{^Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\p{Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(0, 55176, '\p{^Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(0, 55176, '\P{Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(1, 55176, '\P{^Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(0, 55177, '\p{Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(1, 55177, '\p{^Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(1, 55177, '\P{Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Expect(0, 55177, '\P{^Hangul_Syllable_Type=	LV_SYLLABLE}', "");
Error('\p{Hst=_/a/LV}');
Error('\P{Hst=_/a/LV}');
Expect(1, 55176, '\p{Hst=lv}', "");
Expect(0, 55176, '\p{^Hst=lv}', "");
Expect(0, 55176, '\P{Hst=lv}', "");
Expect(1, 55176, '\P{^Hst=lv}', "");
Expect(0, 55177, '\p{Hst=lv}', "");
Expect(1, 55177, '\p{^Hst=lv}', "");
Expect(1, 55177, '\P{Hst=lv}', "");
Expect(0, 55177, '\P{^Hst=lv}', "");
Expect(1, 55176, '\p{Hst= -LV}', "");
Expect(0, 55176, '\p{^Hst= -LV}', "");
Expect(0, 55176, '\P{Hst= -LV}', "");
Expect(1, 55176, '\P{^Hst= -LV}', "");
Expect(0, 55177, '\p{Hst= -LV}', "");
Expect(1, 55177, '\p{^Hst= -LV}', "");
Expect(1, 55177, '\P{Hst= -LV}', "");
Expect(0, 55177, '\P{^Hst= -LV}', "");
Error('\p{Is_Hangul_Syllable_Type:   :=lv_SYLLABLE}');
Error('\P{Is_Hangul_Syllable_Type:   :=lv_SYLLABLE}');
Expect(1, 55176, '\p{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\p{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55176, '\P{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\P{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\p{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\p{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55177, '\P{Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(0, 55177, '\P{^Is_Hangul_Syllable_Type=lvsyllable}', "");
Expect(1, 55176, '\p{Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(0, 55176, '\p{^Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(0, 55176, '\P{Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(1, 55176, '\P{^Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(0, 55177, '\p{Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(1, 55177, '\p{^Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(1, 55177, '\P{Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Expect(0, 55177, '\P{^Is_Hangul_Syllable_Type= lv_SYLLABLE}', "");
Error('\p{Is_Hst=	/a/LV}');
Error('\P{Is_Hst=	/a/LV}');
Expect(1, 55176, '\p{Is_Hst=lv}', "");
Expect(0, 55176, '\p{^Is_Hst=lv}', "");
Expect(0, 55176, '\P{Is_Hst=lv}', "");
Expect(1, 55176, '\P{^Is_Hst=lv}', "");
Expect(0, 55177, '\p{Is_Hst=lv}', "");
Expect(1, 55177, '\p{^Is_Hst=lv}', "");
Expect(1, 55177, '\P{Is_Hst=lv}', "");
Expect(0, 55177, '\P{^Is_Hst=lv}', "");
Expect(1, 55176, '\p{Is_Hst=	lv}', "");
Expect(0, 55176, '\p{^Is_Hst=	lv}', "");
Expect(0, 55176, '\P{Is_Hst=	lv}', "");
Expect(1, 55176, '\P{^Is_Hst=	lv}', "");
Expect(0, 55177, '\p{Is_Hst=	lv}', "");
Expect(1, 55177, '\p{^Is_Hst=	lv}', "");
Expect(1, 55177, '\P{Is_Hst=	lv}', "");
Expect(0, 55177, '\P{^Is_Hst=	lv}', "");
Error('\p{Hangul_Syllable_Type= 	LVT_syllable:=}');
Error('\P{Hangul_Syllable_Type= 	LVT_syllable:=}');
Expect(1, 55203, '\p{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\p{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\P{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\P{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\p{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\p{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\P{Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\P{^Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\p{Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(0, 55203, '\p{^Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(0, 55203, '\P{Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(1, 55203, '\P{^Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(0, 55204, '\p{Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(1, 55204, '\p{^Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(1, 55204, '\P{Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Expect(0, 55204, '\P{^Hangul_Syllable_Type=--LVT_SYLLABLE}', "");
Error('\p{Hst=:=-lvt}');
Error('\P{Hst=:=-lvt}');
Expect(1, 55203, '\p{Hst=lvt}', "");
Expect(0, 55203, '\p{^Hst=lvt}', "");
Expect(0, 55203, '\P{Hst=lvt}', "");
Expect(1, 55203, '\P{^Hst=lvt}', "");
Expect(0, 55204, '\p{Hst=lvt}', "");
Expect(1, 55204, '\p{^Hst=lvt}', "");
Expect(1, 55204, '\P{Hst=lvt}', "");
Expect(0, 55204, '\P{^Hst=lvt}', "");
Expect(1, 55203, '\p{Hst=	 lvt}', "");
Expect(0, 55203, '\p{^Hst=	 lvt}', "");
Expect(0, 55203, '\P{Hst=	 lvt}', "");
Expect(1, 55203, '\P{^Hst=	 lvt}', "");
Expect(0, 55204, '\p{Hst=	 lvt}', "");
Expect(1, 55204, '\p{^Hst=	 lvt}', "");
Expect(1, 55204, '\P{Hst=	 lvt}', "");
Expect(0, 55204, '\P{^Hst=	 lvt}', "");
Error('\p{Is_Hangul_Syllable_Type= :=LVT_Syllable}');
Error('\P{Is_Hangul_Syllable_Type= :=LVT_Syllable}');
Expect(1, 55203, '\p{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\p{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55203, '\P{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\P{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\p{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\p{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55204, '\P{Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(0, 55204, '\P{^Is_Hangul_Syllable_Type=lvtsyllable}', "");
Expect(1, 55203, '\p{Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(0, 55203, '\p{^Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(0, 55203, '\P{Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(1, 55203, '\P{^Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(0, 55204, '\p{Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(1, 55204, '\p{^Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(1, 55204, '\P{Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Expect(0, 55204, '\P{^Is_Hangul_Syllable_Type=__lvt_Syllable}', "");
Error('\p{Is_Hst= :=LVT}');
Error('\P{Is_Hst= :=LVT}');
Expect(1, 55203, '\p{Is_Hst:	lvt}', "");
Expect(0, 55203, '\p{^Is_Hst:	lvt}', "");
Expect(0, 55203, '\P{Is_Hst:	lvt}', "");
Expect(1, 55203, '\P{^Is_Hst:	lvt}', "");
Expect(0, 55204, '\p{Is_Hst:	lvt}', "");
Expect(1, 55204, '\p{^Is_Hst:	lvt}', "");
Expect(1, 55204, '\P{Is_Hst:	lvt}', "");
Expect(0, 55204, '\P{^Is_Hst:	lvt}', "");
Expect(1, 55203, '\p{Is_Hst=_lvt}', "");
Expect(0, 55203, '\p{^Is_Hst=_lvt}', "");
Expect(0, 55203, '\P{Is_Hst=_lvt}', "");
Expect(1, 55203, '\P{^Is_Hst=_lvt}', "");
Expect(0, 55204, '\p{Is_Hst=_lvt}', "");
Expect(1, 55204, '\p{^Is_Hst=_lvt}', "");
Expect(1, 55204, '\P{Is_Hst=_lvt}', "");
Expect(0, 55204, '\P{^Is_Hst=_lvt}', "");
Error('\p{Hangul_Syllable_Type=/a/__NOT_Applicable}');
Error('\P{Hangul_Syllable_Type=/a/__NOT_Applicable}');
Expect(1, 55292, '\p{Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\p{^Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\P{Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\P{^Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\p{Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\p{^Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\P{Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\P{^Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\p{Hangul_Syllable_Type=  Not_applicable}', "");
Expect(0, 55292, '\p{^Hangul_Syllable_Type=  Not_applicable}', "");
Expect(0, 55292, '\P{Hangul_Syllable_Type=  Not_applicable}', "");
Expect(1, 55292, '\P{^Hangul_Syllable_Type=  Not_applicable}', "");
Expect(0, 55291, '\p{Hangul_Syllable_Type=  Not_applicable}', "");
Expect(1, 55291, '\p{^Hangul_Syllable_Type=  Not_applicable}', "");
Expect(1, 55291, '\P{Hangul_Syllable_Type=  Not_applicable}', "");
Expect(0, 55291, '\P{^Hangul_Syllable_Type=  Not_applicable}', "");
Error('\p{Hst=:=	NA}');
Error('\P{Hst=:=	NA}');
Expect(1, 55292, '\p{Hst:   na}', "");
Expect(0, 55292, '\p{^Hst:   na}', "");
Expect(0, 55292, '\P{Hst:   na}', "");
Expect(1, 55292, '\P{^Hst:   na}', "");
Expect(0, 55291, '\p{Hst:   na}', "");
Expect(1, 55291, '\p{^Hst:   na}', "");
Expect(1, 55291, '\P{Hst:   na}', "");
Expect(0, 55291, '\P{^Hst:   na}', "");
Expect(1, 55292, '\p{Hst=_-na}', "");
Expect(0, 55292, '\p{^Hst=_-na}', "");
Expect(0, 55292, '\P{Hst=_-na}', "");
Expect(1, 55292, '\P{^Hst=_-na}', "");
Expect(0, 55291, '\p{Hst=_-na}', "");
Expect(1, 55291, '\p{^Hst=_-na}', "");
Expect(1, 55291, '\P{Hst=_-na}', "");
Expect(0, 55291, '\P{^Hst=_-na}', "");
Error('\p{Is_Hangul_Syllable_Type=-NOT_Applicable:=}');
Error('\P{Is_Hangul_Syllable_Type=-NOT_Applicable:=}');
Expect(1, 55292, '\p{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\p{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55292, '\P{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\P{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\p{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\p{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55291, '\P{Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(0, 55291, '\P{^Is_Hangul_Syllable_Type=notapplicable}', "");
Expect(1, 55292, '\p{Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(0, 55292, '\p{^Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(0, 55292, '\P{Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(1, 55292, '\P{^Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(0, 55291, '\p{Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(1, 55291, '\p{^Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(1, 55291, '\P{Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Expect(0, 55291, '\P{^Is_Hangul_Syllable_Type=-Not_Applicable}', "");
Error('\p{Is_Hst=:=-_NA}');
Error('\P{Is_Hst=:=-_NA}');
Expect(1, 55292, '\p{Is_Hst=na}', "");
Expect(0, 55292, '\p{^Is_Hst=na}', "");
Expect(0, 55292, '\P{Is_Hst=na}', "");
Expect(1, 55292, '\P{^Is_Hst=na}', "");
Expect(0, 55291, '\p{Is_Hst=na}', "");
Expect(1, 55291, '\p{^Is_Hst=na}', "");
Expect(1, 55291, '\P{Is_Hst=na}', "");
Expect(0, 55291, '\P{^Is_Hst=na}', "");
Expect(1, 55292, '\p{Is_Hst=__NA}', "");
Expect(0, 55292, '\p{^Is_Hst=__NA}', "");
Expect(0, 55292, '\P{Is_Hst=__NA}', "");
Expect(1, 55292, '\P{^Is_Hst=__NA}', "");
Expect(0, 55291, '\p{Is_Hst=__NA}', "");
Expect(1, 55291, '\p{^Is_Hst=__NA}', "");
Expect(1, 55291, '\P{Is_Hst=__NA}', "");
Expect(0, 55291, '\P{^Is_Hst=__NA}', "");
Error('\p{Hangul_Syllable_Type: -	Trailing_Jamo:=}');
Error('\P{Hangul_Syllable_Type: -	Trailing_Jamo:=}');
Expect(1, 55291, '\p{Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\p{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\P{Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\P{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\p{Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\p{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\P{Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\P{^Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\p{Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(0, 55291, '\p{^Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(0, 55291, '\P{Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(1, 55291, '\P{^Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(0, 55292, '\p{Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(1, 55292, '\p{^Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(1, 55292, '\P{Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Expect(0, 55292, '\P{^Hangul_Syllable_Type=  TRAILING_JAMO}', "");
Error('\p{Hst= -T:=}');
Error('\P{Hst= -T:=}');
Expect(1, 55291, '\p{Hst=t}', "");
Expect(0, 55291, '\p{^Hst=t}', "");
Expect(0, 55291, '\P{Hst=t}', "");
Expect(1, 55291, '\P{^Hst=t}', "");
Expect(0, 55292, '\p{Hst=t}', "");
Expect(1, 55292, '\p{^Hst=t}', "");
Expect(1, 55292, '\P{Hst=t}', "");
Expect(0, 55292, '\P{^Hst=t}', "");
Expect(1, 55291, '\p{Hst=__T}', "");
Expect(0, 55291, '\p{^Hst=__T}', "");
Expect(0, 55291, '\P{Hst=__T}', "");
Expect(1, 55291, '\P{^Hst=__T}', "");
Expect(0, 55292, '\p{Hst=__T}', "");
Expect(1, 55292, '\p{^Hst=__T}', "");
Expect(1, 55292, '\P{Hst=__T}', "");
Expect(0, 55292, '\P{^Hst=__T}', "");
Error('\p{Is_Hangul_Syllable_Type=-	trailing_Jamo:=}');
Error('\P{Is_Hangul_Syllable_Type=-	trailing_Jamo:=}');
Expect(1, 55291, '\p{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\p{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55291, '\P{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\P{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\p{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\p{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55292, '\P{Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(0, 55292, '\P{^Is_Hangul_Syllable_Type=trailingjamo}', "");
Expect(1, 55291, '\p{Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(0, 55291, '\p{^Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(0, 55291, '\P{Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(1, 55291, '\P{^Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(0, 55292, '\p{Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(1, 55292, '\p{^Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(1, 55292, '\P{Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Expect(0, 55292, '\P{^Is_Hangul_Syllable_Type=_-Trailing_jamo}', "");
Error('\p{Is_Hst=:=-t}');
Error('\P{Is_Hst=:=-t}');
Expect(1, 55291, '\p{Is_Hst=t}', "");
Expect(0, 55291, '\p{^Is_Hst=t}', "");
Expect(0, 55291, '\P{Is_Hst=t}', "");
Expect(1, 55291, '\P{^Is_Hst=t}', "");
Expect(0, 55292, '\p{Is_Hst=t}', "");
Expect(1, 55292, '\p{^Is_Hst=t}', "");
Expect(1, 55292, '\P{Is_Hst=t}', "");
Expect(0, 55292, '\P{^Is_Hst=t}', "");
Expect(1, 55291, '\p{Is_Hst= T}', "");
Expect(0, 55291, '\p{^Is_Hst= T}', "");
Expect(0, 55291, '\P{Is_Hst= T}', "");
Expect(1, 55291, '\P{^Is_Hst= T}', "");
Expect(0, 55292, '\p{Is_Hst= T}', "");
Expect(1, 55292, '\p{^Is_Hst= T}', "");
Expect(1, 55292, '\P{Is_Hst= T}', "");
Expect(0, 55292, '\P{^Is_Hst= T}', "");
Error('\p{Hangul_Syllable_Type=/a/_ Vowel_jamo}');
Error('\P{Hangul_Syllable_Type=/a/_ Vowel_jamo}');
Expect(1, 55238, '\p{Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\p{^Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\P{Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\P{^Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\p{Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\p{^Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\P{Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\P{^Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\p{Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(0, 55238, '\p{^Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(0, 55238, '\P{Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(1, 55238, '\P{^Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(0, 55239, '\p{Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(1, 55239, '\p{^Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(1, 55239, '\P{Hangul_Syllable_Type:-_Vowel_jamo}', "");
Expect(0, 55239, '\P{^Hangul_Syllable_Type:-_Vowel_jamo}', "");
Error('\p{Hst: V:=}');
Error('\P{Hst: V:=}');
Expect(1, 55238, '\p{Hst=v}', "");
Expect(0, 55238, '\p{^Hst=v}', "");
Expect(0, 55238, '\P{Hst=v}', "");
Expect(1, 55238, '\P{^Hst=v}', "");
Expect(0, 55239, '\p{Hst=v}', "");
Expect(1, 55239, '\p{^Hst=v}', "");
Expect(1, 55239, '\P{Hst=v}', "");
Expect(0, 55239, '\P{^Hst=v}', "");
Expect(1, 55238, '\p{Hst=_-V}', "");
Expect(0, 55238, '\p{^Hst=_-V}', "");
Expect(0, 55238, '\P{Hst=_-V}', "");
Expect(1, 55238, '\P{^Hst=_-V}', "");
Expect(0, 55239, '\p{Hst=_-V}', "");
Expect(1, 55239, '\p{^Hst=_-V}', "");
Expect(1, 55239, '\P{Hst=_-V}', "");
Expect(0, 55239, '\P{^Hst=_-V}', "");
Error('\p{Is_Hangul_Syllable_Type:	-:=Vowel_jamo}');
Error('\P{Is_Hangul_Syllable_Type:	-:=Vowel_jamo}');
Expect(1, 55238, '\p{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\p{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55238, '\P{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\P{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\p{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\p{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55239, '\P{Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(0, 55239, '\P{^Is_Hangul_Syllable_Type=voweljamo}', "");
Expect(1, 55238, '\p{Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(0, 55238, '\p{^Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(0, 55238, '\P{Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(1, 55238, '\P{^Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(0, 55239, '\p{Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(1, 55239, '\p{^Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(1, 55239, '\P{Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Expect(0, 55239, '\P{^Is_Hangul_Syllable_Type= 	vowel_Jamo}', "");
Error('\p{Is_Hst=_v:=}');
Error('\P{Is_Hst=_v:=}');
Expect(1, 55238, '\p{Is_Hst=v}', "");
Expect(0, 55238, '\p{^Is_Hst=v}', "");
Expect(0, 55238, '\P{Is_Hst=v}', "");
Expect(1, 55238, '\P{^Is_Hst=v}', "");
Expect(0, 55239, '\p{Is_Hst=v}', "");
Expect(1, 55239, '\p{^Is_Hst=v}', "");
Expect(1, 55239, '\P{Is_Hst=v}', "");
Expect(0, 55239, '\P{^Is_Hst=v}', "");
Expect(1, 55238, '\p{Is_Hst=	-v}', "");
Expect(0, 55238, '\p{^Is_Hst=	-v}', "");
Expect(0, 55238, '\P{Is_Hst=	-v}', "");
Expect(1, 55238, '\P{^Is_Hst=	-v}', "");
Expect(0, 55239, '\p{Is_Hst=	-v}', "");
Expect(1, 55239, '\p{^Is_Hst=	-v}', "");
Expect(1, 55239, '\P{Is_Hst=	-v}', "");
Expect(0, 55239, '\P{^Is_Hst=	-v}', "");
Error('\p{Joining_Group=:= -Ain}');
Error('\P{Joining_Group=:= -Ain}');
Expect(1, 1887, '\p{Joining_Group=ain}', "");
Expect(0, 1887, '\p{^Joining_Group=ain}', "");
Expect(0, 1887, '\P{Joining_Group=ain}', "");
Expect(1, 1887, '\P{^Joining_Group=ain}', "");
Expect(0, 1888, '\p{Joining_Group=ain}', "");
Expect(1, 1888, '\p{^Joining_Group=ain}', "");
Expect(1, 1888, '\P{Joining_Group=ain}', "");
Expect(0, 1888, '\P{^Joining_Group=ain}', "");
Expect(1, 1887, '\p{Joining_Group=		ain}', "");
Expect(0, 1887, '\p{^Joining_Group=		ain}', "");
Expect(0, 1887, '\P{Joining_Group=		ain}', "");
Expect(1, 1887, '\P{^Joining_Group=		ain}', "");
Expect(0, 1888, '\p{Joining_Group=		ain}', "");
Expect(1, 1888, '\p{^Joining_Group=		ain}', "");
Expect(1, 1888, '\P{Joining_Group=		ain}', "");
Expect(0, 1888, '\P{^Joining_Group=		ain}', "");
Error('\p{Jg:		_ain/a/}');
Error('\P{Jg:		_ain/a/}');
Expect(1, 1887, '\p{Jg=ain}', "");
Expect(0, 1887, '\p{^Jg=ain}', "");
Expect(0, 1887, '\P{Jg=ain}', "");
Expect(1, 1887, '\P{^Jg=ain}', "");
Expect(0, 1888, '\p{Jg=ain}', "");
Expect(1, 1888, '\p{^Jg=ain}', "");
Expect(1, 1888, '\P{Jg=ain}', "");
Expect(0, 1888, '\P{^Jg=ain}', "");
Expect(1, 1887, '\p{Jg=--ain}', "");
Expect(0, 1887, '\p{^Jg=--ain}', "");
Expect(0, 1887, '\P{Jg=--ain}', "");
Expect(1, 1887, '\P{^Jg=--ain}', "");
Expect(0, 1888, '\p{Jg=--ain}', "");
Expect(1, 1888, '\p{^Jg=--ain}', "");
Expect(1, 1888, '\P{Jg=--ain}', "");
Expect(0, 1888, '\P{^Jg=--ain}', "");
Error('\p{Is_Joining_Group: 	/a/ain}');
Error('\P{Is_Joining_Group: 	/a/ain}');
Expect(1, 1887, '\p{Is_Joining_Group=ain}', "");
Expect(0, 1887, '\p{^Is_Joining_Group=ain}', "");
Expect(0, 1887, '\P{Is_Joining_Group=ain}', "");
Expect(1, 1887, '\P{^Is_Joining_Group=ain}', "");
Expect(0, 1888, '\p{Is_Joining_Group=ain}', "");
Expect(1, 1888, '\p{^Is_Joining_Group=ain}', "");
Expect(1, 1888, '\P{Is_Joining_Group=ain}', "");
Expect(0, 1888, '\P{^Is_Joining_Group=ain}', "");
Expect(1, 1887, '\p{Is_Joining_Group:   	-AIN}', "");
Expect(0, 1887, '\p{^Is_Joining_Group:   	-AIN}', "");
Expect(0, 1887, '\P{Is_Joining_Group:   	-AIN}', "");
Expect(1, 1887, '\P{^Is_Joining_Group:   	-AIN}', "");
Expect(0, 1888, '\p{Is_Joining_Group:   	-AIN}', "");
Expect(1, 1888, '\p{^Is_Joining_Group:   	-AIN}', "");
Expect(1, 1888, '\P{Is_Joining_Group:   	-AIN}', "");
Expect(0, 1888, '\P{^Is_Joining_Group:   	-AIN}', "");
Error('\p{Is_Jg=/a/Ain}');
Error('\P{Is_Jg=/a/Ain}');
Expect(1, 1887, '\p{Is_Jg=ain}', "");
Expect(0, 1887, '\p{^Is_Jg=ain}', "");
Expect(0, 1887, '\P{Is_Jg=ain}', "");
Expect(1, 1887, '\P{^Is_Jg=ain}', "");
Expect(0, 1888, '\p{Is_Jg=ain}', "");
Expect(1, 1888, '\p{^Is_Jg=ain}', "");
Expect(1, 1888, '\P{Is_Jg=ain}', "");
Expect(0, 1888, '\P{^Is_Jg=ain}', "");
Expect(1, 1887, '\p{Is_Jg=_-AIN}', "");
Expect(0, 1887, '\p{^Is_Jg=_-AIN}', "");
Expect(0, 1887, '\P{Is_Jg=_-AIN}', "");
Expect(1, 1887, '\P{^Is_Jg=_-AIN}', "");
Expect(0, 1888, '\p{Is_Jg=_-AIN}', "");
Expect(1, 1888, '\p{^Is_Jg=_-AIN}', "");
Expect(1, 1888, '\P{Is_Jg=_-AIN}', "");
Expect(0, 1888, '\P{^Is_Jg=_-AIN}', "");
Error('\p{Joining_Group= -Alaph/a/}');
Error('\P{Joining_Group= -Alaph/a/}');
Expect(1, 1808, '\p{Joining_Group=alaph}', "");
Expect(0, 1808, '\p{^Joining_Group=alaph}', "");
Expect(0, 1808, '\P{Joining_Group=alaph}', "");
Expect(1, 1808, '\P{^Joining_Group=alaph}', "");
Expect(0, 1809, '\p{Joining_Group=alaph}', "");
Expect(1, 1809, '\p{^Joining_Group=alaph}', "");
Expect(1, 1809, '\P{Joining_Group=alaph}', "");
Expect(0, 1809, '\P{^Joining_Group=alaph}', "");
Expect(1, 1808, '\p{Joining_Group=_ALAPH}', "");
Expect(0, 1808, '\p{^Joining_Group=_ALAPH}', "");
Expect(0, 1808, '\P{Joining_Group=_ALAPH}', "");
Expect(1, 1808, '\P{^Joining_Group=_ALAPH}', "");
Expect(0, 1809, '\p{Joining_Group=_ALAPH}', "");
Expect(1, 1809, '\p{^Joining_Group=_ALAPH}', "");
Expect(1, 1809, '\P{Joining_Group=_ALAPH}', "");
Expect(0, 1809, '\P{^Joining_Group=_ALAPH}', "");
Error('\p{Jg= Alaph:=}');
Error('\P{Jg= Alaph:=}');
Expect(1, 1808, '\p{Jg=alaph}', "");
Expect(0, 1808, '\p{^Jg=alaph}', "");
Expect(0, 1808, '\P{Jg=alaph}', "");
Expect(1, 1808, '\P{^Jg=alaph}', "");
Expect(0, 1809, '\p{Jg=alaph}', "");
Expect(1, 1809, '\p{^Jg=alaph}', "");
Expect(1, 1809, '\P{Jg=alaph}', "");
Expect(0, 1809, '\P{^Jg=alaph}', "");
Expect(1, 1808, '\p{Jg=	_ALAPH}', "");
Expect(0, 1808, '\p{^Jg=	_ALAPH}', "");
Expect(0, 1808, '\P{Jg=	_ALAPH}', "");
Expect(1, 1808, '\P{^Jg=	_ALAPH}', "");
Expect(0, 1809, '\p{Jg=	_ALAPH}', "");
Expect(1, 1809, '\p{^Jg=	_ALAPH}', "");
Expect(1, 1809, '\P{Jg=	_ALAPH}', "");
Expect(0, 1809, '\P{^Jg=	_ALAPH}', "");
Error('\p{Is_Joining_Group=	/a/Alaph}');
Error('\P{Is_Joining_Group=	/a/Alaph}');
Expect(1, 1808, '\p{Is_Joining_Group=alaph}', "");
Expect(0, 1808, '\p{^Is_Joining_Group=alaph}', "");
Expect(0, 1808, '\P{Is_Joining_Group=alaph}', "");
Expect(1, 1808, '\P{^Is_Joining_Group=alaph}', "");
Expect(0, 1809, '\p{Is_Joining_Group=alaph}', "");
Expect(1, 1809, '\p{^Is_Joining_Group=alaph}', "");
Expect(1, 1809, '\P{Is_Joining_Group=alaph}', "");
Expect(0, 1809, '\P{^Is_Joining_Group=alaph}', "");
Expect(1, 1808, '\p{Is_Joining_Group:	-Alaph}', "");
Expect(0, 1808, '\p{^Is_Joining_Group:	-Alaph}', "");
Expect(0, 1808, '\P{Is_Joining_Group:	-Alaph}', "");
Expect(1, 1808, '\P{^Is_Joining_Group:	-Alaph}', "");
Expect(0, 1809, '\p{Is_Joining_Group:	-Alaph}', "");
Expect(1, 1809, '\p{^Is_Joining_Group:	-Alaph}', "");
Expect(1, 1809, '\P{Is_Joining_Group:	-Alaph}', "");
Expect(0, 1809, '\P{^Is_Joining_Group:	-Alaph}', "");
Error('\p{Is_Jg:	-Alaph:=}');
Error('\P{Is_Jg:	-Alaph:=}');
Expect(1, 1808, '\p{Is_Jg=alaph}', "");
Expect(0, 1808, '\p{^Is_Jg=alaph}', "");
Expect(0, 1808, '\P{Is_Jg=alaph}', "");
Expect(1, 1808, '\P{^Is_Jg=alaph}', "");
Expect(0, 1809, '\p{Is_Jg=alaph}', "");
Expect(1, 1809, '\p{^Is_Jg=alaph}', "");
Expect(1, 1809, '\P{Is_Jg=alaph}', "");
Expect(0, 1809, '\P{^Is_Jg=alaph}', "");
Expect(1, 1808, '\p{Is_Jg:		Alaph}', "");
Expect(0, 1808, '\p{^Is_Jg:		Alaph}', "");
Expect(0, 1808, '\P{Is_Jg:		Alaph}', "");
Expect(1, 1808, '\P{^Is_Jg:		Alaph}', "");
Expect(0, 1809, '\p{Is_Jg:		Alaph}', "");
Expect(1, 1809, '\p{^Is_Jg:		Alaph}', "");
Expect(1, 1809, '\P{Is_Jg:		Alaph}', "");
Expect(0, 1809, '\P{^Is_Jg:		Alaph}', "");
Error('\p{Joining_Group:	/a/	-ALEF}');
Error('\P{Joining_Group:	/a/	-ALEF}');
Expect(1, 1908, '\p{Joining_Group=alef}', "");
Expect(0, 1908, '\p{^Joining_Group=alef}', "");
Expect(0, 1908, '\P{Joining_Group=alef}', "");
Expect(1, 1908, '\P{^Joining_Group=alef}', "");
Expect(0, 1909, '\p{Joining_Group=alef}', "");
Expect(1, 1909, '\p{^Joining_Group=alef}', "");
Expect(1, 1909, '\P{Joining_Group=alef}', "");
Expect(0, 1909, '\P{^Joining_Group=alef}', "");
Expect(1, 1908, '\p{Joining_Group=_Alef}', "");
Expect(0, 1908, '\p{^Joining_Group=_Alef}', "");
Expect(0, 1908, '\P{Joining_Group=_Alef}', "");
Expect(1, 1908, '\P{^Joining_Group=_Alef}', "");
Expect(0, 1909, '\p{Joining_Group=_Alef}', "");
Expect(1, 1909, '\p{^Joining_Group=_Alef}', "");
Expect(1, 1909, '\P{Joining_Group=_Alef}', "");
Expect(0, 1909, '\P{^Joining_Group=_Alef}', "");
Error('\p{Jg=-alef:=}');
Error('\P{Jg=-alef:=}');
Expect(1, 1908, '\p{Jg:alef}', "");
Expect(0, 1908, '\p{^Jg:alef}', "");
Expect(0, 1908, '\P{Jg:alef}', "");
Expect(1, 1908, '\P{^Jg:alef}', "");
Expect(0, 1909, '\p{Jg:alef}', "");
Expect(1, 1909, '\p{^Jg:alef}', "");
Expect(1, 1909, '\P{Jg:alef}', "");
Expect(0, 1909, '\P{^Jg:alef}', "");
Expect(1, 1908, '\p{Jg=__Alef}', "");
Expect(0, 1908, '\p{^Jg=__Alef}', "");
Expect(0, 1908, '\P{Jg=__Alef}', "");
Expect(1, 1908, '\P{^Jg=__Alef}', "");
Expect(0, 1909, '\p{Jg=__Alef}', "");
Expect(1, 1909, '\p{^Jg=__Alef}', "");
Expect(1, 1909, '\P{Jg=__Alef}', "");
Expect(0, 1909, '\P{^Jg=__Alef}', "");
Error('\p{Is_Joining_Group=	 ALEF/a/}');
Error('\P{Is_Joining_Group=	 ALEF/a/}');
Expect(1, 1908, '\p{Is_Joining_Group=alef}', "");
Expect(0, 1908, '\p{^Is_Joining_Group=alef}', "");
Expect(0, 1908, '\P{Is_Joining_Group=alef}', "");
Expect(1, 1908, '\P{^Is_Joining_Group=alef}', "");
Expect(0, 1909, '\p{Is_Joining_Group=alef}', "");
Expect(1, 1909, '\p{^Is_Joining_Group=alef}', "");
Expect(1, 1909, '\P{Is_Joining_Group=alef}', "");
Expect(0, 1909, '\P{^Is_Joining_Group=alef}', "");
Error('\p{Is_Jg:	:=-_Alef}');
Error('\P{Is_Jg:	:=-_Alef}');
Expect(1, 1908, '\p{Is_Jg:	alef}', "");
Expect(0, 1908, '\p{^Is_Jg:	alef}', "");
Expect(0, 1908, '\P{Is_Jg:	alef}', "");
Expect(1, 1908, '\P{^Is_Jg:	alef}', "");
Expect(0, 1909, '\p{Is_Jg:	alef}', "");
Expect(1, 1909, '\p{^Is_Jg:	alef}', "");
Expect(1, 1909, '\P{Is_Jg:	alef}', "");
Expect(0, 1909, '\P{^Is_Jg:	alef}', "");
Expect(1, 1908, '\p{Is_Jg: -Alef}', "");
Expect(0, 1908, '\p{^Is_Jg: -Alef}', "");
Expect(0, 1908, '\P{Is_Jg: -Alef}', "");
Expect(1, 1908, '\P{^Is_Jg: -Alef}', "");
Expect(0, 1909, '\p{Is_Jg: -Alef}', "");
Expect(1, 1909, '\p{^Is_Jg: -Alef}', "");
Expect(1, 1909, '\P{Is_Jg: -Alef}', "");
Expect(0, 1909, '\P{^Is_Jg: -Alef}', "");
Error('\p{Joining_Group=	 Beh/a/}');
Error('\P{Joining_Group=	 Beh/a/}');
Expect(1, 2208, '\p{Joining_Group=beh}', "");
Expect(0, 2208, '\p{^Joining_Group=beh}', "");
Expect(0, 2208, '\P{Joining_Group=beh}', "");
Expect(1, 2208, '\P{^Joining_Group=beh}', "");
Expect(0, 2209, '\p{Joining_Group=beh}', "");
Expect(1, 2209, '\p{^Joining_Group=beh}', "");
Expect(1, 2209, '\P{Joining_Group=beh}', "");
Expect(0, 2209, '\P{^Joining_Group=beh}', "");
Expect(1, 2208, '\p{Joining_Group=_	Beh}', "");
Expect(0, 2208, '\p{^Joining_Group=_	Beh}', "");
Expect(0, 2208, '\P{Joining_Group=_	Beh}', "");
Expect(1, 2208, '\P{^Joining_Group=_	Beh}', "");
Expect(0, 2209, '\p{Joining_Group=_	Beh}', "");
Expect(1, 2209, '\p{^Joining_Group=_	Beh}', "");
Expect(1, 2209, '\P{Joining_Group=_	Beh}', "");
Expect(0, 2209, '\P{^Joining_Group=_	Beh}', "");
Error('\p{Jg=:=	Beh}');
Error('\P{Jg=:=	Beh}');
Expect(1, 2208, '\p{Jg=beh}', "");
Expect(0, 2208, '\p{^Jg=beh}', "");
Expect(0, 2208, '\P{Jg=beh}', "");
Expect(1, 2208, '\P{^Jg=beh}', "");
Expect(0, 2209, '\p{Jg=beh}', "");
Expect(1, 2209, '\p{^Jg=beh}', "");
Expect(1, 2209, '\P{Jg=beh}', "");
Expect(0, 2209, '\P{^Jg=beh}', "");
Expect(1, 2208, '\p{Jg= Beh}', "");
Expect(0, 2208, '\p{^Jg= Beh}', "");
Expect(0, 2208, '\P{Jg= Beh}', "");
Expect(1, 2208, '\P{^Jg= Beh}', "");
Expect(0, 2209, '\p{Jg= Beh}', "");
Expect(1, 2209, '\p{^Jg= Beh}', "");
Expect(1, 2209, '\P{Jg= Beh}', "");
Expect(0, 2209, '\P{^Jg= Beh}', "");
Error('\p{Is_Joining_Group=-:=BEH}');
Error('\P{Is_Joining_Group=-:=BEH}');
Expect(1, 2208, '\p{Is_Joining_Group=beh}', "");
Expect(0, 2208, '\p{^Is_Joining_Group=beh}', "");
Expect(0, 2208, '\P{Is_Joining_Group=beh}', "");
Expect(1, 2208, '\P{^Is_Joining_Group=beh}', "");
Expect(0, 2209, '\p{Is_Joining_Group=beh}', "");
Expect(1, 2209, '\p{^Is_Joining_Group=beh}', "");
Expect(1, 2209, '\P{Is_Joining_Group=beh}', "");
Expect(0, 2209, '\P{^Is_Joining_Group=beh}', "");
Expect(1, 2208, '\p{Is_Joining_Group=		BEH}', "");
Expect(0, 2208, '\p{^Is_Joining_Group=		BEH}', "");
Expect(0, 2208, '\P{Is_Joining_Group=		BEH}', "");
Expect(1, 2208, '\P{^Is_Joining_Group=		BEH}', "");
Expect(0, 2209, '\p{Is_Joining_Group=		BEH}', "");
Expect(1, 2209, '\p{^Is_Joining_Group=		BEH}', "");
Expect(1, 2209, '\P{Is_Joining_Group=		BEH}', "");
Expect(0, 2209, '\P{^Is_Joining_Group=		BEH}', "");
Error('\p{Is_Jg=/a/-BEH}');
Error('\P{Is_Jg=/a/-BEH}');
Expect(1, 2208, '\p{Is_Jg=beh}', "");
Expect(0, 2208, '\p{^Is_Jg=beh}', "");
Expect(0, 2208, '\P{Is_Jg=beh}', "");
Expect(1, 2208, '\P{^Is_Jg=beh}', "");
Expect(0, 2209, '\p{Is_Jg=beh}', "");
Expect(1, 2209, '\p{^Is_Jg=beh}', "");
Expect(1, 2209, '\P{Is_Jg=beh}', "");
Expect(0, 2209, '\P{^Is_Jg=beh}', "");
Expect(1, 2208, '\p{Is_Jg=	beh}', "");
Expect(0, 2208, '\p{^Is_Jg=	beh}', "");
Expect(0, 2208, '\P{Is_Jg=	beh}', "");
Expect(1, 2208, '\P{^Is_Jg=	beh}', "");
Expect(0, 2209, '\p{Is_Jg=	beh}', "");
Expect(1, 2209, '\p{^Is_Jg=	beh}', "");
Expect(1, 2209, '\P{Is_Jg=	beh}', "");
Expect(0, 2209, '\P{^Is_Jg=	beh}', "");
Error('\p{Joining_Group=-:=beth}');
Error('\P{Joining_Group=-:=beth}');
Expect(1, 1837, '\p{Joining_Group: beth}', "");
Expect(0, 1837, '\p{^Joining_Group: beth}', "");
Expect(0, 1837, '\P{Joining_Group: beth}', "");
Expect(1, 1837, '\P{^Joining_Group: beth}', "");
Expect(0, 1838, '\p{Joining_Group: beth}', "");
Expect(1, 1838, '\p{^Joining_Group: beth}', "");
Expect(1, 1838, '\P{Joining_Group: beth}', "");
Expect(0, 1838, '\P{^Joining_Group: beth}', "");
Expect(1, 1837, '\p{Joining_Group=_BETH}', "");
Expect(0, 1837, '\p{^Joining_Group=_BETH}', "");
Expect(0, 1837, '\P{Joining_Group=_BETH}', "");
Expect(1, 1837, '\P{^Joining_Group=_BETH}', "");
Expect(0, 1838, '\p{Joining_Group=_BETH}', "");
Expect(1, 1838, '\p{^Joining_Group=_BETH}', "");
Expect(1, 1838, '\P{Joining_Group=_BETH}', "");
Expect(0, 1838, '\P{^Joining_Group=_BETH}', "");
Error('\p{Jg=:=_ beth}');
Error('\P{Jg=:=_ beth}');
Expect(1, 1837, '\p{Jg=beth}', "");
Expect(0, 1837, '\p{^Jg=beth}', "");
Expect(0, 1837, '\P{Jg=beth}', "");
Expect(1, 1837, '\P{^Jg=beth}', "");
Expect(0, 1838, '\p{Jg=beth}', "");
Expect(1, 1838, '\p{^Jg=beth}', "");
Expect(1, 1838, '\P{Jg=beth}', "");
Expect(0, 1838, '\P{^Jg=beth}', "");
Expect(1, 1837, '\p{Jg:	BETH}', "");
Expect(0, 1837, '\p{^Jg:	BETH}', "");
Expect(0, 1837, '\P{Jg:	BETH}', "");
Expect(1, 1837, '\P{^Jg:	BETH}', "");
Expect(0, 1838, '\p{Jg:	BETH}', "");
Expect(1, 1838, '\p{^Jg:	BETH}', "");
Expect(1, 1838, '\P{Jg:	BETH}', "");
Expect(0, 1838, '\P{^Jg:	BETH}', "");
Error('\p{Is_Joining_Group=/a/		Beth}');
Error('\P{Is_Joining_Group=/a/		Beth}');
Expect(1, 1837, '\p{Is_Joining_Group: beth}', "");
Expect(0, 1837, '\p{^Is_Joining_Group: beth}', "");
Expect(0, 1837, '\P{Is_Joining_Group: beth}', "");
Expect(1, 1837, '\P{^Is_Joining_Group: beth}', "");
Expect(0, 1838, '\p{Is_Joining_Group: beth}', "");
Expect(1, 1838, '\p{^Is_Joining_Group: beth}', "");
Expect(1, 1838, '\P{Is_Joining_Group: beth}', "");
Expect(0, 1838, '\P{^Is_Joining_Group: beth}', "");
Expect(1, 1837, '\p{Is_Joining_Group=	BETH}', "");
Expect(0, 1837, '\p{^Is_Joining_Group=	BETH}', "");
Expect(0, 1837, '\P{Is_Joining_Group=	BETH}', "");
Expect(1, 1837, '\P{^Is_Joining_Group=	BETH}', "");
Expect(0, 1838, '\p{Is_Joining_Group=	BETH}', "");
Expect(1, 1838, '\p{^Is_Joining_Group=	BETH}', "");
Expect(1, 1838, '\P{Is_Joining_Group=	BETH}', "");
Expect(0, 1838, '\P{^Is_Joining_Group=	BETH}', "");
Error('\p{Is_Jg:	:= Beth}');
Error('\P{Is_Jg:	:= Beth}');
Expect(1, 1837, '\p{Is_Jg=beth}', "");
Expect(0, 1837, '\p{^Is_Jg=beth}', "");
Expect(0, 1837, '\P{Is_Jg=beth}', "");
Expect(1, 1837, '\P{^Is_Jg=beth}', "");
Expect(0, 1838, '\p{Is_Jg=beth}', "");
Expect(1, 1838, '\p{^Is_Jg=beth}', "");
Expect(1, 1838, '\P{Is_Jg=beth}', "");
Expect(0, 1838, '\P{^Is_Jg=beth}', "");
Expect(1, 1837, '\p{Is_Jg=_ beth}', "");
Expect(0, 1837, '\p{^Is_Jg=_ beth}', "");
Expect(0, 1837, '\P{Is_Jg=_ beth}', "");
Expect(1, 1837, '\P{^Is_Jg=_ beth}', "");
Expect(0, 1838, '\p{Is_Jg=_ beth}', "");
Expect(1, 1838, '\p{^Is_Jg=_ beth}', "");
Expect(1, 1838, '\P{Is_Jg=_ beth}', "");
Expect(0, 1838, '\P{^Is_Jg=_ beth}', "");
Error('\p{Joining_Group=-:=BURUSHASKI_yeh_Barree}');
Error('\P{Joining_Group=-:=BURUSHASKI_yeh_Barree}');
Expect(1, 1915, '\p{Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Joining_Group= -burushaski_Yeh_barree}', "");
Expect(0, 1915, '\p{^Joining_Group= -burushaski_Yeh_barree}', "");
Expect(0, 1915, '\P{Joining_Group= -burushaski_Yeh_barree}', "");
Expect(1, 1915, '\P{^Joining_Group= -burushaski_Yeh_barree}', "");
Expect(0, 1916, '\p{Joining_Group= -burushaski_Yeh_barree}', "");
Expect(1, 1916, '\p{^Joining_Group= -burushaski_Yeh_barree}', "");
Expect(1, 1916, '\P{Joining_Group= -burushaski_Yeh_barree}', "");
Expect(0, 1916, '\P{^Joining_Group= -burushaski_Yeh_barree}', "");
Error('\p{Jg=		Burushaski_Yeh_BARREE:=}');
Error('\P{Jg=		Burushaski_Yeh_BARREE:=}');
Expect(1, 1915, '\p{Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Jg=_burushaski_Yeh_barree}', "");
Expect(0, 1915, '\p{^Jg=_burushaski_Yeh_barree}', "");
Expect(0, 1915, '\P{Jg=_burushaski_Yeh_barree}', "");
Expect(1, 1915, '\P{^Jg=_burushaski_Yeh_barree}', "");
Expect(0, 1916, '\p{Jg=_burushaski_Yeh_barree}', "");
Expect(1, 1916, '\p{^Jg=_burushaski_Yeh_barree}', "");
Expect(1, 1916, '\P{Jg=_burushaski_Yeh_barree}', "");
Expect(0, 1916, '\P{^Jg=_burushaski_Yeh_barree}', "");
Error('\p{Is_Joining_Group= Burushaski_Yeh_Barree/a/}');
Error('\P{Is_Joining_Group= Burushaski_Yeh_Barree/a/}');
Expect(1, 1915, '\p{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Is_Joining_Group=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Is_Joining_Group=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(0, 1915, '\p{^Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(0, 1915, '\P{Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(1, 1915, '\P{^Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(0, 1916, '\p{Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(1, 1916, '\p{^Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(1, 1916, '\P{Is_Joining_Group=		Burushaski_yeh_barree}', "");
Expect(0, 1916, '\P{^Is_Joining_Group=		Burushaski_yeh_barree}', "");
Error('\p{Is_Jg=_Burushaski_Yeh_barree/a/}');
Error('\P{Is_Jg=_Burushaski_Yeh_barree/a/}');
Expect(1, 1915, '\p{Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\p{^Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1915, '\P{Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\P{^Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\p{Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\p{^Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1916, '\P{Is_Jg=burushaskiyehbarree}', "");
Expect(0, 1916, '\P{^Is_Jg=burushaskiyehbarree}', "");
Expect(1, 1915, '\p{Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(0, 1915, '\p{^Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(0, 1915, '\P{Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(1, 1915, '\P{^Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(0, 1916, '\p{Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(1, 1916, '\p{^Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(1, 1916, '\P{Is_Jg= 	Burushaski_YEH_BARREE}', "");
Expect(0, 1916, '\P{^Is_Jg= 	Burushaski_YEH_BARREE}', "");
Error('\p{Joining_Group: := Dal}');
Error('\P{Joining_Group: := Dal}');
Expect(1, 1882, '\p{Joining_Group=dal}', "");
Expect(0, 1882, '\p{^Joining_Group=dal}', "");
Expect(0, 1882, '\P{Joining_Group=dal}', "");
Expect(1, 1882, '\P{^Joining_Group=dal}', "");
Expect(0, 1883, '\p{Joining_Group=dal}', "");
Expect(1, 1883, '\p{^Joining_Group=dal}', "");
Expect(1, 1883, '\P{Joining_Group=dal}', "");
Expect(0, 1883, '\P{^Joining_Group=dal}', "");
Expect(1, 1882, '\p{Joining_Group=_-DAL}', "");
Expect(0, 1882, '\p{^Joining_Group=_-DAL}', "");
Expect(0, 1882, '\P{Joining_Group=_-DAL}', "");
Expect(1, 1882, '\P{^Joining_Group=_-DAL}', "");
Expect(0, 1883, '\p{Joining_Group=_-DAL}', "");
Expect(1, 1883, '\p{^Joining_Group=_-DAL}', "");
Expect(1, 1883, '\P{Joining_Group=_-DAL}', "");
Expect(0, 1883, '\P{^Joining_Group=_-DAL}', "");
Error('\p{Jg=dal:=}');
Error('\P{Jg=dal:=}');
Expect(1, 1882, '\p{Jg=dal}', "");
Expect(0, 1882, '\p{^Jg=dal}', "");
Expect(0, 1882, '\P{Jg=dal}', "");
Expect(1, 1882, '\P{^Jg=dal}', "");
Expect(0, 1883, '\p{Jg=dal}', "");
Expect(1, 1883, '\p{^Jg=dal}', "");
Expect(1, 1883, '\P{Jg=dal}', "");
Expect(0, 1883, '\P{^Jg=dal}', "");
Expect(1, 1882, '\p{Jg=		dal}', "");
Expect(0, 1882, '\p{^Jg=		dal}', "");
Expect(0, 1882, '\P{Jg=		dal}', "");
Expect(1, 1882, '\P{^Jg=		dal}', "");
Expect(0, 1883, '\p{Jg=		dal}', "");
Expect(1, 1883, '\p{^Jg=		dal}', "");
Expect(1, 1883, '\P{Jg=		dal}', "");
Expect(0, 1883, '\P{^Jg=		dal}', "");
Error('\p{Is_Joining_Group=__Dal/a/}');
Error('\P{Is_Joining_Group=__Dal/a/}');
Expect(1, 1882, '\p{Is_Joining_Group=dal}', "");
Expect(0, 1882, '\p{^Is_Joining_Group=dal}', "");
Expect(0, 1882, '\P{Is_Joining_Group=dal}', "");
Expect(1, 1882, '\P{^Is_Joining_Group=dal}', "");
Expect(0, 1883, '\p{Is_Joining_Group=dal}', "");
Expect(1, 1883, '\p{^Is_Joining_Group=dal}', "");
Expect(1, 1883, '\P{Is_Joining_Group=dal}', "");
Expect(0, 1883, '\P{^Is_Joining_Group=dal}', "");
Expect(1, 1882, '\p{Is_Joining_Group=_-dal}', "");
Expect(0, 1882, '\p{^Is_Joining_Group=_-dal}', "");
Expect(0, 1882, '\P{Is_Joining_Group=_-dal}', "");
Expect(1, 1882, '\P{^Is_Joining_Group=_-dal}', "");
Expect(0, 1883, '\p{Is_Joining_Group=_-dal}', "");
Expect(1, 1883, '\p{^Is_Joining_Group=_-dal}', "");
Expect(1, 1883, '\P{Is_Joining_Group=_-dal}', "");
Expect(0, 1883, '\P{^Is_Joining_Group=_-dal}', "");
Error('\p{Is_Jg=	/a/DAL}');
Error('\P{Is_Jg=	/a/DAL}');
Expect(1, 1882, '\p{Is_Jg=dal}', "");
Expect(0, 1882, '\p{^Is_Jg=dal}', "");
Expect(0, 1882, '\P{Is_Jg=dal}', "");
Expect(1, 1882, '\P{^Is_Jg=dal}', "");
Expect(0, 1883, '\p{Is_Jg=dal}', "");
Expect(1, 1883, '\p{^Is_Jg=dal}', "");
Expect(1, 1883, '\P{Is_Jg=dal}', "");
Expect(0, 1883, '\P{^Is_Jg=dal}', "");
Expect(1, 1882, '\p{Is_Jg=-_DAL}', "");
Expect(0, 1882, '\p{^Is_Jg=-_DAL}', "");
Expect(0, 1882, '\P{Is_Jg=-_DAL}', "");
Expect(1, 1882, '\P{^Is_Jg=-_DAL}', "");
Expect(0, 1883, '\p{Is_Jg=-_DAL}', "");
Expect(1, 1883, '\p{^Is_Jg=-_DAL}', "");
Expect(1, 1883, '\P{Is_Jg=-_DAL}', "");
Expect(0, 1883, '\P{^Is_Jg=-_DAL}', "");
Error('\p{Joining_Group:/a/ 	dalath_rish}');
Error('\P{Joining_Group:/a/ 	dalath_rish}');
Expect(1, 1839, '\p{Joining_Group=dalathrish}', "");
Expect(0, 1839, '\p{^Joining_Group=dalathrish}', "");
Expect(0, 1839, '\P{Joining_Group=dalathrish}', "");
Expect(1, 1839, '\P{^Joining_Group=dalathrish}', "");
Expect(0, 1840, '\p{Joining_Group=dalathrish}', "");
Expect(1, 1840, '\p{^Joining_Group=dalathrish}', "");
Expect(1, 1840, '\P{Joining_Group=dalathrish}', "");
Expect(0, 1840, '\P{^Joining_Group=dalathrish}', "");
Expect(1, 1839, '\p{Joining_Group= _Dalath_Rish}', "");
Expect(0, 1839, '\p{^Joining_Group= _Dalath_Rish}', "");
Expect(0, 1839, '\P{Joining_Group= _Dalath_Rish}', "");
Expect(1, 1839, '\P{^Joining_Group= _Dalath_Rish}', "");
Expect(0, 1840, '\p{Joining_Group= _Dalath_Rish}', "");
Expect(1, 1840, '\p{^Joining_Group= _Dalath_Rish}', "");
Expect(1, 1840, '\P{Joining_Group= _Dalath_Rish}', "");
Expect(0, 1840, '\P{^Joining_Group= _Dalath_Rish}', "");
Error('\p{Jg=	/a/Dalath_RISH}');
Error('\P{Jg=	/a/Dalath_RISH}');
Expect(1, 1839, '\p{Jg:   dalathrish}', "");
Expect(0, 1839, '\p{^Jg:   dalathrish}', "");
Expect(0, 1839, '\P{Jg:   dalathrish}', "");
Expect(1, 1839, '\P{^Jg:   dalathrish}', "");
Expect(0, 1840, '\p{Jg:   dalathrish}', "");
Expect(1, 1840, '\p{^Jg:   dalathrish}', "");
Expect(1, 1840, '\P{Jg:   dalathrish}', "");
Expect(0, 1840, '\P{^Jg:   dalathrish}', "");
Expect(1, 1839, '\p{Jg=-dalath_RISH}', "");
Expect(0, 1839, '\p{^Jg=-dalath_RISH}', "");
Expect(0, 1839, '\P{Jg=-dalath_RISH}', "");
Expect(1, 1839, '\P{^Jg=-dalath_RISH}', "");
Expect(0, 1840, '\p{Jg=-dalath_RISH}', "");
Expect(1, 1840, '\p{^Jg=-dalath_RISH}', "");
Expect(1, 1840, '\P{Jg=-dalath_RISH}', "");
Expect(0, 1840, '\P{^Jg=-dalath_RISH}', "");
Error('\p{Is_Joining_Group=:=	_DALATH_RISH}');
Error('\P{Is_Joining_Group=:=	_DALATH_RISH}');
Expect(1, 1839, '\p{Is_Joining_Group=dalathrish}', "");
Expect(0, 1839, '\p{^Is_Joining_Group=dalathrish}', "");
Expect(0, 1839, '\P{Is_Joining_Group=dalathrish}', "");
Expect(1, 1839, '\P{^Is_Joining_Group=dalathrish}', "");
Expect(0, 1840, '\p{Is_Joining_Group=dalathrish}', "");
Expect(1, 1840, '\p{^Is_Joining_Group=dalathrish}', "");
Expect(1, 1840, '\P{Is_Joining_Group=dalathrish}', "");
Expect(0, 1840, '\P{^Is_Joining_Group=dalathrish}', "");
Expect(1, 1839, '\p{Is_Joining_Group:   --dalath_Rish}', "");
Expect(0, 1839, '\p{^Is_Joining_Group:   --dalath_Rish}', "");
Expect(0, 1839, '\P{Is_Joining_Group:   --dalath_Rish}', "");
Expect(1, 1839, '\P{^Is_Joining_Group:   --dalath_Rish}', "");
Expect(0, 1840, '\p{Is_Joining_Group:   --dalath_Rish}', "");
Expect(1, 1840, '\p{^Is_Joining_Group:   --dalath_Rish}', "");
Expect(1, 1840, '\P{Is_Joining_Group:   --dalath_Rish}', "");
Expect(0, 1840, '\P{^Is_Joining_Group:   --dalath_Rish}', "");
Error('\p{Is_Jg=_ Dalath_Rish:=}');
Error('\P{Is_Jg=_ Dalath_Rish:=}');
Expect(1, 1839, '\p{Is_Jg=dalathrish}', "");
Expect(0, 1839, '\p{^Is_Jg=dalathrish}', "");
Expect(0, 1839, '\P{Is_Jg=dalathrish}', "");
Expect(1, 1839, '\P{^Is_Jg=dalathrish}', "");
Expect(0, 1840, '\p{Is_Jg=dalathrish}', "");
Expect(1, 1840, '\p{^Is_Jg=dalathrish}', "");
Expect(1, 1840, '\P{Is_Jg=dalathrish}', "");
Expect(0, 1840, '\P{^Is_Jg=dalathrish}', "");
Expect(1, 1839, '\p{Is_Jg=-Dalath_RISH}', "");
Expect(0, 1839, '\p{^Is_Jg=-Dalath_RISH}', "");
Expect(0, 1839, '\P{Is_Jg=-Dalath_RISH}', "");
Expect(1, 1839, '\P{^Is_Jg=-Dalath_RISH}', "");
Expect(0, 1840, '\p{Is_Jg=-Dalath_RISH}', "");
Expect(1, 1840, '\p{^Is_Jg=-Dalath_RISH}', "");
Expect(1, 1840, '\P{Is_Jg=-Dalath_RISH}', "");
Expect(0, 1840, '\P{^Is_Jg=-Dalath_RISH}', "");
Error('\p{Joining_Group=_/a/E}');
Error('\P{Joining_Group=_/a/E}');
Expect(1, 1829, '\p{Joining_Group=e}', "");
Expect(0, 1829, '\p{^Joining_Group=e}', "");
Expect(0, 1829, '\P{Joining_Group=e}', "");
Expect(1, 1829, '\P{^Joining_Group=e}', "");
Expect(0, 1830, '\p{Joining_Group=e}', "");
Expect(1, 1830, '\p{^Joining_Group=e}', "");
Expect(1, 1830, '\P{Joining_Group=e}', "");
Expect(0, 1830, '\P{^Joining_Group=e}', "");
Expect(1, 1829, '\p{Joining_Group:   E}', "");
Expect(0, 1829, '\p{^Joining_Group:   E}', "");
Expect(0, 1829, '\P{Joining_Group:   E}', "");
Expect(1, 1829, '\P{^Joining_Group:   E}', "");
Expect(0, 1830, '\p{Joining_Group:   E}', "");
Expect(1, 1830, '\p{^Joining_Group:   E}', "");
Expect(1, 1830, '\P{Joining_Group:   E}', "");
Expect(0, 1830, '\P{^Joining_Group:   E}', "");
Error('\p{Jg=:=	e}');
Error('\P{Jg=:=	e}');
Expect(1, 1829, '\p{Jg=e}', "");
Expect(0, 1829, '\p{^Jg=e}', "");
Expect(0, 1829, '\P{Jg=e}', "");
Expect(1, 1829, '\P{^Jg=e}', "");
Expect(0, 1830, '\p{Jg=e}', "");
Expect(1, 1830, '\p{^Jg=e}', "");
Expect(1, 1830, '\P{Jg=e}', "");
Expect(0, 1830, '\P{^Jg=e}', "");
Expect(1, 1829, '\p{Jg=_e}', "");
Expect(0, 1829, '\p{^Jg=_e}', "");
Expect(0, 1829, '\P{Jg=_e}', "");
Expect(1, 1829, '\P{^Jg=_e}', "");
Expect(0, 1830, '\p{Jg=_e}', "");
Expect(1, 1830, '\p{^Jg=_e}', "");
Expect(1, 1830, '\P{Jg=_e}', "");
Expect(0, 1830, '\P{^Jg=_e}', "");
Error('\p{Is_Joining_Group=--E/a/}');
Error('\P{Is_Joining_Group=--E/a/}');
Expect(1, 1829, '\p{Is_Joining_Group=e}', "");
Expect(0, 1829, '\p{^Is_Joining_Group=e}', "");
Expect(0, 1829, '\P{Is_Joining_Group=e}', "");
Expect(1, 1829, '\P{^Is_Joining_Group=e}', "");
Expect(0, 1830, '\p{Is_Joining_Group=e}', "");
Expect(1, 1830, '\p{^Is_Joining_Group=e}', "");
Expect(1, 1830, '\P{Is_Joining_Group=e}', "");
Expect(0, 1830, '\P{^Is_Joining_Group=e}', "");
Expect(1, 1829, '\p{Is_Joining_Group=-E}', "");
Expect(0, 1829, '\p{^Is_Joining_Group=-E}', "");
Expect(0, 1829, '\P{Is_Joining_Group=-E}', "");
Expect(1, 1829, '\P{^Is_Joining_Group=-E}', "");
Expect(0, 1830, '\p{Is_Joining_Group=-E}', "");
Expect(1, 1830, '\p{^Is_Joining_Group=-E}', "");
Expect(1, 1830, '\P{Is_Joining_Group=-E}', "");
Expect(0, 1830, '\P{^Is_Joining_Group=-E}', "");
Error('\p{Is_Jg=_	E:=}');
Error('\P{Is_Jg=_	E:=}');
Expect(1, 1829, '\p{Is_Jg:   e}', "");
Expect(0, 1829, '\p{^Is_Jg:   e}', "");
Expect(0, 1829, '\P{Is_Jg:   e}', "");
Expect(1, 1829, '\P{^Is_Jg:   e}', "");
Expect(0, 1830, '\p{Is_Jg:   e}', "");
Expect(1, 1830, '\p{^Is_Jg:   e}', "");
Expect(1, 1830, '\P{Is_Jg:   e}', "");
Expect(0, 1830, '\P{^Is_Jg:   e}', "");
Expect(1, 1829, '\p{Is_Jg= -E}', "");
Expect(0, 1829, '\p{^Is_Jg= -E}', "");
Expect(0, 1829, '\P{Is_Jg= -E}', "");
Expect(1, 1829, '\P{^Is_Jg= -E}', "");
Expect(0, 1830, '\p{Is_Jg= -E}', "");
Expect(1, 1830, '\p{^Is_Jg= -E}', "");
Expect(1, 1830, '\P{Is_Jg= -E}', "");
Expect(0, 1830, '\P{^Is_Jg= -E}', "");
Error('\p{Joining_Group=	 farsi_Yeh/a/}');
Error('\P{Joining_Group=	 farsi_Yeh/a/}');
Expect(1, 1910, '\p{Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\p{^Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\P{Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\P{^Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\p{Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\p{^Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\P{Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\P{^Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\p{Joining_Group:  _Farsi_Yeh}', "");
Expect(0, 1910, '\p{^Joining_Group:  _Farsi_Yeh}', "");
Expect(0, 1910, '\P{Joining_Group:  _Farsi_Yeh}', "");
Expect(1, 1910, '\P{^Joining_Group:  _Farsi_Yeh}', "");
Expect(0, 1911, '\p{Joining_Group:  _Farsi_Yeh}', "");
Expect(1, 1911, '\p{^Joining_Group:  _Farsi_Yeh}', "");
Expect(1, 1911, '\P{Joining_Group:  _Farsi_Yeh}', "");
Expect(0, 1911, '\P{^Joining_Group:  _Farsi_Yeh}', "");
Error('\p{Jg=/a/	-FARSI_Yeh}');
Error('\P{Jg=/a/	-FARSI_Yeh}');
Expect(1, 1910, '\p{Jg=farsiyeh}', "");
Expect(0, 1910, '\p{^Jg=farsiyeh}', "");
Expect(0, 1910, '\P{Jg=farsiyeh}', "");
Expect(1, 1910, '\P{^Jg=farsiyeh}', "");
Expect(0, 1911, '\p{Jg=farsiyeh}', "");
Expect(1, 1911, '\p{^Jg=farsiyeh}', "");
Expect(1, 1911, '\P{Jg=farsiyeh}', "");
Expect(0, 1911, '\P{^Jg=farsiyeh}', "");
Expect(1, 1910, '\p{Jg=	 Farsi_Yeh}', "");
Expect(0, 1910, '\p{^Jg=	 Farsi_Yeh}', "");
Expect(0, 1910, '\P{Jg=	 Farsi_Yeh}', "");
Expect(1, 1910, '\P{^Jg=	 Farsi_Yeh}', "");
Expect(0, 1911, '\p{Jg=	 Farsi_Yeh}', "");
Expect(1, 1911, '\p{^Jg=	 Farsi_Yeh}', "");
Expect(1, 1911, '\P{Jg=	 Farsi_Yeh}', "");
Expect(0, 1911, '\P{^Jg=	 Farsi_Yeh}', "");
Error('\p{Is_Joining_Group=/a/Farsi_Yeh}');
Error('\P{Is_Joining_Group=/a/Farsi_Yeh}');
Expect(1, 1910, '\p{Is_Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\p{^Is_Joining_Group=farsiyeh}', "");
Expect(0, 1910, '\P{Is_Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\P{^Is_Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\p{Is_Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\p{^Is_Joining_Group=farsiyeh}', "");
Expect(1, 1911, '\P{Is_Joining_Group=farsiyeh}', "");
Expect(0, 1911, '\P{^Is_Joining_Group=farsiyeh}', "");
Expect(1, 1910, '\p{Is_Joining_Group=--FARSI_yeh}', "");
Expect(0, 1910, '\p{^Is_Joining_Group=--FARSI_yeh}', "");
Expect(0, 1910, '\P{Is_Joining_Group=--FARSI_yeh}', "");
Expect(1, 1910, '\P{^Is_Joining_Group=--FARSI_yeh}', "");
Expect(0, 1911, '\p{Is_Joining_Group=--FARSI_yeh}', "");
Expect(1, 1911, '\p{^Is_Joining_Group=--FARSI_yeh}', "");
Expect(1, 1911, '\P{Is_Joining_Group=--FARSI_yeh}', "");
Expect(0, 1911, '\P{^Is_Joining_Group=--FARSI_yeh}', "");
Error('\p{Is_Jg=	/a/farsi_YEH}');
Error('\P{Is_Jg=	/a/farsi_YEH}');
Expect(1, 1910, '\p{Is_Jg=farsiyeh}', "");
Expect(0, 1910, '\p{^Is_Jg=farsiyeh}', "");
Expect(0, 1910, '\P{Is_Jg=farsiyeh}', "");
Expect(1, 1910, '\P{^Is_Jg=farsiyeh}', "");
Expect(0, 1911, '\p{Is_Jg=farsiyeh}', "");
Expect(1, 1911, '\p{^Is_Jg=farsiyeh}', "");
Expect(1, 1911, '\P{Is_Jg=farsiyeh}', "");
Expect(0, 1911, '\P{^Is_Jg=farsiyeh}', "");
Expect(1, 1910, '\p{Is_Jg=-	Farsi_YEH}', "");
Expect(0, 1910, '\p{^Is_Jg=-	Farsi_YEH}', "");
Expect(0, 1910, '\P{Is_Jg=-	Farsi_YEH}', "");
Expect(1, 1910, '\P{^Is_Jg=-	Farsi_YEH}', "");
Expect(0, 1911, '\p{Is_Jg=-	Farsi_YEH}', "");
Expect(1, 1911, '\p{^Is_Jg=-	Farsi_YEH}', "");
Expect(1, 1911, '\P{Is_Jg=-	Farsi_YEH}', "");
Expect(0, 1911, '\P{^Is_Jg=-	Farsi_YEH}', "");
Error('\p{Joining_Group:		/a/FE}');
Error('\P{Joining_Group:		/a/FE}');
Expect(1, 1871, '\p{Joining_Group=fe}', "");
Expect(0, 1871, '\p{^Joining_Group=fe}', "");
Expect(0, 1871, '\P{Joining_Group=fe}', "");
Expect(1, 1871, '\P{^Joining_Group=fe}', "");
Expect(0, 1872, '\p{Joining_Group=fe}', "");
Expect(1, 1872, '\p{^Joining_Group=fe}', "");
Expect(1, 1872, '\P{Joining_Group=fe}', "");
Expect(0, 1872, '\P{^Joining_Group=fe}', "");
Expect(1, 1871, '\p{Joining_Group:   	 Fe}', "");
Expect(0, 1871, '\p{^Joining_Group:   	 Fe}', "");
Expect(0, 1871, '\P{Joining_Group:   	 Fe}', "");
Expect(1, 1871, '\P{^Joining_Group:   	 Fe}', "");
Expect(0, 1872, '\p{Joining_Group:   	 Fe}', "");
Expect(1, 1872, '\p{^Joining_Group:   	 Fe}', "");
Expect(1, 1872, '\P{Joining_Group:   	 Fe}', "");
Expect(0, 1872, '\P{^Joining_Group:   	 Fe}', "");
Error('\p{Jg:_	Fe/a/}');
Error('\P{Jg:_	Fe/a/}');
Expect(1, 1871, '\p{Jg=fe}', "");
Expect(0, 1871, '\p{^Jg=fe}', "");
Expect(0, 1871, '\P{Jg=fe}', "");
Expect(1, 1871, '\P{^Jg=fe}', "");
Expect(0, 1872, '\p{Jg=fe}', "");
Expect(1, 1872, '\p{^Jg=fe}', "");
Expect(1, 1872, '\P{Jg=fe}', "");
Expect(0, 1872, '\P{^Jg=fe}', "");
Expect(1, 1871, '\p{Jg=-_FE}', "");
Expect(0, 1871, '\p{^Jg=-_FE}', "");
Expect(0, 1871, '\P{Jg=-_FE}', "");
Expect(1, 1871, '\P{^Jg=-_FE}', "");
Expect(0, 1872, '\p{Jg=-_FE}', "");
Expect(1, 1872, '\p{^Jg=-_FE}', "");
Expect(1, 1872, '\P{Jg=-_FE}', "");
Expect(0, 1872, '\P{^Jg=-_FE}', "");
Error('\p{Is_Joining_Group=_ Fe/a/}');
Error('\P{Is_Joining_Group=_ Fe/a/}');
Expect(1, 1871, '\p{Is_Joining_Group=fe}', "");
Expect(0, 1871, '\p{^Is_Joining_Group=fe}', "");
Expect(0, 1871, '\P{Is_Joining_Group=fe}', "");
Expect(1, 1871, '\P{^Is_Joining_Group=fe}', "");
Expect(0, 1872, '\p{Is_Joining_Group=fe}', "");
Expect(1, 1872, '\p{^Is_Joining_Group=fe}', "");
Expect(1, 1872, '\P{Is_Joining_Group=fe}', "");
Expect(0, 1872, '\P{^Is_Joining_Group=fe}', "");
Expect(1, 1871, '\p{Is_Joining_Group=		Fe}', "");
Expect(0, 1871, '\p{^Is_Joining_Group=		Fe}', "");
Expect(0, 1871, '\P{Is_Joining_Group=		Fe}', "");
Expect(1, 1871, '\P{^Is_Joining_Group=		Fe}', "");
Expect(0, 1872, '\p{Is_Joining_Group=		Fe}', "");
Expect(1, 1872, '\p{^Is_Joining_Group=		Fe}', "");
Expect(1, 1872, '\P{Is_Joining_Group=		Fe}', "");
Expect(0, 1872, '\P{^Is_Joining_Group=		Fe}', "");
Error('\p{Is_Jg= /a/FE}');
Error('\P{Is_Jg= /a/FE}');
Expect(1, 1871, '\p{Is_Jg=fe}', "");
Expect(0, 1871, '\p{^Is_Jg=fe}', "");
Expect(0, 1871, '\P{Is_Jg=fe}', "");
Expect(1, 1871, '\P{^Is_Jg=fe}', "");
Expect(0, 1872, '\p{Is_Jg=fe}', "");
Expect(1, 1872, '\p{^Is_Jg=fe}', "");
Expect(1, 1872, '\P{Is_Jg=fe}', "");
Expect(0, 1872, '\P{^Is_Jg=fe}', "");
Expect(1, 1871, '\p{Is_Jg=_	Fe}', "");
Expect(0, 1871, '\p{^Is_Jg=_	Fe}', "");
Expect(0, 1871, '\P{Is_Jg=_	Fe}', "");
Expect(1, 1871, '\P{^Is_Jg=_	Fe}', "");
Expect(0, 1872, '\p{Is_Jg=_	Fe}', "");
Expect(1, 1872, '\p{^Is_Jg=_	Fe}', "");
Expect(1, 1872, '\P{Is_Jg=_	Fe}', "");
Expect(0, 1872, '\P{^Is_Jg=_	Fe}', "");
Error('\p{Joining_Group=/a/- feh}');
Error('\P{Joining_Group=/a/- feh}');
Expect(1, 2212, '\p{Joining_Group=feh}', "");
Expect(0, 2212, '\p{^Joining_Group=feh}', "");
Expect(0, 2212, '\P{Joining_Group=feh}', "");
Expect(1, 2212, '\P{^Joining_Group=feh}', "");
Expect(0, 2213, '\p{Joining_Group=feh}', "");
Expect(1, 2213, '\p{^Joining_Group=feh}', "");
Expect(1, 2213, '\P{Joining_Group=feh}', "");
Expect(0, 2213, '\P{^Joining_Group=feh}', "");
Expect(1, 2212, '\p{Joining_Group=__Feh}', "");
Expect(0, 2212, '\p{^Joining_Group=__Feh}', "");
Expect(0, 2212, '\P{Joining_Group=__Feh}', "");
Expect(1, 2212, '\P{^Joining_Group=__Feh}', "");
Expect(0, 2213, '\p{Joining_Group=__Feh}', "");
Expect(1, 2213, '\p{^Joining_Group=__Feh}', "");
Expect(1, 2213, '\P{Joining_Group=__Feh}', "");
Expect(0, 2213, '\P{^Joining_Group=__Feh}', "");
Error('\p{Jg=:=  FEH}');
Error('\P{Jg=:=  FEH}');
Expect(1, 2212, '\p{Jg=feh}', "");
Expect(0, 2212, '\p{^Jg=feh}', "");
Expect(0, 2212, '\P{Jg=feh}', "");
Expect(1, 2212, '\P{^Jg=feh}', "");
Expect(0, 2213, '\p{Jg=feh}', "");
Expect(1, 2213, '\p{^Jg=feh}', "");
Expect(1, 2213, '\P{Jg=feh}', "");
Expect(0, 2213, '\P{^Jg=feh}', "");
Expect(1, 2212, '\p{Jg=	 feh}', "");
Expect(0, 2212, '\p{^Jg=	 feh}', "");
Expect(0, 2212, '\P{Jg=	 feh}', "");
Expect(1, 2212, '\P{^Jg=	 feh}', "");
Expect(0, 2213, '\p{Jg=	 feh}', "");
Expect(1, 2213, '\p{^Jg=	 feh}', "");
Expect(1, 2213, '\P{Jg=	 feh}', "");
Expect(0, 2213, '\P{^Jg=	 feh}', "");
Error('\p{Is_Joining_Group: /a/  Feh}');
Error('\P{Is_Joining_Group: /a/  Feh}');
Expect(1, 2212, '\p{Is_Joining_Group=feh}', "");
Expect(0, 2212, '\p{^Is_Joining_Group=feh}', "");
Expect(0, 2212, '\P{Is_Joining_Group=feh}', "");
Expect(1, 2212, '\P{^Is_Joining_Group=feh}', "");
Expect(0, 2213, '\p{Is_Joining_Group=feh}', "");
Expect(1, 2213, '\p{^Is_Joining_Group=feh}', "");
Expect(1, 2213, '\P{Is_Joining_Group=feh}', "");
Expect(0, 2213, '\P{^Is_Joining_Group=feh}', "");
Expect(1, 2212, '\p{Is_Joining_Group=	FEH}', "");
Expect(0, 2212, '\p{^Is_Joining_Group=	FEH}', "");
Expect(0, 2212, '\P{Is_Joining_Group=	FEH}', "");
Expect(1, 2212, '\P{^Is_Joining_Group=	FEH}', "");
Expect(0, 2213, '\p{Is_Joining_Group=	FEH}', "");
Expect(1, 2213, '\p{^Is_Joining_Group=	FEH}', "");
Expect(1, 2213, '\P{Is_Joining_Group=	FEH}', "");
Expect(0, 2213, '\P{^Is_Joining_Group=	FEH}', "");
Error('\p{Is_Jg:	- Feh:=}');
Error('\P{Is_Jg:	- Feh:=}');
Expect(1, 2212, '\p{Is_Jg=feh}', "");
Expect(0, 2212, '\p{^Is_Jg=feh}', "");
Expect(0, 2212, '\P{Is_Jg=feh}', "");
Expect(1, 2212, '\P{^Is_Jg=feh}', "");
Expect(0, 2213, '\p{Is_Jg=feh}', "");
Expect(1, 2213, '\p{^Is_Jg=feh}', "");
Expect(1, 2213, '\P{Is_Jg=feh}', "");
Expect(0, 2213, '\P{^Is_Jg=feh}', "");
Expect(1, 2212, '\p{Is_Jg:	_FEH}', "");
Expect(0, 2212, '\p{^Is_Jg:	_FEH}', "");
Expect(0, 2212, '\P{Is_Jg:	_FEH}', "");
Expect(1, 2212, '\P{^Is_Jg:	_FEH}', "");
Expect(0, 2213, '\p{Is_Jg:	_FEH}', "");
Expect(1, 2213, '\p{^Is_Jg:	_FEH}', "");
Expect(1, 2213, '\P{Is_Jg:	_FEH}', "");
Expect(0, 2213, '\P{^Is_Jg:	_FEH}', "");
Error('\p{Joining_Group=:=__Final_semkath}');
Error('\P{Joining_Group=:=__Final_semkath}');
Expect(1, 1828, '\p{Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\p{^Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\P{Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\P{^Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\p{Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\p{^Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\P{Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\P{^Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\p{Joining_Group=_ final_Semkath}', "");
Expect(0, 1828, '\p{^Joining_Group=_ final_Semkath}', "");
Expect(0, 1828, '\P{Joining_Group=_ final_Semkath}', "");
Expect(1, 1828, '\P{^Joining_Group=_ final_Semkath}', "");
Expect(0, 1829, '\p{Joining_Group=_ final_Semkath}', "");
Expect(1, 1829, '\p{^Joining_Group=_ final_Semkath}', "");
Expect(1, 1829, '\P{Joining_Group=_ final_Semkath}', "");
Expect(0, 1829, '\P{^Joining_Group=_ final_Semkath}', "");
Error('\p{Jg=/a/__final_Semkath}');
Error('\P{Jg=/a/__final_Semkath}');
Expect(1, 1828, '\p{Jg=finalsemkath}', "");
Expect(0, 1828, '\p{^Jg=finalsemkath}', "");
Expect(0, 1828, '\P{Jg=finalsemkath}', "");
Expect(1, 1828, '\P{^Jg=finalsemkath}', "");
Expect(0, 1829, '\p{Jg=finalsemkath}', "");
Expect(1, 1829, '\p{^Jg=finalsemkath}', "");
Expect(1, 1829, '\P{Jg=finalsemkath}', "");
Expect(0, 1829, '\P{^Jg=finalsemkath}', "");
Expect(1, 1828, '\p{Jg=-	FINAL_Semkath}', "");
Expect(0, 1828, '\p{^Jg=-	FINAL_Semkath}', "");
Expect(0, 1828, '\P{Jg=-	FINAL_Semkath}', "");
Expect(1, 1828, '\P{^Jg=-	FINAL_Semkath}', "");
Expect(0, 1829, '\p{Jg=-	FINAL_Semkath}', "");
Expect(1, 1829, '\p{^Jg=-	FINAL_Semkath}', "");
Expect(1, 1829, '\P{Jg=-	FINAL_Semkath}', "");
Expect(0, 1829, '\P{^Jg=-	FINAL_Semkath}', "");
Error('\p{Is_Joining_Group=-:=final_semkath}');
Error('\P{Is_Joining_Group=-:=final_semkath}');
Expect(1, 1828, '\p{Is_Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\p{^Is_Joining_Group=finalsemkath}', "");
Expect(0, 1828, '\P{Is_Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\P{^Is_Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\p{Is_Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\p{^Is_Joining_Group=finalsemkath}', "");
Expect(1, 1829, '\P{Is_Joining_Group=finalsemkath}', "");
Expect(0, 1829, '\P{^Is_Joining_Group=finalsemkath}', "");
Expect(1, 1828, '\p{Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(0, 1828, '\p{^Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(0, 1828, '\P{Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(1, 1828, '\P{^Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(0, 1829, '\p{Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(1, 1829, '\p{^Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(1, 1829, '\P{Is_Joining_Group=_	FINAL_Semkath}', "");
Expect(0, 1829, '\P{^Is_Joining_Group=_	FINAL_Semkath}', "");
Error('\p{Is_Jg=:=	Final_SEMKATH}');
Error('\P{Is_Jg=:=	Final_SEMKATH}');
Expect(1, 1828, '\p{Is_Jg=finalsemkath}', "");
Expect(0, 1828, '\p{^Is_Jg=finalsemkath}', "");
Expect(0, 1828, '\P{Is_Jg=finalsemkath}', "");
Expect(1, 1828, '\P{^Is_Jg=finalsemkath}', "");
Expect(0, 1829, '\p{Is_Jg=finalsemkath}', "");
Expect(1, 1829, '\p{^Is_Jg=finalsemkath}', "");
Expect(1, 1829, '\P{Is_Jg=finalsemkath}', "");
Expect(0, 1829, '\P{^Is_Jg=finalsemkath}', "");
Expect(1, 1828, '\p{Is_Jg= 	Final_SEMKATH}', "");
Expect(0, 1828, '\p{^Is_Jg= 	Final_SEMKATH}', "");
Expect(0, 1828, '\P{Is_Jg= 	Final_SEMKATH}', "");
Expect(1, 1828, '\P{^Is_Jg= 	Final_SEMKATH}', "");
Expect(0, 1829, '\p{Is_Jg= 	Final_SEMKATH}', "");
Expect(1, 1829, '\p{^Is_Jg= 	Final_SEMKATH}', "");
Expect(1, 1829, '\P{Is_Jg= 	Final_SEMKATH}', "");
Expect(0, 1829, '\P{^Is_Jg= 	Final_SEMKATH}', "");
Error('\p{Joining_Group=/a/ _GAF}');
Error('\P{Joining_Group=/a/ _GAF}');
Expect(1, 1892, '\p{Joining_Group=gaf}', "");
Expect(0, 1892, '\p{^Joining_Group=gaf}', "");
Expect(0, 1892, '\P{Joining_Group=gaf}', "");
Expect(1, 1892, '\P{^Joining_Group=gaf}', "");
Expect(0, 1893, '\p{Joining_Group=gaf}', "");
Expect(1, 1893, '\p{^Joining_Group=gaf}', "");
Expect(1, 1893, '\P{Joining_Group=gaf}', "");
Expect(0, 1893, '\P{^Joining_Group=gaf}', "");
Expect(1, 1892, '\p{Joining_Group: GAF}', "");
Expect(0, 1892, '\p{^Joining_Group: GAF}', "");
Expect(0, 1892, '\P{Joining_Group: GAF}', "");
Expect(1, 1892, '\P{^Joining_Group: GAF}', "");
Expect(0, 1893, '\p{Joining_Group: GAF}', "");
Expect(1, 1893, '\p{^Joining_Group: GAF}', "");
Expect(1, 1893, '\P{Joining_Group: GAF}', "");
Expect(0, 1893, '\P{^Joining_Group: GAF}', "");
Error('\p{Jg:	_Gaf:=}');
Error('\P{Jg:	_Gaf:=}');
Expect(1, 1892, '\p{Jg:gaf}', "");
Expect(0, 1892, '\p{^Jg:gaf}', "");
Expect(0, 1892, '\P{Jg:gaf}', "");
Expect(1, 1892, '\P{^Jg:gaf}', "");
Expect(0, 1893, '\p{Jg:gaf}', "");
Expect(1, 1893, '\p{^Jg:gaf}', "");
Expect(1, 1893, '\P{Jg:gaf}', "");
Expect(0, 1893, '\P{^Jg:gaf}', "");
Expect(1, 1892, '\p{Jg:		GAF}', "");
Expect(0, 1892, '\p{^Jg:		GAF}', "");
Expect(0, 1892, '\P{Jg:		GAF}', "");
Expect(1, 1892, '\P{^Jg:		GAF}', "");
Expect(0, 1893, '\p{Jg:		GAF}', "");
Expect(1, 1893, '\p{^Jg:		GAF}', "");
Expect(1, 1893, '\P{Jg:		GAF}', "");
Expect(0, 1893, '\P{^Jg:		GAF}', "");
Error('\p{Is_Joining_Group=/a/-_GAF}');
Error('\P{Is_Joining_Group=/a/-_GAF}');
Expect(1, 1892, '\p{Is_Joining_Group=gaf}', "");
Expect(0, 1892, '\p{^Is_Joining_Group=gaf}', "");
Expect(0, 1892, '\P{Is_Joining_Group=gaf}', "");
Expect(1, 1892, '\P{^Is_Joining_Group=gaf}', "");
Expect(0, 1893, '\p{Is_Joining_Group=gaf}', "");
Expect(1, 1893, '\p{^Is_Joining_Group=gaf}', "");
Expect(1, 1893, '\P{Is_Joining_Group=gaf}', "");
Expect(0, 1893, '\P{^Is_Joining_Group=gaf}', "");
Expect(1, 1892, '\p{Is_Joining_Group= gaf}', "");
Expect(0, 1892, '\p{^Is_Joining_Group= gaf}', "");
Expect(0, 1892, '\P{Is_Joining_Group= gaf}', "");
Expect(1, 1892, '\P{^Is_Joining_Group= gaf}', "");
Expect(0, 1893, '\p{Is_Joining_Group= gaf}', "");
Expect(1, 1893, '\p{^Is_Joining_Group= gaf}', "");
Expect(1, 1893, '\P{Is_Joining_Group= gaf}', "");
Expect(0, 1893, '\P{^Is_Joining_Group= gaf}', "");
Error('\p{Is_Jg=	-Gaf/a/}');
Error('\P{Is_Jg=	-Gaf/a/}');
Expect(1, 1892, '\p{Is_Jg=gaf}', "");
Expect(0, 1892, '\p{^Is_Jg=gaf}', "");
Expect(0, 1892, '\P{Is_Jg=gaf}', "");
Expect(1, 1892, '\P{^Is_Jg=gaf}', "");
Expect(0, 1893, '\p{Is_Jg=gaf}', "");
Expect(1, 1893, '\p{^Is_Jg=gaf}', "");
Expect(1, 1893, '\P{Is_Jg=gaf}', "");
Expect(0, 1893, '\P{^Is_Jg=gaf}', "");
Expect(1, 1892, '\p{Is_Jg=	Gaf}', "");
Expect(0, 1892, '\p{^Is_Jg=	Gaf}', "");
Expect(0, 1892, '\P{Is_Jg=	Gaf}', "");
Expect(1, 1892, '\P{^Is_Jg=	Gaf}', "");
Expect(0, 1893, '\p{Is_Jg=	Gaf}', "");
Expect(1, 1893, '\p{^Is_Jg=	Gaf}', "");
Expect(1, 1893, '\P{Is_Jg=	Gaf}', "");
Expect(0, 1893, '\P{^Is_Jg=	Gaf}', "");
Error('\p{Joining_Group=:=	 Gamal}');
Error('\P{Joining_Group=:=	 Gamal}');
Expect(1, 1838, '\p{Joining_Group=gamal}', "");
Expect(0, 1838, '\p{^Joining_Group=gamal}', "");
Expect(0, 1838, '\P{Joining_Group=gamal}', "");
Expect(1, 1838, '\P{^Joining_Group=gamal}', "");
Expect(0, 1839, '\p{Joining_Group=gamal}', "");
Expect(1, 1839, '\p{^Joining_Group=gamal}', "");
Expect(1, 1839, '\P{Joining_Group=gamal}', "");
Expect(0, 1839, '\P{^Joining_Group=gamal}', "");
Expect(1, 1838, '\p{Joining_Group= _gamal}', "");
Expect(0, 1838, '\p{^Joining_Group= _gamal}', "");
Expect(0, 1838, '\P{Joining_Group= _gamal}', "");
Expect(1, 1838, '\P{^Joining_Group= _gamal}', "");
Expect(0, 1839, '\p{Joining_Group= _gamal}', "");
Expect(1, 1839, '\p{^Joining_Group= _gamal}', "");
Expect(1, 1839, '\P{Joining_Group= _gamal}', "");
Expect(0, 1839, '\P{^Joining_Group= _gamal}', "");
Error('\p{Jg=--gamal/a/}');
Error('\P{Jg=--gamal/a/}');
Expect(1, 1838, '\p{Jg=gamal}', "");
Expect(0, 1838, '\p{^Jg=gamal}', "");
Expect(0, 1838, '\P{Jg=gamal}', "");
Expect(1, 1838, '\P{^Jg=gamal}', "");
Expect(0, 1839, '\p{Jg=gamal}', "");
Expect(1, 1839, '\p{^Jg=gamal}', "");
Expect(1, 1839, '\P{Jg=gamal}', "");
Expect(0, 1839, '\P{^Jg=gamal}', "");
Expect(1, 1838, '\p{Jg=_ Gamal}', "");
Expect(0, 1838, '\p{^Jg=_ Gamal}', "");
Expect(0, 1838, '\P{Jg=_ Gamal}', "");
Expect(1, 1838, '\P{^Jg=_ Gamal}', "");
Expect(0, 1839, '\p{Jg=_ Gamal}', "");
Expect(1, 1839, '\p{^Jg=_ Gamal}', "");
Expect(1, 1839, '\P{Jg=_ Gamal}', "");
Expect(0, 1839, '\P{^Jg=_ Gamal}', "");
Error('\p{Is_Joining_Group=:=Gamal}');
Error('\P{Is_Joining_Group=:=Gamal}');
Expect(1, 1838, '\p{Is_Joining_Group=gamal}', "");
Expect(0, 1838, '\p{^Is_Joining_Group=gamal}', "");
Expect(0, 1838, '\P{Is_Joining_Group=gamal}', "");
Expect(1, 1838, '\P{^Is_Joining_Group=gamal}', "");
Expect(0, 1839, '\p{Is_Joining_Group=gamal}', "");
Expect(1, 1839, '\p{^Is_Joining_Group=gamal}', "");
Expect(1, 1839, '\P{Is_Joining_Group=gamal}', "");
Expect(0, 1839, '\P{^Is_Joining_Group=gamal}', "");
Expect(1, 1838, '\p{Is_Joining_Group=_	gamal}', "");
Expect(0, 1838, '\p{^Is_Joining_Group=_	gamal}', "");
Expect(0, 1838, '\P{Is_Joining_Group=_	gamal}', "");
Expect(1, 1838, '\P{^Is_Joining_Group=_	gamal}', "");
Expect(0, 1839, '\p{Is_Joining_Group=_	gamal}', "");
Expect(1, 1839, '\p{^Is_Joining_Group=_	gamal}', "");
Expect(1, 1839, '\P{Is_Joining_Group=_	gamal}', "");
Expect(0, 1839, '\P{^Is_Joining_Group=_	gamal}', "");
Error('\p{Is_Jg:   	:=Gamal}');
Error('\P{Is_Jg:   	:=Gamal}');
Expect(1, 1838, '\p{Is_Jg=gamal}', "");
Expect(0, 1838, '\p{^Is_Jg=gamal}', "");
Expect(0, 1838, '\P{Is_Jg=gamal}', "");
Expect(1, 1838, '\P{^Is_Jg=gamal}', "");
Expect(0, 1839, '\p{Is_Jg=gamal}', "");
Expect(1, 1839, '\p{^Is_Jg=gamal}', "");
Expect(1, 1839, '\P{Is_Jg=gamal}', "");
Expect(0, 1839, '\P{^Is_Jg=gamal}', "");
Expect(1, 1838, '\p{Is_Jg=-_Gamal}', "");
Expect(0, 1838, '\p{^Is_Jg=-_Gamal}', "");
Expect(0, 1838, '\P{Is_Jg=-_Gamal}', "");
Expect(1, 1838, '\P{^Is_Jg=-_Gamal}', "");
Expect(0, 1839, '\p{Is_Jg=-_Gamal}', "");
Expect(1, 1839, '\p{^Is_Jg=-_Gamal}', "");
Expect(1, 1839, '\P{Is_Jg=-_Gamal}', "");
Expect(0, 1839, '\P{^Is_Jg=-_Gamal}', "");
Error('\p{Joining_Group=_:=HAH}');
Error('\P{Joining_Group=_:=HAH}');
Expect(1, 2210, '\p{Joining_Group=hah}', "");
Expect(0, 2210, '\p{^Joining_Group=hah}', "");
Expect(0, 2210, '\P{Joining_Group=hah}', "");
Expect(1, 2210, '\P{^Joining_Group=hah}', "");
Expect(0, 2211, '\p{Joining_Group=hah}', "");
Expect(1, 2211, '\p{^Joining_Group=hah}', "");
Expect(1, 2211, '\P{Joining_Group=hah}', "");
Expect(0, 2211, '\P{^Joining_Group=hah}', "");
Expect(1, 2210, '\p{Joining_Group=-Hah}', "");
Expect(0, 2210, '\p{^Joining_Group=-Hah}', "");
Expect(0, 2210, '\P{Joining_Group=-Hah}', "");
Expect(1, 2210, '\P{^Joining_Group=-Hah}', "");
Expect(0, 2211, '\p{Joining_Group=-Hah}', "");
Expect(1, 2211, '\p{^Joining_Group=-Hah}', "");
Expect(1, 2211, '\P{Joining_Group=-Hah}', "");
Expect(0, 2211, '\P{^Joining_Group=-Hah}', "");
Error('\p{Jg=--hah:=}');
Error('\P{Jg=--hah:=}');
Expect(1, 2210, '\p{Jg=hah}', "");
Expect(0, 2210, '\p{^Jg=hah}', "");
Expect(0, 2210, '\P{Jg=hah}', "");
Expect(1, 2210, '\P{^Jg=hah}', "");
Expect(0, 2211, '\p{Jg=hah}', "");
Expect(1, 2211, '\p{^Jg=hah}', "");
Expect(1, 2211, '\P{Jg=hah}', "");
Expect(0, 2211, '\P{^Jg=hah}', "");
Expect(1, 2210, '\p{Jg=-	HAH}', "");
Expect(0, 2210, '\p{^Jg=-	HAH}', "");
Expect(0, 2210, '\P{Jg=-	HAH}', "");
Expect(1, 2210, '\P{^Jg=-	HAH}', "");
Expect(0, 2211, '\p{Jg=-	HAH}', "");
Expect(1, 2211, '\p{^Jg=-	HAH}', "");
Expect(1, 2211, '\P{Jg=-	HAH}', "");
Expect(0, 2211, '\P{^Jg=-	HAH}', "");
Error('\p{Is_Joining_Group:	 	hah:=}');
Error('\P{Is_Joining_Group:	 	hah:=}');
Expect(1, 2210, '\p{Is_Joining_Group=hah}', "");
Expect(0, 2210, '\p{^Is_Joining_Group=hah}', "");
Expect(0, 2210, '\P{Is_Joining_Group=hah}', "");
Expect(1, 2210, '\P{^Is_Joining_Group=hah}', "");
Expect(0, 2211, '\p{Is_Joining_Group=hah}', "");
Expect(1, 2211, '\p{^Is_Joining_Group=hah}', "");
Expect(1, 2211, '\P{Is_Joining_Group=hah}', "");
Expect(0, 2211, '\P{^Is_Joining_Group=hah}', "");
Expect(1, 2210, '\p{Is_Joining_Group=-Hah}', "");
Expect(0, 2210, '\p{^Is_Joining_Group=-Hah}', "");
Expect(0, 2210, '\P{Is_Joining_Group=-Hah}', "");
Expect(1, 2210, '\P{^Is_Joining_Group=-Hah}', "");
Expect(0, 2211, '\p{Is_Joining_Group=-Hah}', "");
Expect(1, 2211, '\p{^Is_Joining_Group=-Hah}', "");
Expect(1, 2211, '\P{Is_Joining_Group=-Hah}', "");
Expect(0, 2211, '\P{^Is_Joining_Group=-Hah}', "");
Error('\p{Is_Jg= 	Hah:=}');
Error('\P{Is_Jg= 	Hah:=}');
Expect(1, 2210, '\p{Is_Jg=hah}', "");
Expect(0, 2210, '\p{^Is_Jg=hah}', "");
Expect(0, 2210, '\P{Is_Jg=hah}', "");
Expect(1, 2210, '\P{^Is_Jg=hah}', "");
Expect(0, 2211, '\p{Is_Jg=hah}', "");
Expect(1, 2211, '\p{^Is_Jg=hah}', "");
Expect(1, 2211, '\P{Is_Jg=hah}', "");
Expect(0, 2211, '\P{^Is_Jg=hah}', "");
Expect(1, 2210, '\p{Is_Jg=	_Hah}', "");
Expect(0, 2210, '\p{^Is_Jg=	_Hah}', "");
Expect(0, 2210, '\P{Is_Jg=	_Hah}', "");
Expect(1, 2210, '\P{^Is_Jg=	_Hah}', "");
Expect(0, 2211, '\p{Is_Jg=	_Hah}', "");
Expect(1, 2211, '\p{^Is_Jg=	_Hah}', "");
Expect(1, 2211, '\P{Is_Jg=	_Hah}', "");
Expect(0, 2211, '\P{^Is_Jg=	_Hah}', "");
Error('\p{Joining_Group=_he:=}');
Error('\P{Joining_Group=_he:=}');
Expect(1, 1815, '\p{Joining_Group=he}', "");
Expect(0, 1815, '\p{^Joining_Group=he}', "");
Expect(0, 1815, '\P{Joining_Group=he}', "");
Expect(1, 1815, '\P{^Joining_Group=he}', "");
Expect(0, 1816, '\p{Joining_Group=he}', "");
Expect(1, 1816, '\p{^Joining_Group=he}', "");
Expect(1, 1816, '\P{Joining_Group=he}', "");
Expect(0, 1816, '\P{^Joining_Group=he}', "");
Expect(1, 1815, '\p{Joining_Group:   _HE}', "");
Expect(0, 1815, '\p{^Joining_Group:   _HE}', "");
Expect(0, 1815, '\P{Joining_Group:   _HE}', "");
Expect(1, 1815, '\P{^Joining_Group:   _HE}', "");
Expect(0, 1816, '\p{Joining_Group:   _HE}', "");
Expect(1, 1816, '\p{^Joining_Group:   _HE}', "");
Expect(1, 1816, '\P{Joining_Group:   _HE}', "");
Expect(0, 1816, '\P{^Joining_Group:   _HE}', "");
Error('\p{Jg=_	He:=}');
Error('\P{Jg=_	He:=}');
Expect(1, 1815, '\p{Jg=he}', "");
Expect(0, 1815, '\p{^Jg=he}', "");
Expect(0, 1815, '\P{Jg=he}', "");
Expect(1, 1815, '\P{^Jg=he}', "");
Expect(0, 1816, '\p{Jg=he}', "");
Expect(1, 1816, '\p{^Jg=he}', "");
Expect(1, 1816, '\P{Jg=he}', "");
Expect(0, 1816, '\P{^Jg=he}', "");
Expect(1, 1815, '\p{Jg=He}', "");
Expect(0, 1815, '\p{^Jg=He}', "");
Expect(0, 1815, '\P{Jg=He}', "");
Expect(1, 1815, '\P{^Jg=He}', "");
Expect(0, 1816, '\p{Jg=He}', "");
Expect(1, 1816, '\p{^Jg=He}', "");
Expect(1, 1816, '\P{Jg=He}', "");
Expect(0, 1816, '\P{^Jg=He}', "");
Error('\p{Is_Joining_Group=:=_	He}');
Error('\P{Is_Joining_Group=:=_	He}');
Expect(1, 1815, '\p{Is_Joining_Group=he}', "");
Expect(0, 1815, '\p{^Is_Joining_Group=he}', "");
Expect(0, 1815, '\P{Is_Joining_Group=he}', "");
Expect(1, 1815, '\P{^Is_Joining_Group=he}', "");
Expect(0, 1816, '\p{Is_Joining_Group=he}', "");
Expect(1, 1816, '\p{^Is_Joining_Group=he}', "");
Expect(1, 1816, '\P{Is_Joining_Group=he}', "");
Expect(0, 1816, '\P{^Is_Joining_Group=he}', "");
Expect(1, 1815, '\p{Is_Joining_Group=He}', "");
Expect(0, 1815, '\p{^Is_Joining_Group=He}', "");
Expect(0, 1815, '\P{Is_Joining_Group=He}', "");
Expect(1, 1815, '\P{^Is_Joining_Group=He}', "");
Expect(0, 1816, '\p{Is_Joining_Group=He}', "");
Expect(1, 1816, '\p{^Is_Joining_Group=He}', "");
Expect(1, 1816, '\P{Is_Joining_Group=He}', "");
Expect(0, 1816, '\P{^Is_Joining_Group=He}', "");
Error('\p{Is_Jg=		He:=}');
Error('\P{Is_Jg=		He:=}');
Expect(1, 1815, '\p{Is_Jg=he}', "");
Expect(0, 1815, '\p{^Is_Jg=he}', "");
Expect(0, 1815, '\P{Is_Jg=he}', "");
Expect(1, 1815, '\P{^Is_Jg=he}', "");
Expect(0, 1816, '\p{Is_Jg=he}', "");
Expect(1, 1816, '\p{^Is_Jg=he}', "");
Expect(1, 1816, '\P{Is_Jg=he}', "");
Expect(0, 1816, '\P{^Is_Jg=he}', "");
Expect(1, 1815, '\p{Is_Jg= he}', "");
Expect(0, 1815, '\p{^Is_Jg= he}', "");
Expect(0, 1815, '\P{Is_Jg= he}', "");
Expect(1, 1815, '\P{^Is_Jg= he}', "");
Expect(0, 1816, '\p{Is_Jg= he}', "");
Expect(1, 1816, '\p{^Is_Jg= he}', "");
Expect(1, 1816, '\P{Is_Jg= he}', "");
Expect(0, 1816, '\P{^Is_Jg= he}', "");
Error('\p{Joining_Group=	 Heh:=}');
Error('\P{Joining_Group=	 Heh:=}');
Expect(1, 1607, '\p{Joining_Group=heh}', "");
Expect(0, 1607, '\p{^Joining_Group=heh}', "");
Expect(0, 1607, '\P{Joining_Group=heh}', "");
Expect(1, 1607, '\P{^Joining_Group=heh}', "");
Expect(0, 1608, '\p{Joining_Group=heh}', "");
Expect(1, 1608, '\p{^Joining_Group=heh}', "");
Expect(1, 1608, '\P{Joining_Group=heh}', "");
Expect(0, 1608, '\P{^Joining_Group=heh}', "");
Expect(1, 1607, '\p{Joining_Group=_	Heh}', "");
Expect(0, 1607, '\p{^Joining_Group=_	Heh}', "");
Expect(0, 1607, '\P{Joining_Group=_	Heh}', "");
Expect(1, 1607, '\P{^Joining_Group=_	Heh}', "");
Expect(0, 1608, '\p{Joining_Group=_	Heh}', "");
Expect(1, 1608, '\p{^Joining_Group=_	Heh}', "");
Expect(1, 1608, '\P{Joining_Group=_	Heh}', "");
Expect(0, 1608, '\P{^Joining_Group=_	Heh}', "");
Error('\p{Jg=/a/-_heh}');
Error('\P{Jg=/a/-_heh}');
Expect(1, 1607, '\p{Jg:   heh}', "");
Expect(0, 1607, '\p{^Jg:   heh}', "");
Expect(0, 1607, '\P{Jg:   heh}', "");
Expect(1, 1607, '\P{^Jg:   heh}', "");
Expect(0, 1608, '\p{Jg:   heh}', "");
Expect(1, 1608, '\p{^Jg:   heh}', "");
Expect(1, 1608, '\P{Jg:   heh}', "");
Expect(0, 1608, '\P{^Jg:   heh}', "");
Expect(1, 1607, '\p{Jg=__HEH}', "");
Expect(0, 1607, '\p{^Jg=__HEH}', "");
Expect(0, 1607, '\P{Jg=__HEH}', "");
Expect(1, 1607, '\P{^Jg=__HEH}', "");
Expect(0, 1608, '\p{Jg=__HEH}', "");
Expect(1, 1608, '\p{^Jg=__HEH}', "");
Expect(1, 1608, '\P{Jg=__HEH}', "");
Expect(0, 1608, '\P{^Jg=__HEH}', "");
Error('\p{Is_Joining_Group=:=-Heh}');
Error('\P{Is_Joining_Group=:=-Heh}');
Expect(1, 1607, '\p{Is_Joining_Group=heh}', "");
Expect(0, 1607, '\p{^Is_Joining_Group=heh}', "");
Expect(0, 1607, '\P{Is_Joining_Group=heh}', "");
Expect(1, 1607, '\P{^Is_Joining_Group=heh}', "");
Expect(0, 1608, '\p{Is_Joining_Group=heh}', "");
Expect(1, 1608, '\p{^Is_Joining_Group=heh}', "");
Expect(1, 1608, '\P{Is_Joining_Group=heh}', "");
Expect(0, 1608, '\P{^Is_Joining_Group=heh}', "");
Expect(1, 1607, '\p{Is_Joining_Group=Heh}', "");
Expect(0, 1607, '\p{^Is_Joining_Group=Heh}', "");
Expect(0, 1607, '\P{Is_Joining_Group=Heh}', "");
Expect(1, 1607, '\P{^Is_Joining_Group=Heh}', "");
Expect(0, 1608, '\p{Is_Joining_Group=Heh}', "");
Expect(1, 1608, '\p{^Is_Joining_Group=Heh}', "");
Expect(1, 1608, '\P{Is_Joining_Group=Heh}', "");
Expect(0, 1608, '\P{^Is_Joining_Group=Heh}', "");
Error('\p{Is_Jg=	heh:=}');
Error('\P{Is_Jg=	heh:=}');
Expect(1, 1607, '\p{Is_Jg=heh}', "");
Expect(0, 1607, '\p{^Is_Jg=heh}', "");
Expect(0, 1607, '\P{Is_Jg=heh}', "");
Expect(1, 1607, '\P{^Is_Jg=heh}', "");
Expect(0, 1608, '\p{Is_Jg=heh}', "");
Expect(1, 1608, '\p{^Is_Jg=heh}', "");
Expect(1, 1608, '\P{Is_Jg=heh}', "");
Expect(0, 1608, '\P{^Is_Jg=heh}', "");
Expect(1, 1607, '\p{Is_Jg=		Heh}', "");
Expect(0, 1607, '\p{^Is_Jg=		Heh}', "");
Expect(0, 1607, '\P{Is_Jg=		Heh}', "");
Expect(1, 1607, '\P{^Is_Jg=		Heh}', "");
Expect(0, 1608, '\p{Is_Jg=		Heh}', "");
Expect(1, 1608, '\p{^Is_Jg=		Heh}', "");
Expect(1, 1608, '\P{Is_Jg=		Heh}', "");
Expect(0, 1608, '\P{^Is_Jg=		Heh}', "");
Error('\p{Joining_Group=	Heh_GOAL:=}');
Error('\P{Joining_Group=	Heh_GOAL:=}');
Expect(1, 1730, '\p{Joining_Group=hehgoal}', "");
Expect(0, 1730, '\p{^Joining_Group=hehgoal}', "");
Expect(0, 1730, '\P{Joining_Group=hehgoal}', "");
Expect(1, 1730, '\P{^Joining_Group=hehgoal}', "");
Expect(0, 1731, '\p{Joining_Group=hehgoal}', "");
Expect(1, 1731, '\p{^Joining_Group=hehgoal}', "");
Expect(1, 1731, '\P{Joining_Group=hehgoal}', "");
Expect(0, 1731, '\P{^Joining_Group=hehgoal}', "");
Expect(1, 1730, '\p{Joining_Group= heh_Goal}', "");
Expect(0, 1730, '\p{^Joining_Group= heh_Goal}', "");
Expect(0, 1730, '\P{Joining_Group= heh_Goal}', "");
Expect(1, 1730, '\P{^Joining_Group= heh_Goal}', "");
Expect(0, 1731, '\p{Joining_Group= heh_Goal}', "");
Expect(1, 1731, '\p{^Joining_Group= heh_Goal}', "");
Expect(1, 1731, '\P{Joining_Group= heh_Goal}', "");
Expect(0, 1731, '\P{^Joining_Group= heh_Goal}', "");
Error('\p{Jg=-:=heh_GOAL}');
Error('\P{Jg=-:=heh_GOAL}');
Expect(1, 1730, '\p{Jg=hehgoal}', "");
Expect(0, 1730, '\p{^Jg=hehgoal}', "");
Expect(0, 1730, '\P{Jg=hehgoal}', "");
Expect(1, 1730, '\P{^Jg=hehgoal}', "");
Expect(0, 1731, '\p{Jg=hehgoal}', "");
Expect(1, 1731, '\p{^Jg=hehgoal}', "");
Expect(1, 1731, '\P{Jg=hehgoal}', "");
Expect(0, 1731, '\P{^Jg=hehgoal}', "");
Expect(1, 1730, '\p{Jg=		Heh_Goal}', "");
Expect(0, 1730, '\p{^Jg=		Heh_Goal}', "");
Expect(0, 1730, '\P{Jg=		Heh_Goal}', "");
Expect(1, 1730, '\P{^Jg=		Heh_Goal}', "");
Expect(0, 1731, '\p{Jg=		Heh_Goal}', "");
Expect(1, 1731, '\p{^Jg=		Heh_Goal}', "");
Expect(1, 1731, '\P{Jg=		Heh_Goal}', "");
Expect(0, 1731, '\P{^Jg=		Heh_Goal}', "");
Error('\p{Is_Joining_Group=__Heh_GOAL/a/}');
Error('\P{Is_Joining_Group=__Heh_GOAL/a/}');
Expect(1, 1730, '\p{Is_Joining_Group=hehgoal}', "");
Expect(0, 1730, '\p{^Is_Joining_Group=hehgoal}', "");
Expect(0, 1730, '\P{Is_Joining_Group=hehgoal}', "");
Expect(1, 1730, '\P{^Is_Joining_Group=hehgoal}', "");
Expect(0, 1731, '\p{Is_Joining_Group=hehgoal}', "");
Expect(1, 1731, '\p{^Is_Joining_Group=hehgoal}', "");
Expect(1, 1731, '\P{Is_Joining_Group=hehgoal}', "");
Expect(0, 1731, '\P{^Is_Joining_Group=hehgoal}', "");
Expect(1, 1730, '\p{Is_Joining_Group=__heh_Goal}', "");
Expect(0, 1730, '\p{^Is_Joining_Group=__heh_Goal}', "");
Expect(0, 1730, '\P{Is_Joining_Group=__heh_Goal}', "");
Expect(1, 1730, '\P{^Is_Joining_Group=__heh_Goal}', "");
Expect(0, 1731, '\p{Is_Joining_Group=__heh_Goal}', "");
Expect(1, 1731, '\p{^Is_Joining_Group=__heh_Goal}', "");
Expect(1, 1731, '\P{Is_Joining_Group=__heh_Goal}', "");
Expect(0, 1731, '\P{^Is_Joining_Group=__heh_Goal}', "");
Error('\p{Is_Jg=:=	_HEH_GOAL}');
Error('\P{Is_Jg=:=	_HEH_GOAL}');
Expect(1, 1730, '\p{Is_Jg=hehgoal}', "");
Expect(0, 1730, '\p{^Is_Jg=hehgoal}', "");
Expect(0, 1730, '\P{Is_Jg=hehgoal}', "");
Expect(1, 1730, '\P{^Is_Jg=hehgoal}', "");
Expect(0, 1731, '\p{Is_Jg=hehgoal}', "");
Expect(1, 1731, '\p{^Is_Jg=hehgoal}', "");
Expect(1, 1731, '\P{Is_Jg=hehgoal}', "");
Expect(0, 1731, '\P{^Is_Jg=hehgoal}', "");
Expect(1, 1730, '\p{Is_Jg= _HEH_GOAL}', "");
Expect(0, 1730, '\p{^Is_Jg= _HEH_GOAL}', "");
Expect(0, 1730, '\P{Is_Jg= _HEH_GOAL}', "");
Expect(1, 1730, '\P{^Is_Jg= _HEH_GOAL}', "");
Expect(0, 1731, '\p{Is_Jg= _HEH_GOAL}', "");
Expect(1, 1731, '\p{^Is_Jg= _HEH_GOAL}', "");
Expect(1, 1731, '\P{Is_Jg= _HEH_GOAL}', "");
Expect(0, 1731, '\P{^Is_Jg= _HEH_GOAL}', "");
Error('\p{Joining_Group:   __heth:=}');
Error('\P{Joining_Group:   __heth:=}');
Expect(1, 1818, '\p{Joining_Group=heth}', "");
Expect(0, 1818, '\p{^Joining_Group=heth}', "");
Expect(0, 1818, '\P{Joining_Group=heth}', "");
Expect(1, 1818, '\P{^Joining_Group=heth}', "");
Expect(0, 1819, '\p{Joining_Group=heth}', "");
Expect(1, 1819, '\p{^Joining_Group=heth}', "");
Expect(1, 1819, '\P{Joining_Group=heth}', "");
Expect(0, 1819, '\P{^Joining_Group=heth}', "");
Expect(1, 1818, '\p{Joining_Group:   _HETH}', "");
Expect(0, 1818, '\p{^Joining_Group:   _HETH}', "");
Expect(0, 1818, '\P{Joining_Group:   _HETH}', "");
Expect(1, 1818, '\P{^Joining_Group:   _HETH}', "");
Expect(0, 1819, '\p{Joining_Group:   _HETH}', "");
Expect(1, 1819, '\p{^Joining_Group:   _HETH}', "");
Expect(1, 1819, '\P{Joining_Group:   _HETH}', "");
Expect(0, 1819, '\P{^Joining_Group:   _HETH}', "");
Error('\p{Jg=/a/Heth}');
Error('\P{Jg=/a/Heth}');
Expect(1, 1818, '\p{Jg=heth}', "");
Expect(0, 1818, '\p{^Jg=heth}', "");
Expect(0, 1818, '\P{Jg=heth}', "");
Expect(1, 1818, '\P{^Jg=heth}', "");
Expect(0, 1819, '\p{Jg=heth}', "");
Expect(1, 1819, '\p{^Jg=heth}', "");
Expect(1, 1819, '\P{Jg=heth}', "");
Expect(0, 1819, '\P{^Jg=heth}', "");
Expect(1, 1818, '\p{Jg= HETH}', "");
Expect(0, 1818, '\p{^Jg= HETH}', "");
Expect(0, 1818, '\P{Jg= HETH}', "");
Expect(1, 1818, '\P{^Jg= HETH}', "");
Expect(0, 1819, '\p{Jg= HETH}', "");
Expect(1, 1819, '\p{^Jg= HETH}', "");
Expect(1, 1819, '\P{Jg= HETH}', "");
Expect(0, 1819, '\P{^Jg= HETH}', "");
Error('\p{Is_Joining_Group=- Heth:=}');
Error('\P{Is_Joining_Group=- Heth:=}');
Expect(1, 1818, '\p{Is_Joining_Group=heth}', "");
Expect(0, 1818, '\p{^Is_Joining_Group=heth}', "");
Expect(0, 1818, '\P{Is_Joining_Group=heth}', "");
Expect(1, 1818, '\P{^Is_Joining_Group=heth}', "");
Expect(0, 1819, '\p{Is_Joining_Group=heth}', "");
Expect(1, 1819, '\p{^Is_Joining_Group=heth}', "");
Expect(1, 1819, '\P{Is_Joining_Group=heth}', "");
Expect(0, 1819, '\P{^Is_Joining_Group=heth}', "");
Expect(1, 1818, '\p{Is_Joining_Group=-Heth}', "");
Expect(0, 1818, '\p{^Is_Joining_Group=-Heth}', "");
Expect(0, 1818, '\P{Is_Joining_Group=-Heth}', "");
Expect(1, 1818, '\P{^Is_Joining_Group=-Heth}', "");
Expect(0, 1819, '\p{Is_Joining_Group=-Heth}', "");
Expect(1, 1819, '\p{^Is_Joining_Group=-Heth}', "");
Expect(1, 1819, '\P{Is_Joining_Group=-Heth}', "");
Expect(0, 1819, '\P{^Is_Joining_Group=-Heth}', "");
Error('\p{Is_Jg=--Heth:=}');
Error('\P{Is_Jg=--Heth:=}');
Expect(1, 1818, '\p{Is_Jg=heth}', "");
Expect(0, 1818, '\p{^Is_Jg=heth}', "");
Expect(0, 1818, '\P{Is_Jg=heth}', "");
Expect(1, 1818, '\P{^Is_Jg=heth}', "");
Expect(0, 1819, '\p{Is_Jg=heth}', "");
Expect(1, 1819, '\p{^Is_Jg=heth}', "");
Expect(1, 1819, '\P{Is_Jg=heth}', "");
Expect(0, 1819, '\P{^Is_Jg=heth}', "");
Expect(1, 1818, '\p{Is_Jg=-Heth}', "");
Expect(0, 1818, '\p{^Is_Jg=-Heth}', "");
Expect(0, 1818, '\P{Is_Jg=-Heth}', "");
Expect(1, 1818, '\P{^Is_Jg=-Heth}', "");
Expect(0, 1819, '\p{Is_Jg=-Heth}', "");
Expect(1, 1819, '\p{^Is_Jg=-Heth}', "");
Expect(1, 1819, '\P{Is_Jg=-Heth}', "");
Expect(0, 1819, '\P{^Is_Jg=-Heth}', "");
Error('\p{Joining_Group:	-:=KAF}');
Error('\P{Joining_Group:	-:=KAF}');
Expect(1, 1919, '\p{Joining_Group=kaf}', "");
Expect(0, 1919, '\p{^Joining_Group=kaf}', "");
Expect(0, 1919, '\P{Joining_Group=kaf}', "");
Expect(1, 1919, '\P{^Joining_Group=kaf}', "");
Expect(0, 1920, '\p{Joining_Group=kaf}', "");
Expect(1, 1920, '\p{^Joining_Group=kaf}', "");
Expect(1, 1920, '\P{Joining_Group=kaf}', "");
Expect(0, 1920, '\P{^Joining_Group=kaf}', "");
Expect(1, 1919, '\p{Joining_Group=  Kaf}', "");
Expect(0, 1919, '\p{^Joining_Group=  Kaf}', "");
Expect(0, 1919, '\P{Joining_Group=  Kaf}', "");
Expect(1, 1919, '\P{^Joining_Group=  Kaf}', "");
Expect(0, 1920, '\p{Joining_Group=  Kaf}', "");
Expect(1, 1920, '\p{^Joining_Group=  Kaf}', "");
Expect(1, 1920, '\P{Joining_Group=  Kaf}', "");
Expect(0, 1920, '\P{^Joining_Group=  Kaf}', "");
Error('\p{Jg=_-kaf/a/}');
Error('\P{Jg=_-kaf/a/}');
Expect(1, 1919, '\p{Jg=kaf}', "");
Expect(0, 1919, '\p{^Jg=kaf}', "");
Expect(0, 1919, '\P{Jg=kaf}', "");
Expect(1, 1919, '\P{^Jg=kaf}', "");
Expect(0, 1920, '\p{Jg=kaf}', "");
Expect(1, 1920, '\p{^Jg=kaf}', "");
Expect(1, 1920, '\P{Jg=kaf}', "");
Expect(0, 1920, '\P{^Jg=kaf}', "");
Expect(1, 1919, '\p{Jg= Kaf}', "");
Expect(0, 1919, '\p{^Jg= Kaf}', "");
Expect(0, 1919, '\P{Jg= Kaf}', "");
Expect(1, 1919, '\P{^Jg= Kaf}', "");
Expect(0, 1920, '\p{Jg= Kaf}', "");
Expect(1, 1920, '\p{^Jg= Kaf}', "");
Expect(1, 1920, '\P{Jg= Kaf}', "");
Expect(0, 1920, '\P{^Jg= Kaf}', "");
Error('\p{Is_Joining_Group:   /a/-Kaf}');
Error('\P{Is_Joining_Group:   /a/-Kaf}');
Expect(1, 1919, '\p{Is_Joining_Group:	kaf}', "");
Expect(0, 1919, '\p{^Is_Joining_Group:	kaf}', "");
Expect(0, 1919, '\P{Is_Joining_Group:	kaf}', "");
Expect(1, 1919, '\P{^Is_Joining_Group:	kaf}', "");
Expect(0, 1920, '\p{Is_Joining_Group:	kaf}', "");
Expect(1, 1920, '\p{^Is_Joining_Group:	kaf}', "");
Expect(1, 1920, '\P{Is_Joining_Group:	kaf}', "");
Expect(0, 1920, '\P{^Is_Joining_Group:	kaf}', "");
Expect(1, 1919, '\p{Is_Joining_Group=_kaf}', "");
Expect(0, 1919, '\p{^Is_Joining_Group=_kaf}', "");
Expect(0, 1919, '\P{Is_Joining_Group=_kaf}', "");
Expect(1, 1919, '\P{^Is_Joining_Group=_kaf}', "");
Expect(0, 1920, '\p{Is_Joining_Group=_kaf}', "");
Expect(1, 1920, '\p{^Is_Joining_Group=_kaf}', "");
Expect(1, 1920, '\P{Is_Joining_Group=_kaf}', "");
Expect(0, 1920, '\P{^Is_Joining_Group=_kaf}', "");
Error('\p{Is_Jg=	 KAF:=}');
Error('\P{Is_Jg=	 KAF:=}');
Expect(1, 1919, '\p{Is_Jg=kaf}', "");
Expect(0, 1919, '\p{^Is_Jg=kaf}', "");
Expect(0, 1919, '\P{Is_Jg=kaf}', "");
Expect(1, 1919, '\P{^Is_Jg=kaf}', "");
Expect(0, 1920, '\p{Is_Jg=kaf}', "");
Expect(1, 1920, '\p{^Is_Jg=kaf}', "");
Expect(1, 1920, '\P{Is_Jg=kaf}', "");
Expect(0, 1920, '\P{^Is_Jg=kaf}', "");
Expect(1, 1919, '\p{Is_Jg= 	kaf}', "");
Expect(0, 1919, '\p{^Is_Jg= 	kaf}', "");
Expect(0, 1919, '\P{Is_Jg= 	kaf}', "");
Expect(1, 1919, '\P{^Is_Jg= 	kaf}', "");
Expect(0, 1920, '\p{Is_Jg= 	kaf}', "");
Expect(1, 1920, '\p{^Is_Jg= 	kaf}', "");
Expect(1, 1920, '\P{Is_Jg= 	kaf}', "");
Expect(0, 1920, '\P{^Is_Jg= 	kaf}', "");
Error('\p{Joining_Group=- Kaph/a/}');
Error('\P{Joining_Group=- Kaph/a/}');
Expect(1, 1823, '\p{Joining_Group=kaph}', "");
Expect(0, 1823, '\p{^Joining_Group=kaph}', "");
Expect(0, 1823, '\P{Joining_Group=kaph}', "");
Expect(1, 1823, '\P{^Joining_Group=kaph}', "");
Expect(0, 1824, '\p{Joining_Group=kaph}', "");
Expect(1, 1824, '\p{^Joining_Group=kaph}', "");
Expect(1, 1824, '\P{Joining_Group=kaph}', "");
Expect(0, 1824, '\P{^Joining_Group=kaph}', "");
Expect(1, 1823, '\p{Joining_Group=_KAPH}', "");
Expect(0, 1823, '\p{^Joining_Group=_KAPH}', "");
Expect(0, 1823, '\P{Joining_Group=_KAPH}', "");
Expect(1, 1823, '\P{^Joining_Group=_KAPH}', "");
Expect(0, 1824, '\p{Joining_Group=_KAPH}', "");
Expect(1, 1824, '\p{^Joining_Group=_KAPH}', "");
Expect(1, 1824, '\P{Joining_Group=_KAPH}', "");
Expect(0, 1824, '\P{^Joining_Group=_KAPH}', "");
Error('\p{Jg:    :=Kaph}');
Error('\P{Jg:    :=Kaph}');
Expect(1, 1823, '\p{Jg=kaph}', "");
Expect(0, 1823, '\p{^Jg=kaph}', "");
Expect(0, 1823, '\P{Jg=kaph}', "");
Expect(1, 1823, '\P{^Jg=kaph}', "");
Expect(0, 1824, '\p{Jg=kaph}', "");
Expect(1, 1824, '\p{^Jg=kaph}', "");
Expect(1, 1824, '\P{Jg=kaph}', "");
Expect(0, 1824, '\P{^Jg=kaph}', "");
Expect(1, 1823, '\p{Jg=-kaph}', "");
Expect(0, 1823, '\p{^Jg=-kaph}', "");
Expect(0, 1823, '\P{Jg=-kaph}', "");
Expect(1, 1823, '\P{^Jg=-kaph}', "");
Expect(0, 1824, '\p{Jg=-kaph}', "");
Expect(1, 1824, '\p{^Jg=-kaph}', "");
Expect(1, 1824, '\P{Jg=-kaph}', "");
Expect(0, 1824, '\P{^Jg=-kaph}', "");
Error('\p{Is_Joining_Group=/a/ 	Kaph}');
Error('\P{Is_Joining_Group=/a/ 	Kaph}');
Expect(1, 1823, '\p{Is_Joining_Group=kaph}', "");
Expect(0, 1823, '\p{^Is_Joining_Group=kaph}', "");
Expect(0, 1823, '\P{Is_Joining_Group=kaph}', "");
Expect(1, 1823, '\P{^Is_Joining_Group=kaph}', "");
Expect(0, 1824, '\p{Is_Joining_Group=kaph}', "");
Expect(1, 1824, '\p{^Is_Joining_Group=kaph}', "");
Expect(1, 1824, '\P{Is_Joining_Group=kaph}', "");
Expect(0, 1824, '\P{^Is_Joining_Group=kaph}', "");
Expect(1, 1823, '\p{Is_Joining_Group=-Kaph}', "");
Expect(0, 1823, '\p{^Is_Joining_Group=-Kaph}', "");
Expect(0, 1823, '\P{Is_Joining_Group=-Kaph}', "");
Expect(1, 1823, '\P{^Is_Joining_Group=-Kaph}', "");
Expect(0, 1824, '\p{Is_Joining_Group=-Kaph}', "");
Expect(1, 1824, '\p{^Is_Joining_Group=-Kaph}', "");
Expect(1, 1824, '\P{Is_Joining_Group=-Kaph}', "");
Expect(0, 1824, '\P{^Is_Joining_Group=-Kaph}', "");
Error('\p{Is_Jg=- Kaph/a/}');
Error('\P{Is_Jg=- Kaph/a/}');
Expect(1, 1823, '\p{Is_Jg=kaph}', "");
Expect(0, 1823, '\p{^Is_Jg=kaph}', "");
Expect(0, 1823, '\P{Is_Jg=kaph}', "");
Expect(1, 1823, '\P{^Is_Jg=kaph}', "");
Expect(0, 1824, '\p{Is_Jg=kaph}', "");
Expect(1, 1824, '\p{^Is_Jg=kaph}', "");
Expect(1, 1824, '\P{Is_Jg=kaph}', "");
Expect(0, 1824, '\P{^Is_Jg=kaph}', "");
Expect(1, 1823, '\p{Is_Jg: --KAPH}', "");
Expect(0, 1823, '\p{^Is_Jg: --KAPH}', "");
Expect(0, 1823, '\P{Is_Jg: --KAPH}', "");
Expect(1, 1823, '\P{^Is_Jg: --KAPH}', "");
Expect(0, 1824, '\p{Is_Jg: --KAPH}', "");
Expect(1, 1824, '\p{^Is_Jg: --KAPH}', "");
Expect(1, 1824, '\P{Is_Jg: --KAPH}', "");
Expect(0, 1824, '\P{^Is_Jg: --KAPH}', "");
Error('\p{Joining_Group=:=khaph}');
Error('\P{Joining_Group=:=khaph}');
Expect(1, 1870, '\p{Joining_Group=khaph}', "");
Expect(0, 1870, '\p{^Joining_Group=khaph}', "");
Expect(0, 1870, '\P{Joining_Group=khaph}', "");
Expect(1, 1870, '\P{^Joining_Group=khaph}', "");
Expect(0, 1871, '\p{Joining_Group=khaph}', "");
Expect(1, 1871, '\p{^Joining_Group=khaph}', "");
Expect(1, 1871, '\P{Joining_Group=khaph}', "");
Expect(0, 1871, '\P{^Joining_Group=khaph}', "");
Expect(1, 1870, '\p{Joining_Group=-Khaph}', "");
Expect(0, 1870, '\p{^Joining_Group=-Khaph}', "");
Expect(0, 1870, '\P{Joining_Group=-Khaph}', "");
Expect(1, 1870, '\P{^Joining_Group=-Khaph}', "");
Expect(0, 1871, '\p{Joining_Group=-Khaph}', "");
Expect(1, 1871, '\p{^Joining_Group=-Khaph}', "");
Expect(1, 1871, '\P{Joining_Group=-Khaph}', "");
Expect(0, 1871, '\P{^Joining_Group=-Khaph}', "");
Error('\p{Jg=-:=Khaph}');
Error('\P{Jg=-:=Khaph}');
Expect(1, 1870, '\p{Jg=khaph}', "");
Expect(0, 1870, '\p{^Jg=khaph}', "");
Expect(0, 1870, '\P{Jg=khaph}', "");
Expect(1, 1870, '\P{^Jg=khaph}', "");
Expect(0, 1871, '\p{Jg=khaph}', "");
Expect(1, 1871, '\p{^Jg=khaph}', "");
Expect(1, 1871, '\P{Jg=khaph}', "");
Expect(0, 1871, '\P{^Jg=khaph}', "");
Expect(1, 1870, '\p{Jg=-_Khaph}', "");
Expect(0, 1870, '\p{^Jg=-_Khaph}', "");
Expect(0, 1870, '\P{Jg=-_Khaph}', "");
Expect(1, 1870, '\P{^Jg=-_Khaph}', "");
Expect(0, 1871, '\p{Jg=-_Khaph}', "");
Expect(1, 1871, '\p{^Jg=-_Khaph}', "");
Expect(1, 1871, '\P{Jg=-_Khaph}', "");
Expect(0, 1871, '\P{^Jg=-_Khaph}', "");
Error('\p{Is_Joining_Group=	 khaph/a/}');
Error('\P{Is_Joining_Group=	 khaph/a/}');
Expect(1, 1870, '\p{Is_Joining_Group=khaph}', "");
Expect(0, 1870, '\p{^Is_Joining_Group=khaph}', "");
Expect(0, 1870, '\P{Is_Joining_Group=khaph}', "");
Expect(1, 1870, '\P{^Is_Joining_Group=khaph}', "");
Expect(0, 1871, '\p{Is_Joining_Group=khaph}', "");
Expect(1, 1871, '\p{^Is_Joining_Group=khaph}', "");
Expect(1, 1871, '\P{Is_Joining_Group=khaph}', "");
Expect(0, 1871, '\P{^Is_Joining_Group=khaph}', "");
Expect(1, 1870, '\p{Is_Joining_Group:_khaph}', "");
Expect(0, 1870, '\p{^Is_Joining_Group:_khaph}', "");
Expect(0, 1870, '\P{Is_Joining_Group:_khaph}', "");
Expect(1, 1870, '\P{^Is_Joining_Group:_khaph}', "");
Expect(0, 1871, '\p{Is_Joining_Group:_khaph}', "");
Expect(1, 1871, '\p{^Is_Joining_Group:_khaph}', "");
Expect(1, 1871, '\P{Is_Joining_Group:_khaph}', "");
Expect(0, 1871, '\P{^Is_Joining_Group:_khaph}', "");
Error('\p{Is_Jg=/a/ Khaph}');
Error('\P{Is_Jg=/a/ Khaph}');
Expect(1, 1870, '\p{Is_Jg=khaph}', "");
Expect(0, 1870, '\p{^Is_Jg=khaph}', "");
Expect(0, 1870, '\P{Is_Jg=khaph}', "");
Expect(1, 1870, '\P{^Is_Jg=khaph}', "");
Expect(0, 1871, '\p{Is_Jg=khaph}', "");
Expect(1, 1871, '\p{^Is_Jg=khaph}', "");
Expect(1, 1871, '\P{Is_Jg=khaph}', "");
Expect(0, 1871, '\P{^Is_Jg=khaph}', "");
Expect(1, 1870, '\p{Is_Jg=Khaph}', "");
Expect(0, 1870, '\p{^Is_Jg=Khaph}', "");
Expect(0, 1870, '\P{Is_Jg=Khaph}', "");
Expect(1, 1870, '\P{^Is_Jg=Khaph}', "");
Expect(0, 1871, '\p{Is_Jg=Khaph}', "");
Expect(1, 1871, '\p{^Is_Jg=Khaph}', "");
Expect(1, 1871, '\P{Is_Jg=Khaph}', "");
Expect(0, 1871, '\P{^Is_Jg=Khaph}', "");
Error('\p{Joining_Group=/a/-knotted_Heh}');
Error('\P{Joining_Group=/a/-knotted_Heh}');
Expect(1, 1791, '\p{Joining_Group=knottedheh}', "");
Expect(0, 1791, '\p{^Joining_Group=knottedheh}', "");
Expect(0, 1791, '\P{Joining_Group=knottedheh}', "");
Expect(1, 1791, '\P{^Joining_Group=knottedheh}', "");
Expect(0, 1792, '\p{Joining_Group=knottedheh}', "");
Expect(1, 1792, '\p{^Joining_Group=knottedheh}', "");
Expect(1, 1792, '\P{Joining_Group=knottedheh}', "");
Expect(0, 1792, '\P{^Joining_Group=knottedheh}', "");
Expect(1, 1791, '\p{Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1791, '\p{^Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1791, '\P{Joining_Group=_ Knotted_Heh}', "");
Expect(1, 1791, '\P{^Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1792, '\p{Joining_Group=_ Knotted_Heh}', "");
Expect(1, 1792, '\p{^Joining_Group=_ Knotted_Heh}', "");
Expect(1, 1792, '\P{Joining_Group=_ Knotted_Heh}', "");
Expect(0, 1792, '\P{^Joining_Group=_ Knotted_Heh}', "");
Error('\p{Jg=:= KNOTTED_HEH}');
Error('\P{Jg=:= KNOTTED_HEH}');
Expect(1, 1791, '\p{Jg=knottedheh}', "");
Expect(0, 1791, '\p{^Jg=knottedheh}', "");
Expect(0, 1791, '\P{Jg=knottedheh}', "");
Expect(1, 1791, '\P{^Jg=knottedheh}', "");
Expect(0, 1792, '\p{Jg=knottedheh}', "");
Expect(1, 1792, '\p{^Jg=knottedheh}', "");
Expect(1, 1792, '\P{Jg=knottedheh}', "");
Expect(0, 1792, '\P{^Jg=knottedheh}', "");
Expect(1, 1791, '\p{Jg=- Knotted_heh}', "");
Expect(0, 1791, '\p{^Jg=- Knotted_heh}', "");
Expect(0, 1791, '\P{Jg=- Knotted_heh}', "");
Expect(1, 1791, '\P{^Jg=- Knotted_heh}', "");
Expect(0, 1792, '\p{Jg=- Knotted_heh}', "");
Expect(1, 1792, '\p{^Jg=- Knotted_heh}', "");
Expect(1, 1792, '\P{Jg=- Knotted_heh}', "");
Expect(0, 1792, '\P{^Jg=- Knotted_heh}', "");
Error('\p{Is_Joining_Group=__Knotted_HEH:=}');
Error('\P{Is_Joining_Group=__Knotted_HEH:=}');
Expect(1, 1791, '\p{Is_Joining_Group=knottedheh}', "");
Expect(0, 1791, '\p{^Is_Joining_Group=knottedheh}', "");
Expect(0, 1791, '\P{Is_Joining_Group=knottedheh}', "");
Expect(1, 1791, '\P{^Is_Joining_Group=knottedheh}', "");
Expect(0, 1792, '\p{Is_Joining_Group=knottedheh}', "");
Expect(1, 1792, '\p{^Is_Joining_Group=knottedheh}', "");
Expect(1, 1792, '\P{Is_Joining_Group=knottedheh}', "");
Expect(0, 1792, '\P{^Is_Joining_Group=knottedheh}', "");
Expect(1, 1791, '\p{Is_Joining_Group=  Knotted_Heh}', "");
Expect(0, 1791, '\p{^Is_Joining_Group=  Knotted_Heh}', "");
Expect(0, 1791, '\P{Is_Joining_Group=  Knotted_Heh}', "");
Expect(1, 1791, '\P{^Is_Joining_Group=  Knotted_Heh}', "");
Expect(0, 1792, '\p{Is_Joining_Group=  Knotted_Heh}', "");
Expect(1, 1792, '\p{^Is_Joining_Group=  Knotted_Heh}', "");
Expect(1, 1792, '\P{Is_Joining_Group=  Knotted_Heh}', "");
Expect(0, 1792, '\P{^Is_Joining_Group=  Knotted_Heh}', "");
Error('\p{Is_Jg=	_Knotted_heh/a/}');
Error('\P{Is_Jg=	_Knotted_heh/a/}');
Expect(1, 1791, '\p{Is_Jg=knottedheh}', "");
Expect(0, 1791, '\p{^Is_Jg=knottedheh}', "");
Expect(0, 1791, '\P{Is_Jg=knottedheh}', "");
Expect(1, 1791, '\P{^Is_Jg=knottedheh}', "");
Expect(0, 1792, '\p{Is_Jg=knottedheh}', "");
Expect(1, 1792, '\p{^Is_Jg=knottedheh}', "");
Expect(1, 1792, '\P{Is_Jg=knottedheh}', "");
Expect(0, 1792, '\P{^Is_Jg=knottedheh}', "");
Expect(1, 1791, '\p{Is_Jg=-knotted_HEH}', "");
Expect(0, 1791, '\p{^Is_Jg=-knotted_HEH}', "");
Expect(0, 1791, '\P{Is_Jg=-knotted_HEH}', "");
Expect(1, 1791, '\P{^Is_Jg=-knotted_HEH}', "");
Expect(0, 1792, '\p{Is_Jg=-knotted_HEH}', "");
Expect(1, 1792, '\p{^Is_Jg=-knotted_HEH}', "");
Expect(1, 1792, '\P{Is_Jg=-knotted_HEH}', "");
Expect(0, 1792, '\P{^Is_Jg=-knotted_HEH}', "");
Error('\p{Joining_Group=/a/_	lam}');
Error('\P{Joining_Group=/a/_	lam}');
Expect(1, 2214, '\p{Joining_Group=lam}', "");
Expect(0, 2214, '\p{^Joining_Group=lam}', "");
Expect(0, 2214, '\P{Joining_Group=lam}', "");
Expect(1, 2214, '\P{^Joining_Group=lam}', "");
Expect(0, 2215, '\p{Joining_Group=lam}', "");
Expect(1, 2215, '\p{^Joining_Group=lam}', "");
Expect(1, 2215, '\P{Joining_Group=lam}', "");
Expect(0, 2215, '\P{^Joining_Group=lam}', "");
Expect(1, 2214, '\p{Joining_Group=	lam}', "");
Expect(0, 2214, '\p{^Joining_Group=	lam}', "");
Expect(0, 2214, '\P{Joining_Group=	lam}', "");
Expect(1, 2214, '\P{^Joining_Group=	lam}', "");
Expect(0, 2215, '\p{Joining_Group=	lam}', "");
Expect(1, 2215, '\p{^Joining_Group=	lam}', "");
Expect(1, 2215, '\P{Joining_Group=	lam}', "");
Expect(0, 2215, '\P{^Joining_Group=	lam}', "");
Error('\p{Jg=-/a/lam}');
Error('\P{Jg=-/a/lam}');
Expect(1, 2214, '\p{Jg=lam}', "");
Expect(0, 2214, '\p{^Jg=lam}', "");
Expect(0, 2214, '\P{Jg=lam}', "");
Expect(1, 2214, '\P{^Jg=lam}', "");
Expect(0, 2215, '\p{Jg=lam}', "");
Expect(1, 2215, '\p{^Jg=lam}', "");
Expect(1, 2215, '\P{Jg=lam}', "");
Expect(0, 2215, '\P{^Jg=lam}', "");
Expect(1, 2214, '\p{Jg=-Lam}', "");
Expect(0, 2214, '\p{^Jg=-Lam}', "");
Expect(0, 2214, '\P{Jg=-Lam}', "");
Expect(1, 2214, '\P{^Jg=-Lam}', "");
Expect(0, 2215, '\p{Jg=-Lam}', "");
Expect(1, 2215, '\p{^Jg=-Lam}', "");
Expect(1, 2215, '\P{Jg=-Lam}', "");
Expect(0, 2215, '\P{^Jg=-Lam}', "");
Error('\p{Is_Joining_Group= 	Lam/a/}');
Error('\P{Is_Joining_Group= 	Lam/a/}');
Expect(1, 2214, '\p{Is_Joining_Group=lam}', "");
Expect(0, 2214, '\p{^Is_Joining_Group=lam}', "");
Expect(0, 2214, '\P{Is_Joining_Group=lam}', "");
Expect(1, 2214, '\P{^Is_Joining_Group=lam}', "");
Expect(0, 2215, '\p{Is_Joining_Group=lam}', "");
Expect(1, 2215, '\p{^Is_Joining_Group=lam}', "");
Expect(1, 2215, '\P{Is_Joining_Group=lam}', "");
Expect(0, 2215, '\P{^Is_Joining_Group=lam}', "");
Expect(1, 2214, '\p{Is_Joining_Group: _Lam}', "");
Expect(0, 2214, '\p{^Is_Joining_Group: _Lam}', "");
Expect(0, 2214, '\P{Is_Joining_Group: _Lam}', "");
Expect(1, 2214, '\P{^Is_Joining_Group: _Lam}', "");
Expect(0, 2215, '\p{Is_Joining_Group: _Lam}', "");
Expect(1, 2215, '\p{^Is_Joining_Group: _Lam}', "");
Expect(1, 2215, '\P{Is_Joining_Group: _Lam}', "");
Expect(0, 2215, '\P{^Is_Joining_Group: _Lam}', "");
Error('\p{Is_Jg=:=Lam}');
Error('\P{Is_Jg=:=Lam}');
Expect(1, 2214, '\p{Is_Jg=lam}', "");
Expect(0, 2214, '\p{^Is_Jg=lam}', "");
Expect(0, 2214, '\P{Is_Jg=lam}', "");
Expect(1, 2214, '\P{^Is_Jg=lam}', "");
Expect(0, 2215, '\p{Is_Jg=lam}', "");
Expect(1, 2215, '\p{^Is_Jg=lam}', "");
Expect(1, 2215, '\P{Is_Jg=lam}', "");
Expect(0, 2215, '\P{^Is_Jg=lam}', "");
Expect(1, 2214, '\p{Is_Jg:	-	Lam}', "");
Expect(0, 2214, '\p{^Is_Jg:	-	Lam}', "");
Expect(0, 2214, '\P{Is_Jg:	-	Lam}', "");
Expect(1, 2214, '\P{^Is_Jg:	-	Lam}', "");
Expect(0, 2215, '\p{Is_Jg:	-	Lam}', "");
Expect(1, 2215, '\p{^Is_Jg:	-	Lam}', "");
Expect(1, 2215, '\P{Is_Jg:	-	Lam}', "");
Expect(0, 2215, '\P{^Is_Jg:	-	Lam}', "");
Error('\p{Joining_Group=:=-	LAMADH}');
Error('\P{Joining_Group=:=-	LAMADH}');
Expect(1, 1824, '\p{Joining_Group=lamadh}', "");
Expect(0, 1824, '\p{^Joining_Group=lamadh}', "");
Expect(0, 1824, '\P{Joining_Group=lamadh}', "");
Expect(1, 1824, '\P{^Joining_Group=lamadh}', "");
Expect(0, 1825, '\p{Joining_Group=lamadh}', "");
Expect(1, 1825, '\p{^Joining_Group=lamadh}', "");
Expect(1, 1825, '\P{Joining_Group=lamadh}', "");
Expect(0, 1825, '\P{^Joining_Group=lamadh}', "");
Expect(1, 1824, '\p{Joining_Group=-Lamadh}', "");
Expect(0, 1824, '\p{^Joining_Group=-Lamadh}', "");
Expect(0, 1824, '\P{Joining_Group=-Lamadh}', "");
Expect(1, 1824, '\P{^Joining_Group=-Lamadh}', "");
Expect(0, 1825, '\p{Joining_Group=-Lamadh}', "");
Expect(1, 1825, '\p{^Joining_Group=-Lamadh}', "");
Expect(1, 1825, '\P{Joining_Group=-Lamadh}', "");
Expect(0, 1825, '\P{^Joining_Group=-Lamadh}', "");
Error('\p{Jg= Lamadh:=}');
Error('\P{Jg= Lamadh:=}');
Expect(1, 1824, '\p{Jg=lamadh}', "");
Expect(0, 1824, '\p{^Jg=lamadh}', "");
Expect(0, 1824, '\P{Jg=lamadh}', "");
Expect(1, 1824, '\P{^Jg=lamadh}', "");
Expect(0, 1825, '\p{Jg=lamadh}', "");
Expect(1, 1825, '\p{^Jg=lamadh}', "");
Expect(1, 1825, '\P{Jg=lamadh}', "");
Expect(0, 1825, '\P{^Jg=lamadh}', "");
Expect(1, 1824, '\p{Jg=	LAMADH}', "");
Expect(0, 1824, '\p{^Jg=	LAMADH}', "");
Expect(0, 1824, '\P{Jg=	LAMADH}', "");
Expect(1, 1824, '\P{^Jg=	LAMADH}', "");
Expect(0, 1825, '\p{Jg=	LAMADH}', "");
Expect(1, 1825, '\p{^Jg=	LAMADH}', "");
Expect(1, 1825, '\P{Jg=	LAMADH}', "");
Expect(0, 1825, '\P{^Jg=	LAMADH}', "");
Error('\p{Is_Joining_Group=_:=Lamadh}');
Error('\P{Is_Joining_Group=_:=Lamadh}');
Expect(1, 1824, '\p{Is_Joining_Group:lamadh}', "");
Expect(0, 1824, '\p{^Is_Joining_Group:lamadh}', "");
Expect(0, 1824, '\P{Is_Joining_Group:lamadh}', "");
Expect(1, 1824, '\P{^Is_Joining_Group:lamadh}', "");
Expect(0, 1825, '\p{Is_Joining_Group:lamadh}', "");
Expect(1, 1825, '\p{^Is_Joining_Group:lamadh}', "");
Expect(1, 1825, '\P{Is_Joining_Group:lamadh}', "");
Expect(0, 1825, '\P{^Is_Joining_Group:lamadh}', "");
Expect(1, 1824, '\p{Is_Joining_Group:- LAMADH}', "");
Expect(0, 1824, '\p{^Is_Joining_Group:- LAMADH}', "");
Expect(0, 1824, '\P{Is_Joining_Group:- LAMADH}', "");
Expect(1, 1824, '\P{^Is_Joining_Group:- LAMADH}', "");
Expect(0, 1825, '\p{Is_Joining_Group:- LAMADH}', "");
Expect(1, 1825, '\p{^Is_Joining_Group:- LAMADH}', "");
Expect(1, 1825, '\P{Is_Joining_Group:- LAMADH}', "");
Expect(0, 1825, '\P{^Is_Joining_Group:- LAMADH}', "");
Error('\p{Is_Jg=/a/		lamadh}');
Error('\P{Is_Jg=/a/		lamadh}');
Expect(1, 1824, '\p{Is_Jg: lamadh}', "");
Expect(0, 1824, '\p{^Is_Jg: lamadh}', "");
Expect(0, 1824, '\P{Is_Jg: lamadh}', "");
Expect(1, 1824, '\P{^Is_Jg: lamadh}', "");
Expect(0, 1825, '\p{Is_Jg: lamadh}', "");
Expect(1, 1825, '\p{^Is_Jg: lamadh}', "");
Expect(1, 1825, '\P{Is_Jg: lamadh}', "");
Expect(0, 1825, '\P{^Is_Jg: lamadh}', "");
Expect(1, 1824, '\p{Is_Jg=	 LAMADH}', "");
Expect(0, 1824, '\p{^Is_Jg=	 LAMADH}', "");
Expect(0, 1824, '\P{Is_Jg=	 LAMADH}', "");
Expect(1, 1824, '\P{^Is_Jg=	 LAMADH}', "");
Expect(0, 1825, '\p{Is_Jg=	 LAMADH}', "");
Expect(1, 1825, '\p{^Is_Jg=	 LAMADH}', "");
Expect(1, 1825, '\P{Is_Jg=	 LAMADH}', "");
Expect(0, 1825, '\P{^Is_Jg=	 LAMADH}', "");
Error('\p{Joining_Group=-meem:=}');
Error('\P{Joining_Group=-meem:=}');
Expect(1, 2215, '\p{Joining_Group=meem}', "");
Expect(0, 2215, '\p{^Joining_Group=meem}', "");
Expect(0, 2215, '\P{Joining_Group=meem}', "");
Expect(1, 2215, '\P{^Joining_Group=meem}', "");
Expect(0, 2216, '\p{Joining_Group=meem}', "");
Expect(1, 2216, '\p{^Joining_Group=meem}', "");
Expect(1, 2216, '\P{Joining_Group=meem}', "");
Expect(0, 2216, '\P{^Joining_Group=meem}', "");
Expect(1, 2215, '\p{Joining_Group=--Meem}', "");
Expect(0, 2215, '\p{^Joining_Group=--Meem}', "");
Expect(0, 2215, '\P{Joining_Group=--Meem}', "");
Expect(1, 2215, '\P{^Joining_Group=--Meem}', "");
Expect(0, 2216, '\p{Joining_Group=--Meem}', "");
Expect(1, 2216, '\p{^Joining_Group=--Meem}', "");
Expect(1, 2216, '\P{Joining_Group=--Meem}', "");
Expect(0, 2216, '\P{^Joining_Group=--Meem}', "");
Error('\p{Jg=:=-Meem}');
Error('\P{Jg=:=-Meem}');
Expect(1, 2215, '\p{Jg:   meem}', "");
Expect(0, 2215, '\p{^Jg:   meem}', "");
Expect(0, 2215, '\P{Jg:   meem}', "");
Expect(1, 2215, '\P{^Jg:   meem}', "");
Expect(0, 2216, '\p{Jg:   meem}', "");
Expect(1, 2216, '\p{^Jg:   meem}', "");
Expect(1, 2216, '\P{Jg:   meem}', "");
Expect(0, 2216, '\P{^Jg:   meem}', "");
Expect(1, 2215, '\p{Jg=	Meem}', "");
Expect(0, 2215, '\p{^Jg=	Meem}', "");
Expect(0, 2215, '\P{Jg=	Meem}', "");
Expect(1, 2215, '\P{^Jg=	Meem}', "");
Expect(0, 2216, '\p{Jg=	Meem}', "");
Expect(1, 2216, '\p{^Jg=	Meem}', "");
Expect(1, 2216, '\P{Jg=	Meem}', "");
Expect(0, 2216, '\P{^Jg=	Meem}', "");
Error('\p{Is_Joining_Group=	/a/meem}');
Error('\P{Is_Joining_Group=	/a/meem}');
Expect(1, 2215, '\p{Is_Joining_Group=meem}', "");
Expect(0, 2215, '\p{^Is_Joining_Group=meem}', "");
Expect(0, 2215, '\P{Is_Joining_Group=meem}', "");
Expect(1, 2215, '\P{^Is_Joining_Group=meem}', "");
Expect(0, 2216, '\p{Is_Joining_Group=meem}', "");
Expect(1, 2216, '\p{^Is_Joining_Group=meem}', "");
Expect(1, 2216, '\P{Is_Joining_Group=meem}', "");
Expect(0, 2216, '\P{^Is_Joining_Group=meem}', "");
Expect(1, 2215, '\p{Is_Joining_Group=_-meem}', "");
Expect(0, 2215, '\p{^Is_Joining_Group=_-meem}', "");
Expect(0, 2215, '\P{Is_Joining_Group=_-meem}', "");
Expect(1, 2215, '\P{^Is_Joining_Group=_-meem}', "");
Expect(0, 2216, '\p{Is_Joining_Group=_-meem}', "");
Expect(1, 2216, '\p{^Is_Joining_Group=_-meem}', "");
Expect(1, 2216, '\P{Is_Joining_Group=_-meem}', "");
Expect(0, 2216, '\P{^Is_Joining_Group=_-meem}', "");
Error('\p{Is_Jg=:=meem}');
Error('\P{Is_Jg=:=meem}');
Expect(1, 2215, '\p{Is_Jg=meem}', "");
Expect(0, 2215, '\p{^Is_Jg=meem}', "");
Expect(0, 2215, '\P{Is_Jg=meem}', "");
Expect(1, 2215, '\P{^Is_Jg=meem}', "");
Expect(0, 2216, '\p{Is_Jg=meem}', "");
Expect(1, 2216, '\p{^Is_Jg=meem}', "");
Expect(1, 2216, '\P{Is_Jg=meem}', "");
Expect(0, 2216, '\P{^Is_Jg=meem}', "");
Expect(1, 2215, '\p{Is_Jg= _meem}', "");
Expect(0, 2215, '\p{^Is_Jg= _meem}', "");
Expect(0, 2215, '\P{Is_Jg= _meem}', "");
Expect(1, 2215, '\P{^Is_Jg= _meem}', "");
Expect(0, 2216, '\p{Is_Jg= _meem}', "");
Expect(1, 2216, '\p{^Is_Jg= _meem}', "");
Expect(1, 2216, '\P{Is_Jg= _meem}', "");
Expect(0, 2216, '\P{^Is_Jg= _meem}', "");
Error('\p{Joining_Group=-_Mim:=}');
Error('\P{Joining_Group=-_Mim:=}');
Expect(1, 1825, '\p{Joining_Group=mim}', "");
Expect(0, 1825, '\p{^Joining_Group=mim}', "");
Expect(0, 1825, '\P{Joining_Group=mim}', "");
Expect(1, 1825, '\P{^Joining_Group=mim}', "");
Expect(0, 1826, '\p{Joining_Group=mim}', "");
Expect(1, 1826, '\p{^Joining_Group=mim}', "");
Expect(1, 1826, '\P{Joining_Group=mim}', "");
Expect(0, 1826, '\P{^Joining_Group=mim}', "");
Expect(1, 1825, '\p{Joining_Group: 	 mim}', "");
Expect(0, 1825, '\p{^Joining_Group: 	 mim}', "");
Expect(0, 1825, '\P{Joining_Group: 	 mim}', "");
Expect(1, 1825, '\P{^Joining_Group: 	 mim}', "");
Expect(0, 1826, '\p{Joining_Group: 	 mim}', "");
Expect(1, 1826, '\p{^Joining_Group: 	 mim}', "");
Expect(1, 1826, '\P{Joining_Group: 	 mim}', "");
Expect(0, 1826, '\P{^Joining_Group: 	 mim}', "");
Error('\p{Jg= :=Mim}');
Error('\P{Jg= :=Mim}');
Expect(1, 1825, '\p{Jg=mim}', "");
Expect(0, 1825, '\p{^Jg=mim}', "");
Expect(0, 1825, '\P{Jg=mim}', "");
Expect(1, 1825, '\P{^Jg=mim}', "");
Expect(0, 1826, '\p{Jg=mim}', "");
Expect(1, 1826, '\p{^Jg=mim}', "");
Expect(1, 1826, '\P{Jg=mim}', "");
Expect(0, 1826, '\P{^Jg=mim}', "");
Expect(1, 1825, '\p{Jg:	-Mim}', "");
Expect(0, 1825, '\p{^Jg:	-Mim}', "");
Expect(0, 1825, '\P{Jg:	-Mim}', "");
Expect(1, 1825, '\P{^Jg:	-Mim}', "");
Expect(0, 1826, '\p{Jg:	-Mim}', "");
Expect(1, 1826, '\p{^Jg:	-Mim}', "");
Expect(1, 1826, '\P{Jg:	-Mim}', "");
Expect(0, 1826, '\P{^Jg:	-Mim}', "");
Error('\p{Is_Joining_Group=Mim/a/}');
Error('\P{Is_Joining_Group=Mim/a/}');
Expect(1, 1825, '\p{Is_Joining_Group=mim}', "");
Expect(0, 1825, '\p{^Is_Joining_Group=mim}', "");
Expect(0, 1825, '\P{Is_Joining_Group=mim}', "");
Expect(1, 1825, '\P{^Is_Joining_Group=mim}', "");
Expect(0, 1826, '\p{Is_Joining_Group=mim}', "");
Expect(1, 1826, '\p{^Is_Joining_Group=mim}', "");
Expect(1, 1826, '\P{Is_Joining_Group=mim}', "");
Expect(0, 1826, '\P{^Is_Joining_Group=mim}', "");
Expect(1, 1825, '\p{Is_Joining_Group= 	Mim}', "");
Expect(0, 1825, '\p{^Is_Joining_Group= 	Mim}', "");
Expect(0, 1825, '\P{Is_Joining_Group= 	Mim}', "");
Expect(1, 1825, '\P{^Is_Joining_Group= 	Mim}', "");
Expect(0, 1826, '\p{Is_Joining_Group= 	Mim}', "");
Expect(1, 1826, '\p{^Is_Joining_Group= 	Mim}', "");
Expect(1, 1826, '\P{Is_Joining_Group= 	Mim}', "");
Expect(0, 1826, '\P{^Is_Joining_Group= 	Mim}', "");
Error('\p{Is_Jg=/a/	_Mim}');
Error('\P{Is_Jg=/a/	_Mim}');
Expect(1, 1825, '\p{Is_Jg=mim}', "");
Expect(0, 1825, '\p{^Is_Jg=mim}', "");
Expect(0, 1825, '\P{Is_Jg=mim}', "");
Expect(1, 1825, '\P{^Is_Jg=mim}', "");
Expect(0, 1826, '\p{Is_Jg=mim}', "");
Expect(1, 1826, '\p{^Is_Jg=mim}', "");
Expect(1, 1826, '\P{Is_Jg=mim}', "");
Expect(0, 1826, '\P{^Is_Jg=mim}', "");
Expect(1, 1825, '\p{Is_Jg=-	mim}', "");
Expect(0, 1825, '\p{^Is_Jg=-	mim}', "");
Expect(0, 1825, '\P{Is_Jg=-	mim}', "");
Expect(1, 1825, '\P{^Is_Jg=-	mim}', "");
Expect(0, 1826, '\p{Is_Jg=-	mim}', "");
Expect(1, 1826, '\p{^Is_Jg=-	mim}', "");
Expect(1, 1826, '\P{Is_Jg=-	mim}', "");
Expect(0, 1826, '\P{^Is_Jg=-	mim}', "");
Error('\p{Joining_Group=	no_joining_group:=}');
Error('\P{Joining_Group=	no_joining_group:=}');
Expect(1, 2221, '\p{Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\p{^Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\P{Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\P{^Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\p{Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\p{^Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\P{Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\P{^Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\p{Joining_Group=__No_joining_group}', "");
Expect(0, 2221, '\p{^Joining_Group=__No_joining_group}', "");
Expect(0, 2221, '\P{Joining_Group=__No_joining_group}', "");
Expect(1, 2221, '\P{^Joining_Group=__No_joining_group}', "");
Expect(0, 2220, '\p{Joining_Group=__No_joining_group}', "");
Expect(1, 2220, '\p{^Joining_Group=__No_joining_group}', "");
Expect(1, 2220, '\P{Joining_Group=__No_joining_group}', "");
Expect(0, 2220, '\P{^Joining_Group=__No_joining_group}', "");
Error('\p{Jg=_ NO_joining_GROUP/a/}');
Error('\P{Jg=_ NO_joining_GROUP/a/}');
Expect(1, 2221, '\p{Jg=nojoininggroup}', "");
Expect(0, 2221, '\p{^Jg=nojoininggroup}', "");
Expect(0, 2221, '\P{Jg=nojoininggroup}', "");
Expect(1, 2221, '\P{^Jg=nojoininggroup}', "");
Expect(0, 2220, '\p{Jg=nojoininggroup}', "");
Expect(1, 2220, '\p{^Jg=nojoininggroup}', "");
Expect(1, 2220, '\P{Jg=nojoininggroup}', "");
Expect(0, 2220, '\P{^Jg=nojoininggroup}', "");
Expect(1, 2221, '\p{Jg:   NO_Joining_GROUP}', "");
Expect(0, 2221, '\p{^Jg:   NO_Joining_GROUP}', "");
Expect(0, 2221, '\P{Jg:   NO_Joining_GROUP}', "");
Expect(1, 2221, '\P{^Jg:   NO_Joining_GROUP}', "");
Expect(0, 2220, '\p{Jg:   NO_Joining_GROUP}', "");
Expect(1, 2220, '\p{^Jg:   NO_Joining_GROUP}', "");
Expect(1, 2220, '\P{Jg:   NO_Joining_GROUP}', "");
Expect(0, 2220, '\P{^Jg:   NO_Joining_GROUP}', "");
Error('\p{Is_Joining_Group=/a/No_JOINING_GROUP}');
Error('\P{Is_Joining_Group=/a/No_JOINING_GROUP}');
Expect(1, 2221, '\p{Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\p{^Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2221, '\P{Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\P{^Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\p{Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2220, '\P{Is_Joining_Group=nojoininggroup}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=nojoininggroup}', "");
Expect(1, 2221, '\p{Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(0, 2221, '\p{^Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(0, 2221, '\P{Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(1, 2221, '\P{^Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(0, 2220, '\p{Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(1, 2220, '\P{Is_Joining_Group=-	NO_Joining_GROUP}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=-	NO_Joining_GROUP}', "");
Error('\p{Is_Jg=_/a/no_Joining_group}');
Error('\P{Is_Jg=_/a/no_Joining_group}');
Expect(1, 2221, '\p{Is_Jg=nojoininggroup}', "");
Expect(0, 2221, '\p{^Is_Jg=nojoininggroup}', "");
Expect(0, 2221, '\P{Is_Jg=nojoininggroup}', "");
Expect(1, 2221, '\P{^Is_Jg=nojoininggroup}', "");
Expect(0, 2220, '\p{Is_Jg=nojoininggroup}', "");
Expect(1, 2220, '\p{^Is_Jg=nojoininggroup}', "");
Expect(1, 2220, '\P{Is_Jg=nojoininggroup}', "");
Expect(0, 2220, '\P{^Is_Jg=nojoininggroup}', "");
Expect(1, 2221, '\p{Is_Jg= NO_Joining_Group}', "");
Expect(0, 2221, '\p{^Is_Jg= NO_Joining_Group}', "");
Expect(0, 2221, '\P{Is_Jg= NO_Joining_Group}', "");
Expect(1, 2221, '\P{^Is_Jg= NO_Joining_Group}', "");
Expect(0, 2220, '\p{Is_Jg= NO_Joining_Group}', "");
Expect(1, 2220, '\p{^Is_Jg= NO_Joining_Group}', "");
Expect(1, 2220, '\P{Is_Jg= NO_Joining_Group}', "");
Expect(0, 2220, '\P{^Is_Jg= NO_Joining_Group}', "");
Error('\p{Joining_Group=__Noon:=}');
Error('\P{Joining_Group=__Noon:=}');
Expect(1, 1897, '\p{Joining_Group=noon}', "");
Expect(0, 1897, '\p{^Joining_Group=noon}', "");
Expect(0, 1897, '\P{Joining_Group=noon}', "");
Expect(1, 1897, '\P{^Joining_Group=noon}', "");
Expect(0, 1898, '\p{Joining_Group=noon}', "");
Expect(1, 1898, '\p{^Joining_Group=noon}', "");
Expect(1, 1898, '\P{Joining_Group=noon}', "");
Expect(0, 1898, '\P{^Joining_Group=noon}', "");
Expect(1, 1897, '\p{Joining_Group=	Noon}', "");
Expect(0, 1897, '\p{^Joining_Group=	Noon}', "");
Expect(0, 1897, '\P{Joining_Group=	Noon}', "");
Expect(1, 1897, '\P{^Joining_Group=	Noon}', "");
Expect(0, 1898, '\p{Joining_Group=	Noon}', "");
Expect(1, 1898, '\p{^Joining_Group=	Noon}', "");
Expect(1, 1898, '\P{Joining_Group=	Noon}', "");
Expect(0, 1898, '\P{^Joining_Group=	Noon}', "");
Error('\p{Jg=	Noon/a/}');
Error('\P{Jg=	Noon/a/}');
Expect(1, 1897, '\p{Jg=noon}', "");
Expect(0, 1897, '\p{^Jg=noon}', "");
Expect(0, 1897, '\P{Jg=noon}', "");
Expect(1, 1897, '\P{^Jg=noon}', "");
Expect(0, 1898, '\p{Jg=noon}', "");
Expect(1, 1898, '\p{^Jg=noon}', "");
Expect(1, 1898, '\P{Jg=noon}', "");
Expect(0, 1898, '\P{^Jg=noon}', "");
Expect(1, 1897, '\p{Jg=	 NOON}', "");
Expect(0, 1897, '\p{^Jg=	 NOON}', "");
Expect(0, 1897, '\P{Jg=	 NOON}', "");
Expect(1, 1897, '\P{^Jg=	 NOON}', "");
Expect(0, 1898, '\p{Jg=	 NOON}', "");
Expect(1, 1898, '\p{^Jg=	 NOON}', "");
Expect(1, 1898, '\P{Jg=	 NOON}', "");
Expect(0, 1898, '\P{^Jg=	 NOON}', "");
Error('\p{Is_Joining_Group=/a/NOON}');
Error('\P{Is_Joining_Group=/a/NOON}');
Expect(1, 1897, '\p{Is_Joining_Group=noon}', "");
Expect(0, 1897, '\p{^Is_Joining_Group=noon}', "");
Expect(0, 1897, '\P{Is_Joining_Group=noon}', "");
Expect(1, 1897, '\P{^Is_Joining_Group=noon}', "");
Expect(0, 1898, '\p{Is_Joining_Group=noon}', "");
Expect(1, 1898, '\p{^Is_Joining_Group=noon}', "");
Expect(1, 1898, '\P{Is_Joining_Group=noon}', "");
Expect(0, 1898, '\P{^Is_Joining_Group=noon}', "");
Expect(1, 1897, '\p{Is_Joining_Group: 	-Noon}', "");
Expect(0, 1897, '\p{^Is_Joining_Group: 	-Noon}', "");
Expect(0, 1897, '\P{Is_Joining_Group: 	-Noon}', "");
Expect(1, 1897, '\P{^Is_Joining_Group: 	-Noon}', "");
Expect(0, 1898, '\p{Is_Joining_Group: 	-Noon}', "");
Expect(1, 1898, '\p{^Is_Joining_Group: 	-Noon}', "");
Expect(1, 1898, '\P{Is_Joining_Group: 	-Noon}', "");
Expect(0, 1898, '\P{^Is_Joining_Group: 	-Noon}', "");
Error('\p{Is_Jg=:=_	NOON}');
Error('\P{Is_Jg=:=_	NOON}');
Expect(1, 1897, '\p{Is_Jg=noon}', "");
Expect(0, 1897, '\p{^Is_Jg=noon}', "");
Expect(0, 1897, '\P{Is_Jg=noon}', "");
Expect(1, 1897, '\P{^Is_Jg=noon}', "");
Expect(0, 1898, '\p{Is_Jg=noon}', "");
Expect(1, 1898, '\p{^Is_Jg=noon}', "");
Expect(1, 1898, '\P{Is_Jg=noon}', "");
Expect(0, 1898, '\P{^Is_Jg=noon}', "");
Expect(1, 1897, '\p{Is_Jg: --Noon}', "");
Expect(0, 1897, '\p{^Is_Jg: --Noon}', "");
Expect(0, 1897, '\P{Is_Jg: --Noon}', "");
Expect(1, 1897, '\P{^Is_Jg: --Noon}', "");
Expect(0, 1898, '\p{Is_Jg: --Noon}', "");
Expect(1, 1898, '\p{^Is_Jg: --Noon}', "");
Expect(1, 1898, '\P{Is_Jg: --Noon}', "");
Expect(0, 1898, '\P{^Is_Jg: --Noon}', "");
Error('\p{Joining_Group=/a/_	Nun}');
Error('\P{Joining_Group=/a/_	Nun}');
Expect(1, 1826, '\p{Joining_Group=nun}', "");
Expect(0, 1826, '\p{^Joining_Group=nun}', "");
Expect(0, 1826, '\P{Joining_Group=nun}', "");
Expect(1, 1826, '\P{^Joining_Group=nun}', "");
Expect(0, 1827, '\p{Joining_Group=nun}', "");
Expect(1, 1827, '\p{^Joining_Group=nun}', "");
Expect(1, 1827, '\P{Joining_Group=nun}', "");
Expect(0, 1827, '\P{^Joining_Group=nun}', "");
Expect(1, 1826, '\p{Joining_Group=_Nun}', "");
Expect(0, 1826, '\p{^Joining_Group=_Nun}', "");
Expect(0, 1826, '\P{Joining_Group=_Nun}', "");
Expect(1, 1826, '\P{^Joining_Group=_Nun}', "");
Expect(0, 1827, '\p{Joining_Group=_Nun}', "");
Expect(1, 1827, '\p{^Joining_Group=_Nun}', "");
Expect(1, 1827, '\P{Joining_Group=_Nun}', "");
Expect(0, 1827, '\P{^Joining_Group=_Nun}', "");
Error('\p{Jg=:=	NUN}');
Error('\P{Jg=:=	NUN}');
Expect(1, 1826, '\p{Jg:nun}', "");
Expect(0, 1826, '\p{^Jg:nun}', "");
Expect(0, 1826, '\P{Jg:nun}', "");
Expect(1, 1826, '\P{^Jg:nun}', "");
Expect(0, 1827, '\p{Jg:nun}', "");
Expect(1, 1827, '\p{^Jg:nun}', "");
Expect(1, 1827, '\P{Jg:nun}', "");
Expect(0, 1827, '\P{^Jg:nun}', "");
Expect(1, 1826, '\p{Jg=	-nun}', "");
Expect(0, 1826, '\p{^Jg=	-nun}', "");
Expect(0, 1826, '\P{Jg=	-nun}', "");
Expect(1, 1826, '\P{^Jg=	-nun}', "");
Expect(0, 1827, '\p{Jg=	-nun}', "");
Expect(1, 1827, '\p{^Jg=	-nun}', "");
Expect(1, 1827, '\P{Jg=	-nun}', "");
Expect(0, 1827, '\P{^Jg=	-nun}', "");
Error('\p{Is_Joining_Group=/a/NUN}');
Error('\P{Is_Joining_Group=/a/NUN}');
Expect(1, 1826, '\p{Is_Joining_Group=nun}', "");
Expect(0, 1826, '\p{^Is_Joining_Group=nun}', "");
Expect(0, 1826, '\P{Is_Joining_Group=nun}', "");
Expect(1, 1826, '\P{^Is_Joining_Group=nun}', "");
Expect(0, 1827, '\p{Is_Joining_Group=nun}', "");
Expect(1, 1827, '\p{^Is_Joining_Group=nun}', "");
Expect(1, 1827, '\P{Is_Joining_Group=nun}', "");
Expect(0, 1827, '\P{^Is_Joining_Group=nun}', "");
Expect(1, 1826, '\p{Is_Joining_Group=	NUN}', "");
Expect(0, 1826, '\p{^Is_Joining_Group=	NUN}', "");
Expect(0, 1826, '\P{Is_Joining_Group=	NUN}', "");
Expect(1, 1826, '\P{^Is_Joining_Group=	NUN}', "");
Expect(0, 1827, '\p{Is_Joining_Group=	NUN}', "");
Expect(1, 1827, '\p{^Is_Joining_Group=	NUN}', "");
Expect(1, 1827, '\P{Is_Joining_Group=	NUN}', "");
Expect(0, 1827, '\P{^Is_Joining_Group=	NUN}', "");
Error('\p{Is_Jg=	 NUN:=}');
Error('\P{Is_Jg=	 NUN:=}');
Expect(1, 1826, '\p{Is_Jg=nun}', "");
Expect(0, 1826, '\p{^Is_Jg=nun}', "");
Expect(0, 1826, '\P{Is_Jg=nun}', "");
Expect(1, 1826, '\P{^Is_Jg=nun}', "");
Expect(0, 1827, '\p{Is_Jg=nun}', "");
Expect(1, 1827, '\p{^Is_Jg=nun}', "");
Expect(1, 1827, '\P{Is_Jg=nun}', "");
Expect(0, 1827, '\P{^Is_Jg=nun}', "");
Expect(1, 1826, '\p{Is_Jg= Nun}', "");
Expect(0, 1826, '\p{^Is_Jg= Nun}', "");
Expect(0, 1826, '\P{Is_Jg= Nun}', "");
Expect(1, 1826, '\P{^Is_Jg= Nun}', "");
Expect(0, 1827, '\p{Is_Jg= Nun}', "");
Expect(1, 1827, '\p{^Is_Jg= Nun}', "");
Expect(1, 1827, '\P{Is_Jg= Nun}', "");
Expect(0, 1827, '\P{^Is_Jg= Nun}', "");
Error('\p{Joining_Group=/a/__Nya}');
Error('\P{Joining_Group=/a/__Nya}');
Expect(1, 1725, '\p{Joining_Group=nya}', "");
Expect(0, 1725, '\p{^Joining_Group=nya}', "");
Expect(0, 1725, '\P{Joining_Group=nya}', "");
Expect(1, 1725, '\P{^Joining_Group=nya}', "");
Expect(0, 1726, '\p{Joining_Group=nya}', "");
Expect(1, 1726, '\p{^Joining_Group=nya}', "");
Expect(1, 1726, '\P{Joining_Group=nya}', "");
Expect(0, 1726, '\P{^Joining_Group=nya}', "");
Expect(1, 1725, '\p{Joining_Group=--Nya}', "");
Expect(0, 1725, '\p{^Joining_Group=--Nya}', "");
Expect(0, 1725, '\P{Joining_Group=--Nya}', "");
Expect(1, 1725, '\P{^Joining_Group=--Nya}', "");
Expect(0, 1726, '\p{Joining_Group=--Nya}', "");
Expect(1, 1726, '\p{^Joining_Group=--Nya}', "");
Expect(1, 1726, '\P{Joining_Group=--Nya}', "");
Expect(0, 1726, '\P{^Joining_Group=--Nya}', "");
Error('\p{Jg=:= nya}');
Error('\P{Jg=:= nya}');
Expect(1, 1725, '\p{Jg=nya}', "");
Expect(0, 1725, '\p{^Jg=nya}', "");
Expect(0, 1725, '\P{Jg=nya}', "");
Expect(1, 1725, '\P{^Jg=nya}', "");
Expect(0, 1726, '\p{Jg=nya}', "");
Expect(1, 1726, '\p{^Jg=nya}', "");
Expect(1, 1726, '\P{Jg=nya}', "");
Expect(0, 1726, '\P{^Jg=nya}', "");
Expect(1, 1725, '\p{Jg= nya}', "");
Expect(0, 1725, '\p{^Jg= nya}', "");
Expect(0, 1725, '\P{Jg= nya}', "");
Expect(1, 1725, '\P{^Jg= nya}', "");
Expect(0, 1726, '\p{Jg= nya}', "");
Expect(1, 1726, '\p{^Jg= nya}', "");
Expect(1, 1726, '\P{Jg= nya}', "");
Expect(0, 1726, '\P{^Jg= nya}', "");
Error('\p{Is_Joining_Group=__NYA/a/}');
Error('\P{Is_Joining_Group=__NYA/a/}');
Expect(1, 1725, '\p{Is_Joining_Group=nya}', "");
Expect(0, 1725, '\p{^Is_Joining_Group=nya}', "");
Expect(0, 1725, '\P{Is_Joining_Group=nya}', "");
Expect(1, 1725, '\P{^Is_Joining_Group=nya}', "");
Expect(0, 1726, '\p{Is_Joining_Group=nya}', "");
Expect(1, 1726, '\p{^Is_Joining_Group=nya}', "");
Expect(1, 1726, '\P{Is_Joining_Group=nya}', "");
Expect(0, 1726, '\P{^Is_Joining_Group=nya}', "");
Expect(1, 1725, '\p{Is_Joining_Group=-nya}', "");
Expect(0, 1725, '\p{^Is_Joining_Group=-nya}', "");
Expect(0, 1725, '\P{Is_Joining_Group=-nya}', "");
Expect(1, 1725, '\P{^Is_Joining_Group=-nya}', "");
Expect(0, 1726, '\p{Is_Joining_Group=-nya}', "");
Expect(1, 1726, '\p{^Is_Joining_Group=-nya}', "");
Expect(1, 1726, '\P{Is_Joining_Group=-nya}', "");
Expect(0, 1726, '\P{^Is_Joining_Group=-nya}', "");
Error('\p{Is_Jg:/a/	Nya}');
Error('\P{Is_Jg:/a/	Nya}');
Expect(1, 1725, '\p{Is_Jg=nya}', "");
Expect(0, 1725, '\p{^Is_Jg=nya}', "");
Expect(0, 1725, '\P{Is_Jg=nya}', "");
Expect(1, 1725, '\P{^Is_Jg=nya}', "");
Expect(0, 1726, '\p{Is_Jg=nya}', "");
Expect(1, 1726, '\p{^Is_Jg=nya}', "");
Expect(1, 1726, '\P{Is_Jg=nya}', "");
Expect(0, 1726, '\P{^Is_Jg=nya}', "");
Expect(1, 1725, '\p{Is_Jg=- Nya}', "");
Expect(0, 1725, '\p{^Is_Jg=- Nya}', "");
Expect(0, 1725, '\P{Is_Jg=- Nya}', "");
Expect(1, 1725, '\P{^Is_Jg=- Nya}', "");
Expect(0, 1726, '\p{Is_Jg=- Nya}', "");
Expect(1, 1726, '\p{^Is_Jg=- Nya}', "");
Expect(1, 1726, '\P{Is_Jg=- Nya}', "");
Expect(0, 1726, '\P{^Is_Jg=- Nya}', "");
Error('\p{Joining_Group=_ Pe:=}');
Error('\P{Joining_Group=_ Pe:=}');
Expect(1, 1830, '\p{Joining_Group=pe}', "");
Expect(0, 1830, '\p{^Joining_Group=pe}', "");
Expect(0, 1830, '\P{Joining_Group=pe}', "");
Expect(1, 1830, '\P{^Joining_Group=pe}', "");
Expect(0, 1831, '\p{Joining_Group=pe}', "");
Expect(1, 1831, '\p{^Joining_Group=pe}', "");
Expect(1, 1831, '\P{Joining_Group=pe}', "");
Expect(0, 1831, '\P{^Joining_Group=pe}', "");
Expect(1, 1830, '\p{Joining_Group: 	_Pe}', "");
Expect(0, 1830, '\p{^Joining_Group: 	_Pe}', "");
Expect(0, 1830, '\P{Joining_Group: 	_Pe}', "");
Expect(1, 1830, '\P{^Joining_Group: 	_Pe}', "");
Expect(0, 1831, '\p{Joining_Group: 	_Pe}', "");
Expect(1, 1831, '\p{^Joining_Group: 	_Pe}', "");
Expect(1, 1831, '\P{Joining_Group: 	_Pe}', "");
Expect(0, 1831, '\P{^Joining_Group: 	_Pe}', "");
Error('\p{Jg=/a/ Pe}');
Error('\P{Jg=/a/ Pe}');
Expect(1, 1830, '\p{Jg=pe}', "");
Expect(0, 1830, '\p{^Jg=pe}', "");
Expect(0, 1830, '\P{Jg=pe}', "");
Expect(1, 1830, '\P{^Jg=pe}', "");
Expect(0, 1831, '\p{Jg=pe}', "");
Expect(1, 1831, '\p{^Jg=pe}', "");
Expect(1, 1831, '\P{Jg=pe}', "");
Expect(0, 1831, '\P{^Jg=pe}', "");
Expect(1, 1830, '\p{Jg:  pe}', "");
Expect(0, 1830, '\p{^Jg:  pe}', "");
Expect(0, 1830, '\P{Jg:  pe}', "");
Expect(1, 1830, '\P{^Jg:  pe}', "");
Expect(0, 1831, '\p{Jg:  pe}', "");
Expect(1, 1831, '\p{^Jg:  pe}', "");
Expect(1, 1831, '\P{Jg:  pe}', "");
Expect(0, 1831, '\P{^Jg:  pe}', "");
Error('\p{Is_Joining_Group: :=	pe}');
Error('\P{Is_Joining_Group: :=	pe}');
Expect(1, 1830, '\p{Is_Joining_Group=pe}', "");
Expect(0, 1830, '\p{^Is_Joining_Group=pe}', "");
Expect(0, 1830, '\P{Is_Joining_Group=pe}', "");
Expect(1, 1830, '\P{^Is_Joining_Group=pe}', "");
Expect(0, 1831, '\p{Is_Joining_Group=pe}', "");
Expect(1, 1831, '\p{^Is_Joining_Group=pe}', "");
Expect(1, 1831, '\P{Is_Joining_Group=pe}', "");
Expect(0, 1831, '\P{^Is_Joining_Group=pe}', "");
Expect(1, 1830, '\p{Is_Joining_Group=--PE}', "");
Expect(0, 1830, '\p{^Is_Joining_Group=--PE}', "");
Expect(0, 1830, '\P{Is_Joining_Group=--PE}', "");
Expect(1, 1830, '\P{^Is_Joining_Group=--PE}', "");
Expect(0, 1831, '\p{Is_Joining_Group=--PE}', "");
Expect(1, 1831, '\p{^Is_Joining_Group=--PE}', "");
Expect(1, 1831, '\P{Is_Joining_Group=--PE}', "");
Expect(0, 1831, '\P{^Is_Joining_Group=--PE}', "");
Error('\p{Is_Jg=-:=Pe}');
Error('\P{Is_Jg=-:=Pe}');
Expect(1, 1830, '\p{Is_Jg=pe}', "");
Expect(0, 1830, '\p{^Is_Jg=pe}', "");
Expect(0, 1830, '\P{Is_Jg=pe}', "");
Expect(1, 1830, '\P{^Is_Jg=pe}', "");
Expect(0, 1831, '\p{Is_Jg=pe}', "");
Expect(1, 1831, '\p{^Is_Jg=pe}', "");
Expect(1, 1831, '\P{Is_Jg=pe}', "");
Expect(0, 1831, '\P{^Is_Jg=pe}', "");
Expect(1, 1830, '\p{Is_Jg=	 pe}', "");
Expect(0, 1830, '\p{^Is_Jg=	 pe}', "");
Expect(0, 1830, '\P{Is_Jg=	 pe}', "");
Expect(1, 1830, '\P{^Is_Jg=	 pe}', "");
Expect(0, 1831, '\p{Is_Jg=	 pe}', "");
Expect(1, 1831, '\p{^Is_Jg=	 pe}', "");
Expect(1, 1831, '\P{Is_Jg=	 pe}', "");
Expect(0, 1831, '\P{^Is_Jg=	 pe}', "");
Error('\p{Joining_Group= :=Qaf}');
Error('\P{Joining_Group= :=Qaf}');
Expect(1, 2213, '\p{Joining_Group=qaf}', "");
Expect(0, 2213, '\p{^Joining_Group=qaf}', "");
Expect(0, 2213, '\P{Joining_Group=qaf}', "");
Expect(1, 2213, '\P{^Joining_Group=qaf}', "");
Expect(0, 2214, '\p{Joining_Group=qaf}', "");
Expect(1, 2214, '\p{^Joining_Group=qaf}', "");
Expect(1, 2214, '\P{Joining_Group=qaf}', "");
Expect(0, 2214, '\P{^Joining_Group=qaf}', "");
Expect(1, 2213, '\p{Joining_Group=	-qaf}', "");
Expect(0, 2213, '\p{^Joining_Group=	-qaf}', "");
Expect(0, 2213, '\P{Joining_Group=	-qaf}', "");
Expect(1, 2213, '\P{^Joining_Group=	-qaf}', "");
Expect(0, 2214, '\p{Joining_Group=	-qaf}', "");
Expect(1, 2214, '\p{^Joining_Group=	-qaf}', "");
Expect(1, 2214, '\P{Joining_Group=	-qaf}', "");
Expect(0, 2214, '\P{^Joining_Group=	-qaf}', "");
Error('\p{Jg=	/a/Qaf}');
Error('\P{Jg=	/a/Qaf}');
Expect(1, 2213, '\p{Jg=qaf}', "");
Expect(0, 2213, '\p{^Jg=qaf}', "");
Expect(0, 2213, '\P{Jg=qaf}', "");
Expect(1, 2213, '\P{^Jg=qaf}', "");
Expect(0, 2214, '\p{Jg=qaf}', "");
Expect(1, 2214, '\p{^Jg=qaf}', "");
Expect(1, 2214, '\P{Jg=qaf}', "");
Expect(0, 2214, '\P{^Jg=qaf}', "");
Expect(1, 2213, '\p{Jg=	 qaf}', "");
Expect(0, 2213, '\p{^Jg=	 qaf}', "");
Expect(0, 2213, '\P{Jg=	 qaf}', "");
Expect(1, 2213, '\P{^Jg=	 qaf}', "");
Expect(0, 2214, '\p{Jg=	 qaf}', "");
Expect(1, 2214, '\p{^Jg=	 qaf}', "");
Expect(1, 2214, '\P{Jg=	 qaf}', "");
Expect(0, 2214, '\P{^Jg=	 qaf}', "");
Error('\p{Is_Joining_Group=  Qaf:=}');
Error('\P{Is_Joining_Group=  Qaf:=}');
Expect(1, 2213, '\p{Is_Joining_Group=qaf}', "");
Expect(0, 2213, '\p{^Is_Joining_Group=qaf}', "");
Expect(0, 2213, '\P{Is_Joining_Group=qaf}', "");
Expect(1, 2213, '\P{^Is_Joining_Group=qaf}', "");
Expect(0, 2214, '\p{Is_Joining_Group=qaf}', "");
Expect(1, 2214, '\p{^Is_Joining_Group=qaf}', "");
Expect(1, 2214, '\P{Is_Joining_Group=qaf}', "");
Expect(0, 2214, '\P{^Is_Joining_Group=qaf}', "");
Expect(1, 2213, '\p{Is_Joining_Group= _Qaf}', "");
Expect(0, 2213, '\p{^Is_Joining_Group= _Qaf}', "");
Expect(0, 2213, '\P{Is_Joining_Group= _Qaf}', "");
Expect(1, 2213, '\P{^Is_Joining_Group= _Qaf}', "");
Expect(0, 2214, '\p{Is_Joining_Group= _Qaf}', "");
Expect(1, 2214, '\p{^Is_Joining_Group= _Qaf}', "");
Expect(1, 2214, '\P{Is_Joining_Group= _Qaf}', "");
Expect(0, 2214, '\P{^Is_Joining_Group= _Qaf}', "");
Error('\p{Is_Jg=	 qaf/a/}');
Error('\P{Is_Jg=	 qaf/a/}');
Expect(1, 2213, '\p{Is_Jg=qaf}', "");
Expect(0, 2213, '\p{^Is_Jg=qaf}', "");
Expect(0, 2213, '\P{Is_Jg=qaf}', "");
Expect(1, 2213, '\P{^Is_Jg=qaf}', "");
Expect(0, 2214, '\p{Is_Jg=qaf}', "");
Expect(1, 2214, '\p{^Is_Jg=qaf}', "");
Expect(1, 2214, '\P{Is_Jg=qaf}', "");
Expect(0, 2214, '\P{^Is_Jg=qaf}', "");
Expect(1, 2213, '\p{Is_Jg=_ Qaf}', "");
Expect(0, 2213, '\p{^Is_Jg=_ Qaf}', "");
Expect(0, 2213, '\P{Is_Jg=_ Qaf}', "");
Expect(1, 2213, '\P{^Is_Jg=_ Qaf}', "");
Expect(0, 2214, '\p{Is_Jg=_ Qaf}', "");
Expect(1, 2214, '\p{^Is_Jg=_ Qaf}', "");
Expect(1, 2214, '\P{Is_Jg=_ Qaf}', "");
Expect(0, 2214, '\P{^Is_Jg=_ Qaf}', "");
Error('\p{Joining_Group:   -Qaph/a/}');
Error('\P{Joining_Group:   -Qaph/a/}');
Expect(1, 1833, '\p{Joining_Group=qaph}', "");
Expect(0, 1833, '\p{^Joining_Group=qaph}', "");
Expect(0, 1833, '\P{Joining_Group=qaph}', "");
Expect(1, 1833, '\P{^Joining_Group=qaph}', "");
Expect(0, 1834, '\p{Joining_Group=qaph}', "");
Expect(1, 1834, '\p{^Joining_Group=qaph}', "");
Expect(1, 1834, '\P{Joining_Group=qaph}', "");
Expect(0, 1834, '\P{^Joining_Group=qaph}', "");
Expect(1, 1833, '\p{Joining_Group=-Qaph}', "");
Expect(0, 1833, '\p{^Joining_Group=-Qaph}', "");
Expect(0, 1833, '\P{Joining_Group=-Qaph}', "");
Expect(1, 1833, '\P{^Joining_Group=-Qaph}', "");
Expect(0, 1834, '\p{Joining_Group=-Qaph}', "");
Expect(1, 1834, '\p{^Joining_Group=-Qaph}', "");
Expect(1, 1834, '\P{Joining_Group=-Qaph}', "");
Expect(0, 1834, '\P{^Joining_Group=-Qaph}', "");
Error('\p{Jg=- Qaph/a/}');
Error('\P{Jg=- Qaph/a/}');
Expect(1, 1833, '\p{Jg:	qaph}', "");
Expect(0, 1833, '\p{^Jg:	qaph}', "");
Expect(0, 1833, '\P{Jg:	qaph}', "");
Expect(1, 1833, '\P{^Jg:	qaph}', "");
Expect(0, 1834, '\p{Jg:	qaph}', "");
Expect(1, 1834, '\p{^Jg:	qaph}', "");
Expect(1, 1834, '\P{Jg:	qaph}', "");
Expect(0, 1834, '\P{^Jg:	qaph}', "");
Expect(1, 1833, '\p{Jg= _Qaph}', "");
Expect(0, 1833, '\p{^Jg= _Qaph}', "");
Expect(0, 1833, '\P{Jg= _Qaph}', "");
Expect(1, 1833, '\P{^Jg= _Qaph}', "");
Expect(0, 1834, '\p{Jg= _Qaph}', "");
Expect(1, 1834, '\p{^Jg= _Qaph}', "");
Expect(1, 1834, '\P{Jg= _Qaph}', "");
Expect(0, 1834, '\P{^Jg= _Qaph}', "");
Error('\p{Is_Joining_Group: /a/Qaph}');
Error('\P{Is_Joining_Group: /a/Qaph}');
Expect(1, 1833, '\p{Is_Joining_Group=qaph}', "");
Expect(0, 1833, '\p{^Is_Joining_Group=qaph}', "");
Expect(0, 1833, '\P{Is_Joining_Group=qaph}', "");
Expect(1, 1833, '\P{^Is_Joining_Group=qaph}', "");
Expect(0, 1834, '\p{Is_Joining_Group=qaph}', "");
Expect(1, 1834, '\p{^Is_Joining_Group=qaph}', "");
Expect(1, 1834, '\P{Is_Joining_Group=qaph}', "");
Expect(0, 1834, '\P{^Is_Joining_Group=qaph}', "");
Expect(1, 1833, '\p{Is_Joining_Group: 	_Qaph}', "");
Expect(0, 1833, '\p{^Is_Joining_Group: 	_Qaph}', "");
Expect(0, 1833, '\P{Is_Joining_Group: 	_Qaph}', "");
Expect(1, 1833, '\P{^Is_Joining_Group: 	_Qaph}', "");
Expect(0, 1834, '\p{Is_Joining_Group: 	_Qaph}', "");
Expect(1, 1834, '\p{^Is_Joining_Group: 	_Qaph}', "");
Expect(1, 1834, '\P{Is_Joining_Group: 	_Qaph}', "");
Expect(0, 1834, '\P{^Is_Joining_Group: 	_Qaph}', "");
Error('\p{Is_Jg=	_QAPH:=}');
Error('\P{Is_Jg=	_QAPH:=}');
Expect(1, 1833, '\p{Is_Jg=qaph}', "");
Expect(0, 1833, '\p{^Is_Jg=qaph}', "");
Expect(0, 1833, '\P{Is_Jg=qaph}', "");
Expect(1, 1833, '\P{^Is_Jg=qaph}', "");
Expect(0, 1834, '\p{Is_Jg=qaph}', "");
Expect(1, 1834, '\p{^Is_Jg=qaph}', "");
Expect(1, 1834, '\P{Is_Jg=qaph}', "");
Expect(0, 1834, '\P{^Is_Jg=qaph}', "");
Expect(1, 1833, '\p{Is_Jg: QAPH}', "");
Expect(0, 1833, '\p{^Is_Jg: QAPH}', "");
Expect(0, 1833, '\P{Is_Jg: QAPH}', "");
Expect(1, 1833, '\P{^Is_Jg: QAPH}', "");
Expect(0, 1834, '\p{Is_Jg: QAPH}', "");
Expect(1, 1834, '\p{^Is_Jg: QAPH}', "");
Expect(1, 1834, '\P{Is_Jg: QAPH}', "");
Expect(0, 1834, '\P{^Is_Jg: QAPH}', "");
Error('\p{Joining_Group= Reh/a/}');
Error('\P{Joining_Group= Reh/a/}');
Expect(1, 2218, '\p{Joining_Group=reh}', "");
Expect(0, 2218, '\p{^Joining_Group=reh}', "");
Expect(0, 2218, '\P{Joining_Group=reh}', "");
Expect(1, 2218, '\P{^Joining_Group=reh}', "");
Expect(0, 2219, '\p{Joining_Group=reh}', "");
Expect(1, 2219, '\p{^Joining_Group=reh}', "");
Expect(1, 2219, '\P{Joining_Group=reh}', "");
Expect(0, 2219, '\P{^Joining_Group=reh}', "");
Expect(1, 2218, '\p{Joining_Group=	_reh}', "");
Expect(0, 2218, '\p{^Joining_Group=	_reh}', "");
Expect(0, 2218, '\P{Joining_Group=	_reh}', "");
Expect(1, 2218, '\P{^Joining_Group=	_reh}', "");
Expect(0, 2219, '\p{Joining_Group=	_reh}', "");
Expect(1, 2219, '\p{^Joining_Group=	_reh}', "");
Expect(1, 2219, '\P{Joining_Group=	_reh}', "");
Expect(0, 2219, '\P{^Joining_Group=	_reh}', "");
Error('\p{Jg=/a/ 	Reh}');
Error('\P{Jg=/a/ 	Reh}');
Expect(1, 2218, '\p{Jg=reh}', "");
Expect(0, 2218, '\p{^Jg=reh}', "");
Expect(0, 2218, '\P{Jg=reh}', "");
Expect(1, 2218, '\P{^Jg=reh}', "");
Expect(0, 2219, '\p{Jg=reh}', "");
Expect(1, 2219, '\p{^Jg=reh}', "");
Expect(1, 2219, '\P{Jg=reh}', "");
Expect(0, 2219, '\P{^Jg=reh}', "");
Expect(1, 2218, '\p{Jg:	-Reh}', "");
Expect(0, 2218, '\p{^Jg:	-Reh}', "");
Expect(0, 2218, '\P{Jg:	-Reh}', "");
Expect(1, 2218, '\P{^Jg:	-Reh}', "");
Expect(0, 2219, '\p{Jg:	-Reh}', "");
Expect(1, 2219, '\p{^Jg:	-Reh}', "");
Expect(1, 2219, '\P{Jg:	-Reh}', "");
Expect(0, 2219, '\P{^Jg:	-Reh}', "");
Error('\p{Is_Joining_Group=	 REH:=}');
Error('\P{Is_Joining_Group=	 REH:=}');
Expect(1, 2218, '\p{Is_Joining_Group=reh}', "");
Expect(0, 2218, '\p{^Is_Joining_Group=reh}', "");
Expect(0, 2218, '\P{Is_Joining_Group=reh}', "");
Expect(1, 2218, '\P{^Is_Joining_Group=reh}', "");
Expect(0, 2219, '\p{Is_Joining_Group=reh}', "");
Expect(1, 2219, '\p{^Is_Joining_Group=reh}', "");
Expect(1, 2219, '\P{Is_Joining_Group=reh}', "");
Expect(0, 2219, '\P{^Is_Joining_Group=reh}', "");
Expect(1, 2218, '\p{Is_Joining_Group:   	Reh}', "");
Expect(0, 2218, '\p{^Is_Joining_Group:   	Reh}', "");
Expect(0, 2218, '\P{Is_Joining_Group:   	Reh}', "");
Expect(1, 2218, '\P{^Is_Joining_Group:   	Reh}', "");
Expect(0, 2219, '\p{Is_Joining_Group:   	Reh}', "");
Expect(1, 2219, '\p{^Is_Joining_Group:   	Reh}', "");
Expect(1, 2219, '\P{Is_Joining_Group:   	Reh}', "");
Expect(0, 2219, '\P{^Is_Joining_Group:   	Reh}', "");
Error('\p{Is_Jg=		Reh:=}');
Error('\P{Is_Jg=		Reh:=}');
Expect(1, 2218, '\p{Is_Jg=reh}', "");
Expect(0, 2218, '\p{^Is_Jg=reh}', "");
Expect(0, 2218, '\P{Is_Jg=reh}', "");
Expect(1, 2218, '\P{^Is_Jg=reh}', "");
Expect(0, 2219, '\p{Is_Jg=reh}', "");
Expect(1, 2219, '\p{^Is_Jg=reh}', "");
Expect(1, 2219, '\P{Is_Jg=reh}', "");
Expect(0, 2219, '\P{^Is_Jg=reh}', "");
Expect(1, 2218, '\p{Is_Jg=	_REH}', "");
Expect(0, 2218, '\p{^Is_Jg=	_REH}', "");
Expect(0, 2218, '\P{Is_Jg=	_REH}', "");
Expect(1, 2218, '\P{^Is_Jg=	_REH}', "");
Expect(0, 2219, '\p{Is_Jg=	_REH}', "");
Expect(1, 2219, '\p{^Is_Jg=	_REH}', "");
Expect(1, 2219, '\P{Is_Jg=	_REH}', "");
Expect(0, 2219, '\P{^Is_Jg=	_REH}', "");
Error('\p{Joining_Group=	:=REVERSED_Pe}');
Error('\P{Joining_Group=	:=REVERSED_Pe}');
Expect(1, 1831, '\p{Joining_Group=reversedpe}', "");
Expect(0, 1831, '\p{^Joining_Group=reversedpe}', "");
Expect(0, 1831, '\P{Joining_Group=reversedpe}', "");
Expect(1, 1831, '\P{^Joining_Group=reversedpe}', "");
Expect(0, 1832, '\p{Joining_Group=reversedpe}', "");
Expect(1, 1832, '\p{^Joining_Group=reversedpe}', "");
Expect(1, 1832, '\P{Joining_Group=reversedpe}', "");
Expect(0, 1832, '\P{^Joining_Group=reversedpe}', "");
Expect(1, 1831, '\p{Joining_Group=	_Reversed_Pe}', "");
Expect(0, 1831, '\p{^Joining_Group=	_Reversed_Pe}', "");
Expect(0, 1831, '\P{Joining_Group=	_Reversed_Pe}', "");
Expect(1, 1831, '\P{^Joining_Group=	_Reversed_Pe}', "");
Expect(0, 1832, '\p{Joining_Group=	_Reversed_Pe}', "");
Expect(1, 1832, '\p{^Joining_Group=	_Reversed_Pe}', "");
Expect(1, 1832, '\P{Joining_Group=	_Reversed_Pe}', "");
Expect(0, 1832, '\P{^Joining_Group=	_Reversed_Pe}', "");
Error('\p{Jg=-/a/Reversed_Pe}');
Error('\P{Jg=-/a/Reversed_Pe}');
Expect(1, 1831, '\p{Jg=reversedpe}', "");
Expect(0, 1831, '\p{^Jg=reversedpe}', "");
Expect(0, 1831, '\P{Jg=reversedpe}', "");
Expect(1, 1831, '\P{^Jg=reversedpe}', "");
Expect(0, 1832, '\p{Jg=reversedpe}', "");
Expect(1, 1832, '\p{^Jg=reversedpe}', "");
Expect(1, 1832, '\P{Jg=reversedpe}', "");
Expect(0, 1832, '\P{^Jg=reversedpe}', "");
Expect(1, 1831, '\p{Jg= 	reversed_Pe}', "");
Expect(0, 1831, '\p{^Jg= 	reversed_Pe}', "");
Expect(0, 1831, '\P{Jg= 	reversed_Pe}', "");
Expect(1, 1831, '\P{^Jg= 	reversed_Pe}', "");
Expect(0, 1832, '\p{Jg= 	reversed_Pe}', "");
Expect(1, 1832, '\p{^Jg= 	reversed_Pe}', "");
Expect(1, 1832, '\P{Jg= 	reversed_Pe}', "");
Expect(0, 1832, '\P{^Jg= 	reversed_Pe}', "");
Error('\p{Is_Joining_Group=:=reversed_Pe}');
Error('\P{Is_Joining_Group=:=reversed_Pe}');
Expect(1, 1831, '\p{Is_Joining_Group=reversedpe}', "");
Expect(0, 1831, '\p{^Is_Joining_Group=reversedpe}', "");
Expect(0, 1831, '\P{Is_Joining_Group=reversedpe}', "");
Expect(1, 1831, '\P{^Is_Joining_Group=reversedpe}', "");
Expect(0, 1832, '\p{Is_Joining_Group=reversedpe}', "");
Expect(1, 1832, '\p{^Is_Joining_Group=reversedpe}', "");
Expect(1, 1832, '\P{Is_Joining_Group=reversedpe}', "");
Expect(0, 1832, '\P{^Is_Joining_Group=reversedpe}', "");
Expect(1, 1831, '\p{Is_Joining_Group:	Reversed_Pe}', "");
Expect(0, 1831, '\p{^Is_Joining_Group:	Reversed_Pe}', "");
Expect(0, 1831, '\P{Is_Joining_Group:	Reversed_Pe}', "");
Expect(1, 1831, '\P{^Is_Joining_Group:	Reversed_Pe}', "");
Expect(0, 1832, '\p{Is_Joining_Group:	Reversed_Pe}', "");
Expect(1, 1832, '\p{^Is_Joining_Group:	Reversed_Pe}', "");
Expect(1, 1832, '\P{Is_Joining_Group:	Reversed_Pe}', "");
Expect(0, 1832, '\P{^Is_Joining_Group:	Reversed_Pe}', "");
Error('\p{Is_Jg=-reversed_Pe:=}');
Error('\P{Is_Jg=-reversed_Pe:=}');
Expect(1, 1831, '\p{Is_Jg=reversedpe}', "");
Expect(0, 1831, '\p{^Is_Jg=reversedpe}', "");
Expect(0, 1831, '\P{Is_Jg=reversedpe}', "");
Expect(1, 1831, '\P{^Is_Jg=reversedpe}', "");
Expect(0, 1832, '\p{Is_Jg=reversedpe}', "");
Expect(1, 1832, '\p{^Is_Jg=reversedpe}', "");
Expect(1, 1832, '\P{Is_Jg=reversedpe}', "");
Expect(0, 1832, '\P{^Is_Jg=reversedpe}', "");
Expect(1, 1831, '\p{Is_Jg:_Reversed_PE}', "");
Expect(0, 1831, '\p{^Is_Jg:_Reversed_PE}', "");
Expect(0, 1831, '\P{Is_Jg:_Reversed_PE}', "");
Expect(1, 1831, '\P{^Is_Jg:_Reversed_PE}', "");
Expect(0, 1832, '\p{Is_Jg:_Reversed_PE}', "");
Expect(1, 1832, '\p{^Is_Jg:_Reversed_PE}', "");
Expect(1, 1832, '\P{Is_Jg:_Reversed_PE}', "");
Expect(0, 1832, '\P{^Is_Jg:_Reversed_PE}', "");
Error('\p{Joining_Group=:=ROHINGYA_YEH}');
Error('\P{Joining_Group=:=ROHINGYA_YEH}');
Expect(1, 2220, '\p{Joining_Group=rohingyayeh}', "");
Expect(0, 2220, '\p{^Joining_Group=rohingyayeh}', "");
Expect(0, 2220, '\P{Joining_Group=rohingyayeh}', "");
Expect(1, 2220, '\P{^Joining_Group=rohingyayeh}', "");
Expect(0, 2221, '\p{Joining_Group=rohingyayeh}', "");
Expect(1, 2221, '\p{^Joining_Group=rohingyayeh}', "");
Expect(1, 2221, '\P{Joining_Group=rohingyayeh}', "");
Expect(0, 2221, '\P{^Joining_Group=rohingyayeh}', "");
Expect(1, 2220, '\p{Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(0, 2220, '\p{^Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(0, 2220, '\P{Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(1, 2220, '\P{^Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(0, 2221, '\p{Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(1, 2221, '\p{^Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(1, 2221, '\P{Joining_Group=	 ROHINGYA_Yeh}', "");
Expect(0, 2221, '\P{^Joining_Group=	 ROHINGYA_Yeh}', "");
Error('\p{Jg=/a/	Rohingya_Yeh}');
Error('\P{Jg=/a/	Rohingya_Yeh}');
Expect(1, 2220, '\p{Jg=rohingyayeh}', "");
Expect(0, 2220, '\p{^Jg=rohingyayeh}', "");
Expect(0, 2220, '\P{Jg=rohingyayeh}', "");
Expect(1, 2220, '\P{^Jg=rohingyayeh}', "");
Expect(0, 2221, '\p{Jg=rohingyayeh}', "");
Expect(1, 2221, '\p{^Jg=rohingyayeh}', "");
Expect(1, 2221, '\P{Jg=rohingyayeh}', "");
Expect(0, 2221, '\P{^Jg=rohingyayeh}', "");
Expect(1, 2220, '\p{Jg=		rohingya_YEH}', "");
Expect(0, 2220, '\p{^Jg=		rohingya_YEH}', "");
Expect(0, 2220, '\P{Jg=		rohingya_YEH}', "");
Expect(1, 2220, '\P{^Jg=		rohingya_YEH}', "");
Expect(0, 2221, '\p{Jg=		rohingya_YEH}', "");
Expect(1, 2221, '\p{^Jg=		rohingya_YEH}', "");
Expect(1, 2221, '\P{Jg=		rohingya_YEH}', "");
Expect(0, 2221, '\P{^Jg=		rohingya_YEH}', "");
Error('\p{Is_Joining_Group=/a/__Rohingya_Yeh}');
Error('\P{Is_Joining_Group=/a/__Rohingya_Yeh}');
Expect(1, 2220, '\p{Is_Joining_Group:rohingyayeh}', "");
Expect(0, 2220, '\p{^Is_Joining_Group:rohingyayeh}', "");
Expect(0, 2220, '\P{Is_Joining_Group:rohingyayeh}', "");
Expect(1, 2220, '\P{^Is_Joining_Group:rohingyayeh}', "");
Expect(0, 2221, '\p{Is_Joining_Group:rohingyayeh}', "");
Expect(1, 2221, '\p{^Is_Joining_Group:rohingyayeh}', "");
Expect(1, 2221, '\P{Is_Joining_Group:rohingyayeh}', "");
Expect(0, 2221, '\P{^Is_Joining_Group:rohingyayeh}', "");
Expect(1, 2220, '\p{Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(0, 2220, '\p{^Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(0, 2220, '\P{Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(1, 2220, '\P{^Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(0, 2221, '\p{Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(1, 2221, '\p{^Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(1, 2221, '\P{Is_Joining_Group=-_Rohingya_yeh}', "");
Expect(0, 2221, '\P{^Is_Joining_Group=-_Rohingya_yeh}', "");
Error('\p{Is_Jg=_ROHINGYA_Yeh:=}');
Error('\P{Is_Jg=_ROHINGYA_Yeh:=}');
Expect(1, 2220, '\p{Is_Jg=rohingyayeh}', "");
Expect(0, 2220, '\p{^Is_Jg=rohingyayeh}', "");
Expect(0, 2220, '\P{Is_Jg=rohingyayeh}', "");
Expect(1, 2220, '\P{^Is_Jg=rohingyayeh}', "");
Expect(0, 2221, '\p{Is_Jg=rohingyayeh}', "");
Expect(1, 2221, '\p{^Is_Jg=rohingyayeh}', "");
Expect(1, 2221, '\P{Is_Jg=rohingyayeh}', "");
Expect(0, 2221, '\P{^Is_Jg=rohingyayeh}', "");
Expect(1, 2220, '\p{Is_Jg=-Rohingya_Yeh}', "");
Expect(0, 2220, '\p{^Is_Jg=-Rohingya_Yeh}', "");
Expect(0, 2220, '\P{Is_Jg=-Rohingya_Yeh}', "");
Expect(1, 2220, '\P{^Is_Jg=-Rohingya_Yeh}', "");
Expect(0, 2221, '\p{Is_Jg=-Rohingya_Yeh}', "");
Expect(1, 2221, '\p{^Is_Jg=-Rohingya_Yeh}', "");
Expect(1, 2221, '\P{Is_Jg=-Rohingya_Yeh}', "");
Expect(0, 2221, '\P{^Is_Jg=-Rohingya_Yeh}', "");
Error('\p{Joining_Group=/a/ -Sad}');
Error('\P{Joining_Group=/a/ -Sad}');
Expect(1, 1787, '\p{Joining_Group=sad}', "");
Expect(0, 1787, '\p{^Joining_Group=sad}', "");
Expect(0, 1787, '\P{Joining_Group=sad}', "");
Expect(1, 1787, '\P{^Joining_Group=sad}', "");
Expect(0, 1788, '\p{Joining_Group=sad}', "");
Expect(1, 1788, '\p{^Joining_Group=sad}', "");
Expect(1, 1788, '\P{Joining_Group=sad}', "");
Expect(0, 1788, '\P{^Joining_Group=sad}', "");
Expect(1, 1787, '\p{Joining_Group=		sad}', "");
Expect(0, 1787, '\p{^Joining_Group=		sad}', "");
Expect(0, 1787, '\P{Joining_Group=		sad}', "");
Expect(1, 1787, '\P{^Joining_Group=		sad}', "");
Expect(0, 1788, '\p{Joining_Group=		sad}', "");
Expect(1, 1788, '\p{^Joining_Group=		sad}', "");
Expect(1, 1788, '\P{Joining_Group=		sad}', "");
Expect(0, 1788, '\P{^Joining_Group=		sad}', "");
Error('\p{Jg=_/a/Sad}');
Error('\P{Jg=_/a/Sad}');
Expect(1, 1787, '\p{Jg=sad}', "");
Expect(0, 1787, '\p{^Jg=sad}', "");
Expect(0, 1787, '\P{Jg=sad}', "");
Expect(1, 1787, '\P{^Jg=sad}', "");
Expect(0, 1788, '\p{Jg=sad}', "");
Expect(1, 1788, '\p{^Jg=sad}', "");
Expect(1, 1788, '\P{Jg=sad}', "");
Expect(0, 1788, '\P{^Jg=sad}', "");
Expect(1, 1787, '\p{Jg= -Sad}', "");
Expect(0, 1787, '\p{^Jg= -Sad}', "");
Expect(0, 1787, '\P{Jg= -Sad}', "");
Expect(1, 1787, '\P{^Jg= -Sad}', "");
Expect(0, 1788, '\p{Jg= -Sad}', "");
Expect(1, 1788, '\p{^Jg= -Sad}', "");
Expect(1, 1788, '\P{Jg= -Sad}', "");
Expect(0, 1788, '\P{^Jg= -Sad}', "");
Error('\p{Is_Joining_Group=	 sad:=}');
Error('\P{Is_Joining_Group=	 sad:=}');
Expect(1, 1787, '\p{Is_Joining_Group=sad}', "");
Expect(0, 1787, '\p{^Is_Joining_Group=sad}', "");
Expect(0, 1787, '\P{Is_Joining_Group=sad}', "");
Expect(1, 1787, '\P{^Is_Joining_Group=sad}', "");
Expect(0, 1788, '\p{Is_Joining_Group=sad}', "");
Expect(1, 1788, '\p{^Is_Joining_Group=sad}', "");
Expect(1, 1788, '\P{Is_Joining_Group=sad}', "");
Expect(0, 1788, '\P{^Is_Joining_Group=sad}', "");
Expect(1, 1787, '\p{Is_Joining_Group=  Sad}', "");
Expect(0, 1787, '\p{^Is_Joining_Group=  Sad}', "");
Expect(0, 1787, '\P{Is_Joining_Group=  Sad}', "");
Expect(1, 1787, '\P{^Is_Joining_Group=  Sad}', "");
Expect(0, 1788, '\p{Is_Joining_Group=  Sad}', "");
Expect(1, 1788, '\p{^Is_Joining_Group=  Sad}', "");
Expect(1, 1788, '\P{Is_Joining_Group=  Sad}', "");
Expect(0, 1788, '\P{^Is_Joining_Group=  Sad}', "");
Error('\p{Is_Jg=/a/_-Sad}');
Error('\P{Is_Jg=/a/_-Sad}');
Expect(1, 1787, '\p{Is_Jg=sad}', "");
Expect(0, 1787, '\p{^Is_Jg=sad}', "");
Expect(0, 1787, '\P{Is_Jg=sad}', "");
Expect(1, 1787, '\P{^Is_Jg=sad}', "");
Expect(0, 1788, '\p{Is_Jg=sad}', "");
Expect(1, 1788, '\p{^Is_Jg=sad}', "");
Expect(1, 1788, '\P{Is_Jg=sad}', "");
Expect(0, 1788, '\P{^Is_Jg=sad}', "");
Expect(1, 1787, '\p{Is_Jg:   	-Sad}', "");
Expect(0, 1787, '\p{^Is_Jg:   	-Sad}', "");
Expect(0, 1787, '\P{Is_Jg:   	-Sad}', "");
Expect(1, 1787, '\P{^Is_Jg:   	-Sad}', "");
Expect(0, 1788, '\p{Is_Jg:   	-Sad}', "");
Expect(1, 1788, '\p{^Is_Jg:   	-Sad}', "");
Expect(1, 1788, '\P{Is_Jg:   	-Sad}', "");
Expect(0, 1788, '\P{^Is_Jg:   	-Sad}', "");
Error('\p{Joining_Group=	-Sadhe/a/}');
Error('\P{Joining_Group=	-Sadhe/a/}');
Expect(1, 1832, '\p{Joining_Group:	sadhe}', "");
Expect(0, 1832, '\p{^Joining_Group:	sadhe}', "");
Expect(0, 1832, '\P{Joining_Group:	sadhe}', "");
Expect(1, 1832, '\P{^Joining_Group:	sadhe}', "");
Expect(0, 1833, '\p{Joining_Group:	sadhe}', "");
Expect(1, 1833, '\p{^Joining_Group:	sadhe}', "");
Expect(1, 1833, '\P{Joining_Group:	sadhe}', "");
Expect(0, 1833, '\P{^Joining_Group:	sadhe}', "");
Expect(1, 1832, '\p{Joining_Group=-_SADHE}', "");
Expect(0, 1832, '\p{^Joining_Group=-_SADHE}', "");
Expect(0, 1832, '\P{Joining_Group=-_SADHE}', "");
Expect(1, 1832, '\P{^Joining_Group=-_SADHE}', "");
Expect(0, 1833, '\p{Joining_Group=-_SADHE}', "");
Expect(1, 1833, '\p{^Joining_Group=-_SADHE}', "");
Expect(1, 1833, '\P{Joining_Group=-_SADHE}', "");
Expect(0, 1833, '\P{^Joining_Group=-_SADHE}', "");
Error('\p{Jg=:=	sadhe}');
Error('\P{Jg=:=	sadhe}');
Expect(1, 1832, '\p{Jg=sadhe}', "");
Expect(0, 1832, '\p{^Jg=sadhe}', "");
Expect(0, 1832, '\P{Jg=sadhe}', "");
Expect(1, 1832, '\P{^Jg=sadhe}', "");
Expect(0, 1833, '\p{Jg=sadhe}', "");
Expect(1, 1833, '\p{^Jg=sadhe}', "");
Expect(1, 1833, '\P{Jg=sadhe}', "");
Expect(0, 1833, '\P{^Jg=sadhe}', "");
Expect(1, 1832, '\p{Jg: -	SADHE}', "");
Expect(0, 1832, '\p{^Jg: -	SADHE}', "");
Expect(0, 1832, '\P{Jg: -	SADHE}', "");
Expect(1, 1832, '\P{^Jg: -	SADHE}', "");
Expect(0, 1833, '\p{Jg: -	SADHE}', "");
Expect(1, 1833, '\p{^Jg: -	SADHE}', "");
Expect(1, 1833, '\P{Jg: -	SADHE}', "");
Expect(0, 1833, '\P{^Jg: -	SADHE}', "");
Error('\p{Is_Joining_Group=_:=Sadhe}');
Error('\P{Is_Joining_Group=_:=Sadhe}');
Expect(1, 1832, '\p{Is_Joining_Group=sadhe}', "");
Expect(0, 1832, '\p{^Is_Joining_Group=sadhe}', "");
Expect(0, 1832, '\P{Is_Joining_Group=sadhe}', "");
Expect(1, 1832, '\P{^Is_Joining_Group=sadhe}', "");
Expect(0, 1833, '\p{Is_Joining_Group=sadhe}', "");
Expect(1, 1833, '\p{^Is_Joining_Group=sadhe}', "");
Expect(1, 1833, '\P{Is_Joining_Group=sadhe}', "");
Expect(0, 1833, '\P{^Is_Joining_Group=sadhe}', "");
Expect(1, 1832, '\p{Is_Joining_Group=__sadhe}', "");
Expect(0, 1832, '\p{^Is_Joining_Group=__sadhe}', "");
Expect(0, 1832, '\P{Is_Joining_Group=__sadhe}', "");
Expect(1, 1832, '\P{^Is_Joining_Group=__sadhe}', "");
Expect(0, 1833, '\p{Is_Joining_Group=__sadhe}', "");
Expect(1, 1833, '\p{^Is_Joining_Group=__sadhe}', "");
Expect(1, 1833, '\P{Is_Joining_Group=__sadhe}', "");
Expect(0, 1833, '\P{^Is_Joining_Group=__sadhe}', "");
Error('\p{Is_Jg=/a/	Sadhe}');
Error('\P{Is_Jg=/a/	Sadhe}');
Expect(1, 1832, '\p{Is_Jg:   sadhe}', "");
Expect(0, 1832, '\p{^Is_Jg:   sadhe}', "");
Expect(0, 1832, '\P{Is_Jg:   sadhe}', "");
Expect(1, 1832, '\P{^Is_Jg:   sadhe}', "");
Expect(0, 1833, '\p{Is_Jg:   sadhe}', "");
Expect(1, 1833, '\p{^Is_Jg:   sadhe}', "");
Expect(1, 1833, '\P{Is_Jg:   sadhe}', "");
Expect(0, 1833, '\P{^Is_Jg:   sadhe}', "");
Expect(1, 1832, '\p{Is_Jg=_-sadhe}', "");
Expect(0, 1832, '\p{^Is_Jg=_-sadhe}', "");
Expect(0, 1832, '\P{Is_Jg=_-sadhe}', "");
Expect(1, 1832, '\P{^Is_Jg=_-sadhe}', "");
Expect(0, 1833, '\p{Is_Jg=_-sadhe}', "");
Expect(1, 1833, '\p{^Is_Jg=_-sadhe}', "");
Expect(1, 1833, '\P{Is_Jg=_-sadhe}', "");
Expect(0, 1833, '\P{^Is_Jg=_-sadhe}', "");
Error('\p{Joining_Group=	 seen:=}');
Error('\P{Joining_Group=	 seen:=}');
Expect(1, 1918, '\p{Joining_Group=seen}', "");
Expect(0, 1918, '\p{^Joining_Group=seen}', "");
Expect(0, 1918, '\P{Joining_Group=seen}', "");
Expect(1, 1918, '\P{^Joining_Group=seen}', "");
Expect(0, 1919, '\p{Joining_Group=seen}', "");
Expect(1, 1919, '\p{^Joining_Group=seen}', "");
Expect(1, 1919, '\P{Joining_Group=seen}', "");
Expect(0, 1919, '\P{^Joining_Group=seen}', "");
Expect(1, 1918, '\p{Joining_Group= _seen}', "");
Expect(0, 1918, '\p{^Joining_Group= _seen}', "");
Expect(0, 1918, '\P{Joining_Group= _seen}', "");
Expect(1, 1918, '\P{^Joining_Group= _seen}', "");
Expect(0, 1919, '\p{Joining_Group= _seen}', "");
Expect(1, 1919, '\p{^Joining_Group= _seen}', "");
Expect(1, 1919, '\P{Joining_Group= _seen}', "");
Expect(0, 1919, '\P{^Joining_Group= _seen}', "");
Error('\p{Jg=:=	 SEEN}');
Error('\P{Jg=:=	 SEEN}');
Expect(1, 1918, '\p{Jg=seen}', "");
Expect(0, 1918, '\p{^Jg=seen}', "");
Expect(0, 1918, '\P{Jg=seen}', "");
Expect(1, 1918, '\P{^Jg=seen}', "");
Expect(0, 1919, '\p{Jg=seen}', "");
Expect(1, 1919, '\p{^Jg=seen}', "");
Expect(1, 1919, '\P{Jg=seen}', "");
Expect(0, 1919, '\P{^Jg=seen}', "");
Expect(1, 1918, '\p{Jg:		 seen}', "");
Expect(0, 1918, '\p{^Jg:		 seen}', "");
Expect(0, 1918, '\P{Jg:		 seen}', "");
Expect(1, 1918, '\P{^Jg:		 seen}', "");
Expect(0, 1919, '\p{Jg:		 seen}', "");
Expect(1, 1919, '\p{^Jg:		 seen}', "");
Expect(1, 1919, '\P{Jg:		 seen}', "");
Expect(0, 1919, '\P{^Jg:		 seen}', "");
Error('\p{Is_Joining_Group=/a/--Seen}');
Error('\P{Is_Joining_Group=/a/--Seen}');
Expect(1, 1918, '\p{Is_Joining_Group=seen}', "");
Expect(0, 1918, '\p{^Is_Joining_Group=seen}', "");
Expect(0, 1918, '\P{Is_Joining_Group=seen}', "");
Expect(1, 1918, '\P{^Is_Joining_Group=seen}', "");
Expect(0, 1919, '\p{Is_Joining_Group=seen}', "");
Expect(1, 1919, '\p{^Is_Joining_Group=seen}', "");
Expect(1, 1919, '\P{Is_Joining_Group=seen}', "");
Expect(0, 1919, '\P{^Is_Joining_Group=seen}', "");
Expect(1, 1918, '\p{Is_Joining_Group=  seen}', "");
Expect(0, 1918, '\p{^Is_Joining_Group=  seen}', "");
Expect(0, 1918, '\P{Is_Joining_Group=  seen}', "");
Expect(1, 1918, '\P{^Is_Joining_Group=  seen}', "");
Expect(0, 1919, '\p{Is_Joining_Group=  seen}', "");
Expect(1, 1919, '\p{^Is_Joining_Group=  seen}', "");
Expect(1, 1919, '\P{Is_Joining_Group=  seen}', "");
Expect(0, 1919, '\P{^Is_Joining_Group=  seen}', "");
Error('\p{Is_Jg=_Seen:=}');
Error('\P{Is_Jg=_Seen:=}');
Expect(1, 1918, '\p{Is_Jg=seen}', "");
Expect(0, 1918, '\p{^Is_Jg=seen}', "");
Expect(0, 1918, '\P{Is_Jg=seen}', "");
Expect(1, 1918, '\P{^Is_Jg=seen}', "");
Expect(0, 1919, '\p{Is_Jg=seen}', "");
Expect(1, 1919, '\p{^Is_Jg=seen}', "");
Expect(1, 1919, '\P{Is_Jg=seen}', "");
Expect(0, 1919, '\P{^Is_Jg=seen}', "");
Expect(1, 1918, '\p{Is_Jg= -seen}', "");
Expect(0, 1918, '\p{^Is_Jg= -seen}', "");
Expect(0, 1918, '\P{Is_Jg= -seen}', "");
Expect(1, 1918, '\P{^Is_Jg= -seen}', "");
Expect(0, 1919, '\p{Is_Jg= -seen}', "");
Expect(1, 1919, '\p{^Is_Jg= -seen}', "");
Expect(1, 1919, '\P{Is_Jg= -seen}', "");
Expect(0, 1919, '\P{^Is_Jg= -seen}', "");
Error('\p{Joining_Group=-Semkath:=}');
Error('\P{Joining_Group=-Semkath:=}');
Expect(1, 1827, '\p{Joining_Group=semkath}', "");
Expect(0, 1827, '\p{^Joining_Group=semkath}', "");
Expect(0, 1827, '\P{Joining_Group=semkath}', "");
Expect(1, 1827, '\P{^Joining_Group=semkath}', "");
Expect(0, 1828, '\p{Joining_Group=semkath}', "");
Expect(1, 1828, '\p{^Joining_Group=semkath}', "");
Expect(1, 1828, '\P{Joining_Group=semkath}', "");
Expect(0, 1828, '\P{^Joining_Group=semkath}', "");
Expect(1, 1827, '\p{Joining_Group=_	Semkath}', "");
Expect(0, 1827, '\p{^Joining_Group=_	Semkath}', "");
Expect(0, 1827, '\P{Joining_Group=_	Semkath}', "");
Expect(1, 1827, '\P{^Joining_Group=_	Semkath}', "");
Expect(0, 1828, '\p{Joining_Group=_	Semkath}', "");
Expect(1, 1828, '\p{^Joining_Group=_	Semkath}', "");
Expect(1, 1828, '\P{Joining_Group=_	Semkath}', "");
Expect(0, 1828, '\P{^Joining_Group=_	Semkath}', "");
Error('\p{Jg=-_SEMKATH:=}');
Error('\P{Jg=-_SEMKATH:=}');
Expect(1, 1827, '\p{Jg:semkath}', "");
Expect(0, 1827, '\p{^Jg:semkath}', "");
Expect(0, 1827, '\P{Jg:semkath}', "");
Expect(1, 1827, '\P{^Jg:semkath}', "");
Expect(0, 1828, '\p{Jg:semkath}', "");
Expect(1, 1828, '\p{^Jg:semkath}', "");
Expect(1, 1828, '\P{Jg:semkath}', "");
Expect(0, 1828, '\P{^Jg:semkath}', "");
Expect(1, 1827, '\p{Jg=	 Semkath}', "");
Expect(0, 1827, '\p{^Jg=	 Semkath}', "");
Expect(0, 1827, '\P{Jg=	 Semkath}', "");
Expect(1, 1827, '\P{^Jg=	 Semkath}', "");
Expect(0, 1828, '\p{Jg=	 Semkath}', "");
Expect(1, 1828, '\p{^Jg=	 Semkath}', "");
Expect(1, 1828, '\P{Jg=	 Semkath}', "");
Expect(0, 1828, '\P{^Jg=	 Semkath}', "");
Error('\p{Is_Joining_Group=- Semkath:=}');
Error('\P{Is_Joining_Group=- Semkath:=}');
Expect(1, 1827, '\p{Is_Joining_Group=semkath}', "");
Expect(0, 1827, '\p{^Is_Joining_Group=semkath}', "");
Expect(0, 1827, '\P{Is_Joining_Group=semkath}', "");
Expect(1, 1827, '\P{^Is_Joining_Group=semkath}', "");
Expect(0, 1828, '\p{Is_Joining_Group=semkath}', "");
Expect(1, 1828, '\p{^Is_Joining_Group=semkath}', "");
Expect(1, 1828, '\P{Is_Joining_Group=semkath}', "");
Expect(0, 1828, '\P{^Is_Joining_Group=semkath}', "");
Expect(1, 1827, '\p{Is_Joining_Group= -SEMKATH}', "");
Expect(0, 1827, '\p{^Is_Joining_Group= -SEMKATH}', "");
Expect(0, 1827, '\P{Is_Joining_Group= -SEMKATH}', "");
Expect(1, 1827, '\P{^Is_Joining_Group= -SEMKATH}', "");
Expect(0, 1828, '\p{Is_Joining_Group= -SEMKATH}', "");
Expect(1, 1828, '\p{^Is_Joining_Group= -SEMKATH}', "");
Expect(1, 1828, '\P{Is_Joining_Group= -SEMKATH}', "");
Expect(0, 1828, '\P{^Is_Joining_Group= -SEMKATH}', "");
Error('\p{Is_Jg=--Semkath/a/}');
Error('\P{Is_Jg=--Semkath/a/}');
Expect(1, 1827, '\p{Is_Jg=semkath}', "");
Expect(0, 1827, '\p{^Is_Jg=semkath}', "");
Expect(0, 1827, '\P{Is_Jg=semkath}', "");
Expect(1, 1827, '\P{^Is_Jg=semkath}', "");
Expect(0, 1828, '\p{Is_Jg=semkath}', "");
Expect(1, 1828, '\p{^Is_Jg=semkath}', "");
Expect(1, 1828, '\P{Is_Jg=semkath}', "");
Expect(0, 1828, '\P{^Is_Jg=semkath}', "");
Expect(1, 1827, '\p{Is_Jg=Semkath}', "");
Expect(0, 1827, '\p{^Is_Jg=Semkath}', "");
Expect(0, 1827, '\P{Is_Jg=Semkath}', "");
Expect(1, 1827, '\P{^Is_Jg=Semkath}', "");
Expect(0, 1828, '\p{Is_Jg=Semkath}', "");
Expect(1, 1828, '\p{^Is_Jg=Semkath}', "");
Expect(1, 1828, '\P{Is_Jg=Semkath}', "");
Expect(0, 1828, '\P{^Is_Jg=Semkath}', "");
Error('\p{Joining_Group=-/a/Shin}');
Error('\P{Joining_Group=-/a/Shin}');
Expect(1, 1835, '\p{Joining_Group: shin}', "");
Expect(0, 1835, '\p{^Joining_Group: shin}', "");
Expect(0, 1835, '\P{Joining_Group: shin}', "");
Expect(1, 1835, '\P{^Joining_Group: shin}', "");
Expect(0, 1836, '\p{Joining_Group: shin}', "");
Expect(1, 1836, '\p{^Joining_Group: shin}', "");
Expect(1, 1836, '\P{Joining_Group: shin}', "");
Expect(0, 1836, '\P{^Joining_Group: shin}', "");
Expect(1, 1835, '\p{Joining_Group=_SHIN}', "");
Expect(0, 1835, '\p{^Joining_Group=_SHIN}', "");
Expect(0, 1835, '\P{Joining_Group=_SHIN}', "");
Expect(1, 1835, '\P{^Joining_Group=_SHIN}', "");
Expect(0, 1836, '\p{Joining_Group=_SHIN}', "");
Expect(1, 1836, '\p{^Joining_Group=_SHIN}', "");
Expect(1, 1836, '\P{Joining_Group=_SHIN}', "");
Expect(0, 1836, '\P{^Joining_Group=_SHIN}', "");
Error('\p{Jg=__SHIN:=}');
Error('\P{Jg=__SHIN:=}');
Expect(1, 1835, '\p{Jg: shin}', "");
Expect(0, 1835, '\p{^Jg: shin}', "");
Expect(0, 1835, '\P{Jg: shin}', "");
Expect(1, 1835, '\P{^Jg: shin}', "");
Expect(0, 1836, '\p{Jg: shin}', "");
Expect(1, 1836, '\p{^Jg: shin}', "");
Expect(1, 1836, '\P{Jg: shin}', "");
Expect(0, 1836, '\P{^Jg: shin}', "");
Expect(1, 1835, '\p{Jg=_shin}', "");
Expect(0, 1835, '\p{^Jg=_shin}', "");
Expect(0, 1835, '\P{Jg=_shin}', "");
Expect(1, 1835, '\P{^Jg=_shin}', "");
Expect(0, 1836, '\p{Jg=_shin}', "");
Expect(1, 1836, '\p{^Jg=_shin}', "");
Expect(1, 1836, '\P{Jg=_shin}', "");
Expect(0, 1836, '\P{^Jg=_shin}', "");
Error('\p{Is_Joining_Group=_/a/SHIN}');
Error('\P{Is_Joining_Group=_/a/SHIN}');
Expect(1, 1835, '\p{Is_Joining_Group=shin}', "");
Expect(0, 1835, '\p{^Is_Joining_Group=shin}', "");
Expect(0, 1835, '\P{Is_Joining_Group=shin}', "");
Expect(1, 1835, '\P{^Is_Joining_Group=shin}', "");
Expect(0, 1836, '\p{Is_Joining_Group=shin}', "");
Expect(1, 1836, '\p{^Is_Joining_Group=shin}', "");
Expect(1, 1836, '\P{Is_Joining_Group=shin}', "");
Expect(0, 1836, '\P{^Is_Joining_Group=shin}', "");
Expect(1, 1835, '\p{Is_Joining_Group= Shin}', "");
Expect(0, 1835, '\p{^Is_Joining_Group= Shin}', "");
Expect(0, 1835, '\P{Is_Joining_Group= Shin}', "");
Expect(1, 1835, '\P{^Is_Joining_Group= Shin}', "");
Expect(0, 1836, '\p{Is_Joining_Group= Shin}', "");
Expect(1, 1836, '\p{^Is_Joining_Group= Shin}', "");
Expect(1, 1836, '\P{Is_Joining_Group= Shin}', "");
Expect(0, 1836, '\P{^Is_Joining_Group= Shin}', "");
Error('\p{Is_Jg=:= SHIN}');
Error('\P{Is_Jg=:= SHIN}');
Expect(1, 1835, '\p{Is_Jg=shin}', "");
Expect(0, 1835, '\p{^Is_Jg=shin}', "");
Expect(0, 1835, '\P{Is_Jg=shin}', "");
Expect(1, 1835, '\P{^Is_Jg=shin}', "");
Expect(0, 1836, '\p{Is_Jg=shin}', "");
Expect(1, 1836, '\p{^Is_Jg=shin}', "");
Expect(1, 1836, '\P{Is_Jg=shin}', "");
Expect(0, 1836, '\P{^Is_Jg=shin}', "");
Expect(1, 1835, '\p{Is_Jg=_SHIN}', "");
Expect(0, 1835, '\p{^Is_Jg=_SHIN}', "");
Expect(0, 1835, '\P{Is_Jg=_SHIN}', "");
Expect(1, 1835, '\P{^Is_Jg=_SHIN}', "");
Expect(0, 1836, '\p{Is_Jg=_SHIN}', "");
Expect(1, 1836, '\p{^Is_Jg=_SHIN}', "");
Expect(1, 1836, '\P{Is_Jg=_SHIN}', "");
Expect(0, 1836, '\P{^Is_Jg=_SHIN}', "");
Error('\p{Joining_Group=_/a/Swash_Kaf}');
Error('\P{Joining_Group=_/a/Swash_Kaf}');
Expect(1, 1706, '\p{Joining_Group=swashkaf}', "");
Expect(0, 1706, '\p{^Joining_Group=swashkaf}', "");
Expect(0, 1706, '\P{Joining_Group=swashkaf}', "");
Expect(1, 1706, '\P{^Joining_Group=swashkaf}', "");
Expect(0, 1707, '\p{Joining_Group=swashkaf}', "");
Expect(1, 1707, '\p{^Joining_Group=swashkaf}', "");
Expect(1, 1707, '\P{Joining_Group=swashkaf}', "");
Expect(0, 1707, '\P{^Joining_Group=swashkaf}', "");
Expect(1, 1706, '\p{Joining_Group=_-SWASH_kaf}', "");
Expect(0, 1706, '\p{^Joining_Group=_-SWASH_kaf}', "");
Expect(0, 1706, '\P{Joining_Group=_-SWASH_kaf}', "");
Expect(1, 1706, '\P{^Joining_Group=_-SWASH_kaf}', "");
Expect(0, 1707, '\p{Joining_Group=_-SWASH_kaf}', "");
Expect(1, 1707, '\p{^Joining_Group=_-SWASH_kaf}', "");
Expect(1, 1707, '\P{Joining_Group=_-SWASH_kaf}', "");
Expect(0, 1707, '\P{^Joining_Group=_-SWASH_kaf}', "");
Error('\p{Jg=_/a/Swash_kaf}');
Error('\P{Jg=_/a/Swash_kaf}');
Expect(1, 1706, '\p{Jg=swashkaf}', "");
Expect(0, 1706, '\p{^Jg=swashkaf}', "");
Expect(0, 1706, '\P{Jg=swashkaf}', "");
Expect(1, 1706, '\P{^Jg=swashkaf}', "");
Expect(0, 1707, '\p{Jg=swashkaf}', "");
Expect(1, 1707, '\p{^Jg=swashkaf}', "");
Expect(1, 1707, '\P{Jg=swashkaf}', "");
Expect(0, 1707, '\P{^Jg=swashkaf}', "");
Expect(1, 1706, '\p{Jg=-_swash_Kaf}', "");
Expect(0, 1706, '\p{^Jg=-_swash_Kaf}', "");
Expect(0, 1706, '\P{Jg=-_swash_Kaf}', "");
Expect(1, 1706, '\P{^Jg=-_swash_Kaf}', "");
Expect(0, 1707, '\p{Jg=-_swash_Kaf}', "");
Expect(1, 1707, '\p{^Jg=-_swash_Kaf}', "");
Expect(1, 1707, '\P{Jg=-_swash_Kaf}', "");
Expect(0, 1707, '\P{^Jg=-_swash_Kaf}', "");
Error('\p{Is_Joining_Group=_-Swash_kaf/a/}');
Error('\P{Is_Joining_Group=_-Swash_kaf/a/}');
Expect(1, 1706, '\p{Is_Joining_Group=swashkaf}', "");
Expect(0, 1706, '\p{^Is_Joining_Group=swashkaf}', "");
Expect(0, 1706, '\P{Is_Joining_Group=swashkaf}', "");
Expect(1, 1706, '\P{^Is_Joining_Group=swashkaf}', "");
Expect(0, 1707, '\p{Is_Joining_Group=swashkaf}', "");
Expect(1, 1707, '\p{^Is_Joining_Group=swashkaf}', "");
Expect(1, 1707, '\P{Is_Joining_Group=swashkaf}', "");
Expect(0, 1707, '\P{^Is_Joining_Group=swashkaf}', "");
Expect(1, 1706, '\p{Is_Joining_Group:-SWASH_Kaf}', "");
Expect(0, 1706, '\p{^Is_Joining_Group:-SWASH_Kaf}', "");
Expect(0, 1706, '\P{Is_Joining_Group:-SWASH_Kaf}', "");
Expect(1, 1706, '\P{^Is_Joining_Group:-SWASH_Kaf}', "");
Expect(0, 1707, '\p{Is_Joining_Group:-SWASH_Kaf}', "");
Expect(1, 1707, '\p{^Is_Joining_Group:-SWASH_Kaf}', "");
Expect(1, 1707, '\P{Is_Joining_Group:-SWASH_Kaf}', "");
Expect(0, 1707, '\P{^Is_Joining_Group:-SWASH_Kaf}', "");
Error('\p{Is_Jg=_swash_Kaf/a/}');
Error('\P{Is_Jg=_swash_Kaf/a/}');
Expect(1, 1706, '\p{Is_Jg=swashkaf}', "");
Expect(0, 1706, '\p{^Is_Jg=swashkaf}', "");
Expect(0, 1706, '\P{Is_Jg=swashkaf}', "");
Expect(1, 1706, '\P{^Is_Jg=swashkaf}', "");
Expect(0, 1707, '\p{Is_Jg=swashkaf}', "");
Expect(1, 1707, '\p{^Is_Jg=swashkaf}', "");
Expect(1, 1707, '\P{Is_Jg=swashkaf}', "");
Expect(0, 1707, '\P{^Is_Jg=swashkaf}', "");
Expect(1, 1706, '\p{Is_Jg=- SWASH_kaf}', "");
Expect(0, 1706, '\p{^Is_Jg=- SWASH_kaf}', "");
Expect(0, 1706, '\P{Is_Jg=- SWASH_kaf}', "");
Expect(1, 1706, '\P{^Is_Jg=- SWASH_kaf}', "");
Expect(0, 1707, '\p{Is_Jg=- SWASH_kaf}', "");
Expect(1, 1707, '\p{^Is_Jg=- SWASH_kaf}', "");
Expect(1, 1707, '\P{Is_Jg=- SWASH_kaf}', "");
Expect(0, 1707, '\P{^Is_Jg=- SWASH_kaf}', "");
Error('\p{Joining_Group=:=SYRIAC_Waw}');
Error('\P{Joining_Group=:=SYRIAC_Waw}');
Expect(1, 1816, '\p{Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\p{^Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\P{Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\P{^Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\p{Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\p{^Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\P{Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\P{^Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\p{Joining_Group:	__SYRIAC_waw}', "");
Expect(0, 1816, '\p{^Joining_Group:	__SYRIAC_waw}', "");
Expect(0, 1816, '\P{Joining_Group:	__SYRIAC_waw}', "");
Expect(1, 1816, '\P{^Joining_Group:	__SYRIAC_waw}', "");
Expect(0, 1817, '\p{Joining_Group:	__SYRIAC_waw}', "");
Expect(1, 1817, '\p{^Joining_Group:	__SYRIAC_waw}', "");
Expect(1, 1817, '\P{Joining_Group:	__SYRIAC_waw}', "");
Expect(0, 1817, '\P{^Joining_Group:	__SYRIAC_waw}', "");
Error('\p{Jg=Syriac_Waw:=}');
Error('\P{Jg=Syriac_Waw:=}');
Expect(1, 1816, '\p{Jg:   syriacwaw}', "");
Expect(0, 1816, '\p{^Jg:   syriacwaw}', "");
Expect(0, 1816, '\P{Jg:   syriacwaw}', "");
Expect(1, 1816, '\P{^Jg:   syriacwaw}', "");
Expect(0, 1817, '\p{Jg:   syriacwaw}', "");
Expect(1, 1817, '\p{^Jg:   syriacwaw}', "");
Expect(1, 1817, '\P{Jg:   syriacwaw}', "");
Expect(0, 1817, '\P{^Jg:   syriacwaw}', "");
Expect(1, 1816, '\p{Jg= syriac_Waw}', "");
Expect(0, 1816, '\p{^Jg= syriac_Waw}', "");
Expect(0, 1816, '\P{Jg= syriac_Waw}', "");
Expect(1, 1816, '\P{^Jg= syriac_Waw}', "");
Expect(0, 1817, '\p{Jg= syriac_Waw}', "");
Expect(1, 1817, '\p{^Jg= syriac_Waw}', "");
Expect(1, 1817, '\P{Jg= syriac_Waw}', "");
Expect(0, 1817, '\P{^Jg= syriac_Waw}', "");
Error('\p{Is_Joining_Group=	 syriac_Waw:=}');
Error('\P{Is_Joining_Group=	 syriac_Waw:=}');
Expect(1, 1816, '\p{Is_Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\p{^Is_Joining_Group=syriacwaw}', "");
Expect(0, 1816, '\P{Is_Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\P{^Is_Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\p{Is_Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\p{^Is_Joining_Group=syriacwaw}', "");
Expect(1, 1817, '\P{Is_Joining_Group=syriacwaw}', "");
Expect(0, 1817, '\P{^Is_Joining_Group=syriacwaw}', "");
Expect(1, 1816, '\p{Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(0, 1816, '\p{^Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(0, 1816, '\P{Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(1, 1816, '\P{^Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(0, 1817, '\p{Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(1, 1817, '\p{^Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(1, 1817, '\P{Is_Joining_Group=-	SYRIAC_WAW}', "");
Expect(0, 1817, '\P{^Is_Joining_Group=-	SYRIAC_WAW}', "");
Error('\p{Is_Jg=/a/	Syriac_Waw}');
Error('\P{Is_Jg=/a/	Syriac_Waw}');
Expect(1, 1816, '\p{Is_Jg=syriacwaw}', "");
Expect(0, 1816, '\p{^Is_Jg=syriacwaw}', "");
Expect(0, 1816, '\P{Is_Jg=syriacwaw}', "");
Expect(1, 1816, '\P{^Is_Jg=syriacwaw}', "");
Expect(0, 1817, '\p{Is_Jg=syriacwaw}', "");
Expect(1, 1817, '\p{^Is_Jg=syriacwaw}', "");
Expect(1, 1817, '\P{Is_Jg=syriacwaw}', "");
Expect(0, 1817, '\P{^Is_Jg=syriacwaw}', "");
Expect(1, 1816, '\p{Is_Jg= SYRIAC_waw}', "");
Expect(0, 1816, '\p{^Is_Jg= SYRIAC_waw}', "");
Expect(0, 1816, '\P{Is_Jg= SYRIAC_waw}', "");
Expect(1, 1816, '\P{^Is_Jg= SYRIAC_waw}', "");
Expect(0, 1817, '\p{Is_Jg= SYRIAC_waw}', "");
Expect(1, 1817, '\p{^Is_Jg= SYRIAC_waw}', "");
Expect(1, 1817, '\P{Is_Jg= SYRIAC_waw}', "");
Expect(0, 1817, '\P{^Is_Jg= SYRIAC_waw}', "");
Error('\p{Joining_Group=	tah/a/}');
Error('\P{Joining_Group=	tah/a/}');
Expect(1, 2211, '\p{Joining_Group=tah}', "");
Expect(0, 2211, '\p{^Joining_Group=tah}', "");
Expect(0, 2211, '\P{Joining_Group=tah}', "");
Expect(1, 2211, '\P{^Joining_Group=tah}', "");
Expect(0, 2212, '\p{Joining_Group=tah}', "");
Expect(1, 2212, '\p{^Joining_Group=tah}', "");
Expect(1, 2212, '\P{Joining_Group=tah}', "");
Expect(0, 2212, '\P{^Joining_Group=tah}', "");
Expect(1, 2211, '\p{Joining_Group=_-tah}', "");
Expect(0, 2211, '\p{^Joining_Group=_-tah}', "");
Expect(0, 2211, '\P{Joining_Group=_-tah}', "");
Expect(1, 2211, '\P{^Joining_Group=_-tah}', "");
Expect(0, 2212, '\p{Joining_Group=_-tah}', "");
Expect(1, 2212, '\p{^Joining_Group=_-tah}', "");
Expect(1, 2212, '\P{Joining_Group=_-tah}', "");
Expect(0, 2212, '\P{^Joining_Group=_-tah}', "");
Error('\p{Jg:	_/a/Tah}');
Error('\P{Jg:	_/a/Tah}');
Expect(1, 2211, '\p{Jg=tah}', "");
Expect(0, 2211, '\p{^Jg=tah}', "");
Expect(0, 2211, '\P{Jg=tah}', "");
Expect(1, 2211, '\P{^Jg=tah}', "");
Expect(0, 2212, '\p{Jg=tah}', "");
Expect(1, 2212, '\p{^Jg=tah}', "");
Expect(1, 2212, '\P{Jg=tah}', "");
Expect(0, 2212, '\P{^Jg=tah}', "");
Expect(1, 2211, '\p{Jg=-Tah}', "");
Expect(0, 2211, '\p{^Jg=-Tah}', "");
Expect(0, 2211, '\P{Jg=-Tah}', "");
Expect(1, 2211, '\P{^Jg=-Tah}', "");
Expect(0, 2212, '\p{Jg=-Tah}', "");
Expect(1, 2212, '\p{^Jg=-Tah}', "");
Expect(1, 2212, '\P{Jg=-Tah}', "");
Expect(0, 2212, '\P{^Jg=-Tah}', "");
Error('\p{Is_Joining_Group::=	-Tah}');
Error('\P{Is_Joining_Group::=	-Tah}');
Expect(1, 2211, '\p{Is_Joining_Group=tah}', "");
Expect(0, 2211, '\p{^Is_Joining_Group=tah}', "");
Expect(0, 2211, '\P{Is_Joining_Group=tah}', "");
Expect(1, 2211, '\P{^Is_Joining_Group=tah}', "");
Expect(0, 2212, '\p{Is_Joining_Group=tah}', "");
Expect(1, 2212, '\p{^Is_Joining_Group=tah}', "");
Expect(1, 2212, '\P{Is_Joining_Group=tah}', "");
Expect(0, 2212, '\P{^Is_Joining_Group=tah}', "");
Expect(1, 2211, '\p{Is_Joining_Group= Tah}', "");
Expect(0, 2211, '\p{^Is_Joining_Group= Tah}', "");
Expect(0, 2211, '\P{Is_Joining_Group= Tah}', "");
Expect(1, 2211, '\P{^Is_Joining_Group= Tah}', "");
Expect(0, 2212, '\p{Is_Joining_Group= Tah}', "");
Expect(1, 2212, '\p{^Is_Joining_Group= Tah}', "");
Expect(1, 2212, '\P{Is_Joining_Group= Tah}', "");
Expect(0, 2212, '\P{^Is_Joining_Group= Tah}', "");
Error('\p{Is_Jg=tah/a/}');
Error('\P{Is_Jg=tah/a/}');
Expect(1, 2211, '\p{Is_Jg=tah}', "");
Expect(0, 2211, '\p{^Is_Jg=tah}', "");
Expect(0, 2211, '\P{Is_Jg=tah}', "");
Expect(1, 2211, '\P{^Is_Jg=tah}', "");
Expect(0, 2212, '\p{Is_Jg=tah}', "");
Expect(1, 2212, '\p{^Is_Jg=tah}', "");
Expect(1, 2212, '\P{Is_Jg=tah}', "");
Expect(0, 2212, '\P{^Is_Jg=tah}', "");
Expect(1, 2211, '\p{Is_Jg=		Tah}', "");
Expect(0, 2211, '\p{^Is_Jg=		Tah}', "");
Expect(0, 2211, '\P{Is_Jg=		Tah}', "");
Expect(1, 2211, '\P{^Is_Jg=		Tah}', "");
Expect(0, 2212, '\p{Is_Jg=		Tah}', "");
Expect(1, 2212, '\p{^Is_Jg=		Tah}', "");
Expect(1, 2212, '\P{Is_Jg=		Tah}', "");
Expect(0, 2212, '\P{^Is_Jg=		Tah}', "");
Error('\p{Joining_Group=:=-	Taw}');
Error('\P{Joining_Group=:=-	Taw}');
Expect(1, 1836, '\p{Joining_Group=taw}', "");
Expect(0, 1836, '\p{^Joining_Group=taw}', "");
Expect(0, 1836, '\P{Joining_Group=taw}', "");
Expect(1, 1836, '\P{^Joining_Group=taw}', "");
Expect(0, 1837, '\p{Joining_Group=taw}', "");
Expect(1, 1837, '\p{^Joining_Group=taw}', "");
Expect(1, 1837, '\P{Joining_Group=taw}', "");
Expect(0, 1837, '\P{^Joining_Group=taw}', "");
Expect(1, 1836, '\p{Joining_Group=	-TAW}', "");
Expect(0, 1836, '\p{^Joining_Group=	-TAW}', "");
Expect(0, 1836, '\P{Joining_Group=	-TAW}', "");
Expect(1, 1836, '\P{^Joining_Group=	-TAW}', "");
Expect(0, 1837, '\p{Joining_Group=	-TAW}', "");
Expect(1, 1837, '\p{^Joining_Group=	-TAW}', "");
Expect(1, 1837, '\P{Joining_Group=	-TAW}', "");
Expect(0, 1837, '\P{^Joining_Group=	-TAW}', "");
Error('\p{Jg=:=taw}');
Error('\P{Jg=:=taw}');
Expect(1, 1836, '\p{Jg=taw}', "");
Expect(0, 1836, '\p{^Jg=taw}', "");
Expect(0, 1836, '\P{Jg=taw}', "");
Expect(1, 1836, '\P{^Jg=taw}', "");
Expect(0, 1837, '\p{Jg=taw}', "");
Expect(1, 1837, '\p{^Jg=taw}', "");
Expect(1, 1837, '\P{Jg=taw}', "");
Expect(0, 1837, '\P{^Jg=taw}', "");
Expect(1, 1836, '\p{Jg: -	Taw}', "");
Expect(0, 1836, '\p{^Jg: -	Taw}', "");
Expect(0, 1836, '\P{Jg: -	Taw}', "");
Expect(1, 1836, '\P{^Jg: -	Taw}', "");
Expect(0, 1837, '\p{Jg: -	Taw}', "");
Expect(1, 1837, '\p{^Jg: -	Taw}', "");
Expect(1, 1837, '\P{Jg: -	Taw}', "");
Expect(0, 1837, '\P{^Jg: -	Taw}', "");
Error('\p{Is_Joining_Group=/a/_Taw}');
Error('\P{Is_Joining_Group=/a/_Taw}');
Expect(1, 1836, '\p{Is_Joining_Group=taw}', "");
Expect(0, 1836, '\p{^Is_Joining_Group=taw}', "");
Expect(0, 1836, '\P{Is_Joining_Group=taw}', "");
Expect(1, 1836, '\P{^Is_Joining_Group=taw}', "");
Expect(0, 1837, '\p{Is_Joining_Group=taw}', "");
Expect(1, 1837, '\p{^Is_Joining_Group=taw}', "");
Expect(1, 1837, '\P{Is_Joining_Group=taw}', "");
Expect(0, 1837, '\P{^Is_Joining_Group=taw}', "");
Expect(1, 1836, '\p{Is_Joining_Group=	 Taw}', "");
Expect(0, 1836, '\p{^Is_Joining_Group=	 Taw}', "");
Expect(0, 1836, '\P{Is_Joining_Group=	 Taw}', "");
Expect(1, 1836, '\P{^Is_Joining_Group=	 Taw}', "");
Expect(0, 1837, '\p{Is_Joining_Group=	 Taw}', "");
Expect(1, 1837, '\p{^Is_Joining_Group=	 Taw}', "");
Expect(1, 1837, '\P{Is_Joining_Group=	 Taw}', "");
Expect(0, 1837, '\P{^Is_Joining_Group=	 Taw}', "");
Error('\p{Is_Jg=:=	-taw}');
Error('\P{Is_Jg=:=	-taw}');
Expect(1, 1836, '\p{Is_Jg=taw}', "");
Expect(0, 1836, '\p{^Is_Jg=taw}', "");
Expect(0, 1836, '\P{Is_Jg=taw}', "");
Expect(1, 1836, '\P{^Is_Jg=taw}', "");
Expect(0, 1837, '\p{Is_Jg=taw}', "");
Expect(1, 1837, '\p{^Is_Jg=taw}', "");
Expect(1, 1837, '\P{Is_Jg=taw}', "");
Expect(0, 1837, '\P{^Is_Jg=taw}', "");
Expect(1, 1836, '\p{Is_Jg= 	Taw}', "");
Expect(0, 1836, '\p{^Is_Jg= 	Taw}', "");
Expect(0, 1836, '\P{Is_Jg= 	Taw}', "");
Expect(1, 1836, '\P{^Is_Jg= 	Taw}', "");
Expect(0, 1837, '\p{Is_Jg= 	Taw}', "");
Expect(1, 1837, '\p{^Is_Jg= 	Taw}', "");
Expect(1, 1837, '\P{Is_Jg= 	Taw}', "");
Expect(0, 1837, '\P{^Is_Jg= 	Taw}', "");
Error('\p{Joining_Group= _Teh_Marbuta/a/}');
Error('\P{Joining_Group= _Teh_Marbuta/a/}');
Expect(1, 1749, '\p{Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\p{^Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\P{Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\P{^Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\p{Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\p{^Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\P{Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\P{^Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\p{Joining_Group=	-Teh_Marbuta}', "");
Expect(0, 1749, '\p{^Joining_Group=	-Teh_Marbuta}', "");
Expect(0, 1749, '\P{Joining_Group=	-Teh_Marbuta}', "");
Expect(1, 1749, '\P{^Joining_Group=	-Teh_Marbuta}', "");
Expect(0, 1750, '\p{Joining_Group=	-Teh_Marbuta}', "");
Expect(1, 1750, '\p{^Joining_Group=	-Teh_Marbuta}', "");
Expect(1, 1750, '\P{Joining_Group=	-Teh_Marbuta}', "");
Expect(0, 1750, '\P{^Joining_Group=	-Teh_Marbuta}', "");
Error('\p{Jg=_	Teh_Marbuta/a/}');
Error('\P{Jg=_	Teh_Marbuta/a/}');
Expect(1, 1749, '\p{Jg=tehmarbuta}', "");
Expect(0, 1749, '\p{^Jg=tehmarbuta}', "");
Expect(0, 1749, '\P{Jg=tehmarbuta}', "");
Expect(1, 1749, '\P{^Jg=tehmarbuta}', "");
Expect(0, 1750, '\p{Jg=tehmarbuta}', "");
Expect(1, 1750, '\p{^Jg=tehmarbuta}', "");
Expect(1, 1750, '\P{Jg=tehmarbuta}', "");
Expect(0, 1750, '\P{^Jg=tehmarbuta}', "");
Expect(1, 1749, '\p{Jg=_ Teh_Marbuta}', "");
Expect(0, 1749, '\p{^Jg=_ Teh_Marbuta}', "");
Expect(0, 1749, '\P{Jg=_ Teh_Marbuta}', "");
Expect(1, 1749, '\P{^Jg=_ Teh_Marbuta}', "");
Expect(0, 1750, '\p{Jg=_ Teh_Marbuta}', "");
Expect(1, 1750, '\p{^Jg=_ Teh_Marbuta}', "");
Expect(1, 1750, '\P{Jg=_ Teh_Marbuta}', "");
Expect(0, 1750, '\P{^Jg=_ Teh_Marbuta}', "");
Error('\p{Is_Joining_Group=	 TEH_marbuta/a/}');
Error('\P{Is_Joining_Group=	 TEH_marbuta/a/}');
Expect(1, 1749, '\p{Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\p{^Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1749, '\P{Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\P{^Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\p{Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\p{^Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1750, '\P{Is_Joining_Group=tehmarbuta}', "");
Expect(0, 1750, '\P{^Is_Joining_Group=tehmarbuta}', "");
Expect(1, 1749, '\p{Is_Joining_Group= 	Teh_marbuta}', "");
Expect(0, 1749, '\p{^Is_Joining_Group= 	Teh_marbuta}', "");
Expect(0, 1749, '\P{Is_Joining_Group= 	Teh_marbuta}', "");
Expect(1, 1749, '\P{^Is_Joining_Group= 	Teh_marbuta}', "");
Expect(0, 1750, '\p{Is_Joining_Group= 	Teh_marbuta}', "");
Expect(1, 1750, '\p{^Is_Joining_Group= 	Teh_marbuta}', "");
Expect(1, 1750, '\P{Is_Joining_Group= 	Teh_marbuta}', "");
Expect(0, 1750, '\P{^Is_Joining_Group= 	Teh_marbuta}', "");
Error('\p{Is_Jg=-teh_Marbuta/a/}');
Error('\P{Is_Jg=-teh_Marbuta/a/}');
Expect(1, 1749, '\p{Is_Jg=tehmarbuta}', "");
Expect(0, 1749, '\p{^Is_Jg=tehmarbuta}', "");
Expect(0, 1749, '\P{Is_Jg=tehmarbuta}', "");
Expect(1, 1749, '\P{^Is_Jg=tehmarbuta}', "");
Expect(0, 1750, '\p{Is_Jg=tehmarbuta}', "");
Expect(1, 1750, '\p{^Is_Jg=tehmarbuta}', "");
Expect(1, 1750, '\P{Is_Jg=tehmarbuta}', "");
Expect(0, 1750, '\P{^Is_Jg=tehmarbuta}', "");
Expect(1, 1749, '\p{Is_Jg=-_TEH_Marbuta}', "");
Expect(0, 1749, '\p{^Is_Jg=-_TEH_Marbuta}', "");
Expect(0, 1749, '\P{Is_Jg=-_TEH_Marbuta}', "");
Expect(1, 1749, '\P{^Is_Jg=-_TEH_Marbuta}', "");
Expect(0, 1750, '\p{Is_Jg=-_TEH_Marbuta}', "");
Expect(1, 1750, '\p{^Is_Jg=-_TEH_Marbuta}', "");
Expect(1, 1750, '\P{Is_Jg=-_TEH_Marbuta}', "");
Expect(0, 1750, '\P{^Is_Jg=-_TEH_Marbuta}', "");
Error('\p{Joining_Group=-Hamza_on_Heh_GOAL/a/}');
Error('\P{Joining_Group=-Hamza_on_Heh_GOAL/a/}');
Expect(1, 1731, '\p{Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1731, '\p{^Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1731, '\P{Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1731, '\P{^Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1732, '\p{Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1732, '\p{^Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1732, '\P{Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1732, '\P{^Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1731, '\p{Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(0, 1731, '\p{^Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(0, 1731, '\P{Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(1, 1731, '\P{^Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(0, 1732, '\p{Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(1, 1732, '\p{^Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(1, 1732, '\P{Joining_Group= HAMZA_ON_Heh_goal}', "");
Expect(0, 1732, '\P{^Joining_Group= HAMZA_ON_Heh_goal}', "");
Error('\p{Jg= -TEH_marbuta_Goal/a/}');
Error('\P{Jg= -TEH_marbuta_Goal/a/}');
Expect(1, 1731, '\p{Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\p{^Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\P{Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\P{^Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\p{Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\p{^Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\P{Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\P{^Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\p{Jg=- teh_Marbuta_Goal}', "");
Expect(0, 1731, '\p{^Jg=- teh_Marbuta_Goal}', "");
Expect(0, 1731, '\P{Jg=- teh_Marbuta_Goal}', "");
Expect(1, 1731, '\P{^Jg=- teh_Marbuta_Goal}', "");
Expect(0, 1732, '\p{Jg=- teh_Marbuta_Goal}', "");
Expect(1, 1732, '\p{^Jg=- teh_Marbuta_Goal}', "");
Expect(1, 1732, '\P{Jg=- teh_Marbuta_Goal}', "");
Expect(0, 1732, '\P{^Jg=- teh_Marbuta_Goal}', "");
Error('\p{Is_Joining_Group=	 HAMZA_on_heh_goal:=}');
Error('\P{Is_Joining_Group=	 HAMZA_on_heh_goal:=}');
Expect(1, 1731, '\p{Is_Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1731, '\p{^Is_Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1731, '\P{Is_Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1731, '\P{^Is_Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1732, '\p{Is_Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1732, '\p{^Is_Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1732, '\P{Is_Joining_Group=hamzaonhehgoal}', "");
Expect(0, 1732, '\P{^Is_Joining_Group=hamzaonhehgoal}', "");
Expect(1, 1731, '\p{Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(0, 1731, '\p{^Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(0, 1731, '\P{Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(1, 1731, '\P{^Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(0, 1732, '\p{Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(1, 1732, '\p{^Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(1, 1732, '\P{Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Expect(0, 1732, '\P{^Is_Joining_Group=	 Hamza_On_heh_goal}', "");
Error('\p{Is_Jg=_-teh_Marbuta_Goal/a/}');
Error('\P{Is_Jg=_-teh_Marbuta_Goal/a/}');
Expect(1, 1731, '\p{Is_Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\p{^Is_Jg=tehmarbutagoal}', "");
Expect(0, 1731, '\P{Is_Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\P{^Is_Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\p{Is_Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\p{^Is_Jg=tehmarbutagoal}', "");
Expect(1, 1732, '\P{Is_Jg=tehmarbutagoal}', "");
Expect(0, 1732, '\P{^Is_Jg=tehmarbutagoal}', "");
Expect(1, 1731, '\p{Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(0, 1731, '\p{^Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(0, 1731, '\P{Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(1, 1731, '\P{^Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(0, 1732, '\p{Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(1, 1732, '\p{^Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(1, 1732, '\P{Is_Jg=  Teh_Marbuta_Goal}', "");
Expect(0, 1732, '\P{^Is_Jg=  Teh_Marbuta_Goal}', "");
Error('\p{Joining_Group=_/a/Teth}');
Error('\P{Joining_Group=_/a/Teth}');
Expect(1, 1820, '\p{Joining_Group=teth}', "");
Expect(0, 1820, '\p{^Joining_Group=teth}', "");
Expect(0, 1820, '\P{Joining_Group=teth}', "");
Expect(1, 1820, '\P{^Joining_Group=teth}', "");
Expect(0, 1821, '\p{Joining_Group=teth}', "");
Expect(1, 1821, '\p{^Joining_Group=teth}', "");
Expect(1, 1821, '\P{Joining_Group=teth}', "");
Expect(0, 1821, '\P{^Joining_Group=teth}', "");
Expect(1, 1820, '\p{Joining_Group=- Teth}', "");
Expect(0, 1820, '\p{^Joining_Group=- Teth}', "");
Expect(0, 1820, '\P{Joining_Group=- Teth}', "");
Expect(1, 1820, '\P{^Joining_Group=- Teth}', "");
Expect(0, 1821, '\p{Joining_Group=- Teth}', "");
Expect(1, 1821, '\p{^Joining_Group=- Teth}', "");
Expect(1, 1821, '\P{Joining_Group=- Teth}', "");
Expect(0, 1821, '\P{^Joining_Group=- Teth}', "");
Error('\p{Jg=/a/TETH}');
Error('\P{Jg=/a/TETH}');
Expect(1, 1820, '\p{Jg=teth}', "");
Expect(0, 1820, '\p{^Jg=teth}', "");
Expect(0, 1820, '\P{Jg=teth}', "");
Expect(1, 1820, '\P{^Jg=teth}', "");
Expect(0, 1821, '\p{Jg=teth}', "");
Expect(1, 1821, '\p{^Jg=teth}', "");
Expect(1, 1821, '\P{Jg=teth}', "");
Expect(0, 1821, '\P{^Jg=teth}', "");
Expect(1, 1820, '\p{Jg= TETH}', "");
Expect(0, 1820, '\p{^Jg= TETH}', "");
Expect(0, 1820, '\P{Jg= TETH}', "");
Expect(1, 1820, '\P{^Jg= TETH}', "");
Expect(0, 1821, '\p{Jg= TETH}', "");
Expect(1, 1821, '\p{^Jg= TETH}', "");
Expect(1, 1821, '\P{Jg= TETH}', "");
Expect(0, 1821, '\P{^Jg= TETH}', "");
Error('\p{Is_Joining_Group=	_TETH/a/}');
Error('\P{Is_Joining_Group=	_TETH/a/}');
Expect(1, 1820, '\p{Is_Joining_Group=teth}', "");
Expect(0, 1820, '\p{^Is_Joining_Group=teth}', "");
Expect(0, 1820, '\P{Is_Joining_Group=teth}', "");
Expect(1, 1820, '\P{^Is_Joining_Group=teth}', "");
Expect(0, 1821, '\p{Is_Joining_Group=teth}', "");
Expect(1, 1821, '\p{^Is_Joining_Group=teth}', "");
Expect(1, 1821, '\P{Is_Joining_Group=teth}', "");
Expect(0, 1821, '\P{^Is_Joining_Group=teth}', "");
Expect(1, 1820, '\p{Is_Joining_Group:   -	TETH}', "");
Expect(0, 1820, '\p{^Is_Joining_Group:   -	TETH}', "");
Expect(0, 1820, '\P{Is_Joining_Group:   -	TETH}', "");
Expect(1, 1820, '\P{^Is_Joining_Group:   -	TETH}', "");
Expect(0, 1821, '\p{Is_Joining_Group:   -	TETH}', "");
Expect(1, 1821, '\p{^Is_Joining_Group:   -	TETH}', "");
Expect(1, 1821, '\P{Is_Joining_Group:   -	TETH}', "");
Expect(0, 1821, '\P{^Is_Joining_Group:   -	TETH}', "");
Error('\p{Is_Jg=_ Teth:=}');
Error('\P{Is_Jg=_ Teth:=}');
Expect(1, 1820, '\p{Is_Jg:teth}', "");
Expect(0, 1820, '\p{^Is_Jg:teth}', "");
Expect(0, 1820, '\P{Is_Jg:teth}', "");
Expect(1, 1820, '\P{^Is_Jg:teth}', "");
Expect(0, 1821, '\p{Is_Jg:teth}', "");
Expect(1, 1821, '\p{^Is_Jg:teth}', "");
Expect(1, 1821, '\P{Is_Jg:teth}', "");
Expect(0, 1821, '\P{^Is_Jg:teth}', "");
Expect(1, 1820, '\p{Is_Jg=		Teth}', "");
Expect(0, 1820, '\p{^Is_Jg=		Teth}', "");
Expect(0, 1820, '\P{Is_Jg=		Teth}', "");
Expect(1, 1820, '\P{^Is_Jg=		Teth}', "");
Expect(0, 1821, '\p{Is_Jg=		Teth}', "");
Expect(1, 1821, '\p{^Is_Jg=		Teth}', "");
Expect(1, 1821, '\P{Is_Jg=		Teth}', "");
Expect(0, 1821, '\P{^Is_Jg=		Teth}', "");
Error('\p{Joining_Group=  waw:=}');
Error('\P{Joining_Group=  waw:=}');
Expect(1, 2219, '\p{Joining_Group=waw}', "");
Expect(0, 2219, '\p{^Joining_Group=waw}', "");
Expect(0, 2219, '\P{Joining_Group=waw}', "");
Expect(1, 2219, '\P{^Joining_Group=waw}', "");
Expect(0, 2220, '\p{Joining_Group=waw}', "");
Expect(1, 2220, '\p{^Joining_Group=waw}', "");
Expect(1, 2220, '\P{Joining_Group=waw}', "");
Expect(0, 2220, '\P{^Joining_Group=waw}', "");
Expect(1, 2219, '\p{Joining_Group= WAW}', "");
Expect(0, 2219, '\p{^Joining_Group= WAW}', "");
Expect(0, 2219, '\P{Joining_Group= WAW}', "");
Expect(1, 2219, '\P{^Joining_Group= WAW}', "");
Expect(0, 2220, '\p{Joining_Group= WAW}', "");
Expect(1, 2220, '\p{^Joining_Group= WAW}', "");
Expect(1, 2220, '\P{Joining_Group= WAW}', "");
Expect(0, 2220, '\P{^Joining_Group= WAW}', "");
Error('\p{Jg=:=	WAW}');
Error('\P{Jg=:=	WAW}');
Expect(1, 2219, '\p{Jg=waw}', "");
Expect(0, 2219, '\p{^Jg=waw}', "");
Expect(0, 2219, '\P{Jg=waw}', "");
Expect(1, 2219, '\P{^Jg=waw}', "");
Expect(0, 2220, '\p{Jg=waw}', "");
Expect(1, 2220, '\p{^Jg=waw}', "");
Expect(1, 2220, '\P{Jg=waw}', "");
Expect(0, 2220, '\P{^Jg=waw}', "");
Expect(1, 2219, '\p{Jg=-_waw}', "");
Expect(0, 2219, '\p{^Jg=-_waw}', "");
Expect(0, 2219, '\P{Jg=-_waw}', "");
Expect(1, 2219, '\P{^Jg=-_waw}', "");
Expect(0, 2220, '\p{Jg=-_waw}', "");
Expect(1, 2220, '\p{^Jg=-_waw}', "");
Expect(1, 2220, '\P{Jg=-_waw}', "");
Expect(0, 2220, '\P{^Jg=-_waw}', "");
Error('\p{Is_Joining_Group=- WAW/a/}');
Error('\P{Is_Joining_Group=- WAW/a/}');
Expect(1, 2219, '\p{Is_Joining_Group=waw}', "");
Expect(0, 2219, '\p{^Is_Joining_Group=waw}', "");
Expect(0, 2219, '\P{Is_Joining_Group=waw}', "");
Expect(1, 2219, '\P{^Is_Joining_Group=waw}', "");
Expect(0, 2220, '\p{Is_Joining_Group=waw}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=waw}', "");
Expect(1, 2220, '\P{Is_Joining_Group=waw}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=waw}', "");
Expect(1, 2219, '\p{Is_Joining_Group=_	WAW}', "");
Expect(0, 2219, '\p{^Is_Joining_Group=_	WAW}', "");
Expect(0, 2219, '\P{Is_Joining_Group=_	WAW}', "");
Expect(1, 2219, '\P{^Is_Joining_Group=_	WAW}', "");
Expect(0, 2220, '\p{Is_Joining_Group=_	WAW}', "");
Expect(1, 2220, '\p{^Is_Joining_Group=_	WAW}', "");
Expect(1, 2220, '\P{Is_Joining_Group=_	WAW}', "");
Expect(0, 2220, '\P{^Is_Joining_Group=_	WAW}', "");
Error('\p{Is_Jg=/a/-Waw}');
Error('\P{Is_Jg=/a/-Waw}');
Expect(1, 2219, '\p{Is_Jg=waw}', "");
Expect(0, 2219, '\p{^Is_Jg=waw}', "");
Expect(0, 2219, '\P{Is_Jg=waw}', "");
Expect(1, 2219, '\P{^Is_Jg=waw}', "");
Expect(0, 2220, '\p{Is_Jg=waw}', "");
Expect(1, 2220, '\p{^Is_Jg=waw}', "");
Expect(1, 2220, '\P{Is_Jg=waw}', "");
Expect(0, 2220, '\P{^Is_Jg=waw}', "");
Expect(1, 2219, '\p{Is_Jg=	-waw}', "");
Expect(0, 2219, '\p{^Is_Jg=	-waw}', "");
Expect(0, 2219, '\P{Is_Jg=	-waw}', "");
Expect(1, 2219, '\P{^Is_Jg=	-waw}', "");
Expect(0, 2220, '\p{Is_Jg=	-waw}', "");
Expect(1, 2220, '\p{^Is_Jg=	-waw}', "");
Expect(1, 2220, '\P{Is_Jg=	-waw}', "");
Expect(0, 2220, '\P{^Is_Jg=	-waw}', "");
Error('\p{Joining_Group=/a/  YEH}');
Error('\P{Joining_Group=/a/  YEH}');
Expect(1, 2217, '\p{Joining_Group: yeh}', "");
Expect(0, 2217, '\p{^Joining_Group: yeh}', "");
Expect(0, 2217, '\P{Joining_Group: yeh}', "");
Expect(1, 2217, '\P{^Joining_Group: yeh}', "");
Expect(0, 2218, '\p{Joining_Group: yeh}', "");
Expect(1, 2218, '\p{^Joining_Group: yeh}', "");
Expect(1, 2218, '\P{Joining_Group: yeh}', "");
Expect(0, 2218, '\P{^Joining_Group: yeh}', "");
Expect(1, 2217, '\p{Joining_Group=__Yeh}', "");
Expect(0, 2217, '\p{^Joining_Group=__Yeh}', "");
Expect(0, 2217, '\P{Joining_Group=__Yeh}', "");
Expect(1, 2217, '\P{^Joining_Group=__Yeh}', "");
Expect(0, 2218, '\p{Joining_Group=__Yeh}', "");
Expect(1, 2218, '\p{^Joining_Group=__Yeh}', "");
Expect(1, 2218, '\P{Joining_Group=__Yeh}', "");
Expect(0, 2218, '\P{^Joining_Group=__Yeh}', "");
Error('\p{Jg=:=_yeh}');
Error('\P{Jg=:=_yeh}');
Expect(1, 2217, '\p{Jg=yeh}', "");
Expect(0, 2217, '\p{^Jg=yeh}', "");
Expect(0, 2217, '\P{Jg=yeh}', "");
Expect(1, 2217, '\P{^Jg=yeh}', "");
Expect(0, 2218, '\p{Jg=yeh}', "");
Expect(1, 2218, '\p{^Jg=yeh}', "");
Expect(1, 2218, '\P{Jg=yeh}', "");
Expect(0, 2218, '\P{^Jg=yeh}', "");
Expect(1, 2217, '\p{Jg=		Yeh}', "");
Expect(0, 2217, '\p{^Jg=		Yeh}', "");
Expect(0, 2217, '\P{Jg=		Yeh}', "");
Expect(1, 2217, '\P{^Jg=		Yeh}', "");
Expect(0, 2218, '\p{Jg=		Yeh}', "");
Expect(1, 2218, '\p{^Jg=		Yeh}', "");
Expect(1, 2218, '\P{Jg=		Yeh}', "");
Expect(0, 2218, '\P{^Jg=		Yeh}', "");
Error('\p{Is_Joining_Group=/a/--YEH}');
Error('\P{Is_Joining_Group=/a/--YEH}');
Expect(1, 2217, '\p{Is_Joining_Group:   yeh}', "");
Expect(0, 2217, '\p{^Is_Joining_Group:   yeh}', "");
Expect(0, 2217, '\P{Is_Joining_Group:   yeh}', "");
Expect(1, 2217, '\P{^Is_Joining_Group:   yeh}', "");
Expect(0, 2218, '\p{Is_Joining_Group:   yeh}', "");
Expect(1, 2218, '\p{^Is_Joining_Group:   yeh}', "");
Expect(1, 2218, '\P{Is_Joining_Group:   yeh}', "");
Expect(0, 2218, '\P{^Is_Joining_Group:   yeh}', "");
Expect(1, 2217, '\p{Is_Joining_Group= 	Yeh}', "");
Expect(0, 2217, '\p{^Is_Joining_Group= 	Yeh}', "");
Expect(0, 2217, '\P{Is_Joining_Group= 	Yeh}', "");
Expect(1, 2217, '\P{^Is_Joining_Group= 	Yeh}', "");
Expect(0, 2218, '\p{Is_Joining_Group= 	Yeh}', "");
Expect(1, 2218, '\p{^Is_Joining_Group= 	Yeh}', "");
Expect(1, 2218, '\P{Is_Joining_Group= 	Yeh}', "");
Expect(0, 2218, '\P{^Is_Joining_Group= 	Yeh}', "");
Error('\p{Is_Jg=:=--yeh}');
Error('\P{Is_Jg=:=--yeh}');
Expect(1, 2217, '\p{Is_Jg:   yeh}', "");
Expect(0, 2217, '\p{^Is_Jg:   yeh}', "");
Expect(0, 2217, '\P{Is_Jg:   yeh}', "");
Expect(1, 2217, '\P{^Is_Jg:   yeh}', "");
Expect(0, 2218, '\p{Is_Jg:   yeh}', "");
Expect(1, 2218, '\p{^Is_Jg:   yeh}', "");
Expect(1, 2218, '\P{Is_Jg:   yeh}', "");
Expect(0, 2218, '\P{^Is_Jg:   yeh}', "");
Expect(1, 2217, '\p{Is_Jg=	YEH}', "");
Expect(0, 2217, '\p{^Is_Jg=	YEH}', "");
Expect(0, 2217, '\P{Is_Jg=	YEH}', "");
Expect(1, 2217, '\P{^Is_Jg=	YEH}', "");
Expect(0, 2218, '\p{Is_Jg=	YEH}', "");
Expect(1, 2218, '\p{^Is_Jg=	YEH}', "");
Expect(1, 2218, '\P{Is_Jg=	YEH}', "");
Expect(0, 2218, '\P{^Is_Jg=	YEH}', "");
Error('\p{Joining_Group= Yeh_BARREE:=}');
Error('\P{Joining_Group= Yeh_BARREE:=}');
Expect(1, 1747, '\p{Joining_Group=yehbarree}', "");
Expect(0, 1747, '\p{^Joining_Group=yehbarree}', "");
Expect(0, 1747, '\P{Joining_Group=yehbarree}', "");
Expect(1, 1747, '\P{^Joining_Group=yehbarree}', "");
Expect(0, 1748, '\p{Joining_Group=yehbarree}', "");
Expect(1, 1748, '\p{^Joining_Group=yehbarree}', "");
Expect(1, 1748, '\P{Joining_Group=yehbarree}', "");
Expect(0, 1748, '\P{^Joining_Group=yehbarree}', "");
Expect(1, 1747, '\p{Joining_Group=	-Yeh_BARREE}', "");
Expect(0, 1747, '\p{^Joining_Group=	-Yeh_BARREE}', "");
Expect(0, 1747, '\P{Joining_Group=	-Yeh_BARREE}', "");
Expect(1, 1747, '\P{^Joining_Group=	-Yeh_BARREE}', "");
Expect(0, 1748, '\p{Joining_Group=	-Yeh_BARREE}', "");
Expect(1, 1748, '\p{^Joining_Group=	-Yeh_BARREE}', "");
Expect(1, 1748, '\P{Joining_Group=	-Yeh_BARREE}', "");
Expect(0, 1748, '\P{^Joining_Group=	-Yeh_BARREE}', "");
Error('\p{Jg=-:=Yeh_BARREE}');
Error('\P{Jg=-:=Yeh_BARREE}');
Expect(1, 1747, '\p{Jg=yehbarree}', "");
Expect(0, 1747, '\p{^Jg=yehbarree}', "");
Expect(0, 1747, '\P{Jg=yehbarree}', "");
Expect(1, 1747, '\P{^Jg=yehbarree}', "");
Expect(0, 1748, '\p{Jg=yehbarree}', "");
Expect(1, 1748, '\p{^Jg=yehbarree}', "");
Expect(1, 1748, '\P{Jg=yehbarree}', "");
Expect(0, 1748, '\P{^Jg=yehbarree}', "");
Expect(1, 1747, '\p{Jg=_ Yeh_Barree}', "");
Expect(0, 1747, '\p{^Jg=_ Yeh_Barree}', "");
Expect(0, 1747, '\P{Jg=_ Yeh_Barree}', "");
Expect(1, 1747, '\P{^Jg=_ Yeh_Barree}', "");
Expect(0, 1748, '\p{Jg=_ Yeh_Barree}', "");
Expect(1, 1748, '\p{^Jg=_ Yeh_Barree}', "");
Expect(1, 1748, '\P{Jg=_ Yeh_Barree}', "");
Expect(0, 1748, '\P{^Jg=_ Yeh_Barree}', "");
Error('\p{Is_Joining_Group=/a/--yeh_BARREE}');
Error('\P{Is_Joining_Group=/a/--yeh_BARREE}');
Expect(1, 1747, '\p{Is_Joining_Group:   yehbarree}', "");
Expect(0, 1747, '\p{^Is_Joining_Group:   yehbarree}', "");
Expect(0, 1747, '\P{Is_Joining_Group:   yehbarree}', "");
Expect(1, 1747, '\P{^Is_Joining_Group:   yehbarree}', "");
Expect(0, 1748, '\p{Is_Joining_Group:   yehbarree}', "");
Expect(1, 1748, '\p{^Is_Joining_Group:   yehbarree}', "");
Expect(1, 1748, '\P{Is_Joining_Group:   yehbarree}', "");
Expect(0, 1748, '\P{^Is_Joining_Group:   yehbarree}', "");
Expect(1, 1747, '\p{Is_Joining_Group=__Yeh_Barree}', "");
Expect(0, 1747, '\p{^Is_Joining_Group=__Yeh_Barree}', "");
Expect(0, 1747, '\P{Is_Joining_Group=__Yeh_Barree}', "");
Expect(1, 1747, '\P{^Is_Joining_Group=__Yeh_Barree}', "");
Expect(0, 1748, '\p{Is_Joining_Group=__Yeh_Barree}', "");
Expect(1, 1748, '\p{^Is_Joining_Group=__Yeh_Barree}', "");
Expect(1, 1748, '\P{Is_Joining_Group=__Yeh_Barree}', "");
Expect(0, 1748, '\P{^Is_Joining_Group=__Yeh_Barree}', "");
Error('\p{Is_Jg= /a/yeh_barree}');
Error('\P{Is_Jg= /a/yeh_barree}');
Expect(1, 1747, '\p{Is_Jg:   yehbarree}', "");
Expect(0, 1747, '\p{^Is_Jg:   yehbarree}', "");
Expect(0, 1747, '\P{Is_Jg:   yehbarree}', "");
Expect(1, 1747, '\P{^Is_Jg:   yehbarree}', "");
Expect(0, 1748, '\p{Is_Jg:   yehbarree}', "");
Expect(1, 1748, '\p{^Is_Jg:   yehbarree}', "");
Expect(1, 1748, '\P{Is_Jg:   yehbarree}', "");
Expect(0, 1748, '\P{^Is_Jg:   yehbarree}', "");
Expect(1, 1747, '\p{Is_Jg= _Yeh_barree}', "");
Expect(0, 1747, '\p{^Is_Jg= _Yeh_barree}', "");
Expect(0, 1747, '\P{Is_Jg= _Yeh_barree}', "");
Expect(1, 1747, '\P{^Is_Jg= _Yeh_barree}', "");
Expect(0, 1748, '\p{Is_Jg= _Yeh_barree}', "");
Expect(1, 1748, '\p{^Is_Jg= _Yeh_barree}', "");
Expect(1, 1748, '\P{Is_Jg= _Yeh_barree}', "");
Expect(0, 1748, '\P{^Is_Jg= _Yeh_barree}', "");
Error('\p{Joining_Group=	:=yeh_WITH_Tail}');
Error('\P{Joining_Group=	:=yeh_WITH_Tail}');
Expect(1, 1741, '\p{Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\p{^Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\P{Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\P{^Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\p{Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\p{^Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\P{Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\P{^Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\p{Joining_Group=_YEH_With_Tail}', "");
Expect(0, 1741, '\p{^Joining_Group=_YEH_With_Tail}', "");
Expect(0, 1741, '\P{Joining_Group=_YEH_With_Tail}', "");
Expect(1, 1741, '\P{^Joining_Group=_YEH_With_Tail}', "");
Expect(0, 1742, '\p{Joining_Group=_YEH_With_Tail}', "");
Expect(1, 1742, '\p{^Joining_Group=_YEH_With_Tail}', "");
Expect(1, 1742, '\P{Joining_Group=_YEH_With_Tail}', "");
Expect(0, 1742, '\P{^Joining_Group=_YEH_With_Tail}', "");
Error('\p{Jg: /a/YEH_WITH_TAIL}');
Error('\P{Jg: /a/YEH_WITH_TAIL}');
Expect(1, 1741, '\p{Jg=yehwithtail}', "");
Expect(0, 1741, '\p{^Jg=yehwithtail}', "");
Expect(0, 1741, '\P{Jg=yehwithtail}', "");
Expect(1, 1741, '\P{^Jg=yehwithtail}', "");
Expect(0, 1742, '\p{Jg=yehwithtail}', "");
Expect(1, 1742, '\p{^Jg=yehwithtail}', "");
Expect(1, 1742, '\P{Jg=yehwithtail}', "");
Expect(0, 1742, '\P{^Jg=yehwithtail}', "");
Expect(1, 1741, '\p{Jg:	_ Yeh_With_TAIL}', "");
Expect(0, 1741, '\p{^Jg:	_ Yeh_With_TAIL}', "");
Expect(0, 1741, '\P{Jg:	_ Yeh_With_TAIL}', "");
Expect(1, 1741, '\P{^Jg:	_ Yeh_With_TAIL}', "");
Expect(0, 1742, '\p{Jg:	_ Yeh_With_TAIL}', "");
Expect(1, 1742, '\p{^Jg:	_ Yeh_With_TAIL}', "");
Expect(1, 1742, '\P{Jg:	_ Yeh_With_TAIL}', "");
Expect(0, 1742, '\P{^Jg:	_ Yeh_With_TAIL}', "");
Error('\p{Is_Joining_Group=/a/YEH_With_tail}');
Error('\P{Is_Joining_Group=/a/YEH_With_tail}');
Expect(1, 1741, '\p{Is_Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\p{^Is_Joining_Group=yehwithtail}', "");
Expect(0, 1741, '\P{Is_Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\P{^Is_Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\p{Is_Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\p{^Is_Joining_Group=yehwithtail}', "");
Expect(1, 1742, '\P{Is_Joining_Group=yehwithtail}', "");
Expect(0, 1742, '\P{^Is_Joining_Group=yehwithtail}', "");
Expect(1, 1741, '\p{Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(0, 1741, '\p{^Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(0, 1741, '\P{Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(1, 1741, '\P{^Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(0, 1742, '\p{Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(1, 1742, '\p{^Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(1, 1742, '\P{Is_Joining_Group=__Yeh_With_Tail}', "");
Expect(0, 1742, '\P{^Is_Joining_Group=__Yeh_With_Tail}', "");
Error('\p{Is_Jg=-/a/YEH_With_TAIL}');
Error('\P{Is_Jg=-/a/YEH_With_TAIL}');
Expect(1, 1741, '\p{Is_Jg=yehwithtail}', "");
Expect(0, 1741, '\p{^Is_Jg=yehwithtail}', "");
Expect(0, 1741, '\P{Is_Jg=yehwithtail}', "");
Expect(1, 1741, '\P{^Is_Jg=yehwithtail}', "");
Expect(0, 1742, '\p{Is_Jg=yehwithtail}', "");
Expect(1, 1742, '\p{^Is_Jg=yehwithtail}', "");
Expect(1, 1742, '\P{Is_Jg=yehwithtail}', "");
Expect(0, 1742, '\P{^Is_Jg=yehwithtail}', "");
Expect(1, 1741, '\p{Is_Jg=	yeh_with_Tail}', "");
Expect(0, 1741, '\p{^Is_Jg=	yeh_with_Tail}', "");
Expect(0, 1741, '\P{Is_Jg=	yeh_with_Tail}', "");
Expect(1, 1741, '\P{^Is_Jg=	yeh_with_Tail}', "");
Expect(0, 1742, '\p{Is_Jg=	yeh_with_Tail}', "");
Expect(1, 1742, '\p{^Is_Jg=	yeh_with_Tail}', "");
Expect(1, 1742, '\P{Is_Jg=	yeh_with_Tail}', "");
Expect(0, 1742, '\P{^Is_Jg=	yeh_with_Tail}', "");
Error('\p{Joining_Group:	/a/  yudh}');
Error('\P{Joining_Group:	/a/  yudh}');
Expect(1, 1821, '\p{Joining_Group=yudh}', "");
Expect(0, 1821, '\p{^Joining_Group=yudh}', "");
Expect(0, 1821, '\P{Joining_Group=yudh}', "");
Expect(1, 1821, '\P{^Joining_Group=yudh}', "");
Expect(0, 1822, '\p{Joining_Group=yudh}', "");
Expect(1, 1822, '\p{^Joining_Group=yudh}', "");
Expect(1, 1822, '\P{Joining_Group=yudh}', "");
Expect(0, 1822, '\P{^Joining_Group=yudh}', "");
Expect(1, 1821, '\p{Joining_Group: _ Yudh}', "");
Expect(0, 1821, '\p{^Joining_Group: _ Yudh}', "");
Expect(0, 1821, '\P{Joining_Group: _ Yudh}', "");
Expect(1, 1821, '\P{^Joining_Group: _ Yudh}', "");
Expect(0, 1822, '\p{Joining_Group: _ Yudh}', "");
Expect(1, 1822, '\p{^Joining_Group: _ Yudh}', "");
Expect(1, 1822, '\P{Joining_Group: _ Yudh}', "");
Expect(0, 1822, '\P{^Joining_Group: _ Yudh}', "");
Error('\p{Jg=:=	 Yudh}');
Error('\P{Jg=:=	 Yudh}');
Expect(1, 1821, '\p{Jg=yudh}', "");
Expect(0, 1821, '\p{^Jg=yudh}', "");
Expect(0, 1821, '\P{Jg=yudh}', "");
Expect(1, 1821, '\P{^Jg=yudh}', "");
Expect(0, 1822, '\p{Jg=yudh}', "");
Expect(1, 1822, '\p{^Jg=yudh}', "");
Expect(1, 1822, '\P{Jg=yudh}', "");
Expect(0, 1822, '\P{^Jg=yudh}', "");
Expect(1, 1821, '\p{Jg=	Yudh}', "");
Expect(0, 1821, '\p{^Jg=	Yudh}', "");
Expect(0, 1821, '\P{Jg=	Yudh}', "");
Expect(1, 1821, '\P{^Jg=	Yudh}', "");
Expect(0, 1822, '\p{Jg=	Yudh}', "");
Expect(1, 1822, '\p{^Jg=	Yudh}', "");
Expect(1, 1822, '\P{Jg=	Yudh}', "");
Expect(0, 1822, '\P{^Jg=	Yudh}', "");
Error('\p{Is_Joining_Group=	/a/Yudh}');
Error('\P{Is_Joining_Group=	/a/Yudh}');
Expect(1, 1821, '\p{Is_Joining_Group=yudh}', "");
Expect(0, 1821, '\p{^Is_Joining_Group=yudh}', "");
Expect(0, 1821, '\P{Is_Joining_Group=yudh}', "");
Expect(1, 1821, '\P{^Is_Joining_Group=yudh}', "");
Expect(0, 1822, '\p{Is_Joining_Group=yudh}', "");
Expect(1, 1822, '\p{^Is_Joining_Group=yudh}', "");
Expect(1, 1822, '\P{Is_Joining_Group=yudh}', "");
Expect(0, 1822, '\P{^Is_Joining_Group=yudh}', "");
Expect(1, 1821, '\p{Is_Joining_Group=-Yudh}', "");
Expect(0, 1821, '\p{^Is_Joining_Group=-Yudh}', "");
Expect(0, 1821, '\P{Is_Joining_Group=-Yudh}', "");
Expect(1, 1821, '\P{^Is_Joining_Group=-Yudh}', "");
Expect(0, 1822, '\p{Is_Joining_Group=-Yudh}', "");
Expect(1, 1822, '\p{^Is_Joining_Group=-Yudh}', "");
Expect(1, 1822, '\P{Is_Joining_Group=-Yudh}', "");
Expect(0, 1822, '\P{^Is_Joining_Group=-Yudh}', "");
Error('\p{Is_Jg=:=YUDH}');
Error('\P{Is_Jg=:=YUDH}');
Expect(1, 1821, '\p{Is_Jg=yudh}', "");
Expect(0, 1821, '\p{^Is_Jg=yudh}', "");
Expect(0, 1821, '\P{Is_Jg=yudh}', "");
Expect(1, 1821, '\P{^Is_Jg=yudh}', "");
Expect(0, 1822, '\p{Is_Jg=yudh}', "");
Expect(1, 1822, '\p{^Is_Jg=yudh}', "");
Expect(1, 1822, '\P{Is_Jg=yudh}', "");
Expect(0, 1822, '\P{^Is_Jg=yudh}', "");
Expect(1, 1821, '\p{Is_Jg=__Yudh}', "");
Expect(0, 1821, '\p{^Is_Jg=__Yudh}', "");
Expect(0, 1821, '\P{Is_Jg=__Yudh}', "");
Expect(1, 1821, '\P{^Is_Jg=__Yudh}', "");
Expect(0, 1822, '\p{Is_Jg=__Yudh}', "");
Expect(1, 1822, '\p{^Is_Jg=__Yudh}', "");
Expect(1, 1822, '\P{Is_Jg=__Yudh}', "");
Expect(0, 1822, '\P{^Is_Jg=__Yudh}', "");
Error('\p{Joining_Group=:=	YUDH_He}');
Error('\P{Joining_Group=:=	YUDH_He}');
Expect(1, 1822, '\p{Joining_Group: yudhhe}', "");
Expect(0, 1822, '\p{^Joining_Group: yudhhe}', "");
Expect(0, 1822, '\P{Joining_Group: yudhhe}', "");
Expect(1, 1822, '\P{^Joining_Group: yudhhe}', "");
Expect(0, 1823, '\p{Joining_Group: yudhhe}', "");
Expect(1, 1823, '\p{^Joining_Group: yudhhe}', "");
Expect(1, 1823, '\P{Joining_Group: yudhhe}', "");
Expect(0, 1823, '\P{^Joining_Group: yudhhe}', "");
Expect(1, 1822, '\p{Joining_Group=--Yudh_He}', "");
Expect(0, 1822, '\p{^Joining_Group=--Yudh_He}', "");
Expect(0, 1822, '\P{Joining_Group=--Yudh_He}', "");
Expect(1, 1822, '\P{^Joining_Group=--Yudh_He}', "");
Expect(0, 1823, '\p{Joining_Group=--Yudh_He}', "");
Expect(1, 1823, '\p{^Joining_Group=--Yudh_He}', "");
Expect(1, 1823, '\P{Joining_Group=--Yudh_He}', "");
Expect(0, 1823, '\P{^Joining_Group=--Yudh_He}', "");
Error('\p{Jg=:=__yudh_He}');
Error('\P{Jg=:=__yudh_He}');
Expect(1, 1822, '\p{Jg=yudhhe}', "");
Expect(0, 1822, '\p{^Jg=yudhhe}', "");
Expect(0, 1822, '\P{Jg=yudhhe}', "");
Expect(1, 1822, '\P{^Jg=yudhhe}', "");
Expect(0, 1823, '\p{Jg=yudhhe}', "");
Expect(1, 1823, '\p{^Jg=yudhhe}', "");
Expect(1, 1823, '\P{Jg=yudhhe}', "");
Expect(0, 1823, '\P{^Jg=yudhhe}', "");
Expect(1, 1822, '\p{Jg: _	Yudh_HE}', "");
Expect(0, 1822, '\p{^Jg: _	Yudh_HE}', "");
Expect(0, 1822, '\P{Jg: _	Yudh_HE}', "");
Expect(1, 1822, '\P{^Jg: _	Yudh_HE}', "");
Expect(0, 1823, '\p{Jg: _	Yudh_HE}', "");
Expect(1, 1823, '\p{^Jg: _	Yudh_HE}', "");
Expect(1, 1823, '\P{Jg: _	Yudh_HE}', "");
Expect(0, 1823, '\P{^Jg: _	Yudh_HE}', "");
Error('\p{Is_Joining_Group=_ Yudh_He:=}');
Error('\P{Is_Joining_Group=_ Yudh_He:=}');
Expect(1, 1822, '\p{Is_Joining_Group=yudhhe}', "");
Expect(0, 1822, '\p{^Is_Joining_Group=yudhhe}', "");
Expect(0, 1822, '\P{Is_Joining_Group=yudhhe}', "");
Expect(1, 1822, '\P{^Is_Joining_Group=yudhhe}', "");
Expect(0, 1823, '\p{Is_Joining_Group=yudhhe}', "");
Expect(1, 1823, '\p{^Is_Joining_Group=yudhhe}', "");
Expect(1, 1823, '\P{Is_Joining_Group=yudhhe}', "");
Expect(0, 1823, '\P{^Is_Joining_Group=yudhhe}', "");
Expect(1, 1822, '\p{Is_Joining_Group=_-YUDH_HE}', "");
Expect(0, 1822, '\p{^Is_Joining_Group=_-YUDH_HE}', "");
Expect(0, 1822, '\P{Is_Joining_Group=_-YUDH_HE}', "");
Expect(1, 1822, '\P{^Is_Joining_Group=_-YUDH_HE}', "");
Expect(0, 1823, '\p{Is_Joining_Group=_-YUDH_HE}', "");
Expect(1, 1823, '\p{^Is_Joining_Group=_-YUDH_HE}', "");
Expect(1, 1823, '\P{Is_Joining_Group=_-YUDH_HE}', "");
Expect(0, 1823, '\P{^Is_Joining_Group=_-YUDH_HE}', "");
Error('\p{Is_Jg=:=yudh_he}');
Error('\P{Is_Jg=:=yudh_he}');
Expect(1, 1822, '\p{Is_Jg=yudhhe}', "");
Expect(0, 1822, '\p{^Is_Jg=yudhhe}', "");
Expect(0, 1822, '\P{Is_Jg=yudhhe}', "");
Expect(1, 1822, '\P{^Is_Jg=yudhhe}', "");
Expect(0, 1823, '\p{Is_Jg=yudhhe}', "");
Expect(1, 1823, '\p{^Is_Jg=yudhhe}', "");
Expect(1, 1823, '\P{Is_Jg=yudhhe}', "");
Expect(0, 1823, '\P{^Is_Jg=yudhhe}', "");
Expect(1, 1822, '\p{Is_Jg=- Yudh_He}', "");
Expect(0, 1822, '\p{^Is_Jg=- Yudh_He}', "");
Expect(0, 1822, '\P{Is_Jg=- Yudh_He}', "");
Expect(1, 1822, '\P{^Is_Jg=- Yudh_He}', "");
Expect(0, 1823, '\p{Is_Jg=- Yudh_He}', "");
Expect(1, 1823, '\p{^Is_Jg=- Yudh_He}', "");
Expect(1, 1823, '\P{Is_Jg=- Yudh_He}', "");
Expect(0, 1823, '\P{^Is_Jg=- Yudh_He}', "");
Error('\p{Joining_Group=/a/Zain}');
Error('\P{Joining_Group=/a/Zain}');
Expect(1, 1817, '\p{Joining_Group=zain}', "");
Expect(0, 1817, '\p{^Joining_Group=zain}', "");
Expect(0, 1817, '\P{Joining_Group=zain}', "");
Expect(1, 1817, '\P{^Joining_Group=zain}', "");
Expect(0, 1818, '\p{Joining_Group=zain}', "");
Expect(1, 1818, '\p{^Joining_Group=zain}', "");
Expect(1, 1818, '\P{Joining_Group=zain}', "");
Expect(0, 1818, '\P{^Joining_Group=zain}', "");
Expect(1, 1817, '\p{Joining_Group:- ZAIN}', "");
Expect(0, 1817, '\p{^Joining_Group:- ZAIN}', "");
Expect(0, 1817, '\P{Joining_Group:- ZAIN}', "");
Expect(1, 1817, '\P{^Joining_Group:- ZAIN}', "");
Expect(0, 1818, '\p{Joining_Group:- ZAIN}', "");
Expect(1, 1818, '\p{^Joining_Group:- ZAIN}', "");
Expect(1, 1818, '\P{Joining_Group:- ZAIN}', "");
Expect(0, 1818, '\P{^Joining_Group:- ZAIN}', "");
Error('\p{Jg=:=_ Zain}');
Error('\P{Jg=:=_ Zain}');
Expect(1, 1817, '\p{Jg=zain}', "");
Expect(0, 1817, '\p{^Jg=zain}', "");
Expect(0, 1817, '\P{Jg=zain}', "");
Expect(1, 1817, '\P{^Jg=zain}', "");
Expect(0, 1818, '\p{Jg=zain}', "");
Expect(1, 1818, '\p{^Jg=zain}', "");
Expect(1, 1818, '\P{Jg=zain}', "");
Expect(0, 1818, '\P{^Jg=zain}', "");
Expect(1, 1817, '\p{Jg=		Zain}', "");
Expect(0, 1817, '\p{^Jg=		Zain}', "");
Expect(0, 1817, '\P{Jg=		Zain}', "");
Expect(1, 1817, '\P{^Jg=		Zain}', "");
Expect(0, 1818, '\p{Jg=		Zain}', "");
Expect(1, 1818, '\p{^Jg=		Zain}', "");
Expect(1, 1818, '\P{Jg=		Zain}', "");
Expect(0, 1818, '\P{^Jg=		Zain}', "");
Error('\p{Is_Joining_Group:	- ZAIN/a/}');
Error('\P{Is_Joining_Group:	- ZAIN/a/}');
Expect(1, 1817, '\p{Is_Joining_Group=zain}', "");
Expect(0, 1817, '\p{^Is_Joining_Group=zain}', "");
Expect(0, 1817, '\P{Is_Joining_Group=zain}', "");
Expect(1, 1817, '\P{^Is_Joining_Group=zain}', "");
Expect(0, 1818, '\p{Is_Joining_Group=zain}', "");
Expect(1, 1818, '\p{^Is_Joining_Group=zain}', "");
Expect(1, 1818, '\P{Is_Joining_Group=zain}', "");
Expect(0, 1818, '\P{^Is_Joining_Group=zain}', "");
Expect(1, 1817, '\p{Is_Joining_Group=_zain}', "");
Expect(0, 1817, '\p{^Is_Joining_Group=_zain}', "");
Expect(0, 1817, '\P{Is_Joining_Group=_zain}', "");
Expect(1, 1817, '\P{^Is_Joining_Group=_zain}', "");
Expect(0, 1818, '\p{Is_Joining_Group=_zain}', "");
Expect(1, 1818, '\p{^Is_Joining_Group=_zain}', "");
Expect(1, 1818, '\P{Is_Joining_Group=_zain}', "");
Expect(0, 1818, '\P{^Is_Joining_Group=_zain}', "");
Error('\p{Is_Jg=-_zain:=}');
Error('\P{Is_Jg=-_zain:=}');
Expect(1, 1817, '\p{Is_Jg=zain}', "");
Expect(0, 1817, '\p{^Is_Jg=zain}', "");
Expect(0, 1817, '\P{Is_Jg=zain}', "");
Expect(1, 1817, '\P{^Is_Jg=zain}', "");
Expect(0, 1818, '\p{Is_Jg=zain}', "");
Expect(1, 1818, '\p{^Is_Jg=zain}', "");
Expect(1, 1818, '\P{Is_Jg=zain}', "");
Expect(0, 1818, '\P{^Is_Jg=zain}', "");
Expect(1, 1817, '\p{Is_Jg= _zain}', "");
Expect(0, 1817, '\p{^Is_Jg= _zain}', "");
Expect(0, 1817, '\P{Is_Jg= _zain}', "");
Expect(1, 1817, '\P{^Is_Jg= _zain}', "");
Expect(0, 1818, '\p{Is_Jg= _zain}', "");
Expect(1, 1818, '\p{^Is_Jg= _zain}', "");
Expect(1, 1818, '\P{Is_Jg= _zain}', "");
Expect(0, 1818, '\P{^Is_Jg= _zain}', "");
Error('\p{Joining_Group=	-Zhain:=}');
Error('\P{Joining_Group=	-Zhain:=}');
Expect(1, 1869, '\p{Joining_Group=zhain}', "");
Expect(0, 1869, '\p{^Joining_Group=zhain}', "");
Expect(0, 1869, '\P{Joining_Group=zhain}', "");
Expect(1, 1869, '\P{^Joining_Group=zhain}', "");
Expect(0, 1870, '\p{Joining_Group=zhain}', "");
Expect(1, 1870, '\p{^Joining_Group=zhain}', "");
Expect(1, 1870, '\P{Joining_Group=zhain}', "");
Expect(0, 1870, '\P{^Joining_Group=zhain}', "");
Expect(1, 1869, '\p{Joining_Group=	Zhain}', "");
Expect(0, 1869, '\p{^Joining_Group=	Zhain}', "");
Expect(0, 1869, '\P{Joining_Group=	Zhain}', "");
Expect(1, 1869, '\P{^Joining_Group=	Zhain}', "");
Expect(0, 1870, '\p{Joining_Group=	Zhain}', "");
Expect(1, 1870, '\p{^Joining_Group=	Zhain}', "");
Expect(1, 1870, '\P{Joining_Group=	Zhain}', "");
Expect(0, 1870, '\P{^Joining_Group=	Zhain}', "");
Error('\p{Jg=	:=Zhain}');
Error('\P{Jg=	:=Zhain}');
Expect(1, 1869, '\p{Jg=zhain}', "");
Expect(0, 1869, '\p{^Jg=zhain}', "");
Expect(0, 1869, '\P{Jg=zhain}', "");
Expect(1, 1869, '\P{^Jg=zhain}', "");
Expect(0, 1870, '\p{Jg=zhain}', "");
Expect(1, 1870, '\p{^Jg=zhain}', "");
Expect(1, 1870, '\P{Jg=zhain}', "");
Expect(0, 1870, '\P{^Jg=zhain}', "");
Expect(1, 1869, '\p{Jg=_	ZHAIN}', "");
Expect(0, 1869, '\p{^Jg=_	ZHAIN}', "");
Expect(0, 1869, '\P{Jg=_	ZHAIN}', "");
Expect(1, 1869, '\P{^Jg=_	ZHAIN}', "");
Expect(0, 1870, '\p{Jg=_	ZHAIN}', "");
Expect(1, 1870, '\p{^Jg=_	ZHAIN}', "");
Expect(1, 1870, '\P{Jg=_	ZHAIN}', "");
Expect(0, 1870, '\P{^Jg=_	ZHAIN}', "");
Error('\p{Is_Joining_Group=/a/zhain}');
Error('\P{Is_Joining_Group=/a/zhain}');
Expect(1, 1869, '\p{Is_Joining_Group=zhain}', "");
Expect(0, 1869, '\p{^Is_Joining_Group=zhain}', "");
Expect(0, 1869, '\P{Is_Joining_Group=zhain}', "");
Expect(1, 1869, '\P{^Is_Joining_Group=zhain}', "");
Expect(0, 1870, '\p{Is_Joining_Group=zhain}', "");
Expect(1, 1870, '\p{^Is_Joining_Group=zhain}', "");
Expect(1, 1870, '\P{Is_Joining_Group=zhain}', "");
Expect(0, 1870, '\P{^Is_Joining_Group=zhain}', "");
Expect(1, 1869, '\p{Is_Joining_Group=  ZHAIN}', "");
Expect(0, 1869, '\p{^Is_Joining_Group=  ZHAIN}', "");
Expect(0, 1869, '\P{Is_Joining_Group=  ZHAIN}', "");
Expect(1, 1869, '\P{^Is_Joining_Group=  ZHAIN}', "");
Expect(0, 1870, '\p{Is_Joining_Group=  ZHAIN}', "");
Expect(1, 1870, '\p{^Is_Joining_Group=  ZHAIN}', "");
Expect(1, 1870, '\P{Is_Joining_Group=  ZHAIN}', "");
Expect(0, 1870, '\P{^Is_Joining_Group=  ZHAIN}', "");
Error('\p{Is_Jg=:=--Zhain}');
Error('\P{Is_Jg=:=--Zhain}');
Expect(1, 1869, '\p{Is_Jg=zhain}', "");
Expect(0, 1869, '\p{^Is_Jg=zhain}', "");
Expect(0, 1869, '\P{Is_Jg=zhain}', "");
Expect(1, 1869, '\P{^Is_Jg=zhain}', "");
Expect(0, 1870, '\p{Is_Jg=zhain}', "");
Expect(1, 1870, '\p{^Is_Jg=zhain}', "");
Expect(1, 1870, '\P{Is_Jg=zhain}', "");
Expect(0, 1870, '\P{^Is_Jg=zhain}', "");
Expect(1, 1869, '\p{Is_Jg:		 zhain}', "");
Expect(0, 1869, '\p{^Is_Jg:		 zhain}', "");
Expect(0, 1869, '\P{Is_Jg:		 zhain}', "");
Expect(1, 1869, '\P{^Is_Jg:		 zhain}', "");
Expect(0, 1870, '\p{Is_Jg:		 zhain}', "");
Expect(1, 1870, '\p{^Is_Jg:		 zhain}', "");
Expect(1, 1870, '\P{Is_Jg:		 zhain}', "");
Expect(0, 1870, '\P{^Is_Jg:		 zhain}', "");
Error('\p{Joining_Type=	/a/Join_Causing}');
Error('\P{Joining_Type=	/a/Join_Causing}');
Expect(1, 8205, '\p{Joining_Type=joincausing}', "");
Expect(0, 8205, '\p{^Joining_Type=joincausing}', "");
Expect(0, 8205, '\P{Joining_Type=joincausing}', "");
Expect(1, 8205, '\P{^Joining_Type=joincausing}', "");
Expect(0, 8206, '\p{Joining_Type=joincausing}', "");
Expect(1, 8206, '\p{^Joining_Type=joincausing}', "");
Expect(1, 8206, '\P{Joining_Type=joincausing}', "");
Expect(0, 8206, '\P{^Joining_Type=joincausing}', "");
Expect(1, 8205, '\p{Joining_Type=	_JOIN_Causing}', "");
Expect(0, 8205, '\p{^Joining_Type=	_JOIN_Causing}', "");
Expect(0, 8205, '\P{Joining_Type=	_JOIN_Causing}', "");
Expect(1, 8205, '\P{^Joining_Type=	_JOIN_Causing}', "");
Expect(0, 8206, '\p{Joining_Type=	_JOIN_Causing}', "");
Expect(1, 8206, '\p{^Joining_Type=	_JOIN_Causing}', "");
Expect(1, 8206, '\P{Joining_Type=	_JOIN_Causing}', "");
Expect(0, 8206, '\P{^Joining_Type=	_JOIN_Causing}', "");
Error('\p{Jt=-/a/c}');
Error('\P{Jt=-/a/c}');
Expect(1, 8205, '\p{Jt: c}', "");
Expect(0, 8205, '\p{^Jt: c}', "");
Expect(0, 8205, '\P{Jt: c}', "");
Expect(1, 8205, '\P{^Jt: c}', "");
Expect(0, 8206, '\p{Jt: c}', "");
Expect(1, 8206, '\p{^Jt: c}', "");
Expect(1, 8206, '\P{Jt: c}', "");
Expect(0, 8206, '\P{^Jt: c}', "");
Expect(1, 8205, '\p{Jt: _C}', "");
Expect(0, 8205, '\p{^Jt: _C}', "");
Expect(0, 8205, '\P{Jt: _C}', "");
Expect(1, 8205, '\P{^Jt: _C}', "");
Expect(0, 8206, '\p{Jt: _C}', "");
Expect(1, 8206, '\p{^Jt: _C}', "");
Expect(1, 8206, '\P{Jt: _C}', "");
Expect(0, 8206, '\P{^Jt: _C}', "");
Error('\p{Is_Joining_Type= -join_CAUSING/a/}');
Error('\P{Is_Joining_Type= -join_CAUSING/a/}');
Expect(1, 8205, '\p{Is_Joining_Type=joincausing}', "");
Expect(0, 8205, '\p{^Is_Joining_Type=joincausing}', "");
Expect(0, 8205, '\P{Is_Joining_Type=joincausing}', "");
Expect(1, 8205, '\P{^Is_Joining_Type=joincausing}', "");
Expect(0, 8206, '\p{Is_Joining_Type=joincausing}', "");
Expect(1, 8206, '\p{^Is_Joining_Type=joincausing}', "");
Expect(1, 8206, '\P{Is_Joining_Type=joincausing}', "");
Expect(0, 8206, '\P{^Is_Joining_Type=joincausing}', "");
Expect(1, 8205, '\p{Is_Joining_Type=	Join_Causing}', "");
Expect(0, 8205, '\p{^Is_Joining_Type=	Join_Causing}', "");
Expect(0, 8205, '\P{Is_Joining_Type=	Join_Causing}', "");
Expect(1, 8205, '\P{^Is_Joining_Type=	Join_Causing}', "");
Expect(0, 8206, '\p{Is_Joining_Type=	Join_Causing}', "");
Expect(1, 8206, '\p{^Is_Joining_Type=	Join_Causing}', "");
Expect(1, 8206, '\P{Is_Joining_Type=	Join_Causing}', "");
Expect(0, 8206, '\P{^Is_Joining_Type=	Join_Causing}', "");
Error('\p{Is_Jt=_-C/a/}');
Error('\P{Is_Jt=_-C/a/}');
Expect(1, 8205, '\p{Is_Jt=c}', "");
Expect(0, 8205, '\p{^Is_Jt=c}', "");
Expect(0, 8205, '\P{Is_Jt=c}', "");
Expect(1, 8205, '\P{^Is_Jt=c}', "");
Expect(0, 8206, '\p{Is_Jt=c}', "");
Expect(1, 8206, '\p{^Is_Jt=c}', "");
Expect(1, 8206, '\P{Is_Jt=c}', "");
Expect(0, 8206, '\P{^Is_Jt=c}', "");
Error('\p{Joining_Type= 	dual_JOINING:=}');
Error('\P{Joining_Type= 	dual_JOINING:=}');
Expect(1, 2217, '\p{Joining_Type=dualjoining}', "");
Expect(0, 2217, '\p{^Joining_Type=dualjoining}', "");
Expect(0, 2217, '\P{Joining_Type=dualjoining}', "");
Expect(1, 2217, '\P{^Joining_Type=dualjoining}', "");
Expect(0, 2218, '\p{Joining_Type=dualjoining}', "");
Expect(1, 2218, '\p{^Joining_Type=dualjoining}', "");
Expect(1, 2218, '\P{Joining_Type=dualjoining}', "");
Expect(0, 2218, '\P{^Joining_Type=dualjoining}', "");
Expect(1, 2217, '\p{Joining_Type:	 -Dual_JOINING}', "");
Expect(0, 2217, '\p{^Joining_Type:	 -Dual_JOINING}', "");
Expect(0, 2217, '\P{Joining_Type:	 -Dual_JOINING}', "");
Expect(1, 2217, '\P{^Joining_Type:	 -Dual_JOINING}', "");
Expect(0, 2218, '\p{Joining_Type:	 -Dual_JOINING}', "");
Expect(1, 2218, '\p{^Joining_Type:	 -Dual_JOINING}', "");
Expect(1, 2218, '\P{Joining_Type:	 -Dual_JOINING}', "");
Expect(0, 2218, '\P{^Joining_Type:	 -Dual_JOINING}', "");
Error('\p{Jt=_:=D}');
Error('\P{Jt=_:=D}');
Expect(1, 2217, '\p{Jt: d}', "");
Expect(0, 2217, '\p{^Jt: d}', "");
Expect(0, 2217, '\P{Jt: d}', "");
Expect(1, 2217, '\P{^Jt: d}', "");
Expect(0, 2218, '\p{Jt: d}', "");
Expect(1, 2218, '\p{^Jt: d}', "");
Expect(1, 2218, '\P{Jt: d}', "");
Expect(0, 2218, '\P{^Jt: d}', "");
Expect(1, 2217, '\p{Jt=_ D}', "");
Expect(0, 2217, '\p{^Jt=_ D}', "");
Expect(0, 2217, '\P{Jt=_ D}', "");
Expect(1, 2217, '\P{^Jt=_ D}', "");
Expect(0, 2218, '\p{Jt=_ D}', "");
Expect(1, 2218, '\p{^Jt=_ D}', "");
Expect(1, 2218, '\P{Jt=_ D}', "");
Expect(0, 2218, '\P{^Jt=_ D}', "");
Error('\p{Is_Joining_Type=:=_DUAL_joining}');
Error('\P{Is_Joining_Type=:=_DUAL_joining}');
Expect(1, 2217, '\p{Is_Joining_Type:   dualjoining}', "");
Expect(0, 2217, '\p{^Is_Joining_Type:   dualjoining}', "");
Expect(0, 2217, '\P{Is_Joining_Type:   dualjoining}', "");
Expect(1, 2217, '\P{^Is_Joining_Type:   dualjoining}', "");
Expect(0, 2218, '\p{Is_Joining_Type:   dualjoining}', "");
Expect(1, 2218, '\p{^Is_Joining_Type:   dualjoining}', "");
Expect(1, 2218, '\P{Is_Joining_Type:   dualjoining}', "");
Expect(0, 2218, '\P{^Is_Joining_Type:   dualjoining}', "");
Expect(1, 2217, '\p{Is_Joining_Type=_-DUAL_Joining}', "");
Expect(0, 2217, '\p{^Is_Joining_Type=_-DUAL_Joining}', "");
Expect(0, 2217, '\P{Is_Joining_Type=_-DUAL_Joining}', "");
Expect(1, 2217, '\P{^Is_Joining_Type=_-DUAL_Joining}', "");
Expect(0, 2218, '\p{Is_Joining_Type=_-DUAL_Joining}', "");
Expect(1, 2218, '\p{^Is_Joining_Type=_-DUAL_Joining}', "");
Expect(1, 2218, '\P{Is_Joining_Type=_-DUAL_Joining}', "");
Expect(0, 2218, '\P{^Is_Joining_Type=_-DUAL_Joining}', "");
Error('\p{Is_Jt=/a/--D}');
Error('\P{Is_Jt=/a/--D}');
Expect(1, 2217, '\p{Is_Jt=d}', "");
Expect(0, 2217, '\p{^Is_Jt=d}', "");
Expect(0, 2217, '\P{Is_Jt=d}', "");
Expect(1, 2217, '\P{^Is_Jt=d}', "");
Expect(0, 2218, '\p{Is_Jt=d}', "");
Expect(1, 2218, '\p{^Is_Jt=d}', "");
Expect(1, 2218, '\P{Is_Jt=d}', "");
Expect(0, 2218, '\P{^Is_Jt=d}', "");
Expect(1, 2217, '\p{Is_Jt=-D}', "");
Expect(0, 2217, '\p{^Is_Jt=-D}', "");
Expect(0, 2217, '\P{Is_Jt=-D}', "");
Expect(1, 2217, '\P{^Is_Jt=-D}', "");
Expect(0, 2218, '\p{Is_Jt=-D}', "");
Expect(1, 2218, '\p{^Is_Jt=-D}', "");
Expect(1, 2218, '\P{Is_Jt=-D}', "");
Expect(0, 2218, '\P{^Is_Jt=-D}', "");
Error('\p{Joining_Type=:= 	Left_Joining}');
Error('\P{Joining_Type=:= 	Left_Joining}');
Expect(0, 1, '\p{Joining_Type=leftjoining}', "");
Expect(1, 1, '\p{^Joining_Type=leftjoining}', "");
Expect(1, 1, '\P{Joining_Type=leftjoining}', "");
Expect(0, 1, '\P{^Joining_Type=leftjoining}', "");
Expect(0, 1, '\p{Joining_Type:   	-Left_joining}', "");
Expect(1, 1, '\p{^Joining_Type:   	-Left_joining}', "");
Expect(1, 1, '\P{Joining_Type:   	-Left_joining}', "");
Expect(0, 1, '\P{^Joining_Type:   	-Left_joining}', "");
Error('\p{Jt=	/a/L}');
Error('\P{Jt=	/a/L}');
Expect(0, 1, '\p{Jt=l}', "");
Expect(1, 1, '\p{^Jt=l}', "");
Expect(1, 1, '\P{Jt=l}', "");
Expect(0, 1, '\P{^Jt=l}', "");
Expect(0, 1, '\p{Jt=-L}', "");
Expect(1, 1, '\p{^Jt=-L}', "");
Expect(1, 1, '\P{Jt=-L}', "");
Expect(0, 1, '\P{^Jt=-L}', "");
Error('\p{Is_Joining_Type=/a/left_JOINING}');
Error('\P{Is_Joining_Type=/a/left_JOINING}');
Expect(0, 1, '\p{Is_Joining_Type=leftjoining}', "");
Expect(1, 1, '\p{^Is_Joining_Type=leftjoining}', "");
Expect(1, 1, '\P{Is_Joining_Type=leftjoining}', "");
Expect(0, 1, '\P{^Is_Joining_Type=leftjoining}', "");
Expect(0, 1, '\p{Is_Joining_Type=-LEFT_Joining}', "");
Expect(1, 1, '\p{^Is_Joining_Type=-LEFT_Joining}', "");
Expect(1, 1, '\P{Is_Joining_Type=-LEFT_Joining}', "");
Expect(0, 1, '\P{^Is_Joining_Type=-LEFT_Joining}', "");
Error('\p{Is_Jt=	:=l}');
Error('\P{Is_Jt=	:=l}');
Expect(0, 1, '\p{Is_Jt=l}', "");
Expect(1, 1, '\p{^Is_Jt=l}', "");
Expect(1, 1, '\P{Is_Jt=l}', "");
Expect(0, 1, '\P{^Is_Jt=l}', "");
Expect(0, 1, '\p{Is_Jt=_L}', "");
Expect(1, 1, '\p{^Is_Jt=_L}', "");
Expect(1, 1, '\P{Is_Jt=_L}', "");
Expect(0, 1, '\P{^Is_Jt=_L}', "");
Error('\p{Joining_Type=	/a/right_JOINING}');
Error('\P{Joining_Type=	/a/right_JOINING}');
Expect(1, 2220, '\p{Joining_Type:   rightjoining}', "");
Expect(0, 2220, '\p{^Joining_Type:   rightjoining}', "");
Expect(0, 2220, '\P{Joining_Type:   rightjoining}', "");
Expect(1, 2220, '\P{^Joining_Type:   rightjoining}', "");
Expect(0, 2221, '\p{Joining_Type:   rightjoining}', "");
Expect(1, 2221, '\p{^Joining_Type:   rightjoining}', "");
Expect(1, 2221, '\P{Joining_Type:   rightjoining}', "");
Expect(0, 2221, '\P{^Joining_Type:   rightjoining}', "");
Expect(1, 2220, '\p{Joining_Type=  right_Joining}', "");
Expect(0, 2220, '\p{^Joining_Type=  right_Joining}', "");
Expect(0, 2220, '\P{Joining_Type=  right_Joining}', "");
Expect(1, 2220, '\P{^Joining_Type=  right_Joining}', "");
Expect(0, 2221, '\p{Joining_Type=  right_Joining}', "");
Expect(1, 2221, '\p{^Joining_Type=  right_Joining}', "");
Expect(1, 2221, '\P{Joining_Type=  right_Joining}', "");
Expect(0, 2221, '\P{^Joining_Type=  right_Joining}', "");
Error('\p{Jt:-R:=}');
Error('\P{Jt:-R:=}');
Expect(1, 2220, '\p{Jt=r}', "");
Expect(0, 2220, '\p{^Jt=r}', "");
Expect(0, 2220, '\P{Jt=r}', "");
Expect(1, 2220, '\P{^Jt=r}', "");
Expect(0, 2221, '\p{Jt=r}', "");
Expect(1, 2221, '\p{^Jt=r}', "");
Expect(1, 2221, '\P{Jt=r}', "");
Expect(0, 2221, '\P{^Jt=r}', "");
Expect(1, 2220, '\p{Jt=	 R}', "");
Expect(0, 2220, '\p{^Jt=	 R}', "");
Expect(0, 2220, '\P{Jt=	 R}', "");
Expect(1, 2220, '\P{^Jt=	 R}', "");
Expect(0, 2221, '\p{Jt=	 R}', "");
Expect(1, 2221, '\p{^Jt=	 R}', "");
Expect(1, 2221, '\P{Jt=	 R}', "");
Expect(0, 2221, '\P{^Jt=	 R}', "");
Error('\p{Is_Joining_Type=:=- Right_JOINING}');
Error('\P{Is_Joining_Type=:=- Right_JOINING}');
Expect(1, 2220, '\p{Is_Joining_Type:rightjoining}', "");
Expect(0, 2220, '\p{^Is_Joining_Type:rightjoining}', "");
Expect(0, 2220, '\P{Is_Joining_Type:rightjoining}', "");
Expect(1, 2220, '\P{^Is_Joining_Type:rightjoining}', "");
Expect(0, 2221, '\p{Is_Joining_Type:rightjoining}', "");
Expect(1, 2221, '\p{^Is_Joining_Type:rightjoining}', "");
Expect(1, 2221, '\P{Is_Joining_Type:rightjoining}', "");
Expect(0, 2221, '\P{^Is_Joining_Type:rightjoining}', "");
Expect(1, 2220, '\p{Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(0, 2220, '\p{^Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(0, 2220, '\P{Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(1, 2220, '\P{^Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(0, 2221, '\p{Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(1, 2221, '\p{^Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(1, 2221, '\P{Is_Joining_Type=	RIGHT_JOINING}', "");
Expect(0, 2221, '\P{^Is_Joining_Type=	RIGHT_JOINING}', "");
Error('\p{Is_Jt=:=-	r}');
Error('\P{Is_Jt=:=-	r}');
Expect(1, 2220, '\p{Is_Jt=r}', "");
Expect(0, 2220, '\p{^Is_Jt=r}', "");
Expect(0, 2220, '\P{Is_Jt=r}', "");
Expect(1, 2220, '\P{^Is_Jt=r}', "");
Expect(0, 2221, '\p{Is_Jt=r}', "");
Expect(1, 2221, '\p{^Is_Jt=r}', "");
Expect(1, 2221, '\P{Is_Jt=r}', "");
Expect(0, 2221, '\P{^Is_Jt=r}', "");
Expect(1, 2220, '\p{Is_Jt=_R}', "");
Expect(0, 2220, '\p{^Is_Jt=_R}', "");
Expect(0, 2220, '\P{Is_Jt=_R}', "");
Expect(1, 2220, '\P{^Is_Jt=_R}', "");
Expect(0, 2221, '\p{Is_Jt=_R}', "");
Expect(1, 2221, '\p{^Is_Jt=_R}', "");
Expect(1, 2221, '\P{Is_Jt=_R}', "");
Expect(0, 2221, '\P{^Is_Jt=_R}', "");
Error('\p{Joining_Type= :=transparent}');
Error('\P{Joining_Type= :=transparent}');
Expect(1, 917999, '\p{Joining_Type=transparent}', "");
Expect(0, 917999, '\p{^Joining_Type=transparent}', "");
Expect(0, 917999, '\P{Joining_Type=transparent}', "");
Expect(1, 917999, '\P{^Joining_Type=transparent}', "");
Expect(0, 918000, '\p{Joining_Type=transparent}', "");
Expect(1, 918000, '\p{^Joining_Type=transparent}', "");
Expect(1, 918000, '\P{Joining_Type=transparent}', "");
Expect(0, 918000, '\P{^Joining_Type=transparent}', "");
Expect(1, 917999, '\p{Joining_Type= _transparent}', "");
Expect(0, 917999, '\p{^Joining_Type= _transparent}', "");
Expect(0, 917999, '\P{Joining_Type= _transparent}', "");
Expect(1, 917999, '\P{^Joining_Type= _transparent}', "");
Expect(0, 918000, '\p{Joining_Type= _transparent}', "");
Expect(1, 918000, '\p{^Joining_Type= _transparent}', "");
Expect(1, 918000, '\P{Joining_Type= _transparent}', "");
Expect(0, 918000, '\P{^Joining_Type= _transparent}', "");
Error('\p{Jt=:=_ T}');
Error('\P{Jt=:=_ T}');
Expect(1, 917999, '\p{Jt=t}', "");
Expect(0, 917999, '\p{^Jt=t}', "");
Expect(0, 917999, '\P{Jt=t}', "");
Expect(1, 917999, '\P{^Jt=t}', "");
Expect(0, 918000, '\p{Jt=t}', "");
Expect(1, 918000, '\p{^Jt=t}', "");
Expect(1, 918000, '\P{Jt=t}', "");
Expect(0, 918000, '\P{^Jt=t}', "");
Expect(1, 917999, '\p{Jt= T}', "");
Expect(0, 917999, '\p{^Jt= T}', "");
Expect(0, 917999, '\P{Jt= T}', "");
Expect(1, 917999, '\P{^Jt= T}', "");
Expect(0, 918000, '\p{Jt= T}', "");
Expect(1, 918000, '\p{^Jt= T}', "");
Expect(1, 918000, '\P{Jt= T}', "");
Expect(0, 918000, '\P{^Jt= T}', "");
Error('\p{Is_Joining_Type= TRANSPARENT/a/}');
Error('\P{Is_Joining_Type= TRANSPARENT/a/}');
Expect(1, 917999, '\p{Is_Joining_Type=transparent}', "");
Expect(0, 917999, '\p{^Is_Joining_Type=transparent}', "");
Expect(0, 917999, '\P{Is_Joining_Type=transparent}', "");
Expect(1, 917999, '\P{^Is_Joining_Type=transparent}', "");
Expect(0, 918000, '\p{Is_Joining_Type=transparent}', "");
Expect(1, 918000, '\p{^Is_Joining_Type=transparent}', "");
Expect(1, 918000, '\P{Is_Joining_Type=transparent}', "");
Expect(0, 918000, '\P{^Is_Joining_Type=transparent}', "");
Expect(1, 917999, '\p{Is_Joining_Type=_-Transparent}', "");
Expect(0, 917999, '\p{^Is_Joining_Type=_-Transparent}', "");
Expect(0, 917999, '\P{Is_Joining_Type=_-Transparent}', "");
Expect(1, 917999, '\P{^Is_Joining_Type=_-Transparent}', "");
Expect(0, 918000, '\p{Is_Joining_Type=_-Transparent}', "");
Expect(1, 918000, '\p{^Is_Joining_Type=_-Transparent}', "");
Expect(1, 918000, '\P{Is_Joining_Type=_-Transparent}', "");
Expect(0, 918000, '\P{^Is_Joining_Type=_-Transparent}', "");
Error('\p{Is_Jt: 	 T:=}');
Error('\P{Is_Jt: 	 T:=}');
Expect(1, 917999, '\p{Is_Jt:	t}', "");
Expect(0, 917999, '\p{^Is_Jt:	t}', "");
Expect(0, 917999, '\P{Is_Jt:	t}', "");
Expect(1, 917999, '\P{^Is_Jt:	t}', "");
Expect(0, 918000, '\p{Is_Jt:	t}', "");
Expect(1, 918000, '\p{^Is_Jt:	t}', "");
Expect(1, 918000, '\P{Is_Jt:	t}', "");
Expect(0, 918000, '\P{^Is_Jt:	t}', "");
Expect(1, 917999, '\p{Is_Jt= _T}', "");
Expect(0, 917999, '\p{^Is_Jt= _T}', "");
Expect(0, 917999, '\P{Is_Jt= _T}', "");
Expect(1, 917999, '\P{^Is_Jt= _T}', "");
Expect(0, 918000, '\p{Is_Jt= _T}', "");
Expect(1, 918000, '\p{^Is_Jt= _T}', "");
Expect(1, 918000, '\P{Is_Jt= _T}', "");
Expect(0, 918000, '\P{^Is_Jt= _T}', "");
Error('\p{Joining_Type=-/a/NON_JOINING}');
Error('\P{Joining_Type=-/a/NON_JOINING}');
Expect(1, 918000, '\p{Joining_Type=nonjoining}', "");
Expect(0, 918000, '\p{^Joining_Type=nonjoining}', "");
Expect(0, 918000, '\P{Joining_Type=nonjoining}', "");
Expect(1, 918000, '\P{^Joining_Type=nonjoining}', "");
Expect(0, 917999, '\p{Joining_Type=nonjoining}', "");
Expect(1, 917999, '\p{^Joining_Type=nonjoining}', "");
Expect(1, 917999, '\P{Joining_Type=nonjoining}', "");
Expect(0, 917999, '\P{^Joining_Type=nonjoining}', "");
Expect(1, 918000, '\p{Joining_Type= _Non_Joining}', "");
Expect(0, 918000, '\p{^Joining_Type= _Non_Joining}', "");
Expect(0, 918000, '\P{Joining_Type= _Non_Joining}', "");
Expect(1, 918000, '\P{^Joining_Type= _Non_Joining}', "");
Expect(0, 917999, '\p{Joining_Type= _Non_Joining}', "");
Expect(1, 917999, '\p{^Joining_Type= _Non_Joining}', "");
Expect(1, 917999, '\P{Joining_Type= _Non_Joining}', "");
Expect(0, 917999, '\P{^Joining_Type= _Non_Joining}', "");
Error('\p{Jt=_:=U}');
Error('\P{Jt=_:=U}');
Expect(1, 918000, '\p{Jt=u}', "");
Expect(0, 918000, '\p{^Jt=u}', "");
Expect(0, 918000, '\P{Jt=u}', "");
Expect(1, 918000, '\P{^Jt=u}', "");
Expect(0, 917999, '\p{Jt=u}', "");
Expect(1, 917999, '\p{^Jt=u}', "");
Expect(1, 917999, '\P{Jt=u}', "");
Expect(0, 917999, '\P{^Jt=u}', "");
Expect(1, 918000, '\p{Jt=_	U}', "");
Expect(0, 918000, '\p{^Jt=_	U}', "");
Expect(0, 918000, '\P{Jt=_	U}', "");
Expect(1, 918000, '\P{^Jt=_	U}', "");
Expect(0, 917999, '\p{Jt=_	U}', "");
Expect(1, 917999, '\p{^Jt=_	U}', "");
Expect(1, 917999, '\P{Jt=_	U}', "");
Expect(0, 917999, '\P{^Jt=_	U}', "");
Error('\p{Is_Joining_Type= /a/non_JOINING}');
Error('\P{Is_Joining_Type= /a/non_JOINING}');
Expect(1, 918000, '\p{Is_Joining_Type=nonjoining}', "");
Expect(0, 918000, '\p{^Is_Joining_Type=nonjoining}', "");
Expect(0, 918000, '\P{Is_Joining_Type=nonjoining}', "");
Expect(1, 918000, '\P{^Is_Joining_Type=nonjoining}', "");
Expect(0, 917999, '\p{Is_Joining_Type=nonjoining}', "");
Expect(1, 917999, '\p{^Is_Joining_Type=nonjoining}', "");
Expect(1, 917999, '\P{Is_Joining_Type=nonjoining}', "");
Expect(0, 917999, '\P{^Is_Joining_Type=nonjoining}', "");
Expect(1, 918000, '\p{Is_Joining_Type=__Non_JOINING}', "");
Expect(0, 918000, '\p{^Is_Joining_Type=__Non_JOINING}', "");
Expect(0, 918000, '\P{Is_Joining_Type=__Non_JOINING}', "");
Expect(1, 918000, '\P{^Is_Joining_Type=__Non_JOINING}', "");
Expect(0, 917999, '\p{Is_Joining_Type=__Non_JOINING}', "");
Expect(1, 917999, '\p{^Is_Joining_Type=__Non_JOINING}', "");
Expect(1, 917999, '\P{Is_Joining_Type=__Non_JOINING}', "");
Expect(0, 917999, '\P{^Is_Joining_Type=__Non_JOINING}', "");
Error('\p{Is_Jt=_:=u}');
Error('\P{Is_Jt=_:=u}');
Expect(1, 918000, '\p{Is_Jt:   u}', "");
Expect(0, 918000, '\p{^Is_Jt:   u}', "");
Expect(0, 918000, '\P{Is_Jt:   u}', "");
Expect(1, 918000, '\P{^Is_Jt:   u}', "");
Expect(0, 917999, '\p{Is_Jt:   u}', "");
Expect(1, 917999, '\p{^Is_Jt:   u}', "");
Expect(1, 917999, '\P{Is_Jt:   u}', "");
Expect(0, 917999, '\P{^Is_Jt:   u}', "");
Expect(1, 918000, '\p{Is_Jt:   -u}', "");
Expect(0, 918000, '\p{^Is_Jt:   -u}', "");
Expect(0, 918000, '\P{Is_Jt:   -u}', "");
Expect(1, 918000, '\P{^Is_Jt:   -u}', "");
Expect(0, 917999, '\p{Is_Jt:   -u}', "");
Expect(1, 917999, '\p{^Is_Jt:   -u}', "");
Expect(1, 917999, '\P{Is_Jt:   -u}', "");
Expect(0, 917999, '\P{^Is_Jt:   -u}', "");
Error('\p{Line_Break=_:=AMBIGUOUS}');
Error('\P{Line_Break=_:=AMBIGUOUS}');
Expect(1, 127386, '\p{Line_Break=ambiguous}', "");
Expect(0, 127386, '\p{^Line_Break=ambiguous}', "");
Expect(0, 127386, '\P{Line_Break=ambiguous}', "");
Expect(1, 127386, '\P{^Line_Break=ambiguous}', "");
Expect(0, 127387, '\p{Line_Break=ambiguous}', "");
Expect(1, 127387, '\p{^Line_Break=ambiguous}', "");
Expect(1, 127387, '\P{Line_Break=ambiguous}', "");
Expect(0, 127387, '\P{^Line_Break=ambiguous}', "");
Expect(1, 127386, '\p{Line_Break=	_ambiguous}', "");
Expect(0, 127386, '\p{^Line_Break=	_ambiguous}', "");
Expect(0, 127386, '\P{Line_Break=	_ambiguous}', "");
Expect(1, 127386, '\P{^Line_Break=	_ambiguous}', "");
Expect(0, 127387, '\p{Line_Break=	_ambiguous}', "");
Expect(1, 127387, '\p{^Line_Break=	_ambiguous}', "");
Expect(1, 127387, '\P{Line_Break=	_ambiguous}', "");
Expect(0, 127387, '\P{^Line_Break=	_ambiguous}', "");
Error('\p{Lb=/a/ 	AI}');
Error('\P{Lb=/a/ 	AI}');
Expect(1, 127386, '\p{Lb=ai}', "");
Expect(0, 127386, '\p{^Lb=ai}', "");
Expect(0, 127386, '\P{Lb=ai}', "");
Expect(1, 127386, '\P{^Lb=ai}', "");
Expect(0, 127387, '\p{Lb=ai}', "");
Expect(1, 127387, '\p{^Lb=ai}', "");
Expect(1, 127387, '\P{Lb=ai}', "");
Expect(0, 127387, '\P{^Lb=ai}', "");
Expect(1, 127386, '\p{Lb=_ ai}', "");
Expect(0, 127386, '\p{^Lb=_ ai}', "");
Expect(0, 127386, '\P{Lb=_ ai}', "");
Expect(1, 127386, '\P{^Lb=_ ai}', "");
Expect(0, 127387, '\p{Lb=_ ai}', "");
Expect(1, 127387, '\p{^Lb=_ ai}', "");
Expect(1, 127387, '\P{Lb=_ ai}', "");
Expect(0, 127387, '\P{^Lb=_ ai}', "");
Error('\p{Is_Line_Break=/a/- Ambiguous}');
Error('\P{Is_Line_Break=/a/- Ambiguous}');
Expect(1, 127386, '\p{Is_Line_Break=ambiguous}', "");
Expect(0, 127386, '\p{^Is_Line_Break=ambiguous}', "");
Expect(0, 127386, '\P{Is_Line_Break=ambiguous}', "");
Expect(1, 127386, '\P{^Is_Line_Break=ambiguous}', "");
Expect(0, 127387, '\p{Is_Line_Break=ambiguous}', "");
Expect(1, 127387, '\p{^Is_Line_Break=ambiguous}', "");
Expect(1, 127387, '\P{Is_Line_Break=ambiguous}', "");
Expect(0, 127387, '\P{^Is_Line_Break=ambiguous}', "");
Expect(1, 127386, '\p{Is_Line_Break=-ambiguous}', "");
Expect(0, 127386, '\p{^Is_Line_Break=-ambiguous}', "");
Expect(0, 127386, '\P{Is_Line_Break=-ambiguous}', "");
Expect(1, 127386, '\P{^Is_Line_Break=-ambiguous}', "");
Expect(0, 127387, '\p{Is_Line_Break=-ambiguous}', "");
Expect(1, 127387, '\p{^Is_Line_Break=-ambiguous}', "");
Expect(1, 127387, '\P{Is_Line_Break=-ambiguous}', "");
Expect(0, 127387, '\P{^Is_Line_Break=-ambiguous}', "");
Error('\p{Is_Lb=	AI/a/}');
Error('\P{Is_Lb=	AI/a/}');
Expect(1, 127386, '\p{Is_Lb=ai}', "");
Expect(0, 127386, '\p{^Is_Lb=ai}', "");
Expect(0, 127386, '\P{Is_Lb=ai}', "");
Expect(1, 127386, '\P{^Is_Lb=ai}', "");
Expect(0, 127387, '\p{Is_Lb=ai}', "");
Expect(1, 127387, '\p{^Is_Lb=ai}', "");
Expect(1, 127387, '\P{Is_Lb=ai}', "");
Expect(0, 127387, '\P{^Is_Lb=ai}', "");
Expect(1, 127386, '\p{Is_Lb=-_ai}', "");
Expect(0, 127386, '\p{^Is_Lb=-_ai}', "");
Expect(0, 127386, '\P{Is_Lb=-_ai}', "");
Expect(1, 127386, '\P{^Is_Lb=-_ai}', "");
Expect(0, 127387, '\p{Is_Lb=-_ai}', "");
Expect(1, 127387, '\p{^Is_Lb=-_ai}', "");
Expect(1, 127387, '\P{Is_Lb=-_ai}', "");
Expect(0, 127387, '\P{^Is_Lb=-_ai}', "");
Error('\p{Line_Break= :=ALPHABETIC}');
Error('\P{Line_Break= :=ALPHABETIC}');
Expect(1, 128883, '\p{Line_Break=alphabetic}', "");
Expect(0, 128883, '\p{^Line_Break=alphabetic}', "");
Expect(0, 128883, '\P{Line_Break=alphabetic}', "");
Expect(1, 128883, '\P{^Line_Break=alphabetic}', "");
Expect(0, 128884, '\p{Line_Break=alphabetic}', "");
Expect(1, 128884, '\p{^Line_Break=alphabetic}', "");
Expect(1, 128884, '\P{Line_Break=alphabetic}', "");
Expect(0, 128884, '\P{^Line_Break=alphabetic}', "");
Expect(1, 128883, '\p{Line_Break=_Alphabetic}', "");
Expect(0, 128883, '\p{^Line_Break=_Alphabetic}', "");
Expect(0, 128883, '\P{Line_Break=_Alphabetic}', "");
Expect(1, 128883, '\P{^Line_Break=_Alphabetic}', "");
Expect(0, 128884, '\p{Line_Break=_Alphabetic}', "");
Expect(1, 128884, '\p{^Line_Break=_Alphabetic}', "");
Expect(1, 128884, '\P{Line_Break=_Alphabetic}', "");
Expect(0, 128884, '\P{^Line_Break=_Alphabetic}', "");
Error('\p{Lb=	_AL/a/}');
Error('\P{Lb=	_AL/a/}');
Expect(1, 128883, '\p{Lb: al}', "");
Expect(0, 128883, '\p{^Lb: al}', "");
Expect(0, 128883, '\P{Lb: al}', "");
Expect(1, 128883, '\P{^Lb: al}', "");
Expect(0, 128884, '\p{Lb: al}', "");
Expect(1, 128884, '\p{^Lb: al}', "");
Expect(1, 128884, '\P{Lb: al}', "");
Expect(0, 128884, '\P{^Lb: al}', "");
Expect(1, 128883, '\p{Lb=	-al}', "");
Expect(0, 128883, '\p{^Lb=	-al}', "");
Expect(0, 128883, '\P{Lb=	-al}', "");
Expect(1, 128883, '\P{^Lb=	-al}', "");
Expect(0, 128884, '\p{Lb=	-al}', "");
Expect(1, 128884, '\p{^Lb=	-al}', "");
Expect(1, 128884, '\P{Lb=	-al}', "");
Expect(0, 128884, '\P{^Lb=	-al}', "");
Error('\p{Is_Line_Break=/a/ Alphabetic}');
Error('\P{Is_Line_Break=/a/ Alphabetic}');
Expect(1, 128883, '\p{Is_Line_Break=alphabetic}', "");
Expect(0, 128883, '\p{^Is_Line_Break=alphabetic}', "");
Expect(0, 128883, '\P{Is_Line_Break=alphabetic}', "");
Expect(1, 128883, '\P{^Is_Line_Break=alphabetic}', "");
Expect(0, 128884, '\p{Is_Line_Break=alphabetic}', "");
Expect(1, 128884, '\p{^Is_Line_Break=alphabetic}', "");
Expect(1, 128884, '\P{Is_Line_Break=alphabetic}', "");
Expect(0, 128884, '\P{^Is_Line_Break=alphabetic}', "");
Expect(1, 128883, '\p{Is_Line_Break=-_Alphabetic}', "");
Expect(0, 128883, '\p{^Is_Line_Break=-_Alphabetic}', "");
Expect(0, 128883, '\P{Is_Line_Break=-_Alphabetic}', "");
Expect(1, 128883, '\P{^Is_Line_Break=-_Alphabetic}', "");
Expect(0, 128884, '\p{Is_Line_Break=-_Alphabetic}', "");
Expect(1, 128884, '\p{^Is_Line_Break=-_Alphabetic}', "");
Expect(1, 128884, '\P{Is_Line_Break=-_Alphabetic}', "");
Expect(0, 128884, '\P{^Is_Line_Break=-_Alphabetic}', "");
Error('\p{Is_Lb=	:=AL}');
Error('\P{Is_Lb=	:=AL}');
Expect(1, 128883, '\p{Is_Lb=al}', "");
Expect(0, 128883, '\p{^Is_Lb=al}', "");
Expect(0, 128883, '\P{Is_Lb=al}', "");
Expect(1, 128883, '\P{^Is_Lb=al}', "");
Expect(0, 128884, '\p{Is_Lb=al}', "");
Expect(1, 128884, '\p{^Is_Lb=al}', "");
Expect(1, 128884, '\P{Is_Lb=al}', "");
Expect(0, 128884, '\P{^Is_Lb=al}', "");
Expect(1, 128883, '\p{Is_Lb=-_AL}', "");
Expect(0, 128883, '\p{^Is_Lb=-_AL}', "");
Expect(0, 128883, '\P{Is_Lb=-_AL}', "");
Expect(1, 128883, '\P{^Is_Lb=-_AL}', "");
Expect(0, 128884, '\p{Is_Lb=-_AL}', "");
Expect(1, 128884, '\p{^Is_Lb=-_AL}', "");
Expect(1, 128884, '\P{Is_Lb=-_AL}', "");
Expect(0, 128884, '\P{^Is_Lb=-_AL}', "");
Error('\p{Line_Break=_/a/BREAK_BOTH}');
Error('\P{Line_Break=_/a/BREAK_BOTH}');
Expect(1, 11835, '\p{Line_Break=breakboth}', "");
Expect(0, 11835, '\p{^Line_Break=breakboth}', "");
Expect(0, 11835, '\P{Line_Break=breakboth}', "");
Expect(1, 11835, '\P{^Line_Break=breakboth}', "");
Expect(0, 11836, '\p{Line_Break=breakboth}', "");
Expect(1, 11836, '\p{^Line_Break=breakboth}', "");
Expect(1, 11836, '\P{Line_Break=breakboth}', "");
Expect(0, 11836, '\P{^Line_Break=breakboth}', "");
Expect(1, 11835, '\p{Line_Break=-Break_Both}', "");
Expect(0, 11835, '\p{^Line_Break=-Break_Both}', "");
Expect(0, 11835, '\P{Line_Break=-Break_Both}', "");
Expect(1, 11835, '\P{^Line_Break=-Break_Both}', "");
Expect(0, 11836, '\p{Line_Break=-Break_Both}', "");
Expect(1, 11836, '\p{^Line_Break=-Break_Both}', "");
Expect(1, 11836, '\P{Line_Break=-Break_Both}', "");
Expect(0, 11836, '\P{^Line_Break=-Break_Both}', "");
Error('\p{Lb=:=-	B2}');
Error('\P{Lb=:=-	B2}');
Expect(1, 11835, '\p{Lb=b2}', "");
Expect(0, 11835, '\p{^Lb=b2}', "");
Expect(0, 11835, '\P{Lb=b2}', "");
Expect(1, 11835, '\P{^Lb=b2}', "");
Expect(0, 11836, '\p{Lb=b2}', "");
Expect(1, 11836, '\p{^Lb=b2}', "");
Expect(1, 11836, '\P{Lb=b2}', "");
Expect(0, 11836, '\P{^Lb=b2}', "");
Expect(1, 11835, '\p{Lb= 	B2}', "");
Expect(0, 11835, '\p{^Lb= 	B2}', "");
Expect(0, 11835, '\P{Lb= 	B2}', "");
Expect(1, 11835, '\P{^Lb= 	B2}', "");
Expect(0, 11836, '\p{Lb= 	B2}', "");
Expect(1, 11836, '\p{^Lb= 	B2}', "");
Expect(1, 11836, '\P{Lb= 	B2}', "");
Expect(0, 11836, '\P{^Lb= 	B2}', "");
Error('\p{Is_Line_Break=:=__Break_Both}');
Error('\P{Is_Line_Break=:=__Break_Both}');
Expect(1, 11835, '\p{Is_Line_Break=breakboth}', "");
Expect(0, 11835, '\p{^Is_Line_Break=breakboth}', "");
Expect(0, 11835, '\P{Is_Line_Break=breakboth}', "");
Expect(1, 11835, '\P{^Is_Line_Break=breakboth}', "");
Expect(0, 11836, '\p{Is_Line_Break=breakboth}', "");
Expect(1, 11836, '\p{^Is_Line_Break=breakboth}', "");
Expect(1, 11836, '\P{Is_Line_Break=breakboth}', "");
Expect(0, 11836, '\P{^Is_Line_Break=breakboth}', "");
Expect(1, 11835, '\p{Is_Line_Break= _Break_Both}', "");
Expect(0, 11835, '\p{^Is_Line_Break= _Break_Both}', "");
Expect(0, 11835, '\P{Is_Line_Break= _Break_Both}', "");
Expect(1, 11835, '\P{^Is_Line_Break= _Break_Both}', "");
Expect(0, 11836, '\p{Is_Line_Break= _Break_Both}', "");
Expect(1, 11836, '\p{^Is_Line_Break= _Break_Both}', "");
Expect(1, 11836, '\P{Is_Line_Break= _Break_Both}', "");
Expect(0, 11836, '\P{^Is_Line_Break= _Break_Both}', "");
Error('\p{Is_Lb=_	B2:=}');
Error('\P{Is_Lb=_	B2:=}');
Expect(1, 11835, '\p{Is_Lb=b2}', "");
Expect(0, 11835, '\p{^Is_Lb=b2}', "");
Expect(0, 11835, '\P{Is_Lb=b2}', "");
Expect(1, 11835, '\P{^Is_Lb=b2}', "");
Expect(0, 11836, '\p{Is_Lb=b2}', "");
Expect(1, 11836, '\p{^Is_Lb=b2}', "");
Expect(1, 11836, '\P{Is_Lb=b2}', "");
Expect(0, 11836, '\P{^Is_Lb=b2}', "");
Expect(1, 11835, '\p{Is_Lb=-b2}', "");
Expect(0, 11835, '\p{^Is_Lb=-b2}', "");
Expect(0, 11835, '\P{Is_Lb=-b2}', "");
Expect(1, 11835, '\P{^Is_Lb=-b2}', "");
Expect(0, 11836, '\p{Is_Lb=-b2}', "");
Expect(1, 11836, '\p{^Is_Lb=-b2}', "");
Expect(1, 11836, '\P{Is_Lb=-b2}', "");
Expect(0, 11836, '\P{^Is_Lb=-b2}', "");
Error('\p{Line_Break:	:=_	Break_after}');
Error('\P{Line_Break:	:=_	Break_after}');
Expect(1, 74867, '\p{Line_Break=breakafter}', "");
Expect(0, 74867, '\p{^Line_Break=breakafter}', "");
Expect(0, 74867, '\P{Line_Break=breakafter}', "");
Expect(1, 74867, '\P{^Line_Break=breakafter}', "");
Expect(0, 74868, '\p{Line_Break=breakafter}', "");
Expect(1, 74868, '\p{^Line_Break=breakafter}', "");
Expect(1, 74868, '\P{Line_Break=breakafter}', "");
Expect(0, 74868, '\P{^Line_Break=breakafter}', "");
Expect(1, 74867, '\p{Line_Break=- Break_After}', "");
Expect(0, 74867, '\p{^Line_Break=- Break_After}', "");
Expect(0, 74867, '\P{Line_Break=- Break_After}', "");
Expect(1, 74867, '\P{^Line_Break=- Break_After}', "");
Expect(0, 74868, '\p{Line_Break=- Break_After}', "");
Expect(1, 74868, '\p{^Line_Break=- Break_After}', "");
Expect(1, 74868, '\P{Line_Break=- Break_After}', "");
Expect(0, 74868, '\P{^Line_Break=- Break_After}', "");
Error('\p{Lb=:=	 BA}');
Error('\P{Lb=:=	 BA}');
Expect(1, 74867, '\p{Lb=ba}', "");
Expect(0, 74867, '\p{^Lb=ba}', "");
Expect(0, 74867, '\P{Lb=ba}', "");
Expect(1, 74867, '\P{^Lb=ba}', "");
Expect(0, 74868, '\p{Lb=ba}', "");
Expect(1, 74868, '\p{^Lb=ba}', "");
Expect(1, 74868, '\P{Lb=ba}', "");
Expect(0, 74868, '\P{^Lb=ba}', "");
Expect(1, 74867, '\p{Lb=_ba}', "");
Expect(0, 74867, '\p{^Lb=_ba}', "");
Expect(0, 74867, '\P{Lb=_ba}', "");
Expect(1, 74867, '\P{^Lb=_ba}', "");
Expect(0, 74868, '\p{Lb=_ba}', "");
Expect(1, 74868, '\p{^Lb=_ba}', "");
Expect(1, 74868, '\P{Lb=_ba}', "");
Expect(0, 74868, '\P{^Lb=_ba}', "");
Error('\p{Is_Line_Break=/a/-break_after}');
Error('\P{Is_Line_Break=/a/-break_after}');
Expect(1, 74867, '\p{Is_Line_Break=breakafter}', "");
Expect(0, 74867, '\p{^Is_Line_Break=breakafter}', "");
Expect(0, 74867, '\P{Is_Line_Break=breakafter}', "");
Expect(1, 74867, '\P{^Is_Line_Break=breakafter}', "");
Expect(0, 74868, '\p{Is_Line_Break=breakafter}', "");
Expect(1, 74868, '\p{^Is_Line_Break=breakafter}', "");
Expect(1, 74868, '\P{Is_Line_Break=breakafter}', "");
Expect(0, 74868, '\P{^Is_Line_Break=breakafter}', "");
Expect(1, 74867, '\p{Is_Line_Break=_Break_After}', "");
Expect(0, 74867, '\p{^Is_Line_Break=_Break_After}', "");
Expect(0, 74867, '\P{Is_Line_Break=_Break_After}', "");
Expect(1, 74867, '\P{^Is_Line_Break=_Break_After}', "");
Expect(0, 74868, '\p{Is_Line_Break=_Break_After}', "");
Expect(1, 74868, '\p{^Is_Line_Break=_Break_After}', "");
Expect(1, 74868, '\P{Is_Line_Break=_Break_After}', "");
Expect(0, 74868, '\P{^Is_Line_Break=_Break_After}', "");
Error('\p{Is_Lb=	BA:=}');
Error('\P{Is_Lb=	BA:=}');
Expect(1, 74867, '\p{Is_Lb=ba}', "");
Expect(0, 74867, '\p{^Is_Lb=ba}', "");
Expect(0, 74867, '\P{Is_Lb=ba}', "");
Expect(1, 74867, '\P{^Is_Lb=ba}', "");
Expect(0, 74868, '\p{Is_Lb=ba}', "");
Expect(1, 74868, '\p{^Is_Lb=ba}', "");
Expect(1, 74868, '\P{Is_Lb=ba}', "");
Expect(0, 74868, '\P{^Is_Lb=ba}', "");
Expect(1, 74867, '\p{Is_Lb=	BA}', "");
Expect(0, 74867, '\p{^Is_Lb=	BA}', "");
Expect(0, 74867, '\P{Is_Lb=	BA}', "");
Expect(1, 74867, '\P{^Is_Lb=	BA}', "");
Expect(0, 74868, '\p{Is_Lb=	BA}', "");
Expect(1, 74868, '\p{^Is_Lb=	BA}', "");
Expect(1, 74868, '\P{Is_Lb=	BA}', "");
Expect(0, 74868, '\P{^Is_Lb=	BA}', "");
Error('\p{Line_Break= :=Break_before}');
Error('\P{Line_Break= :=Break_before}');
Expect(1, 43125, '\p{Line_Break:	breakbefore}', "");
Expect(0, 43125, '\p{^Line_Break:	breakbefore}', "");
Expect(0, 43125, '\P{Line_Break:	breakbefore}', "");
Expect(1, 43125, '\P{^Line_Break:	breakbefore}', "");
Expect(0, 43126, '\p{Line_Break:	breakbefore}', "");
Expect(1, 43126, '\p{^Line_Break:	breakbefore}', "");
Expect(1, 43126, '\P{Line_Break:	breakbefore}', "");
Expect(0, 43126, '\P{^Line_Break:	breakbefore}', "");
Expect(1, 43125, '\p{Line_Break=_Break_BEFORE}', "");
Expect(0, 43125, '\p{^Line_Break=_Break_BEFORE}', "");
Expect(0, 43125, '\P{Line_Break=_Break_BEFORE}', "");
Expect(1, 43125, '\P{^Line_Break=_Break_BEFORE}', "");
Expect(0, 43126, '\p{Line_Break=_Break_BEFORE}', "");
Expect(1, 43126, '\p{^Line_Break=_Break_BEFORE}', "");
Expect(1, 43126, '\P{Line_Break=_Break_BEFORE}', "");
Expect(0, 43126, '\P{^Line_Break=_Break_BEFORE}', "");
Error('\p{Lb=/a/		BB}');
Error('\P{Lb=/a/		BB}');
Expect(1, 43125, '\p{Lb=bb}', "");
Expect(0, 43125, '\p{^Lb=bb}', "");
Expect(0, 43125, '\P{Lb=bb}', "");
Expect(1, 43125, '\P{^Lb=bb}', "");
Expect(0, 43126, '\p{Lb=bb}', "");
Expect(1, 43126, '\p{^Lb=bb}', "");
Expect(1, 43126, '\P{Lb=bb}', "");
Expect(0, 43126, '\P{^Lb=bb}', "");
Expect(1, 43125, '\p{Lb:   	_BB}', "");
Expect(0, 43125, '\p{^Lb:   	_BB}', "");
Expect(0, 43125, '\P{Lb:   	_BB}', "");
Expect(1, 43125, '\P{^Lb:   	_BB}', "");
Expect(0, 43126, '\p{Lb:   	_BB}', "");
Expect(1, 43126, '\p{^Lb:   	_BB}', "");
Expect(1, 43126, '\P{Lb:   	_BB}', "");
Expect(0, 43126, '\P{^Lb:   	_BB}', "");
Error('\p{Is_Line_Break=-_BREAK_before:=}');
Error('\P{Is_Line_Break=-_BREAK_before:=}');
Expect(1, 43125, '\p{Is_Line_Break=breakbefore}', "");
Expect(0, 43125, '\p{^Is_Line_Break=breakbefore}', "");
Expect(0, 43125, '\P{Is_Line_Break=breakbefore}', "");
Expect(1, 43125, '\P{^Is_Line_Break=breakbefore}', "");
Expect(0, 43126, '\p{Is_Line_Break=breakbefore}', "");
Expect(1, 43126, '\p{^Is_Line_Break=breakbefore}', "");
Expect(1, 43126, '\P{Is_Line_Break=breakbefore}', "");
Expect(0, 43126, '\P{^Is_Line_Break=breakbefore}', "");
Expect(1, 43125, '\p{Is_Line_Break=__break_Before}', "");
Expect(0, 43125, '\p{^Is_Line_Break=__break_Before}', "");
Expect(0, 43125, '\P{Is_Line_Break=__break_Before}', "");
Expect(1, 43125, '\P{^Is_Line_Break=__break_Before}', "");
Expect(0, 43126, '\p{Is_Line_Break=__break_Before}', "");
Expect(1, 43126, '\p{^Is_Line_Break=__break_Before}', "");
Expect(1, 43126, '\P{Is_Line_Break=__break_Before}', "");
Expect(0, 43126, '\P{^Is_Line_Break=__break_Before}', "");
Error('\p{Is_Lb= /a/bb}');
Error('\P{Is_Lb= /a/bb}');
Expect(1, 43125, '\p{Is_Lb=bb}', "");
Expect(0, 43125, '\p{^Is_Lb=bb}', "");
Expect(0, 43125, '\P{Is_Lb=bb}', "");
Expect(1, 43125, '\P{^Is_Lb=bb}', "");
Expect(0, 43126, '\p{Is_Lb=bb}', "");
Expect(1, 43126, '\p{^Is_Lb=bb}', "");
Expect(1, 43126, '\P{Is_Lb=bb}', "");
Expect(0, 43126, '\P{^Is_Lb=bb}', "");
Expect(1, 43125, '\p{Is_Lb=_	bb}', "");
Expect(0, 43125, '\p{^Is_Lb=_	bb}', "");
Expect(0, 43125, '\P{Is_Lb=_	bb}', "");
Expect(1, 43125, '\P{^Is_Lb=_	bb}', "");
Expect(0, 43126, '\p{Is_Lb=_	bb}', "");
Expect(1, 43126, '\p{^Is_Lb=_	bb}', "");
Expect(1, 43126, '\P{Is_Lb=_	bb}', "");
Expect(0, 43126, '\P{^Is_Lb=_	bb}', "");
Error('\p{Line_Break=/a/_	Mandatory_Break}');
Error('\P{Line_Break=/a/_	Mandatory_Break}');
Expect(1, 8233, '\p{Line_Break=mandatorybreak}', "");
Expect(0, 8233, '\p{^Line_Break=mandatorybreak}', "");
Expect(0, 8233, '\P{Line_Break=mandatorybreak}', "");
Expect(1, 8233, '\P{^Line_Break=mandatorybreak}', "");
Expect(0, 8234, '\p{Line_Break=mandatorybreak}', "");
Expect(1, 8234, '\p{^Line_Break=mandatorybreak}', "");
Expect(1, 8234, '\P{Line_Break=mandatorybreak}', "");
Expect(0, 8234, '\P{^Line_Break=mandatorybreak}', "");
Expect(1, 8233, '\p{Line_Break=	 mandatory_BREAK}', "");
Expect(0, 8233, '\p{^Line_Break=	 mandatory_BREAK}', "");
Expect(0, 8233, '\P{Line_Break=	 mandatory_BREAK}', "");
Expect(1, 8233, '\P{^Line_Break=	 mandatory_BREAK}', "");
Expect(0, 8234, '\p{Line_Break=	 mandatory_BREAK}', "");
Expect(1, 8234, '\p{^Line_Break=	 mandatory_BREAK}', "");
Expect(1, 8234, '\P{Line_Break=	 mandatory_BREAK}', "");
Expect(0, 8234, '\P{^Line_Break=	 mandatory_BREAK}', "");
Error('\p{Lb=/a/BK}');
Error('\P{Lb=/a/BK}');
Expect(1, 8233, '\p{Lb=bk}', "");
Expect(0, 8233, '\p{^Lb=bk}', "");
Expect(0, 8233, '\P{Lb=bk}', "");
Expect(1, 8233, '\P{^Lb=bk}', "");
Expect(0, 8234, '\p{Lb=bk}', "");
Expect(1, 8234, '\p{^Lb=bk}', "");
Expect(1, 8234, '\P{Lb=bk}', "");
Expect(0, 8234, '\P{^Lb=bk}', "");
Expect(1, 8233, '\p{Lb=BK}', "");
Expect(0, 8233, '\p{^Lb=BK}', "");
Expect(0, 8233, '\P{Lb=BK}', "");
Expect(1, 8233, '\P{^Lb=BK}', "");
Expect(0, 8234, '\p{Lb=BK}', "");
Expect(1, 8234, '\p{^Lb=BK}', "");
Expect(1, 8234, '\P{Lb=BK}', "");
Expect(0, 8234, '\P{^Lb=BK}', "");
Error('\p{Is_Line_Break=-/a/Mandatory_break}');
Error('\P{Is_Line_Break=-/a/Mandatory_break}');
Expect(1, 8233, '\p{Is_Line_Break=mandatorybreak}', "");
Expect(0, 8233, '\p{^Is_Line_Break=mandatorybreak}', "");
Expect(0, 8233, '\P{Is_Line_Break=mandatorybreak}', "");
Expect(1, 8233, '\P{^Is_Line_Break=mandatorybreak}', "");
Expect(0, 8234, '\p{Is_Line_Break=mandatorybreak}', "");
Expect(1, 8234, '\p{^Is_Line_Break=mandatorybreak}', "");
Expect(1, 8234, '\P{Is_Line_Break=mandatorybreak}', "");
Expect(0, 8234, '\P{^Is_Line_Break=mandatorybreak}', "");
Expect(1, 8233, '\p{Is_Line_Break=-mandatory_break}', "");
Expect(0, 8233, '\p{^Is_Line_Break=-mandatory_break}', "");
Expect(0, 8233, '\P{Is_Line_Break=-mandatory_break}', "");
Expect(1, 8233, '\P{^Is_Line_Break=-mandatory_break}', "");
Expect(0, 8234, '\p{Is_Line_Break=-mandatory_break}', "");
Expect(1, 8234, '\p{^Is_Line_Break=-mandatory_break}', "");
Expect(1, 8234, '\P{Is_Line_Break=-mandatory_break}', "");
Expect(0, 8234, '\P{^Is_Line_Break=-mandatory_break}', "");
Error('\p{Is_Lb=/a/ BK}');
Error('\P{Is_Lb=/a/ BK}');
Expect(1, 8233, '\p{Is_Lb=bk}', "");
Expect(0, 8233, '\p{^Is_Lb=bk}', "");
Expect(0, 8233, '\P{Is_Lb=bk}', "");
Expect(1, 8233, '\P{^Is_Lb=bk}', "");
Expect(0, 8234, '\p{Is_Lb=bk}', "");
Expect(1, 8234, '\p{^Is_Lb=bk}', "");
Expect(1, 8234, '\P{Is_Lb=bk}', "");
Expect(0, 8234, '\P{^Is_Lb=bk}', "");
Expect(1, 8233, '\p{Is_Lb=	 BK}', "");
Expect(0, 8233, '\p{^Is_Lb=	 BK}', "");
Expect(0, 8233, '\P{Is_Lb=	 BK}', "");
Expect(1, 8233, '\P{^Is_Lb=	 BK}', "");
Expect(0, 8234, '\p{Is_Lb=	 BK}', "");
Expect(1, 8234, '\p{^Is_Lb=	 BK}', "");
Expect(1, 8234, '\P{Is_Lb=	 BK}', "");
Expect(0, 8234, '\P{^Is_Lb=	 BK}', "");
Error('\p{Line_Break=-CONTINGENT_Break/a/}');
Error('\P{Line_Break=-CONTINGENT_Break/a/}');
Expect(1, 65532, '\p{Line_Break=contingentbreak}', "");
Expect(0, 65532, '\p{^Line_Break=contingentbreak}', "");
Expect(0, 65532, '\P{Line_Break=contingentbreak}', "");
Expect(1, 65532, '\P{^Line_Break=contingentbreak}', "");
Expect(0, 65533, '\p{Line_Break=contingentbreak}', "");
Expect(1, 65533, '\p{^Line_Break=contingentbreak}', "");
Expect(1, 65533, '\P{Line_Break=contingentbreak}', "");
Expect(0, 65533, '\P{^Line_Break=contingentbreak}', "");
Expect(1, 65532, '\p{Line_Break=- CONTINGENT_Break}', "");
Expect(0, 65532, '\p{^Line_Break=- CONTINGENT_Break}', "");
Expect(0, 65532, '\P{Line_Break=- CONTINGENT_Break}', "");
Expect(1, 65532, '\P{^Line_Break=- CONTINGENT_Break}', "");
Expect(0, 65533, '\p{Line_Break=- CONTINGENT_Break}', "");
Expect(1, 65533, '\p{^Line_Break=- CONTINGENT_Break}', "");
Expect(1, 65533, '\P{Line_Break=- CONTINGENT_Break}', "");
Expect(0, 65533, '\P{^Line_Break=- CONTINGENT_Break}', "");
Error('\p{Lb= /a/cb}');
Error('\P{Lb= /a/cb}');
Expect(1, 65532, '\p{Lb=cb}', "");
Expect(0, 65532, '\p{^Lb=cb}', "");
Expect(0, 65532, '\P{Lb=cb}', "");
Expect(1, 65532, '\P{^Lb=cb}', "");
Expect(0, 65533, '\p{Lb=cb}', "");
Expect(1, 65533, '\p{^Lb=cb}', "");
Expect(1, 65533, '\P{Lb=cb}', "");
Expect(0, 65533, '\P{^Lb=cb}', "");
Expect(1, 65532, '\p{Lb=	cb}', "");
Expect(0, 65532, '\p{^Lb=	cb}', "");
Expect(0, 65532, '\P{Lb=	cb}', "");
Expect(1, 65532, '\P{^Lb=	cb}', "");
Expect(0, 65533, '\p{Lb=	cb}', "");
Expect(1, 65533, '\p{^Lb=	cb}', "");
Expect(1, 65533, '\P{Lb=	cb}', "");
Expect(0, 65533, '\P{^Lb=	cb}', "");
Error('\p{Is_Line_Break= :=Contingent_break}');
Error('\P{Is_Line_Break= :=Contingent_break}');
Expect(1, 65532, '\p{Is_Line_Break=contingentbreak}', "");
Expect(0, 65532, '\p{^Is_Line_Break=contingentbreak}', "");
Expect(0, 65532, '\P{Is_Line_Break=contingentbreak}', "");
Expect(1, 65532, '\P{^Is_Line_Break=contingentbreak}', "");
Expect(0, 65533, '\p{Is_Line_Break=contingentbreak}', "");
Expect(1, 65533, '\p{^Is_Line_Break=contingentbreak}', "");
Expect(1, 65533, '\P{Is_Line_Break=contingentbreak}', "");
Expect(0, 65533, '\P{^Is_Line_Break=contingentbreak}', "");
Expect(1, 65532, '\p{Is_Line_Break=Contingent_BREAK}', "");
Expect(0, 65532, '\p{^Is_Line_Break=Contingent_BREAK}', "");
Expect(0, 65532, '\P{Is_Line_Break=Contingent_BREAK}', "");
Expect(1, 65532, '\P{^Is_Line_Break=Contingent_BREAK}', "");
Expect(0, 65533, '\p{Is_Line_Break=Contingent_BREAK}', "");
Expect(1, 65533, '\p{^Is_Line_Break=Contingent_BREAK}', "");
Expect(1, 65533, '\P{Is_Line_Break=Contingent_BREAK}', "");
Expect(0, 65533, '\P{^Is_Line_Break=Contingent_BREAK}', "");
Error('\p{Is_Lb=--CB:=}');
Error('\P{Is_Lb=--CB:=}');
Expect(1, 65532, '\p{Is_Lb: cb}', "");
Expect(0, 65532, '\p{^Is_Lb: cb}', "");
Expect(0, 65532, '\P{Is_Lb: cb}', "");
Expect(1, 65532, '\P{^Is_Lb: cb}', "");
Expect(0, 65533, '\p{Is_Lb: cb}', "");
Expect(1, 65533, '\p{^Is_Lb: cb}', "");
Expect(1, 65533, '\P{Is_Lb: cb}', "");
Expect(0, 65533, '\P{^Is_Lb: cb}', "");
Expect(1, 65532, '\p{Is_Lb=--CB}', "");
Expect(0, 65532, '\p{^Is_Lb=--CB}', "");
Expect(0, 65532, '\P{Is_Lb=--CB}', "");
Expect(1, 65532, '\P{^Is_Lb=--CB}', "");
Expect(0, 65533, '\p{Is_Lb=--CB}', "");
Expect(1, 65533, '\p{^Is_Lb=--CB}', "");
Expect(1, 65533, '\P{Is_Lb=--CB}', "");
Expect(0, 65533, '\P{^Is_Lb=--CB}', "");
Error('\p{Line_Break=:=- Conditional_JAPANESE_starter}');
Error('\P{Line_Break=:=- Conditional_JAPANESE_starter}');
Expect(1, 65392, '\p{Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65392, '\p{^Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65392, '\P{Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65392, '\P{^Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65393, '\p{Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65393, '\p{^Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65393, '\P{Line_Break=conditionaljapanesestarter}', "");
Expect(0, 65393, '\P{^Line_Break=conditionaljapanesestarter}', "");
Expect(1, 65392, '\p{Line_Break=-_Conditional_japanese_Starter}', "");
Expect(0, 65392, '\p{^Line_Break=-_Conditional_japanese_Starter}', "");
Expect(0, 65392, '\P{Line_Break=-_Conditional_japanese_Starter}', "");
Expect(1, 65392, '\P{^Line_Break=-_Conditional_japanese_Starter}', "");
Expect(0, 65393, '\p{Line_Break=-_Conditional_japanese_Starter}', "");
Expect(1, 65393, '\p{^Line_Break=-_Conditional_japanese_Starter}', "");
Expect(1, 65393, '\P{Line_Break=-_Conditional_japanese_Starter}', "");
Expect(0, 65393, '\P{^Line_Break=-_Conditional_japanese_Starter}', "");
Error('\p{Lb=:=  CJ}');
Error('\P{Lb=:=  CJ}');
Expect(1, 65392, '\p{Lb=cj}', "");
Expect(0, 65392, '\p{^Lb=cj}', "");
Expect(0, 65392, '\P{Lb=cj}', "");
Expect(1, 65392, '\P{^Lb=cj}', "");
Expect(0, 65393, '\p{Lb=cj}', "");
Expect(1, 65393, '\p{^Lb=cj}', "");
Expect(1, 65393, '\P{Lb=cj}', "");
Expect(0, 65393, '\P{^Lb=cj}', "");
Expect(1, 65392, '\p{Lb:   -	CJ}', "");
Expect(0, 65392, '\p{^Lb:   -	CJ}', "");
Expect(0, 65392, '\P{Lb:   -	CJ}', "");
Expect(1, 65392, '\P{^Lb:   -	CJ}', "");
Expect(0, 65393, '\p{Lb:   -	CJ}', "");
Expect(1, 65393, '\p{^Lb:   -	CJ}', "");
Expect(1, 65393, '\P{Lb:   -	CJ}', "");
Expect(0, 65393, '\P{^Lb:   -	CJ}', "");
Error('\p{Is_Line_Break=- conditional_JAPANESE_STARTER:=}');
Error('\P{Is_Line_Break=- conditional_JAPANESE_STARTER:=}');
Expect(1, 65392, '\p{Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(0, 65392, '\p{^Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(0, 65392, '\P{Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(1, 65392, '\P{^Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(0, 65393, '\p{Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(1, 65393, '\p{^Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(1, 65393, '\P{Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(0, 65393, '\P{^Is_Line_Break:   conditionaljapanesestarter}', "");
Expect(1, 65392, '\p{Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(0, 65392, '\p{^Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(0, 65392, '\P{Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(1, 65392, '\P{^Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(0, 65393, '\p{Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(1, 65393, '\p{^Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(1, 65393, '\P{Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Expect(0, 65393, '\P{^Is_Line_Break=_ Conditional_Japanese_Starter}', "");
Error('\p{Is_Lb= /a/cj}');
Error('\P{Is_Lb= /a/cj}');
Expect(1, 65392, '\p{Is_Lb=cj}', "");
Expect(0, 65392, '\p{^Is_Lb=cj}', "");
Expect(0, 65392, '\P{Is_Lb=cj}', "");
Expect(1, 65392, '\P{^Is_Lb=cj}', "");
Expect(0, 65393, '\p{Is_Lb=cj}', "");
Expect(1, 65393, '\p{^Is_Lb=cj}', "");
Expect(1, 65393, '\P{Is_Lb=cj}', "");
Expect(0, 65393, '\P{^Is_Lb=cj}', "");
Expect(1, 65392, '\p{Is_Lb= _CJ}', "");
Expect(0, 65392, '\p{^Is_Lb= _CJ}', "");
Expect(0, 65392, '\P{Is_Lb= _CJ}', "");
Expect(1, 65392, '\P{^Is_Lb= _CJ}', "");
Expect(0, 65393, '\p{Is_Lb= _CJ}', "");
Expect(1, 65393, '\p{^Is_Lb= _CJ}', "");
Expect(1, 65393, '\P{Is_Lb= _CJ}', "");
Expect(0, 65393, '\P{^Is_Lb= _CJ}', "");
Error('\p{Line_Break=	:=Close_PUNCTUATION}');
Error('\P{Line_Break=	:=Close_PUNCTUATION}');
Expect(1, 78715, '\p{Line_Break=closepunctuation}', "");
Expect(0, 78715, '\p{^Line_Break=closepunctuation}', "");
Expect(0, 78715, '\P{Line_Break=closepunctuation}', "");
Expect(1, 78715, '\P{^Line_Break=closepunctuation}', "");
Expect(0, 78716, '\p{Line_Break=closepunctuation}', "");
Expect(1, 78716, '\p{^Line_Break=closepunctuation}', "");
Expect(1, 78716, '\P{Line_Break=closepunctuation}', "");
Expect(0, 78716, '\P{^Line_Break=closepunctuation}', "");
Expect(1, 78715, '\p{Line_Break=	Close_PUNCTUATION}', "");
Expect(0, 78715, '\p{^Line_Break=	Close_PUNCTUATION}', "");
Expect(0, 78715, '\P{Line_Break=	Close_PUNCTUATION}', "");
Expect(1, 78715, '\P{^Line_Break=	Close_PUNCTUATION}', "");
Expect(0, 78716, '\p{Line_Break=	Close_PUNCTUATION}', "");
Expect(1, 78716, '\p{^Line_Break=	Close_PUNCTUATION}', "");
Expect(1, 78716, '\P{Line_Break=	Close_PUNCTUATION}', "");
Expect(0, 78716, '\P{^Line_Break=	Close_PUNCTUATION}', "");
Error('\p{Lb= CL:=}');
Error('\P{Lb= CL:=}');
Expect(1, 78715, '\p{Lb=cl}', "");
Expect(0, 78715, '\p{^Lb=cl}', "");
Expect(0, 78715, '\P{Lb=cl}', "");
Expect(1, 78715, '\P{^Lb=cl}', "");
Expect(0, 78716, '\p{Lb=cl}', "");
Expect(1, 78716, '\p{^Lb=cl}', "");
Expect(1, 78716, '\P{Lb=cl}', "");
Expect(0, 78716, '\P{^Lb=cl}', "");
Expect(1, 78715, '\p{Lb=--CL}', "");
Expect(0, 78715, '\p{^Lb=--CL}', "");
Expect(0, 78715, '\P{Lb=--CL}', "");
Expect(1, 78715, '\P{^Lb=--CL}', "");
Expect(0, 78716, '\p{Lb=--CL}', "");
Expect(1, 78716, '\p{^Lb=--CL}', "");
Expect(1, 78716, '\P{Lb=--CL}', "");
Expect(0, 78716, '\P{^Lb=--CL}', "");
Error('\p{Is_Line_Break=/a/Close_PUNCTUATION}');
Error('\P{Is_Line_Break=/a/Close_PUNCTUATION}');
Expect(1, 78715, '\p{Is_Line_Break: closepunctuation}', "");
Expect(0, 78715, '\p{^Is_Line_Break: closepunctuation}', "");
Expect(0, 78715, '\P{Is_Line_Break: closepunctuation}', "");
Expect(1, 78715, '\P{^Is_Line_Break: closepunctuation}', "");
Expect(0, 78716, '\p{Is_Line_Break: closepunctuation}', "");
Expect(1, 78716, '\p{^Is_Line_Break: closepunctuation}', "");
Expect(1, 78716, '\P{Is_Line_Break: closepunctuation}', "");
Expect(0, 78716, '\P{^Is_Line_Break: closepunctuation}', "");
Expect(1, 78715, '\p{Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(0, 78715, '\p{^Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(0, 78715, '\P{Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(1, 78715, '\P{^Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(0, 78716, '\p{Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(1, 78716, '\p{^Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(1, 78716, '\P{Is_Line_Break:   - CLOSE_punctuation}', "");
Expect(0, 78716, '\P{^Is_Line_Break:   - CLOSE_punctuation}', "");
Error('\p{Is_Lb=:=_CL}');
Error('\P{Is_Lb=:=_CL}');
Expect(1, 78715, '\p{Is_Lb=cl}', "");
Expect(0, 78715, '\p{^Is_Lb=cl}', "");
Expect(0, 78715, '\P{Is_Lb=cl}', "");
Expect(1, 78715, '\P{^Is_Lb=cl}', "");
Expect(0, 78716, '\p{Is_Lb=cl}', "");
Expect(1, 78716, '\p{^Is_Lb=cl}', "");
Expect(1, 78716, '\P{Is_Lb=cl}', "");
Expect(0, 78716, '\P{^Is_Lb=cl}', "");
Expect(1, 78715, '\p{Is_Lb= _CL}', "");
Expect(0, 78715, '\p{^Is_Lb= _CL}', "");
Expect(0, 78715, '\P{Is_Lb= _CL}', "");
Expect(1, 78715, '\P{^Is_Lb= _CL}', "");
Expect(0, 78716, '\p{Is_Lb= _CL}', "");
Expect(1, 78716, '\p{^Is_Lb= _CL}', "");
Expect(1, 78716, '\P{Is_Lb= _CL}', "");
Expect(0, 78716, '\P{^Is_Lb= _CL}', "");
Error('\p{Line_Break= :=Combining_Mark}');
Error('\P{Line_Break= :=Combining_Mark}');
Expect(1, 917999, '\p{Line_Break=combiningmark}', "");
Expect(0, 917999, '\p{^Line_Break=combiningmark}', "");
Expect(0, 917999, '\P{Line_Break=combiningmark}', "");
Expect(1, 917999, '\P{^Line_Break=combiningmark}', "");
Expect(0, 918000, '\p{Line_Break=combiningmark}', "");
Expect(1, 918000, '\p{^Line_Break=combiningmark}', "");
Expect(1, 918000, '\P{Line_Break=combiningmark}', "");
Expect(0, 918000, '\P{^Line_Break=combiningmark}', "");
Expect(1, 917999, '\p{Line_Break= Combining_mark}', "");
Expect(0, 917999, '\p{^Line_Break= Combining_mark}', "");
Expect(0, 917999, '\P{Line_Break= Combining_mark}', "");
Expect(1, 917999, '\P{^Line_Break= Combining_mark}', "");
Expect(0, 918000, '\p{Line_Break= Combining_mark}', "");
Expect(1, 918000, '\p{^Line_Break= Combining_mark}', "");
Expect(1, 918000, '\P{Line_Break= Combining_mark}', "");
Expect(0, 918000, '\P{^Line_Break= Combining_mark}', "");
Error('\p{Lb= 	cm:=}');
Error('\P{Lb= 	cm:=}');
Expect(1, 917999, '\p{Lb=cm}', "");
Expect(0, 917999, '\p{^Lb=cm}', "");
Expect(0, 917999, '\P{Lb=cm}', "");
Expect(1, 917999, '\P{^Lb=cm}', "");
Expect(0, 918000, '\p{Lb=cm}', "");
Expect(1, 918000, '\p{^Lb=cm}', "");
Expect(1, 918000, '\P{Lb=cm}', "");
Expect(0, 918000, '\P{^Lb=cm}', "");
Expect(1, 917999, '\p{Lb=	cm}', "");
Expect(0, 917999, '\p{^Lb=	cm}', "");
Expect(0, 917999, '\P{Lb=	cm}', "");
Expect(1, 917999, '\P{^Lb=	cm}', "");
Expect(0, 918000, '\p{Lb=	cm}', "");
Expect(1, 918000, '\p{^Lb=	cm}', "");
Expect(1, 918000, '\P{Lb=	cm}', "");
Expect(0, 918000, '\P{^Lb=	cm}', "");
Error('\p{Is_Line_Break=/a/__Combining_MARK}');
Error('\P{Is_Line_Break=/a/__Combining_MARK}');
Expect(1, 917999, '\p{Is_Line_Break=combiningmark}', "");
Expect(0, 917999, '\p{^Is_Line_Break=combiningmark}', "");
Expect(0, 917999, '\P{Is_Line_Break=combiningmark}', "");
Expect(1, 917999, '\P{^Is_Line_Break=combiningmark}', "");
Expect(0, 918000, '\p{Is_Line_Break=combiningmark}', "");
Expect(1, 918000, '\p{^Is_Line_Break=combiningmark}', "");
Expect(1, 918000, '\P{Is_Line_Break=combiningmark}', "");
Expect(0, 918000, '\P{^Is_Line_Break=combiningmark}', "");
Expect(1, 917999, '\p{Is_Line_Break=  Combining_MARK}', "");
Expect(0, 917999, '\p{^Is_Line_Break=  Combining_MARK}', "");
Expect(0, 917999, '\P{Is_Line_Break=  Combining_MARK}', "");
Expect(1, 917999, '\P{^Is_Line_Break=  Combining_MARK}', "");
Expect(0, 918000, '\p{Is_Line_Break=  Combining_MARK}', "");
Expect(1, 918000, '\p{^Is_Line_Break=  Combining_MARK}', "");
Expect(1, 918000, '\P{Is_Line_Break=  Combining_MARK}', "");
Expect(0, 918000, '\P{^Is_Line_Break=  Combining_MARK}', "");
Error('\p{Is_Lb= :=cm}');
Error('\P{Is_Lb= :=cm}');
Expect(1, 917999, '\p{Is_Lb=cm}', "");
Expect(0, 917999, '\p{^Is_Lb=cm}', "");
Expect(0, 917999, '\P{Is_Lb=cm}', "");
Expect(1, 917999, '\P{^Is_Lb=cm}', "");
Expect(0, 918000, '\p{Is_Lb=cm}', "");
Expect(1, 918000, '\p{^Is_Lb=cm}', "");
Expect(1, 918000, '\P{Is_Lb=cm}', "");
Expect(0, 918000, '\P{^Is_Lb=cm}', "");
Expect(1, 917999, '\p{Is_Lb=	 CM}', "");
Expect(0, 917999, '\p{^Is_Lb=	 CM}', "");
Expect(0, 917999, '\P{Is_Lb=	 CM}', "");
Expect(1, 917999, '\P{^Is_Lb=	 CM}', "");
Expect(0, 918000, '\p{Is_Lb=	 CM}', "");
Expect(1, 918000, '\p{^Is_Lb=	 CM}', "");
Expect(1, 918000, '\P{Is_Lb=	 CM}', "");
Expect(0, 918000, '\P{^Is_Lb=	 CM}', "");
Error('\p{Line_Break::= CLOSE_Parenthesis}');
Error('\P{Line_Break::= CLOSE_Parenthesis}');
Expect(1, 93, '\p{Line_Break=closeparenthesis}', "");
Expect(0, 93, '\p{^Line_Break=closeparenthesis}', "");
Expect(0, 93, '\P{Line_Break=closeparenthesis}', "");
Expect(1, 93, '\P{^Line_Break=closeparenthesis}', "");
Expect(0, 94, '\p{Line_Break=closeparenthesis}', "");
Expect(1, 94, '\p{^Line_Break=closeparenthesis}', "");
Expect(1, 94, '\P{Line_Break=closeparenthesis}', "");
Expect(0, 94, '\P{^Line_Break=closeparenthesis}', "");
Expect(1, 93, '\p{Line_Break=-	CLOSE_Parenthesis}', "");
Expect(0, 93, '\p{^Line_Break=-	CLOSE_Parenthesis}', "");
Expect(0, 93, '\P{Line_Break=-	CLOSE_Parenthesis}', "");
Expect(1, 93, '\P{^Line_Break=-	CLOSE_Parenthesis}', "");
Expect(0, 94, '\p{Line_Break=-	CLOSE_Parenthesis}', "");
Expect(1, 94, '\p{^Line_Break=-	CLOSE_Parenthesis}', "");
Expect(1, 94, '\P{Line_Break=-	CLOSE_Parenthesis}', "");
Expect(0, 94, '\P{^Line_Break=-	CLOSE_Parenthesis}', "");
Error('\p{Lb=:= CP}');
Error('\P{Lb=:= CP}');
Expect(1, 93, '\p{Lb=cp}', "");
Expect(0, 93, '\p{^Lb=cp}', "");
Expect(0, 93, '\P{Lb=cp}', "");
Expect(1, 93, '\P{^Lb=cp}', "");
Expect(0, 94, '\p{Lb=cp}', "");
Expect(1, 94, '\p{^Lb=cp}', "");
Expect(1, 94, '\P{Lb=cp}', "");
Expect(0, 94, '\P{^Lb=cp}', "");
Expect(1, 93, '\p{Lb= 	CP}', "");
Expect(0, 93, '\p{^Lb= 	CP}', "");
Expect(0, 93, '\P{Lb= 	CP}', "");
Expect(1, 93, '\P{^Lb= 	CP}', "");
Expect(0, 94, '\p{Lb= 	CP}', "");
Expect(1, 94, '\p{^Lb= 	CP}', "");
Expect(1, 94, '\P{Lb= 	CP}', "");
Expect(0, 94, '\P{^Lb= 	CP}', "");
Error('\p{Is_Line_Break=_	close_PARENTHESIS/a/}');
Error('\P{Is_Line_Break=_	close_PARENTHESIS/a/}');
Expect(1, 93, '\p{Is_Line_Break=closeparenthesis}', "");
Expect(0, 93, '\p{^Is_Line_Break=closeparenthesis}', "");
Expect(0, 93, '\P{Is_Line_Break=closeparenthesis}', "");
Expect(1, 93, '\P{^Is_Line_Break=closeparenthesis}', "");
Expect(0, 94, '\p{Is_Line_Break=closeparenthesis}', "");
Expect(1, 94, '\p{^Is_Line_Break=closeparenthesis}', "");
Expect(1, 94, '\P{Is_Line_Break=closeparenthesis}', "");
Expect(0, 94, '\P{^Is_Line_Break=closeparenthesis}', "");
Expect(1, 93, '\p{Is_Line_Break=_	Close_Parenthesis}', "");
Expect(0, 93, '\p{^Is_Line_Break=_	Close_Parenthesis}', "");
Expect(0, 93, '\P{Is_Line_Break=_	Close_Parenthesis}', "");
Expect(1, 93, '\P{^Is_Line_Break=_	Close_Parenthesis}', "");
Expect(0, 94, '\p{Is_Line_Break=_	Close_Parenthesis}', "");
Expect(1, 94, '\p{^Is_Line_Break=_	Close_Parenthesis}', "");
Expect(1, 94, '\P{Is_Line_Break=_	Close_Parenthesis}', "");
Expect(0, 94, '\P{^Is_Line_Break=_	Close_Parenthesis}', "");
Error('\p{Is_Lb=_ cp:=}');
Error('\P{Is_Lb=_ cp:=}');
Expect(1, 93, '\p{Is_Lb=cp}', "");
Expect(0, 93, '\p{^Is_Lb=cp}', "");
Expect(0, 93, '\P{Is_Lb=cp}', "");
Expect(1, 93, '\P{^Is_Lb=cp}', "");
Expect(0, 94, '\p{Is_Lb=cp}', "");
Expect(1, 94, '\p{^Is_Lb=cp}', "");
Expect(1, 94, '\P{Is_Lb=cp}', "");
Expect(0, 94, '\P{^Is_Lb=cp}', "");
Expect(1, 93, '\p{Is_Lb=	 CP}', "");
Expect(0, 93, '\p{^Is_Lb=	 CP}', "");
Expect(0, 93, '\P{Is_Lb=	 CP}', "");
Expect(1, 93, '\P{^Is_Lb=	 CP}', "");
Expect(0, 94, '\p{Is_Lb=	 CP}', "");
Expect(1, 94, '\p{^Is_Lb=	 CP}', "");
Expect(1, 94, '\P{Is_Lb=	 CP}', "");
Expect(0, 94, '\P{^Is_Lb=	 CP}', "");
Error('\p{Line_Break=:=Carriage_return}');
Error('\P{Line_Break=:=Carriage_return}');
Expect(1, 13, '\p{Line_Break=carriagereturn}', "");
Expect(0, 13, '\p{^Line_Break=carriagereturn}', "");
Expect(0, 13, '\P{Line_Break=carriagereturn}', "");
Expect(1, 13, '\P{^Line_Break=carriagereturn}', "");
Expect(0, 14, '\p{Line_Break=carriagereturn}', "");
Expect(1, 14, '\p{^Line_Break=carriagereturn}', "");
Expect(1, 14, '\P{Line_Break=carriagereturn}', "");
Expect(0, 14, '\P{^Line_Break=carriagereturn}', "");
Expect(1, 13, '\p{Line_Break=	carriage_Return}', "");
Expect(0, 13, '\p{^Line_Break=	carriage_Return}', "");
Expect(0, 13, '\P{Line_Break=	carriage_Return}', "");
Expect(1, 13, '\P{^Line_Break=	carriage_Return}', "");
Expect(0, 14, '\p{Line_Break=	carriage_Return}', "");
Expect(1, 14, '\p{^Line_Break=	carriage_Return}', "");
Expect(1, 14, '\P{Line_Break=	carriage_Return}', "");
Expect(0, 14, '\P{^Line_Break=	carriage_Return}', "");
Error('\p{Lb= 	CR:=}');
Error('\P{Lb= 	CR:=}');
Expect(1, 13, '\p{Lb=cr}', "");
Expect(0, 13, '\p{^Lb=cr}', "");
Expect(0, 13, '\P{Lb=cr}', "");
Expect(1, 13, '\P{^Lb=cr}', "");
Expect(0, 14, '\p{Lb=cr}', "");
Expect(1, 14, '\p{^Lb=cr}', "");
Expect(1, 14, '\P{Lb=cr}', "");
Expect(0, 14, '\P{^Lb=cr}', "");
Expect(1, 13, '\p{Lb=-	cr}', "");
Expect(0, 13, '\p{^Lb=-	cr}', "");
Expect(0, 13, '\P{Lb=-	cr}', "");
Expect(1, 13, '\P{^Lb=-	cr}', "");
Expect(0, 14, '\p{Lb=-	cr}', "");
Expect(1, 14, '\p{^Lb=-	cr}', "");
Expect(1, 14, '\P{Lb=-	cr}', "");
Expect(0, 14, '\P{^Lb=-	cr}', "");
Error('\p{Is_Line_Break=_Carriage_return/a/}');
Error('\P{Is_Line_Break=_Carriage_return/a/}');
Expect(1, 13, '\p{Is_Line_Break=carriagereturn}', "");
Expect(0, 13, '\p{^Is_Line_Break=carriagereturn}', "");
Expect(0, 13, '\P{Is_Line_Break=carriagereturn}', "");
Expect(1, 13, '\P{^Is_Line_Break=carriagereturn}', "");
Expect(0, 14, '\p{Is_Line_Break=carriagereturn}', "");
Expect(1, 14, '\p{^Is_Line_Break=carriagereturn}', "");
Expect(1, 14, '\P{Is_Line_Break=carriagereturn}', "");
Expect(0, 14, '\P{^Is_Line_Break=carriagereturn}', "");
Expect(1, 13, '\p{Is_Line_Break=--carriage_RETURN}', "");
Expect(0, 13, '\p{^Is_Line_Break=--carriage_RETURN}', "");
Expect(0, 13, '\P{Is_Line_Break=--carriage_RETURN}', "");
Expect(1, 13, '\P{^Is_Line_Break=--carriage_RETURN}', "");
Expect(0, 14, '\p{Is_Line_Break=--carriage_RETURN}', "");
Expect(1, 14, '\p{^Is_Line_Break=--carriage_RETURN}', "");
Expect(1, 14, '\P{Is_Line_Break=--carriage_RETURN}', "");
Expect(0, 14, '\P{^Is_Line_Break=--carriage_RETURN}', "");
Error('\p{Is_Lb=	_CR/a/}');
Error('\P{Is_Lb=	_CR/a/}');
Expect(1, 13, '\p{Is_Lb=cr}', "");
Expect(0, 13, '\p{^Is_Lb=cr}', "");
Expect(0, 13, '\P{Is_Lb=cr}', "");
Expect(1, 13, '\P{^Is_Lb=cr}', "");
Expect(0, 14, '\p{Is_Lb=cr}', "");
Expect(1, 14, '\p{^Is_Lb=cr}', "");
Expect(1, 14, '\P{Is_Lb=cr}', "");
Expect(0, 14, '\P{^Is_Lb=cr}', "");
Expect(1, 13, '\p{Is_Lb:	- CR}', "");
Expect(0, 13, '\p{^Is_Lb:	- CR}', "");
Expect(0, 13, '\P{Is_Lb:	- CR}', "");
Expect(1, 13, '\P{^Is_Lb:	- CR}', "");
Expect(0, 14, '\p{Is_Lb:	- CR}', "");
Expect(1, 14, '\p{^Is_Lb:	- CR}', "");
Expect(1, 14, '\P{Is_Lb:	- CR}', "");
Expect(0, 14, '\P{^Is_Lb:	- CR}', "");
Error('\p{Line_Break=__exclamation/a/}');
Error('\P{Line_Break=__exclamation/a/}');
Expect(1, 65311, '\p{Line_Break=exclamation}', "");
Expect(0, 65311, '\p{^Line_Break=exclamation}', "");
Expect(0, 65311, '\P{Line_Break=exclamation}', "");
Expect(1, 65311, '\P{^Line_Break=exclamation}', "");
Expect(0, 65312, '\p{Line_Break=exclamation}', "");
Expect(1, 65312, '\p{^Line_Break=exclamation}', "");
Expect(1, 65312, '\P{Line_Break=exclamation}', "");
Expect(0, 65312, '\P{^Line_Break=exclamation}', "");
Expect(1, 65311, '\p{Line_Break=- Exclamation}', "");
Expect(0, 65311, '\p{^Line_Break=- Exclamation}', "");
Expect(0, 65311, '\P{Line_Break=- Exclamation}', "");
Expect(1, 65311, '\P{^Line_Break=- Exclamation}', "");
Expect(0, 65312, '\p{Line_Break=- Exclamation}', "");
Expect(1, 65312, '\p{^Line_Break=- Exclamation}', "");
Expect(1, 65312, '\P{Line_Break=- Exclamation}', "");
Expect(0, 65312, '\P{^Line_Break=- Exclamation}', "");
Error('\p{Lb=:=ex}');
Error('\P{Lb=:=ex}');
Expect(1, 65311, '\p{Lb=ex}', "");
Expect(0, 65311, '\p{^Lb=ex}', "");
Expect(0, 65311, '\P{Lb=ex}', "");
Expect(1, 65311, '\P{^Lb=ex}', "");
Expect(0, 65312, '\p{Lb=ex}', "");
Expect(1, 65312, '\p{^Lb=ex}', "");
Expect(1, 65312, '\P{Lb=ex}', "");
Expect(0, 65312, '\P{^Lb=ex}', "");
Expect(1, 65311, '\p{Lb=_	ex}', "");
Expect(0, 65311, '\p{^Lb=_	ex}', "");
Expect(0, 65311, '\P{Lb=_	ex}', "");
Expect(1, 65311, '\P{^Lb=_	ex}', "");
Expect(0, 65312, '\p{Lb=_	ex}', "");
Expect(1, 65312, '\p{^Lb=_	ex}', "");
Expect(1, 65312, '\P{Lb=_	ex}', "");
Expect(0, 65312, '\P{^Lb=_	ex}', "");
Error('\p{Is_Line_Break=	/a/Exclamation}');
Error('\P{Is_Line_Break=	/a/Exclamation}');
Expect(1, 65311, '\p{Is_Line_Break:exclamation}', "");
Expect(0, 65311, '\p{^Is_Line_Break:exclamation}', "");
Expect(0, 65311, '\P{Is_Line_Break:exclamation}', "");
Expect(1, 65311, '\P{^Is_Line_Break:exclamation}', "");
Expect(0, 65312, '\p{Is_Line_Break:exclamation}', "");
Expect(1, 65312, '\p{^Is_Line_Break:exclamation}', "");
Expect(1, 65312, '\P{Is_Line_Break:exclamation}', "");
Expect(0, 65312, '\P{^Is_Line_Break:exclamation}', "");
Expect(1, 65311, '\p{Is_Line_Break= _Exclamation}', "");
Expect(0, 65311, '\p{^Is_Line_Break= _Exclamation}', "");
Expect(0, 65311, '\P{Is_Line_Break= _Exclamation}', "");
Expect(1, 65311, '\P{^Is_Line_Break= _Exclamation}', "");
Expect(0, 65312, '\p{Is_Line_Break= _Exclamation}', "");
Expect(1, 65312, '\p{^Is_Line_Break= _Exclamation}', "");
Expect(1, 65312, '\P{Is_Line_Break= _Exclamation}', "");
Expect(0, 65312, '\P{^Is_Line_Break= _Exclamation}', "");
Error('\p{Is_Lb=/a/ -EX}');
Error('\P{Is_Lb=/a/ -EX}');
Expect(1, 65311, '\p{Is_Lb=ex}', "");
Expect(0, 65311, '\p{^Is_Lb=ex}', "");
Expect(0, 65311, '\P{Is_Lb=ex}', "");
Expect(1, 65311, '\P{^Is_Lb=ex}', "");
Expect(0, 65312, '\p{Is_Lb=ex}', "");
Expect(1, 65312, '\p{^Is_Lb=ex}', "");
Expect(1, 65312, '\P{Is_Lb=ex}', "");
Expect(0, 65312, '\P{^Is_Lb=ex}', "");
Expect(1, 65311, '\p{Is_Lb=-EX}', "");
Expect(0, 65311, '\p{^Is_Lb=-EX}', "");
Expect(0, 65311, '\P{Is_Lb=-EX}', "");
Expect(1, 65311, '\P{^Is_Lb=-EX}', "");
Expect(0, 65312, '\p{Is_Lb=-EX}', "");
Expect(1, 65312, '\p{^Is_Lb=-EX}', "");
Expect(1, 65312, '\P{Is_Lb=-EX}', "");
Expect(0, 65312, '\P{^Is_Lb=-EX}', "");
Error('\p{Line_Break=/a/ -Glue}');
Error('\P{Line_Break=/a/ -Glue}');
Expect(1, 8239, '\p{Line_Break=glue}', "");
Expect(0, 8239, '\p{^Line_Break=glue}', "");
Expect(0, 8239, '\P{Line_Break=glue}', "");
Expect(1, 8239, '\P{^Line_Break=glue}', "");
Expect(0, 8240, '\p{Line_Break=glue}', "");
Expect(1, 8240, '\p{^Line_Break=glue}', "");
Expect(1, 8240, '\P{Line_Break=glue}', "");
Expect(0, 8240, '\P{^Line_Break=glue}', "");
Expect(1, 8239, '\p{Line_Break:   -_GLUE}', "");
Expect(0, 8239, '\p{^Line_Break:   -_GLUE}', "");
Expect(0, 8239, '\P{Line_Break:   -_GLUE}', "");
Expect(1, 8239, '\P{^Line_Break:   -_GLUE}', "");
Expect(0, 8240, '\p{Line_Break:   -_GLUE}', "");
Expect(1, 8240, '\p{^Line_Break:   -_GLUE}', "");
Expect(1, 8240, '\P{Line_Break:   -_GLUE}', "");
Expect(0, 8240, '\P{^Line_Break:   -_GLUE}', "");
Error('\p{Lb=--GL/a/}');
Error('\P{Lb=--GL/a/}');
Expect(1, 8239, '\p{Lb=gl}', "");
Expect(0, 8239, '\p{^Lb=gl}', "");
Expect(0, 8239, '\P{Lb=gl}', "");
Expect(1, 8239, '\P{^Lb=gl}', "");
Expect(0, 8240, '\p{Lb=gl}', "");
Expect(1, 8240, '\p{^Lb=gl}', "");
Expect(1, 8240, '\P{Lb=gl}', "");
Expect(0, 8240, '\P{^Lb=gl}', "");
Expect(1, 8239, '\p{Lb=_GL}', "");
Expect(0, 8239, '\p{^Lb=_GL}', "");
Expect(0, 8239, '\P{Lb=_GL}', "");
Expect(1, 8239, '\P{^Lb=_GL}', "");
Expect(0, 8240, '\p{Lb=_GL}', "");
Expect(1, 8240, '\p{^Lb=_GL}', "");
Expect(1, 8240, '\P{Lb=_GL}', "");
Expect(0, 8240, '\P{^Lb=_GL}', "");
Error('\p{Is_Line_Break=	_glue:=}');
Error('\P{Is_Line_Break=	_glue:=}');
Expect(1, 8239, '\p{Is_Line_Break=glue}', "");
Expect(0, 8239, '\p{^Is_Line_Break=glue}', "");
Expect(0, 8239, '\P{Is_Line_Break=glue}', "");
Expect(1, 8239, '\P{^Is_Line_Break=glue}', "");
Expect(0, 8240, '\p{Is_Line_Break=glue}', "");
Expect(1, 8240, '\p{^Is_Line_Break=glue}', "");
Expect(1, 8240, '\P{Is_Line_Break=glue}', "");
Expect(0, 8240, '\P{^Is_Line_Break=glue}', "");
Expect(1, 8239, '\p{Is_Line_Break= -Glue}', "");
Expect(0, 8239, '\p{^Is_Line_Break= -Glue}', "");
Expect(0, 8239, '\P{Is_Line_Break= -Glue}', "");
Expect(1, 8239, '\P{^Is_Line_Break= -Glue}', "");
Expect(0, 8240, '\p{Is_Line_Break= -Glue}', "");
Expect(1, 8240, '\p{^Is_Line_Break= -Glue}', "");
Expect(1, 8240, '\P{Is_Line_Break= -Glue}', "");
Expect(0, 8240, '\P{^Is_Line_Break= -Glue}', "");
Error('\p{Is_Lb= gl:=}');
Error('\P{Is_Lb= gl:=}');
Expect(1, 8239, '\p{Is_Lb=gl}', "");
Expect(0, 8239, '\p{^Is_Lb=gl}', "");
Expect(0, 8239, '\P{Is_Lb=gl}', "");
Expect(1, 8239, '\P{^Is_Lb=gl}', "");
Expect(0, 8240, '\p{Is_Lb=gl}', "");
Expect(1, 8240, '\p{^Is_Lb=gl}', "");
Expect(1, 8240, '\P{Is_Lb=gl}', "");
Expect(0, 8240, '\P{^Is_Lb=gl}', "");
Expect(1, 8239, '\p{Is_Lb=		GL}', "");
Expect(0, 8239, '\p{^Is_Lb=		GL}', "");
Expect(0, 8239, '\P{Is_Lb=		GL}', "");
Expect(1, 8239, '\P{^Is_Lb=		GL}', "");
Expect(0, 8240, '\p{Is_Lb=		GL}', "");
Expect(1, 8240, '\p{^Is_Lb=		GL}', "");
Expect(1, 8240, '\P{Is_Lb=		GL}', "");
Expect(0, 8240, '\P{^Is_Lb=		GL}', "");
Error('\p{Line_Break=	/a/h2}');
Error('\P{Line_Break=	/a/h2}');
Expect(1, 55176, '\p{Line_Break=h2}', "");
Expect(0, 55176, '\p{^Line_Break=h2}', "");
Expect(0, 55176, '\P{Line_Break=h2}', "");
Expect(1, 55176, '\P{^Line_Break=h2}', "");
Expect(0, 55177, '\p{Line_Break=h2}', "");
Expect(1, 55177, '\p{^Line_Break=h2}', "");
Expect(1, 55177, '\P{Line_Break=h2}', "");
Expect(0, 55177, '\P{^Line_Break=h2}', "");
Expect(1, 55176, '\p{Line_Break=-h2}', "");
Expect(0, 55176, '\p{^Line_Break=-h2}', "");
Expect(0, 55176, '\P{Line_Break=-h2}', "");
Expect(1, 55176, '\P{^Line_Break=-h2}', "");
Expect(0, 55177, '\p{Line_Break=-h2}', "");
Expect(1, 55177, '\p{^Line_Break=-h2}', "");
Expect(1, 55177, '\P{Line_Break=-h2}', "");
Expect(0, 55177, '\P{^Line_Break=-h2}', "");
Error('\p{Lb::= h2}');
Error('\P{Lb::= h2}');
Expect(1, 55176, '\p{Lb=h2}', "");
Expect(0, 55176, '\p{^Lb=h2}', "");
Expect(0, 55176, '\P{Lb=h2}', "");
Expect(1, 55176, '\P{^Lb=h2}', "");
Expect(0, 55177, '\p{Lb=h2}', "");
Expect(1, 55177, '\p{^Lb=h2}', "");
Expect(1, 55177, '\P{Lb=h2}', "");
Expect(0, 55177, '\P{^Lb=h2}', "");
Expect(1, 55176, '\p{Lb=	 H2}', "");
Expect(0, 55176, '\p{^Lb=	 H2}', "");
Expect(0, 55176, '\P{Lb=	 H2}', "");
Expect(1, 55176, '\P{^Lb=	 H2}', "");
Expect(0, 55177, '\p{Lb=	 H2}', "");
Expect(1, 55177, '\p{^Lb=	 H2}', "");
Expect(1, 55177, '\P{Lb=	 H2}', "");
Expect(0, 55177, '\P{^Lb=	 H2}', "");
Error('\p{Is_Line_Break=:=  H2}');
Error('\P{Is_Line_Break=:=  H2}');
Expect(1, 55176, '\p{Is_Line_Break=h2}', "");
Expect(0, 55176, '\p{^Is_Line_Break=h2}', "");
Expect(0, 55176, '\P{Is_Line_Break=h2}', "");
Expect(1, 55176, '\P{^Is_Line_Break=h2}', "");
Expect(0, 55177, '\p{Is_Line_Break=h2}', "");
Expect(1, 55177, '\p{^Is_Line_Break=h2}', "");
Expect(1, 55177, '\P{Is_Line_Break=h2}', "");
Expect(0, 55177, '\P{^Is_Line_Break=h2}', "");
Expect(1, 55176, '\p{Is_Line_Break=_h2}', "");
Expect(0, 55176, '\p{^Is_Line_Break=_h2}', "");
Expect(0, 55176, '\P{Is_Line_Break=_h2}', "");
Expect(1, 55176, '\P{^Is_Line_Break=_h2}', "");
Expect(0, 55177, '\p{Is_Line_Break=_h2}', "");
Expect(1, 55177, '\p{^Is_Line_Break=_h2}', "");
Expect(1, 55177, '\P{Is_Line_Break=_h2}', "");
Expect(0, 55177, '\P{^Is_Line_Break=_h2}', "");
Error('\p{Is_Lb: -/a/H2}');
Error('\P{Is_Lb: -/a/H2}');
Expect(1, 55176, '\p{Is_Lb=h2}', "");
Expect(0, 55176, '\p{^Is_Lb=h2}', "");
Expect(0, 55176, '\P{Is_Lb=h2}', "");
Expect(1, 55176, '\P{^Is_Lb=h2}', "");
Expect(0, 55177, '\p{Is_Lb=h2}', "");
Expect(1, 55177, '\p{^Is_Lb=h2}', "");
Expect(1, 55177, '\P{Is_Lb=h2}', "");
Expect(0, 55177, '\P{^Is_Lb=h2}', "");
Expect(1, 55176, '\p{Is_Lb=	_H2}', "");
Expect(0, 55176, '\p{^Is_Lb=	_H2}', "");
Expect(0, 55176, '\P{Is_Lb=	_H2}', "");
Expect(1, 55176, '\P{^Is_Lb=	_H2}', "");
Expect(0, 55177, '\p{Is_Lb=	_H2}', "");
Expect(1, 55177, '\p{^Is_Lb=	_H2}', "");
Expect(1, 55177, '\P{Is_Lb=	_H2}', "");
Expect(0, 55177, '\P{^Is_Lb=	_H2}', "");
Error('\p{Line_Break=:=	-H3}');
Error('\P{Line_Break=:=	-H3}');
Expect(1, 55203, '\p{Line_Break=h3}', "");
Expect(0, 55203, '\p{^Line_Break=h3}', "");
Expect(0, 55203, '\P{Line_Break=h3}', "");
Expect(1, 55203, '\P{^Line_Break=h3}', "");
Expect(0, 55204, '\p{Line_Break=h3}', "");
Expect(1, 55204, '\p{^Line_Break=h3}', "");
Expect(1, 55204, '\P{Line_Break=h3}', "");
Expect(0, 55204, '\P{^Line_Break=h3}', "");
Expect(1, 55203, '\p{Line_Break=-h3}', "");
Expect(0, 55203, '\p{^Line_Break=-h3}', "");
Expect(0, 55203, '\P{Line_Break=-h3}', "");
Expect(1, 55203, '\P{^Line_Break=-h3}', "");
Expect(0, 55204, '\p{Line_Break=-h3}', "");
Expect(1, 55204, '\p{^Line_Break=-h3}', "");
Expect(1, 55204, '\P{Line_Break=-h3}', "");
Expect(0, 55204, '\P{^Line_Break=-h3}', "");
Error('\p{Lb=	H3/a/}');
Error('\P{Lb=	H3/a/}');
Expect(1, 55203, '\p{Lb=h3}', "");
Expect(0, 55203, '\p{^Lb=h3}', "");
Expect(0, 55203, '\P{Lb=h3}', "");
Expect(1, 55203, '\P{^Lb=h3}', "");
Expect(0, 55204, '\p{Lb=h3}', "");
Expect(1, 55204, '\p{^Lb=h3}', "");
Expect(1, 55204, '\P{Lb=h3}', "");
Expect(0, 55204, '\P{^Lb=h3}', "");
Expect(1, 55203, '\p{Lb=H3}', "");
Expect(0, 55203, '\p{^Lb=H3}', "");
Expect(0, 55203, '\P{Lb=H3}', "");
Expect(1, 55203, '\P{^Lb=H3}', "");
Expect(0, 55204, '\p{Lb=H3}', "");
Expect(1, 55204, '\p{^Lb=H3}', "");
Expect(1, 55204, '\P{Lb=H3}', "");
Expect(0, 55204, '\P{^Lb=H3}', "");
Error('\p{Is_Line_Break=	/a/H3}');
Error('\P{Is_Line_Break=	/a/H3}');
Expect(1, 55203, '\p{Is_Line_Break=h3}', "");
Expect(0, 55203, '\p{^Is_Line_Break=h3}', "");
Expect(0, 55203, '\P{Is_Line_Break=h3}', "");
Expect(1, 55203, '\P{^Is_Line_Break=h3}', "");
Expect(0, 55204, '\p{Is_Line_Break=h3}', "");
Expect(1, 55204, '\p{^Is_Line_Break=h3}', "");
Expect(1, 55204, '\P{Is_Line_Break=h3}', "");
Expect(0, 55204, '\P{^Is_Line_Break=h3}', "");
Expect(1, 55203, '\p{Is_Line_Break=_-H3}', "");
Expect(0, 55203, '\p{^Is_Line_Break=_-H3}', "");
Expect(0, 55203, '\P{Is_Line_Break=_-H3}', "");
Expect(1, 55203, '\P{^Is_Line_Break=_-H3}', "");
Expect(0, 55204, '\p{Is_Line_Break=_-H3}', "");
Expect(1, 55204, '\p{^Is_Line_Break=_-H3}', "");
Expect(1, 55204, '\P{Is_Line_Break=_-H3}', "");
Expect(0, 55204, '\P{^Is_Line_Break=_-H3}', "");
Error('\p{Is_Lb=_ H3:=}');
Error('\P{Is_Lb=_ H3:=}');
Expect(1, 55203, '\p{Is_Lb=h3}', "");
Expect(0, 55203, '\p{^Is_Lb=h3}', "");
Expect(0, 55203, '\P{Is_Lb=h3}', "");
Expect(1, 55203, '\P{^Is_Lb=h3}', "");
Expect(0, 55204, '\p{Is_Lb=h3}', "");
Expect(1, 55204, '\p{^Is_Lb=h3}', "");
Expect(1, 55204, '\P{Is_Lb=h3}', "");
Expect(0, 55204, '\P{^Is_Lb=h3}', "");
Expect(1, 55203, '\p{Is_Lb=	-H3}', "");
Expect(0, 55203, '\p{^Is_Lb=	-H3}', "");
Expect(0, 55203, '\P{Is_Lb=	-H3}', "");
Expect(1, 55203, '\P{^Is_Lb=	-H3}', "");
Expect(0, 55204, '\p{Is_Lb=	-H3}', "");
Expect(1, 55204, '\p{^Is_Lb=	-H3}', "");
Expect(1, 55204, '\P{Is_Lb=	-H3}', "");
Expect(0, 55204, '\P{^Is_Lb=	-H3}', "");
Error('\p{Line_Break:    /a/hebrew_LETTER}');
Error('\P{Line_Break:    /a/hebrew_LETTER}');
Expect(1, 64335, '\p{Line_Break=hebrewletter}', "");
Expect(0, 64335, '\p{^Line_Break=hebrewletter}', "");
Expect(0, 64335, '\P{Line_Break=hebrewletter}', "");
Expect(1, 64335, '\P{^Line_Break=hebrewletter}', "");
Expect(0, 64336, '\p{Line_Break=hebrewletter}', "");
Expect(1, 64336, '\p{^Line_Break=hebrewletter}', "");
Expect(1, 64336, '\P{Line_Break=hebrewletter}', "");
Expect(0, 64336, '\P{^Line_Break=hebrewletter}', "");
Expect(1, 64335, '\p{Line_Break=__Hebrew_letter}', "");
Expect(0, 64335, '\p{^Line_Break=__Hebrew_letter}', "");
Expect(0, 64335, '\P{Line_Break=__Hebrew_letter}', "");
Expect(1, 64335, '\P{^Line_Break=__Hebrew_letter}', "");
Expect(0, 64336, '\p{Line_Break=__Hebrew_letter}', "");
Expect(1, 64336, '\p{^Line_Break=__Hebrew_letter}', "");
Expect(1, 64336, '\P{Line_Break=__Hebrew_letter}', "");
Expect(0, 64336, '\P{^Line_Break=__Hebrew_letter}', "");
Error('\p{Lb=-:=HL}');
Error('\P{Lb=-:=HL}');
Expect(1, 64335, '\p{Lb=hl}', "");
Expect(0, 64335, '\p{^Lb=hl}', "");
Expect(0, 64335, '\P{Lb=hl}', "");
Expect(1, 64335, '\P{^Lb=hl}', "");
Expect(0, 64336, '\p{Lb=hl}', "");
Expect(1, 64336, '\p{^Lb=hl}', "");
Expect(1, 64336, '\P{Lb=hl}', "");
Expect(0, 64336, '\P{^Lb=hl}', "");
Expect(1, 64335, '\p{Lb= _HL}', "");
Expect(0, 64335, '\p{^Lb= _HL}', "");
Expect(0, 64335, '\P{Lb= _HL}', "");
Expect(1, 64335, '\P{^Lb= _HL}', "");
Expect(0, 64336, '\p{Lb= _HL}', "");
Expect(1, 64336, '\p{^Lb= _HL}', "");
Expect(1, 64336, '\P{Lb= _HL}', "");
Expect(0, 64336, '\P{^Lb= _HL}', "");
Error('\p{Is_Line_Break=/a/Hebrew_LETTER}');
Error('\P{Is_Line_Break=/a/Hebrew_LETTER}');
Expect(1, 64335, '\p{Is_Line_Break=hebrewletter}', "");
Expect(0, 64335, '\p{^Is_Line_Break=hebrewletter}', "");
Expect(0, 64335, '\P{Is_Line_Break=hebrewletter}', "");
Expect(1, 64335, '\P{^Is_Line_Break=hebrewletter}', "");
Expect(0, 64336, '\p{Is_Line_Break=hebrewletter}', "");
Expect(1, 64336, '\p{^Is_Line_Break=hebrewletter}', "");
Expect(1, 64336, '\P{Is_Line_Break=hebrewletter}', "");
Expect(0, 64336, '\P{^Is_Line_Break=hebrewletter}', "");
Expect(1, 64335, '\p{Is_Line_Break= -hebrew_Letter}', "");
Expect(0, 64335, '\p{^Is_Line_Break= -hebrew_Letter}', "");
Expect(0, 64335, '\P{Is_Line_Break= -hebrew_Letter}', "");
Expect(1, 64335, '\P{^Is_Line_Break= -hebrew_Letter}', "");
Expect(0, 64336, '\p{Is_Line_Break= -hebrew_Letter}', "");
Expect(1, 64336, '\p{^Is_Line_Break= -hebrew_Letter}', "");
Expect(1, 64336, '\P{Is_Line_Break= -hebrew_Letter}', "");
Expect(0, 64336, '\P{^Is_Line_Break= -hebrew_Letter}', "");
Error('\p{Is_Lb=-/a/HL}');
Error('\P{Is_Lb=-/a/HL}');
Expect(1, 64335, '\p{Is_Lb=hl}', "");
Expect(0, 64335, '\p{^Is_Lb=hl}', "");
Expect(0, 64335, '\P{Is_Lb=hl}', "");
Expect(1, 64335, '\P{^Is_Lb=hl}', "");
Expect(0, 64336, '\p{Is_Lb=hl}', "");
Expect(1, 64336, '\p{^Is_Lb=hl}', "");
Expect(1, 64336, '\P{Is_Lb=hl}', "");
Expect(0, 64336, '\P{^Is_Lb=hl}', "");
Expect(1, 64335, '\p{Is_Lb=-HL}', "");
Expect(0, 64335, '\p{^Is_Lb=-HL}', "");
Expect(0, 64335, '\P{Is_Lb=-HL}', "");
Expect(1, 64335, '\P{^Is_Lb=-HL}', "");
Expect(0, 64336, '\p{Is_Lb=-HL}', "");
Expect(1, 64336, '\p{^Is_Lb=-HL}', "");
Expect(1, 64336, '\P{Is_Lb=-HL}', "");
Expect(0, 64336, '\P{^Is_Lb=-HL}', "");
Error('\p{Line_Break=/a/	 HYPHEN}');
Error('\P{Line_Break=/a/	 HYPHEN}');
Expect(1, 45, '\p{Line_Break=hyphen}', "");
Expect(0, 45, '\p{^Line_Break=hyphen}', "");
Expect(0, 45, '\P{Line_Break=hyphen}', "");
Expect(1, 45, '\P{^Line_Break=hyphen}', "");
Expect(0, 46, '\p{Line_Break=hyphen}', "");
Expect(1, 46, '\p{^Line_Break=hyphen}', "");
Expect(1, 46, '\P{Line_Break=hyphen}', "");
Expect(0, 46, '\P{^Line_Break=hyphen}', "");
Expect(1, 45, '\p{Line_Break=--Hyphen}', "");
Expect(0, 45, '\p{^Line_Break=--Hyphen}', "");
Expect(0, 45, '\P{Line_Break=--Hyphen}', "");
Expect(1, 45, '\P{^Line_Break=--Hyphen}', "");
Expect(0, 46, '\p{Line_Break=--Hyphen}', "");
Expect(1, 46, '\p{^Line_Break=--Hyphen}', "");
Expect(1, 46, '\P{Line_Break=--Hyphen}', "");
Expect(0, 46, '\P{^Line_Break=--Hyphen}', "");
Error('\p{Lb=:=--HY}');
Error('\P{Lb=:=--HY}');
Expect(1, 45, '\p{Lb=hy}', "");
Expect(0, 45, '\p{^Lb=hy}', "");
Expect(0, 45, '\P{Lb=hy}', "");
Expect(1, 45, '\P{^Lb=hy}', "");
Expect(0, 46, '\p{Lb=hy}', "");
Expect(1, 46, '\p{^Lb=hy}', "");
Expect(1, 46, '\P{Lb=hy}', "");
Expect(0, 46, '\P{^Lb=hy}', "");
Expect(1, 45, '\p{Lb=_ HY}', "");
Expect(0, 45, '\p{^Lb=_ HY}', "");
Expect(0, 45, '\P{Lb=_ HY}', "");
Expect(1, 45, '\P{^Lb=_ HY}', "");
Expect(0, 46, '\p{Lb=_ HY}', "");
Expect(1, 46, '\p{^Lb=_ HY}', "");
Expect(1, 46, '\P{Lb=_ HY}', "");
Expect(0, 46, '\P{^Lb=_ HY}', "");
Error('\p{Is_Line_Break=-	Hyphen/a/}');
Error('\P{Is_Line_Break=-	Hyphen/a/}');
Expect(1, 45, '\p{Is_Line_Break=hyphen}', "");
Expect(0, 45, '\p{^Is_Line_Break=hyphen}', "");
Expect(0, 45, '\P{Is_Line_Break=hyphen}', "");
Expect(1, 45, '\P{^Is_Line_Break=hyphen}', "");
Expect(0, 46, '\p{Is_Line_Break=hyphen}', "");
Expect(1, 46, '\p{^Is_Line_Break=hyphen}', "");
Expect(1, 46, '\P{Is_Line_Break=hyphen}', "");
Expect(0, 46, '\P{^Is_Line_Break=hyphen}', "");
Expect(1, 45, '\p{Is_Line_Break:   -hyphen}', "");
Expect(0, 45, '\p{^Is_Line_Break:   -hyphen}', "");
Expect(0, 45, '\P{Is_Line_Break:   -hyphen}', "");
Expect(1, 45, '\P{^Is_Line_Break:   -hyphen}', "");
Expect(0, 46, '\p{Is_Line_Break:   -hyphen}', "");
Expect(1, 46, '\p{^Is_Line_Break:   -hyphen}', "");
Expect(1, 46, '\P{Is_Line_Break:   -hyphen}', "");
Expect(0, 46, '\P{^Is_Line_Break:   -hyphen}', "");
Error('\p{Is_Lb=:=_ HY}');
Error('\P{Is_Lb=:=_ HY}');
Expect(1, 45, '\p{Is_Lb=hy}', "");
Expect(0, 45, '\p{^Is_Lb=hy}', "");
Expect(0, 45, '\P{Is_Lb=hy}', "");
Expect(1, 45, '\P{^Is_Lb=hy}', "");
Expect(0, 46, '\p{Is_Lb=hy}', "");
Expect(1, 46, '\p{^Is_Lb=hy}', "");
Expect(1, 46, '\P{Is_Lb=hy}', "");
Expect(0, 46, '\P{^Is_Lb=hy}', "");
Expect(1, 45, '\p{Is_Lb:	HY}', "");
Expect(0, 45, '\p{^Is_Lb:	HY}', "");
Expect(0, 45, '\P{Is_Lb:	HY}', "");
Expect(1, 45, '\P{^Is_Lb:	HY}', "");
Expect(0, 46, '\p{Is_Lb:	HY}', "");
Expect(1, 46, '\p{^Is_Lb:	HY}', "");
Expect(1, 46, '\P{Is_Lb:	HY}', "");
Expect(0, 46, '\P{^Is_Lb:	HY}', "");
Error('\p{Line_Break=:=-Ideographic}');
Error('\P{Line_Break=:=-Ideographic}');
Expect(1, 262141, '\p{Line_Break=ideographic}', "");
Expect(0, 262141, '\p{^Line_Break=ideographic}', "");
Expect(0, 262141, '\P{Line_Break=ideographic}', "");
Expect(1, 262141, '\P{^Line_Break=ideographic}', "");
Expect(0, 262144, '\p{Line_Break=ideographic}', "");
Expect(1, 262144, '\p{^Line_Break=ideographic}', "");
Expect(1, 262144, '\P{Line_Break=ideographic}', "");
Expect(0, 262144, '\P{^Line_Break=ideographic}', "");
Expect(1, 262141, '\p{Line_Break=_ Ideographic}', "");
Expect(0, 262141, '\p{^Line_Break=_ Ideographic}', "");
Expect(0, 262141, '\P{Line_Break=_ Ideographic}', "");
Expect(1, 262141, '\P{^Line_Break=_ Ideographic}', "");
Expect(0, 262144, '\p{Line_Break=_ Ideographic}', "");
Expect(1, 262144, '\p{^Line_Break=_ Ideographic}', "");
Expect(1, 262144, '\P{Line_Break=_ Ideographic}', "");
Expect(0, 262144, '\P{^Line_Break=_ Ideographic}', "");
Error('\p{Lb=:= ID}');
Error('\P{Lb=:= ID}');
Expect(1, 262141, '\p{Lb=id}', "");
Expect(0, 262141, '\p{^Lb=id}', "");
Expect(0, 262141, '\P{Lb=id}', "");
Expect(1, 262141, '\P{^Lb=id}', "");
Expect(0, 262144, '\p{Lb=id}', "");
Expect(1, 262144, '\p{^Lb=id}', "");
Expect(1, 262144, '\P{Lb=id}', "");
Expect(0, 262144, '\P{^Lb=id}', "");
Expect(1, 262141, '\p{Lb:    ID}', "");
Expect(0, 262141, '\p{^Lb:    ID}', "");
Expect(0, 262141, '\P{Lb:    ID}', "");
Expect(1, 262141, '\P{^Lb:    ID}', "");
Expect(0, 262144, '\p{Lb:    ID}', "");
Expect(1, 262144, '\p{^Lb:    ID}', "");
Expect(1, 262144, '\P{Lb:    ID}', "");
Expect(0, 262144, '\P{^Lb:    ID}', "");
Error('\p{Is_Line_Break=:=_-ideographic}');
Error('\P{Is_Line_Break=:=_-ideographic}');
Expect(1, 262141, '\p{Is_Line_Break=ideographic}', "");
Expect(0, 262141, '\p{^Is_Line_Break=ideographic}', "");
Expect(0, 262141, '\P{Is_Line_Break=ideographic}', "");
Expect(1, 262141, '\P{^Is_Line_Break=ideographic}', "");
Expect(0, 262144, '\p{Is_Line_Break=ideographic}', "");
Expect(1, 262144, '\p{^Is_Line_Break=ideographic}', "");
Expect(1, 262144, '\P{Is_Line_Break=ideographic}', "");
Expect(0, 262144, '\P{^Is_Line_Break=ideographic}', "");
Expect(1, 262141, '\p{Is_Line_Break=- ideographic}', "");
Expect(0, 262141, '\p{^Is_Line_Break=- ideographic}', "");
Expect(0, 262141, '\P{Is_Line_Break=- ideographic}', "");
Expect(1, 262141, '\P{^Is_Line_Break=- ideographic}', "");
Expect(0, 262144, '\p{Is_Line_Break=- ideographic}', "");
Expect(1, 262144, '\p{^Is_Line_Break=- ideographic}', "");
Expect(1, 262144, '\P{Is_Line_Break=- ideographic}', "");
Expect(0, 262144, '\P{^Is_Line_Break=- ideographic}', "");
Error('\p{Is_Lb=:=-_ID}');
Error('\P{Is_Lb=:=-_ID}');
Expect(1, 262141, '\p{Is_Lb:   id}', "");
Expect(0, 262141, '\p{^Is_Lb:   id}', "");
Expect(0, 262141, '\P{Is_Lb:   id}', "");
Expect(1, 262141, '\P{^Is_Lb:   id}', "");
Expect(0, 262144, '\p{Is_Lb:   id}', "");
Expect(1, 262144, '\p{^Is_Lb:   id}', "");
Expect(1, 262144, '\P{Is_Lb:   id}', "");
Expect(0, 262144, '\P{^Is_Lb:   id}', "");
Expect(1, 262141, '\p{Is_Lb=-	ID}', "");
Expect(0, 262141, '\p{^Is_Lb=-	ID}', "");
Expect(0, 262141, '\P{Is_Lb=-	ID}', "");
Expect(1, 262141, '\P{^Is_Lb=-	ID}', "");
Expect(0, 262144, '\p{Is_Lb=-	ID}', "");
Expect(1, 262144, '\p{^Is_Lb=-	ID}', "");
Expect(1, 262144, '\P{Is_Lb=-	ID}', "");
Expect(0, 262144, '\P{^Is_Lb=-	ID}', "");
Error('\p{Line_Break:   	_INSEPARABLE:=}');
Error('\P{Line_Break:   	_INSEPARABLE:=}');
Expect(1, 65049, '\p{Line_Break=inseparable}', "");
Expect(0, 65049, '\p{^Line_Break=inseparable}', "");
Expect(0, 65049, '\P{Line_Break=inseparable}', "");
Expect(1, 65049, '\P{^Line_Break=inseparable}', "");
Expect(0, 65050, '\p{Line_Break=inseparable}', "");
Expect(1, 65050, '\p{^Line_Break=inseparable}', "");
Expect(1, 65050, '\P{Line_Break=inseparable}', "");
Expect(0, 65050, '\P{^Line_Break=inseparable}', "");
Expect(1, 65049, '\p{Line_Break=- Inseparable}', "");
Expect(0, 65049, '\p{^Line_Break=- Inseparable}', "");
Expect(0, 65049, '\P{Line_Break=- Inseparable}', "");
Expect(1, 65049, '\P{^Line_Break=- Inseparable}', "");
Expect(0, 65050, '\p{Line_Break=- Inseparable}', "");
Expect(1, 65050, '\p{^Line_Break=- Inseparable}', "");
Expect(1, 65050, '\P{Line_Break=- Inseparable}', "");
Expect(0, 65050, '\P{^Line_Break=- Inseparable}', "");
Error('\p{Lb=/a/ _IN}');
Error('\P{Lb=/a/ _IN}');
Expect(1, 65049, '\p{Lb=in}', "");
Expect(0, 65049, '\p{^Lb=in}', "");
Expect(0, 65049, '\P{Lb=in}', "");
Expect(1, 65049, '\P{^Lb=in}', "");
Expect(0, 65050, '\p{Lb=in}', "");
Expect(1, 65050, '\p{^Lb=in}', "");
Expect(1, 65050, '\P{Lb=in}', "");
Expect(0, 65050, '\P{^Lb=in}', "");
Expect(1, 65049, '\p{Lb= 	in}', "");
Expect(0, 65049, '\p{^Lb= 	in}', "");
Expect(0, 65049, '\P{Lb= 	in}', "");
Expect(1, 65049, '\P{^Lb= 	in}', "");
Expect(0, 65050, '\p{Lb= 	in}', "");
Expect(1, 65050, '\p{^Lb= 	in}', "");
Expect(1, 65050, '\P{Lb= 	in}', "");
Expect(0, 65050, '\P{^Lb= 	in}', "");
Error('\p{Is_Line_Break=/a/	 Inseperable}');
Error('\P{Is_Line_Break=/a/	 Inseperable}');
Expect(1, 65049, '\p{Is_Line_Break=inseperable}', "");
Expect(0, 65049, '\p{^Is_Line_Break=inseperable}', "");
Expect(0, 65049, '\P{Is_Line_Break=inseperable}', "");
Expect(1, 65049, '\P{^Is_Line_Break=inseperable}', "");
Expect(0, 65050, '\p{Is_Line_Break=inseperable}', "");
Expect(1, 65050, '\p{^Is_Line_Break=inseperable}', "");
Expect(1, 65050, '\P{Is_Line_Break=inseperable}', "");
Expect(0, 65050, '\P{^Is_Line_Break=inseperable}', "");
Expect(1, 65049, '\p{Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65049, '\p{^Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65049, '\P{Is_Line_Break=	_INSEPERABLE}', "");
Expect(1, 65049, '\P{^Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65050, '\p{Is_Line_Break=	_INSEPERABLE}', "");
Expect(1, 65050, '\p{^Is_Line_Break=	_INSEPERABLE}', "");
Expect(1, 65050, '\P{Is_Line_Break=	_INSEPERABLE}', "");
Expect(0, 65050, '\P{^Is_Line_Break=	_INSEPERABLE}', "");
Error('\p{Is_Lb=:=Inseparable}');
Error('\P{Is_Lb=:=Inseparable}');
Expect(1, 65049, '\p{Is_Lb=inseparable}', "");
Expect(0, 65049, '\p{^Is_Lb=inseparable}', "");
Expect(0, 65049, '\P{Is_Lb=inseparable}', "");
Expect(1, 65049, '\P{^Is_Lb=inseparable}', "");
Expect(0, 65050, '\p{Is_Lb=inseparable}', "");
Expect(1, 65050, '\p{^Is_Lb=inseparable}', "");
Expect(1, 65050, '\P{Is_Lb=inseparable}', "");
Expect(0, 65050, '\P{^Is_Lb=inseparable}', "");
Expect(1, 65049, '\p{Is_Lb=_-Inseparable}', "");
Expect(0, 65049, '\p{^Is_Lb=_-Inseparable}', "");
Expect(0, 65049, '\P{Is_Lb=_-Inseparable}', "");
Expect(1, 65049, '\P{^Is_Lb=_-Inseparable}', "");
Expect(0, 65050, '\p{Is_Lb=_-Inseparable}', "");
Expect(1, 65050, '\p{^Is_Lb=_-Inseparable}', "");
Expect(1, 65050, '\P{Is_Lb=_-Inseparable}', "");
Expect(0, 65050, '\P{^Is_Lb=_-Inseparable}', "");
Error('\p{Line_Break=:=__Infix_numeric}');
Error('\P{Line_Break=:=__Infix_numeric}');
Expect(1, 65044, '\p{Line_Break=infixnumeric}', "");
Expect(0, 65044, '\p{^Line_Break=infixnumeric}', "");
Expect(0, 65044, '\P{Line_Break=infixnumeric}', "");
Expect(1, 65044, '\P{^Line_Break=infixnumeric}', "");
Expect(0, 65045, '\p{Line_Break=infixnumeric}', "");
Expect(1, 65045, '\p{^Line_Break=infixnumeric}', "");
Expect(1, 65045, '\P{Line_Break=infixnumeric}', "");
Expect(0, 65045, '\P{^Line_Break=infixnumeric}', "");
Expect(1, 65044, '\p{Line_Break=_ infix_numeric}', "");
Expect(0, 65044, '\p{^Line_Break=_ infix_numeric}', "");
Expect(0, 65044, '\P{Line_Break=_ infix_numeric}', "");
Expect(1, 65044, '\P{^Line_Break=_ infix_numeric}', "");
Expect(0, 65045, '\p{Line_Break=_ infix_numeric}', "");
Expect(1, 65045, '\p{^Line_Break=_ infix_numeric}', "");
Expect(1, 65045, '\P{Line_Break=_ infix_numeric}', "");
Expect(0, 65045, '\P{^Line_Break=_ infix_numeric}', "");
Error('\p{Lb=/a/ _IS}');
Error('\P{Lb=/a/ _IS}');
Expect(1, 65044, '\p{Lb=is}', "");
Expect(0, 65044, '\p{^Lb=is}', "");
Expect(0, 65044, '\P{Lb=is}', "");
Expect(1, 65044, '\P{^Lb=is}', "");
Expect(0, 65045, '\p{Lb=is}', "");
Expect(1, 65045, '\p{^Lb=is}', "");
Expect(1, 65045, '\P{Lb=is}', "");
Expect(0, 65045, '\P{^Lb=is}', "");
Expect(1, 65044, '\p{Lb=-	is}', "");
Expect(0, 65044, '\p{^Lb=-	is}', "");
Expect(0, 65044, '\P{Lb=-	is}', "");
Expect(1, 65044, '\P{^Lb=-	is}', "");
Expect(0, 65045, '\p{Lb=-	is}', "");
Expect(1, 65045, '\p{^Lb=-	is}', "");
Expect(1, 65045, '\P{Lb=-	is}', "");
Expect(0, 65045, '\P{^Lb=-	is}', "");
Error('\p{Is_Line_Break=_/a/INFIX_Numeric}');
Error('\P{Is_Line_Break=_/a/INFIX_Numeric}');
Expect(1, 65044, '\p{Is_Line_Break=infixnumeric}', "");
Expect(0, 65044, '\p{^Is_Line_Break=infixnumeric}', "");
Expect(0, 65044, '\P{Is_Line_Break=infixnumeric}', "");
Expect(1, 65044, '\P{^Is_Line_Break=infixnumeric}', "");
Expect(0, 65045, '\p{Is_Line_Break=infixnumeric}', "");
Expect(1, 65045, '\p{^Is_Line_Break=infixnumeric}', "");
Expect(1, 65045, '\P{Is_Line_Break=infixnumeric}', "");
Expect(0, 65045, '\P{^Is_Line_Break=infixnumeric}', "");
Expect(1, 65044, '\p{Is_Line_Break= Infix_NUMERIC}', "");
Expect(0, 65044, '\p{^Is_Line_Break= Infix_NUMERIC}', "");
Expect(0, 65044, '\P{Is_Line_Break= Infix_NUMERIC}', "");
Expect(1, 65044, '\P{^Is_Line_Break= Infix_NUMERIC}', "");
Expect(0, 65045, '\p{Is_Line_Break= Infix_NUMERIC}', "");
Expect(1, 65045, '\p{^Is_Line_Break= Infix_NUMERIC}', "");
Expect(1, 65045, '\P{Is_Line_Break= Infix_NUMERIC}', "");
Expect(0, 65045, '\P{^Is_Line_Break= Infix_NUMERIC}', "");
Error('\p{Is_Lb=	:=IS}');
Error('\P{Is_Lb=	:=IS}');
Expect(1, 65044, '\p{Is_Lb=is}', "");
Expect(0, 65044, '\p{^Is_Lb=is}', "");
Expect(0, 65044, '\P{Is_Lb=is}', "");
Expect(1, 65044, '\P{^Is_Lb=is}', "");
Expect(0, 65045, '\p{Is_Lb=is}', "");
Expect(1, 65045, '\p{^Is_Lb=is}', "");
Expect(1, 65045, '\P{Is_Lb=is}', "");
Expect(0, 65045, '\P{^Is_Lb=is}', "");
Expect(1, 65044, '\p{Is_Lb=-is}', "");
Expect(0, 65044, '\p{^Is_Lb=-is}', "");
Expect(0, 65044, '\P{Is_Lb=-is}', "");
Expect(1, 65044, '\P{^Is_Lb=-is}', "");
Expect(0, 65045, '\p{Is_Lb=-is}', "");
Expect(1, 65045, '\p{^Is_Lb=-is}', "");
Expect(1, 65045, '\P{Is_Lb=-is}', "");
Expect(0, 65045, '\P{^Is_Lb=-is}', "");
Error('\p{Line_Break:	 /a/jl}');
Error('\P{Line_Break:	 /a/jl}');
Expect(1, 43388, '\p{Line_Break:	jl}', "");
Expect(0, 43388, '\p{^Line_Break:	jl}', "");
Expect(0, 43388, '\P{Line_Break:	jl}', "");
Expect(1, 43388, '\P{^Line_Break:	jl}', "");
Expect(0, 43389, '\p{Line_Break:	jl}', "");
Expect(1, 43389, '\p{^Line_Break:	jl}', "");
Expect(1, 43389, '\P{Line_Break:	jl}', "");
Expect(0, 43389, '\P{^Line_Break:	jl}', "");
Expect(1, 43388, '\p{Line_Break= 	JL}', "");
Expect(0, 43388, '\p{^Line_Break= 	JL}', "");
Expect(0, 43388, '\P{Line_Break= 	JL}', "");
Expect(1, 43388, '\P{^Line_Break= 	JL}', "");
Expect(0, 43389, '\p{Line_Break= 	JL}', "");
Expect(1, 43389, '\p{^Line_Break= 	JL}', "");
Expect(1, 43389, '\P{Line_Break= 	JL}', "");
Expect(0, 43389, '\P{^Line_Break= 	JL}', "");
Error('\p{Lb: /a/_	JL}');
Error('\P{Lb: /a/_	JL}');
Expect(1, 43388, '\p{Lb=jl}', "");
Expect(0, 43388, '\p{^Lb=jl}', "");
Expect(0, 43388, '\P{Lb=jl}', "");
Expect(1, 43388, '\P{^Lb=jl}', "");
Expect(0, 43389, '\p{Lb=jl}', "");
Expect(1, 43389, '\p{^Lb=jl}', "");
Expect(1, 43389, '\P{Lb=jl}', "");
Expect(0, 43389, '\P{^Lb=jl}', "");
Expect(1, 43388, '\p{Lb= _JL}', "");
Expect(0, 43388, '\p{^Lb= _JL}', "");
Expect(0, 43388, '\P{Lb= _JL}', "");
Expect(1, 43388, '\P{^Lb= _JL}', "");
Expect(0, 43389, '\p{Lb= _JL}', "");
Expect(1, 43389, '\p{^Lb= _JL}', "");
Expect(1, 43389, '\P{Lb= _JL}', "");
Expect(0, 43389, '\P{^Lb= _JL}', "");
Error('\p{Is_Line_Break:	 _JL/a/}');
Error('\P{Is_Line_Break:	 _JL/a/}');
Expect(1, 43388, '\p{Is_Line_Break=jl}', "");
Expect(0, 43388, '\p{^Is_Line_Break=jl}', "");
Expect(0, 43388, '\P{Is_Line_Break=jl}', "");
Expect(1, 43388, '\P{^Is_Line_Break=jl}', "");
Expect(0, 43389, '\p{Is_Line_Break=jl}', "");
Expect(1, 43389, '\p{^Is_Line_Break=jl}', "");
Expect(1, 43389, '\P{Is_Line_Break=jl}', "");
Expect(0, 43389, '\P{^Is_Line_Break=jl}', "");
Expect(1, 43388, '\p{Is_Line_Break= -JL}', "");
Expect(0, 43388, '\p{^Is_Line_Break= -JL}', "");
Expect(0, 43388, '\P{Is_Line_Break= -JL}', "");
Expect(1, 43388, '\P{^Is_Line_Break= -JL}', "");
Expect(0, 43389, '\p{Is_Line_Break= -JL}', "");
Expect(1, 43389, '\p{^Is_Line_Break= -JL}', "");
Expect(1, 43389, '\P{Is_Line_Break= -JL}', "");
Expect(0, 43389, '\P{^Is_Line_Break= -JL}', "");
Error('\p{Is_Lb=	_JL:=}');
Error('\P{Is_Lb=	_JL:=}');
Expect(1, 43388, '\p{Is_Lb=jl}', "");
Expect(0, 43388, '\p{^Is_Lb=jl}', "");
Expect(0, 43388, '\P{Is_Lb=jl}', "");
Expect(1, 43388, '\P{^Is_Lb=jl}', "");
Expect(0, 43389, '\p{Is_Lb=jl}', "");
Expect(1, 43389, '\p{^Is_Lb=jl}', "");
Expect(1, 43389, '\P{Is_Lb=jl}', "");
Expect(0, 43389, '\P{^Is_Lb=jl}', "");
Expect(1, 43388, '\p{Is_Lb=__JL}', "");
Expect(0, 43388, '\p{^Is_Lb=__JL}', "");
Expect(0, 43388, '\P{Is_Lb=__JL}', "");
Expect(1, 43388, '\P{^Is_Lb=__JL}', "");
Expect(0, 43389, '\p{Is_Lb=__JL}', "");
Expect(1, 43389, '\p{^Is_Lb=__JL}', "");
Expect(1, 43389, '\P{Is_Lb=__JL}', "");
Expect(0, 43389, '\P{^Is_Lb=__JL}', "");
Error('\p{Line_Break=-/a/JT}');
Error('\P{Line_Break=-/a/JT}');
Expect(1, 55291, '\p{Line_Break=jt}', "");
Expect(0, 55291, '\p{^Line_Break=jt}', "");
Expect(0, 55291, '\P{Line_Break=jt}', "");
Expect(1, 55291, '\P{^Line_Break=jt}', "");
Expect(0, 55292, '\p{Line_Break=jt}', "");
Expect(1, 55292, '\p{^Line_Break=jt}', "");
Expect(1, 55292, '\P{Line_Break=jt}', "");
Expect(0, 55292, '\P{^Line_Break=jt}', "");
Expect(1, 55291, '\p{Line_Break:   -_JT}', "");
Expect(0, 55291, '\p{^Line_Break:   -_JT}', "");
Expect(0, 55291, '\P{Line_Break:   -_JT}', "");
Expect(1, 55291, '\P{^Line_Break:   -_JT}', "");
Expect(0, 55292, '\p{Line_Break:   -_JT}', "");
Expect(1, 55292, '\p{^Line_Break:   -_JT}', "");
Expect(1, 55292, '\P{Line_Break:   -_JT}', "");
Expect(0, 55292, '\P{^Line_Break:   -_JT}', "");
Error('\p{Lb=_JT/a/}');
Error('\P{Lb=_JT/a/}');
Expect(1, 55291, '\p{Lb=jt}', "");
Expect(0, 55291, '\p{^Lb=jt}', "");
Expect(0, 55291, '\P{Lb=jt}', "");
Expect(1, 55291, '\P{^Lb=jt}', "");
Expect(0, 55292, '\p{Lb=jt}', "");
Expect(1, 55292, '\p{^Lb=jt}', "");
Expect(1, 55292, '\P{Lb=jt}', "");
Expect(0, 55292, '\P{^Lb=jt}', "");
Expect(1, 55291, '\p{Lb= JT}', "");
Expect(0, 55291, '\p{^Lb= JT}', "");
Expect(0, 55291, '\P{Lb= JT}', "");
Expect(1, 55291, '\P{^Lb= JT}', "");
Expect(0, 55292, '\p{Lb= JT}', "");
Expect(1, 55292, '\p{^Lb= JT}', "");
Expect(1, 55292, '\P{Lb= JT}', "");
Expect(0, 55292, '\P{^Lb= JT}', "");
Error('\p{Is_Line_Break=:=- JT}');
Error('\P{Is_Line_Break=:=- JT}');
Expect(1, 55291, '\p{Is_Line_Break:jt}', "");
Expect(0, 55291, '\p{^Is_Line_Break:jt}', "");
Expect(0, 55291, '\P{Is_Line_Break:jt}', "");
Expect(1, 55291, '\P{^Is_Line_Break:jt}', "");
Expect(0, 55292, '\p{Is_Line_Break:jt}', "");
Expect(1, 55292, '\p{^Is_Line_Break:jt}', "");
Expect(1, 55292, '\P{Is_Line_Break:jt}', "");
Expect(0, 55292, '\P{^Is_Line_Break:jt}', "");
Expect(1, 55291, '\p{Is_Line_Break:   -jt}', "");
Expect(0, 55291, '\p{^Is_Line_Break:   -jt}', "");
Expect(0, 55291, '\P{Is_Line_Break:   -jt}', "");
Expect(1, 55291, '\P{^Is_Line_Break:   -jt}', "");
Expect(0, 55292, '\p{Is_Line_Break:   -jt}', "");
Expect(1, 55292, '\p{^Is_Line_Break:   -jt}', "");
Expect(1, 55292, '\P{Is_Line_Break:   -jt}', "");
Expect(0, 55292, '\P{^Is_Line_Break:   -jt}', "");
Error('\p{Is_Lb=:= -JT}');
Error('\P{Is_Lb=:= -JT}');
Expect(1, 55291, '\p{Is_Lb=jt}', "");
Expect(0, 55291, '\p{^Is_Lb=jt}', "");
Expect(0, 55291, '\P{Is_Lb=jt}', "");
Expect(1, 55291, '\P{^Is_Lb=jt}', "");
Expect(0, 55292, '\p{Is_Lb=jt}', "");
Expect(1, 55292, '\p{^Is_Lb=jt}', "");
Expect(1, 55292, '\P{Is_Lb=jt}', "");
Expect(0, 55292, '\P{^Is_Lb=jt}', "");
Expect(1, 55291, '\p{Is_Lb:   __JT}', "");
Expect(0, 55291, '\p{^Is_Lb:   __JT}', "");
Expect(0, 55291, '\P{Is_Lb:   __JT}', "");
Expect(1, 55291, '\P{^Is_Lb:   __JT}', "");
Expect(0, 55292, '\p{Is_Lb:   __JT}', "");
Expect(1, 55292, '\p{^Is_Lb:   __JT}', "");
Expect(1, 55292, '\P{Is_Lb:   __JT}', "");
Expect(0, 55292, '\P{^Is_Lb:   __JT}', "");
Error('\p{Line_Break=/a/-JV}');
Error('\P{Line_Break=/a/-JV}');
Expect(1, 55238, '\p{Line_Break=jv}', "");
Expect(0, 55238, '\p{^Line_Break=jv}', "");
Expect(0, 55238, '\P{Line_Break=jv}', "");
Expect(1, 55238, '\P{^Line_Break=jv}', "");
Expect(0, 55239, '\p{Line_Break=jv}', "");
Expect(1, 55239, '\p{^Line_Break=jv}', "");
Expect(1, 55239, '\P{Line_Break=jv}', "");
Expect(0, 55239, '\P{^Line_Break=jv}', "");
Expect(1, 55238, '\p{Line_Break= 	jv}', "");
Expect(0, 55238, '\p{^Line_Break= 	jv}', "");
Expect(0, 55238, '\P{Line_Break= 	jv}', "");
Expect(1, 55238, '\P{^Line_Break= 	jv}', "");
Expect(0, 55239, '\p{Line_Break= 	jv}', "");
Expect(1, 55239, '\p{^Line_Break= 	jv}', "");
Expect(1, 55239, '\P{Line_Break= 	jv}', "");
Expect(0, 55239, '\P{^Line_Break= 	jv}', "");
Error('\p{Lb:	 _JV:=}');
Error('\P{Lb:	 _JV:=}');
Expect(1, 55238, '\p{Lb=jv}', "");
Expect(0, 55238, '\p{^Lb=jv}', "");
Expect(0, 55238, '\P{Lb=jv}', "");
Expect(1, 55238, '\P{^Lb=jv}', "");
Expect(0, 55239, '\p{Lb=jv}', "");
Expect(1, 55239, '\p{^Lb=jv}', "");
Expect(1, 55239, '\P{Lb=jv}', "");
Expect(0, 55239, '\P{^Lb=jv}', "");
Expect(1, 55238, '\p{Lb= JV}', "");
Expect(0, 55238, '\p{^Lb= JV}', "");
Expect(0, 55238, '\P{Lb= JV}', "");
Expect(1, 55238, '\P{^Lb= JV}', "");
Expect(0, 55239, '\p{Lb= JV}', "");
Expect(1, 55239, '\p{^Lb= JV}', "");
Expect(1, 55239, '\P{Lb= JV}', "");
Expect(0, 55239, '\P{^Lb= JV}', "");
Error('\p{Is_Line_Break=/a/-	JV}');
Error('\P{Is_Line_Break=/a/-	JV}');
Expect(1, 55238, '\p{Is_Line_Break=jv}', "");
Expect(0, 55238, '\p{^Is_Line_Break=jv}', "");
Expect(0, 55238, '\P{Is_Line_Break=jv}', "");
Expect(1, 55238, '\P{^Is_Line_Break=jv}', "");
Expect(0, 55239, '\p{Is_Line_Break=jv}', "");
Expect(1, 55239, '\p{^Is_Line_Break=jv}', "");
Expect(1, 55239, '\P{Is_Line_Break=jv}', "");
Expect(0, 55239, '\P{^Is_Line_Break=jv}', "");
Expect(1, 55238, '\p{Is_Line_Break= JV}', "");
Expect(0, 55238, '\p{^Is_Line_Break= JV}', "");
Expect(0, 55238, '\P{Is_Line_Break= JV}', "");
Expect(1, 55238, '\P{^Is_Line_Break= JV}', "");
Expect(0, 55239, '\p{Is_Line_Break= JV}', "");
Expect(1, 55239, '\p{^Is_Line_Break= JV}', "");
Expect(1, 55239, '\P{Is_Line_Break= JV}', "");
Expect(0, 55239, '\P{^Is_Line_Break= JV}', "");
Error('\p{Is_Lb=:=_JV}');
Error('\P{Is_Lb=:=_JV}');
Expect(1, 55238, '\p{Is_Lb=jv}', "");
Expect(0, 55238, '\p{^Is_Lb=jv}', "");
Expect(0, 55238, '\P{Is_Lb=jv}', "");
Expect(1, 55238, '\P{^Is_Lb=jv}', "");
Expect(0, 55239, '\p{Is_Lb=jv}', "");
Expect(1, 55239, '\p{^Is_Lb=jv}', "");
Expect(1, 55239, '\P{Is_Lb=jv}', "");
Expect(0, 55239, '\P{^Is_Lb=jv}', "");
Expect(1, 55238, '\p{Is_Lb=	jv}', "");
Expect(0, 55238, '\p{^Is_Lb=	jv}', "");
Expect(0, 55238, '\P{Is_Lb=	jv}', "");
Expect(1, 55238, '\P{^Is_Lb=	jv}', "");
Expect(0, 55239, '\p{Is_Lb=	jv}', "");
Expect(1, 55239, '\p{^Is_Lb=	jv}', "");
Expect(1, 55239, '\P{Is_Lb=	jv}', "");
Expect(0, 55239, '\P{^Is_Lb=	jv}', "");
Error('\p{Line_Break= /a/line_FEED}');
Error('\P{Line_Break= /a/line_FEED}');
Expect(1, 10, '\p{Line_Break=linefeed}', "");
Expect(0, 10, '\p{^Line_Break=linefeed}', "");
Expect(0, 10, '\P{Line_Break=linefeed}', "");
Expect(1, 10, '\P{^Line_Break=linefeed}', "");
Expect(0, 11, '\p{Line_Break=linefeed}', "");
Expect(1, 11, '\p{^Line_Break=linefeed}', "");
Expect(1, 11, '\P{Line_Break=linefeed}', "");
Expect(0, 11, '\P{^Line_Break=linefeed}', "");
Expect(1, 10, '\p{Line_Break=- Line_Feed}', "");
Expect(0, 10, '\p{^Line_Break=- Line_Feed}', "");
Expect(0, 10, '\P{Line_Break=- Line_Feed}', "");
Expect(1, 10, '\P{^Line_Break=- Line_Feed}', "");
Expect(0, 11, '\p{Line_Break=- Line_Feed}', "");
Expect(1, 11, '\p{^Line_Break=- Line_Feed}', "");
Expect(1, 11, '\P{Line_Break=- Line_Feed}', "");
Expect(0, 11, '\P{^Line_Break=- Line_Feed}', "");
Error('\p{Lb=	/a/LF}');
Error('\P{Lb=	/a/LF}');
Expect(1, 10, '\p{Lb=lf}', "");
Expect(0, 10, '\p{^Lb=lf}', "");
Expect(0, 10, '\P{Lb=lf}', "");
Expect(1, 10, '\P{^Lb=lf}', "");
Expect(0, 11, '\p{Lb=lf}', "");
Expect(1, 11, '\p{^Lb=lf}', "");
Expect(1, 11, '\P{Lb=lf}', "");
Expect(0, 11, '\P{^Lb=lf}', "");
Expect(1, 10, '\p{Lb=_ lf}', "");
Expect(0, 10, '\p{^Lb=_ lf}', "");
Expect(0, 10, '\P{Lb=_ lf}', "");
Expect(1, 10, '\P{^Lb=_ lf}', "");
Expect(0, 11, '\p{Lb=_ lf}', "");
Expect(1, 11, '\p{^Lb=_ lf}', "");
Expect(1, 11, '\P{Lb=_ lf}', "");
Expect(0, 11, '\P{^Lb=_ lf}', "");
Error('\p{Is_Line_Break:   :=LINE_Feed}');
Error('\P{Is_Line_Break:   :=LINE_Feed}');
Expect(1, 10, '\p{Is_Line_Break=linefeed}', "");
Expect(0, 10, '\p{^Is_Line_Break=linefeed}', "");
Expect(0, 10, '\P{Is_Line_Break=linefeed}', "");
Expect(1, 10, '\P{^Is_Line_Break=linefeed}', "");
Expect(0, 11, '\p{Is_Line_Break=linefeed}', "");
Expect(1, 11, '\p{^Is_Line_Break=linefeed}', "");
Expect(1, 11, '\P{Is_Line_Break=linefeed}', "");
Expect(0, 11, '\P{^Is_Line_Break=linefeed}', "");
Expect(1, 10, '\p{Is_Line_Break=--line_Feed}', "");
Expect(0, 10, '\p{^Is_Line_Break=--line_Feed}', "");
Expect(0, 10, '\P{Is_Line_Break=--line_Feed}', "");
Expect(1, 10, '\P{^Is_Line_Break=--line_Feed}', "");
Expect(0, 11, '\p{Is_Line_Break=--line_Feed}', "");
Expect(1, 11, '\p{^Is_Line_Break=--line_Feed}', "");
Expect(1, 11, '\P{Is_Line_Break=--line_Feed}', "");
Expect(0, 11, '\P{^Is_Line_Break=--line_Feed}', "");
Error('\p{Is_Lb=_/a/LF}');
Error('\P{Is_Lb=_/a/LF}');
Expect(1, 10, '\p{Is_Lb=lf}', "");
Expect(0, 10, '\p{^Is_Lb=lf}', "");
Expect(0, 10, '\P{Is_Lb=lf}', "");
Expect(1, 10, '\P{^Is_Lb=lf}', "");
Expect(0, 11, '\p{Is_Lb=lf}', "");
Expect(1, 11, '\p{^Is_Lb=lf}', "");
Expect(1, 11, '\P{Is_Lb=lf}', "");
Expect(0, 11, '\P{^Is_Lb=lf}', "");
Expect(1, 10, '\p{Is_Lb=_lf}', "");
Expect(0, 10, '\p{^Is_Lb=_lf}', "");
Expect(0, 10, '\P{Is_Lb=_lf}', "");
Expect(1, 10, '\P{^Is_Lb=_lf}', "");
Expect(0, 11, '\p{Is_Lb=_lf}', "");
Expect(1, 11, '\p{^Is_Lb=_lf}', "");
Expect(1, 11, '\P{Is_Lb=_lf}', "");
Expect(0, 11, '\P{^Is_Lb=_lf}', "");
Error('\p{Line_Break= 	next_line:=}');
Error('\P{Line_Break= 	next_line:=}');
Expect(1, 133, '\p{Line_Break:	nextline}', "");
Expect(0, 133, '\p{^Line_Break:	nextline}', "");
Expect(0, 133, '\P{Line_Break:	nextline}', "");
Expect(1, 133, '\P{^Line_Break:	nextline}', "");
Expect(0, 134, '\p{Line_Break:	nextline}', "");
Expect(1, 134, '\p{^Line_Break:	nextline}', "");
Expect(1, 134, '\P{Line_Break:	nextline}', "");
Expect(0, 134, '\P{^Line_Break:	nextline}', "");
Expect(1, 133, '\p{Line_Break: -NEXT_LINE}', "");
Expect(0, 133, '\p{^Line_Break: -NEXT_LINE}', "");
Expect(0, 133, '\P{Line_Break: -NEXT_LINE}', "");
Expect(1, 133, '\P{^Line_Break: -NEXT_LINE}', "");
Expect(0, 134, '\p{Line_Break: -NEXT_LINE}', "");
Expect(1, 134, '\p{^Line_Break: -NEXT_LINE}', "");
Expect(1, 134, '\P{Line_Break: -NEXT_LINE}', "");
Expect(0, 134, '\P{^Line_Break: -NEXT_LINE}', "");
Error('\p{Lb=:=	nl}');
Error('\P{Lb=:=	nl}');
Expect(1, 133, '\p{Lb=nl}', "");
Expect(0, 133, '\p{^Lb=nl}', "");
Expect(0, 133, '\P{Lb=nl}', "");
Expect(1, 133, '\P{^Lb=nl}', "");
Expect(0, 134, '\p{Lb=nl}', "");
Expect(1, 134, '\p{^Lb=nl}', "");
Expect(1, 134, '\P{Lb=nl}', "");
Expect(0, 134, '\P{^Lb=nl}', "");
Expect(1, 133, '\p{Lb:	-NL}', "");
Expect(0, 133, '\p{^Lb:	-NL}', "");
Expect(0, 133, '\P{Lb:	-NL}', "");
Expect(1, 133, '\P{^Lb:	-NL}', "");
Expect(0, 134, '\p{Lb:	-NL}', "");
Expect(1, 134, '\p{^Lb:	-NL}', "");
Expect(1, 134, '\P{Lb:	-NL}', "");
Expect(0, 134, '\P{^Lb:	-NL}', "");
Error('\p{Is_Line_Break=:=	_Next_LINE}');
Error('\P{Is_Line_Break=:=	_Next_LINE}');
Expect(1, 133, '\p{Is_Line_Break=nextline}', "");
Expect(0, 133, '\p{^Is_Line_Break=nextline}', "");
Expect(0, 133, '\P{Is_Line_Break=nextline}', "");
Expect(1, 133, '\P{^Is_Line_Break=nextline}', "");
Expect(0, 134, '\p{Is_Line_Break=nextline}', "");
Expect(1, 134, '\p{^Is_Line_Break=nextline}', "");
Expect(1, 134, '\P{Is_Line_Break=nextline}', "");
Expect(0, 134, '\P{^Is_Line_Break=nextline}', "");
Expect(1, 133, '\p{Is_Line_Break:			Next_Line}', "");
Expect(0, 133, '\p{^Is_Line_Break:			Next_Line}', "");
Expect(0, 133, '\P{Is_Line_Break:			Next_Line}', "");
Expect(1, 133, '\P{^Is_Line_Break:			Next_Line}', "");
Expect(0, 134, '\p{Is_Line_Break:			Next_Line}', "");
Expect(1, 134, '\p{^Is_Line_Break:			Next_Line}', "");
Expect(1, 134, '\P{Is_Line_Break:			Next_Line}', "");
Expect(0, 134, '\P{^Is_Line_Break:			Next_Line}', "");
Error('\p{Is_Lb=/a/nl}');
Error('\P{Is_Lb=/a/nl}');
Expect(1, 133, '\p{Is_Lb=nl}', "");
Expect(0, 133, '\p{^Is_Lb=nl}', "");
Expect(0, 133, '\P{Is_Lb=nl}', "");
Expect(1, 133, '\P{^Is_Lb=nl}', "");
Expect(0, 134, '\p{Is_Lb=nl}', "");
Expect(1, 134, '\p{^Is_Lb=nl}', "");
Expect(1, 134, '\P{Is_Lb=nl}', "");
Expect(0, 134, '\P{^Is_Lb=nl}', "");
Expect(1, 133, '\p{Is_Lb=--nl}', "");
Expect(0, 133, '\p{^Is_Lb=--nl}', "");
Expect(0, 133, '\P{Is_Lb=--nl}', "");
Expect(1, 133, '\P{^Is_Lb=--nl}', "");
Expect(0, 134, '\p{Is_Lb=--nl}', "");
Expect(1, 134, '\p{^Is_Lb=--nl}', "");
Expect(1, 134, '\P{Is_Lb=--nl}', "");
Expect(0, 134, '\P{^Is_Lb=--nl}', "");
Error('\p{Line_Break=/a/Nonstarter}');
Error('\P{Line_Break=/a/Nonstarter}');
Expect(1, 65439, '\p{Line_Break=nonstarter}', "");
Expect(0, 65439, '\p{^Line_Break=nonstarter}', "");
Expect(0, 65439, '\P{Line_Break=nonstarter}', "");
Expect(1, 65439, '\P{^Line_Break=nonstarter}', "");
Expect(0, 65440, '\p{Line_Break=nonstarter}', "");
Expect(1, 65440, '\p{^Line_Break=nonstarter}', "");
Expect(1, 65440, '\P{Line_Break=nonstarter}', "");
Expect(0, 65440, '\P{^Line_Break=nonstarter}', "");
Expect(1, 65439, '\p{Line_Break=	Nonstarter}', "");
Expect(0, 65439, '\p{^Line_Break=	Nonstarter}', "");
Expect(0, 65439, '\P{Line_Break=	Nonstarter}', "");
Expect(1, 65439, '\P{^Line_Break=	Nonstarter}', "");
Expect(0, 65440, '\p{Line_Break=	Nonstarter}', "");
Expect(1, 65440, '\p{^Line_Break=	Nonstarter}', "");
Expect(1, 65440, '\P{Line_Break=	Nonstarter}', "");
Expect(0, 65440, '\P{^Line_Break=	Nonstarter}', "");
Error('\p{Lb=	/a/NS}');
Error('\P{Lb=	/a/NS}');
Expect(1, 65439, '\p{Lb=ns}', "");
Expect(0, 65439, '\p{^Lb=ns}', "");
Expect(0, 65439, '\P{Lb=ns}', "");
Expect(1, 65439, '\P{^Lb=ns}', "");
Expect(0, 65440, '\p{Lb=ns}', "");
Expect(1, 65440, '\p{^Lb=ns}', "");
Expect(1, 65440, '\P{Lb=ns}', "");
Expect(0, 65440, '\P{^Lb=ns}', "");
Expect(1, 65439, '\p{Lb=	NS}', "");
Expect(0, 65439, '\p{^Lb=	NS}', "");
Expect(0, 65439, '\P{Lb=	NS}', "");
Expect(1, 65439, '\P{^Lb=	NS}', "");
Expect(0, 65440, '\p{Lb=	NS}', "");
Expect(1, 65440, '\p{^Lb=	NS}', "");
Expect(1, 65440, '\P{Lb=	NS}', "");
Expect(0, 65440, '\P{^Lb=	NS}', "");
Error('\p{Is_Line_Break=:= Nonstarter}');
Error('\P{Is_Line_Break=:= Nonstarter}');
Expect(1, 65439, '\p{Is_Line_Break=nonstarter}', "");
Expect(0, 65439, '\p{^Is_Line_Break=nonstarter}', "");
Expect(0, 65439, '\P{Is_Line_Break=nonstarter}', "");
Expect(1, 65439, '\P{^Is_Line_Break=nonstarter}', "");
Expect(0, 65440, '\p{Is_Line_Break=nonstarter}', "");
Expect(1, 65440, '\p{^Is_Line_Break=nonstarter}', "");
Expect(1, 65440, '\P{Is_Line_Break=nonstarter}', "");
Expect(0, 65440, '\P{^Is_Line_Break=nonstarter}', "");
Expect(1, 65439, '\p{Is_Line_Break=_-Nonstarter}', "");
Expect(0, 65439, '\p{^Is_Line_Break=_-Nonstarter}', "");
Expect(0, 65439, '\P{Is_Line_Break=_-Nonstarter}', "");
Expect(1, 65439, '\P{^Is_Line_Break=_-Nonstarter}', "");
Expect(0, 65440, '\p{Is_Line_Break=_-Nonstarter}', "");
Expect(1, 65440, '\p{^Is_Line_Break=_-Nonstarter}', "");
Expect(1, 65440, '\P{Is_Line_Break=_-Nonstarter}', "");
Expect(0, 65440, '\P{^Is_Line_Break=_-Nonstarter}', "");
Error('\p{Is_Lb=/a/  NS}');
Error('\P{Is_Lb=/a/  NS}');
Expect(1, 65439, '\p{Is_Lb=ns}', "");
Expect(0, 65439, '\p{^Is_Lb=ns}', "");
Expect(0, 65439, '\P{Is_Lb=ns}', "");
Expect(1, 65439, '\P{^Is_Lb=ns}', "");
Expect(0, 65440, '\p{Is_Lb=ns}', "");
Expect(1, 65440, '\p{^Is_Lb=ns}', "");
Expect(1, 65440, '\P{Is_Lb=ns}', "");
Expect(0, 65440, '\P{^Is_Lb=ns}', "");
Expect(1, 65439, '\p{Is_Lb= _ns}', "");
Expect(0, 65439, '\p{^Is_Lb= _ns}', "");
Expect(0, 65439, '\P{Is_Lb= _ns}', "");
Expect(1, 65439, '\P{^Is_Lb= _ns}', "");
Expect(0, 65440, '\p{Is_Lb= _ns}', "");
Expect(1, 65440, '\p{^Is_Lb= _ns}', "");
Expect(1, 65440, '\P{Is_Lb= _ns}', "");
Expect(0, 65440, '\P{^Is_Lb= _ns}', "");
Error('\p{Line_Break=/a/_	NUMERIC}');
Error('\P{Line_Break=/a/_	NUMERIC}');
Expect(1, 120831, '\p{Line_Break=numeric}', "");
Expect(0, 120831, '\p{^Line_Break=numeric}', "");
Expect(0, 120831, '\P{Line_Break=numeric}', "");
Expect(1, 120831, '\P{^Line_Break=numeric}', "");
Expect(0, 120832, '\p{Line_Break=numeric}', "");
Expect(1, 120832, '\p{^Line_Break=numeric}', "");
Expect(1, 120832, '\P{Line_Break=numeric}', "");
Expect(0, 120832, '\P{^Line_Break=numeric}', "");
Expect(1, 120831, '\p{Line_Break=-numeric}', "");
Expect(0, 120831, '\p{^Line_Break=-numeric}', "");
Expect(0, 120831, '\P{Line_Break=-numeric}', "");
Expect(1, 120831, '\P{^Line_Break=-numeric}', "");
Expect(0, 120832, '\p{Line_Break=-numeric}', "");
Expect(1, 120832, '\p{^Line_Break=-numeric}', "");
Expect(1, 120832, '\P{Line_Break=-numeric}', "");
Expect(0, 120832, '\P{^Line_Break=-numeric}', "");
Error('\p{Lb= NU/a/}');
Error('\P{Lb= NU/a/}');
Expect(1, 120831, '\p{Lb=nu}', "");
Expect(0, 120831, '\p{^Lb=nu}', "");
Expect(0, 120831, '\P{Lb=nu}', "");
Expect(1, 120831, '\P{^Lb=nu}', "");
Expect(0, 120832, '\p{Lb=nu}', "");
Expect(1, 120832, '\p{^Lb=nu}', "");
Expect(1, 120832, '\P{Lb=nu}', "");
Expect(0, 120832, '\P{^Lb=nu}', "");
Expect(1, 120831, '\p{Lb=__nu}', "");
Expect(0, 120831, '\p{^Lb=__nu}', "");
Expect(0, 120831, '\P{Lb=__nu}', "");
Expect(1, 120831, '\P{^Lb=__nu}', "");
Expect(0, 120832, '\p{Lb=__nu}', "");
Expect(1, 120832, '\p{^Lb=__nu}', "");
Expect(1, 120832, '\P{Lb=__nu}', "");
Expect(0, 120832, '\P{^Lb=__nu}', "");
Error('\p{Is_Line_Break=:=  NUMERIC}');
Error('\P{Is_Line_Break=:=  NUMERIC}');
Expect(1, 120831, '\p{Is_Line_Break=numeric}', "");
Expect(0, 120831, '\p{^Is_Line_Break=numeric}', "");
Expect(0, 120831, '\P{Is_Line_Break=numeric}', "");
Expect(1, 120831, '\P{^Is_Line_Break=numeric}', "");
Expect(0, 120832, '\p{Is_Line_Break=numeric}', "");
Expect(1, 120832, '\p{^Is_Line_Break=numeric}', "");
Expect(1, 120832, '\P{Is_Line_Break=numeric}', "");
Expect(0, 120832, '\P{^Is_Line_Break=numeric}', "");
Expect(1, 120831, '\p{Is_Line_Break=	 Numeric}', "");
Expect(0, 120831, '\p{^Is_Line_Break=	 Numeric}', "");
Expect(0, 120831, '\P{Is_Line_Break=	 Numeric}', "");
Expect(1, 120831, '\P{^Is_Line_Break=	 Numeric}', "");
Expect(0, 120832, '\p{Is_Line_Break=	 Numeric}', "");
Expect(1, 120832, '\p{^Is_Line_Break=	 Numeric}', "");
Expect(1, 120832, '\P{Is_Line_Break=	 Numeric}', "");
Expect(0, 120832, '\P{^Is_Line_Break=	 Numeric}', "");
Error('\p{Is_Lb=	NU/a/}');
Error('\P{Is_Lb=	NU/a/}');
Expect(1, 120831, '\p{Is_Lb=nu}', "");
Expect(0, 120831, '\p{^Is_Lb=nu}', "");
Expect(0, 120831, '\P{Is_Lb=nu}', "");
Expect(1, 120831, '\P{^Is_Lb=nu}', "");
Expect(0, 120832, '\p{Is_Lb=nu}', "");
Expect(1, 120832, '\p{^Is_Lb=nu}', "");
Expect(1, 120832, '\P{Is_Lb=nu}', "");
Expect(0, 120832, '\P{^Is_Lb=nu}', "");
Expect(1, 120831, '\p{Is_Lb:	_-NU}', "");
Expect(0, 120831, '\p{^Is_Lb:	_-NU}', "");
Expect(0, 120831, '\P{Is_Lb:	_-NU}', "");
Expect(1, 120831, '\P{^Is_Lb:	_-NU}', "");
Expect(0, 120832, '\p{Is_Lb:	_-NU}', "");
Expect(1, 120832, '\p{^Is_Lb:	_-NU}', "");
Expect(1, 120832, '\P{Is_Lb:	_-NU}', "");
Expect(0, 120832, '\P{^Is_Lb:	_-NU}', "");
Error('\p{Line_Break=:=	OPEN_Punctuation}');
Error('\P{Line_Break=:=	OPEN_Punctuation}');
Expect(1, 78713, '\p{Line_Break=openpunctuation}', "");
Expect(0, 78713, '\p{^Line_Break=openpunctuation}', "");
Expect(0, 78713, '\P{Line_Break=openpunctuation}', "");
Expect(1, 78713, '\P{^Line_Break=openpunctuation}', "");
Expect(0, 78714, '\p{Line_Break=openpunctuation}', "");
Expect(1, 78714, '\p{^Line_Break=openpunctuation}', "");
Expect(1, 78714, '\P{Line_Break=openpunctuation}', "");
Expect(0, 78714, '\P{^Line_Break=openpunctuation}', "");
Expect(1, 78713, '\p{Line_Break=_	OPEN_punctuation}', "");
Expect(0, 78713, '\p{^Line_Break=_	OPEN_punctuation}', "");
Expect(0, 78713, '\P{Line_Break=_	OPEN_punctuation}', "");
Expect(1, 78713, '\P{^Line_Break=_	OPEN_punctuation}', "");
Expect(0, 78714, '\p{Line_Break=_	OPEN_punctuation}', "");
Expect(1, 78714, '\p{^Line_Break=_	OPEN_punctuation}', "");
Expect(1, 78714, '\P{Line_Break=_	OPEN_punctuation}', "");
Expect(0, 78714, '\P{^Line_Break=_	OPEN_punctuation}', "");
Error('\p{Lb:   /a/-	OP}');
Error('\P{Lb:   /a/-	OP}');
Expect(1, 78713, '\p{Lb=op}', "");
Expect(0, 78713, '\p{^Lb=op}', "");
Expect(0, 78713, '\P{Lb=op}', "");
Expect(1, 78713, '\P{^Lb=op}', "");
Expect(0, 78714, '\p{Lb=op}', "");
Expect(1, 78714, '\p{^Lb=op}', "");
Expect(1, 78714, '\P{Lb=op}', "");
Expect(0, 78714, '\P{^Lb=op}', "");
Expect(1, 78713, '\p{Lb=	_op}', "");
Expect(0, 78713, '\p{^Lb=	_op}', "");
Expect(0, 78713, '\P{Lb=	_op}', "");
Expect(1, 78713, '\P{^Lb=	_op}', "");
Expect(0, 78714, '\p{Lb=	_op}', "");
Expect(1, 78714, '\p{^Lb=	_op}', "");
Expect(1, 78714, '\P{Lb=	_op}', "");
Expect(0, 78714, '\P{^Lb=	_op}', "");
Error('\p{Is_Line_Break= 	Open_punctuation/a/}');
Error('\P{Is_Line_Break= 	Open_punctuation/a/}');
Expect(1, 78713, '\p{Is_Line_Break=openpunctuation}', "");
Expect(0, 78713, '\p{^Is_Line_Break=openpunctuation}', "");
Expect(0, 78713, '\P{Is_Line_Break=openpunctuation}', "");
Expect(1, 78713, '\P{^Is_Line_Break=openpunctuation}', "");
Expect(0, 78714, '\p{Is_Line_Break=openpunctuation}', "");
Expect(1, 78714, '\p{^Is_Line_Break=openpunctuation}', "");
Expect(1, 78714, '\P{Is_Line_Break=openpunctuation}', "");
Expect(0, 78714, '\P{^Is_Line_Break=openpunctuation}', "");
Expect(1, 78713, '\p{Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(0, 78713, '\p{^Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(0, 78713, '\P{Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(1, 78713, '\P{^Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(0, 78714, '\p{Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(1, 78714, '\p{^Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(1, 78714, '\P{Is_Line_Break:		-open_PUNCTUATION}', "");
Expect(0, 78714, '\P{^Is_Line_Break:		-open_PUNCTUATION}', "");
Error('\p{Is_Lb=:= -op}');
Error('\P{Is_Lb=:= -op}');
Expect(1, 78713, '\p{Is_Lb=op}', "");
Expect(0, 78713, '\p{^Is_Lb=op}', "");
Expect(0, 78713, '\P{Is_Lb=op}', "");
Expect(1, 78713, '\P{^Is_Lb=op}', "");
Expect(0, 78714, '\p{Is_Lb=op}', "");
Expect(1, 78714, '\p{^Is_Lb=op}', "");
Expect(1, 78714, '\P{Is_Lb=op}', "");
Expect(0, 78714, '\P{^Is_Lb=op}', "");
Expect(1, 78713, '\p{Is_Lb=-	OP}', "");
Expect(0, 78713, '\p{^Is_Lb=-	OP}', "");
Expect(0, 78713, '\P{Is_Lb=-	OP}', "");
Expect(1, 78713, '\P{^Is_Lb=-	OP}', "");
Expect(0, 78714, '\p{Is_Lb=-	OP}', "");
Expect(1, 78714, '\p{^Is_Lb=-	OP}', "");
Expect(1, 78714, '\P{Is_Lb=-	OP}', "");
Expect(0, 78714, '\P{^Is_Lb=-	OP}', "");
Error('\p{Line_Break=:=Postfix_Numeric}');
Error('\P{Line_Break=:=Postfix_Numeric}');
Expect(1, 65504, '\p{Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\p{^Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\P{Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\P{^Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\p{Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\p{^Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\P{Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\P{^Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\p{Line_Break=Postfix_Numeric}', "");
Expect(0, 65504, '\p{^Line_Break=Postfix_Numeric}', "");
Expect(0, 65504, '\P{Line_Break=Postfix_Numeric}', "");
Expect(1, 65504, '\P{^Line_Break=Postfix_Numeric}', "");
Expect(0, 65505, '\p{Line_Break=Postfix_Numeric}', "");
Expect(1, 65505, '\p{^Line_Break=Postfix_Numeric}', "");
Expect(1, 65505, '\P{Line_Break=Postfix_Numeric}', "");
Expect(0, 65505, '\P{^Line_Break=Postfix_Numeric}', "");
Error('\p{Lb:  /a/PO}');
Error('\P{Lb:  /a/PO}');
Expect(1, 65504, '\p{Lb=po}', "");
Expect(0, 65504, '\p{^Lb=po}', "");
Expect(0, 65504, '\P{Lb=po}', "");
Expect(1, 65504, '\P{^Lb=po}', "");
Expect(0, 65505, '\p{Lb=po}', "");
Expect(1, 65505, '\p{^Lb=po}', "");
Expect(1, 65505, '\P{Lb=po}', "");
Expect(0, 65505, '\P{^Lb=po}', "");
Expect(1, 65504, '\p{Lb=_-po}', "");
Expect(0, 65504, '\p{^Lb=_-po}', "");
Expect(0, 65504, '\P{Lb=_-po}', "");
Expect(1, 65504, '\P{^Lb=_-po}', "");
Expect(0, 65505, '\p{Lb=_-po}', "");
Expect(1, 65505, '\p{^Lb=_-po}', "");
Expect(1, 65505, '\P{Lb=_-po}', "");
Expect(0, 65505, '\P{^Lb=_-po}', "");
Error('\p{Is_Line_Break=/a/	POSTFIX_Numeric}');
Error('\P{Is_Line_Break=/a/	POSTFIX_Numeric}');
Expect(1, 65504, '\p{Is_Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\p{^Is_Line_Break=postfixnumeric}', "");
Expect(0, 65504, '\P{Is_Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\P{^Is_Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\p{Is_Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\p{^Is_Line_Break=postfixnumeric}', "");
Expect(1, 65505, '\P{Is_Line_Break=postfixnumeric}', "");
Expect(0, 65505, '\P{^Is_Line_Break=postfixnumeric}', "");
Expect(1, 65504, '\p{Is_Line_Break: -Postfix_Numeric}', "");
Expect(0, 65504, '\p{^Is_Line_Break: -Postfix_Numeric}', "");
Expect(0, 65504, '\P{Is_Line_Break: -Postfix_Numeric}', "");
Expect(1, 65504, '\P{^Is_Line_Break: -Postfix_Numeric}', "");
Expect(0, 65505, '\p{Is_Line_Break: -Postfix_Numeric}', "");
Expect(1, 65505, '\p{^Is_Line_Break: -Postfix_Numeric}', "");
Expect(1, 65505, '\P{Is_Line_Break: -Postfix_Numeric}', "");
Expect(0, 65505, '\P{^Is_Line_Break: -Postfix_Numeric}', "");
Error('\p{Is_Lb=_/a/PO}');
Error('\P{Is_Lb=_/a/PO}');
Expect(1, 65504, '\p{Is_Lb=po}', "");
Expect(0, 65504, '\p{^Is_Lb=po}', "");
Expect(0, 65504, '\P{Is_Lb=po}', "");
Expect(1, 65504, '\P{^Is_Lb=po}', "");
Expect(0, 65505, '\p{Is_Lb=po}', "");
Expect(1, 65505, '\p{^Is_Lb=po}', "");
Expect(1, 65505, '\P{Is_Lb=po}', "");
Expect(0, 65505, '\P{^Is_Lb=po}', "");
Expect(1, 65504, '\p{Is_Lb=  PO}', "");
Expect(0, 65504, '\p{^Is_Lb=  PO}', "");
Expect(0, 65504, '\P{Is_Lb=  PO}', "");
Expect(1, 65504, '\P{^Is_Lb=  PO}', "");
Expect(0, 65505, '\p{Is_Lb=  PO}', "");
Expect(1, 65505, '\p{^Is_Lb=  PO}', "");
Expect(1, 65505, '\P{Is_Lb=  PO}', "");
Expect(0, 65505, '\P{^Is_Lb=  PO}', "");
Error('\p{Line_Break=-/a/prefix_Numeric}');
Error('\P{Line_Break=-/a/prefix_Numeric}');
Expect(1, 65510, '\p{Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\p{^Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\P{Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\P{^Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\p{Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\p{^Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\P{Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\P{^Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\p{Line_Break=  Prefix_numeric}', "");
Expect(0, 65510, '\p{^Line_Break=  Prefix_numeric}', "");
Expect(0, 65510, '\P{Line_Break=  Prefix_numeric}', "");
Expect(1, 65510, '\P{^Line_Break=  Prefix_numeric}', "");
Expect(0, 65511, '\p{Line_Break=  Prefix_numeric}', "");
Expect(1, 65511, '\p{^Line_Break=  Prefix_numeric}', "");
Expect(1, 65511, '\P{Line_Break=  Prefix_numeric}', "");
Expect(0, 65511, '\P{^Line_Break=  Prefix_numeric}', "");
Error('\p{Lb=-PR:=}');
Error('\P{Lb=-PR:=}');
Expect(1, 65510, '\p{Lb=pr}', "");
Expect(0, 65510, '\p{^Lb=pr}', "");
Expect(0, 65510, '\P{Lb=pr}', "");
Expect(1, 65510, '\P{^Lb=pr}', "");
Expect(0, 65511, '\p{Lb=pr}', "");
Expect(1, 65511, '\p{^Lb=pr}', "");
Expect(1, 65511, '\P{Lb=pr}', "");
Expect(0, 65511, '\P{^Lb=pr}', "");
Expect(1, 65510, '\p{Lb=	PR}', "");
Expect(0, 65510, '\p{^Lb=	PR}', "");
Expect(0, 65510, '\P{Lb=	PR}', "");
Expect(1, 65510, '\P{^Lb=	PR}', "");
Expect(0, 65511, '\p{Lb=	PR}', "");
Expect(1, 65511, '\p{^Lb=	PR}', "");
Expect(1, 65511, '\P{Lb=	PR}', "");
Expect(0, 65511, '\P{^Lb=	PR}', "");
Error('\p{Is_Line_Break:    /a/PREFIX_Numeric}');
Error('\P{Is_Line_Break:    /a/PREFIX_Numeric}');
Expect(1, 65510, '\p{Is_Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\p{^Is_Line_Break=prefixnumeric}', "");
Expect(0, 65510, '\P{Is_Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\P{^Is_Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\p{Is_Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\p{^Is_Line_Break=prefixnumeric}', "");
Expect(1, 65511, '\P{Is_Line_Break=prefixnumeric}', "");
Expect(0, 65511, '\P{^Is_Line_Break=prefixnumeric}', "");
Expect(1, 65510, '\p{Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(0, 65510, '\p{^Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(0, 65510, '\P{Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(1, 65510, '\P{^Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(0, 65511, '\p{Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(1, 65511, '\p{^Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(1, 65511, '\P{Is_Line_Break=	Prefix_NUMERIC}', "");
Expect(0, 65511, '\P{^Is_Line_Break=	Prefix_NUMERIC}', "");
Error('\p{Is_Lb=/a/PR}');
Error('\P{Is_Lb=/a/PR}');
Expect(1, 65510, '\p{Is_Lb=pr}', "");
Expect(0, 65510, '\p{^Is_Lb=pr}', "");
Expect(0, 65510, '\P{Is_Lb=pr}', "");
Expect(1, 65510, '\P{^Is_Lb=pr}', "");
Expect(0, 65511, '\p{Is_Lb=pr}', "");
Expect(1, 65511, '\p{^Is_Lb=pr}', "");
Expect(1, 65511, '\P{Is_Lb=pr}', "");
Expect(0, 65511, '\P{^Is_Lb=pr}', "");
Expect(1, 65510, '\p{Is_Lb=	PR}', "");
Expect(0, 65510, '\p{^Is_Lb=	PR}', "");
Expect(0, 65510, '\P{Is_Lb=	PR}', "");
Expect(1, 65510, '\P{^Is_Lb=	PR}', "");
Expect(0, 65511, '\p{Is_Lb=	PR}', "");
Expect(1, 65511, '\p{^Is_Lb=	PR}', "");
Expect(1, 65511, '\P{Is_Lb=	PR}', "");
Expect(0, 65511, '\P{^Is_Lb=	PR}', "");
Error('\p{Line_Break=:=_	quotation}');
Error('\P{Line_Break=:=_	quotation}');
Expect(1, 11809, '\p{Line_Break=quotation}', "");
Expect(0, 11809, '\p{^Line_Break=quotation}', "");
Expect(0, 11809, '\P{Line_Break=quotation}', "");
Expect(1, 11809, '\P{^Line_Break=quotation}', "");
Expect(0, 11810, '\p{Line_Break=quotation}', "");
Expect(1, 11810, '\p{^Line_Break=quotation}', "");
Expect(1, 11810, '\P{Line_Break=quotation}', "");
Expect(0, 11810, '\P{^Line_Break=quotation}', "");
Expect(1, 11809, '\p{Line_Break=--quotation}', "");
Expect(0, 11809, '\p{^Line_Break=--quotation}', "");
Expect(0, 11809, '\P{Line_Break=--quotation}', "");
Expect(1, 11809, '\P{^Line_Break=--quotation}', "");
Expect(0, 11810, '\p{Line_Break=--quotation}', "");
Expect(1, 11810, '\p{^Line_Break=--quotation}', "");
Expect(1, 11810, '\P{Line_Break=--quotation}', "");
Expect(0, 11810, '\P{^Line_Break=--quotation}', "");
Error('\p{Lb=:=-_QU}');
Error('\P{Lb=:=-_QU}');
Expect(1, 11809, '\p{Lb=qu}', "");
Expect(0, 11809, '\p{^Lb=qu}', "");
Expect(0, 11809, '\P{Lb=qu}', "");
Expect(1, 11809, '\P{^Lb=qu}', "");
Expect(0, 11810, '\p{Lb=qu}', "");
Expect(1, 11810, '\p{^Lb=qu}', "");
Expect(1, 11810, '\P{Lb=qu}', "");
Expect(0, 11810, '\P{^Lb=qu}', "");
Expect(1, 11809, '\p{Lb=_-QU}', "");
Expect(0, 11809, '\p{^Lb=_-QU}', "");
Expect(0, 11809, '\P{Lb=_-QU}', "");
Expect(1, 11809, '\P{^Lb=_-QU}', "");
Expect(0, 11810, '\p{Lb=_-QU}', "");
Expect(1, 11810, '\p{^Lb=_-QU}', "");
Expect(1, 11810, '\P{Lb=_-QU}', "");
Expect(0, 11810, '\P{^Lb=_-QU}', "");
Error('\p{Is_Line_Break=_/a/quotation}');
Error('\P{Is_Line_Break=_/a/quotation}');
Expect(1, 11809, '\p{Is_Line_Break=quotation}', "");
Expect(0, 11809, '\p{^Is_Line_Break=quotation}', "");
Expect(0, 11809, '\P{Is_Line_Break=quotation}', "");
Expect(1, 11809, '\P{^Is_Line_Break=quotation}', "");
Expect(0, 11810, '\p{Is_Line_Break=quotation}', "");
Expect(1, 11810, '\p{^Is_Line_Break=quotation}', "");
Expect(1, 11810, '\P{Is_Line_Break=quotation}', "");
Expect(0, 11810, '\P{^Is_Line_Break=quotation}', "");
Expect(1, 11809, '\p{Is_Line_Break=	Quotation}', "");
Expect(0, 11809, '\p{^Is_Line_Break=	Quotation}', "");
Expect(0, 11809, '\P{Is_Line_Break=	Quotation}', "");
Expect(1, 11809, '\P{^Is_Line_Break=	Quotation}', "");
Expect(0, 11810, '\p{Is_Line_Break=	Quotation}', "");
Expect(1, 11810, '\p{^Is_Line_Break=	Quotation}', "");
Expect(1, 11810, '\P{Is_Line_Break=	Quotation}', "");
Expect(0, 11810, '\P{^Is_Line_Break=	Quotation}', "");
Error('\p{Is_Lb=:=_QU}');
Error('\P{Is_Lb=:=_QU}');
Expect(1, 11809, '\p{Is_Lb=qu}', "");
Expect(0, 11809, '\p{^Is_Lb=qu}', "");
Expect(0, 11809, '\P{Is_Lb=qu}', "");
Expect(1, 11809, '\P{^Is_Lb=qu}', "");
Expect(0, 11810, '\p{Is_Lb=qu}', "");
Expect(1, 11810, '\p{^Is_Lb=qu}', "");
Expect(1, 11810, '\P{Is_Lb=qu}', "");
Expect(0, 11810, '\P{^Is_Lb=qu}', "");
Expect(1, 11809, '\p{Is_Lb=-	QU}', "");
Expect(0, 11809, '\p{^Is_Lb=-	QU}', "");
Expect(0, 11809, '\P{Is_Lb=-	QU}', "");
Expect(1, 11809, '\P{^Is_Lb=-	QU}', "");
Expect(0, 11810, '\p{Is_Lb=-	QU}', "");
Expect(1, 11810, '\p{^Is_Lb=-	QU}', "");
Expect(1, 11810, '\P{Is_Lb=-	QU}', "");
Expect(0, 11810, '\P{^Is_Lb=-	QU}', "");
Error('\p{Line_Break=:=--Regional_Indicator}');
Error('\P{Line_Break=:=--Regional_Indicator}');
Expect(1, 127487, '\p{Line_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Line_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Line_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Line_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Line_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Line_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Line_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Line_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Line_Break=_Regional_indicator}', "");
Expect(0, 127487, '\p{^Line_Break=_Regional_indicator}', "");
Expect(0, 127487, '\P{Line_Break=_Regional_indicator}', "");
Expect(1, 127487, '\P{^Line_Break=_Regional_indicator}', "");
Expect(0, 127488, '\p{Line_Break=_Regional_indicator}', "");
Expect(1, 127488, '\p{^Line_Break=_Regional_indicator}', "");
Expect(1, 127488, '\P{Line_Break=_Regional_indicator}', "");
Expect(0, 127488, '\P{^Line_Break=_Regional_indicator}', "");
Error('\p{Lb=:=RI}');
Error('\P{Lb=:=RI}');
Expect(1, 127487, '\p{Lb=ri}', "");
Expect(0, 127487, '\p{^Lb=ri}', "");
Expect(0, 127487, '\P{Lb=ri}', "");
Expect(1, 127487, '\P{^Lb=ri}', "");
Expect(0, 127488, '\p{Lb=ri}', "");
Expect(1, 127488, '\p{^Lb=ri}', "");
Expect(1, 127488, '\P{Lb=ri}', "");
Expect(0, 127488, '\P{^Lb=ri}', "");
Expect(1, 127487, '\p{Lb=_ RI}', "");
Expect(0, 127487, '\p{^Lb=_ RI}', "");
Expect(0, 127487, '\P{Lb=_ RI}', "");
Expect(1, 127487, '\P{^Lb=_ RI}', "");
Expect(0, 127488, '\p{Lb=_ RI}', "");
Expect(1, 127488, '\p{^Lb=_ RI}', "");
Expect(1, 127488, '\P{Lb=_ RI}', "");
Expect(0, 127488, '\P{^Lb=_ RI}', "");
Error('\p{Is_Line_Break=-/a/regional_INDICATOR}');
Error('\P{Is_Line_Break=-/a/regional_INDICATOR}');
Expect(1, 127487, '\p{Is_Line_Break=regionalindicator}', "");
Expect(0, 127487, '\p{^Is_Line_Break=regionalindicator}', "");
Expect(0, 127487, '\P{Is_Line_Break=regionalindicator}', "");
Expect(1, 127487, '\P{^Is_Line_Break=regionalindicator}', "");
Expect(0, 127488, '\p{Is_Line_Break=regionalindicator}', "");
Expect(1, 127488, '\p{^Is_Line_Break=regionalindicator}', "");
Expect(1, 127488, '\P{Is_Line_Break=regionalindicator}', "");
Expect(0, 127488, '\P{^Is_Line_Break=regionalindicator}', "");
Expect(1, 127487, '\p{Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(0, 127487, '\p{^Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(0, 127487, '\P{Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(1, 127487, '\P{^Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(0, 127488, '\p{Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(1, 127488, '\p{^Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(1, 127488, '\P{Is_Line_Break=  REGIONAL_Indicator}', "");
Expect(0, 127488, '\P{^Is_Line_Break=  REGIONAL_Indicator}', "");
Error('\p{Is_Lb=-:=ri}');
Error('\P{Is_Lb=-:=ri}');
Expect(1, 127487, '\p{Is_Lb=ri}', "");
Expect(0, 127487, '\p{^Is_Lb=ri}', "");
Expect(0, 127487, '\P{Is_Lb=ri}', "");
Expect(1, 127487, '\P{^Is_Lb=ri}', "");
Expect(0, 127488, '\p{Is_Lb=ri}', "");
Expect(1, 127488, '\p{^Is_Lb=ri}', "");
Expect(1, 127488, '\P{Is_Lb=ri}', "");
Expect(0, 127488, '\P{^Is_Lb=ri}', "");
Expect(1, 127487, '\p{Is_Lb=RI}', "");
Expect(0, 127487, '\p{^Is_Lb=RI}', "");
Expect(0, 127487, '\P{Is_Lb=RI}', "");
Expect(1, 127487, '\P{^Is_Lb=RI}', "");
Expect(0, 127488, '\p{Is_Lb=RI}', "");
Expect(1, 127488, '\p{^Is_Lb=RI}', "");
Expect(1, 127488, '\P{Is_Lb=RI}', "");
Expect(0, 127488, '\P{^Is_Lb=RI}', "");
Error('\p{Line_Break=/a/  Complex_CONTEXT}');
Error('\P{Line_Break=/a/  Complex_CONTEXT}');
Expect(1, 43743, '\p{Line_Break=complexcontext}', "");
Expect(0, 43743, '\p{^Line_Break=complexcontext}', "");
Expect(0, 43743, '\P{Line_Break=complexcontext}', "");
Expect(1, 43743, '\P{^Line_Break=complexcontext}', "");
Expect(0, 43744, '\p{Line_Break=complexcontext}', "");
Expect(1, 43744, '\p{^Line_Break=complexcontext}', "");
Expect(1, 43744, '\P{Line_Break=complexcontext}', "");
Expect(0, 43744, '\P{^Line_Break=complexcontext}', "");
Expect(1, 43743, '\p{Line_Break=-Complex_CONTEXT}', "");
Expect(0, 43743, '\p{^Line_Break=-Complex_CONTEXT}', "");
Expect(0, 43743, '\P{Line_Break=-Complex_CONTEXT}', "");
Expect(1, 43743, '\P{^Line_Break=-Complex_CONTEXT}', "");
Expect(0, 43744, '\p{Line_Break=-Complex_CONTEXT}', "");
Expect(1, 43744, '\p{^Line_Break=-Complex_CONTEXT}', "");
Expect(1, 43744, '\P{Line_Break=-Complex_CONTEXT}', "");
Expect(0, 43744, '\P{^Line_Break=-Complex_CONTEXT}', "");
Error('\p{Lb=-	SA:=}');
Error('\P{Lb=-	SA:=}');
Expect(1, 43743, '\p{Lb=sa}', "");
Expect(0, 43743, '\p{^Lb=sa}', "");
Expect(0, 43743, '\P{Lb=sa}', "");
Expect(1, 43743, '\P{^Lb=sa}', "");
Expect(0, 43744, '\p{Lb=sa}', "");
Expect(1, 43744, '\p{^Lb=sa}', "");
Expect(1, 43744, '\P{Lb=sa}', "");
Expect(0, 43744, '\P{^Lb=sa}', "");
Expect(1, 43743, '\p{Lb=SA}', "");
Expect(0, 43743, '\p{^Lb=SA}', "");
Expect(0, 43743, '\P{Lb=SA}', "");
Expect(1, 43743, '\P{^Lb=SA}', "");
Expect(0, 43744, '\p{Lb=SA}', "");
Expect(1, 43744, '\p{^Lb=SA}', "");
Expect(1, 43744, '\P{Lb=SA}', "");
Expect(0, 43744, '\P{^Lb=SA}', "");
Error('\p{Is_Line_Break=	Complex_Context:=}');
Error('\P{Is_Line_Break=	Complex_Context:=}');
Expect(1, 43743, '\p{Is_Line_Break=complexcontext}', "");
Expect(0, 43743, '\p{^Is_Line_Break=complexcontext}', "");
Expect(0, 43743, '\P{Is_Line_Break=complexcontext}', "");
Expect(1, 43743, '\P{^Is_Line_Break=complexcontext}', "");
Expect(0, 43744, '\p{Is_Line_Break=complexcontext}', "");
Expect(1, 43744, '\p{^Is_Line_Break=complexcontext}', "");
Expect(1, 43744, '\P{Is_Line_Break=complexcontext}', "");
Expect(0, 43744, '\P{^Is_Line_Break=complexcontext}', "");
Expect(1, 43743, '\p{Is_Line_Break=--Complex_context}', "");
Expect(0, 43743, '\p{^Is_Line_Break=--Complex_context}', "");
Expect(0, 43743, '\P{Is_Line_Break=--Complex_context}', "");
Expect(1, 43743, '\P{^Is_Line_Break=--Complex_context}', "");
Expect(0, 43744, '\p{Is_Line_Break=--Complex_context}', "");
Expect(1, 43744, '\p{^Is_Line_Break=--Complex_context}', "");
Expect(1, 43744, '\P{Is_Line_Break=--Complex_context}', "");
Expect(0, 43744, '\P{^Is_Line_Break=--Complex_context}', "");
Error('\p{Is_Lb=		SA/a/}');
Error('\P{Is_Lb=		SA/a/}');
Expect(1, 43743, '\p{Is_Lb=sa}', "");
Expect(0, 43743, '\p{^Is_Lb=sa}', "");
Expect(0, 43743, '\P{Is_Lb=sa}', "");
Expect(1, 43743, '\P{^Is_Lb=sa}', "");
Expect(0, 43744, '\p{Is_Lb=sa}', "");
Expect(1, 43744, '\p{^Is_Lb=sa}', "");
Expect(1, 43744, '\P{Is_Lb=sa}', "");
Expect(0, 43744, '\P{^Is_Lb=sa}', "");
Expect(1, 43743, '\p{Is_Lb=_ sa}', "");
Expect(0, 43743, '\p{^Is_Lb=_ sa}', "");
Expect(0, 43743, '\P{Is_Lb=_ sa}', "");
Expect(1, 43743, '\P{^Is_Lb=_ sa}', "");
Expect(0, 43744, '\p{Is_Lb=_ sa}', "");
Expect(1, 43744, '\p{^Is_Lb=_ sa}', "");
Expect(1, 43744, '\P{Is_Lb=_ sa}', "");
Expect(0, 43744, '\P{^Is_Lb=_ sa}', "");
Error('\p{Line_Break=/a/-SURROGATE}');
Error('\P{Line_Break=/a/-SURROGATE}');
Expect(1, 57343, '\p{Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\p{^Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\P{Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\P{^Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\p{Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\p{^Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\P{Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\P{^Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\p{Line_Break=-surrogate}', 'deprecated');
Expect(0, 57343, '\p{^Line_Break=-surrogate}', 'deprecated');
Expect(0, 57343, '\P{Line_Break=-surrogate}', 'deprecated');
Expect(1, 57343, '\P{^Line_Break=-surrogate}', 'deprecated');
Expect(0, 57344, '\p{Line_Break=-surrogate}', 'deprecated');
Expect(1, 57344, '\p{^Line_Break=-surrogate}', 'deprecated');
Expect(1, 57344, '\P{Line_Break=-surrogate}', 'deprecated');
Expect(0, 57344, '\P{^Line_Break=-surrogate}', 'deprecated');
Error('\p{Lb=:= sg}');
Error('\P{Lb=:= sg}');
Expect(1, 57343, '\p{Lb:sg}', 'deprecated');
Expect(0, 57343, '\p{^Lb:sg}', 'deprecated');
Expect(0, 57343, '\P{Lb:sg}', 'deprecated');
Expect(1, 57343, '\P{^Lb:sg}', 'deprecated');
Expect(0, 57344, '\p{Lb:sg}', 'deprecated');
Expect(1, 57344, '\p{^Lb:sg}', 'deprecated');
Expect(1, 57344, '\P{Lb:sg}', 'deprecated');
Expect(0, 57344, '\P{^Lb:sg}', 'deprecated');
Expect(1, 57343, '\p{Lb=_SG}', 'deprecated');
Expect(0, 57343, '\p{^Lb=_SG}', 'deprecated');
Expect(0, 57343, '\P{Lb=_SG}', 'deprecated');
Expect(1, 57343, '\P{^Lb=_SG}', 'deprecated');
Expect(0, 57344, '\p{Lb=_SG}', 'deprecated');
Expect(1, 57344, '\p{^Lb=_SG}', 'deprecated');
Expect(1, 57344, '\P{Lb=_SG}', 'deprecated');
Expect(0, 57344, '\P{^Lb=_SG}', 'deprecated');
Error('\p{Is_Line_Break=	-Surrogate:=}');
Error('\P{Is_Line_Break=	-Surrogate:=}');
Expect(1, 57343, '\p{Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\p{^Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57343, '\P{Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\P{^Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\p{Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\p{^Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57344, '\P{Is_Line_Break=surrogate}', 'deprecated');
Expect(0, 57344, '\P{^Is_Line_Break=surrogate}', 'deprecated');
Expect(1, 57343, '\p{Is_Line_Break= Surrogate}', 'deprecated');
Expect(0, 57343, '\p{^Is_Line_Break= Surrogate}', 'deprecated');
Expect(0, 57343, '\P{Is_Line_Break= Surrogate}', 'deprecated');
Expect(1, 57343, '\P{^Is_Line_Break= Surrogate}', 'deprecated');
Expect(0, 57344, '\p{Is_Line_Break= Surrogate}', 'deprecated');
Expect(1, 57344, '\p{^Is_Line_Break= Surrogate}', 'deprecated');
Expect(1, 57344, '\P{Is_Line_Break= Surrogate}', 'deprecated');
Expect(0, 57344, '\P{^Is_Line_Break= Surrogate}', 'deprecated');
Error('\p{Is_Lb=:= SG}');
Error('\P{Is_Lb=:= SG}');
Expect(1, 57343, '\p{Is_Lb=sg}', 'deprecated');
Expect(0, 57343, '\p{^Is_Lb=sg}', 'deprecated');
Expect(0, 57343, '\P{Is_Lb=sg}', 'deprecated');
Expect(1, 57343, '\P{^Is_Lb=sg}', 'deprecated');
Expect(0, 57344, '\p{Is_Lb=sg}', 'deprecated');
Expect(1, 57344, '\p{^Is_Lb=sg}', 'deprecated');
Expect(1, 57344, '\P{Is_Lb=sg}', 'deprecated');
Expect(0, 57344, '\P{^Is_Lb=sg}', 'deprecated');
Expect(1, 57343, '\p{Is_Lb=_SG}', 'deprecated');
Expect(0, 57343, '\p{^Is_Lb=_SG}', 'deprecated');
Expect(0, 57343, '\P{Is_Lb=_SG}', 'deprecated');
Expect(1, 57343, '\P{^Is_Lb=_SG}', 'deprecated');
Expect(0, 57344, '\p{Is_Lb=_SG}', 'deprecated');
Expect(1, 57344, '\p{^Is_Lb=_SG}', 'deprecated');
Expect(1, 57344, '\P{Is_Lb=_SG}', 'deprecated');
Expect(0, 57344, '\P{^Is_Lb=_SG}', 'deprecated');
Error('\p{Line_Break=		SPACE/a/}');
Error('\P{Line_Break=		SPACE/a/}');
Expect(1, 32, '\p{Line_Break:   space}', "");
Expect(0, 32, '\p{^Line_Break:   space}', "");
Expect(0, 32, '\P{Line_Break:   space}', "");
Expect(1, 32, '\P{^Line_Break:   space}', "");
Expect(0, 33, '\p{Line_Break:   space}', "");
Expect(1, 33, '\p{^Line_Break:   space}', "");
Expect(1, 33, '\P{Line_Break:   space}', "");
Expect(0, 33, '\P{^Line_Break:   space}', "");
Expect(1, 32, '\p{Line_Break=--SPACE}', "");
Expect(0, 32, '\p{^Line_Break=--SPACE}', "");
Expect(0, 32, '\P{Line_Break=--SPACE}', "");
Expect(1, 32, '\P{^Line_Break=--SPACE}', "");
Expect(0, 33, '\p{Line_Break=--SPACE}', "");
Expect(1, 33, '\p{^Line_Break=--SPACE}', "");
Expect(1, 33, '\P{Line_Break=--SPACE}', "");
Expect(0, 33, '\P{^Line_Break=--SPACE}', "");
Error('\p{Lb=:=sp}');
Error('\P{Lb=:=sp}');
Expect(1, 32, '\p{Lb=sp}', "");
Expect(0, 32, '\p{^Lb=sp}', "");
Expect(0, 32, '\P{Lb=sp}', "");
Expect(1, 32, '\P{^Lb=sp}', "");
Expect(0, 33, '\p{Lb=sp}', "");
Expect(1, 33, '\p{^Lb=sp}', "");
Expect(1, 33, '\P{Lb=sp}', "");
Expect(0, 33, '\P{^Lb=sp}', "");
Expect(1, 32, '\p{Lb=__SP}', "");
Expect(0, 32, '\p{^Lb=__SP}', "");
Expect(0, 32, '\P{Lb=__SP}', "");
Expect(1, 32, '\P{^Lb=__SP}', "");
Expect(0, 33, '\p{Lb=__SP}', "");
Expect(1, 33, '\p{^Lb=__SP}', "");
Expect(1, 33, '\P{Lb=__SP}', "");
Expect(0, 33, '\P{^Lb=__SP}', "");
Error('\p{Is_Line_Break=	-space/a/}');
Error('\P{Is_Line_Break=	-space/a/}');
Expect(1, 32, '\p{Is_Line_Break=space}', "");
Expect(0, 32, '\p{^Is_Line_Break=space}', "");
Expect(0, 32, '\P{Is_Line_Break=space}', "");
Expect(1, 32, '\P{^Is_Line_Break=space}', "");
Expect(0, 33, '\p{Is_Line_Break=space}', "");
Expect(1, 33, '\p{^Is_Line_Break=space}', "");
Expect(1, 33, '\P{Is_Line_Break=space}', "");
Expect(0, 33, '\P{^Is_Line_Break=space}', "");
Expect(1, 32, '\p{Is_Line_Break= 	SPACE}', "");
Expect(0, 32, '\p{^Is_Line_Break= 	SPACE}', "");
Expect(0, 32, '\P{Is_Line_Break= 	SPACE}', "");
Expect(1, 32, '\P{^Is_Line_Break= 	SPACE}', "");
Expect(0, 33, '\p{Is_Line_Break= 	SPACE}', "");
Expect(1, 33, '\p{^Is_Line_Break= 	SPACE}', "");
Expect(1, 33, '\P{Is_Line_Break= 	SPACE}', "");
Expect(0, 33, '\P{^Is_Line_Break= 	SPACE}', "");
Error('\p{Is_Lb=/a/_sp}');
Error('\P{Is_Lb=/a/_sp}');
Expect(1, 32, '\p{Is_Lb=sp}', "");
Expect(0, 32, '\p{^Is_Lb=sp}', "");
Expect(0, 32, '\P{Is_Lb=sp}', "");
Expect(1, 32, '\P{^Is_Lb=sp}', "");
Expect(0, 33, '\p{Is_Lb=sp}', "");
Expect(1, 33, '\p{^Is_Lb=sp}', "");
Expect(1, 33, '\P{Is_Lb=sp}', "");
Expect(0, 33, '\P{^Is_Lb=sp}', "");
Expect(1, 32, '\p{Is_Lb=-SP}', "");
Expect(0, 32, '\p{^Is_Lb=-SP}', "");
Expect(0, 32, '\P{Is_Lb=-SP}', "");
Expect(1, 32, '\P{^Is_Lb=-SP}', "");
Expect(0, 33, '\p{Is_Lb=-SP}', "");
Expect(1, 33, '\p{^Is_Lb=-SP}', "");
Expect(1, 33, '\P{Is_Lb=-SP}', "");
Expect(0, 33, '\P{^Is_Lb=-SP}', "");
Error('\p{Line_Break=  Break_Symbols:=}');
Error('\P{Line_Break=  Break_Symbols:=}');
Expect(1, 47, '\p{Line_Break:	breaksymbols}', "");
Expect(0, 47, '\p{^Line_Break:	breaksymbols}', "");
Expect(0, 47, '\P{Line_Break:	breaksymbols}', "");
Expect(1, 47, '\P{^Line_Break:	breaksymbols}', "");
Expect(0, 48, '\p{Line_Break:	breaksymbols}', "");
Expect(1, 48, '\p{^Line_Break:	breaksymbols}', "");
Expect(1, 48, '\P{Line_Break:	breaksymbols}', "");
Expect(0, 48, '\P{^Line_Break:	breaksymbols}', "");
Expect(1, 47, '\p{Line_Break=-	Break_symbols}', "");
Expect(0, 47, '\p{^Line_Break=-	Break_symbols}', "");
Expect(0, 47, '\P{Line_Break=-	Break_symbols}', "");
Expect(1, 47, '\P{^Line_Break=-	Break_symbols}', "");
Expect(0, 48, '\p{Line_Break=-	Break_symbols}', "");
Expect(1, 48, '\p{^Line_Break=-	Break_symbols}', "");
Expect(1, 48, '\P{Line_Break=-	Break_symbols}', "");
Expect(0, 48, '\P{^Line_Break=-	Break_symbols}', "");
Error('\p{Lb=_sy/a/}');
Error('\P{Lb=_sy/a/}');
Expect(1, 47, '\p{Lb:sy}', "");
Expect(0, 47, '\p{^Lb:sy}', "");
Expect(0, 47, '\P{Lb:sy}', "");
Expect(1, 47, '\P{^Lb:sy}', "");
Expect(0, 48, '\p{Lb:sy}', "");
Expect(1, 48, '\p{^Lb:sy}', "");
Expect(1, 48, '\P{Lb:sy}', "");
Expect(0, 48, '\P{^Lb:sy}', "");
Expect(1, 47, '\p{Lb=	SY}', "");
Expect(0, 47, '\p{^Lb=	SY}', "");
Expect(0, 47, '\P{Lb=	SY}', "");
Expect(1, 47, '\P{^Lb=	SY}', "");
Expect(0, 48, '\p{Lb=	SY}', "");
Expect(1, 48, '\p{^Lb=	SY}', "");
Expect(1, 48, '\P{Lb=	SY}', "");
Expect(0, 48, '\P{^Lb=	SY}', "");
Error('\p{Is_Line_Break=:=-_BREAK_Symbols}');
Error('\P{Is_Line_Break=:=-_BREAK_Symbols}');
Expect(1, 47, '\p{Is_Line_Break:breaksymbols}', "");
Expect(0, 47, '\p{^Is_Line_Break:breaksymbols}', "");
Expect(0, 47, '\P{Is_Line_Break:breaksymbols}', "");
Expect(1, 47, '\P{^Is_Line_Break:breaksymbols}', "");
Expect(0, 48, '\p{Is_Line_Break:breaksymbols}', "");
Expect(1, 48, '\p{^Is_Line_Break:breaksymbols}', "");
Expect(1, 48, '\P{Is_Line_Break:breaksymbols}', "");
Expect(0, 48, '\P{^Is_Line_Break:breaksymbols}', "");
Expect(1, 47, '\p{Is_Line_Break=-Break_symbols}', "");
Expect(0, 47, '\p{^Is_Line_Break=-Break_symbols}', "");
Expect(0, 47, '\P{Is_Line_Break=-Break_symbols}', "");
Expect(1, 47, '\P{^Is_Line_Break=-Break_symbols}', "");
Expect(0, 48, '\p{Is_Line_Break=-Break_symbols}', "");
Expect(1, 48, '\p{^Is_Line_Break=-Break_symbols}', "");
Expect(1, 48, '\P{Is_Line_Break=-Break_symbols}', "");
Expect(0, 48, '\P{^Is_Line_Break=-Break_symbols}', "");
Error('\p{Is_Lb=/a/	_SY}');
Error('\P{Is_Lb=/a/	_SY}');
Expect(1, 47, '\p{Is_Lb=sy}', "");
Expect(0, 47, '\p{^Is_Lb=sy}', "");
Expect(0, 47, '\P{Is_Lb=sy}', "");
Expect(1, 47, '\P{^Is_Lb=sy}', "");
Expect(0, 48, '\p{Is_Lb=sy}', "");
Expect(1, 48, '\p{^Is_Lb=sy}', "");
Expect(1, 48, '\P{Is_Lb=sy}', "");
Expect(0, 48, '\P{^Is_Lb=sy}', "");
Expect(1, 47, '\p{Is_Lb=	 SY}', "");
Expect(0, 47, '\p{^Is_Lb=	 SY}', "");
Expect(0, 47, '\P{Is_Lb=	 SY}', "");
Expect(1, 47, '\P{^Is_Lb=	 SY}', "");
Expect(0, 48, '\p{Is_Lb=	 SY}', "");
Expect(1, 48, '\p{^Is_Lb=	 SY}', "");
Expect(1, 48, '\P{Is_Lb=	 SY}', "");
Expect(0, 48, '\P{^Is_Lb=	 SY}', "");
Error('\p{Line_Break=		WORD_Joiner:=}');
Error('\P{Line_Break=		WORD_Joiner:=}');
Expect(1, 65279, '\p{Line_Break=wordjoiner}', "");
Expect(0, 65279, '\p{^Line_Break=wordjoiner}', "");
Expect(0, 65279, '\P{Line_Break=wordjoiner}', "");
Expect(1, 65279, '\P{^Line_Break=wordjoiner}', "");
Expect(0, 65280, '\p{Line_Break=wordjoiner}', "");
Expect(1, 65280, '\p{^Line_Break=wordjoiner}', "");
Expect(1, 65280, '\P{Line_Break=wordjoiner}', "");
Expect(0, 65280, '\P{^Line_Break=wordjoiner}', "");
Expect(1, 65279, '\p{Line_Break=- word_Joiner}', "");
Expect(0, 65279, '\p{^Line_Break=- word_Joiner}', "");
Expect(0, 65279, '\P{Line_Break=- word_Joiner}', "");
Expect(1, 65279, '\P{^Line_Break=- word_Joiner}', "");
Expect(0, 65280, '\p{Line_Break=- word_Joiner}', "");
Expect(1, 65280, '\p{^Line_Break=- word_Joiner}', "");
Expect(1, 65280, '\P{Line_Break=- word_Joiner}', "");
Expect(0, 65280, '\P{^Line_Break=- word_Joiner}', "");
Error('\p{Lb=	/a/WJ}');
Error('\P{Lb=	/a/WJ}');
Expect(1, 65279, '\p{Lb=wj}', "");
Expect(0, 65279, '\p{^Lb=wj}', "");
Expect(0, 65279, '\P{Lb=wj}', "");
Expect(1, 65279, '\P{^Lb=wj}', "");
Expect(0, 65280, '\p{Lb=wj}', "");
Expect(1, 65280, '\p{^Lb=wj}', "");
Expect(1, 65280, '\P{Lb=wj}', "");
Expect(0, 65280, '\P{^Lb=wj}', "");
Expect(1, 65279, '\p{Lb= WJ}', "");
Expect(0, 65279, '\p{^Lb= WJ}', "");
Expect(0, 65279, '\P{Lb= WJ}', "");
Expect(1, 65279, '\P{^Lb= WJ}', "");
Expect(0, 65280, '\p{Lb= WJ}', "");
Expect(1, 65280, '\p{^Lb= WJ}', "");
Expect(1, 65280, '\P{Lb= WJ}', "");
Expect(0, 65280, '\P{^Lb= WJ}', "");
Error('\p{Is_Line_Break= /a/Word_Joiner}');
Error('\P{Is_Line_Break= /a/Word_Joiner}');
Expect(1, 65279, '\p{Is_Line_Break=wordjoiner}', "");
Expect(0, 65279, '\p{^Is_Line_Break=wordjoiner}', "");
Expect(0, 65279, '\P{Is_Line_Break=wordjoiner}', "");
Expect(1, 65279, '\P{^Is_Line_Break=wordjoiner}', "");
Expect(0, 65280, '\p{Is_Line_Break=wordjoiner}', "");
Expect(1, 65280, '\p{^Is_Line_Break=wordjoiner}', "");
Expect(1, 65280, '\P{Is_Line_Break=wordjoiner}', "");
Expect(0, 65280, '\P{^Is_Line_Break=wordjoiner}', "");
Expect(1, 65279, '\p{Is_Line_Break=_-Word_joiner}', "");
Expect(0, 65279, '\p{^Is_Line_Break=_-Word_joiner}', "");
Expect(0, 65279, '\P{Is_Line_Break=_-Word_joiner}', "");
Expect(1, 65279, '\P{^Is_Line_Break=_-Word_joiner}', "");
Expect(0, 65280, '\p{Is_Line_Break=_-Word_joiner}', "");
Expect(1, 65280, '\p{^Is_Line_Break=_-Word_joiner}', "");
Expect(1, 65280, '\P{Is_Line_Break=_-Word_joiner}', "");
Expect(0, 65280, '\P{^Is_Line_Break=_-Word_joiner}', "");
Error('\p{Is_Lb=	-wj:=}');
Error('\P{Is_Lb=	-wj:=}');
Expect(1, 65279, '\p{Is_Lb=wj}', "");
Expect(0, 65279, '\p{^Is_Lb=wj}', "");
Expect(0, 65279, '\P{Is_Lb=wj}', "");
Expect(1, 65279, '\P{^Is_Lb=wj}', "");
Expect(0, 65280, '\p{Is_Lb=wj}', "");
Expect(1, 65280, '\p{^Is_Lb=wj}', "");
Expect(1, 65280, '\P{Is_Lb=wj}', "");
Expect(0, 65280, '\P{^Is_Lb=wj}', "");
Expect(1, 65279, '\p{Is_Lb= 	WJ}', "");
Expect(0, 65279, '\p{^Is_Lb= 	WJ}', "");
Expect(0, 65279, '\P{Is_Lb= 	WJ}', "");
Expect(1, 65279, '\P{^Is_Lb= 	WJ}', "");
Expect(0, 65280, '\p{Is_Lb= 	WJ}', "");
Expect(1, 65280, '\p{^Is_Lb= 	WJ}', "");
Expect(1, 65280, '\P{Is_Lb= 	WJ}', "");
Expect(0, 65280, '\P{^Is_Lb= 	WJ}', "");
Error('\p{Line_Break=-unknown/a/}');
Error('\P{Line_Break=-unknown/a/}');
Expect(1, 918000, '\p{Line_Break=unknown}', "");
Expect(0, 918000, '\p{^Line_Break=unknown}', "");
Expect(0, 918000, '\P{Line_Break=unknown}', "");
Expect(1, 918000, '\P{^Line_Break=unknown}', "");
Expect(0, 917999, '\p{Line_Break=unknown}', "");
Expect(1, 917999, '\p{^Line_Break=unknown}', "");
Expect(1, 917999, '\P{Line_Break=unknown}', "");
Expect(0, 917999, '\P{^Line_Break=unknown}', "");
Expect(1, 918000, '\p{Line_Break=_unknown}', "");
Expect(0, 918000, '\p{^Line_Break=_unknown}', "");
Expect(0, 918000, '\P{Line_Break=_unknown}', "");
Expect(1, 918000, '\P{^Line_Break=_unknown}', "");
Expect(0, 917999, '\p{Line_Break=_unknown}', "");
Expect(1, 917999, '\p{^Line_Break=_unknown}', "");
Expect(1, 917999, '\P{Line_Break=_unknown}', "");
Expect(0, 917999, '\P{^Line_Break=_unknown}', "");
Error('\p{Lb=:=-xx}');
Error('\P{Lb=:=-xx}');
Expect(1, 918000, '\p{Lb=xx}', "");
Expect(0, 918000, '\p{^Lb=xx}', "");
Expect(0, 918000, '\P{Lb=xx}', "");
Expect(1, 918000, '\P{^Lb=xx}', "");
Expect(0, 917999, '\p{Lb=xx}', "");
Expect(1, 917999, '\p{^Lb=xx}', "");
Expect(1, 917999, '\P{Lb=xx}', "");
Expect(0, 917999, '\P{^Lb=xx}', "");
Expect(1, 918000, '\p{Lb=	_XX}', "");
Expect(0, 918000, '\p{^Lb=	_XX}', "");
Expect(0, 918000, '\P{Lb=	_XX}', "");
Expect(1, 918000, '\P{^Lb=	_XX}', "");
Expect(0, 917999, '\p{Lb=	_XX}', "");
Expect(1, 917999, '\p{^Lb=	_XX}', "");
Expect(1, 917999, '\P{Lb=	_XX}', "");
Expect(0, 917999, '\P{^Lb=	_XX}', "");
Error('\p{Is_Line_Break=	-Unknown/a/}');
Error('\P{Is_Line_Break=	-Unknown/a/}');
Expect(1, 918000, '\p{Is_Line_Break:   unknown}', "");
Expect(0, 918000, '\p{^Is_Line_Break:   unknown}', "");
Expect(0, 918000, '\P{Is_Line_Break:   unknown}', "");
Expect(1, 918000, '\P{^Is_Line_Break:   unknown}', "");
Expect(0, 917999, '\p{Is_Line_Break:   unknown}', "");
Expect(1, 917999, '\p{^Is_Line_Break:   unknown}', "");
Expect(1, 917999, '\P{Is_Line_Break:   unknown}', "");
Expect(0, 917999, '\P{^Is_Line_Break:   unknown}', "");
Expect(1, 918000, '\p{Is_Line_Break=_ Unknown}', "");
Expect(0, 918000, '\p{^Is_Line_Break=_ Unknown}', "");
Expect(0, 918000, '\P{Is_Line_Break=_ Unknown}', "");
Expect(1, 918000, '\P{^Is_Line_Break=_ Unknown}', "");
Expect(0, 917999, '\p{Is_Line_Break=_ Unknown}', "");
Expect(1, 917999, '\p{^Is_Line_Break=_ Unknown}', "");
Expect(1, 917999, '\P{Is_Line_Break=_ Unknown}', "");
Expect(0, 917999, '\P{^Is_Line_Break=_ Unknown}', "");
Error('\p{Is_Lb=/a/-	XX}');
Error('\P{Is_Lb=/a/-	XX}');
Expect(1, 918000, '\p{Is_Lb=xx}', "");
Expect(0, 918000, '\p{^Is_Lb=xx}', "");
Expect(0, 918000, '\P{Is_Lb=xx}', "");
Expect(1, 918000, '\P{^Is_Lb=xx}', "");
Expect(0, 917999, '\p{Is_Lb=xx}', "");
Expect(1, 917999, '\p{^Is_Lb=xx}', "");
Expect(1, 917999, '\P{Is_Lb=xx}', "");
Expect(0, 917999, '\P{^Is_Lb=xx}', "");
Expect(1, 918000, '\p{Is_Lb=_ XX}', "");
Expect(0, 918000, '\p{^Is_Lb=_ XX}', "");
Expect(0, 918000, '\P{Is_Lb=_ XX}', "");
Expect(1, 918000, '\P{^Is_Lb=_ XX}', "");
Expect(0, 917999, '\p{Is_Lb=_ XX}', "");
Expect(1, 917999, '\p{^Is_Lb=_ XX}', "");
Expect(1, 917999, '\P{Is_Lb=_ XX}', "");
Expect(0, 917999, '\P{^Is_Lb=_ XX}', "");
Error('\p{Line_Break=:=_zwspace}');
Error('\P{Line_Break=:=_zwspace}');
Expect(1, 8203, '\p{Line_Break: zwspace}', "");
Expect(0, 8203, '\p{^Line_Break: zwspace}', "");
Expect(0, 8203, '\P{Line_Break: zwspace}', "");
Expect(1, 8203, '\P{^Line_Break: zwspace}', "");
Expect(0, 8204, '\p{Line_Break: zwspace}', "");
Expect(1, 8204, '\p{^Line_Break: zwspace}', "");
Expect(1, 8204, '\P{Line_Break: zwspace}', "");
Expect(0, 8204, '\P{^Line_Break: zwspace}', "");
Expect(1, 8203, '\p{Line_Break=_-ZWSpace}', "");
Expect(0, 8203, '\p{^Line_Break=_-ZWSpace}', "");
Expect(0, 8203, '\P{Line_Break=_-ZWSpace}', "");
Expect(1, 8203, '\P{^Line_Break=_-ZWSpace}', "");
Expect(0, 8204, '\p{Line_Break=_-ZWSpace}', "");
Expect(1, 8204, '\p{^Line_Break=_-ZWSpace}', "");
Expect(1, 8204, '\P{Line_Break=_-ZWSpace}', "");
Expect(0, 8204, '\P{^Line_Break=_-ZWSpace}', "");
Error('\p{Lb=	_ZW:=}');
Error('\P{Lb=	_ZW:=}');
Expect(1, 8203, '\p{Lb=zw}', "");
Expect(0, 8203, '\p{^Lb=zw}', "");
Expect(0, 8203, '\P{Lb=zw}', "");
Expect(1, 8203, '\P{^Lb=zw}', "");
Expect(0, 8204, '\p{Lb=zw}', "");
Expect(1, 8204, '\p{^Lb=zw}', "");
Expect(1, 8204, '\P{Lb=zw}', "");
Expect(0, 8204, '\P{^Lb=zw}', "");
Expect(1, 8203, '\p{Lb=-_ZW}', "");
Expect(0, 8203, '\p{^Lb=-_ZW}', "");
Expect(0, 8203, '\P{Lb=-_ZW}', "");
Expect(1, 8203, '\P{^Lb=-_ZW}', "");
Expect(0, 8204, '\p{Lb=-_ZW}', "");
Expect(1, 8204, '\p{^Lb=-_ZW}', "");
Expect(1, 8204, '\P{Lb=-_ZW}', "");
Expect(0, 8204, '\P{^Lb=-_ZW}', "");
Error('\p{Is_Line_Break= _ZWSpace:=}');
Error('\P{Is_Line_Break= _ZWSpace:=}');
Expect(1, 8203, '\p{Is_Line_Break:   zwspace}', "");
Expect(0, 8203, '\p{^Is_Line_Break:   zwspace}', "");
Expect(0, 8203, '\P{Is_Line_Break:   zwspace}', "");
Expect(1, 8203, '\P{^Is_Line_Break:   zwspace}', "");
Expect(0, 8204, '\p{Is_Line_Break:   zwspace}', "");
Expect(1, 8204, '\p{^Is_Line_Break:   zwspace}', "");
Expect(1, 8204, '\P{Is_Line_Break:   zwspace}', "");
Expect(0, 8204, '\P{^Is_Line_Break:   zwspace}', "");
Expect(1, 8203, '\p{Is_Line_Break=_ ZWSpace}', "");
Expect(0, 8203, '\p{^Is_Line_Break=_ ZWSpace}', "");
Expect(0, 8203, '\P{Is_Line_Break=_ ZWSpace}', "");
Expect(1, 8203, '\P{^Is_Line_Break=_ ZWSpace}', "");
Expect(0, 8204, '\p{Is_Line_Break=_ ZWSpace}', "");
Expect(1, 8204, '\p{^Is_Line_Break=_ ZWSpace}', "");
Expect(1, 8204, '\P{Is_Line_Break=_ ZWSpace}', "");
Expect(0, 8204, '\P{^Is_Line_Break=_ ZWSpace}', "");
Error('\p{Is_Lb=	 ZW/a/}');
Error('\P{Is_Lb=	 ZW/a/}');
Expect(1, 8203, '\p{Is_Lb=zw}', "");
Expect(0, 8203, '\p{^Is_Lb=zw}', "");
Expect(0, 8203, '\P{Is_Lb=zw}', "");
Expect(1, 8203, '\P{^Is_Lb=zw}', "");
Expect(0, 8204, '\p{Is_Lb=zw}', "");
Expect(1, 8204, '\p{^Is_Lb=zw}', "");
Expect(1, 8204, '\P{Is_Lb=zw}', "");
Expect(0, 8204, '\P{^Is_Lb=zw}', "");
Expect(1, 8203, '\p{Is_Lb=- ZW}', "");
Expect(0, 8203, '\p{^Is_Lb=- ZW}', "");
Expect(0, 8203, '\P{Is_Lb=- ZW}', "");
Expect(1, 8203, '\P{^Is_Lb=- ZW}', "");
Expect(0, 8204, '\p{Is_Lb=- ZW}', "");
Expect(1, 8204, '\p{^Is_Lb=- ZW}', "");
Expect(1, 8204, '\P{Is_Lb=- ZW}', "");
Expect(0, 8204, '\P{^Is_Lb=- ZW}', "");
Error('\p{Numeric_Type:	 decimal:=}');
Error('\P{Numeric_Type:	 decimal:=}');
Expect(1, 120831, '\p{Numeric_Type=decimal}', "");
Expect(0, 120831, '\p{^Numeric_Type=decimal}', "");
Expect(0, 120831, '\P{Numeric_Type=decimal}', "");
Expect(1, 120831, '\P{^Numeric_Type=decimal}', "");
Expect(0, 120832, '\p{Numeric_Type=decimal}', "");
Expect(1, 120832, '\p{^Numeric_Type=decimal}', "");
Expect(1, 120832, '\P{Numeric_Type=decimal}', "");
Expect(0, 120832, '\P{^Numeric_Type=decimal}', "");
Expect(1, 120831, '\p{Numeric_Type=_-DECIMAL}', "");
Expect(0, 120831, '\p{^Numeric_Type=_-DECIMAL}', "");
Expect(0, 120831, '\P{Numeric_Type=_-DECIMAL}', "");
Expect(1, 120831, '\P{^Numeric_Type=_-DECIMAL}', "");
Expect(0, 120832, '\p{Numeric_Type=_-DECIMAL}', "");
Expect(1, 120832, '\p{^Numeric_Type=_-DECIMAL}', "");
Expect(1, 120832, '\P{Numeric_Type=_-DECIMAL}', "");
Expect(0, 120832, '\P{^Numeric_Type=_-DECIMAL}', "");
Error('\p{Nt=_:=DE}');
Error('\P{Nt=_:=DE}');
Expect(1, 120831, '\p{Nt: de}', "");
Expect(0, 120831, '\p{^Nt: de}', "");
Expect(0, 120831, '\P{Nt: de}', "");
Expect(1, 120831, '\P{^Nt: de}', "");
Expect(0, 120832, '\p{Nt: de}', "");
Expect(1, 120832, '\p{^Nt: de}', "");
Expect(1, 120832, '\P{Nt: de}', "");
Expect(0, 120832, '\P{^Nt: de}', "");
Expect(1, 120831, '\p{Nt=_	De}', "");
Expect(0, 120831, '\p{^Nt=_	De}', "");
Expect(0, 120831, '\P{Nt=_	De}', "");
Expect(1, 120831, '\P{^Nt=_	De}', "");
Expect(0, 120832, '\p{Nt=_	De}', "");
Expect(1, 120832, '\p{^Nt=_	De}', "");
Expect(1, 120832, '\P{Nt=_	De}', "");
Expect(0, 120832, '\P{^Nt=_	De}', "");
Error('\p{Is_Numeric_Type=/a/-	DECIMAL}');
Error('\P{Is_Numeric_Type=/a/-	DECIMAL}');
Expect(1, 120831, '\p{Is_Numeric_Type=decimal}', "");
Expect(0, 120831, '\p{^Is_Numeric_Type=decimal}', "");
Expect(0, 120831, '\P{Is_Numeric_Type=decimal}', "");
Expect(1, 120831, '\P{^Is_Numeric_Type=decimal}', "");
Expect(0, 120832, '\p{Is_Numeric_Type=decimal}', "");
Expect(1, 120832, '\p{^Is_Numeric_Type=decimal}', "");
Expect(1, 120832, '\P{Is_Numeric_Type=decimal}', "");
Expect(0, 120832, '\P{^Is_Numeric_Type=decimal}', "");
Expect(1, 120831, '\p{Is_Numeric_Type:    DECIMAL}', "");
Expect(0, 120831, '\p{^Is_Numeric_Type:    DECIMAL}', "");
Expect(0, 120831, '\P{Is_Numeric_Type:    DECIMAL}', "");
Expect(1, 120831, '\P{^Is_Numeric_Type:    DECIMAL}', "");
Expect(0, 120832, '\p{Is_Numeric_Type:    DECIMAL}', "");
Expect(1, 120832, '\p{^Is_Numeric_Type:    DECIMAL}', "");
Expect(1, 120832, '\P{Is_Numeric_Type:    DECIMAL}', "");
Expect(0, 120832, '\P{^Is_Numeric_Type:    DECIMAL}', "");
Error('\p{Is_Nt=:=_de}');
Error('\P{Is_Nt=:=_de}');
Expect(1, 120831, '\p{Is_Nt=de}', "");
Expect(0, 120831, '\p{^Is_Nt=de}', "");
Expect(0, 120831, '\P{Is_Nt=de}', "");
Expect(1, 120831, '\P{^Is_Nt=de}', "");
Expect(0, 120832, '\p{Is_Nt=de}', "");
Expect(1, 120832, '\p{^Is_Nt=de}', "");
Expect(1, 120832, '\P{Is_Nt=de}', "");
Expect(0, 120832, '\P{^Is_Nt=de}', "");
Expect(1, 120831, '\p{Is_Nt=__De}', "");
Expect(0, 120831, '\p{^Is_Nt=__De}', "");
Expect(0, 120831, '\P{Is_Nt=__De}', "");
Expect(1, 120831, '\P{^Is_Nt=__De}', "");
Expect(0, 120832, '\p{Is_Nt=__De}', "");
Expect(1, 120832, '\p{^Is_Nt=__De}', "");
Expect(1, 120832, '\P{Is_Nt=__De}', "");
Expect(0, 120832, '\P{^Is_Nt=__De}', "");
Error('\p{Numeric_Type= :=digit}');
Error('\P{Numeric_Type= :=digit}');
Expect(1, 127242, '\p{Numeric_Type=digit}', "");
Expect(0, 127242, '\p{^Numeric_Type=digit}', "");
Expect(0, 127242, '\P{Numeric_Type=digit}', "");
Expect(1, 127242, '\P{^Numeric_Type=digit}', "");
Expect(0, 127243, '\p{Numeric_Type=digit}', "");
Expect(1, 127243, '\p{^Numeric_Type=digit}', "");
Expect(1, 127243, '\P{Numeric_Type=digit}', "");
Expect(0, 127243, '\P{^Numeric_Type=digit}', "");
Expect(1, 127242, '\p{Numeric_Type=	DIGIT}', "");
Expect(0, 127242, '\p{^Numeric_Type=	DIGIT}', "");
Expect(0, 127242, '\P{Numeric_Type=	DIGIT}', "");
Expect(1, 127242, '\P{^Numeric_Type=	DIGIT}', "");
Expect(0, 127243, '\p{Numeric_Type=	DIGIT}', "");
Expect(1, 127243, '\p{^Numeric_Type=	DIGIT}', "");
Expect(1, 127243, '\P{Numeric_Type=	DIGIT}', "");
Expect(0, 127243, '\P{^Numeric_Type=	DIGIT}', "");
Error('\p{Nt=-Di:=}');
Error('\P{Nt=-Di:=}');
Expect(1, 127242, '\p{Nt=di}', "");
Expect(0, 127242, '\p{^Nt=di}', "");
Expect(0, 127242, '\P{Nt=di}', "");
Expect(1, 127242, '\P{^Nt=di}', "");
Expect(0, 127243, '\p{Nt=di}', "");
Expect(1, 127243, '\p{^Nt=di}', "");
Expect(1, 127243, '\P{Nt=di}', "");
Expect(0, 127243, '\P{^Nt=di}', "");
Expect(1, 127242, '\p{Nt= -Di}', "");
Expect(0, 127242, '\p{^Nt= -Di}', "");
Expect(0, 127242, '\P{Nt= -Di}', "");
Expect(1, 127242, '\P{^Nt= -Di}', "");
Expect(0, 127243, '\p{Nt= -Di}', "");
Expect(1, 127243, '\p{^Nt= -Di}', "");
Expect(1, 127243, '\P{Nt= -Di}', "");
Expect(0, 127243, '\P{^Nt= -Di}', "");
Error('\p{Is_Numeric_Type=	:=DIGIT}');
Error('\P{Is_Numeric_Type=	:=DIGIT}');
Expect(1, 127242, '\p{Is_Numeric_Type=digit}', "");
Expect(0, 127242, '\p{^Is_Numeric_Type=digit}', "");
Expect(0, 127242, '\P{Is_Numeric_Type=digit}', "");
Expect(1, 127242, '\P{^Is_Numeric_Type=digit}', "");
Expect(0, 127243, '\p{Is_Numeric_Type=digit}', "");
Expect(1, 127243, '\p{^Is_Numeric_Type=digit}', "");
Expect(1, 127243, '\P{Is_Numeric_Type=digit}', "");
Expect(0, 127243, '\P{^Is_Numeric_Type=digit}', "");
Expect(1, 127242, '\p{Is_Numeric_Type=-_digit}', "");
Expect(0, 127242, '\p{^Is_Numeric_Type=-_digit}', "");
Expect(0, 127242, '\P{Is_Numeric_Type=-_digit}', "");
Expect(1, 127242, '\P{^Is_Numeric_Type=-_digit}', "");
Expect(0, 127243, '\p{Is_Numeric_Type=-_digit}', "");
Expect(1, 127243, '\p{^Is_Numeric_Type=-_digit}', "");
Expect(1, 127243, '\P{Is_Numeric_Type=-_digit}', "");
Expect(0, 127243, '\P{^Is_Numeric_Type=-_digit}', "");
Error('\p{Is_Nt=- Di/a/}');
Error('\P{Is_Nt=- Di/a/}');
Expect(1, 127242, '\p{Is_Nt=di}', "");
Expect(0, 127242, '\p{^Is_Nt=di}', "");
Expect(0, 127242, '\P{Is_Nt=di}', "");
Expect(1, 127242, '\P{^Is_Nt=di}', "");
Expect(0, 127243, '\p{Is_Nt=di}', "");
Expect(1, 127243, '\p{^Is_Nt=di}', "");
Expect(1, 127243, '\P{Is_Nt=di}', "");
Expect(0, 127243, '\P{^Is_Nt=di}', "");
Expect(1, 127242, '\p{Is_Nt= 	Di}', "");
Expect(0, 127242, '\p{^Is_Nt= 	Di}', "");
Expect(0, 127242, '\P{Is_Nt= 	Di}', "");
Expect(1, 127242, '\P{^Is_Nt= 	Di}', "");
Expect(0, 127243, '\p{Is_Nt= 	Di}', "");
Expect(1, 127243, '\p{^Is_Nt= 	Di}', "");
Expect(1, 127243, '\P{Is_Nt= 	Di}', "");
Expect(0, 127243, '\P{^Is_Nt= 	Di}', "");
Error('\p{Numeric_Type=-none:=}');
Error('\P{Numeric_Type=-none:=}');
Expect(1, 194705, '\p{Numeric_Type=none}', "");
Expect(0, 194705, '\p{^Numeric_Type=none}', "");
Expect(0, 194705, '\P{Numeric_Type=none}', "");
Expect(1, 194705, '\P{^Numeric_Type=none}', "");
Expect(0, 194704, '\p{Numeric_Type=none}', "");
Expect(1, 194704, '\p{^Numeric_Type=none}', "");
Expect(1, 194704, '\P{Numeric_Type=none}', "");
Expect(0, 194704, '\P{^Numeric_Type=none}', "");
Expect(1, 194705, '\p{Numeric_Type:   --none}', "");
Expect(0, 194705, '\p{^Numeric_Type:   --none}', "");
Expect(0, 194705, '\P{Numeric_Type:   --none}', "");
Expect(1, 194705, '\P{^Numeric_Type:   --none}', "");
Expect(0, 194704, '\p{Numeric_Type:   --none}', "");
Expect(1, 194704, '\p{^Numeric_Type:   --none}', "");
Expect(1, 194704, '\P{Numeric_Type:   --none}', "");
Expect(0, 194704, '\P{^Numeric_Type:   --none}', "");
Error('\p{Nt:	_-NONE/a/}');
Error('\P{Nt:	_-NONE/a/}');
Expect(1, 194705, '\p{Nt=none}', "");
Expect(0, 194705, '\p{^Nt=none}', "");
Expect(0, 194705, '\P{Nt=none}', "");
Expect(1, 194705, '\P{^Nt=none}', "");
Expect(0, 194704, '\p{Nt=none}', "");
Expect(1, 194704, '\p{^Nt=none}', "");
Expect(1, 194704, '\P{Nt=none}', "");
Expect(0, 194704, '\P{^Nt=none}', "");
Expect(1, 194705, '\p{Nt=None}', "");
Expect(0, 194705, '\p{^Nt=None}', "");
Expect(0, 194705, '\P{Nt=None}', "");
Expect(1, 194705, '\P{^Nt=None}', "");
Expect(0, 194704, '\p{Nt=None}', "");
Expect(1, 194704, '\p{^Nt=None}', "");
Expect(1, 194704, '\P{Nt=None}', "");
Expect(0, 194704, '\P{^Nt=None}', "");
Error('\p{Is_Numeric_Type=	:=NONE}');
Error('\P{Is_Numeric_Type=	:=NONE}');
Expect(1, 194705, '\p{Is_Numeric_Type=none}', "");
Expect(0, 194705, '\p{^Is_Numeric_Type=none}', "");
Expect(0, 194705, '\P{Is_Numeric_Type=none}', "");
Expect(1, 194705, '\P{^Is_Numeric_Type=none}', "");
Expect(0, 194704, '\p{Is_Numeric_Type=none}', "");
Expect(1, 194704, '\p{^Is_Numeric_Type=none}', "");
Expect(1, 194704, '\P{Is_Numeric_Type=none}', "");
Expect(0, 194704, '\P{^Is_Numeric_Type=none}', "");
Expect(1, 194705, '\p{Is_Numeric_Type=--None}', "");
Expect(0, 194705, '\p{^Is_Numeric_Type=--None}', "");
Expect(0, 194705, '\P{Is_Numeric_Type=--None}', "");
Expect(1, 194705, '\P{^Is_Numeric_Type=--None}', "");
Expect(0, 194704, '\p{Is_Numeric_Type=--None}', "");
Expect(1, 194704, '\p{^Is_Numeric_Type=--None}', "");
Expect(1, 194704, '\P{Is_Numeric_Type=--None}', "");
Expect(0, 194704, '\P{^Is_Numeric_Type=--None}', "");
Error('\p{Is_Nt= /a/none}');
Error('\P{Is_Nt= /a/none}');
Expect(1, 194705, '\p{Is_Nt=none}', "");
Expect(0, 194705, '\p{^Is_Nt=none}', "");
Expect(0, 194705, '\P{Is_Nt=none}', "");
Expect(1, 194705, '\P{^Is_Nt=none}', "");
Expect(0, 194704, '\p{Is_Nt=none}', "");
Expect(1, 194704, '\p{^Is_Nt=none}', "");
Expect(1, 194704, '\P{Is_Nt=none}', "");
Expect(0, 194704, '\P{^Is_Nt=none}', "");
Expect(1, 194705, '\p{Is_Nt=--NONE}', "");
Expect(0, 194705, '\p{^Is_Nt=--NONE}', "");
Expect(0, 194705, '\P{Is_Nt=--NONE}', "");
Expect(1, 194705, '\P{^Is_Nt=--NONE}', "");
Expect(0, 194704, '\p{Is_Nt=--NONE}', "");
Expect(1, 194704, '\p{^Is_Nt=--NONE}', "");
Expect(1, 194704, '\P{Is_Nt=--NONE}', "");
Expect(0, 194704, '\P{^Is_Nt=--NONE}', "");
Error('\p{Numeric_Type=		Numeric:=}');
Error('\P{Numeric_Type=		Numeric:=}');
Expect(1, 194704, '\p{Numeric_Type=numeric}', "");
Expect(0, 194704, '\p{^Numeric_Type=numeric}', "");
Expect(0, 194704, '\P{Numeric_Type=numeric}', "");
Expect(1, 194704, '\P{^Numeric_Type=numeric}', "");
Expect(0, 194705, '\p{Numeric_Type=numeric}', "");
Expect(1, 194705, '\p{^Numeric_Type=numeric}', "");
Expect(1, 194705, '\P{Numeric_Type=numeric}', "");
Expect(0, 194705, '\P{^Numeric_Type=numeric}', "");
Expect(1, 194704, '\p{Numeric_Type= _numeric}', "");
Expect(0, 194704, '\p{^Numeric_Type= _numeric}', "");
Expect(0, 194704, '\P{Numeric_Type= _numeric}', "");
Expect(1, 194704, '\P{^Numeric_Type= _numeric}', "");
Expect(0, 194705, '\p{Numeric_Type= _numeric}', "");
Expect(1, 194705, '\p{^Numeric_Type= _numeric}', "");
Expect(1, 194705, '\P{Numeric_Type= _numeric}', "");
Expect(0, 194705, '\P{^Numeric_Type= _numeric}', "");
Error('\p{Nt=	/a/Nu}');
Error('\P{Nt=	/a/Nu}');
Expect(1, 194704, '\p{Nt=nu}', "");
Expect(0, 194704, '\p{^Nt=nu}', "");
Expect(0, 194704, '\P{Nt=nu}', "");
Expect(1, 194704, '\P{^Nt=nu}', "");
Expect(0, 194705, '\p{Nt=nu}', "");
Expect(1, 194705, '\p{^Nt=nu}', "");
Expect(1, 194705, '\P{Nt=nu}', "");
Expect(0, 194705, '\P{^Nt=nu}', "");
Expect(1, 194704, '\p{Nt= _Nu}', "");
Expect(0, 194704, '\p{^Nt= _Nu}', "");
Expect(0, 194704, '\P{Nt= _Nu}', "");
Expect(1, 194704, '\P{^Nt= _Nu}', "");
Expect(0, 194705, '\p{Nt= _Nu}', "");
Expect(1, 194705, '\p{^Nt= _Nu}', "");
Expect(1, 194705, '\P{Nt= _Nu}', "");
Expect(0, 194705, '\P{^Nt= _Nu}', "");
Error('\p{Is_Numeric_Type=:=_-NUMERIC}');
Error('\P{Is_Numeric_Type=:=_-NUMERIC}');
Expect(1, 194704, '\p{Is_Numeric_Type=numeric}', "");
Expect(0, 194704, '\p{^Is_Numeric_Type=numeric}', "");
Expect(0, 194704, '\P{Is_Numeric_Type=numeric}', "");
Expect(1, 194704, '\P{^Is_Numeric_Type=numeric}', "");
Expect(0, 194705, '\p{Is_Numeric_Type=numeric}', "");
Expect(1, 194705, '\p{^Is_Numeric_Type=numeric}', "");
Expect(1, 194705, '\P{Is_Numeric_Type=numeric}', "");
Expect(0, 194705, '\P{^Is_Numeric_Type=numeric}', "");
Expect(1, 194704, '\p{Is_Numeric_Type=NUMERIC}', "");
Expect(0, 194704, '\p{^Is_Numeric_Type=NUMERIC}', "");
Expect(0, 194704, '\P{Is_Numeric_Type=NUMERIC}', "");
Expect(1, 194704, '\P{^Is_Numeric_Type=NUMERIC}', "");
Expect(0, 194705, '\p{Is_Numeric_Type=NUMERIC}', "");
Expect(1, 194705, '\p{^Is_Numeric_Type=NUMERIC}', "");
Expect(1, 194705, '\P{Is_Numeric_Type=NUMERIC}', "");
Expect(0, 194705, '\P{^Is_Numeric_Type=NUMERIC}', "");
Error('\p{Is_Nt=-NU:=}');
Error('\P{Is_Nt=-NU:=}');
Expect(1, 194704, '\p{Is_Nt=nu}', "");
Expect(0, 194704, '\p{^Is_Nt=nu}', "");
Expect(0, 194704, '\P{Is_Nt=nu}', "");
Expect(1, 194704, '\P{^Is_Nt=nu}', "");
Expect(0, 194705, '\p{Is_Nt=nu}', "");
Expect(1, 194705, '\p{^Is_Nt=nu}', "");
Expect(1, 194705, '\P{Is_Nt=nu}', "");
Expect(0, 194705, '\P{^Is_Nt=nu}', "");
Expect(1, 194704, '\p{Is_Nt= -nu}', "");
Expect(0, 194704, '\p{^Is_Nt= -nu}', "");
Expect(0, 194704, '\P{Is_Nt= -nu}', "");
Expect(1, 194704, '\P{^Is_Nt= -nu}', "");
Expect(0, 194705, '\p{Is_Nt= -nu}', "");
Expect(1, 194705, '\p{^Is_Nt= -nu}', "");
Expect(1, 194705, '\P{Is_Nt= -nu}', "");
Expect(0, 194705, '\P{^Is_Nt= -nu}', "");
Error('\p{Numeric_Value=:=	-000001}');
Error('\P{Numeric_Value=:=	-000001}');
Expect(1, 74839, '\p{Numeric_Value=-000000001}', "");
Expect(0, 74839, '\p{^Numeric_Value=-000000001}', "");
Expect(0, 74839, '\P{Numeric_Value=-000000001}', "");
Expect(1, 74839, '\P{^Numeric_Value=-000000001}', "");
Expect(0, 74840, '\p{Numeric_Value=-000000001}', "");
Expect(1, 74840, '\p{^Numeric_Value=-000000001}', "");
Expect(1, 74840, '\P{Numeric_Value=-000000001}', "");
Expect(0, 74840, '\P{^Numeric_Value=-000000001}', "");
Error('\p{Nv= 	-000001/a/}');
Error('\P{Nv= 	-000001/a/}');
Expect(1, 74839, '\p{Nv=-01}', "");
Expect(0, 74839, '\p{^Nv=-01}', "");
Expect(0, 74839, '\P{Nv=-01}', "");
Expect(1, 74839, '\P{^Nv=-01}', "");
Expect(0, 74840, '\p{Nv=-01}', "");
Expect(1, 74840, '\p{^Nv=-01}', "");
Expect(1, 74840, '\P{Nv=-01}', "");
Expect(0, 74840, '\P{^Nv=-01}', "");
Error('\p{Is_Numeric_Value=-/a/-00001}');
Error('\P{Is_Numeric_Value=-/a/-00001}');
Expect(1, 74839, '\p{Is_Numeric_Value: -0000000001}', "");
Expect(0, 74839, '\p{^Is_Numeric_Value: -0000000001}', "");
Expect(0, 74839, '\P{Is_Numeric_Value: -0000000001}', "");
Expect(1, 74839, '\P{^Is_Numeric_Value: -0000000001}', "");
Expect(0, 74840, '\p{Is_Numeric_Value: -0000000001}', "");
Expect(1, 74840, '\p{^Is_Numeric_Value: -0000000001}', "");
Expect(1, 74840, '\P{Is_Numeric_Value: -0000000001}', "");
Expect(0, 74840, '\P{^Is_Numeric_Value: -0000000001}', "");
Error('\p{Is_Nv=:=-000000001}');
Error('\P{Is_Nv=:=-000000001}');
Expect(1, 74839, '\p{Is_Nv=-00001}', "");
Expect(0, 74839, '\p{^Is_Nv=-00001}', "");
Expect(0, 74839, '\P{Is_Nv=-00001}', "");
Expect(1, 74839, '\P{^Is_Nv=-00001}', "");
Expect(0, 74840, '\p{Is_Nv=-00001}', "");
Expect(1, 74840, '\p{^Is_Nv=-00001}', "");
Expect(1, 74840, '\P{Is_Nv=-00001}', "");
Expect(0, 74840, '\P{^Is_Nv=-00001}', "");
Error('\p{Numeric_Value=_-0000001/002:=}');
Error('\P{Numeric_Value=_-0000001/002:=}');
Expect(1, 3891, '\p{Numeric_Value=-01/000002}', "");
Expect(0, 3891, '\p{^Numeric_Value=-01/000002}', "");
Expect(0, 3891, '\P{Numeric_Value=-01/000002}', "");
Expect(1, 3891, '\P{^Numeric_Value=-01/000002}', "");
Expect(0, 3892, '\p{Numeric_Value=-01/000002}', "");
Expect(1, 3892, '\p{^Numeric_Value=-01/000002}', "");
Expect(1, 3892, '\P{Numeric_Value=-01/000002}', "");
Expect(0, 3892, '\P{^Numeric_Value=-01/000002}', "");
Expect(1, 3891, '\p{Numeric_Value=-0.500}', "");
Expect(0, 3891, '\p{^Numeric_Value=-0.500}', "");
Expect(0, 3891, '\P{Numeric_Value=-0.500}', "");
Expect(1, 3891, '\P{^Numeric_Value=-0.500}', "");
Expect(0, 3892, '\p{Numeric_Value=-0.500}', "");
Expect(1, 3892, '\p{^Numeric_Value=-0.500}', "");
Expect(1, 3892, '\P{Numeric_Value=-0.500}', "");
Expect(0, 3892, '\P{^Numeric_Value=-0.500}', "");
Error('\p{Nv=:=-000000001/0002}');
Error('\P{Nv=:=-000000001/0002}');
Expect(1, 3891, '\p{Nv=-00001/02}', "");
Expect(0, 3891, '\p{^Nv=-00001/02}', "");
Expect(0, 3891, '\P{Nv=-00001/02}', "");
Expect(1, 3891, '\P{^Nv=-00001/02}', "");
Expect(0, 3892, '\p{Nv=-00001/02}', "");
Expect(1, 3892, '\p{^Nv=-00001/02}', "");
Expect(1, 3892, '\P{Nv=-00001/02}', "");
Expect(0, 3892, '\P{^Nv=-00001/02}', "");
Expect(1, 3891, '\p{Nv=-0.500}', "");
Expect(0, 3891, '\p{^Nv=-0.500}', "");
Expect(0, 3891, '\P{Nv=-0.500}', "");
Expect(1, 3891, '\P{^Nv=-0.500}', "");
Expect(0, 3892, '\p{Nv=-0.500}', "");
Expect(1, 3892, '\p{^Nv=-0.500}', "");
Expect(1, 3892, '\P{Nv=-0.500}', "");
Expect(0, 3892, '\P{^Nv=-0.500}', "");
Error('\p{Is_Numeric_Value=-001/00000002:=}');
Error('\P{Is_Numeric_Value=-001/00000002:=}');
Expect(1, 3891, '\p{Is_Numeric_Value=-01/0002}', "");
Expect(0, 3891, '\p{^Is_Numeric_Value=-01/0002}', "");
Expect(0, 3891, '\P{Is_Numeric_Value=-01/0002}', "");
Expect(1, 3891, '\P{^Is_Numeric_Value=-01/0002}', "");
Expect(0, 3892, '\p{Is_Numeric_Value=-01/0002}', "");
Expect(1, 3892, '\p{^Is_Numeric_Value=-01/0002}', "");
Expect(1, 3892, '\P{Is_Numeric_Value=-01/0002}', "");
Expect(0, 3892, '\P{^Is_Numeric_Value=-01/0002}', "");
Expect(1, 3891, '\p{Is_Numeric_Value=-0.500}', "");
Expect(0, 3891, '\p{^Is_Numeric_Value=-0.500}', "");
Expect(0, 3891, '\P{Is_Numeric_Value=-0.500}', "");
Expect(1, 3891, '\P{^Is_Numeric_Value=-0.500}', "");
Expect(0, 3892, '\p{Is_Numeric_Value=-0.500}', "");
Expect(1, 3892, '\p{^Is_Numeric_Value=-0.500}', "");
Expect(1, 3892, '\P{Is_Numeric_Value=-0.500}', "");
Expect(0, 3892, '\P{^Is_Numeric_Value=-0.500}', "");
Error('\p{Is_Nv=_:=-01/0000002}');
Error('\P{Is_Nv=_:=-01/0000002}');
Expect(1, 3891, '\p{Is_Nv=-01/0002}', "");
Expect(0, 3891, '\p{^Is_Nv=-01/0002}', "");
Expect(0, 3891, '\P{Is_Nv=-01/0002}', "");
Expect(1, 3891, '\P{^Is_Nv=-01/0002}', "");
Expect(0, 3892, '\p{Is_Nv=-01/0002}', "");
Expect(1, 3892, '\p{^Is_Nv=-01/0002}', "");
Expect(1, 3892, '\P{Is_Nv=-01/0002}', "");
Expect(0, 3892, '\P{^Is_Nv=-01/0002}', "");
Expect(1, 3891, '\p{Is_Nv=-0.500}', "");
Expect(0, 3891, '\p{^Is_Nv=-0.500}', "");
Expect(0, 3891, '\P{Is_Nv=-0.500}', "");
Expect(1, 3891, '\P{^Is_Nv=-0.500}', "");
Expect(0, 3892, '\p{Is_Nv=-0.500}', "");
Expect(1, 3892, '\p{^Is_Nv=-0.500}', "");
Expect(1, 3892, '\P{Is_Nv=-0.500}', "");
Expect(0, 3892, '\P{^Is_Nv=-0.500}', "");
Error('\p{Numeric_Value=	-+0_0_0_000/a/}');
Error('\P{Numeric_Value=	-+0_0_0_000/a/}');
Expect(1, 127233, '\p{Numeric_Value=00}', "");
Expect(0, 127233, '\p{^Numeric_Value=00}', "");
Expect(0, 127233, '\P{Numeric_Value=00}', "");
Expect(1, 127233, '\P{^Numeric_Value=00}', "");
Expect(0, 127234, '\p{Numeric_Value=00}', "");
Expect(1, 127234, '\p{^Numeric_Value=00}', "");
Expect(1, 127234, '\P{Numeric_Value=00}', "");
Expect(0, 127234, '\P{^Numeric_Value=00}', "");
Error('\p{Nv=/a/_-+000_0}');
Error('\P{Nv=/a/_-+000_0}');
Expect(1, 127233, '\p{Nv=0_0_0_0_0_0_00}', "");
Expect(0, 127233, '\p{^Nv=0_0_0_0_0_0_00}', "");
Expect(0, 127233, '\P{Nv=0_0_0_0_0_0_00}', "");
Expect(1, 127233, '\P{^Nv=0_0_0_0_0_0_00}', "");
Expect(0, 127234, '\p{Nv=0_0_0_0_0_0_00}', "");
Expect(1, 127234, '\p{^Nv=0_0_0_0_0_0_00}', "");
Expect(1, 127234, '\P{Nv=0_0_0_0_0_0_00}', "");
Expect(0, 127234, '\P{^Nv=0_0_0_0_0_0_00}', "");
Error('\p{Is_Numeric_Value:	 /a/000}');
Error('\P{Is_Numeric_Value:	 /a/000}');
Expect(1, 127233, '\p{Is_Numeric_Value=+00000000}', "");
Expect(0, 127233, '\p{^Is_Numeric_Value=+00000000}', "");
Expect(0, 127233, '\P{Is_Numeric_Value=+00000000}', "");
Expect(1, 127233, '\P{^Is_Numeric_Value=+00000000}', "");
Expect(0, 127234, '\p{Is_Numeric_Value=+00000000}', "");
Expect(1, 127234, '\p{^Is_Numeric_Value=+00000000}', "");
Expect(1, 127234, '\P{Is_Numeric_Value=+00000000}', "");
Expect(0, 127234, '\P{^Is_Numeric_Value=+00000000}', "");
Error('\p{Is_Nv=	/a/0000}');
Error('\P{Is_Nv=	/a/0000}');
Expect(1, 127233, '\p{Is_Nv=0_0_0_0_0000}', "");
Expect(0, 127233, '\p{^Is_Nv=0_0_0_0_0000}', "");
Expect(0, 127233, '\P{Is_Nv=0_0_0_0_0000}', "");
Expect(1, 127233, '\P{^Is_Nv=0_0_0_0_0000}', "");
Expect(0, 127234, '\p{Is_Nv=0_0_0_0_0000}', "");
Expect(1, 127234, '\p{^Is_Nv=0_0_0_0_0000}', "");
Expect(1, 127234, '\P{Is_Nv=0_0_0_0_0000}', "");
Expect(0, 127234, '\P{^Is_Nv=0_0_0_0_0000}', "");
Error('\p{Numeric_Value=-:=+0_0_0_01}');
Error('\P{Numeric_Value=-:=+0_0_0_01}');
Expect(1, 133418, '\p{Numeric_Value=0_0_0_0_0_01}', "");
Expect(0, 133418, '\p{^Numeric_Value=0_0_0_0_0_01}', "");
Expect(0, 133418, '\P{Numeric_Value=0_0_0_0_0_01}', "");
Expect(1, 133418, '\P{^Numeric_Value=0_0_0_0_0_01}', "");
Expect(0, 133419, '\p{Numeric_Value=0_0_0_0_0_01}', "");
Expect(1, 133419, '\p{^Numeric_Value=0_0_0_0_0_01}', "");
Expect(1, 133419, '\P{Numeric_Value=0_0_0_0_0_01}', "");
Expect(0, 133419, '\P{^Numeric_Value=0_0_0_0_0_01}', "");
Error('\p{Nv:--0_0_0_0_0_0_0_0_01:=}');
Error('\P{Nv:--0_0_0_0_0_0_0_0_01:=}');
Expect(1, 133418, '\p{Nv: 000001}', "");
Expect(0, 133418, '\p{^Nv: 000001}', "");
Expect(0, 133418, '\P{Nv: 000001}', "");
Expect(1, 133418, '\P{^Nv: 000001}', "");
Expect(0, 133419, '\p{Nv: 000001}', "");
Expect(1, 133419, '\p{^Nv: 000001}', "");
Expect(1, 133419, '\P{Nv: 000001}', "");
Expect(0, 133419, '\P{^Nv: 000001}', "");
Error('\p{Is_Numeric_Value=	/a/+000_000_000_1}');
Error('\P{Is_Numeric_Value=	/a/+000_000_000_1}');
Expect(1, 133418, '\p{Is_Numeric_Value=+0_1}', "");
Expect(0, 133418, '\p{^Is_Numeric_Value=+0_1}', "");
Expect(0, 133418, '\P{Is_Numeric_Value=+0_1}', "");
Expect(1, 133418, '\P{^Is_Numeric_Value=+0_1}', "");
Expect(0, 133419, '\p{Is_Numeric_Value=+0_1}', "");
Expect(1, 133419, '\p{^Is_Numeric_Value=+0_1}', "");
Expect(1, 133419, '\P{Is_Numeric_Value=+0_1}', "");
Expect(0, 133419, '\P{^Is_Numeric_Value=+0_1}', "");
Error('\p{Is_Nv=+001/a/}');
Error('\P{Is_Nv=+001/a/}');
Expect(1, 133418, '\p{Is_Nv=00_00_00_00_1}', "");
Expect(0, 133418, '\p{^Is_Nv=00_00_00_00_1}', "");
Expect(0, 133418, '\P{Is_Nv=00_00_00_00_1}', "");
Expect(1, 133418, '\P{^Is_Nv=00_00_00_00_1}', "");
Expect(0, 133419, '\p{Is_Nv=00_00_00_00_1}', "");
Expect(1, 133419, '\p{^Is_Nv=00_00_00_00_1}', "");
Expect(1, 133419, '\P{Is_Nv=00_00_00_00_1}', "");
Expect(0, 133419, '\P{^Is_Nv=00_00_00_00_1}', "");
Error('\p{Numeric_Value=:=_-001/000000010}');
Error('\P{Numeric_Value=:=_-001/000000010}');
Expect(1, 8530, '\p{Numeric_Value=+01/010}', "");
Expect(0, 8530, '\p{^Numeric_Value=+01/010}', "");
Expect(0, 8530, '\P{Numeric_Value=+01/010}', "");
Expect(1, 8530, '\P{^Numeric_Value=+01/010}', "");
Expect(0, 8531, '\p{Numeric_Value=+01/010}', "");
Expect(1, 8531, '\p{^Numeric_Value=+01/010}', "");
Expect(1, 8531, '\P{Numeric_Value=+01/010}', "");
Expect(0, 8531, '\P{^Numeric_Value=+01/010}', "");
Expect(1, 8530, '\p{Numeric_Value=0.100}', "");
Expect(0, 8530, '\p{^Numeric_Value=0.100}', "");
Expect(0, 8530, '\P{Numeric_Value=0.100}', "");
Expect(1, 8530, '\P{^Numeric_Value=0.100}', "");
Expect(0, 8531, '\p{Numeric_Value=0.100}', "");
Expect(1, 8531, '\p{^Numeric_Value=0.100}', "");
Expect(1, 8531, '\P{Numeric_Value=0.100}', "");
Expect(0, 8531, '\P{^Numeric_Value=0.100}', "");
Error('\p{Nv=	:=01/00000010}');
Error('\P{Nv=	:=01/00000010}');
Expect(1, 8530, '\p{Nv:	0000001/0010}', "");
Expect(0, 8530, '\p{^Nv:	0000001/0010}', "");
Expect(0, 8530, '\P{Nv:	0000001/0010}', "");
Expect(1, 8530, '\P{^Nv:	0000001/0010}', "");
Expect(0, 8531, '\p{Nv:	0000001/0010}', "");
Expect(1, 8531, '\p{^Nv:	0000001/0010}', "");
Expect(1, 8531, '\P{Nv:	0000001/0010}', "");
Expect(0, 8531, '\P{^Nv:	0000001/0010}', "");
Expect(1, 8530, '\p{Nv=0.100}', "");
Expect(0, 8530, '\p{^Nv=0.100}', "");
Expect(0, 8530, '\P{Nv=0.100}', "");
Expect(1, 8530, '\P{^Nv=0.100}', "");
Expect(0, 8531, '\p{Nv=0.100}', "");
Expect(1, 8531, '\p{^Nv=0.100}', "");
Expect(1, 8531, '\P{Nv=0.100}', "");
Expect(0, 8531, '\P{^Nv=0.100}', "");
Error('\p{Is_Numeric_Value=- 0000001/0000010:=}');
Error('\P{Is_Numeric_Value=- 0000001/0000010:=}');
Expect(1, 8530, '\p{Is_Numeric_Value=0001/0000000010}', "");
Expect(0, 8530, '\p{^Is_Numeric_Value=0001/0000000010}', "");
Expect(0, 8530, '\P{Is_Numeric_Value=0001/0000000010}', "");
Expect(1, 8530, '\P{^Is_Numeric_Value=0001/0000000010}', "");
Expect(0, 8531, '\p{Is_Numeric_Value=0001/0000000010}', "");
Expect(1, 8531, '\p{^Is_Numeric_Value=0001/0000000010}', "");
Expect(1, 8531, '\P{Is_Numeric_Value=0001/0000000010}', "");
Expect(0, 8531, '\P{^Is_Numeric_Value=0001/0000000010}', "");
Expect(1, 8530, '\p{Is_Numeric_Value=0.100}', "");
Expect(0, 8530, '\p{^Is_Numeric_Value=0.100}', "");
Expect(0, 8530, '\P{Is_Numeric_Value=0.100}', "");
Expect(1, 8530, '\P{^Is_Numeric_Value=0.100}', "");
Expect(0, 8531, '\p{Is_Numeric_Value=0.100}', "");
Expect(1, 8531, '\p{^Is_Numeric_Value=0.100}', "");
Expect(1, 8531, '\P{Is_Numeric_Value=0.100}', "");
Expect(0, 8531, '\P{^Is_Numeric_Value=0.100}', "");
Error('\p{Is_Nv=:= -000001/0000000010}');
Error('\P{Is_Nv=:= -000001/0000000010}');
Expect(1, 8530, '\p{Is_Nv=000001/0010}', "");
Expect(0, 8530, '\p{^Is_Nv=000001/0010}', "");
Expect(0, 8530, '\P{Is_Nv=000001/0010}', "");
Expect(1, 8530, '\P{^Is_Nv=000001/0010}', "");
Expect(0, 8531, '\p{Is_Nv=000001/0010}', "");
Expect(1, 8531, '\p{^Is_Nv=000001/0010}', "");
Expect(1, 8531, '\P{Is_Nv=000001/0010}', "");
Expect(0, 8531, '\P{^Is_Nv=000001/0010}', "");
Expect(1, 8530, '\p{Is_Nv=0.100}', "");
Expect(0, 8530, '\p{^Is_Nv=0.100}', "");
Expect(0, 8530, '\P{Is_Nv=0.100}', "");
Expect(1, 8530, '\P{^Is_Nv=0.100}', "");
Expect(0, 8531, '\p{Is_Nv=0.100}', "");
Expect(1, 8531, '\p{^Is_Nv=0.100}', "");
Expect(1, 8531, '\P{Is_Nv=0.100}', "");
Expect(0, 8531, '\P{^Is_Nv=0.100}', "");
Error('\p{Numeric_Value=/a/__+00000001/0000016}');
Error('\P{Numeric_Value=/a/__+00000001/0000016}');
Expect(1, 43059, '\p{Numeric_Value=0000000001/00000016}', "");
Expect(0, 43059, '\p{^Numeric_Value=0000000001/00000016}', "");
Expect(0, 43059, '\P{Numeric_Value=0000000001/00000016}', "");
Expect(1, 43059, '\P{^Numeric_Value=0000000001/00000016}', "");
Expect(0, 43060, '\p{Numeric_Value=0000000001/00000016}', "");
Expect(1, 43060, '\p{^Numeric_Value=0000000001/00000016}', "");
Expect(1, 43060, '\P{Numeric_Value=0000000001/00000016}', "");
Expect(0, 43060, '\P{^Numeric_Value=0000000001/00000016}', "");
Error('\p{Numeric_Value:	0.06}');
Error('\P{Numeric_Value:	0.06}');
Expect(1, 43059, '\p{Numeric_Value=0.063}', "");
Expect(0, 43059, '\p{^Numeric_Value=0.063}', "");
Expect(0, 43059, '\P{Numeric_Value=0.063}', "");
Expect(1, 43059, '\P{^Numeric_Value=0.063}', "");
Expect(0, 43060, '\p{Numeric_Value=0.063}', "");
Expect(1, 43060, '\p{^Numeric_Value=0.063}', "");
Expect(1, 43060, '\P{Numeric_Value=0.063}', "");
Expect(0, 43060, '\P{^Numeric_Value=0.063}', "");
Error('\p{Nv=	-00001/000000016:=}');
Error('\P{Nv=	-00001/000000016:=}');
Expect(1, 43059, '\p{Nv=00000001/00000016}', "");
Expect(0, 43059, '\p{^Nv=00000001/00000016}', "");
Expect(0, 43059, '\P{Nv=00000001/00000016}', "");
Expect(1, 43059, '\P{^Nv=00000001/00000016}', "");
Expect(0, 43060, '\p{Nv=00000001/00000016}', "");
Expect(1, 43060, '\p{^Nv=00000001/00000016}', "");
Expect(1, 43060, '\P{Nv=00000001/00000016}', "");
Expect(0, 43060, '\P{^Nv=00000001/00000016}', "");
Error('\p{Nv=0.06}');
Error('\P{Nv=0.06}');
Expect(1, 43059, '\p{Nv=0.063}', "");
Expect(0, 43059, '\p{^Nv=0.063}', "");
Expect(0, 43059, '\P{Nv=0.063}', "");
Expect(1, 43059, '\P{^Nv=0.063}', "");
Expect(0, 43060, '\p{Nv=0.063}', "");
Expect(1, 43060, '\p{^Nv=0.063}', "");
Expect(1, 43060, '\P{Nv=0.063}', "");
Expect(0, 43060, '\P{^Nv=0.063}', "");
Error('\p{Is_Numeric_Value=:=_ 0000001/00016}');
Error('\P{Is_Numeric_Value=:=_ 0000001/00016}');
Expect(1, 43059, '\p{Is_Numeric_Value=01/00000000016}', "");
Expect(0, 43059, '\p{^Is_Numeric_Value=01/00000000016}', "");
Expect(0, 43059, '\P{Is_Numeric_Value=01/00000000016}', "");
Expect(1, 43059, '\P{^Is_Numeric_Value=01/00000000016}', "");
Expect(0, 43060, '\p{Is_Numeric_Value=01/00000000016}', "");
Expect(1, 43060, '\p{^Is_Numeric_Value=01/00000000016}', "");
Expect(1, 43060, '\P{Is_Numeric_Value=01/00000000016}', "");
Expect(0, 43060, '\P{^Is_Numeric_Value=01/00000000016}', "");
Error('\p{Is_Numeric_Value=0.06}');
Error('\P{Is_Numeric_Value=0.06}');
Expect(1, 43059, '\p{Is_Numeric_Value=0.063}', "");
Expect(0, 43059, '\p{^Is_Numeric_Value=0.063}', "");
Expect(0, 43059, '\P{Is_Numeric_Value=0.063}', "");
Expect(1, 43059, '\P{^Is_Numeric_Value=0.063}', "");
Expect(0, 43060, '\p{Is_Numeric_Value=0.063}', "");
Expect(1, 43060, '\p{^Is_Numeric_Value=0.063}', "");
Expect(1, 43060, '\P{Is_Numeric_Value=0.063}', "");
Expect(0, 43060, '\P{^Is_Numeric_Value=0.063}', "");
Error('\p{Is_Nv=_/a/+000000001/00016}');
Error('\P{Is_Nv=_/a/+000000001/00016}');
Expect(1, 43059, '\p{Is_Nv=1/0016}', "");
Expect(0, 43059, '\p{^Is_Nv=1/0016}', "");
Expect(0, 43059, '\P{Is_Nv=1/0016}', "");
Expect(1, 43059, '\P{^Is_Nv=1/0016}', "");
Expect(0, 43060, '\p{Is_Nv=1/0016}', "");
Expect(1, 43060, '\p{^Is_Nv=1/0016}', "");
Expect(1, 43060, '\P{Is_Nv=1/0016}', "");
Expect(0, 43060, '\P{^Is_Nv=1/0016}', "");
Error('\p{Is_Nv=0.06}');
Error('\P{Is_Nv=0.06}');
Expect(1, 43059, '\p{Is_Nv=0.063}', "");
Expect(0, 43059, '\p{^Is_Nv=0.063}', "");
Expect(0, 43059, '\P{Is_Nv=0.063}', "");
Expect(1, 43059, '\P{^Is_Nv=0.063}', "");
Expect(0, 43060, '\p{Is_Nv=0.063}', "");
Expect(1, 43060, '\p{^Is_Nv=0.063}', "");
Expect(1, 43060, '\P{Is_Nv=0.063}', "");
Expect(0, 43060, '\P{^Is_Nv=0.063}', "");
Error('\p{Numeric_Value=:=000001/0002}');
Error('\P{Numeric_Value=:=000001/0002}');
Expect(1, 69243, '\p{Numeric_Value=000001/2}', "");
Expect(0, 69243, '\p{^Numeric_Value=000001/2}', "");
Expect(0, 69243, '\P{Numeric_Value=000001/2}', "");
Expect(1, 69243, '\P{^Numeric_Value=000001/2}', "");
Expect(0, 69244, '\p{Numeric_Value=000001/2}', "");
Expect(1, 69244, '\p{^Numeric_Value=000001/2}', "");
Expect(1, 69244, '\P{Numeric_Value=000001/2}', "");
Expect(0, 69244, '\P{^Numeric_Value=000001/2}', "");
Expect(1, 69243, '\p{Numeric_Value=0.500}', "");
Expect(0, 69243, '\p{^Numeric_Value=0.500}', "");
Expect(0, 69243, '\P{Numeric_Value=0.500}', "");
Expect(1, 69243, '\P{^Numeric_Value=0.500}', "");
Expect(0, 69244, '\p{Numeric_Value=0.500}', "");
Expect(1, 69244, '\p{^Numeric_Value=0.500}', "");
Expect(1, 69244, '\P{Numeric_Value=0.500}', "");
Expect(0, 69244, '\P{^Numeric_Value=0.500}', "");
Error('\p{Nv= /a/0000001/2}');
Error('\P{Nv= /a/0000001/2}');
Expect(1, 69243, '\p{Nv=0001/00000002}', "");
Expect(0, 69243, '\p{^Nv=0001/00000002}', "");
Expect(0, 69243, '\P{Nv=0001/00000002}', "");
Expect(1, 69243, '\P{^Nv=0001/00000002}', "");
Expect(0, 69244, '\p{Nv=0001/00000002}', "");
Expect(1, 69244, '\p{^Nv=0001/00000002}', "");
Expect(1, 69244, '\P{Nv=0001/00000002}', "");
Expect(0, 69244, '\P{^Nv=0001/00000002}', "");
Expect(1, 69243, '\p{Nv=0.500}', "");
Expect(0, 69243, '\p{^Nv=0.500}', "");
Expect(0, 69243, '\P{Nv=0.500}', "");
Expect(1, 69243, '\P{^Nv=0.500}', "");
Expect(0, 69244, '\p{Nv=0.500}', "");
Expect(1, 69244, '\p{^Nv=0.500}', "");
Expect(1, 69244, '\P{Nv=0.500}', "");
Expect(0, 69244, '\P{^Nv=0.500}', "");
Error('\p{Is_Numeric_Value=:=-1/000000002}');
Error('\P{Is_Numeric_Value=:=-1/000000002}');
Expect(1, 69243, '\p{Is_Numeric_Value=000000001/2}', "");
Expect(0, 69243, '\p{^Is_Numeric_Value=000000001/2}', "");
Expect(0, 69243, '\P{Is_Numeric_Value=000000001/2}', "");
Expect(1, 69243, '\P{^Is_Numeric_Value=000000001/2}', "");
Expect(0, 69244, '\p{Is_Numeric_Value=000000001/2}', "");
Expect(1, 69244, '\p{^Is_Numeric_Value=000000001/2}', "");
Expect(1, 69244, '\P{Is_Numeric_Value=000000001/2}', "");
Expect(0, 69244, '\P{^Is_Numeric_Value=000000001/2}', "");
Expect(1, 69243, '\p{Is_Numeric_Value:   0.500}', "");
Expect(0, 69243, '\p{^Is_Numeric_Value:   0.500}', "");
Expect(0, 69243, '\P{Is_Numeric_Value:   0.500}', "");
Expect(1, 69243, '\P{^Is_Numeric_Value:   0.500}', "");
Expect(0, 69244, '\p{Is_Numeric_Value:   0.500}', "");
Expect(1, 69244, '\p{^Is_Numeric_Value:   0.500}', "");
Expect(1, 69244, '\P{Is_Numeric_Value:   0.500}', "");
Expect(0, 69244, '\P{^Is_Numeric_Value:   0.500}', "");
Error('\p{Is_Nv=		+000001/002/a/}');
Error('\P{Is_Nv=		+000001/002/a/}');
Expect(1, 69243, '\p{Is_Nv=+0000000001/0002}', "");
Expect(0, 69243, '\p{^Is_Nv=+0000000001/0002}', "");
Expect(0, 69243, '\P{Is_Nv=+0000000001/0002}', "");
Expect(1, 69243, '\P{^Is_Nv=+0000000001/0002}', "");
Expect(0, 69244, '\p{Is_Nv=+0000000001/0002}', "");
Expect(1, 69244, '\p{^Is_Nv=+0000000001/0002}', "");
Expect(1, 69244, '\P{Is_Nv=+0000000001/0002}', "");
Expect(0, 69244, '\P{^Is_Nv=+0000000001/0002}', "");
Expect(1, 69243, '\p{Is_Nv=0.500}', "");
Expect(0, 69243, '\p{^Is_Nv=0.500}', "");
Expect(0, 69243, '\P{Is_Nv=0.500}', "");
Expect(1, 69243, '\P{^Is_Nv=0.500}', "");
Expect(0, 69244, '\p{Is_Nv=0.500}', "");
Expect(1, 69244, '\p{^Is_Nv=0.500}', "");
Expect(1, 69244, '\P{Is_Nv=0.500}', "");
Expect(0, 69244, '\P{^Is_Nv=0.500}', "");
Error('\p{Numeric_Value=/a/--+000001/000000003}');
Error('\P{Numeric_Value=/a/--+000001/000000003}');
Expect(1, 74845, '\p{Numeric_Value=+0000000001/00003}', "");
Expect(0, 74845, '\p{^Numeric_Value=+0000000001/00003}', "");
Expect(0, 74845, '\P{Numeric_Value=+0000000001/00003}', "");
Expect(1, 74845, '\P{^Numeric_Value=+0000000001/00003}', "");
Expect(0, 74846, '\p{Numeric_Value=+0000000001/00003}', "");
Expect(1, 74846, '\p{^Numeric_Value=+0000000001/00003}', "");
Expect(1, 74846, '\P{Numeric_Value=+0000000001/00003}', "");
Expect(0, 74846, '\P{^Numeric_Value=+0000000001/00003}', "");
Error('\p{Numeric_Value=0.3}');
Error('\P{Numeric_Value=0.3}');
Error('\p{Numeric_Value=0.33}');
Error('\P{Numeric_Value=0.33}');
Expect(1, 74845, '\p{Numeric_Value=0.333}', "");
Expect(0, 74845, '\p{^Numeric_Value=0.333}', "");
Expect(0, 74845, '\P{Numeric_Value=0.333}', "");
Expect(1, 74845, '\P{^Numeric_Value=0.333}', "");
Expect(0, 74846, '\p{Numeric_Value=0.333}', "");
Expect(1, 74846, '\p{^Numeric_Value=0.333}', "");
Expect(1, 74846, '\P{Numeric_Value=0.333}', "");
Expect(0, 74846, '\P{^Numeric_Value=0.333}', "");
Error('\p{Nv=_00001/03/a/}');
Error('\P{Nv=_00001/03/a/}');
Expect(1, 74845, '\p{Nv=0001/03}', "");
Expect(0, 74845, '\p{^Nv=0001/03}', "");
Expect(0, 74845, '\P{Nv=0001/03}', "");
Expect(1, 74845, '\P{^Nv=0001/03}', "");
Expect(0, 74846, '\p{Nv=0001/03}', "");
Expect(1, 74846, '\p{^Nv=0001/03}', "");
Expect(1, 74846, '\P{Nv=0001/03}', "");
Expect(0, 74846, '\P{^Nv=0001/03}', "");
Error('\p{Nv:0.3}');
Error('\P{Nv:0.3}');
Error('\p{Nv=0.33}');
Error('\P{Nv=0.33}');
Expect(1, 74845, '\p{Nv=0.333}', "");
Expect(0, 74845, '\p{^Nv=0.333}', "");
Expect(0, 74845, '\P{Nv=0.333}', "");
Expect(1, 74845, '\P{^Nv=0.333}', "");
Expect(0, 74846, '\p{Nv=0.333}', "");
Expect(1, 74846, '\p{^Nv=0.333}', "");
Expect(1, 74846, '\P{Nv=0.333}', "");
Expect(0, 74846, '\P{^Nv=0.333}', "");
Error('\p{Is_Numeric_Value=:=-_01/00000003}');
Error('\P{Is_Numeric_Value=:=-_01/00000003}');
Expect(1, 74845, '\p{Is_Numeric_Value:+01/3}', "");
Expect(0, 74845, '\p{^Is_Numeric_Value:+01/3}', "");
Expect(0, 74845, '\P{Is_Numeric_Value:+01/3}', "");
Expect(1, 74845, '\P{^Is_Numeric_Value:+01/3}', "");
Expect(0, 74846, '\p{Is_Numeric_Value:+01/3}', "");
Expect(1, 74846, '\p{^Is_Numeric_Value:+01/3}', "");
Expect(1, 74846, '\P{Is_Numeric_Value:+01/3}', "");
Expect(0, 74846, '\P{^Is_Numeric_Value:+01/3}', "");
Error('\p{Is_Numeric_Value=0.3}');
Error('\P{Is_Numeric_Value=0.3}');
Error('\p{Is_Numeric_Value=0.33}');
Error('\P{Is_Numeric_Value=0.33}');
Expect(1, 74845, '\p{Is_Numeric_Value=0.333}', "");
Expect(0, 74845, '\p{^Is_Numeric_Value=0.333}', "");
Expect(0, 74845, '\P{Is_Numeric_Value=0.333}', "");
Expect(1, 74845, '\P{^Is_Numeric_Value=0.333}', "");
Expect(0, 74846, '\p{Is_Numeric_Value=0.333}', "");
Expect(1, 74846, '\p{^Is_Numeric_Value=0.333}', "");
Expect(1, 74846, '\P{Is_Numeric_Value=0.333}', "");
Expect(0, 74846, '\P{^Is_Numeric_Value=0.333}', "");
Error('\p{Is_Nv=	_+01/0003/a/}');
Error('\P{Is_Nv=	_+01/0003/a/}');
Expect(1, 74845, '\p{Is_Nv=00001/000000003}', "");
Expect(0, 74845, '\p{^Is_Nv=00001/000000003}', "");
Expect(0, 74845, '\P{Is_Nv=00001/000000003}', "");
Expect(1, 74845, '\P{^Is_Nv=00001/000000003}', "");
Expect(0, 74846, '\p{Is_Nv=00001/000000003}', "");
Expect(1, 74846, '\p{^Is_Nv=00001/000000003}', "");
Expect(1, 74846, '\P{Is_Nv=00001/000000003}', "");
Expect(0, 74846, '\P{^Is_Nv=00001/000000003}', "");
Error('\p{Is_Nv=0.3}');
Error('\P{Is_Nv=0.3}');
Error('\p{Is_Nv=0.33}');
Error('\P{Is_Nv=0.33}');
Expect(1, 74845, '\p{Is_Nv=0.333}', "");
Expect(0, 74845, '\p{^Is_Nv=0.333}', "");
Expect(0, 74845, '\P{Is_Nv=0.333}', "");
Expect(1, 74845, '\P{^Is_Nv=0.333}', "");
Expect(0, 74846, '\p{Is_Nv=0.333}', "");
Expect(1, 74846, '\p{^Is_Nv=0.333}', "");
Expect(1, 74846, '\P{Is_Nv=0.333}', "");
Expect(0, 74846, '\P{^Is_Nv=0.333}', "");
Error('\p{Numeric_Value:   /a/+01/000004}');
Error('\P{Numeric_Value:   /a/+01/000004}');
Expect(1, 74850, '\p{Numeric_Value:   0000000001/4}', "");
Expect(0, 74850, '\p{^Numeric_Value:   0000000001/4}', "");
Expect(0, 74850, '\P{Numeric_Value:   0000000001/4}', "");
Expect(1, 74850, '\P{^Numeric_Value:   0000000001/4}', "");
Expect(0, 74851, '\p{Numeric_Value:   0000000001/4}', "");
Expect(1, 74851, '\p{^Numeric_Value:   0000000001/4}', "");
Expect(1, 74851, '\P{Numeric_Value:   0000000001/4}', "");
Expect(0, 74851, '\P{^Numeric_Value:   0000000001/4}', "");
Error('\p{Numeric_Value=0.3}');
Error('\P{Numeric_Value=0.3}');
Expect(1, 74850, '\p{Numeric_Value: 0.250}', "");
Expect(0, 74850, '\p{^Numeric_Value: 0.250}', "");
Expect(0, 74850, '\P{Numeric_Value: 0.250}', "");
Expect(1, 74850, '\P{^Numeric_Value: 0.250}', "");
Expect(0, 74851, '\p{Numeric_Value: 0.250}', "");
Expect(1, 74851, '\p{^Numeric_Value: 0.250}', "");
Expect(1, 74851, '\P{Numeric_Value: 0.250}', "");
Expect(0, 74851, '\P{^Numeric_Value: 0.250}', "");
Error('\p{Nv:	 /a/+01/4}');
Error('\P{Nv:	 /a/+01/4}');
Expect(1, 74850, '\p{Nv=000000001/000000004}', "");
Expect(0, 74850, '\p{^Nv=000000001/000000004}', "");
Expect(0, 74850, '\P{Nv=000000001/000000004}', "");
Expect(1, 74850, '\P{^Nv=000000001/000000004}', "");
Expect(0, 74851, '\p{Nv=000000001/000000004}', "");
Expect(1, 74851, '\p{^Nv=000000001/000000004}', "");
Expect(1, 74851, '\P{Nv=000000001/000000004}', "");
Expect(0, 74851, '\P{^Nv=000000001/000000004}', "");
Error('\p{Nv=0.3}');
Error('\P{Nv=0.3}');
Expect(1, 74850, '\p{Nv=0.250}', "");
Expect(0, 74850, '\p{^Nv=0.250}', "");
Expect(0, 74850, '\P{Nv=0.250}', "");
Expect(1, 74850, '\P{^Nv=0.250}', "");
Expect(0, 74851, '\p{Nv=0.250}', "");
Expect(1, 74851, '\p{^Nv=0.250}', "");
Expect(1, 74851, '\P{Nv=0.250}', "");
Expect(0, 74851, '\P{^Nv=0.250}', "");
Error('\p{Is_Numeric_Value=/a/__001/04}');
Error('\P{Is_Numeric_Value=/a/__001/04}');
Expect(1, 74850, '\p{Is_Numeric_Value=0000000001/000000004}', "");
Expect(0, 74850, '\p{^Is_Numeric_Value=0000000001/000000004}', "");
Expect(0, 74850, '\P{Is_Numeric_Value=0000000001/000000004}', "");
Expect(1, 74850, '\P{^Is_Numeric_Value=0000000001/000000004}', "");
Expect(0, 74851, '\p{Is_Numeric_Value=0000000001/000000004}', "");
Expect(1, 74851, '\p{^Is_Numeric_Value=0000000001/000000004}', "");
Expect(1, 74851, '\P{Is_Numeric_Value=0000000001/000000004}', "");
Expect(0, 74851, '\P{^Is_Numeric_Value=0000000001/000000004}', "");
Error('\p{Is_Numeric_Value:	0.3}');
Error('\P{Is_Numeric_Value:	0.3}');
Expect(1, 74850, '\p{Is_Numeric_Value=0.250}', "");
Expect(0, 74850, '\p{^Is_Numeric_Value=0.250}', "");
Expect(0, 74850, '\P{Is_Numeric_Value=0.250}', "");
Expect(1, 74850, '\P{^Is_Numeric_Value=0.250}', "");
Expect(0, 74851, '\p{Is_Numeric_Value=0.250}', "");
Expect(1, 74851, '\p{^Is_Numeric_Value=0.250}', "");
Expect(1, 74851, '\P{Is_Numeric_Value=0.250}', "");
Expect(0, 74851, '\P{^Is_Numeric_Value=0.250}', "");
Error('\p{Is_Nv=:=0001/000004}');
Error('\P{Is_Nv=:=0001/000004}');
Expect(1, 74850, '\p{Is_Nv=1/004}', "");
Expect(0, 74850, '\p{^Is_Nv=1/004}', "");
Expect(0, 74850, '\P{Is_Nv=1/004}', "");
Expect(1, 74850, '\P{^Is_Nv=1/004}', "");
Expect(0, 74851, '\p{Is_Nv=1/004}', "");
Expect(1, 74851, '\p{^Is_Nv=1/004}', "");
Expect(1, 74851, '\P{Is_Nv=1/004}', "");
Expect(0, 74851, '\P{^Is_Nv=1/004}', "");
Error('\p{Is_Nv:	0.3}');
Error('\P{Is_Nv:	0.3}');
Expect(1, 74850, '\p{Is_Nv=0.250}', "");
Expect(0, 74850, '\p{^Is_Nv=0.250}', "");
Expect(0, 74850, '\P{Is_Nv=0.250}', "");
Expect(1, 74850, '\P{^Is_Nv=0.250}', "");
Expect(0, 74851, '\p{Is_Nv=0.250}', "");
Expect(1, 74851, '\p{^Is_Nv=0.250}', "");
Expect(1, 74851, '\P{Is_Nv=0.250}', "");
Expect(0, 74851, '\P{^Is_Nv=0.250}', "");
Error('\p{Numeric_Value= /a/0000000001/00005}');
Error('\P{Numeric_Value= /a/0000000001/00005}');
Expect(1, 8533, '\p{Numeric_Value=00000001/000000005}', "");
Expect(0, 8533, '\p{^Numeric_Value=00000001/000000005}', "");
Expect(0, 8533, '\P{Numeric_Value=00000001/000000005}', "");
Expect(1, 8533, '\P{^Numeric_Value=00000001/000000005}', "");
Expect(0, 8534, '\p{Numeric_Value=00000001/000000005}', "");
Expect(1, 8534, '\p{^Numeric_Value=00000001/000000005}', "");
Expect(1, 8534, '\P{Numeric_Value=00000001/000000005}', "");
Expect(0, 8534, '\P{^Numeric_Value=00000001/000000005}', "");
Expect(1, 8533, '\p{Numeric_Value=0.200}', "");
Expect(0, 8533, '\p{^Numeric_Value=0.200}', "");
Expect(0, 8533, '\P{Numeric_Value=0.200}', "");
Expect(1, 8533, '\P{^Numeric_Value=0.200}', "");
Expect(0, 8534, '\p{Numeric_Value=0.200}', "");
Expect(1, 8534, '\p{^Numeric_Value=0.200}', "");
Expect(1, 8534, '\P{Numeric_Value=0.200}', "");
Expect(0, 8534, '\P{^Numeric_Value=0.200}', "");
Error('\p{Nv=_/a/0001/05}');
Error('\P{Nv=_/a/0001/05}');
Expect(1, 8533, '\p{Nv=+0000001/005}', "");
Expect(0, 8533, '\p{^Nv=+0000001/005}', "");
Expect(0, 8533, '\P{Nv=+0000001/005}', "");
Expect(1, 8533, '\P{^Nv=+0000001/005}', "");
Expect(0, 8534, '\p{Nv=+0000001/005}', "");
Expect(1, 8534, '\p{^Nv=+0000001/005}', "");
Expect(1, 8534, '\P{Nv=+0000001/005}', "");
Expect(0, 8534, '\P{^Nv=+0000001/005}', "");
Expect(1, 8533, '\p{Nv=0.200}', "");
Expect(0, 8533, '\p{^Nv=0.200}', "");
Expect(0, 8533, '\P{Nv=0.200}', "");
Expect(1, 8533, '\P{^Nv=0.200}', "");
Expect(0, 8534, '\p{Nv=0.200}', "");
Expect(1, 8534, '\p{^Nv=0.200}', "");
Expect(1, 8534, '\P{Nv=0.200}', "");
Expect(0, 8534, '\P{^Nv=0.200}', "");
Error('\p{Is_Numeric_Value=	/a/1/05}');
Error('\P{Is_Numeric_Value=	/a/1/05}');
Expect(1, 8533, '\p{Is_Numeric_Value=1/0000000005}', "");
Expect(0, 8533, '\p{^Is_Numeric_Value=1/0000000005}', "");
Expect(0, 8533, '\P{Is_Numeric_Value=1/0000000005}', "");
Expect(1, 8533, '\P{^Is_Numeric_Value=1/0000000005}', "");
Expect(0, 8534, '\p{Is_Numeric_Value=1/0000000005}', "");
Expect(1, 8534, '\p{^Is_Numeric_Value=1/0000000005}', "");
Expect(1, 8534, '\P{Is_Numeric_Value=1/0000000005}', "");
Expect(0, 8534, '\P{^Is_Numeric_Value=1/0000000005}', "");
Expect(1, 8533, '\p{Is_Numeric_Value=0.200}', "");
Expect(0, 8533, '\p{^Is_Numeric_Value=0.200}', "");
Expect(0, 8533, '\P{Is_Numeric_Value=0.200}', "");
Expect(1, 8533, '\P{^Is_Numeric_Value=0.200}', "");
Expect(0, 8534, '\p{Is_Numeric_Value=0.200}', "");
Expect(1, 8534, '\p{^Is_Numeric_Value=0.200}', "");
Expect(1, 8534, '\P{Is_Numeric_Value=0.200}', "");
Expect(0, 8534, '\P{^Is_Numeric_Value=0.200}', "");
Error('\p{Is_Nv:_:=+0000001/000000005}');
Error('\P{Is_Nv:_:=+0000001/000000005}');
Expect(1, 8533, '\p{Is_Nv=+00001/0000005}', "");
Expect(0, 8533, '\p{^Is_Nv=+00001/0000005}', "");
Expect(0, 8533, '\P{Is_Nv=+00001/0000005}', "");
Expect(1, 8533, '\P{^Is_Nv=+00001/0000005}', "");
Expect(0, 8534, '\p{Is_Nv=+00001/0000005}', "");
Expect(1, 8534, '\p{^Is_Nv=+00001/0000005}', "");
Expect(1, 8534, '\P{Is_Nv=+00001/0000005}', "");
Expect(0, 8534, '\P{^Is_Nv=+00001/0000005}', "");
Expect(1, 8533, '\p{Is_Nv=0.200}', "");
Expect(0, 8533, '\p{^Is_Nv=0.200}', "");
Expect(0, 8533, '\P{Is_Nv=0.200}', "");
Expect(1, 8533, '\P{^Is_Nv=0.200}', "");
Expect(0, 8534, '\p{Is_Nv=0.200}', "");
Expect(1, 8534, '\p{^Is_Nv=0.200}', "");
Expect(1, 8534, '\P{Is_Nv=0.200}', "");
Expect(0, 8534, '\P{^Is_Nv=0.200}', "");
Error('\p{Numeric_Value=:=__1/006}');
Error('\P{Numeric_Value=:=__1/006}');
Expect(1, 74849, '\p{Numeric_Value=00001/0000000006}', "");
Expect(0, 74849, '\p{^Numeric_Value=00001/0000000006}', "");
Expect(0, 74849, '\P{Numeric_Value=00001/0000000006}', "");
Expect(1, 74849, '\P{^Numeric_Value=00001/0000000006}', "");
Expect(0, 74850, '\p{Numeric_Value=00001/0000000006}', "");
Expect(1, 74850, '\p{^Numeric_Value=00001/0000000006}', "");
Expect(1, 74850, '\P{Numeric_Value=00001/0000000006}', "");
Expect(0, 74850, '\P{^Numeric_Value=00001/0000000006}', "");
Error('\p{Numeric_Value=0.17}');
Error('\P{Numeric_Value=0.17}');
Expect(1, 74849, '\p{Numeric_Value=0.167}', "");
Expect(0, 74849, '\p{^Numeric_Value=0.167}', "");
Expect(0, 74849, '\P{Numeric_Value=0.167}', "");
Expect(1, 74849, '\P{^Numeric_Value=0.167}', "");
Expect(0, 74850, '\p{Numeric_Value=0.167}', "");
Expect(1, 74850, '\p{^Numeric_Value=0.167}', "");
Expect(1, 74850, '\P{Numeric_Value=0.167}', "");
Expect(0, 74850, '\P{^Numeric_Value=0.167}', "");
Error('\p{Nv=:=0000000001/00000006}');
Error('\P{Nv=:=0000000001/00000006}');
Expect(1, 74849, '\p{Nv=00000001/06}', "");
Expect(0, 74849, '\p{^Nv=00000001/06}', "");
Expect(0, 74849, '\P{Nv=00000001/06}', "");
Expect(1, 74849, '\P{^Nv=00000001/06}', "");
Expect(0, 74850, '\p{Nv=00000001/06}', "");
Expect(1, 74850, '\p{^Nv=00000001/06}', "");
Expect(1, 74850, '\P{Nv=00000001/06}', "");
Expect(0, 74850, '\P{^Nv=00000001/06}', "");
Error('\p{Nv=0.17}');
Error('\P{Nv=0.17}');
Expect(1, 74849, '\p{Nv=0.167}', "");
Expect(0, 74849, '\p{^Nv=0.167}', "");
Expect(0, 74849, '\P{Nv=0.167}', "");
Expect(1, 74849, '\P{^Nv=0.167}', "");
Expect(0, 74850, '\p{Nv=0.167}', "");
Expect(1, 74850, '\p{^Nv=0.167}', "");
Expect(1, 74850, '\P{Nv=0.167}', "");
Expect(0, 74850, '\P{^Nv=0.167}', "");
Error('\p{Is_Numeric_Value=_-0000000001/6/a/}');
Error('\P{Is_Numeric_Value=_-0000000001/6/a/}');
Expect(1, 74849, '\p{Is_Numeric_Value=000000001/000000006}', "");
Expect(0, 74849, '\p{^Is_Numeric_Value=000000001/000000006}', "");
Expect(0, 74849, '\P{Is_Numeric_Value=000000001/000000006}', "");
Expect(1, 74849, '\P{^Is_Numeric_Value=000000001/000000006}', "");
Expect(0, 74850, '\p{Is_Numeric_Value=000000001/000000006}', "");
Expect(1, 74850, '\p{^Is_Numeric_Value=000000001/000000006}', "");
Expect(1, 74850, '\P{Is_Numeric_Value=000000001/000000006}', "");
Expect(0, 74850, '\P{^Is_Numeric_Value=000000001/000000006}', "");
Error('\p{Is_Numeric_Value=0.17}');
Error('\P{Is_Numeric_Value=0.17}');
Expect(1, 74849, '\p{Is_Numeric_Value=0.167}', "");
Expect(0, 74849, '\p{^Is_Numeric_Value=0.167}', "");
Expect(0, 74849, '\P{Is_Numeric_Value=0.167}', "");
Expect(1, 74849, '\P{^Is_Numeric_Value=0.167}', "");
Expect(0, 74850, '\p{Is_Numeric_Value=0.167}', "");
Expect(1, 74850, '\p{^Is_Numeric_Value=0.167}', "");
Expect(1, 74850, '\P{Is_Numeric_Value=0.167}', "");
Expect(0, 74850, '\P{^Is_Numeric_Value=0.167}', "");
Error('\p{Is_Nv=_-+000000001/00006:=}');
Error('\P{Is_Nv=_-+000000001/00006:=}');
Expect(1, 74849, '\p{Is_Nv=+0000000001/0000006}', "");
Expect(0, 74849, '\p{^Is_Nv=+0000000001/0000006}', "");
Expect(0, 74849, '\P{Is_Nv=+0000000001/0000006}', "");
Expect(1, 74849, '\P{^Is_Nv=+0000000001/0000006}', "");
Expect(0, 74850, '\p{Is_Nv=+0000000001/0000006}', "");
Expect(1, 74850, '\p{^Is_Nv=+0000000001/0000006}', "");
Expect(1, 74850, '\P{Is_Nv=+0000000001/0000006}', "");
Expect(0, 74850, '\P{^Is_Nv=+0000000001/0000006}', "");
Error('\p{Is_Nv:0.17}');
Error('\P{Is_Nv:0.17}');
Expect(1, 74849, '\p{Is_Nv=0.167}', "");
Expect(0, 74849, '\p{^Is_Nv=0.167}', "");
Expect(0, 74849, '\P{Is_Nv=0.167}', "");
Expect(1, 74849, '\P{^Is_Nv=0.167}', "");
Expect(0, 74850, '\p{Is_Nv=0.167}', "");
Expect(1, 74850, '\p{^Is_Nv=0.167}', "");
Expect(1, 74850, '\P{Is_Nv=0.167}', "");
Expect(0, 74850, '\P{^Is_Nv=0.167}', "");
Error('\p{Numeric_Value=	:=+0000000001/7}');
Error('\P{Numeric_Value=	:=+0000000001/7}');
Expect(1, 8528, '\p{Numeric_Value=01/000007}', "");
Expect(0, 8528, '\p{^Numeric_Value=01/000007}', "");
Expect(0, 8528, '\P{Numeric_Value=01/000007}', "");
Expect(1, 8528, '\P{^Numeric_Value=01/000007}', "");
Expect(0, 8529, '\p{Numeric_Value=01/000007}', "");
Expect(1, 8529, '\p{^Numeric_Value=01/000007}', "");
Expect(1, 8529, '\P{Numeric_Value=01/000007}', "");
Expect(0, 8529, '\P{^Numeric_Value=01/000007}', "");
Error('\p{Numeric_Value=0.14}');
Error('\P{Numeric_Value=0.14}');
Expect(1, 8528, '\p{Numeric_Value=0.143}', "");
Expect(0, 8528, '\p{^Numeric_Value=0.143}', "");
Expect(0, 8528, '\P{Numeric_Value=0.143}', "");
Expect(1, 8528, '\P{^Numeric_Value=0.143}', "");
Expect(0, 8529, '\p{Numeric_Value=0.143}', "");
Expect(1, 8529, '\p{^Numeric_Value=0.143}', "");
Expect(1, 8529, '\P{Numeric_Value=0.143}', "");
Expect(0, 8529, '\P{^Numeric_Value=0.143}', "");
Error('\p{Nv=-/a/0000001/0000000007}');
Error('\P{Nv=-/a/0000001/0000000007}');
Expect(1, 8528, '\p{Nv: 01/07}', "");
Expect(0, 8528, '\p{^Nv: 01/07}', "");
Expect(0, 8528, '\P{Nv: 01/07}', "");
Expect(1, 8528, '\P{^Nv: 01/07}', "");
Expect(0, 8529, '\p{Nv: 01/07}', "");
Expect(1, 8529, '\p{^Nv: 01/07}', "");
Expect(1, 8529, '\P{Nv: 01/07}', "");
Expect(0, 8529, '\P{^Nv: 01/07}', "");
Error('\p{Nv:	0.14}');
Error('\P{Nv:	0.14}');
Expect(1, 8528, '\p{Nv=0.143}', "");
Expect(0, 8528, '\p{^Nv=0.143}', "");
Expect(0, 8528, '\P{Nv=0.143}', "");
Expect(1, 8528, '\P{^Nv=0.143}', "");
Expect(0, 8529, '\p{Nv=0.143}', "");
Expect(1, 8529, '\p{^Nv=0.143}', "");
Expect(1, 8529, '\P{Nv=0.143}', "");
Expect(0, 8529, '\P{^Nv=0.143}', "");
Error('\p{Is_Numeric_Value:-:=+000001/0000000007}');
Error('\P{Is_Numeric_Value:-:=+000001/0000000007}');
Expect(1, 8528, '\p{Is_Numeric_Value=00000001/00000007}', "");
Expect(0, 8528, '\p{^Is_Numeric_Value=00000001/00000007}', "");
Expect(0, 8528, '\P{Is_Numeric_Value=00000001/00000007}', "");
Expect(1, 8528, '\P{^Is_Numeric_Value=00000001/00000007}', "");
Expect(0, 8529, '\p{Is_Numeric_Value=00000001/00000007}', "");
Expect(1, 8529, '\p{^Is_Numeric_Value=00000001/00000007}', "");
Expect(1, 8529, '\P{Is_Numeric_Value=00000001/00000007}', "");
Expect(0, 8529, '\P{^Is_Numeric_Value=00000001/00000007}', "");
Error('\p{Is_Numeric_Value=0.14}');
Error('\P{Is_Numeric_Value=0.14}');
Expect(1, 8528, '\p{Is_Numeric_Value=0.143}', "");
Expect(0, 8528, '\p{^Is_Numeric_Value=0.143}', "");
Expect(0, 8528, '\P{Is_Numeric_Value=0.143}', "");
Expect(1, 8528, '\P{^Is_Numeric_Value=0.143}', "");
Expect(0, 8529, '\p{Is_Numeric_Value=0.143}', "");
Expect(1, 8529, '\p{^Is_Numeric_Value=0.143}', "");
Expect(1, 8529, '\P{Is_Numeric_Value=0.143}', "");
Expect(0, 8529, '\P{^Is_Numeric_Value=0.143}', "");
Error('\p{Is_Nv=:=_1/0007}');
Error('\P{Is_Nv=:=_1/0007}');
Expect(1, 8528, '\p{Is_Nv=0000001/0000000007}', "");
Expect(0, 8528, '\p{^Is_Nv=0000001/0000000007}', "");
Expect(0, 8528, '\P{Is_Nv=0000001/0000000007}', "");
Expect(1, 8528, '\P{^Is_Nv=0000001/0000000007}', "");
Expect(0, 8529, '\p{Is_Nv=0000001/0000000007}', "");
Expect(1, 8529, '\p{^Is_Nv=0000001/0000000007}', "");
Expect(1, 8529, '\P{Is_Nv=0000001/0000000007}', "");
Expect(0, 8529, '\P{^Is_Nv=0000001/0000000007}', "");
Error('\p{Is_Nv=0.14}');
Error('\P{Is_Nv=0.14}');
Expect(1, 8528, '\p{Is_Nv=0.143}', "");
Expect(0, 8528, '\p{^Is_Nv=0.143}', "");
Expect(0, 8528, '\P{Is_Nv=0.143}', "");
Expect(1, 8528, '\P{^Is_Nv=0.143}', "");
Expect(0, 8529, '\p{Is_Nv=0.143}', "");
Expect(1, 8529, '\p{^Is_Nv=0.143}', "");
Expect(1, 8529, '\P{Is_Nv=0.143}', "");
Expect(0, 8529, '\P{^Is_Nv=0.143}', "");
Error('\p{Numeric_Value:   -_000000001/0000008/a/}');
Error('\P{Numeric_Value:   -_000000001/0000008/a/}');
Expect(1, 74847, '\p{Numeric_Value=0001/008}', "");
Expect(0, 74847, '\p{^Numeric_Value=0001/008}', "");
Expect(0, 74847, '\P{Numeric_Value=0001/008}', "");
Expect(1, 74847, '\P{^Numeric_Value=0001/008}', "");
Expect(0, 74848, '\p{Numeric_Value=0001/008}', "");
Expect(1, 74848, '\p{^Numeric_Value=0001/008}', "");
Expect(1, 74848, '\P{Numeric_Value=0001/008}', "");
Expect(0, 74848, '\P{^Numeric_Value=0001/008}', "");
Error('\p{Numeric_Value=0.13}');
Error('\P{Numeric_Value=0.13}');
Expect(1, 74847, '\p{Numeric_Value=0.125}', "");
Expect(0, 74847, '\p{^Numeric_Value=0.125}', "");
Expect(0, 74847, '\P{Numeric_Value=0.125}', "");
Expect(1, 74847, '\P{^Numeric_Value=0.125}', "");
Expect(0, 74848, '\p{Numeric_Value=0.125}', "");
Expect(1, 74848, '\p{^Numeric_Value=0.125}', "");
Expect(1, 74848, '\P{Numeric_Value=0.125}', "");
Expect(0, 74848, '\P{^Numeric_Value=0.125}', "");
Error('\p{Nv=-_000001/8:=}');
Error('\P{Nv=-_000001/8:=}');
Expect(1, 74847, '\p{Nv=+000000001/000008}', "");
Expect(0, 74847, '\p{^Nv=+000000001/000008}', "");
Expect(0, 74847, '\P{Nv=+000000001/000008}', "");
Expect(1, 74847, '\P{^Nv=+000000001/000008}', "");
Expect(0, 74848, '\p{Nv=+000000001/000008}', "");
Expect(1, 74848, '\p{^Nv=+000000001/000008}', "");
Expect(1, 74848, '\P{Nv=+000000001/000008}', "");
Expect(0, 74848, '\P{^Nv=+000000001/000008}', "");
Error('\p{Nv=0.13}');
Error('\P{Nv=0.13}');
Expect(1, 74847, '\p{Nv=0.125}', "");
Expect(0, 74847, '\p{^Nv=0.125}', "");
Expect(0, 74847, '\P{Nv=0.125}', "");
Expect(1, 74847, '\P{^Nv=0.125}', "");
Expect(0, 74848, '\p{Nv=0.125}', "");
Expect(1, 74848, '\p{^Nv=0.125}', "");
Expect(1, 74848, '\P{Nv=0.125}', "");
Expect(0, 74848, '\P{^Nv=0.125}', "");
Error('\p{Is_Numeric_Value= _1/000008/a/}');
Error('\P{Is_Numeric_Value= _1/000008/a/}');
Expect(1, 74847, '\p{Is_Numeric_Value=0000000001/0000000008}', "");
Expect(0, 74847, '\p{^Is_Numeric_Value=0000000001/0000000008}', "");
Expect(0, 74847, '\P{Is_Numeric_Value=0000000001/0000000008}', "");
Expect(1, 74847, '\P{^Is_Numeric_Value=0000000001/0000000008}', "");
Expect(0, 74848, '\p{Is_Numeric_Value=0000000001/0000000008}', "");
Expect(1, 74848, '\p{^Is_Numeric_Value=0000000001/0000000008}', "");
Expect(1, 74848, '\P{Is_Numeric_Value=0000000001/0000000008}', "");
Expect(0, 74848, '\P{^Is_Numeric_Value=0000000001/0000000008}', "");
Error('\p{Is_Numeric_Value=0.13}');
Error('\P{Is_Numeric_Value=0.13}');
Expect(1, 74847, '\p{Is_Numeric_Value: 0.125}', "");
Expect(0, 74847, '\p{^Is_Numeric_Value: 0.125}', "");
Expect(0, 74847, '\P{Is_Numeric_Value: 0.125}', "");
Expect(1, 74847, '\P{^Is_Numeric_Value: 0.125}', "");
Expect(0, 74848, '\p{Is_Numeric_Value: 0.125}', "");
Expect(1, 74848, '\p{^Is_Numeric_Value: 0.125}', "");
Expect(1, 74848, '\P{Is_Numeric_Value: 0.125}', "");
Expect(0, 74848, '\P{^Is_Numeric_Value: 0.125}', "");
Error('\p{Is_Nv= /a/0001/0000008}');
Error('\P{Is_Nv= /a/0001/0000008}');
Expect(1, 74847, '\p{Is_Nv=+0000000001/0000008}', "");
Expect(0, 74847, '\p{^Is_Nv=+0000000001/0000008}', "");
Expect(0, 74847, '\P{Is_Nv=+0000000001/0000008}', "");
Expect(1, 74847, '\P{^Is_Nv=+0000000001/0000008}', "");
Expect(0, 74848, '\p{Is_Nv=+0000000001/0000008}', "");
Expect(1, 74848, '\p{^Is_Nv=+0000000001/0000008}', "");
Expect(1, 74848, '\P{Is_Nv=+0000000001/0000008}', "");
Expect(0, 74848, '\P{^Is_Nv=+0000000001/0000008}', "");
Error('\p{Is_Nv=0.13}');
Error('\P{Is_Nv=0.13}');
Expect(1, 74847, '\p{Is_Nv=0.125}', "");
Expect(0, 74847, '\p{^Is_Nv=0.125}', "");
Expect(0, 74847, '\P{Is_Nv=0.125}', "");
Expect(1, 74847, '\P{^Is_Nv=0.125}', "");
Expect(0, 74848, '\p{Is_Nv=0.125}', "");
Expect(1, 74848, '\p{^Is_Nv=0.125}', "");
Expect(1, 74848, '\P{Is_Nv=0.125}', "");
Expect(0, 74848, '\P{^Is_Nv=0.125}', "");
Error('\p{Numeric_Value=-0000001/09:=}');
Error('\P{Numeric_Value=-0000001/09:=}');
Expect(1, 8529, '\p{Numeric_Value=00001/0009}', "");
Expect(0, 8529, '\p{^Numeric_Value=00001/0009}', "");
Expect(0, 8529, '\P{Numeric_Value=00001/0009}', "");
Expect(1, 8529, '\P{^Numeric_Value=00001/0009}', "");
Expect(0, 8530, '\p{Numeric_Value=00001/0009}', "");
Expect(1, 8530, '\p{^Numeric_Value=00001/0009}', "");
Expect(1, 8530, '\P{Numeric_Value=00001/0009}', "");
Expect(0, 8530, '\P{^Numeric_Value=00001/0009}', "");
Error('\p{Numeric_Value=0.11}');
Error('\P{Numeric_Value=0.11}');
Expect(1, 8529, '\p{Numeric_Value=0.111}', "");
Expect(0, 8529, '\p{^Numeric_Value=0.111}', "");
Expect(0, 8529, '\P{Numeric_Value=0.111}', "");
Expect(1, 8529, '\P{^Numeric_Value=0.111}', "");
Expect(0, 8530, '\p{Numeric_Value=0.111}', "");
Expect(1, 8530, '\p{^Numeric_Value=0.111}', "");
Expect(1, 8530, '\P{Numeric_Value=0.111}', "");
Expect(0, 8530, '\P{^Numeric_Value=0.111}', "");
Error('\p{Nv=/a/__0000001/0000009}');
Error('\P{Nv=/a/__0000001/0000009}');
Expect(1, 8529, '\p{Nv=001/00000009}', "");
Expect(0, 8529, '\p{^Nv=001/00000009}', "");
Expect(0, 8529, '\P{Nv=001/00000009}', "");
Expect(1, 8529, '\P{^Nv=001/00000009}', "");
Expect(0, 8530, '\p{Nv=001/00000009}', "");
Expect(1, 8530, '\p{^Nv=001/00000009}', "");
Expect(1, 8530, '\P{Nv=001/00000009}', "");
Expect(0, 8530, '\P{^Nv=001/00000009}', "");
Error('\p{Nv:	0.11}');
Error('\P{Nv:	0.11}');
Expect(1, 8529, '\p{Nv=0.111}', "");
Expect(0, 8529, '\p{^Nv=0.111}', "");
Expect(0, 8529, '\P{Nv=0.111}', "");
Expect(1, 8529, '\P{^Nv=0.111}', "");
Expect(0, 8530, '\p{Nv=0.111}', "");
Expect(1, 8530, '\p{^Nv=0.111}', "");
Expect(1, 8530, '\P{Nv=0.111}', "");
Expect(0, 8530, '\P{^Nv=0.111}', "");
Error('\p{Is_Numeric_Value=	-+1/09/a/}');
Error('\P{Is_Numeric_Value=	-+1/09/a/}');
Expect(1, 8529, '\p{Is_Numeric_Value=00001/009}', "");
Expect(0, 8529, '\p{^Is_Numeric_Value=00001/009}', "");
Expect(0, 8529, '\P{Is_Numeric_Value=00001/009}', "");
Expect(1, 8529, '\P{^Is_Numeric_Value=00001/009}', "");
Expect(0, 8530, '\p{Is_Numeric_Value=00001/009}', "");
Expect(1, 8530, '\p{^Is_Numeric_Value=00001/009}', "");
Expect(1, 8530, '\P{Is_Numeric_Value=00001/009}', "");
Expect(0, 8530, '\P{^Is_Numeric_Value=00001/009}', "");
Error('\p{Is_Numeric_Value=0.11}');
Error('\P{Is_Numeric_Value=0.11}');
Expect(1, 8529, '\p{Is_Numeric_Value=0.111}', "");
Expect(0, 8529, '\p{^Is_Numeric_Value=0.111}', "");
Expect(0, 8529, '\P{Is_Numeric_Value=0.111}', "");
Expect(1, 8529, '\P{^Is_Numeric_Value=0.111}', "");
Expect(0, 8530, '\p{Is_Numeric_Value=0.111}', "");
Expect(1, 8530, '\p{^Is_Numeric_Value=0.111}', "");
Expect(1, 8530, '\P{Is_Numeric_Value=0.111}', "");
Expect(0, 8530, '\P{^Is_Numeric_Value=0.111}', "");
Error('\p{Is_Nv=	:=000001/9}');
Error('\P{Is_Nv=	:=000001/9}');
Expect(1, 8529, '\p{Is_Nv=+0000001/009}', "");
Expect(0, 8529, '\p{^Is_Nv=+0000001/009}', "");
Expect(0, 8529, '\P{Is_Nv=+0000001/009}', "");
Expect(1, 8529, '\P{^Is_Nv=+0000001/009}', "");
Expect(0, 8530, '\p{Is_Nv=+0000001/009}', "");
Expect(1, 8530, '\p{^Is_Nv=+0000001/009}', "");
Expect(1, 8530, '\P{Is_Nv=+0000001/009}', "");
Expect(0, 8530, '\P{^Is_Nv=+0000001/009}', "");
Error('\p{Is_Nv=0.11}');
Error('\P{Is_Nv=0.11}');
Expect(1, 8529, '\p{Is_Nv: 0.111}', "");
Expect(0, 8529, '\p{^Is_Nv: 0.111}', "");
Expect(0, 8529, '\P{Is_Nv: 0.111}', "");
Expect(1, 8529, '\P{^Is_Nv: 0.111}', "");
Expect(0, 8530, '\p{Is_Nv: 0.111}', "");
Expect(1, 8530, '\p{^Is_Nv: 0.111}', "");
Expect(1, 8530, '\P{Is_Nv: 0.111}', "");
Expect(0, 8530, '\P{^Is_Nv: 0.111}', "");
Error('\p{Numeric_Value=/a/_0_0_0_0_0_0010}');
Error('\P{Numeric_Value=/a/_0_0_0_0_0_0010}');
Expect(1, 119657, '\p{Numeric_Value=1_0}', "");
Expect(0, 119657, '\p{^Numeric_Value=1_0}', "");
Expect(0, 119657, '\P{Numeric_Value=1_0}', "");
Expect(1, 119657, '\P{^Numeric_Value=1_0}', "");
Expect(0, 119658, '\p{Numeric_Value=1_0}', "");
Expect(1, 119658, '\p{^Numeric_Value=1_0}', "");
Expect(1, 119658, '\P{Numeric_Value=1_0}', "");
Expect(0, 119658, '\P{^Numeric_Value=1_0}', "");
Error('\p{Nv=-:=01_0}');
Error('\P{Nv=-:=01_0}');
Expect(1, 119657, '\p{Nv:	000000010}', "");
Expect(0, 119657, '\p{^Nv:	000000010}', "");
Expect(0, 119657, '\P{Nv:	000000010}', "");
Expect(1, 119657, '\P{^Nv:	000000010}', "");
Expect(0, 119658, '\p{Nv:	000000010}', "");
Expect(1, 119658, '\p{^Nv:	000000010}', "");
Expect(1, 119658, '\P{Nv:	000000010}', "");
Expect(0, 119658, '\P{^Nv:	000000010}', "");
Error('\p{Is_Numeric_Value=_:=+000010}');
Error('\P{Is_Numeric_Value=_:=+000010}');
Expect(1, 119657, '\p{Is_Numeric_Value=0_0_0_0_10}', "");
Expect(0, 119657, '\p{^Is_Numeric_Value=0_0_0_0_10}', "");
Expect(0, 119657, '\P{Is_Numeric_Value=0_0_0_0_10}', "");
Expect(1, 119657, '\P{^Is_Numeric_Value=0_0_0_0_10}', "");
Expect(0, 119658, '\p{Is_Numeric_Value=0_0_0_0_10}', "");
Expect(1, 119658, '\p{^Is_Numeric_Value=0_0_0_0_10}', "");
Expect(1, 119658, '\P{Is_Numeric_Value=0_0_0_0_10}', "");
Expect(0, 119658, '\P{^Is_Numeric_Value=0_0_0_0_10}', "");
Error('\p{Is_Nv=:=	 10}');
Error('\P{Is_Nv=:=	 10}');
Expect(1, 119657, '\p{Is_Nv=010}', "");
Expect(0, 119657, '\p{^Is_Nv=010}', "");
Expect(0, 119657, '\P{Is_Nv=010}', "");
Expect(1, 119657, '\P{^Is_Nv=010}', "");
Expect(0, 119658, '\p{Is_Nv=010}', "");
Expect(1, 119658, '\p{^Is_Nv=010}', "");
Expect(1, 119658, '\P{Is_Nv=010}', "");
Expect(0, 119658, '\P{^Is_Nv=010}', "");
Error('\p{Numeric_Value: -_000000100:=}');
Error('\P{Numeric_Value: -_000000100:=}');
Expect(1, 69732, '\p{Numeric_Value=+000_010_0}', "");
Expect(0, 69732, '\p{^Numeric_Value=+000_010_0}', "");
Expect(0, 69732, '\P{Numeric_Value=+000_010_0}', "");
Expect(1, 69732, '\P{^Numeric_Value=+000_010_0}', "");
Expect(0, 69733, '\p{Numeric_Value=+000_010_0}', "");
Expect(1, 69733, '\p{^Numeric_Value=+000_010_0}', "");
Expect(1, 69733, '\P{Numeric_Value=+000_010_0}', "");
Expect(0, 69733, '\P{^Numeric_Value=+000_010_0}', "");
Error('\p{Nv=:=_00_00_00_100}');
Error('\P{Nv=:=_00_00_00_100}');
Expect(1, 69732, '\p{Nv=+0_0_1_00}', "");
Expect(0, 69732, '\p{^Nv=+0_0_1_00}', "");
Expect(0, 69732, '\P{Nv=+0_0_1_00}', "");
Expect(1, 69732, '\P{^Nv=+0_0_1_00}', "");
Expect(0, 69733, '\p{Nv=+0_0_1_00}', "");
Expect(1, 69733, '\p{^Nv=+0_0_1_00}', "");
Expect(1, 69733, '\P{Nv=+0_0_1_00}', "");
Expect(0, 69733, '\P{^Nv=+0_0_1_00}', "");
Error('\p{Is_Numeric_Value=/a/	 00_00_00_00_01_00}');
Error('\P{Is_Numeric_Value=/a/	 00_00_00_00_01_00}');
Expect(1, 69732, '\p{Is_Numeric_Value=0100}', "");
Expect(0, 69732, '\p{^Is_Numeric_Value=0100}', "");
Expect(0, 69732, '\P{Is_Numeric_Value=0100}', "");
Expect(1, 69732, '\P{^Is_Numeric_Value=0100}', "");
Expect(0, 69733, '\p{Is_Numeric_Value=0100}', "");
Expect(1, 69733, '\p{^Is_Numeric_Value=0100}', "");
Expect(1, 69733, '\P{Is_Numeric_Value=0100}', "");
Expect(0, 69733, '\P{^Is_Numeric_Value=0100}', "");
Error('\p{Is_Nv=:= -00000100}');
Error('\P{Is_Nv=:= -00000100}');
Expect(1, 69732, '\p{Is_Nv=+00_10_0}', "");
Expect(0, 69732, '\p{^Is_Nv=+00_10_0}', "");
Expect(0, 69732, '\P{Is_Nv=+00_10_0}', "");
Expect(1, 69732, '\P{^Is_Nv=+00_10_0}', "");
Expect(0, 69733, '\p{Is_Nv=+00_10_0}', "");
Expect(1, 69733, '\p{^Is_Nv=+00_10_0}', "");
Expect(1, 69733, '\P{Is_Nv=+00_10_0}', "");
Expect(0, 69733, '\P{^Is_Nv=+00_10_0}', "");
Error('\p{Numeric_Value=	/a/0_0_0_0_0_0_0_1_000}');
Error('\P{Numeric_Value=	/a/0_0_0_0_0_0_0_1_000}');
Expect(1, 69733, '\p{Numeric_Value=0001000}', "");
Expect(0, 69733, '\p{^Numeric_Value=0001000}', "");
Expect(0, 69733, '\P{Numeric_Value=0001000}', "");
Expect(1, 69733, '\P{^Numeric_Value=0001000}', "");
Expect(0, 69734, '\p{Numeric_Value=0001000}', "");
Expect(1, 69734, '\p{^Numeric_Value=0001000}', "");
Expect(1, 69734, '\P{Numeric_Value=0001000}', "");
Expect(0, 69734, '\P{^Numeric_Value=0001000}', "");
Error('\p{Nv=:=_ 000001000}');
Error('\P{Nv=:=_ 000001000}');
Expect(1, 69733, '\p{Nv=001000}', "");
Expect(0, 69733, '\p{^Nv=001000}', "");
Expect(0, 69733, '\P{Nv=001000}', "");
Expect(1, 69733, '\P{^Nv=001000}', "");
Expect(0, 69734, '\p{Nv=001000}', "");
Expect(1, 69734, '\p{^Nv=001000}', "");
Expect(1, 69734, '\P{Nv=001000}', "");
Expect(0, 69734, '\P{^Nv=001000}', "");
Error('\p{Is_Numeric_Value= /a/001000}');
Error('\P{Is_Numeric_Value= /a/001000}');
Expect(1, 69733, '\p{Is_Numeric_Value=001000}', "");
Expect(0, 69733, '\p{^Is_Numeric_Value=001000}', "");
Expect(0, 69733, '\P{Is_Numeric_Value=001000}', "");
Expect(1, 69733, '\P{^Is_Numeric_Value=001000}', "");
Expect(0, 69734, '\p{Is_Numeric_Value=001000}', "");
Expect(1, 69734, '\p{^Is_Numeric_Value=001000}', "");
Expect(1, 69734, '\P{Is_Numeric_Value=001000}', "");
Expect(0, 69734, '\P{^Is_Numeric_Value=001000}', "");
Error('\p{Is_Nv=:= +0001000}');
Error('\P{Is_Nv=:= +0001000}');
Expect(1, 69733, '\p{Is_Nv=+00000001000}', "");
Expect(0, 69733, '\p{^Is_Nv=+00000001000}', "");
Expect(0, 69733, '\P{Is_Nv=+00000001000}', "");
Expect(1, 69733, '\P{^Is_Nv=+00000001000}', "");
Expect(0, 69734, '\p{Is_Nv=+00000001000}', "");
Expect(1, 69734, '\p{^Is_Nv=+00000001000}', "");
Expect(1, 69734, '\P{Is_Nv=+00000001000}', "");
Expect(0, 69734, '\P{^Is_Nv=+00000001000}', "");
Error('\p{Numeric_Value= :=+010000}');
Error('\P{Numeric_Value= :=+010000}');
Expect(1, 67679, '\p{Numeric_Value:   0_0_0_1_0_000}', "");
Expect(0, 67679, '\p{^Numeric_Value:   0_0_0_1_0_000}', "");
Expect(0, 67679, '\P{Numeric_Value:   0_0_0_1_0_000}', "");
Expect(1, 67679, '\P{^Numeric_Value:   0_0_0_1_0_000}', "");
Expect(0, 67680, '\p{Numeric_Value:   0_0_0_1_0_000}', "");
Expect(1, 67680, '\p{^Numeric_Value:   0_0_0_1_0_000}', "");
Expect(1, 67680, '\P{Numeric_Value:   0_0_0_1_0_000}', "");
Expect(0, 67680, '\P{^Numeric_Value:   0_0_0_1_0_000}', "");
Error('\p{Nv:	 0000001000_0/a/}');
Error('\P{Nv:	 0000001000_0/a/}');
Expect(1, 67679, '\p{Nv=00000010000}', "");
Expect(0, 67679, '\p{^Nv=00000010000}', "");
Expect(0, 67679, '\P{Nv=00000010000}', "");
Expect(1, 67679, '\P{^Nv=00000010000}', "");
Expect(0, 67680, '\p{Nv=00000010000}', "");
Expect(1, 67680, '\p{^Nv=00000010000}', "");
Expect(1, 67680, '\P{Nv=00000010000}', "");
Expect(0, 67680, '\P{^Nv=00000010000}', "");
Error('\p{Is_Numeric_Value= 0010000/a/}');
Error('\P{Is_Numeric_Value= 0010000/a/}');
Expect(1, 67679, '\p{Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(0, 67679, '\p{^Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(0, 67679, '\P{Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(1, 67679, '\P{^Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(0, 67680, '\p{Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(1, 67680, '\p{^Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(1, 67680, '\P{Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Expect(0, 67680, '\P{^Is_Numeric_Value=+0_0_0_0_0_1_0_000}', "");
Error('\p{Is_Nv=-+0_1_0_000:=}');
Error('\P{Is_Nv=-+0_1_0_000:=}');
Expect(1, 67679, '\p{Is_Nv:   +0000010000}', "");
Expect(0, 67679, '\p{^Is_Nv:   +0000010000}', "");
Expect(0, 67679, '\P{Is_Nv:   +0000010000}', "");
Expect(1, 67679, '\P{^Is_Nv:   +0000010000}', "");
Expect(0, 67680, '\p{Is_Nv:   +0000010000}', "");
Expect(1, 67680, '\p{^Is_Nv:   +0000010000}', "");
Expect(1, 67680, '\P{Is_Nv:   +0000010000}', "");
Expect(0, 67680, '\P{^Is_Nv:   +0000010000}', "");
Error('\p{Numeric_Value=:=__0000_0000_0100_000}');
Error('\P{Numeric_Value=:=__0000_0000_0100_000}');
Expect(1, 8584, '\p{Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(0, 8584, '\p{^Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(0, 8584, '\P{Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(1, 8584, '\P{^Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(0, 8585, '\p{Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(1, 8585, '\p{^Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(1, 8585, '\P{Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Expect(0, 8585, '\P{^Numeric_Value:	0_0_0_0_0_0_0_0_0100000}', "");
Error('\p{Nv= 0_0_0_0_0_0_1_0_0_0_00/a/}');
Error('\P{Nv= 0_0_0_0_0_0_1_0_0_0_00/a/}');
Expect(1, 8584, '\p{Nv=0000000100000}', "");
Expect(0, 8584, '\p{^Nv=0000000100000}', "");
Expect(0, 8584, '\P{Nv=0000000100000}', "");
Expect(1, 8584, '\P{^Nv=0000000100000}', "");
Expect(0, 8585, '\p{Nv=0000000100000}', "");
Expect(1, 8585, '\p{^Nv=0000000100000}', "");
Expect(1, 8585, '\P{Nv=0000000100000}', "");
Expect(0, 8585, '\P{^Nv=0000000100000}', "");
Error('\p{Is_Numeric_Value:   :=+00_00_00_00_01_00_00_0}');
Error('\P{Is_Numeric_Value:   :=+00_00_00_00_01_00_00_0}');
Expect(1, 8584, '\p{Is_Numeric_Value=00000_01000_00}', "");
Expect(0, 8584, '\p{^Is_Numeric_Value=00000_01000_00}', "");
Expect(0, 8584, '\P{Is_Numeric_Value=00000_01000_00}', "");
Expect(1, 8584, '\P{^Is_Numeric_Value=00000_01000_00}', "");
Expect(0, 8585, '\p{Is_Numeric_Value=00000_01000_00}', "");
Expect(1, 8585, '\p{^Is_Numeric_Value=00000_01000_00}', "");
Expect(1, 8585, '\P{Is_Numeric_Value=00000_01000_00}', "");
Expect(0, 8585, '\P{^Is_Numeric_Value=00000_01000_00}', "");
Error('\p{Is_Nv=/a/00000100000}');
Error('\P{Is_Nv=/a/00000100000}');
Expect(1, 8584, '\p{Is_Nv=00_00_01_00_000}', "");
Expect(0, 8584, '\p{^Is_Nv=00_00_01_00_000}', "");
Expect(0, 8584, '\P{Is_Nv=00_00_01_00_000}', "");
Expect(1, 8584, '\P{^Is_Nv=00_00_01_00_000}', "");
Expect(0, 8585, '\p{Is_Nv=00_00_01_00_000}', "");
Expect(1, 8585, '\p{^Is_Nv=00_00_01_00_000}', "");
Expect(1, 8585, '\P{Is_Nv=00_00_01_00_000}', "");
Expect(0, 8585, '\P{^Is_Nv=00_00_01_00_000}', "");
Error('\p{Numeric_Value:/a/000100000000}');
Error('\P{Numeric_Value:/a/000100000000}');
Expect(1, 20740, '\p{Numeric_Value=00100_00000_0}', "");
Expect(0, 20740, '\p{^Numeric_Value=00100_00000_0}', "");
Expect(0, 20740, '\P{Numeric_Value=00100_00000_0}', "");
Expect(1, 20740, '\P{^Numeric_Value=00100_00000_0}', "");
Expect(0, 20741, '\p{Numeric_Value=00100_00000_0}', "");
Expect(1, 20741, '\p{^Numeric_Value=00100_00000_0}', "");
Expect(1, 20741, '\P{Numeric_Value=00100_00000_0}', "");
Expect(0, 20741, '\P{^Numeric_Value=00100_00000_0}', "");
Error('\p{Nv= -0000000010000000_0/a/}');
Error('\P{Nv= -0000000010000000_0/a/}');
Expect(1, 20740, '\p{Nv=+0_1_0_0_0_0_0000}', "");
Expect(0, 20740, '\p{^Nv=+0_1_0_0_0_0_0000}', "");
Expect(0, 20740, '\P{Nv=+0_1_0_0_0_0_0000}', "");
Expect(1, 20740, '\P{^Nv=+0_1_0_0_0_0_0000}', "");
Expect(0, 20741, '\p{Nv=+0_1_0_0_0_0_0000}', "");
Expect(1, 20741, '\p{^Nv=+0_1_0_0_0_0_0000}', "");
Expect(1, 20741, '\P{Nv=+0_1_0_0_0_0_0000}', "");
Expect(0, 20741, '\P{^Nv=+0_1_0_0_0_0_0000}', "");
Error('\p{Is_Numeric_Value=-:=000000100000000}');
Error('\P{Is_Numeric_Value=-:=000000100000000}');
Expect(1, 20740, '\p{Is_Numeric_Value=000000000100000000}', "");
Expect(0, 20740, '\p{^Is_Numeric_Value=000000000100000000}', "");
Expect(0, 20740, '\P{Is_Numeric_Value=000000000100000000}', "");
Expect(1, 20740, '\P{^Is_Numeric_Value=000000000100000000}', "");
Expect(0, 20741, '\p{Is_Numeric_Value=000000000100000000}', "");
Expect(1, 20741, '\p{^Is_Numeric_Value=000000000100000000}', "");
Expect(1, 20741, '\P{Is_Numeric_Value=000000000100000000}', "");
Expect(0, 20741, '\P{^Is_Numeric_Value=000000000100000000}', "");
Error('\p{Is_Nv=  +0000000100000000:=}');
Error('\P{Is_Nv=  +0000000100000000:=}');
Expect(1, 20740, '\p{Is_Nv=0000100000000}', "");
Expect(0, 20740, '\p{^Is_Nv=0000100000000}', "");
Expect(0, 20740, '\P{Is_Nv=0000100000000}', "");
Expect(1, 20740, '\P{^Is_Nv=0000100000000}', "");
Expect(0, 20741, '\p{Is_Nv=0000100000000}', "");
Expect(1, 20741, '\p{^Is_Nv=0000100000000}', "");
Expect(1, 20741, '\P{Is_Nv=0000100000000}', "");
Expect(0, 20741, '\P{^Is_Nv=0000100000000}', "");
Error('\p{Numeric_Value=_/a/000000001000000000000}');
Error('\P{Numeric_Value=_/a/000000001000000000000}');
Expect(1, 20806, '\p{Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(0, 20806, '\p{^Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(0, 20806, '\P{Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(1, 20806, '\P{^Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(0, 20807, '\p{Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(1, 20807, '\p{^Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(1, 20807, '\P{Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Expect(0, 20807, '\P{^Numeric_Value=+1_0_0_0_0_0_0_0_00000}', "");
Error('\p{Nv=	000000100000000000_0/a/}');
Error('\P{Nv=	000000100000000000_0/a/}');
Expect(1, 20806, '\p{Nv=000000_010000_000000_00}', "");
Expect(0, 20806, '\p{^Nv=000000_010000_000000_00}', "");
Expect(0, 20806, '\P{Nv=000000_010000_000000_00}', "");
Expect(1, 20806, '\P{^Nv=000000_010000_000000_00}', "");
Expect(0, 20807, '\p{Nv=000000_010000_000000_00}', "");
Expect(1, 20807, '\p{^Nv=000000_010000_000000_00}', "");
Expect(1, 20807, '\P{Nv=000000_010000_000000_00}', "");
Expect(0, 20807, '\P{^Nv=000000_010000_000000_00}', "");
Error('\p{Is_Numeric_Value=-_0_1_0_0_0_0_0_0_0_0_0_000:=}');
Error('\P{Is_Numeric_Value=-_0_1_0_0_0_0_0_0_0_0_0_000:=}');
Expect(1, 20806, '\p{Is_Numeric_Value=000001000000000000}', "");
Expect(0, 20806, '\p{^Is_Numeric_Value=000001000000000000}', "");
Expect(0, 20806, '\P{Is_Numeric_Value=000001000000000000}', "");
Expect(1, 20806, '\P{^Is_Numeric_Value=000001000000000000}', "");
Expect(0, 20807, '\p{Is_Numeric_Value=000001000000000000}', "");
Expect(1, 20807, '\p{^Is_Numeric_Value=000001000000000000}', "");
Expect(1, 20807, '\P{Is_Numeric_Value=000001000000000000}', "");
Expect(0, 20807, '\P{^Is_Numeric_Value=000001000000000000}', "");
Error('\p{Is_Nv=:=_ 0000001000000000000}');
Error('\P{Is_Nv=:=_ 0000001000000000000}');
Expect(1, 20806, '\p{Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(0, 20806, '\p{^Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(0, 20806, '\P{Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(1, 20806, '\P{^Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(0, 20807, '\p{Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(1, 20807, '\p{^Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(1, 20807, '\P{Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Expect(0, 20807, '\P{^Is_Nv: +0_0_0_0_0_0_0_1_0_0_0_0_0_0_0_0_0000}', "");
Error('\p{Numeric_Value:	_/a/+00000000011}');
Error('\P{Numeric_Value:	_/a/+00000000011}');
Expect(1, 9451, '\p{Numeric_Value:   +000000011}', "");
Expect(0, 9451, '\p{^Numeric_Value:   +000000011}', "");
Expect(0, 9451, '\P{Numeric_Value:   +000000011}', "");
Expect(1, 9451, '\P{^Numeric_Value:   +000000011}', "");
Expect(0, 9452, '\p{Numeric_Value:   +000000011}', "");
Expect(1, 9452, '\p{^Numeric_Value:   +000000011}', "");
Expect(1, 9452, '\P{Numeric_Value:   +000000011}', "");
Expect(0, 9452, '\P{^Numeric_Value:   +000000011}', "");
Error('\p{Nv=- 001_1/a/}');
Error('\P{Nv=- 001_1/a/}');
Expect(1, 9451, '\p{Nv=+0_0_0_0_011}', "");
Expect(0, 9451, '\p{^Nv=+0_0_0_0_011}', "");
Expect(0, 9451, '\P{Nv=+0_0_0_0_011}', "");
Expect(1, 9451, '\P{^Nv=+0_0_0_0_011}', "");
Expect(0, 9452, '\p{Nv=+0_0_0_0_011}', "");
Expect(1, 9452, '\p{^Nv=+0_0_0_0_011}', "");
Expect(1, 9452, '\P{Nv=+0_0_0_0_011}', "");
Expect(0, 9452, '\P{^Nv=+0_0_0_0_011}', "");
Error('\p{Is_Numeric_Value= 0_0_0_0_0_011/a/}');
Error('\P{Is_Numeric_Value= 0_0_0_0_0_011/a/}');
Expect(1, 9451, '\p{Is_Numeric_Value=0000011}', "");
Expect(0, 9451, '\p{^Is_Numeric_Value=0000011}', "");
Expect(0, 9451, '\P{Is_Numeric_Value=0000011}', "");
Expect(1, 9451, '\P{^Is_Numeric_Value=0000011}', "");
Expect(0, 9452, '\p{Is_Numeric_Value=0000011}', "");
Expect(1, 9452, '\p{^Is_Numeric_Value=0000011}', "");
Expect(1, 9452, '\P{Is_Numeric_Value=0000011}', "");
Expect(0, 9452, '\P{^Is_Numeric_Value=0000011}', "");
Error('\p{Is_Nv=/a/-_+0_0_0_0_11}');
Error('\P{Is_Nv=/a/-_+0_0_0_0_11}');
Expect(1, 9451, '\p{Is_Nv: +0000011}', "");
Expect(0, 9451, '\p{^Is_Nv: +0000011}', "");
Expect(0, 9451, '\P{Is_Nv: +0000011}', "");
Expect(1, 9451, '\P{^Is_Nv: +0000011}', "");
Expect(0, 9452, '\p{Is_Nv: +0000011}', "");
Expect(1, 9452, '\p{^Is_Nv: +0000011}', "");
Expect(1, 9452, '\P{Is_Nv: +0000011}', "");
Expect(0, 9452, '\P{^Is_Nv: +0000011}', "");
Error('\p{Numeric_Value=/a/		011/0002}');
Error('\P{Numeric_Value=/a/		011/0002}');
Expect(1, 3887, '\p{Numeric_Value=+011/00002}', "");
Expect(0, 3887, '\p{^Numeric_Value=+011/00002}', "");
Expect(0, 3887, '\P{Numeric_Value=+011/00002}', "");
Expect(1, 3887, '\P{^Numeric_Value=+011/00002}', "");
Expect(0, 3888, '\p{Numeric_Value=+011/00002}', "");
Expect(1, 3888, '\p{^Numeric_Value=+011/00002}', "");
Expect(1, 3888, '\P{Numeric_Value=+011/00002}', "");
Expect(0, 3888, '\P{^Numeric_Value=+011/00002}', "");
Expect(1, 3887, '\p{Numeric_Value=5.500}', "");
Expect(0, 3887, '\p{^Numeric_Value=5.500}', "");
Expect(0, 3887, '\P{Numeric_Value=5.500}', "");
Expect(1, 3887, '\P{^Numeric_Value=5.500}', "");
Expect(0, 3888, '\p{Numeric_Value=5.500}', "");
Expect(1, 3888, '\p{^Numeric_Value=5.500}', "");
Expect(1, 3888, '\P{Numeric_Value=5.500}', "");
Expect(0, 3888, '\P{^Numeric_Value=5.500}', "");
Error('\p{Nv=:=000000011/00000002}');
Error('\P{Nv=:=000000011/00000002}');
Expect(1, 3887, '\p{Nv=00011/000000002}', "");
Expect(0, 3887, '\p{^Nv=00011/000000002}', "");
Expect(0, 3887, '\P{Nv=00011/000000002}', "");
Expect(1, 3887, '\P{^Nv=00011/000000002}', "");
Expect(0, 3888, '\p{Nv=00011/000000002}', "");
Expect(1, 3888, '\p{^Nv=00011/000000002}', "");
Expect(1, 3888, '\P{Nv=00011/000000002}', "");
Expect(0, 3888, '\P{^Nv=00011/000000002}', "");
Expect(1, 3887, '\p{Nv=5.500}', "");
Expect(0, 3887, '\p{^Nv=5.500}', "");
Expect(0, 3887, '\P{Nv=5.500}', "");
Expect(1, 3887, '\P{^Nv=5.500}', "");
Expect(0, 3888, '\p{Nv=5.500}', "");
Expect(1, 3888, '\p{^Nv=5.500}', "");
Expect(1, 3888, '\P{Nv=5.500}', "");
Expect(0, 3888, '\P{^Nv=5.500}', "");
Error('\p{Is_Numeric_Value=--000011/000000002:=}');
Error('\P{Is_Numeric_Value=--000011/000000002:=}');
Expect(1, 3887, '\p{Is_Numeric_Value=11/000002}', "");
Expect(0, 3887, '\p{^Is_Numeric_Value=11/000002}', "");
Expect(0, 3887, '\P{Is_Numeric_Value=11/000002}', "");
Expect(1, 3887, '\P{^Is_Numeric_Value=11/000002}', "");
Expect(0, 3888, '\p{Is_Numeric_Value=11/000002}', "");
Expect(1, 3888, '\p{^Is_Numeric_Value=11/000002}', "");
Expect(1, 3888, '\P{Is_Numeric_Value=11/000002}', "");
Expect(0, 3888, '\P{^Is_Numeric_Value=11/000002}', "");
Expect(1, 3887, '\p{Is_Numeric_Value=5.500}', "");
Expect(0, 3887, '\p{^Is_Numeric_Value=5.500}', "");
Expect(0, 3887, '\P{Is_Numeric_Value=5.500}', "");
Expect(1, 3887, '\P{^Is_Numeric_Value=5.500}', "");
Expect(0, 3888, '\p{Is_Numeric_Value=5.500}', "");
Expect(1, 3888, '\p{^Is_Numeric_Value=5.500}', "");
Expect(1, 3888, '\P{Is_Numeric_Value=5.500}', "");
Expect(0, 3888, '\P{^Is_Numeric_Value=5.500}', "");
Error('\p{Is_Nv=/a/+0000000011/02}');
Error('\P{Is_Nv=/a/+0000000011/02}');
Expect(1, 3887, '\p{Is_Nv=0011/2}', "");
Expect(0, 3887, '\p{^Is_Nv=0011/2}', "");
Expect(0, 3887, '\P{Is_Nv=0011/2}', "");
Expect(1, 3887, '\P{^Is_Nv=0011/2}', "");
Expect(0, 3888, '\p{Is_Nv=0011/2}', "");
Expect(1, 3888, '\p{^Is_Nv=0011/2}', "");
Expect(1, 3888, '\P{Is_Nv=0011/2}', "");
Expect(0, 3888, '\P{^Is_Nv=0011/2}', "");
Expect(1, 3887, '\p{Is_Nv=5.500}', "");
Expect(0, 3887, '\p{^Is_Nv=5.500}', "");
Expect(0, 3887, '\P{Is_Nv=5.500}', "");
Expect(1, 3887, '\P{^Is_Nv=5.500}', "");
Expect(0, 3888, '\p{Is_Nv=5.500}', "");
Expect(1, 3888, '\p{^Is_Nv=5.500}', "");
Expect(1, 3888, '\P{Is_Nv=5.500}', "");
Expect(0, 3888, '\P{^Is_Nv=5.500}', "");
Error('\p{Numeric_Value=/a/0000000012}');
Error('\P{Numeric_Value=/a/0000000012}');
Expect(1, 9452, '\p{Numeric_Value=+1_2}', "");
Expect(0, 9452, '\p{^Numeric_Value=+1_2}', "");
Expect(0, 9452, '\P{Numeric_Value=+1_2}', "");
Expect(1, 9452, '\P{^Numeric_Value=+1_2}', "");
Expect(0, 9453, '\p{Numeric_Value=+1_2}', "");
Expect(1, 9453, '\p{^Numeric_Value=+1_2}', "");
Expect(1, 9453, '\P{Numeric_Value=+1_2}', "");
Expect(0, 9453, '\P{^Numeric_Value=+1_2}', "");
Error('\p{Nv= :=0_0_0_0_0_0_12}');
Error('\P{Nv= :=0_0_0_0_0_0_12}');
Expect(1, 9452, '\p{Nv=00_00_00_012}', "");
Expect(0, 9452, '\p{^Nv=00_00_00_012}', "");
Expect(0, 9452, '\P{Nv=00_00_00_012}', "");
Expect(1, 9452, '\P{^Nv=00_00_00_012}', "");
Expect(0, 9453, '\p{Nv=00_00_00_012}', "");
Expect(1, 9453, '\p{^Nv=00_00_00_012}', "");
Expect(1, 9453, '\P{Nv=00_00_00_012}', "");
Expect(0, 9453, '\P{^Nv=00_00_00_012}', "");
Error('\p{Is_Numeric_Value=:=0_0_0_12}');
Error('\P{Is_Numeric_Value=:=0_0_0_12}');
Expect(1, 9452, '\p{Is_Numeric_Value=0000000012}', "");
Expect(0, 9452, '\p{^Is_Numeric_Value=0000000012}', "");
Expect(0, 9452, '\P{Is_Numeric_Value=0000000012}', "");
Expect(1, 9452, '\P{^Is_Numeric_Value=0000000012}', "");
Expect(0, 9453, '\p{Is_Numeric_Value=0000000012}', "");
Expect(1, 9453, '\p{^Is_Numeric_Value=0000000012}', "");
Expect(1, 9453, '\P{Is_Numeric_Value=0000000012}', "");
Expect(0, 9453, '\P{^Is_Numeric_Value=0000000012}', "");
Error('\p{Is_Nv=	_0012/a/}');
Error('\P{Is_Nv=	_0012/a/}');
Expect(1, 9452, '\p{Is_Nv=00012}', "");
Expect(0, 9452, '\p{^Is_Nv=00012}', "");
Expect(0, 9452, '\P{Is_Nv=00012}', "");
Expect(1, 9452, '\P{^Is_Nv=00012}', "");
Expect(0, 9453, '\p{Is_Nv=00012}', "");
Expect(1, 9453, '\p{^Is_Nv=00012}', "");
Expect(1, 9453, '\P{Is_Nv=00012}', "");
Expect(0, 9453, '\P{^Is_Nv=00012}', "");
Error('\p{Numeric_Value=-	00000013:=}');
Error('\P{Numeric_Value=-	00000013:=}');
Expect(1, 9453, '\p{Numeric_Value=01_3}', "");
Expect(0, 9453, '\p{^Numeric_Value=01_3}', "");
Expect(0, 9453, '\P{Numeric_Value=01_3}', "");
Expect(1, 9453, '\P{^Numeric_Value=01_3}', "");
Expect(0, 9454, '\p{Numeric_Value=01_3}', "");
Expect(1, 9454, '\p{^Numeric_Value=01_3}', "");
Expect(1, 9454, '\P{Numeric_Value=01_3}', "");
Expect(0, 9454, '\P{^Numeric_Value=01_3}', "");
Error('\p{Nv=/a/	00013}');
Error('\P{Nv=/a/	00013}');
Expect(1, 9453, '\p{Nv=000013}', "");
Expect(0, 9453, '\p{^Nv=000013}', "");
Expect(0, 9453, '\P{Nv=000013}', "");
Expect(1, 9453, '\P{^Nv=000013}', "");
Expect(0, 9454, '\p{Nv=000013}', "");
Expect(1, 9454, '\p{^Nv=000013}', "");
Expect(1, 9454, '\P{Nv=000013}', "");
Expect(0, 9454, '\P{^Nv=000013}', "");
Error('\p{Is_Numeric_Value::=+00013}');
Error('\P{Is_Numeric_Value::=+00013}');
Expect(1, 9453, '\p{Is_Numeric_Value=1_3}', "");
Expect(0, 9453, '\p{^Is_Numeric_Value=1_3}', "");
Expect(0, 9453, '\P{Is_Numeric_Value=1_3}', "");
Expect(1, 9453, '\P{^Is_Numeric_Value=1_3}', "");
Expect(0, 9454, '\p{Is_Numeric_Value=1_3}', "");
Expect(1, 9454, '\p{^Is_Numeric_Value=1_3}', "");
Expect(1, 9454, '\P{Is_Numeric_Value=1_3}', "");
Expect(0, 9454, '\P{^Is_Numeric_Value=1_3}', "");
Error('\p{Is_Nv=13/a/}');
Error('\P{Is_Nv=13/a/}');
Expect(1, 9453, '\p{Is_Nv: +01_3}', "");
Expect(0, 9453, '\p{^Is_Nv: +01_3}', "");
Expect(0, 9453, '\P{Is_Nv: +01_3}', "");
Expect(1, 9453, '\P{^Is_Nv: +01_3}', "");
Expect(0, 9454, '\p{Is_Nv: +01_3}', "");
Expect(1, 9454, '\p{^Is_Nv: +01_3}', "");
Expect(1, 9454, '\P{Is_Nv: +01_3}', "");
Expect(0, 9454, '\P{^Is_Nv: +01_3}', "");
Error('\p{Numeric_Value= /a/+0013/00002}');
Error('\P{Numeric_Value= /a/+0013/00002}');
Expect(1, 3888, '\p{Numeric_Value=000000013/00000002}', "");
Expect(0, 3888, '\p{^Numeric_Value=000000013/00000002}', "");
Expect(0, 3888, '\P{Numeric_Value=000000013/00000002}', "");
Expect(1, 3888, '\P{^Numeric_Value=000000013/00000002}', "");
Expect(0, 3889, '\p{Numeric_Value=000000013/00000002}', "");
Expect(1, 3889, '\p{^Numeric_Value=000000013/00000002}', "");
Expect(1, 3889, '\P{Numeric_Value=000000013/00000002}', "");
Expect(0, 3889, '\P{^Numeric_Value=000000013/00000002}', "");
Expect(1, 3888, '\p{Numeric_Value=6.500}', "");
Expect(0, 3888, '\p{^Numeric_Value=6.500}', "");
Expect(0, 3888, '\P{Numeric_Value=6.500}', "");
Expect(1, 3888, '\P{^Numeric_Value=6.500}', "");
Expect(0, 3889, '\p{Numeric_Value=6.500}', "");
Expect(1, 3889, '\p{^Numeric_Value=6.500}', "");
Expect(1, 3889, '\P{Numeric_Value=6.500}', "");
Expect(0, 3889, '\P{^Numeric_Value=6.500}', "");
Error('\p{Nv=_ +00000013/02/a/}');
Error('\P{Nv=_ +00000013/02/a/}');
Expect(1, 3888, '\p{Nv=00013/2}', "");
Expect(0, 3888, '\p{^Nv=00013/2}', "");
Expect(0, 3888, '\P{Nv=00013/2}', "");
Expect(1, 3888, '\P{^Nv=00013/2}', "");
Expect(0, 3889, '\p{Nv=00013/2}', "");
Expect(1, 3889, '\p{^Nv=00013/2}', "");
Expect(1, 3889, '\P{Nv=00013/2}', "");
Expect(0, 3889, '\P{^Nv=00013/2}', "");
Expect(1, 3888, '\p{Nv=6.500}', "");
Expect(0, 3888, '\p{^Nv=6.500}', "");
Expect(0, 3888, '\P{Nv=6.500}', "");
Expect(1, 3888, '\P{^Nv=6.500}', "");
Expect(0, 3889, '\p{Nv=6.500}', "");
Expect(1, 3889, '\p{^Nv=6.500}', "");
Expect(1, 3889, '\P{Nv=6.500}', "");
Expect(0, 3889, '\P{^Nv=6.500}', "");
Error('\p{Is_Numeric_Value=_:=0000013/2}');
Error('\P{Is_Numeric_Value=_:=0000013/2}');
Expect(1, 3888, '\p{Is_Numeric_Value=13/0000002}', "");
Expect(0, 3888, '\p{^Is_Numeric_Value=13/0000002}', "");
Expect(0, 3888, '\P{Is_Numeric_Value=13/0000002}', "");
Expect(1, 3888, '\P{^Is_Numeric_Value=13/0000002}', "");
Expect(0, 3889, '\p{Is_Numeric_Value=13/0000002}', "");
Expect(1, 3889, '\p{^Is_Numeric_Value=13/0000002}', "");
Expect(1, 3889, '\P{Is_Numeric_Value=13/0000002}', "");
Expect(0, 3889, '\P{^Is_Numeric_Value=13/0000002}', "");
Expect(1, 3888, '\p{Is_Numeric_Value=6.500}', "");
Expect(0, 3888, '\p{^Is_Numeric_Value=6.500}', "");
Expect(0, 3888, '\P{Is_Numeric_Value=6.500}', "");
Expect(1, 3888, '\P{^Is_Numeric_Value=6.500}', "");
Expect(0, 3889, '\p{Is_Numeric_Value=6.500}', "");
Expect(1, 3889, '\p{^Is_Numeric_Value=6.500}', "");
Expect(1, 3889, '\P{Is_Numeric_Value=6.500}', "");
Expect(0, 3889, '\P{^Is_Numeric_Value=6.500}', "");
Error('\p{Is_Nv= :=000000013/02}');
Error('\P{Is_Nv= :=000000013/02}');
Expect(1, 3888, '\p{Is_Nv: 00000000013/02}', "");
Expect(0, 3888, '\p{^Is_Nv: 00000000013/02}', "");
Expect(0, 3888, '\P{Is_Nv: 00000000013/02}', "");
Expect(1, 3888, '\P{^Is_Nv: 00000000013/02}', "");
Expect(0, 3889, '\p{Is_Nv: 00000000013/02}', "");
Expect(1, 3889, '\p{^Is_Nv: 00000000013/02}', "");
Expect(1, 3889, '\P{Is_Nv: 00000000013/02}', "");
Expect(0, 3889, '\P{^Is_Nv: 00000000013/02}', "");
Expect(1, 3888, '\p{Is_Nv=6.500}', "");
Expect(0, 3888, '\p{^Is_Nv=6.500}', "");
Expect(0, 3888, '\P{Is_Nv=6.500}', "");
Expect(1, 3888, '\P{^Is_Nv=6.500}', "");
Expect(0, 3889, '\p{Is_Nv=6.500}', "");
Expect(1, 3889, '\p{^Is_Nv=6.500}', "");
Expect(1, 3889, '\P{Is_Nv=6.500}', "");
Expect(0, 3889, '\P{^Is_Nv=6.500}', "");
Error('\p{Numeric_Value=:=	-00000_00001_4}');
Error('\P{Numeric_Value=:=	-00000_00001_4}');
Expect(1, 9454, '\p{Numeric_Value=+00000014}', "");
Expect(0, 9454, '\p{^Numeric_Value=+00000014}', "");
Expect(0, 9454, '\P{Numeric_Value=+00000014}', "");
Expect(1, 9454, '\P{^Numeric_Value=+00000014}', "");
Expect(0, 9455, '\p{Numeric_Value=+00000014}', "");
Expect(1, 9455, '\p{^Numeric_Value=+00000014}', "");
Expect(1, 9455, '\P{Numeric_Value=+00000014}', "");
Expect(0, 9455, '\P{^Numeric_Value=+00000014}', "");
Error('\p{Nv=	/a/00000000014}');
Error('\P{Nv=	/a/00000000014}');
Expect(1, 9454, '\p{Nv=00000000014}', "");
Expect(0, 9454, '\p{^Nv=00000000014}', "");
Expect(0, 9454, '\P{Nv=00000000014}', "");
Expect(1, 9454, '\P{^Nv=00000000014}', "");
Expect(0, 9455, '\p{Nv=00000000014}', "");
Expect(1, 9455, '\p{^Nv=00000000014}', "");
Expect(1, 9455, '\P{Nv=00000000014}', "");
Expect(0, 9455, '\P{^Nv=00000000014}', "");
Error('\p{Is_Numeric_Value= 	+0_0_0_0_14:=}');
Error('\P{Is_Numeric_Value= 	+0_0_0_0_14:=}');
Expect(1, 9454, '\p{Is_Numeric_Value: 0000000014}', "");
Expect(0, 9454, '\p{^Is_Numeric_Value: 0000000014}', "");
Expect(0, 9454, '\P{Is_Numeric_Value: 0000000014}', "");
Expect(1, 9454, '\P{^Is_Numeric_Value: 0000000014}', "");
Expect(0, 9455, '\p{Is_Numeric_Value: 0000000014}', "");
Expect(1, 9455, '\p{^Is_Numeric_Value: 0000000014}', "");
Expect(1, 9455, '\P{Is_Numeric_Value: 0000000014}', "");
Expect(0, 9455, '\P{^Is_Numeric_Value: 0000000014}', "");
Error('\p{Is_Nv=:=_ 0000000014}');
Error('\P{Is_Nv=:=_ 0000000014}');
Expect(1, 9454, '\p{Is_Nv=014}', "");
Expect(0, 9454, '\p{^Is_Nv=014}', "");
Expect(0, 9454, '\P{Is_Nv=014}', "");
Expect(1, 9454, '\P{^Is_Nv=014}', "");
Expect(0, 9455, '\p{Is_Nv=014}', "");
Expect(1, 9455, '\p{^Is_Nv=014}', "");
Expect(1, 9455, '\P{Is_Nv=014}', "");
Expect(0, 9455, '\P{^Is_Nv=014}', "");
Error('\p{Numeric_Value=:=0_0_15}');
Error('\P{Numeric_Value=:=0_0_15}');
Expect(1, 9455, '\p{Numeric_Value=0001_5}', "");
Expect(0, 9455, '\p{^Numeric_Value=0001_5}', "");
Expect(0, 9455, '\P{Numeric_Value=0001_5}', "");
Expect(1, 9455, '\P{^Numeric_Value=0001_5}', "");
Expect(0, 9456, '\p{Numeric_Value=0001_5}', "");
Expect(1, 9456, '\p{^Numeric_Value=0001_5}', "");
Expect(1, 9456, '\P{Numeric_Value=0001_5}', "");
Expect(0, 9456, '\P{^Numeric_Value=0001_5}', "");
Error('\p{Nv=-:=0_0_15}');
Error('\P{Nv=-:=0_0_15}');
Expect(1, 9455, '\p{Nv=0015}', "");
Expect(0, 9455, '\p{^Nv=0015}', "");
Expect(0, 9455, '\P{Nv=0015}', "");
Expect(1, 9455, '\P{^Nv=0015}', "");
Expect(0, 9456, '\p{Nv=0015}', "");
Expect(1, 9456, '\p{^Nv=0015}', "");
Expect(1, 9456, '\P{Nv=0015}', "");
Expect(0, 9456, '\P{^Nv=0015}', "");
Error('\p{Is_Numeric_Value=	-+000_000_15:=}');
Error('\P{Is_Numeric_Value=	-+000_000_15:=}');
Expect(1, 9455, '\p{Is_Numeric_Value=+000_000_000_15}', "");
Expect(0, 9455, '\p{^Is_Numeric_Value=+000_000_000_15}', "");
Expect(0, 9455, '\P{Is_Numeric_Value=+000_000_000_15}', "");
Expect(1, 9455, '\P{^Is_Numeric_Value=+000_000_000_15}', "");
Expect(0, 9456, '\p{Is_Numeric_Value=+000_000_000_15}', "");
Expect(1, 9456, '\p{^Is_Numeric_Value=+000_000_000_15}', "");
Expect(1, 9456, '\P{Is_Numeric_Value=+000_000_000_15}', "");
Expect(0, 9456, '\P{^Is_Numeric_Value=+000_000_000_15}', "");
Error('\p{Is_Nv= :=00015}');
Error('\P{Is_Nv= :=00015}');
Expect(1, 9455, '\p{Is_Nv=+00000_00001_5}', "");
Expect(0, 9455, '\p{^Is_Nv=+00000_00001_5}', "");
Expect(0, 9455, '\P{Is_Nv=+00000_00001_5}', "");
Expect(1, 9455, '\P{^Is_Nv=+00000_00001_5}', "");
Expect(0, 9456, '\p{Is_Nv=+00000_00001_5}', "");
Expect(1, 9456, '\p{^Is_Nv=+00000_00001_5}', "");
Expect(1, 9456, '\P{Is_Nv=+00000_00001_5}', "");
Expect(0, 9456, '\P{^Is_Nv=+00000_00001_5}', "");
Error('\p{Numeric_Value=/a/	 000000015/00000002}');
Error('\P{Numeric_Value=/a/	 000000015/00000002}');
Expect(1, 3889, '\p{Numeric_Value=00015/000000002}', "");
Expect(0, 3889, '\p{^Numeric_Value=00015/000000002}', "");
Expect(0, 3889, '\P{Numeric_Value=00015/000000002}', "");
Expect(1, 3889, '\P{^Numeric_Value=00015/000000002}', "");
Expect(0, 3890, '\p{Numeric_Value=00015/000000002}', "");
Expect(1, 3890, '\p{^Numeric_Value=00015/000000002}', "");
Expect(1, 3890, '\P{Numeric_Value=00015/000000002}', "");
Expect(0, 3890, '\P{^Numeric_Value=00015/000000002}', "");
Expect(1, 3889, '\p{Numeric_Value:	7.500}', "");
Expect(0, 3889, '\p{^Numeric_Value:	7.500}', "");
Expect(0, 3889, '\P{Numeric_Value:	7.500}', "");
Expect(1, 3889, '\P{^Numeric_Value:	7.500}', "");
Expect(0, 3890, '\p{Numeric_Value:	7.500}', "");
Expect(1, 3890, '\p{^Numeric_Value:	7.500}', "");
Expect(1, 3890, '\P{Numeric_Value:	7.500}', "");
Expect(0, 3890, '\P{^Numeric_Value:	7.500}', "");
Error('\p{Nv=:=		0015/2}');
Error('\P{Nv=:=		0015/2}');
Expect(1, 3889, '\p{Nv=015/002}', "");
Expect(0, 3889, '\p{^Nv=015/002}', "");
Expect(0, 3889, '\P{Nv=015/002}', "");
Expect(1, 3889, '\P{^Nv=015/002}', "");
Expect(0, 3890, '\p{Nv=015/002}', "");
Expect(1, 3890, '\p{^Nv=015/002}', "");
Expect(1, 3890, '\P{Nv=015/002}', "");
Expect(0, 3890, '\P{^Nv=015/002}', "");
Expect(1, 3889, '\p{Nv=7.500}', "");
Expect(0, 3889, '\p{^Nv=7.500}', "");
Expect(0, 3889, '\P{Nv=7.500}', "");
Expect(1, 3889, '\P{^Nv=7.500}', "");
Expect(0, 3890, '\p{Nv=7.500}', "");
Expect(1, 3890, '\p{^Nv=7.500}', "");
Expect(1, 3890, '\P{Nv=7.500}', "");
Expect(0, 3890, '\P{^Nv=7.500}', "");
Error('\p{Is_Numeric_Value=_ 015/000000002/a/}');
Error('\P{Is_Numeric_Value=_ 015/000000002/a/}');
Expect(1, 3889, '\p{Is_Numeric_Value=0000000015/00002}', "");
Expect(0, 3889, '\p{^Is_Numeric_Value=0000000015/00002}', "");
Expect(0, 3889, '\P{Is_Numeric_Value=0000000015/00002}', "");
Expect(1, 3889, '\P{^Is_Numeric_Value=0000000015/00002}', "");
Expect(0, 3890, '\p{Is_Numeric_Value=0000000015/00002}', "");
Expect(1, 3890, '\p{^Is_Numeric_Value=0000000015/00002}', "");
Expect(1, 3890, '\P{Is_Numeric_Value=0000000015/00002}', "");
Expect(0, 3890, '\P{^Is_Numeric_Value=0000000015/00002}', "");
Expect(1, 3889, '\p{Is_Numeric_Value=7.500}', "");
Expect(0, 3889, '\p{^Is_Numeric_Value=7.500}', "");
Expect(0, 3889, '\P{Is_Numeric_Value=7.500}', "");
Expect(1, 3889, '\P{^Is_Numeric_Value=7.500}', "");
Expect(0, 3890, '\p{Is_Numeric_Value=7.500}', "");
Expect(1, 3890, '\p{^Is_Numeric_Value=7.500}', "");
Expect(1, 3890, '\P{Is_Numeric_Value=7.500}', "");
Expect(0, 3890, '\P{^Is_Numeric_Value=7.500}', "");
Error('\p{Is_Nv=:=_	+015/00002}');
Error('\P{Is_Nv=:=_	+015/00002}');
Expect(1, 3889, '\p{Is_Nv=+0015/00002}', "");
Expect(0, 3889, '\p{^Is_Nv=+0015/00002}', "");
Expect(0, 3889, '\P{Is_Nv=+0015/00002}', "");
Expect(1, 3889, '\P{^Is_Nv=+0015/00002}', "");
Expect(0, 3890, '\p{Is_Nv=+0015/00002}', "");
Expect(1, 3890, '\p{^Is_Nv=+0015/00002}', "");
Expect(1, 3890, '\P{Is_Nv=+0015/00002}', "");
Expect(0, 3890, '\P{^Is_Nv=+0015/00002}', "");
Expect(1, 3889, '\p{Is_Nv=7.500}', "");
Expect(0, 3889, '\p{^Is_Nv=7.500}', "");
Expect(0, 3889, '\P{Is_Nv=7.500}', "");
Expect(1, 3889, '\P{^Is_Nv=7.500}', "");
Expect(0, 3890, '\p{Is_Nv=7.500}', "");
Expect(1, 3890, '\p{^Is_Nv=7.500}', "");
Expect(1, 3890, '\P{Is_Nv=7.500}', "");
Expect(0, 3890, '\P{^Is_Nv=7.500}', "");
Error('\p{Numeric_Value=:=  0016}');
Error('\P{Numeric_Value=:=  0016}');
Expect(1, 9456, '\p{Numeric_Value=016}', "");
Expect(0, 9456, '\p{^Numeric_Value=016}', "");
Expect(0, 9456, '\P{Numeric_Value=016}', "");
Expect(1, 9456, '\P{^Numeric_Value=016}', "");
Expect(0, 9457, '\p{Numeric_Value=016}', "");
Expect(1, 9457, '\p{^Numeric_Value=016}', "");
Expect(1, 9457, '\P{Numeric_Value=016}', "");
Expect(0, 9457, '\P{^Numeric_Value=016}', "");
Error('\p{Nv:  0000000016:=}');
Error('\P{Nv:  0000000016:=}');
Expect(1, 9456, '\p{Nv=+00000001_6}', "");
Expect(0, 9456, '\p{^Nv=+00000001_6}', "");
Expect(0, 9456, '\P{Nv=+00000001_6}', "");
Expect(1, 9456, '\P{^Nv=+00000001_6}', "");
Expect(0, 9457, '\p{Nv=+00000001_6}', "");
Expect(1, 9457, '\p{^Nv=+00000001_6}', "");
Expect(1, 9457, '\P{Nv=+00000001_6}', "");
Expect(0, 9457, '\P{^Nv=+00000001_6}', "");
Error('\p{Is_Numeric_Value=/a/- 0001_6}');
Error('\P{Is_Numeric_Value=/a/- 0001_6}');
Expect(1, 9456, '\p{Is_Numeric_Value=000000016}', "");
Expect(0, 9456, '\p{^Is_Numeric_Value=000000016}', "");
Expect(0, 9456, '\P{Is_Numeric_Value=000000016}', "");
Expect(1, 9456, '\P{^Is_Numeric_Value=000000016}', "");
Expect(0, 9457, '\p{Is_Numeric_Value=000000016}', "");
Expect(1, 9457, '\p{^Is_Numeric_Value=000000016}', "");
Expect(1, 9457, '\P{Is_Numeric_Value=000000016}', "");
Expect(0, 9457, '\P{^Is_Numeric_Value=000000016}', "");
Error('\p{Is_Nv=:=01_6}');
Error('\P{Is_Nv=:=01_6}');
Expect(1, 9456, '\p{Is_Nv=00000000016}', "");
Expect(0, 9456, '\p{^Is_Nv=00000000016}', "");
Expect(0, 9456, '\P{Is_Nv=00000000016}', "");
Expect(1, 9456, '\P{^Is_Nv=00000000016}', "");
Expect(0, 9457, '\p{Is_Nv=00000000016}', "");
Expect(1, 9457, '\p{^Is_Nv=00000000016}', "");
Expect(1, 9457, '\P{Is_Nv=00000000016}', "");
Expect(0, 9457, '\P{^Is_Nv=00000000016}', "");
Error('\p{Numeric_Value=:= 0001_7}');
Error('\P{Numeric_Value=:= 0001_7}');
Expect(1, 9457, '\p{Numeric_Value=0000017}', "");
Expect(0, 9457, '\p{^Numeric_Value=0000017}', "");
Expect(0, 9457, '\P{Numeric_Value=0000017}', "");
Expect(1, 9457, '\P{^Numeric_Value=0000017}', "");
Expect(0, 9458, '\p{Numeric_Value=0000017}', "");
Expect(1, 9458, '\p{^Numeric_Value=0000017}', "");
Expect(1, 9458, '\P{Numeric_Value=0000017}', "");
Expect(0, 9458, '\P{^Numeric_Value=0000017}', "");
Error('\p{Nv=/a/1_7}');
Error('\P{Nv=/a/1_7}');
Expect(1, 9457, '\p{Nv=000017}', "");
Expect(0, 9457, '\p{^Nv=000017}', "");
Expect(0, 9457, '\P{Nv=000017}', "");
Expect(1, 9457, '\P{^Nv=000017}', "");
Expect(0, 9458, '\p{Nv=000017}', "");
Expect(1, 9458, '\p{^Nv=000017}', "");
Expect(1, 9458, '\P{Nv=000017}', "");
Expect(0, 9458, '\P{^Nv=000017}', "");
Error('\p{Is_Numeric_Value=:=_ 00000000017}');
Error('\P{Is_Numeric_Value=:=_ 00000000017}');
Expect(1, 9457, '\p{Is_Numeric_Value=00001_7}', "");
Expect(0, 9457, '\p{^Is_Numeric_Value=00001_7}', "");
Expect(0, 9457, '\P{Is_Numeric_Value=00001_7}', "");
Expect(1, 9457, '\P{^Is_Numeric_Value=00001_7}', "");
Expect(0, 9458, '\p{Is_Numeric_Value=00001_7}', "");
Expect(1, 9458, '\p{^Is_Numeric_Value=00001_7}', "");
Expect(1, 9458, '\P{Is_Numeric_Value=00001_7}', "");
Expect(0, 9458, '\P{^Is_Numeric_Value=00001_7}', "");
Error('\p{Is_Nv=_:=000017}');
Error('\P{Is_Nv=_:=000017}');
Expect(1, 9457, '\p{Is_Nv=00000017}', "");
Expect(0, 9457, '\p{^Is_Nv=00000017}', "");
Expect(0, 9457, '\P{Is_Nv=00000017}', "");
Expect(1, 9457, '\P{^Is_Nv=00000017}', "");
Expect(0, 9458, '\p{Is_Nv=00000017}', "");
Expect(1, 9458, '\p{^Is_Nv=00000017}', "");
Expect(1, 9458, '\P{Is_Nv=00000017}', "");
Expect(0, 9458, '\P{^Is_Nv=00000017}', "");
Error('\p{Numeric_Value=_-0017/0000000002/a/}');
Error('\P{Numeric_Value=_-0017/0000000002/a/}');
Expect(1, 3890, '\p{Numeric_Value=000017/2}', "");
Expect(0, 3890, '\p{^Numeric_Value=000017/2}', "");
Expect(0, 3890, '\P{Numeric_Value=000017/2}', "");
Expect(1, 3890, '\P{^Numeric_Value=000017/2}', "");
Expect(0, 3891, '\p{Numeric_Value=000017/2}', "");
Expect(1, 3891, '\p{^Numeric_Value=000017/2}', "");
Expect(1, 3891, '\P{Numeric_Value=000017/2}', "");
Expect(0, 3891, '\P{^Numeric_Value=000017/2}', "");
Expect(1, 3890, '\p{Numeric_Value=8.500}', "");
Expect(0, 3890, '\p{^Numeric_Value=8.500}', "");
Expect(0, 3890, '\P{Numeric_Value=8.500}', "");
Expect(1, 3890, '\P{^Numeric_Value=8.500}', "");
Expect(0, 3891, '\p{Numeric_Value=8.500}', "");
Expect(1, 3891, '\p{^Numeric_Value=8.500}', "");
Expect(1, 3891, '\P{Numeric_Value=8.500}', "");
Expect(0, 3891, '\P{^Numeric_Value=8.500}', "");
Error('\p{Nv=_/a/000017/0000000002}');
Error('\P{Nv=_/a/000017/0000000002}');
Expect(1, 3890, '\p{Nv:	000000017/02}', "");
Expect(0, 3890, '\p{^Nv:	000000017/02}', "");
Expect(0, 3890, '\P{Nv:	000000017/02}', "");
Expect(1, 3890, '\P{^Nv:	000000017/02}', "");
Expect(0, 3891, '\p{Nv:	000000017/02}', "");
Expect(1, 3891, '\p{^Nv:	000000017/02}', "");
Expect(1, 3891, '\P{Nv:	000000017/02}', "");
Expect(0, 3891, '\P{^Nv:	000000017/02}', "");
Expect(1, 3890, '\p{Nv=8.500}', "");
Expect(0, 3890, '\p{^Nv=8.500}', "");
Expect(0, 3890, '\P{Nv=8.500}', "");
Expect(1, 3890, '\P{^Nv=8.500}', "");
Expect(0, 3891, '\p{Nv=8.500}', "");
Expect(1, 3891, '\p{^Nv=8.500}', "");
Expect(1, 3891, '\P{Nv=8.500}', "");
Expect(0, 3891, '\P{^Nv=8.500}', "");
Error('\p{Is_Numeric_Value=	 +17/000002:=}');
Error('\P{Is_Numeric_Value=	 +17/000002:=}');
Expect(1, 3890, '\p{Is_Numeric_Value=+00017/002}', "");
Expect(0, 3890, '\p{^Is_Numeric_Value=+00017/002}', "");
Expect(0, 3890, '\P{Is_Numeric_Value=+00017/002}', "");
Expect(1, 3890, '\P{^Is_Numeric_Value=+00017/002}', "");
Expect(0, 3891, '\p{Is_Numeric_Value=+00017/002}', "");
Expect(1, 3891, '\p{^Is_Numeric_Value=+00017/002}', "");
Expect(1, 3891, '\P{Is_Numeric_Value=+00017/002}', "");
Expect(0, 3891, '\P{^Is_Numeric_Value=+00017/002}', "");
Expect(1, 3890, '\p{Is_Numeric_Value=8.500}', "");
Expect(0, 3890, '\p{^Is_Numeric_Value=8.500}', "");
Expect(0, 3890, '\P{Is_Numeric_Value=8.500}', "");
Expect(1, 3890, '\P{^Is_Numeric_Value=8.500}', "");
Expect(0, 3891, '\p{Is_Numeric_Value=8.500}', "");
Expect(1, 3891, '\p{^Is_Numeric_Value=8.500}', "");
Expect(1, 3891, '\P{Is_Numeric_Value=8.500}', "");
Expect(0, 3891, '\P{^Is_Numeric_Value=8.500}', "");
Error('\p{Is_Nv::=	000000017/000002}');
Error('\P{Is_Nv::=	000000017/000002}');
Expect(1, 3890, '\p{Is_Nv=00000017/000002}', "");
Expect(0, 3890, '\p{^Is_Nv=00000017/000002}', "");
Expect(0, 3890, '\P{Is_Nv=00000017/000002}', "");
Expect(1, 3890, '\P{^Is_Nv=00000017/000002}', "");
Expect(0, 3891, '\p{Is_Nv=00000017/000002}', "");
Expect(1, 3891, '\p{^Is_Nv=00000017/000002}', "");
Expect(1, 3891, '\P{Is_Nv=00000017/000002}', "");
Expect(0, 3891, '\P{^Is_Nv=00000017/000002}', "");
Expect(1, 3890, '\p{Is_Nv=8.500}', "");
Expect(0, 3890, '\p{^Is_Nv=8.500}', "");
Expect(0, 3890, '\P{Is_Nv=8.500}', "");
Expect(1, 3890, '\P{^Is_Nv=8.500}', "");
Expect(0, 3891, '\p{Is_Nv=8.500}', "");
Expect(1, 3891, '\p{^Is_Nv=8.500}', "");
Expect(1, 3891, '\P{Is_Nv=8.500}', "");
Expect(0, 3891, '\P{^Is_Nv=8.500}', "");
Error('\p{Numeric_Value:	-	00018:=}');
Error('\P{Numeric_Value:	-	00018:=}');
Expect(1, 9458, '\p{Numeric_Value=000001_8}', "");
Expect(0, 9458, '\p{^Numeric_Value=000001_8}', "");
Expect(0, 9458, '\P{Numeric_Value=000001_8}', "");
Expect(1, 9458, '\P{^Numeric_Value=000001_8}', "");
Expect(0, 9459, '\p{Numeric_Value=000001_8}', "");
Expect(1, 9459, '\p{^Numeric_Value=000001_8}', "");
Expect(1, 9459, '\P{Numeric_Value=000001_8}', "");
Expect(0, 9459, '\P{^Numeric_Value=000001_8}', "");
Error('\p{Nv=-+18/a/}');
Error('\P{Nv=-+18/a/}');
Expect(1, 9458, '\p{Nv: 00_00_00_18}', "");
Expect(0, 9458, '\p{^Nv: 00_00_00_18}', "");
Expect(0, 9458, '\P{Nv: 00_00_00_18}', "");
Expect(1, 9458, '\P{^Nv: 00_00_00_18}', "");
Expect(0, 9459, '\p{Nv: 00_00_00_18}', "");
Expect(1, 9459, '\p{^Nv: 00_00_00_18}', "");
Expect(1, 9459, '\P{Nv: 00_00_00_18}', "");
Expect(0, 9459, '\P{^Nv: 00_00_00_18}', "");
Error('\p{Is_Numeric_Value=		0018/a/}');
Error('\P{Is_Numeric_Value=		0018/a/}');
Expect(1, 9458, '\p{Is_Numeric_Value=1_8}', "");
Expect(0, 9458, '\p{^Is_Numeric_Value=1_8}', "");
Expect(0, 9458, '\P{Is_Numeric_Value=1_8}', "");
Expect(1, 9458, '\P{^Is_Numeric_Value=1_8}', "");
Expect(0, 9459, '\p{Is_Numeric_Value=1_8}', "");
Expect(1, 9459, '\p{^Is_Numeric_Value=1_8}', "");
Expect(1, 9459, '\P{Is_Numeric_Value=1_8}', "");
Expect(0, 9459, '\P{^Is_Numeric_Value=1_8}', "");
Error('\p{Is_Nv=:=	_+00000018}');
Error('\P{Is_Nv=:=	_+00000018}');
Expect(1, 9458, '\p{Is_Nv=00000018}', "");
Expect(0, 9458, '\p{^Is_Nv=00000018}', "");
Expect(0, 9458, '\P{Is_Nv=00000018}', "");
Expect(1, 9458, '\P{^Is_Nv=00000018}', "");
Expect(0, 9459, '\p{Is_Nv=00000018}', "");
Expect(1, 9459, '\p{^Is_Nv=00000018}', "");
Expect(1, 9459, '\P{Is_Nv=00000018}', "");
Expect(0, 9459, '\P{^Is_Nv=00000018}', "");
Error('\p{Numeric_Value:-	000000019:=}');
Error('\P{Numeric_Value:-	000000019:=}');
Expect(1, 9459, '\p{Numeric_Value=+0000000019}', "");
Expect(0, 9459, '\p{^Numeric_Value=+0000000019}', "");
Expect(0, 9459, '\P{Numeric_Value=+0000000019}', "");
Expect(1, 9459, '\P{^Numeric_Value=+0000000019}', "");
Expect(0, 9460, '\p{Numeric_Value=+0000000019}', "");
Expect(1, 9460, '\p{^Numeric_Value=+0000000019}', "");
Expect(1, 9460, '\P{Numeric_Value=+0000000019}', "");
Expect(0, 9460, '\P{^Numeric_Value=+0000000019}', "");
Error('\p{Nv=	 +0000000019:=}');
Error('\P{Nv=	 +0000000019:=}');
Expect(1, 9459, '\p{Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(0, 9459, '\p{^Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(0, 9459, '\P{Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(1, 9459, '\P{^Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(0, 9460, '\p{Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(1, 9460, '\p{^Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(1, 9460, '\P{Nv=0_0_0_0_0_0_0_0_0_19}', "");
Expect(0, 9460, '\P{^Nv=0_0_0_0_0_0_0_0_0_19}', "");
Error('\p{Is_Numeric_Value:		/a/+0001_9}');
Error('\P{Is_Numeric_Value:		/a/+0001_9}');
Expect(1, 9459, '\p{Is_Numeric_Value:	1_9}', "");
Expect(0, 9459, '\p{^Is_Numeric_Value:	1_9}', "");
Expect(0, 9459, '\P{Is_Numeric_Value:	1_9}', "");
Expect(1, 9459, '\P{^Is_Numeric_Value:	1_9}', "");
Expect(0, 9460, '\p{Is_Numeric_Value:	1_9}', "");
Expect(1, 9460, '\p{^Is_Numeric_Value:	1_9}', "");
Expect(1, 9460, '\P{Is_Numeric_Value:	1_9}', "");
Expect(0, 9460, '\P{^Is_Numeric_Value:	1_9}', "");
Error('\p{Is_Nv:   :=-0000_0001_9}');
Error('\P{Is_Nv:   :=-0000_0001_9}');
Expect(1, 9459, '\p{Is_Nv:   00001_9}', "");
Expect(0, 9459, '\p{^Is_Nv:   00001_9}', "");
Expect(0, 9459, '\P{Is_Nv:   00001_9}', "");
Expect(1, 9459, '\P{^Is_Nv:   00001_9}', "");
Expect(0, 9460, '\p{Is_Nv:   00001_9}', "");
Expect(1, 9460, '\p{^Is_Nv:   00001_9}', "");
Expect(1, 9460, '\P{Is_Nv:   00001_9}', "");
Expect(0, 9460, '\P{^Is_Nv:   00001_9}', "");
Error('\p{Numeric_Value=:=	 0_2}');
Error('\P{Numeric_Value=:=	 0_2}');
Expect(1, 140176, '\p{Numeric_Value=+000_2}', "");
Expect(0, 140176, '\p{^Numeric_Value=+000_2}', "");
Expect(0, 140176, '\P{Numeric_Value=+000_2}', "");
Expect(1, 140176, '\P{^Numeric_Value=+000_2}', "");
Expect(0, 140177, '\p{Numeric_Value=+000_2}', "");
Expect(1, 140177, '\p{^Numeric_Value=+000_2}', "");
Expect(1, 140177, '\P{Numeric_Value=+000_2}', "");
Expect(0, 140177, '\P{^Numeric_Value=+000_2}', "");
Error('\p{Nv=/a/_ 000002}');
Error('\P{Nv=/a/_ 000002}');
Expect(1, 140176, '\p{Nv=00002}', "");
Expect(0, 140176, '\p{^Nv=00002}', "");
Expect(0, 140176, '\P{Nv=00002}', "");
Expect(1, 140176, '\P{^Nv=00002}', "");
Expect(0, 140177, '\p{Nv=00002}', "");
Expect(1, 140177, '\p{^Nv=00002}', "");
Expect(1, 140177, '\P{Nv=00002}', "");
Expect(0, 140177, '\P{^Nv=00002}', "");
Error('\p{Is_Numeric_Value=_0000_2:=}');
Error('\P{Is_Numeric_Value=_0000_2:=}');
Expect(1, 140176, '\p{Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(0, 140176, '\p{^Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(0, 140176, '\P{Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(1, 140176, '\P{^Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(0, 140177, '\p{Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(1, 140177, '\p{^Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(1, 140177, '\P{Is_Numeric_Value:   0_0_0_0_002}', "");
Expect(0, 140177, '\P{^Is_Numeric_Value:   0_0_0_0_002}', "");
Error('\p{Is_Nv=	2:=}');
Error('\P{Is_Nv=	2:=}');
Expect(1, 140176, '\p{Is_Nv:   000002}', "");
Expect(0, 140176, '\p{^Is_Nv:   000002}', "");
Expect(0, 140176, '\P{Is_Nv:   000002}', "");
Expect(1, 140176, '\P{^Is_Nv:   000002}', "");
Expect(0, 140177, '\p{Is_Nv:   000002}', "");
Expect(1, 140177, '\p{^Is_Nv:   000002}', "");
Expect(1, 140177, '\P{Is_Nv:   000002}', "");
Expect(0, 140177, '\P{^Is_Nv:   000002}', "");
Error('\p{Numeric_Value=:=-_0002/3}');
Error('\P{Numeric_Value=:=-_0002/3}');
Expect(1, 74846, '\p{Numeric_Value=2/3}', "");
Expect(0, 74846, '\p{^Numeric_Value=2/3}', "");
Expect(0, 74846, '\P{Numeric_Value=2/3}', "");
Expect(1, 74846, '\P{^Numeric_Value=2/3}', "");
Expect(0, 74847, '\p{Numeric_Value=2/3}', "");
Expect(1, 74847, '\p{^Numeric_Value=2/3}', "");
Expect(1, 74847, '\P{Numeric_Value=2/3}', "");
Expect(0, 74847, '\P{^Numeric_Value=2/3}', "");
Error('\p{Numeric_Value=0.7}');
Error('\P{Numeric_Value=0.7}');
Error('\p{Numeric_Value=0.67}');
Error('\P{Numeric_Value=0.67}');
Expect(1, 74846, '\p{Numeric_Value: 0.667}', "");
Expect(0, 74846, '\p{^Numeric_Value: 0.667}', "");
Expect(0, 74846, '\P{Numeric_Value: 0.667}', "");
Expect(1, 74846, '\P{^Numeric_Value: 0.667}', "");
Expect(0, 74847, '\p{Numeric_Value: 0.667}', "");
Expect(1, 74847, '\p{^Numeric_Value: 0.667}', "");
Expect(1, 74847, '\P{Numeric_Value: 0.667}', "");
Expect(0, 74847, '\P{^Numeric_Value: 0.667}', "");
Error('\p{Nv=/a/_	0000002/0003}');
Error('\P{Nv=/a/_	0000002/0003}');
Expect(1, 74846, '\p{Nv=00002/0000000003}', "");
Expect(0, 74846, '\p{^Nv=00002/0000000003}', "");
Expect(0, 74846, '\P{Nv=00002/0000000003}', "");
Expect(1, 74846, '\P{^Nv=00002/0000000003}', "");
Expect(0, 74847, '\p{Nv=00002/0000000003}', "");
Expect(1, 74847, '\p{^Nv=00002/0000000003}', "");
Expect(1, 74847, '\P{Nv=00002/0000000003}', "");
Expect(0, 74847, '\P{^Nv=00002/0000000003}', "");
Error('\p{Nv=0.7}');
Error('\P{Nv=0.7}');
Error('\p{Nv=0.67}');
Error('\P{Nv=0.67}');
Expect(1, 74846, '\p{Nv:0.667}', "");
Expect(0, 74846, '\p{^Nv:0.667}', "");
Expect(0, 74846, '\P{Nv:0.667}', "");
Expect(1, 74846, '\P{^Nv:0.667}', "");
Expect(0, 74847, '\p{Nv:0.667}', "");
Expect(1, 74847, '\p{^Nv:0.667}', "");
Expect(1, 74847, '\P{Nv:0.667}', "");
Expect(0, 74847, '\P{^Nv:0.667}', "");
Error('\p{Is_Numeric_Value=		0002/0000000003:=}');
Error('\P{Is_Numeric_Value=		0002/0000000003:=}');
Expect(1, 74846, '\p{Is_Numeric_Value=2/000003}', "");
Expect(0, 74846, '\p{^Is_Numeric_Value=2/000003}', "");
Expect(0, 74846, '\P{Is_Numeric_Value=2/000003}', "");
Expect(1, 74846, '\P{^Is_Numeric_Value=2/000003}', "");
Expect(0, 74847, '\p{Is_Numeric_Value=2/000003}', "");
Expect(1, 74847, '\p{^Is_Numeric_Value=2/000003}', "");
Expect(1, 74847, '\P{Is_Numeric_Value=2/000003}', "");
Expect(0, 74847, '\P{^Is_Numeric_Value=2/000003}', "");
Error('\p{Is_Numeric_Value: 0.7}');
Error('\P{Is_Numeric_Value: 0.7}');
Error('\p{Is_Numeric_Value=0.67}');
Error('\P{Is_Numeric_Value=0.67}');
Expect(1, 74846, '\p{Is_Numeric_Value=0.667}', "");
Expect(0, 74846, '\p{^Is_Numeric_Value=0.667}', "");
Expect(0, 74846, '\P{Is_Numeric_Value=0.667}', "");
Expect(1, 74846, '\P{^Is_Numeric_Value=0.667}', "");
Expect(0, 74847, '\p{Is_Numeric_Value=0.667}', "");
Expect(1, 74847, '\p{^Is_Numeric_Value=0.667}', "");
Expect(1, 74847, '\P{Is_Numeric_Value=0.667}', "");
Expect(0, 74847, '\P{^Is_Numeric_Value=0.667}', "");
Error('\p{Is_Nv=	:=2/00003}');
Error('\P{Is_Nv=	:=2/00003}');
Expect(1, 74846, '\p{Is_Nv=0000002/03}', "");
Expect(0, 74846, '\p{^Is_Nv=0000002/03}', "");
Expect(0, 74846, '\P{Is_Nv=0000002/03}', "");
Expect(1, 74846, '\P{^Is_Nv=0000002/03}', "");
Expect(0, 74847, '\p{Is_Nv=0000002/03}', "");
Expect(1, 74847, '\p{^Is_Nv=0000002/03}', "");
Expect(1, 74847, '\P{Is_Nv=0000002/03}', "");
Expect(0, 74847, '\P{^Is_Nv=0000002/03}', "");
Error('\p{Is_Nv=0.7}');
Error('\P{Is_Nv=0.7}');
Error('\p{Is_Nv=0.67}');
Error('\P{Is_Nv=0.67}');
Expect(1, 74846, '\p{Is_Nv=0.667}', "");
Expect(0, 74846, '\p{^Is_Nv=0.667}', "");
Expect(0, 74846, '\P{Is_Nv=0.667}', "");
Expect(1, 74846, '\P{^Is_Nv=0.667}', "");
Expect(0, 74847, '\p{Is_Nv=0.667}', "");
Expect(1, 74847, '\p{^Is_Nv=0.667}', "");
Expect(1, 74847, '\P{Is_Nv=0.667}', "");
Expect(0, 74847, '\P{^Is_Nv=0.667}', "");
Error('\p{Numeric_Value=/a/	0000002/005}');
Error('\P{Numeric_Value=/a/	0000002/005}');
Expect(1, 8534, '\p{Numeric_Value=2/00005}', "");
Expect(0, 8534, '\p{^Numeric_Value=2/00005}', "");
Expect(0, 8534, '\P{Numeric_Value=2/00005}', "");
Expect(1, 8534, '\P{^Numeric_Value=2/00005}', "");
Expect(0, 8535, '\p{Numeric_Value=2/00005}', "");
Expect(1, 8535, '\p{^Numeric_Value=2/00005}', "");
Expect(1, 8535, '\P{Numeric_Value=2/00005}', "");
Expect(0, 8535, '\P{^Numeric_Value=2/00005}', "");
Expect(1, 8534, '\p{Numeric_Value: 0.400}', "");
Expect(0, 8534, '\p{^Numeric_Value: 0.400}', "");
Expect(0, 8534, '\P{Numeric_Value: 0.400}', "");
Expect(1, 8534, '\P{^Numeric_Value: 0.400}', "");
Expect(0, 8535, '\p{Numeric_Value: 0.400}', "");
Expect(1, 8535, '\p{^Numeric_Value: 0.400}', "");
Expect(1, 8535, '\P{Numeric_Value: 0.400}', "");
Expect(0, 8535, '\P{^Numeric_Value: 0.400}', "");
Error('\p{Nv=-/a/002/5}');
Error('\P{Nv=-/a/002/5}');
Expect(1, 8534, '\p{Nv=+00000002/000000005}', "");
Expect(0, 8534, '\p{^Nv=+00000002/000000005}', "");
Expect(0, 8534, '\P{Nv=+00000002/000000005}', "");
Expect(1, 8534, '\P{^Nv=+00000002/000000005}', "");
Expect(0, 8535, '\p{Nv=+00000002/000000005}', "");
Expect(1, 8535, '\p{^Nv=+00000002/000000005}', "");
Expect(1, 8535, '\P{Nv=+00000002/000000005}', "");
Expect(0, 8535, '\P{^Nv=+00000002/000000005}', "");
Expect(1, 8534, '\p{Nv=0.400}', "");
Expect(0, 8534, '\p{^Nv=0.400}', "");
Expect(0, 8534, '\P{Nv=0.400}', "");
Expect(1, 8534, '\P{^Nv=0.400}', "");
Expect(0, 8535, '\p{Nv=0.400}', "");
Expect(1, 8535, '\p{^Nv=0.400}', "");
Expect(1, 8535, '\P{Nv=0.400}', "");
Expect(0, 8535, '\P{^Nv=0.400}', "");
Error('\p{Is_Numeric_Value=/a/0000000002/5}');
Error('\P{Is_Numeric_Value=/a/0000000002/5}');
Expect(1, 8534, '\p{Is_Numeric_Value=+000002/00005}', "");
Expect(0, 8534, '\p{^Is_Numeric_Value=+000002/00005}', "");
Expect(0, 8534, '\P{Is_Numeric_Value=+000002/00005}', "");
Expect(1, 8534, '\P{^Is_Numeric_Value=+000002/00005}', "");
Expect(0, 8535, '\p{Is_Numeric_Value=+000002/00005}', "");
Expect(1, 8535, '\p{^Is_Numeric_Value=+000002/00005}', "");
Expect(1, 8535, '\P{Is_Numeric_Value=+000002/00005}', "");
Expect(0, 8535, '\P{^Is_Numeric_Value=+000002/00005}', "");
Expect(1, 8534, '\p{Is_Numeric_Value=0.400}', "");
Expect(0, 8534, '\p{^Is_Numeric_Value=0.400}', "");
Expect(0, 8534, '\P{Is_Numeric_Value=0.400}', "");
Expect(1, 8534, '\P{^Is_Numeric_Value=0.400}', "");
Expect(0, 8535, '\p{Is_Numeric_Value=0.400}', "");
Expect(1, 8535, '\p{^Is_Numeric_Value=0.400}', "");
Expect(1, 8535, '\P{Is_Numeric_Value=0.400}', "");
Expect(0, 8535, '\P{^Is_Numeric_Value=0.400}', "");
Error('\p{Is_Nv=/a/ -0000002/000005}');
Error('\P{Is_Nv=/a/ -0000002/000005}');
Expect(1, 8534, '\p{Is_Nv=000000002/0000000005}', "");
Expect(0, 8534, '\p{^Is_Nv=000000002/0000000005}', "");
Expect(0, 8534, '\P{Is_Nv=000000002/0000000005}', "");
Expect(1, 8534, '\P{^Is_Nv=000000002/0000000005}', "");
Expect(0, 8535, '\p{Is_Nv=000000002/0000000005}', "");
Expect(1, 8535, '\p{^Is_Nv=000000002/0000000005}', "");
Expect(1, 8535, '\P{Is_Nv=000000002/0000000005}', "");
Expect(0, 8535, '\P{^Is_Nv=000000002/0000000005}', "");
Expect(1, 8534, '\p{Is_Nv:   0.400}', "");
Expect(0, 8534, '\p{^Is_Nv:   0.400}', "");
Expect(0, 8534, '\P{Is_Nv:   0.400}', "");
Expect(1, 8534, '\P{^Is_Nv:   0.400}', "");
Expect(0, 8535, '\p{Is_Nv:   0.400}', "");
Expect(1, 8535, '\p{^Is_Nv:   0.400}', "");
Expect(1, 8535, '\P{Is_Nv:   0.400}', "");
Expect(0, 8535, '\P{^Is_Nv:   0.400}', "");
Error('\p{Numeric_Value=:= 	+00_00_00_02_0}');
Error('\P{Numeric_Value=:= 	+00_00_00_02_0}');
Expect(1, 119658, '\p{Numeric_Value=00000000020}', "");
Expect(0, 119658, '\p{^Numeric_Value=00000000020}', "");
Expect(0, 119658, '\P{Numeric_Value=00000000020}', "");
Expect(1, 119658, '\P{^Numeric_Value=00000000020}', "");
Expect(0, 119659, '\p{Numeric_Value=00000000020}', "");
Expect(1, 119659, '\p{^Numeric_Value=00000000020}', "");
Expect(1, 119659, '\P{Numeric_Value=00000000020}', "");
Expect(0, 119659, '\P{^Numeric_Value=00000000020}', "");
Error('\p{Nv=	:=0000020}');
Error('\P{Nv=	:=0000020}');
Expect(1, 119658, '\p{Nv=02_0}', "");
Expect(0, 119658, '\p{^Nv=02_0}', "");
Expect(0, 119658, '\P{Nv=02_0}', "");
Expect(1, 119658, '\P{^Nv=02_0}', "");
Expect(0, 119659, '\p{Nv=02_0}', "");
Expect(1, 119659, '\p{^Nv=02_0}', "");
Expect(1, 119659, '\P{Nv=02_0}', "");
Expect(0, 119659, '\P{^Nv=02_0}', "");
Error('\p{Is_Numeric_Value= +0020:=}');
Error('\P{Is_Numeric_Value= +0020:=}');
Expect(1, 119658, '\p{Is_Numeric_Value=0_0_20}', "");
Expect(0, 119658, '\p{^Is_Numeric_Value=0_0_20}', "");
Expect(0, 119658, '\P{Is_Numeric_Value=0_0_20}', "");
Expect(1, 119658, '\P{^Is_Numeric_Value=0_0_20}', "");
Expect(0, 119659, '\p{Is_Numeric_Value=0_0_20}', "");
Expect(1, 119659, '\p{^Is_Numeric_Value=0_0_20}', "");
Expect(1, 119659, '\P{Is_Numeric_Value=0_0_20}', "");
Expect(0, 119659, '\P{^Is_Numeric_Value=0_0_20}', "");
Error('\p{Is_Nv= -00000002_0:=}');
Error('\P{Is_Nv= -00000002_0:=}');
Expect(1, 119658, '\p{Is_Nv=+0000000020}', "");
Expect(0, 119658, '\p{^Is_Nv=+0000000020}', "");
Expect(0, 119658, '\P{Is_Nv=+0000000020}', "");
Expect(1, 119658, '\P{^Is_Nv=+0000000020}', "");
Expect(0, 119659, '\p{Is_Nv=+0000000020}', "");
Expect(1, 119659, '\p{^Is_Nv=+0000000020}', "");
Expect(1, 119659, '\P{Is_Nv=+0000000020}', "");
Expect(0, 119659, '\P{^Is_Nv=+0000000020}', "");
Error('\p{Numeric_Value=-/a/+00000200}');
Error('\P{Numeric_Value=-/a/+00000200}');
Expect(1, 69235, '\p{Numeric_Value=000000000200}', "");
Expect(0, 69235, '\p{^Numeric_Value=000000000200}', "");
Expect(0, 69235, '\P{Numeric_Value=000000000200}', "");
Expect(1, 69235, '\P{^Numeric_Value=000000000200}', "");
Expect(0, 69236, '\p{Numeric_Value=000000000200}', "");
Expect(1, 69236, '\p{^Numeric_Value=000000000200}', "");
Expect(1, 69236, '\P{Numeric_Value=000000000200}', "");
Expect(0, 69236, '\P{^Numeric_Value=000000000200}', "");
Error('\p{Nv=-:=+000000200}');
Error('\P{Nv=-:=+000000200}');
Expect(1, 69235, '\p{Nv=00000000200}', "");
Expect(0, 69235, '\p{^Nv=00000000200}', "");
Expect(0, 69235, '\P{Nv=00000000200}', "");
Expect(1, 69235, '\P{^Nv=00000000200}', "");
Expect(0, 69236, '\p{Nv=00000000200}', "");
Expect(1, 69236, '\p{^Nv=00000000200}', "");
Expect(1, 69236, '\P{Nv=00000000200}', "");
Expect(0, 69236, '\P{^Nv=00000000200}', "");
Error('\p{Is_Numeric_Value:	-0200/a/}');
Error('\P{Is_Numeric_Value:	-0200/a/}');
Expect(1, 69235, '\p{Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(0, 69235, '\p{^Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(0, 69235, '\P{Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(1, 69235, '\P{^Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(0, 69236, '\p{Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(1, 69236, '\p{^Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(1, 69236, '\P{Is_Numeric_Value=00_00_00_00_20_0}', "");
Expect(0, 69236, '\P{^Is_Numeric_Value=00_00_00_00_20_0}', "");
Error('\p{Is_Nv=-:=200}');
Error('\P{Is_Nv=-:=200}');
Expect(1, 69235, '\p{Is_Nv=00000000200}', "");
Expect(0, 69235, '\p{^Is_Nv=00000000200}', "");
Expect(0, 69235, '\P{Is_Nv=00000000200}', "");
Expect(1, 69235, '\P{^Is_Nv=00000000200}', "");
Expect(0, 69236, '\p{Is_Nv=00000000200}', "");
Expect(1, 69236, '\p{^Is_Nv=00000000200}', "");
Expect(1, 69236, '\P{Is_Nv=00000000200}', "");
Expect(0, 69236, '\P{^Is_Nv=00000000200}', "");
Error('\p{Numeric_Value=/a/  00002000}');
Error('\P{Numeric_Value=/a/  00002000}');
Expect(1, 65827, '\p{Numeric_Value:	002000}', "");
Expect(0, 65827, '\p{^Numeric_Value:	002000}', "");
Expect(0, 65827, '\P{Numeric_Value:	002000}', "");
Expect(1, 65827, '\P{^Numeric_Value:	002000}', "");
Expect(0, 65828, '\p{Numeric_Value:	002000}', "");
Expect(1, 65828, '\p{^Numeric_Value:	002000}', "");
Expect(1, 65828, '\P{Numeric_Value:	002000}', "");
Expect(0, 65828, '\P{^Numeric_Value:	002000}', "");
Error('\p{Nv=/a/__002000}');
Error('\P{Nv=/a/__002000}');
Expect(1, 65827, '\p{Nv:00002000}', "");
Expect(0, 65827, '\p{^Nv:00002000}', "");
Expect(0, 65827, '\P{Nv:00002000}', "");
Expect(1, 65827, '\P{^Nv:00002000}', "");
Expect(0, 65828, '\p{Nv:00002000}', "");
Expect(1, 65828, '\p{^Nv:00002000}', "");
Expect(1, 65828, '\P{Nv:00002000}', "");
Expect(0, 65828, '\P{^Nv:00002000}', "");
Error('\p{Is_Numeric_Value= 	0_0_0_0_0_0_0_0_2_000:=}');
Error('\P{Is_Numeric_Value= 	0_0_0_0_0_0_0_0_2_000:=}');
Expect(1, 65827, '\p{Is_Numeric_Value=02_00_0}', "");
Expect(0, 65827, '\p{^Is_Numeric_Value=02_00_0}', "");
Expect(0, 65827, '\P{Is_Numeric_Value=02_00_0}', "");
Expect(1, 65827, '\P{^Is_Numeric_Value=02_00_0}', "");
Expect(0, 65828, '\p{Is_Numeric_Value=02_00_0}', "");
Expect(1, 65828, '\p{^Is_Numeric_Value=02_00_0}', "");
Expect(1, 65828, '\P{Is_Numeric_Value=02_00_0}', "");
Expect(0, 65828, '\P{^Is_Numeric_Value=02_00_0}', "");
Error('\p{Is_Nv=/a/000000002000}');
Error('\P{Is_Nv=/a/000000002000}');
Expect(1, 65827, '\p{Is_Nv=+00000002000}', "");
Expect(0, 65827, '\p{^Is_Nv=+00000002000}', "");
Expect(0, 65827, '\P{Is_Nv=+00000002000}', "");
Expect(1, 65827, '\P{^Is_Nv=+00000002000}', "");
Expect(0, 65828, '\p{Is_Nv=+00000002000}', "");
Expect(1, 65828, '\p{^Is_Nv=+00000002000}', "");
Expect(1, 65828, '\P{Is_Nv=+00000002000}', "");
Expect(0, 65828, '\P{^Is_Nv=+00000002000}', "");
Error('\p{Numeric_Value=/a/-00_02_00_00}');
Error('\P{Numeric_Value=/a/-00_02_00_00}');
Expect(1, 65836, '\p{Numeric_Value=+0002000_0}', "");
Expect(0, 65836, '\p{^Numeric_Value=+0002000_0}', "");
Expect(0, 65836, '\P{Numeric_Value=+0002000_0}', "");
Expect(1, 65836, '\P{^Numeric_Value=+0002000_0}', "");
Expect(0, 65837, '\p{Numeric_Value=+0002000_0}', "");
Expect(1, 65837, '\p{^Numeric_Value=+0002000_0}', "");
Expect(1, 65837, '\P{Numeric_Value=+0002000_0}', "");
Expect(0, 65837, '\P{^Numeric_Value=+0002000_0}', "");
Error('\p{Nv=:=_0_0_0_2_0000}');
Error('\P{Nv=:=_0_0_0_2_0000}');
Expect(1, 65836, '\p{Nv=000020000}', "");
Expect(0, 65836, '\p{^Nv=000020000}', "");
Expect(0, 65836, '\P{Nv=000020000}', "");
Expect(1, 65836, '\P{^Nv=000020000}', "");
Expect(0, 65837, '\p{Nv=000020000}', "");
Expect(1, 65837, '\p{^Nv=000020000}', "");
Expect(1, 65837, '\P{Nv=000020000}', "");
Expect(0, 65837, '\P{^Nv=000020000}', "");
Error('\p{Is_Numeric_Value=	_0_0_0_0_0_20000/a/}');
Error('\P{Is_Numeric_Value=	_0_0_0_0_0_20000/a/}');
Expect(1, 65836, '\p{Is_Numeric_Value=000000020000}', "");
Expect(0, 65836, '\p{^Is_Numeric_Value=000000020000}', "");
Expect(0, 65836, '\P{Is_Numeric_Value=000000020000}', "");
Expect(1, 65836, '\P{^Is_Numeric_Value=000000020000}', "");
Expect(0, 65837, '\p{Is_Numeric_Value=000000020000}', "");
Expect(1, 65837, '\p{^Is_Numeric_Value=000000020000}', "");
Expect(1, 65837, '\P{Is_Numeric_Value=000000020000}', "");
Expect(0, 65837, '\P{^Is_Numeric_Value=000000020000}', "");
Error('\p{Is_Nv=	-00020000/a/}');
Error('\P{Is_Nv=	-00020000/a/}');
Expect(1, 65836, '\p{Is_Nv=+00_00_00_00_02_0000}', "");
Expect(0, 65836, '\p{^Is_Nv=+00_00_00_00_02_0000}', "");
Expect(0, 65836, '\P{Is_Nv=+00_00_00_00_02_0000}', "");
Expect(1, 65836, '\P{^Is_Nv=+00_00_00_00_02_0000}', "");
Expect(0, 65837, '\p{Is_Nv=+00_00_00_00_02_0000}', "");
Expect(1, 65837, '\p{^Is_Nv=+00_00_00_00_02_0000}', "");
Expect(1, 65837, '\P{Is_Nv=+00_00_00_00_02_0000}', "");
Expect(0, 65837, '\P{^Is_Nv=+00_00_00_00_02_0000}', "");
Error('\p{Numeric_Value=-_+0021:=}');
Error('\P{Numeric_Value=-_+0021:=}');
Expect(1, 12881, '\p{Numeric_Value=+021}', "");
Expect(0, 12881, '\p{^Numeric_Value=+021}', "");
Expect(0, 12881, '\P{Numeric_Value=+021}', "");
Expect(1, 12881, '\P{^Numeric_Value=+021}', "");
Expect(0, 12882, '\p{Numeric_Value=+021}', "");
Expect(1, 12882, '\p{^Numeric_Value=+021}', "");
Expect(1, 12882, '\P{Numeric_Value=+021}', "");
Expect(0, 12882, '\P{^Numeric_Value=+021}', "");
Error('\p{Nv=-:=02_1}');
Error('\P{Nv=-:=02_1}');
Expect(1, 12881, '\p{Nv=+0_0_0_0_0_0_0_021}', "");
Expect(0, 12881, '\p{^Nv=+0_0_0_0_0_0_0_021}', "");
Expect(0, 12881, '\P{Nv=+0_0_0_0_0_0_0_021}', "");
Expect(1, 12881, '\P{^Nv=+0_0_0_0_0_0_0_021}', "");
Expect(0, 12882, '\p{Nv=+0_0_0_0_0_0_0_021}', "");
Expect(1, 12882, '\p{^Nv=+0_0_0_0_0_0_0_021}', "");
Expect(1, 12882, '\P{Nv=+0_0_0_0_0_0_0_021}', "");
Expect(0, 12882, '\P{^Nv=+0_0_0_0_0_0_0_021}', "");
Error('\p{Is_Numeric_Value=	-02_1/a/}');
Error('\P{Is_Numeric_Value=	-02_1/a/}');
Expect(1, 12881, '\p{Is_Numeric_Value=0000000021}', "");
Expect(0, 12881, '\p{^Is_Numeric_Value=0000000021}', "");
Expect(0, 12881, '\P{Is_Numeric_Value=0000000021}', "");
Expect(1, 12881, '\P{^Is_Numeric_Value=0000000021}', "");
Expect(0, 12882, '\p{Is_Numeric_Value=0000000021}', "");
Expect(1, 12882, '\p{^Is_Numeric_Value=0000000021}', "");
Expect(1, 12882, '\P{Is_Numeric_Value=0000000021}', "");
Expect(0, 12882, '\P{^Is_Numeric_Value=0000000021}', "");
Error('\p{Is_Nv=:=_ +00021}');
Error('\P{Is_Nv=:=_ +00021}');
Expect(1, 12881, '\p{Is_Nv=00000021}', "");
Expect(0, 12881, '\p{^Is_Nv=00000021}', "");
Expect(0, 12881, '\P{Is_Nv=00000021}', "");
Expect(1, 12881, '\P{^Is_Nv=00000021}', "");
Expect(0, 12882, '\p{Is_Nv=00000021}', "");
Expect(1, 12882, '\p{^Is_Nv=00000021}', "");
Expect(1, 12882, '\P{Is_Nv=00000021}', "");
Expect(0, 12882, '\P{^Is_Nv=00000021}', "");
Error('\p{Numeric_Value=:=-	000000000216000}');
Error('\P{Numeric_Value=:=-	000000000216000}');
Expect(1, 74802, '\p{Numeric_Value=216000}', "");
Expect(0, 74802, '\p{^Numeric_Value=216000}', "");
Expect(0, 74802, '\P{Numeric_Value=216000}', "");
Expect(1, 74802, '\P{^Numeric_Value=216000}', "");
Expect(0, 74803, '\p{Numeric_Value=216000}', "");
Expect(1, 74803, '\p{^Numeric_Value=216000}', "");
Expect(1, 74803, '\P{Numeric_Value=216000}', "");
Expect(0, 74803, '\P{^Numeric_Value=216000}', "");
Error('\p{Nv=/a/-_+00216000}');
Error('\P{Nv=/a/-_+00216000}');
Expect(1, 74802, '\p{Nv=+000216000}', "");
Expect(0, 74802, '\p{^Nv=+000216000}', "");
Expect(0, 74802, '\P{Nv=+000216000}', "");
Expect(1, 74802, '\P{^Nv=+000216000}', "");
Expect(0, 74803, '\p{Nv=+000216000}', "");
Expect(1, 74803, '\p{^Nv=+000216000}', "");
Expect(1, 74803, '\P{Nv=+000216000}', "");
Expect(0, 74803, '\P{^Nv=+000216000}', "");
Error('\p{Is_Numeric_Value= _00_02_16_000:=}');
Error('\P{Is_Numeric_Value= _00_02_16_000:=}');
Expect(1, 74802, '\p{Is_Numeric_Value=0000216000}', "");
Expect(0, 74802, '\p{^Is_Numeric_Value=0000216000}', "");
Expect(0, 74802, '\P{Is_Numeric_Value=0000216000}', "");
Expect(1, 74802, '\P{^Is_Numeric_Value=0000216000}', "");
Expect(0, 74803, '\p{Is_Numeric_Value=0000216000}', "");
Expect(1, 74803, '\p{^Is_Numeric_Value=0000216000}', "");
Expect(1, 74803, '\P{Is_Numeric_Value=0000216000}', "");
Expect(0, 74803, '\P{^Is_Numeric_Value=0000216000}', "");
Error('\p{Is_Nv=-	0_0_0_0_0_0_2_1_6_0_00:=}');
Error('\P{Is_Nv=-	0_0_0_0_0_0_2_1_6_0_00:=}');
Expect(1, 74802, '\p{Is_Nv:   00_21_60_00}', "");
Expect(0, 74802, '\p{^Is_Nv:   00_21_60_00}', "");
Expect(0, 74802, '\P{Is_Nv:   00_21_60_00}', "");
Expect(1, 74802, '\P{^Is_Nv:   00_21_60_00}', "");
Expect(0, 74803, '\p{Is_Nv:   00_21_60_00}', "");
Expect(1, 74803, '\p{^Is_Nv:   00_21_60_00}', "");
Expect(1, 74803, '\P{Is_Nv:   00_21_60_00}', "");
Expect(0, 74803, '\P{^Is_Nv:   00_21_60_00}', "");
Error('\p{Numeric_Value=-+00000022:=}');
Error('\P{Numeric_Value=-+00000022:=}');
Expect(1, 12882, '\p{Numeric_Value=+0_0_0_022}', "");
Expect(0, 12882, '\p{^Numeric_Value=+0_0_0_022}', "");
Expect(0, 12882, '\P{Numeric_Value=+0_0_0_022}', "");
Expect(1, 12882, '\P{^Numeric_Value=+0_0_0_022}', "");
Expect(0, 12883, '\p{Numeric_Value=+0_0_0_022}', "");
Expect(1, 12883, '\p{^Numeric_Value=+0_0_0_022}', "");
Expect(1, 12883, '\P{Numeric_Value=+0_0_0_022}', "");
Expect(0, 12883, '\P{^Numeric_Value=+0_0_0_022}', "");
Error('\p{Nv=/a/_22}');
Error('\P{Nv=/a/_22}');
Expect(1, 12882, '\p{Nv=22}', "");
Expect(0, 12882, '\p{^Nv=22}', "");
Expect(0, 12882, '\P{Nv=22}', "");
Expect(1, 12882, '\P{^Nv=22}', "");
Expect(0, 12883, '\p{Nv=22}', "");
Expect(1, 12883, '\p{^Nv=22}', "");
Expect(1, 12883, '\P{Nv=22}', "");
Expect(0, 12883, '\P{^Nv=22}', "");
Error('\p{Is_Numeric_Value:   -_+022:=}');
Error('\P{Is_Numeric_Value:   -_+022:=}');
Expect(1, 12882, '\p{Is_Numeric_Value=00022}', "");
Expect(0, 12882, '\p{^Is_Numeric_Value=00022}', "");
Expect(0, 12882, '\P{Is_Numeric_Value=00022}', "");
Expect(1, 12882, '\P{^Is_Numeric_Value=00022}', "");
Expect(0, 12883, '\p{Is_Numeric_Value=00022}', "");
Expect(1, 12883, '\p{^Is_Numeric_Value=00022}', "");
Expect(1, 12883, '\P{Is_Numeric_Value=00022}', "");
Expect(0, 12883, '\P{^Is_Numeric_Value=00022}', "");
Error('\p{Is_Nv=:=000022}');
Error('\P{Is_Nv=:=000022}');
Expect(1, 12882, '\p{Is_Nv=+0_0_0_0_0_22}', "");
Expect(0, 12882, '\p{^Is_Nv=+0_0_0_0_0_22}', "");
Expect(0, 12882, '\P{Is_Nv=+0_0_0_0_0_22}', "");
Expect(1, 12882, '\P{^Is_Nv=+0_0_0_0_0_22}', "");
Expect(0, 12883, '\p{Is_Nv=+0_0_0_0_0_22}', "");
Expect(1, 12883, '\p{^Is_Nv=+0_0_0_0_0_22}', "");
Expect(1, 12883, '\P{Is_Nv=+0_0_0_0_0_22}', "");
Expect(0, 12883, '\P{^Is_Nv=+0_0_0_0_0_22}', "");
Error('\p{Numeric_Value:  _0000023:=}');
Error('\P{Numeric_Value:  _0000023:=}');
Expect(1, 12883, '\p{Numeric_Value: 23}', "");
Expect(0, 12883, '\p{^Numeric_Value: 23}', "");
Expect(0, 12883, '\P{Numeric_Value: 23}', "");
Expect(1, 12883, '\P{^Numeric_Value: 23}', "");
Expect(0, 12884, '\p{Numeric_Value: 23}', "");
Expect(1, 12884, '\p{^Numeric_Value: 23}', "");
Expect(1, 12884, '\P{Numeric_Value: 23}', "");
Expect(0, 12884, '\P{^Numeric_Value: 23}', "");
Error('\p{Nv:    	0_0_0_0_023/a/}');
Error('\P{Nv:    	0_0_0_0_023/a/}');
Expect(1, 12883, '\p{Nv:   023}', "");
Expect(0, 12883, '\p{^Nv:   023}', "");
Expect(0, 12883, '\P{Nv:   023}', "");
Expect(1, 12883, '\P{^Nv:   023}', "");
Expect(0, 12884, '\p{Nv:   023}', "");
Expect(1, 12884, '\p{^Nv:   023}', "");
Expect(1, 12884, '\P{Nv:   023}', "");
Expect(0, 12884, '\P{^Nv:   023}', "");
Error('\p{Is_Numeric_Value= /a/0000000002_3}');
Error('\P{Is_Numeric_Value= /a/0000000002_3}');
Expect(1, 12883, '\p{Is_Numeric_Value:	0_0_0_023}', "");
Expect(0, 12883, '\p{^Is_Numeric_Value:	0_0_0_023}', "");
Expect(0, 12883, '\P{Is_Numeric_Value:	0_0_0_023}', "");
Expect(1, 12883, '\P{^Is_Numeric_Value:	0_0_0_023}', "");
Expect(0, 12884, '\p{Is_Numeric_Value:	0_0_0_023}', "");
Expect(1, 12884, '\p{^Is_Numeric_Value:	0_0_0_023}', "");
Expect(1, 12884, '\P{Is_Numeric_Value:	0_0_0_023}', "");
Expect(0, 12884, '\P{^Is_Numeric_Value:	0_0_0_023}', "");
Error('\p{Is_Nv= _023:=}');
Error('\P{Is_Nv= _023:=}');
Expect(1, 12883, '\p{Is_Nv=00000023}', "");
Expect(0, 12883, '\p{^Is_Nv=00000023}', "");
Expect(0, 12883, '\P{Is_Nv=00000023}', "");
Expect(1, 12883, '\P{^Is_Nv=00000023}', "");
Expect(0, 12884, '\p{Is_Nv=00000023}', "");
Expect(1, 12884, '\p{^Is_Nv=00000023}', "");
Expect(1, 12884, '\P{Is_Nv=00000023}', "");
Expect(0, 12884, '\P{^Is_Nv=00000023}', "");
Error('\p{Numeric_Value:	_/a/+0024}');
Error('\P{Numeric_Value:	_/a/+0024}');
Expect(1, 12884, '\p{Numeric_Value=00_02_4}', "");
Expect(0, 12884, '\p{^Numeric_Value=00_02_4}', "");
Expect(0, 12884, '\P{Numeric_Value=00_02_4}', "");
Expect(1, 12884, '\P{^Numeric_Value=00_02_4}', "");
Expect(0, 12885, '\p{Numeric_Value=00_02_4}', "");
Expect(1, 12885, '\p{^Numeric_Value=00_02_4}', "");
Expect(1, 12885, '\P{Numeric_Value=00_02_4}', "");
Expect(0, 12885, '\P{^Numeric_Value=00_02_4}', "");
Error('\p{Nv=	-002_4/a/}');
Error('\P{Nv=	-002_4/a/}');
Expect(1, 12884, '\p{Nv=+00000000024}', "");
Expect(0, 12884, '\p{^Nv=+00000000024}', "");
Expect(0, 12884, '\P{Nv=+00000000024}', "");
Expect(1, 12884, '\P{^Nv=+00000000024}', "");
Expect(0, 12885, '\p{Nv=+00000000024}', "");
Expect(1, 12885, '\p{^Nv=+00000000024}', "");
Expect(1, 12885, '\P{Nv=+00000000024}', "");
Expect(0, 12885, '\P{^Nv=+00000000024}', "");
Error('\p{Is_Numeric_Value=-000024/a/}');
Error('\P{Is_Numeric_Value=-000024/a/}');
Expect(1, 12884, '\p{Is_Numeric_Value=+24}', "");
Expect(0, 12884, '\p{^Is_Numeric_Value=+24}', "");
Expect(0, 12884, '\P{Is_Numeric_Value=+24}', "");
Expect(1, 12884, '\P{^Is_Numeric_Value=+24}', "");
Expect(0, 12885, '\p{Is_Numeric_Value=+24}', "");
Expect(1, 12885, '\p{^Is_Numeric_Value=+24}', "");
Expect(1, 12885, '\P{Is_Numeric_Value=+24}', "");
Expect(0, 12885, '\P{^Is_Numeric_Value=+24}', "");
Error('\p{Is_Nv=  +000024:=}');
Error('\P{Is_Nv=  +000024:=}');
Expect(1, 12884, '\p{Is_Nv=0_0_0_0_24}', "");
Expect(0, 12884, '\p{^Is_Nv=0_0_0_0_24}', "");
Expect(0, 12884, '\P{Is_Nv=0_0_0_0_24}', "");
Expect(1, 12884, '\P{^Is_Nv=0_0_0_0_24}', "");
Expect(0, 12885, '\p{Is_Nv=0_0_0_0_24}', "");
Expect(1, 12885, '\p{^Is_Nv=0_0_0_0_24}', "");
Expect(1, 12885, '\P{Is_Nv=0_0_0_0_24}', "");
Expect(0, 12885, '\P{^Is_Nv=0_0_0_0_24}', "");
Error('\p{Numeric_Value=:=_-0025}');
Error('\P{Numeric_Value=:=_-0025}');
Expect(1, 12885, '\p{Numeric_Value=+00000000025}', "");
Expect(0, 12885, '\p{^Numeric_Value=+00000000025}', "");
Expect(0, 12885, '\P{Numeric_Value=+00000000025}', "");
Expect(1, 12885, '\P{^Numeric_Value=+00000000025}', "");
Expect(0, 12886, '\p{Numeric_Value=+00000000025}', "");
Expect(1, 12886, '\p{^Numeric_Value=+00000000025}', "");
Expect(1, 12886, '\P{Numeric_Value=+00000000025}', "");
Expect(0, 12886, '\P{^Numeric_Value=+00000000025}', "");
Error('\p{Nv= /a/00_00_00_00_25}');
Error('\P{Nv= /a/00_00_00_00_25}');
Expect(1, 12885, '\p{Nv=0_0_0_0_25}', "");
Expect(0, 12885, '\p{^Nv=0_0_0_0_25}', "");
Expect(0, 12885, '\P{Nv=0_0_0_0_25}', "");
Expect(1, 12885, '\P{^Nv=0_0_0_0_25}', "");
Expect(0, 12886, '\p{Nv=0_0_0_0_25}', "");
Expect(1, 12886, '\p{^Nv=0_0_0_0_25}', "");
Expect(1, 12886, '\P{Nv=0_0_0_0_25}', "");
Expect(0, 12886, '\P{^Nv=0_0_0_0_25}', "");
Error('\p{Is_Numeric_Value=:= 	0_0_0_0_0_0_0_025}');
Error('\P{Is_Numeric_Value=:= 	0_0_0_0_0_0_0_025}');
Expect(1, 12885, '\p{Is_Numeric_Value=0000000025}', "");
Expect(0, 12885, '\p{^Is_Numeric_Value=0000000025}', "");
Expect(0, 12885, '\P{Is_Numeric_Value=0000000025}', "");
Expect(1, 12885, '\P{^Is_Numeric_Value=0000000025}', "");
Expect(0, 12886, '\p{Is_Numeric_Value=0000000025}', "");
Expect(1, 12886, '\p{^Is_Numeric_Value=0000000025}', "");
Expect(1, 12886, '\P{Is_Numeric_Value=0000000025}', "");
Expect(0, 12886, '\P{^Is_Numeric_Value=0000000025}', "");
Error('\p{Is_Nv=_0025:=}');
Error('\P{Is_Nv=_0025:=}');
Expect(1, 12885, '\p{Is_Nv=00025}', "");
Expect(0, 12885, '\p{^Is_Nv=00025}', "");
Expect(0, 12885, '\P{Is_Nv=00025}', "");
Expect(1, 12885, '\P{^Is_Nv=00025}', "");
Expect(0, 12886, '\p{Is_Nv=00025}', "");
Expect(1, 12886, '\p{^Is_Nv=00025}', "");
Expect(1, 12886, '\P{Is_Nv=00025}', "");
Expect(0, 12886, '\P{^Is_Nv=00025}', "");
Error('\p{Numeric_Value=/a/_ 0_0_0_0_0_26}');
Error('\P{Numeric_Value=/a/_ 0_0_0_0_0_26}');
Expect(1, 12886, '\p{Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(0, 12886, '\p{^Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(0, 12886, '\P{Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(1, 12886, '\P{^Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(0, 12887, '\p{Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(1, 12887, '\p{^Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(1, 12887, '\P{Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Expect(0, 12887, '\P{^Numeric_Value=+0_0_0_0_0_0_0_0_0_26}', "");
Error('\p{Nv=	/a/00000000026}');
Error('\P{Nv=	/a/00000000026}');
Expect(1, 12886, '\p{Nv=+2_6}', "");
Expect(0, 12886, '\p{^Nv=+2_6}', "");
Expect(0, 12886, '\P{Nv=+2_6}', "");
Expect(1, 12886, '\P{^Nv=+2_6}', "");
Expect(0, 12887, '\p{Nv=+2_6}', "");
Expect(1, 12887, '\p{^Nv=+2_6}', "");
Expect(1, 12887, '\P{Nv=+2_6}', "");
Expect(0, 12887, '\P{^Nv=+2_6}', "");
Error('\p{Is_Numeric_Value= 	+000_002_6:=}');
Error('\P{Is_Numeric_Value= 	+000_002_6:=}');
Expect(1, 12886, '\p{Is_Numeric_Value=+02_6}', "");
Expect(0, 12886, '\p{^Is_Numeric_Value=+02_6}', "");
Expect(0, 12886, '\P{Is_Numeric_Value=+02_6}', "");
Expect(1, 12886, '\P{^Is_Numeric_Value=+02_6}', "");
Expect(0, 12887, '\p{Is_Numeric_Value=+02_6}', "");
Expect(1, 12887, '\p{^Is_Numeric_Value=+02_6}', "");
Expect(1, 12887, '\P{Is_Numeric_Value=+02_6}', "");
Expect(0, 12887, '\P{^Is_Numeric_Value=+02_6}', "");
Error('\p{Is_Nv=-:=0_0_0_0_0_26}');
Error('\P{Is_Nv=-:=0_0_0_0_0_26}');
Expect(1, 12886, '\p{Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(0, 12886, '\p{^Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(0, 12886, '\P{Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(1, 12886, '\P{^Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(0, 12887, '\p{Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(1, 12887, '\p{^Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(1, 12887, '\P{Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Expect(0, 12887, '\P{^Is_Nv=0_0_0_0_0_0_0_0_026}', "");
Error('\p{Numeric_Value=-_2_7/a/}');
Error('\P{Numeric_Value=-_2_7/a/}');
Expect(1, 12887, '\p{Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(0, 12887, '\p{^Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(0, 12887, '\P{Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(1, 12887, '\P{^Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(0, 12888, '\p{Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(1, 12888, '\p{^Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(1, 12888, '\P{Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Expect(0, 12888, '\P{^Numeric_Value=+0_0_0_0_0_0_0_027}', "");
Error('\p{Nv=-:=0000000002_7}');
Error('\P{Nv=-:=0000000002_7}');
Expect(1, 12887, '\p{Nv=+00000027}', "");
Expect(0, 12887, '\p{^Nv=+00000027}', "");
Expect(0, 12887, '\P{Nv=+00000027}', "");
Expect(1, 12887, '\P{^Nv=+00000027}', "");
Expect(0, 12888, '\p{Nv=+00000027}', "");
Expect(1, 12888, '\p{^Nv=+00000027}', "");
Expect(1, 12888, '\P{Nv=+00000027}', "");
Expect(0, 12888, '\P{^Nv=+00000027}', "");
Error('\p{Is_Numeric_Value= 	00027/a/}');
Error('\P{Is_Numeric_Value= 	00027/a/}');
Expect(1, 12887, '\p{Is_Numeric_Value: 000027}', "");
Expect(0, 12887, '\p{^Is_Numeric_Value: 000027}', "");
Expect(0, 12887, '\P{Is_Numeric_Value: 000027}', "");
Expect(1, 12887, '\P{^Is_Numeric_Value: 000027}', "");
Expect(0, 12888, '\p{Is_Numeric_Value: 000027}', "");
Expect(1, 12888, '\p{^Is_Numeric_Value: 000027}', "");
Expect(1, 12888, '\P{Is_Numeric_Value: 000027}', "");
Expect(0, 12888, '\P{^Is_Numeric_Value: 000027}', "");
Error('\p{Is_Nv=_:=0_0_0_0_0_0_0_0027}');
Error('\P{Is_Nv=_:=0_0_0_0_0_0_0_0027}');
Expect(1, 12887, '\p{Is_Nv=00_02_7}', "");
Expect(0, 12887, '\p{^Is_Nv=00_02_7}', "");
Expect(0, 12887, '\P{Is_Nv=00_02_7}', "");
Expect(1, 12887, '\P{^Is_Nv=00_02_7}', "");
Expect(0, 12888, '\p{Is_Nv=00_02_7}', "");
Expect(1, 12888, '\p{^Is_Nv=00_02_7}', "");
Expect(1, 12888, '\P{Is_Nv=00_02_7}', "");
Expect(0, 12888, '\P{^Is_Nv=00_02_7}', "");
Error('\p{Numeric_Value=/a/  +000_000_002_8}');
Error('\P{Numeric_Value=/a/  +000_000_002_8}');
Expect(1, 12888, '\p{Numeric_Value=02_8}', "");
Expect(0, 12888, '\p{^Numeric_Value=02_8}', "");
Expect(0, 12888, '\P{Numeric_Value=02_8}', "");
Expect(1, 12888, '\P{^Numeric_Value=02_8}', "");
Expect(0, 12889, '\p{Numeric_Value=02_8}', "");
Expect(1, 12889, '\p{^Numeric_Value=02_8}', "");
Expect(1, 12889, '\P{Numeric_Value=02_8}', "");
Expect(0, 12889, '\P{^Numeric_Value=02_8}', "");
Error('\p{Nv=/a/_000028}');
Error('\P{Nv=/a/_000028}');
Expect(1, 12888, '\p{Nv=+0000_0000_28}', "");
Expect(0, 12888, '\p{^Nv=+0000_0000_28}', "");
Expect(0, 12888, '\P{Nv=+0000_0000_28}', "");
Expect(1, 12888, '\P{^Nv=+0000_0000_28}', "");
Expect(0, 12889, '\p{Nv=+0000_0000_28}', "");
Expect(1, 12889, '\p{^Nv=+0000_0000_28}', "");
Expect(1, 12889, '\P{Nv=+0000_0000_28}', "");
Expect(0, 12889, '\P{^Nv=+0000_0000_28}', "");
Error('\p{Is_Numeric_Value=_:=02_8}');
Error('\P{Is_Numeric_Value=_:=02_8}');
Expect(1, 12888, '\p{Is_Numeric_Value=+02_8}', "");
Expect(0, 12888, '\p{^Is_Numeric_Value=+02_8}', "");
Expect(0, 12888, '\P{Is_Numeric_Value=+02_8}', "");
Expect(1, 12888, '\P{^Is_Numeric_Value=+02_8}', "");
Expect(0, 12889, '\p{Is_Numeric_Value=+02_8}', "");
Expect(1, 12889, '\p{^Is_Numeric_Value=+02_8}', "");
Expect(1, 12889, '\P{Is_Numeric_Value=+02_8}', "");
Expect(0, 12889, '\P{^Is_Numeric_Value=+02_8}', "");
Error('\p{Is_Nv=_/a/002_8}');
Error('\P{Is_Nv=_/a/002_8}');
Expect(1, 12888, '\p{Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(0, 12888, '\p{^Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(0, 12888, '\P{Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(1, 12888, '\P{^Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(0, 12889, '\p{Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(1, 12889, '\p{^Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(1, 12889, '\P{Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Expect(0, 12889, '\P{^Is_Nv=+0_0_0_0_0_0_0_0_0_28}', "");
Error('\p{Numeric_Value= +0_0_0_029/a/}');
Error('\P{Numeric_Value= +0_0_0_029/a/}');
Expect(1, 12889, '\p{Numeric_Value=+02_9}', "");
Expect(0, 12889, '\p{^Numeric_Value=+02_9}', "");
Expect(0, 12889, '\P{Numeric_Value=+02_9}', "");
Expect(1, 12889, '\P{^Numeric_Value=+02_9}', "");
Expect(0, 12890, '\p{Numeric_Value=+02_9}', "");
Expect(1, 12890, '\p{^Numeric_Value=+02_9}', "");
Expect(1, 12890, '\P{Numeric_Value=+02_9}', "");
Expect(0, 12890, '\P{^Numeric_Value=+02_9}', "");
Error('\p{Nv=:=_ 00029}');
Error('\P{Nv=:=_ 00029}');
Expect(1, 12889, '\p{Nv=+029}', "");
Expect(0, 12889, '\p{^Nv=+029}', "");
Expect(0, 12889, '\P{Nv=+029}', "");
Expect(1, 12889, '\P{^Nv=+029}', "");
Expect(0, 12890, '\p{Nv=+029}', "");
Expect(1, 12890, '\p{^Nv=+029}', "");
Expect(1, 12890, '\P{Nv=+029}', "");
Expect(0, 12890, '\P{^Nv=+029}', "");
Error('\p{Is_Numeric_Value=:=__+029}');
Error('\P{Is_Numeric_Value=:=__+029}');
Expect(1, 12889, '\p{Is_Numeric_Value=+00029}', "");
Expect(0, 12889, '\p{^Is_Numeric_Value=+00029}', "");
Expect(0, 12889, '\P{Is_Numeric_Value=+00029}', "");
Expect(1, 12889, '\P{^Is_Numeric_Value=+00029}', "");
Expect(0, 12890, '\p{Is_Numeric_Value=+00029}', "");
Expect(1, 12890, '\p{^Is_Numeric_Value=+00029}', "");
Expect(1, 12890, '\P{Is_Numeric_Value=+00029}', "");
Expect(0, 12890, '\P{^Is_Numeric_Value=+00029}', "");
Error('\p{Is_Nv=:=	_0002_9}');
Error('\P{Is_Nv=:=	_0002_9}');
Expect(1, 12889, '\p{Is_Nv=000000029}', "");
Expect(0, 12889, '\p{^Is_Nv=000000029}', "");
Expect(0, 12889, '\P{Is_Nv=000000029}', "");
Expect(1, 12889, '\P{^Is_Nv=000000029}', "");
Expect(0, 12890, '\p{Is_Nv=000000029}', "");
Expect(1, 12890, '\p{^Is_Nv=000000029}', "");
Expect(1, 12890, '\P{Is_Nv=000000029}', "");
Expect(0, 12890, '\P{^Is_Nv=000000029}', "");
Error('\p{Numeric_Value=:=+00003}');
Error('\P{Numeric_Value=:=+00003}');
Expect(1, 146203, '\p{Numeric_Value=0_3}', "");
Expect(0, 146203, '\p{^Numeric_Value=0_3}', "");
Expect(0, 146203, '\P{Numeric_Value=0_3}', "");
Expect(1, 146203, '\P{^Numeric_Value=0_3}', "");
Expect(0, 146204, '\p{Numeric_Value=0_3}', "");
Expect(1, 146204, '\p{^Numeric_Value=0_3}', "");
Expect(1, 146204, '\P{Numeric_Value=0_3}', "");
Expect(0, 146204, '\P{^Numeric_Value=0_3}', "");
Error('\p{Nv= /a/3}');
Error('\P{Nv= /a/3}');
Expect(1, 146203, '\p{Nv=+000_3}', "");
Expect(0, 146203, '\p{^Nv=+000_3}', "");
Expect(0, 146203, '\P{Nv=+000_3}', "");
Expect(1, 146203, '\P{^Nv=+000_3}', "");
Expect(0, 146204, '\p{Nv=+000_3}', "");
Expect(1, 146204, '\p{^Nv=+000_3}', "");
Expect(1, 146204, '\P{Nv=+000_3}', "");
Expect(0, 146204, '\P{^Nv=+000_3}', "");
Error('\p{Is_Numeric_Value=	:=+00_00_00_00_3}');
Error('\P{Is_Numeric_Value=	:=+00_00_00_00_3}');
Expect(1, 146203, '\p{Is_Numeric_Value=+3}', "");
Expect(0, 146203, '\p{^Is_Numeric_Value=+3}', "");
Expect(0, 146203, '\P{Is_Numeric_Value=+3}', "");
Expect(1, 146203, '\P{^Is_Numeric_Value=+3}', "");
Expect(0, 146204, '\p{Is_Numeric_Value=+3}', "");
Expect(1, 146204, '\p{^Is_Numeric_Value=+3}', "");
Expect(1, 146204, '\P{Is_Numeric_Value=+3}', "");
Expect(0, 146204, '\P{^Is_Numeric_Value=+3}', "");
Error('\p{Is_Nv=:=  +0_0_03}');
Error('\P{Is_Nv=:=  +0_0_03}');
Expect(1, 146203, '\p{Is_Nv:   00_3}', "");
Expect(0, 146203, '\p{^Is_Nv:   00_3}', "");
Expect(0, 146203, '\P{Is_Nv:   00_3}', "");
Expect(1, 146203, '\P{^Is_Nv:   00_3}', "");
Expect(0, 146204, '\p{Is_Nv:   00_3}', "");
Expect(1, 146204, '\p{^Is_Nv:   00_3}', "");
Expect(1, 146204, '\P{Is_Nv:   00_3}', "");
Expect(0, 146204, '\P{^Is_Nv:   00_3}', "");
Error('\p{Numeric_Value=/a/		+00003/00016}');
Error('\P{Numeric_Value=/a/		+00003/00016}');
Expect(1, 43061, '\p{Numeric_Value:0000000003/0016}', "");
Expect(0, 43061, '\p{^Numeric_Value:0000000003/0016}', "");
Expect(0, 43061, '\P{Numeric_Value:0000000003/0016}', "");
Expect(1, 43061, '\P{^Numeric_Value:0000000003/0016}', "");
Expect(0, 43062, '\p{Numeric_Value:0000000003/0016}', "");
Expect(1, 43062, '\p{^Numeric_Value:0000000003/0016}', "");
Expect(1, 43062, '\P{Numeric_Value:0000000003/0016}', "");
Expect(0, 43062, '\P{^Numeric_Value:0000000003/0016}', "");
Error('\p{Numeric_Value=0.19}');
Error('\P{Numeric_Value=0.19}');
Expect(1, 43061, '\p{Numeric_Value=0.188}', "");
Expect(0, 43061, '\p{^Numeric_Value=0.188}', "");
Expect(0, 43061, '\P{Numeric_Value=0.188}', "");
Expect(1, 43061, '\P{^Numeric_Value=0.188}', "");
Expect(0, 43062, '\p{Numeric_Value=0.188}', "");
Expect(1, 43062, '\p{^Numeric_Value=0.188}', "");
Expect(1, 43062, '\P{Numeric_Value=0.188}', "");
Expect(0, 43062, '\P{^Numeric_Value=0.188}', "");
Error('\p{Nv=_00000003/000016:=}');
Error('\P{Nv=_00000003/000016:=}');
Expect(1, 43061, '\p{Nv=+000000003/0000016}', "");
Expect(0, 43061, '\p{^Nv=+000000003/0000016}', "");
Expect(0, 43061, '\P{Nv=+000000003/0000016}', "");
Expect(1, 43061, '\P{^Nv=+000000003/0000016}', "");
Expect(0, 43062, '\p{Nv=+000000003/0000016}', "");
Expect(1, 43062, '\p{^Nv=+000000003/0000016}', "");
Expect(1, 43062, '\P{Nv=+000000003/0000016}', "");
Expect(0, 43062, '\P{^Nv=+000000003/0000016}', "");
Error('\p{Nv=0.19}');
Error('\P{Nv=0.19}');
Expect(1, 43061, '\p{Nv=0.188}', "");
Expect(0, 43061, '\p{^Nv=0.188}', "");
Expect(0, 43061, '\P{Nv=0.188}', "");
Expect(1, 43061, '\P{^Nv=0.188}', "");
Expect(0, 43062, '\p{Nv=0.188}', "");
Expect(1, 43062, '\p{^Nv=0.188}', "");
Expect(1, 43062, '\P{Nv=0.188}', "");
Expect(0, 43062, '\P{^Nv=0.188}', "");
Error('\p{Is_Numeric_Value=/a/-_3/000016}');
Error('\P{Is_Numeric_Value=/a/-_3/000016}');
Expect(1, 43061, '\p{Is_Numeric_Value=+000000003/000016}', "");
Expect(0, 43061, '\p{^Is_Numeric_Value=+000000003/000016}', "");
Expect(0, 43061, '\P{Is_Numeric_Value=+000000003/000016}', "");
Expect(1, 43061, '\P{^Is_Numeric_Value=+000000003/000016}', "");
Expect(0, 43062, '\p{Is_Numeric_Value=+000000003/000016}', "");
Expect(1, 43062, '\p{^Is_Numeric_Value=+000000003/000016}', "");
Expect(1, 43062, '\P{Is_Numeric_Value=+000000003/000016}', "");
Expect(0, 43062, '\P{^Is_Numeric_Value=+000000003/000016}', "");
Error('\p{Is_Numeric_Value=0.19}');
Error('\P{Is_Numeric_Value=0.19}');
Expect(1, 43061, '\p{Is_Numeric_Value=0.188}', "");
Expect(0, 43061, '\p{^Is_Numeric_Value=0.188}', "");
Expect(0, 43061, '\P{Is_Numeric_Value=0.188}', "");
Expect(1, 43061, '\P{^Is_Numeric_Value=0.188}', "");
Expect(0, 43062, '\p{Is_Numeric_Value=0.188}', "");
Expect(1, 43062, '\p{^Is_Numeric_Value=0.188}', "");
Expect(1, 43062, '\P{Is_Numeric_Value=0.188}', "");
Expect(0, 43062, '\P{^Is_Numeric_Value=0.188}', "");
Error('\p{Is_Nv=-:=3/000016}');
Error('\P{Is_Nv=-:=3/000016}');
Expect(1, 43061, '\p{Is_Nv=+0000003/00000000016}', "");
Expect(0, 43061, '\p{^Is_Nv=+0000003/00000000016}', "");
Expect(0, 43061, '\P{Is_Nv=+0000003/00000000016}', "");
Expect(1, 43061, '\P{^Is_Nv=+0000003/00000000016}', "");
Expect(0, 43062, '\p{Is_Nv=+0000003/00000000016}', "");
Expect(1, 43062, '\p{^Is_Nv=+0000003/00000000016}', "");
Expect(1, 43062, '\P{Is_Nv=+0000003/00000000016}', "");
Expect(0, 43062, '\P{^Is_Nv=+0000003/00000000016}', "");
Error('\p{Is_Nv=0.19}');
Error('\P{Is_Nv=0.19}');
Expect(1, 43061, '\p{Is_Nv:0.188}', "");
Expect(0, 43061, '\p{^Is_Nv:0.188}', "");
Expect(0, 43061, '\P{Is_Nv:0.188}', "");
Expect(1, 43061, '\P{^Is_Nv:0.188}', "");
Expect(0, 43062, '\p{Is_Nv:0.188}', "");
Expect(1, 43062, '\p{^Is_Nv:0.188}', "");
Expect(1, 43062, '\P{Is_Nv:0.188}', "");
Expect(0, 43062, '\P{^Is_Nv:0.188}', "");
Error('\p{Numeric_Value= 0000000003/0002/a/}');
Error('\P{Numeric_Value= 0000000003/0002/a/}');
Expect(1, 3883, '\p{Numeric_Value:0000000003/0000000002}', "");
Expect(0, 3883, '\p{^Numeric_Value:0000000003/0000000002}', "");
Expect(0, 3883, '\P{Numeric_Value:0000000003/0000000002}', "");
Expect(1, 3883, '\P{^Numeric_Value:0000000003/0000000002}', "");
Expect(0, 3884, '\p{Numeric_Value:0000000003/0000000002}', "");
Expect(1, 3884, '\p{^Numeric_Value:0000000003/0000000002}', "");
Expect(1, 3884, '\P{Numeric_Value:0000000003/0000000002}', "");
Expect(0, 3884, '\P{^Numeric_Value:0000000003/0000000002}', "");
Expect(1, 3883, '\p{Numeric_Value=1.500}', "");
Expect(0, 3883, '\p{^Numeric_Value=1.500}', "");
Expect(0, 3883, '\P{Numeric_Value=1.500}', "");
Expect(1, 3883, '\P{^Numeric_Value=1.500}', "");
Expect(0, 3884, '\p{Numeric_Value=1.500}', "");
Expect(1, 3884, '\p{^Numeric_Value=1.500}', "");
Expect(1, 3884, '\P{Numeric_Value=1.500}', "");
Expect(0, 3884, '\P{^Numeric_Value=1.500}', "");
Error('\p{Nv=/a/-3/000002}');
Error('\P{Nv=/a/-3/000002}');
Expect(1, 3883, '\p{Nv=003/0000002}', "");
Expect(0, 3883, '\p{^Nv=003/0000002}', "");
Expect(0, 3883, '\P{Nv=003/0000002}', "");
Expect(1, 3883, '\P{^Nv=003/0000002}', "");
Expect(0, 3884, '\p{Nv=003/0000002}', "");
Expect(1, 3884, '\p{^Nv=003/0000002}', "");
Expect(1, 3884, '\P{Nv=003/0000002}', "");
Expect(0, 3884, '\P{^Nv=003/0000002}', "");
Expect(1, 3883, '\p{Nv=1.500}', "");
Expect(0, 3883, '\p{^Nv=1.500}', "");
Expect(0, 3883, '\P{Nv=1.500}', "");
Expect(1, 3883, '\P{^Nv=1.500}', "");
Expect(0, 3884, '\p{Nv=1.500}', "");
Expect(1, 3884, '\p{^Nv=1.500}', "");
Expect(1, 3884, '\P{Nv=1.500}', "");
Expect(0, 3884, '\P{^Nv=1.500}', "");
Error('\p{Is_Numeric_Value= /a/00000003/00000002}');
Error('\P{Is_Numeric_Value= /a/00000003/00000002}');
Expect(1, 3883, '\p{Is_Numeric_Value=0000003/00000002}', "");
Expect(0, 3883, '\p{^Is_Numeric_Value=0000003/00000002}', "");
Expect(0, 3883, '\P{Is_Numeric_Value=0000003/00000002}', "");
Expect(1, 3883, '\P{^Is_Numeric_Value=0000003/00000002}', "");
Expect(0, 3884, '\p{Is_Numeric_Value=0000003/00000002}', "");
Expect(1, 3884, '\p{^Is_Numeric_Value=0000003/00000002}', "");
Expect(1, 3884, '\P{Is_Numeric_Value=0000003/00000002}', "");
Expect(0, 3884, '\P{^Is_Numeric_Value=0000003/00000002}', "");
Expect(1, 3883, '\p{Is_Numeric_Value=1.500}', "");
Expect(0, 3883, '\p{^Is_Numeric_Value=1.500}', "");
Expect(0, 3883, '\P{Is_Numeric_Value=1.500}', "");
Expect(1, 3883, '\P{^Is_Numeric_Value=1.500}', "");
Expect(0, 3884, '\p{Is_Numeric_Value=1.500}', "");
Expect(1, 3884, '\p{^Is_Numeric_Value=1.500}', "");
Expect(1, 3884, '\P{Is_Numeric_Value=1.500}', "");
Expect(0, 3884, '\P{^Is_Numeric_Value=1.500}', "");
Error('\p{Is_Nv=/a/-003/0002}');
Error('\P{Is_Nv=/a/-003/0002}');
Expect(1, 3883, '\p{Is_Nv: 0000003/0002}', "");
Expect(0, 3883, '\p{^Is_Nv: 0000003/0002}', "");
Expect(0, 3883, '\P{Is_Nv: 0000003/0002}', "");
Expect(1, 3883, '\P{^Is_Nv: 0000003/0002}', "");
Expect(0, 3884, '\p{Is_Nv: 0000003/0002}', "");
Expect(1, 3884, '\p{^Is_Nv: 0000003/0002}', "");
Expect(1, 3884, '\P{Is_Nv: 0000003/0002}', "");
Expect(0, 3884, '\P{^Is_Nv: 0000003/0002}', "");
Expect(1, 3883, '\p{Is_Nv=1.500}', "");
Expect(0, 3883, '\p{^Is_Nv=1.500}', "");
Expect(0, 3883, '\P{Is_Nv=1.500}', "");
Expect(1, 3883, '\P{^Is_Nv=1.500}', "");
Expect(0, 3884, '\p{Is_Nv=1.500}', "");
Expect(1, 3884, '\p{^Is_Nv=1.500}', "");
Expect(1, 3884, '\P{Is_Nv=1.500}', "");
Expect(0, 3884, '\P{^Is_Nv=1.500}', "");
Error('\p{Numeric_Value=	/a/000003/000004}');
Error('\P{Numeric_Value=	/a/000003/000004}');
Expect(1, 65912, '\p{Numeric_Value=0000000003/00004}', "");
Expect(0, 65912, '\p{^Numeric_Value=0000000003/00004}', "");
Expect(0, 65912, '\P{Numeric_Value=0000000003/00004}', "");
Expect(1, 65912, '\P{^Numeric_Value=0000000003/00004}', "");
Expect(0, 65913, '\p{Numeric_Value=0000000003/00004}', "");
Expect(1, 65913, '\p{^Numeric_Value=0000000003/00004}', "");
Expect(1, 65913, '\P{Numeric_Value=0000000003/00004}', "");
Expect(0, 65913, '\P{^Numeric_Value=0000000003/00004}', "");
Expect(1, 65912, '\p{Numeric_Value=0.750}', "");
Expect(0, 65912, '\p{^Numeric_Value=0.750}', "");
Expect(0, 65912, '\P{Numeric_Value=0.750}', "");
Expect(1, 65912, '\P{^Numeric_Value=0.750}', "");
Expect(0, 65913, '\p{Numeric_Value=0.750}', "");
Expect(1, 65913, '\p{^Numeric_Value=0.750}', "");
Expect(1, 65913, '\P{Numeric_Value=0.750}', "");
Expect(0, 65913, '\P{^Numeric_Value=0.750}', "");
Error('\p{Nv=/a/-_00000003/004}');
Error('\P{Nv=/a/-_00000003/004}');
Expect(1, 65912, '\p{Nv=03/0000004}', "");
Expect(0, 65912, '\p{^Nv=03/0000004}', "");
Expect(0, 65912, '\P{Nv=03/0000004}', "");
Expect(1, 65912, '\P{^Nv=03/0000004}', "");
Expect(0, 65913, '\p{Nv=03/0000004}', "");
Expect(1, 65913, '\p{^Nv=03/0000004}', "");
Expect(1, 65913, '\P{Nv=03/0000004}', "");
Expect(0, 65913, '\P{^Nv=03/0000004}', "");
Expect(1, 65912, '\p{Nv=0.750}', "");
Expect(0, 65912, '\p{^Nv=0.750}', "");
Expect(0, 65912, '\P{Nv=0.750}', "");
Expect(1, 65912, '\P{^Nv=0.750}', "");
Expect(0, 65913, '\p{Nv=0.750}', "");
Expect(1, 65913, '\p{^Nv=0.750}', "");
Expect(1, 65913, '\P{Nv=0.750}', "");
Expect(0, 65913, '\P{^Nv=0.750}', "");
Error('\p{Is_Numeric_Value=	:=0000000003/0004}');
Error('\P{Is_Numeric_Value=	:=0000000003/0004}');
Expect(1, 65912, '\p{Is_Numeric_Value=003/4}', "");
Expect(0, 65912, '\p{^Is_Numeric_Value=003/4}', "");
Expect(0, 65912, '\P{Is_Numeric_Value=003/4}', "");
Expect(1, 65912, '\P{^Is_Numeric_Value=003/4}', "");
Expect(0, 65913, '\p{Is_Numeric_Value=003/4}', "");
Expect(1, 65913, '\p{^Is_Numeric_Value=003/4}', "");
Expect(1, 65913, '\P{Is_Numeric_Value=003/4}', "");
Expect(0, 65913, '\P{^Is_Numeric_Value=003/4}', "");
Expect(1, 65912, '\p{Is_Numeric_Value=0.750}', "");
Expect(0, 65912, '\p{^Is_Numeric_Value=0.750}', "");
Expect(0, 65912, '\P{Is_Numeric_Value=0.750}', "");
Expect(1, 65912, '\P{^Is_Numeric_Value=0.750}', "");
Expect(0, 65913, '\p{Is_Numeric_Value=0.750}', "");
Expect(1, 65913, '\p{^Is_Numeric_Value=0.750}', "");
Expect(1, 65913, '\P{Is_Numeric_Value=0.750}', "");
Expect(0, 65913, '\P{^Is_Numeric_Value=0.750}', "");
Error('\p{Is_Nv= 3/4/a/}');
Error('\P{Is_Nv= 3/4/a/}');
Expect(1, 65912, '\p{Is_Nv=0000003/04}', "");
Expect(0, 65912, '\p{^Is_Nv=0000003/04}', "");
Expect(0, 65912, '\P{Is_Nv=0000003/04}', "");
Expect(1, 65912, '\P{^Is_Nv=0000003/04}', "");
Expect(0, 65913, '\p{Is_Nv=0000003/04}', "");
Expect(1, 65913, '\p{^Is_Nv=0000003/04}', "");
Expect(1, 65913, '\P{Is_Nv=0000003/04}', "");
Expect(0, 65913, '\P{^Is_Nv=0000003/04}', "");
Expect(1, 65912, '\p{Is_Nv=0.750}', "");
Expect(0, 65912, '\p{^Is_Nv=0.750}', "");
Expect(0, 65912, '\P{Is_Nv=0.750}', "");
Expect(1, 65912, '\P{^Is_Nv=0.750}', "");
Expect(0, 65913, '\p{Is_Nv=0.750}', "");
Expect(1, 65913, '\p{^Is_Nv=0.750}', "");
Expect(1, 65913, '\P{Is_Nv=0.750}', "");
Expect(0, 65913, '\P{^Is_Nv=0.750}', "");
Error('\p{Numeric_Value:   -000000003/00005/a/}');
Error('\P{Numeric_Value:   -000000003/00005/a/}');
Expect(1, 8535, '\p{Numeric_Value=+0000000003/0005}', "");
Expect(0, 8535, '\p{^Numeric_Value=+0000000003/0005}', "");
Expect(0, 8535, '\P{Numeric_Value=+0000000003/0005}', "");
Expect(1, 8535, '\P{^Numeric_Value=+0000000003/0005}', "");
Expect(0, 8536, '\p{Numeric_Value=+0000000003/0005}', "");
Expect(1, 8536, '\p{^Numeric_Value=+0000000003/0005}', "");
Expect(1, 8536, '\P{Numeric_Value=+0000000003/0005}', "");
Expect(0, 8536, '\P{^Numeric_Value=+0000000003/0005}', "");
Expect(1, 8535, '\p{Numeric_Value=0.600}', "");
Expect(0, 8535, '\p{^Numeric_Value=0.600}', "");
Expect(0, 8535, '\P{Numeric_Value=0.600}', "");
Expect(1, 8535, '\P{^Numeric_Value=0.600}', "");
Expect(0, 8536, '\p{Numeric_Value=0.600}', "");
Expect(1, 8536, '\p{^Numeric_Value=0.600}', "");
Expect(1, 8536, '\P{Numeric_Value=0.600}', "");
Expect(0, 8536, '\P{^Numeric_Value=0.600}', "");
Error('\p{Nv:   :=+000000003/000005}');
Error('\P{Nv:   :=+000000003/000005}');
Expect(1, 8535, '\p{Nv=00000003/00005}', "");
Expect(0, 8535, '\p{^Nv=00000003/00005}', "");
Expect(0, 8535, '\P{Nv=00000003/00005}', "");
Expect(1, 8535, '\P{^Nv=00000003/00005}', "");
Expect(0, 8536, '\p{Nv=00000003/00005}', "");
Expect(1, 8536, '\p{^Nv=00000003/00005}', "");
Expect(1, 8536, '\P{Nv=00000003/00005}', "");
Expect(0, 8536, '\P{^Nv=00000003/00005}', "");
Expect(1, 8535, '\p{Nv:	0.600}', "");
Expect(0, 8535, '\p{^Nv:	0.600}', "");
Expect(0, 8535, '\P{Nv:	0.600}', "");
Expect(1, 8535, '\P{^Nv:	0.600}', "");
Expect(0, 8536, '\p{Nv:	0.600}', "");
Expect(1, 8536, '\p{^Nv:	0.600}', "");
Expect(1, 8536, '\P{Nv:	0.600}', "");
Expect(0, 8536, '\P{^Nv:	0.600}', "");
Error('\p{Is_Numeric_Value: /a/03/000000005}');
Error('\P{Is_Numeric_Value: /a/03/000000005}');
Expect(1, 8535, '\p{Is_Numeric_Value=00003/005}', "");
Expect(0, 8535, '\p{^Is_Numeric_Value=00003/005}', "");
Expect(0, 8535, '\P{Is_Numeric_Value=00003/005}', "");
Expect(1, 8535, '\P{^Is_Numeric_Value=00003/005}', "");
Expect(0, 8536, '\p{Is_Numeric_Value=00003/005}', "");
Expect(1, 8536, '\p{^Is_Numeric_Value=00003/005}', "");
Expect(1, 8536, '\P{Is_Numeric_Value=00003/005}', "");
Expect(0, 8536, '\P{^Is_Numeric_Value=00003/005}', "");
Expect(1, 8535, '\p{Is_Numeric_Value=0.600}', "");
Expect(0, 8535, '\p{^Is_Numeric_Value=0.600}', "");
Expect(0, 8535, '\P{Is_Numeric_Value=0.600}', "");
Expect(1, 8535, '\P{^Is_Numeric_Value=0.600}', "");
Expect(0, 8536, '\p{Is_Numeric_Value=0.600}', "");
Expect(1, 8536, '\p{^Is_Numeric_Value=0.600}', "");
Expect(1, 8536, '\P{Is_Numeric_Value=0.600}', "");
Expect(0, 8536, '\P{^Is_Numeric_Value=0.600}', "");
Error('\p{Is_Nv=:=_+03/05}');
Error('\P{Is_Nv=:=_+03/05}');
Expect(1, 8535, '\p{Is_Nv:0003/00000005}', "");
Expect(0, 8535, '\p{^Is_Nv:0003/00000005}', "");
Expect(0, 8535, '\P{Is_Nv:0003/00000005}', "");
Expect(1, 8535, '\P{^Is_Nv:0003/00000005}', "");
Expect(0, 8536, '\p{Is_Nv:0003/00000005}', "");
Expect(1, 8536, '\p{^Is_Nv:0003/00000005}', "");
Expect(1, 8536, '\P{Is_Nv:0003/00000005}', "");
Expect(0, 8536, '\P{^Is_Nv:0003/00000005}', "");
Expect(1, 8535, '\p{Is_Nv: 0.600}', "");
Expect(0, 8535, '\p{^Is_Nv: 0.600}', "");
Expect(0, 8535, '\P{Is_Nv: 0.600}', "");
Expect(1, 8535, '\P{^Is_Nv: 0.600}', "");
Expect(0, 8536, '\p{Is_Nv: 0.600}', "");
Expect(1, 8536, '\p{^Is_Nv: 0.600}', "");
Expect(1, 8536, '\P{Is_Nv: 0.600}', "");
Expect(0, 8536, '\P{^Is_Nv: 0.600}', "");
Error('\p{Numeric_Value=	-000000003/0008:=}');
Error('\P{Numeric_Value=	-000000003/0008:=}');
Expect(1, 8540, '\p{Numeric_Value=+003/00000008}', "");
Expect(0, 8540, '\p{^Numeric_Value=+003/00000008}', "");
Expect(0, 8540, '\P{Numeric_Value=+003/00000008}', "");
Expect(1, 8540, '\P{^Numeric_Value=+003/00000008}', "");
Expect(0, 8541, '\p{Numeric_Value=+003/00000008}', "");
Expect(1, 8541, '\p{^Numeric_Value=+003/00000008}', "");
Expect(1, 8541, '\P{Numeric_Value=+003/00000008}', "");
Expect(0, 8541, '\P{^Numeric_Value=+003/00000008}', "");
Error('\p{Numeric_Value=0.38}');
Error('\P{Numeric_Value=0.38}');
Expect(1, 8540, '\p{Numeric_Value=0.375}', "");
Expect(0, 8540, '\p{^Numeric_Value=0.375}', "");
Expect(0, 8540, '\P{Numeric_Value=0.375}', "");
Expect(1, 8540, '\P{^Numeric_Value=0.375}', "");
Expect(0, 8541, '\p{Numeric_Value=0.375}', "");
Expect(1, 8541, '\p{^Numeric_Value=0.375}', "");
Expect(1, 8541, '\P{Numeric_Value=0.375}', "");
Expect(0, 8541, '\P{^Numeric_Value=0.375}', "");
Error('\p{Nv=_-0000000003/000000008:=}');
Error('\P{Nv=_-0000000003/000000008:=}');
Expect(1, 8540, '\p{Nv=0000003/0000000008}', "");
Expect(0, 8540, '\p{^Nv=0000003/0000000008}', "");
Expect(0, 8540, '\P{Nv=0000003/0000000008}', "");
Expect(1, 8540, '\P{^Nv=0000003/0000000008}', "");
Expect(0, 8541, '\p{Nv=0000003/0000000008}', "");
Expect(1, 8541, '\p{^Nv=0000003/0000000008}', "");
Expect(1, 8541, '\P{Nv=0000003/0000000008}', "");
Expect(0, 8541, '\P{^Nv=0000003/0000000008}', "");
Error('\p{Nv:	0.38}');
Error('\P{Nv:	0.38}');
Expect(1, 8540, '\p{Nv=0.375}', "");
Expect(0, 8540, '\p{^Nv=0.375}', "");
Expect(0, 8540, '\P{Nv=0.375}', "");
Expect(1, 8540, '\P{^Nv=0.375}', "");
Expect(0, 8541, '\p{Nv=0.375}', "");
Expect(1, 8541, '\p{^Nv=0.375}', "");
Expect(1, 8541, '\P{Nv=0.375}', "");
Expect(0, 8541, '\P{^Nv=0.375}', "");
Error('\p{Is_Numeric_Value=-/a/+000000003/0000008}');
Error('\P{Is_Numeric_Value=-/a/+000000003/0000008}');
Expect(1, 8540, '\p{Is_Numeric_Value=3/000008}', "");
Expect(0, 8540, '\p{^Is_Numeric_Value=3/000008}', "");
Expect(0, 8540, '\P{Is_Numeric_Value=3/000008}', "");
Expect(1, 8540, '\P{^Is_Numeric_Value=3/000008}', "");
Expect(0, 8541, '\p{Is_Numeric_Value=3/000008}', "");
Expect(1, 8541, '\p{^Is_Numeric_Value=3/000008}', "");
Expect(1, 8541, '\P{Is_Numeric_Value=3/000008}', "");
Expect(0, 8541, '\P{^Is_Numeric_Value=3/000008}', "");
Error('\p{Is_Numeric_Value=0.38}');
Error('\P{Is_Numeric_Value=0.38}');
Expect(1, 8540, '\p{Is_Numeric_Value=0.375}', "");
Expect(0, 8540, '\p{^Is_Numeric_Value=0.375}', "");
Expect(0, 8540, '\P{Is_Numeric_Value=0.375}', "");
Expect(1, 8540, '\P{^Is_Numeric_Value=0.375}', "");
Expect(0, 8541, '\p{Is_Numeric_Value=0.375}', "");
Expect(1, 8541, '\p{^Is_Numeric_Value=0.375}', "");
Expect(1, 8541, '\P{Is_Numeric_Value=0.375}', "");
Expect(0, 8541, '\P{^Is_Numeric_Value=0.375}', "");
Error('\p{Is_Nv= :=3/000008}');
Error('\P{Is_Nv= :=3/000008}');
Expect(1, 8540, '\p{Is_Nv=0003/0000000008}', "");
Expect(0, 8540, '\p{^Is_Nv=0003/0000000008}', "");
Expect(0, 8540, '\P{Is_Nv=0003/0000000008}', "");
Expect(1, 8540, '\P{^Is_Nv=0003/0000000008}', "");
Expect(0, 8541, '\p{Is_Nv=0003/0000000008}', "");
Expect(1, 8541, '\p{^Is_Nv=0003/0000000008}', "");
Expect(1, 8541, '\P{Is_Nv=0003/0000000008}', "");
Expect(0, 8541, '\P{^Is_Nv=0003/0000000008}', "");
Error('\p{Is_Nv=0.38}');
Error('\P{Is_Nv=0.38}');
Expect(1, 8540, '\p{Is_Nv=0.375}', "");
Expect(0, 8540, '\p{^Is_Nv=0.375}', "");
Expect(0, 8540, '\P{Is_Nv=0.375}', "");
Expect(1, 8540, '\P{^Is_Nv=0.375}', "");
Expect(0, 8541, '\p{Is_Nv=0.375}', "");
Expect(1, 8541, '\p{^Is_Nv=0.375}', "");
Expect(1, 8541, '\P{Is_Nv=0.375}', "");
Expect(0, 8541, '\P{^Is_Nv=0.375}', "");
Error('\p{Numeric_Value=	00000030:=}');
Error('\P{Numeric_Value=	00000030:=}');
Expect(1, 133507, '\p{Numeric_Value: 0_0_0_0_0_030}', "");
Expect(0, 133507, '\p{^Numeric_Value: 0_0_0_0_0_030}', "");
Expect(0, 133507, '\P{Numeric_Value: 0_0_0_0_0_030}', "");
Expect(1, 133507, '\P{^Numeric_Value: 0_0_0_0_0_030}', "");
Expect(0, 133508, '\p{Numeric_Value: 0_0_0_0_0_030}', "");
Expect(1, 133508, '\p{^Numeric_Value: 0_0_0_0_0_030}', "");
Expect(1, 133508, '\P{Numeric_Value: 0_0_0_0_0_030}', "");
Expect(0, 133508, '\P{^Numeric_Value: 0_0_0_0_0_030}', "");
Error('\p{Nv=/a/ _03_0}');
Error('\P{Nv=/a/ _03_0}');
Expect(1, 133507, '\p{Nv=+00_00_00_00_30}', "");
Expect(0, 133507, '\p{^Nv=+00_00_00_00_30}', "");
Expect(0, 133507, '\P{Nv=+00_00_00_00_30}', "");
Expect(1, 133507, '\P{^Nv=+00_00_00_00_30}', "");
Expect(0, 133508, '\p{Nv=+00_00_00_00_30}', "");
Expect(1, 133508, '\p{^Nv=+00_00_00_00_30}', "");
Expect(1, 133508, '\P{Nv=+00_00_00_00_30}', "");
Expect(0, 133508, '\P{^Nv=+00_00_00_00_30}', "");
Error('\p{Is_Numeric_Value=:=-+00_03_0}');
Error('\P{Is_Numeric_Value=:=-+00_03_0}');
Expect(1, 133507, '\p{Is_Numeric_Value=000030}', "");
Expect(0, 133507, '\p{^Is_Numeric_Value=000030}', "");
Expect(0, 133507, '\P{Is_Numeric_Value=000030}', "");
Expect(1, 133507, '\P{^Is_Numeric_Value=000030}', "");
Expect(0, 133508, '\p{Is_Numeric_Value=000030}', "");
Expect(1, 133508, '\p{^Is_Numeric_Value=000030}', "");
Expect(1, 133508, '\P{Is_Numeric_Value=000030}', "");
Expect(0, 133508, '\P{^Is_Numeric_Value=000030}', "");
Error('\p{Is_Nv: /a/	-0_0_0_0_0_0_0_030}');
Error('\P{Is_Nv: /a/	-0_0_0_0_0_0_0_030}');
Expect(1, 133507, '\p{Is_Nv=+00000030}', "");
Expect(0, 133507, '\p{^Is_Nv=+00000030}', "");
Expect(0, 133507, '\P{Is_Nv=+00000030}', "");
Expect(1, 133507, '\P{^Is_Nv=+00000030}', "");
Expect(0, 133508, '\p{Is_Nv=+00000030}', "");
Expect(1, 133508, '\p{^Is_Nv=+00000030}', "");
Expect(1, 133508, '\P{Is_Nv=+00000030}', "");
Expect(0, 133508, '\P{^Is_Nv=+00000030}', "");
Error('\p{Numeric_Value: 	00_00_00_03_00:=}');
Error('\P{Numeric_Value: 	00_00_00_03_00:=}');
Expect(1, 69236, '\p{Numeric_Value=00300}', "");
Expect(0, 69236, '\p{^Numeric_Value=00300}', "");
Expect(0, 69236, '\P{Numeric_Value=00300}', "");
Expect(1, 69236, '\P{^Numeric_Value=00300}', "");
Expect(0, 69237, '\p{Numeric_Value=00300}', "");
Expect(1, 69237, '\p{^Numeric_Value=00300}', "");
Expect(1, 69237, '\P{Numeric_Value=00300}', "");
Expect(0, 69237, '\P{^Numeric_Value=00300}', "");
Error('\p{Nv= 0300:=}');
Error('\P{Nv= 0300:=}');
Expect(1, 69236, '\p{Nv=+0_0_0_0_0_0_0300}', "");
Expect(0, 69236, '\p{^Nv=+0_0_0_0_0_0_0300}', "");
Expect(0, 69236, '\P{Nv=+0_0_0_0_0_0_0300}', "");
Expect(1, 69236, '\P{^Nv=+0_0_0_0_0_0_0300}', "");
Expect(0, 69237, '\p{Nv=+0_0_0_0_0_0_0300}', "");
Expect(1, 69237, '\p{^Nv=+0_0_0_0_0_0_0300}', "");
Expect(1, 69237, '\P{Nv=+0_0_0_0_0_0_0300}', "");
Expect(0, 69237, '\P{^Nv=+0_0_0_0_0_0_0300}', "");
Error('\p{Is_Numeric_Value=-	00000300:=}');
Error('\P{Is_Numeric_Value=-	00000300:=}');
Expect(1, 69236, '\p{Is_Numeric_Value=000000000300}', "");
Expect(0, 69236, '\p{^Is_Numeric_Value=000000000300}', "");
Expect(0, 69236, '\P{Is_Numeric_Value=000000000300}', "");
Expect(1, 69236, '\P{^Is_Numeric_Value=000000000300}', "");
Expect(0, 69237, '\p{Is_Numeric_Value=000000000300}', "");
Expect(1, 69237, '\p{^Is_Numeric_Value=000000000300}', "");
Expect(1, 69237, '\P{Is_Numeric_Value=000000000300}', "");
Expect(0, 69237, '\P{^Is_Numeric_Value=000000000300}', "");
Error('\p{Is_Nv=:=000_000_000_300}');
Error('\P{Is_Nv=:=000_000_000_300}');
Expect(1, 69236, '\p{Is_Nv=000_000_000_300}', "");
Expect(0, 69236, '\p{^Is_Nv=000_000_000_300}', "");
Expect(0, 69236, '\P{Is_Nv=000_000_000_300}', "");
Expect(1, 69236, '\P{^Is_Nv=000_000_000_300}', "");
Expect(0, 69237, '\p{Is_Nv=000_000_000_300}', "");
Expect(1, 69237, '\p{^Is_Nv=000_000_000_300}', "");
Expect(1, 69237, '\P{Is_Nv=000_000_000_300}', "");
Expect(0, 69237, '\P{^Is_Nv=000_000_000_300}', "");
Error('\p{Numeric_Value=:=-+000003000}');
Error('\P{Numeric_Value=:=-+000003000}');
Expect(1, 65828, '\p{Numeric_Value:	+00000003000}', "");
Expect(0, 65828, '\p{^Numeric_Value:	+00000003000}', "");
Expect(0, 65828, '\P{Numeric_Value:	+00000003000}', "");
Expect(1, 65828, '\P{^Numeric_Value:	+00000003000}', "");
Expect(0, 65829, '\p{Numeric_Value:	+00000003000}', "");
Expect(1, 65829, '\p{^Numeric_Value:	+00000003000}', "");
Expect(1, 65829, '\P{Numeric_Value:	+00000003000}', "");
Expect(0, 65829, '\P{^Numeric_Value:	+00000003000}', "");
Error('\p{Nv=:=	 0_0_0_0_0_03000}');
Error('\P{Nv=:=	 0_0_0_0_0_03000}');
Expect(1, 65828, '\p{Nv=+003000}', "");
Expect(0, 65828, '\p{^Nv=+003000}', "");
Expect(0, 65828, '\P{Nv=+003000}', "");
Expect(1, 65828, '\P{^Nv=+003000}', "");
Expect(0, 65829, '\p{Nv=+003000}', "");
Expect(1, 65829, '\p{^Nv=+003000}', "");
Expect(1, 65829, '\P{Nv=+003000}', "");
Expect(0, 65829, '\P{^Nv=+003000}', "");
Error('\p{Is_Numeric_Value=	:=0003000}');
Error('\P{Is_Numeric_Value=	:=0003000}');
Expect(1, 65828, '\p{Is_Numeric_Value=000003000}', "");
Expect(0, 65828, '\p{^Is_Numeric_Value=000003000}', "");
Expect(0, 65828, '\P{Is_Numeric_Value=000003000}', "");
Expect(1, 65828, '\P{^Is_Numeric_Value=000003000}', "");
Expect(0, 65829, '\p{Is_Numeric_Value=000003000}', "");
Expect(1, 65829, '\p{^Is_Numeric_Value=000003000}', "");
Expect(1, 65829, '\P{Is_Numeric_Value=000003000}', "");
Expect(0, 65829, '\P{^Is_Numeric_Value=000003000}', "");
Error('\p{Is_Nv=	0000003000/a/}');
Error('\P{Is_Nv=	0000003000/a/}');
Expect(1, 65828, '\p{Is_Nv=3000}', "");
Expect(0, 65828, '\p{^Is_Nv=3000}', "");
Expect(0, 65828, '\P{Is_Nv=3000}', "");
Expect(1, 65828, '\P{^Is_Nv=3000}', "");
Expect(0, 65829, '\p{Is_Nv=3000}', "");
Expect(1, 65829, '\p{^Is_Nv=3000}', "");
Expect(1, 65829, '\P{Is_Nv=3000}', "");
Expect(0, 65829, '\P{^Is_Nv=3000}', "");
Error('\p{Numeric_Value=- 0_0_0_0_0_0_0_3_0_0_00/a/}');
Error('\P{Numeric_Value=- 0_0_0_0_0_0_0_3_0_0_00/a/}');
Expect(1, 65837, '\p{Numeric_Value=003_000_0}', "");
Expect(0, 65837, '\p{^Numeric_Value=003_000_0}', "");
Expect(0, 65837, '\P{Numeric_Value=003_000_0}', "");
Expect(1, 65837, '\P{^Numeric_Value=003_000_0}', "");
Expect(0, 65838, '\p{Numeric_Value=003_000_0}', "");
Expect(1, 65838, '\p{^Numeric_Value=003_000_0}', "");
Expect(1, 65838, '\P{Numeric_Value=003_000_0}', "");
Expect(0, 65838, '\P{^Numeric_Value=003_000_0}', "");
Error('\p{Nv=:=-	00000000030000}');
Error('\P{Nv=:=-	00000000030000}');
Expect(1, 65837, '\p{Nv=0000030000}', "");
Expect(0, 65837, '\p{^Nv=0000030000}', "");
Expect(0, 65837, '\P{Nv=0000030000}', "");
Expect(1, 65837, '\P{^Nv=0000030000}', "");
Expect(0, 65838, '\p{Nv=0000030000}', "");
Expect(1, 65838, '\p{^Nv=0000030000}', "");
Expect(1, 65838, '\P{Nv=0000030000}', "");
Expect(0, 65838, '\P{^Nv=0000030000}', "");
Error('\p{Is_Numeric_Value=		030000/a/}');
Error('\P{Is_Numeric_Value=		030000/a/}');
Expect(1, 65837, '\p{Is_Numeric_Value=030000}', "");
Expect(0, 65837, '\p{^Is_Numeric_Value=030000}', "");
Expect(0, 65837, '\P{Is_Numeric_Value=030000}', "");
Expect(1, 65837, '\P{^Is_Numeric_Value=030000}', "");
Expect(0, 65838, '\p{Is_Numeric_Value=030000}', "");
Expect(1, 65838, '\p{^Is_Numeric_Value=030000}', "");
Expect(1, 65838, '\P{Is_Numeric_Value=030000}', "");
Expect(0, 65838, '\P{^Is_Numeric_Value=030000}', "");
Error('\p{Is_Nv=-000_000_000_300_00/a/}');
Error('\P{Is_Nv=-000_000_000_300_00/a/}');
Expect(1, 65837, '\p{Is_Nv=030000}', "");
Expect(0, 65837, '\p{^Is_Nv=030000}', "");
Expect(0, 65837, '\P{Is_Nv=030000}', "");
Expect(1, 65837, '\P{^Is_Nv=030000}', "");
Expect(0, 65838, '\p{Is_Nv=030000}', "");
Expect(1, 65838, '\p{^Is_Nv=030000}', "");
Expect(1, 65838, '\P{Is_Nv=030000}', "");
Expect(0, 65838, '\P{^Is_Nv=030000}', "");
Error('\p{Numeric_Value= +00000031:=}');
Error('\P{Numeric_Value= +00000031:=}');
Expect(1, 12891, '\p{Numeric_Value=0_0_31}', "");
Expect(0, 12891, '\p{^Numeric_Value=0_0_31}', "");
Expect(0, 12891, '\P{Numeric_Value=0_0_31}', "");
Expect(1, 12891, '\P{^Numeric_Value=0_0_31}', "");
Expect(0, 12892, '\p{Numeric_Value=0_0_31}', "");
Expect(1, 12892, '\p{^Numeric_Value=0_0_31}', "");
Expect(1, 12892, '\P{Numeric_Value=0_0_31}', "");
Expect(0, 12892, '\P{^Numeric_Value=0_0_31}', "");
Error('\p{Nv=_:=0_0_0_0_0_031}');
Error('\P{Nv=_:=0_0_0_0_0_031}');
Expect(1, 12891, '\p{Nv: +0031}', "");
Expect(0, 12891, '\p{^Nv: +0031}', "");
Expect(0, 12891, '\P{Nv: +0031}', "");
Expect(1, 12891, '\P{^Nv: +0031}', "");
Expect(0, 12892, '\p{Nv: +0031}', "");
Expect(1, 12892, '\p{^Nv: +0031}', "");
Expect(1, 12892, '\P{Nv: +0031}', "");
Expect(0, 12892, '\P{^Nv: +0031}', "");
Error('\p{Is_Numeric_Value=/a/	00000000031}');
Error('\P{Is_Numeric_Value=/a/	00000000031}');
Expect(1, 12891, '\p{Is_Numeric_Value=00031}', "");
Expect(0, 12891, '\p{^Is_Numeric_Value=00031}', "");
Expect(0, 12891, '\P{Is_Numeric_Value=00031}', "");
Expect(1, 12891, '\P{^Is_Numeric_Value=00031}', "");
Expect(0, 12892, '\p{Is_Numeric_Value=00031}', "");
Expect(1, 12892, '\p{^Is_Numeric_Value=00031}', "");
Expect(1, 12892, '\P{Is_Numeric_Value=00031}', "");
Expect(0, 12892, '\P{^Is_Numeric_Value=00031}', "");
Error('\p{Is_Nv=-:=00003_1}');
Error('\P{Is_Nv=-:=00003_1}');
Expect(1, 12891, '\p{Is_Nv=0000000031}', "");
Expect(0, 12891, '\p{^Is_Nv=0000000031}', "");
Expect(0, 12891, '\P{Is_Nv=0000000031}', "");
Expect(1, 12891, '\P{^Is_Nv=0000000031}', "");
Expect(0, 12892, '\p{Is_Nv=0000000031}', "");
Expect(1, 12892, '\p{^Is_Nv=0000000031}', "");
Expect(1, 12892, '\P{Is_Nv=0000000031}', "");
Expect(0, 12892, '\P{^Is_Nv=0000000031}', "");
Error('\p{Numeric_Value= -003_2/a/}');
Error('\P{Numeric_Value= -003_2/a/}');
Expect(1, 12892, '\p{Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(0, 12892, '\p{^Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(0, 12892, '\P{Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(1, 12892, '\P{^Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(0, 12893, '\p{Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(1, 12893, '\p{^Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(1, 12893, '\P{Numeric_Value=+0_0_0_0_0_0_00032}', "");
Expect(0, 12893, '\P{^Numeric_Value=+0_0_0_0_0_0_00032}', "");
Error('\p{Nv=:=-00000000032}');
Error('\P{Nv=:=-00000000032}');
Expect(1, 12892, '\p{Nv=0_0_0_0_0_0_0_0032}', "");
Expect(0, 12892, '\p{^Nv=0_0_0_0_0_0_0_0032}', "");
Expect(0, 12892, '\P{Nv=0_0_0_0_0_0_0_0032}', "");
Expect(1, 12892, '\P{^Nv=0_0_0_0_0_0_0_0032}', "");
Expect(0, 12893, '\p{Nv=0_0_0_0_0_0_0_0032}', "");
Expect(1, 12893, '\p{^Nv=0_0_0_0_0_0_0_0032}', "");
Expect(1, 12893, '\P{Nv=0_0_0_0_0_0_0_0032}', "");
Expect(0, 12893, '\P{^Nv=0_0_0_0_0_0_0_0032}', "");
Error('\p{Is_Numeric_Value:  -00000032/a/}');
Error('\P{Is_Numeric_Value:  -00000032/a/}');
Expect(1, 12892, '\p{Is_Numeric_Value=+000032}', "");
Expect(0, 12892, '\p{^Is_Numeric_Value=+000032}', "");
Expect(0, 12892, '\P{Is_Numeric_Value=+000032}', "");
Expect(1, 12892, '\P{^Is_Numeric_Value=+000032}', "");
Expect(0, 12893, '\p{Is_Numeric_Value=+000032}', "");
Expect(1, 12893, '\p{^Is_Numeric_Value=+000032}', "");
Expect(1, 12893, '\P{Is_Numeric_Value=+000032}', "");
Expect(0, 12893, '\P{^Is_Numeric_Value=+000032}', "");
Error('\p{Is_Nv=/a/--0_0_0_0_0_0_0_032}');
Error('\P{Is_Nv=/a/--0_0_0_0_0_0_0_032}');
Expect(1, 12892, '\p{Is_Nv=0000000032}', "");
Expect(0, 12892, '\p{^Is_Nv=0000000032}', "");
Expect(0, 12892, '\P{Is_Nv=0000000032}', "");
Expect(1, 12892, '\P{^Is_Nv=0000000032}', "");
Expect(0, 12893, '\p{Is_Nv=0000000032}', "");
Expect(1, 12893, '\p{^Is_Nv=0000000032}', "");
Expect(1, 12893, '\P{Is_Nv=0000000032}', "");
Expect(0, 12893, '\P{^Is_Nv=0000000032}', "");
Error('\p{Numeric_Value:   /a/ +3_3}');
Error('\P{Numeric_Value:   /a/ +3_3}');
Expect(1, 12893, '\p{Numeric_Value: 0000033}', "");
Expect(0, 12893, '\p{^Numeric_Value: 0000033}', "");
Expect(0, 12893, '\P{Numeric_Value: 0000033}', "");
Expect(1, 12893, '\P{^Numeric_Value: 0000033}', "");
Expect(0, 12894, '\p{Numeric_Value: 0000033}', "");
Expect(1, 12894, '\p{^Numeric_Value: 0000033}', "");
Expect(1, 12894, '\P{Numeric_Value: 0000033}', "");
Expect(0, 12894, '\P{^Numeric_Value: 0000033}', "");
Error('\p{Nv:   :=	000003_3}');
Error('\P{Nv:   :=	000003_3}');
Expect(1, 12893, '\p{Nv=00000033}', "");
Expect(0, 12893, '\p{^Nv=00000033}', "");
Expect(0, 12893, '\P{Nv=00000033}', "");
Expect(1, 12893, '\P{^Nv=00000033}', "");
Expect(0, 12894, '\p{Nv=00000033}', "");
Expect(1, 12894, '\p{^Nv=00000033}', "");
Expect(1, 12894, '\P{Nv=00000033}', "");
Expect(0, 12894, '\P{^Nv=00000033}', "");
Error('\p{Is_Numeric_Value=	:=33}');
Error('\P{Is_Numeric_Value=	:=33}');
Expect(1, 12893, '\p{Is_Numeric_Value:003_3}', "");
Expect(0, 12893, '\p{^Is_Numeric_Value:003_3}', "");
Expect(0, 12893, '\P{Is_Numeric_Value:003_3}', "");
Expect(1, 12893, '\P{^Is_Numeric_Value:003_3}', "");
Expect(0, 12894, '\p{Is_Numeric_Value:003_3}', "");
Expect(1, 12894, '\p{^Is_Numeric_Value:003_3}', "");
Expect(1, 12894, '\P{Is_Numeric_Value:003_3}', "");
Expect(0, 12894, '\P{^Is_Numeric_Value:003_3}', "");
Error('\p{Is_Nv=:=-0_0_0_0_0_0_0_33}');
Error('\P{Is_Nv=:=-0_0_0_0_0_0_0_33}');
Expect(1, 12893, '\p{Is_Nv=00_00_00_00_033}', "");
Expect(0, 12893, '\p{^Is_Nv=00_00_00_00_033}', "");
Expect(0, 12893, '\P{Is_Nv=00_00_00_00_033}', "");
Expect(1, 12893, '\P{^Is_Nv=00_00_00_00_033}', "");
Expect(0, 12894, '\p{Is_Nv=00_00_00_00_033}', "");
Expect(1, 12894, '\p{^Is_Nv=00_00_00_00_033}', "");
Expect(1, 12894, '\P{Is_Nv=00_00_00_00_033}', "");
Expect(0, 12894, '\P{^Is_Nv=00_00_00_00_033}', "");
Error('\p{Numeric_Value=		0_0_0_0_0_34/a/}');
Error('\P{Numeric_Value=		0_0_0_0_0_34/a/}');
Expect(1, 12894, '\p{Numeric_Value=00000000034}', "");
Expect(0, 12894, '\p{^Numeric_Value=00000000034}', "");
Expect(0, 12894, '\P{Numeric_Value=00000000034}', "");
Expect(1, 12894, '\P{^Numeric_Value=00000000034}', "");
Expect(0, 12895, '\p{Numeric_Value=00000000034}', "");
Expect(1, 12895, '\p{^Numeric_Value=00000000034}', "");
Expect(1, 12895, '\P{Numeric_Value=00000000034}', "");
Expect(0, 12895, '\P{^Numeric_Value=00000000034}', "");
Error('\p{Nv= :=0034}');
Error('\P{Nv= :=0034}');
Expect(1, 12894, '\p{Nv=+00_00_03_4}', "");
Expect(0, 12894, '\p{^Nv=+00_00_03_4}', "");
Expect(0, 12894, '\P{Nv=+00_00_03_4}', "");
Expect(1, 12894, '\P{^Nv=+00_00_03_4}', "");
Expect(0, 12895, '\p{Nv=+00_00_03_4}', "");
Expect(1, 12895, '\p{^Nv=+00_00_03_4}', "");
Expect(1, 12895, '\P{Nv=+00_00_03_4}', "");
Expect(0, 12895, '\P{^Nv=+00_00_03_4}', "");
Error('\p{Is_Numeric_Value=--00_00_03_4:=}');
Error('\P{Is_Numeric_Value=--00_00_03_4:=}');
Expect(1, 12894, '\p{Is_Numeric_Value=0_0_0_034}', "");
Expect(0, 12894, '\p{^Is_Numeric_Value=0_0_0_034}', "");
Expect(0, 12894, '\P{Is_Numeric_Value=0_0_0_034}', "");
Expect(1, 12894, '\P{^Is_Numeric_Value=0_0_0_034}', "");
Expect(0, 12895, '\p{Is_Numeric_Value=0_0_0_034}', "");
Expect(1, 12895, '\p{^Is_Numeric_Value=0_0_0_034}', "");
Expect(1, 12895, '\P{Is_Numeric_Value=0_0_0_034}', "");
Expect(0, 12895, '\P{^Is_Numeric_Value=0_0_0_034}', "");
Error('\p{Is_Nv=:=-0_0_0_0_34}');
Error('\P{Is_Nv=:=-0_0_0_0_34}');
Expect(1, 12894, '\p{Is_Nv=00000034}', "");
Expect(0, 12894, '\p{^Is_Nv=00000034}', "");
Expect(0, 12894, '\P{Is_Nv=00000034}', "");
Expect(1, 12894, '\P{^Is_Nv=00000034}', "");
Expect(0, 12895, '\p{Is_Nv=00000034}', "");
Expect(1, 12895, '\p{^Is_Nv=00000034}', "");
Expect(1, 12895, '\P{Is_Nv=00000034}', "");
Expect(0, 12895, '\P{^Is_Nv=00000034}', "");
Error('\p{Numeric_Value:    -03_5:=}');
Error('\P{Numeric_Value:    -03_5:=}');
Expect(1, 12895, '\p{Numeric_Value=+0000035}', "");
Expect(0, 12895, '\p{^Numeric_Value=+0000035}', "");
Expect(0, 12895, '\P{Numeric_Value=+0000035}', "");
Expect(1, 12895, '\P{^Numeric_Value=+0000035}', "");
Expect(0, 12896, '\p{Numeric_Value=+0000035}', "");
Expect(1, 12896, '\p{^Numeric_Value=+0000035}', "");
Expect(1, 12896, '\P{Numeric_Value=+0000035}', "");
Expect(0, 12896, '\P{^Numeric_Value=+0000035}', "");
Error('\p{Nv=/a/ +000035}');
Error('\P{Nv=/a/ +000035}');
Expect(1, 12895, '\p{Nv=00000000035}', "");
Expect(0, 12895, '\p{^Nv=00000000035}', "");
Expect(0, 12895, '\P{Nv=00000000035}', "");
Expect(1, 12895, '\P{^Nv=00000000035}', "");
Expect(0, 12896, '\p{Nv=00000000035}', "");
Expect(1, 12896, '\p{^Nv=00000000035}', "");
Expect(1, 12896, '\P{Nv=00000000035}', "");
Expect(0, 12896, '\P{^Nv=00000000035}', "");
Error('\p{Is_Numeric_Value:	/a/0_0_0_0_0_0035}');
Error('\P{Is_Numeric_Value:	/a/0_0_0_0_0_0035}');
Expect(1, 12895, '\p{Is_Numeric_Value=0000000035}', "");
Expect(0, 12895, '\p{^Is_Numeric_Value=0000000035}', "");
Expect(0, 12895, '\P{Is_Numeric_Value=0000000035}', "");
Expect(1, 12895, '\P{^Is_Numeric_Value=0000000035}', "");
Expect(0, 12896, '\p{Is_Numeric_Value=0000000035}', "");
Expect(1, 12896, '\p{^Is_Numeric_Value=0000000035}', "");
Expect(1, 12896, '\P{Is_Numeric_Value=0000000035}', "");
Expect(0, 12896, '\P{^Is_Numeric_Value=0000000035}', "");
Error('\p{Is_Nv=_/a/3_5}');
Error('\P{Is_Nv=_/a/3_5}');
Expect(1, 12895, '\p{Is_Nv=+03_5}', "");
Expect(0, 12895, '\p{^Is_Nv=+03_5}', "");
Expect(0, 12895, '\P{Is_Nv=+03_5}', "");
Expect(1, 12895, '\P{^Is_Nv=+03_5}', "");
Expect(0, 12896, '\p{Is_Nv=+03_5}', "");
Expect(1, 12896, '\p{^Is_Nv=+03_5}', "");
Expect(1, 12896, '\P{Is_Nv=+03_5}', "");
Expect(0, 12896, '\P{^Is_Nv=+03_5}', "");
Error('\p{Numeric_Value= /a/00000000036}');
Error('\P{Numeric_Value= /a/00000000036}');
Expect(1, 12977, '\p{Numeric_Value=0000036}', "");
Expect(0, 12977, '\p{^Numeric_Value=0000036}', "");
Expect(0, 12977, '\P{Numeric_Value=0000036}', "");
Expect(1, 12977, '\P{^Numeric_Value=0000036}', "");
Expect(0, 12978, '\p{Numeric_Value=0000036}', "");
Expect(1, 12978, '\p{^Numeric_Value=0000036}', "");
Expect(1, 12978, '\P{Numeric_Value=0000036}', "");
Expect(0, 12978, '\P{^Numeric_Value=0000036}', "");
Error('\p{Nv= :=0036}');
Error('\P{Nv= :=0036}');
Expect(1, 12977, '\p{Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(0, 12977, '\p{^Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(0, 12977, '\P{Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(1, 12977, '\P{^Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(0, 12978, '\p{Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(1, 12978, '\p{^Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(1, 12978, '\P{Nv=0_0_0_0_0_0_0_0_036}', "");
Expect(0, 12978, '\P{^Nv=0_0_0_0_0_0_0_0_036}', "");
Error('\p{Is_Numeric_Value=:=	 000_000_36}');
Error('\P{Is_Numeric_Value=:=	 000_000_36}');
Expect(1, 12977, '\p{Is_Numeric_Value=0000000036}', "");
Expect(0, 12977, '\p{^Is_Numeric_Value=0000000036}', "");
Expect(0, 12977, '\P{Is_Numeric_Value=0000000036}', "");
Expect(1, 12977, '\P{^Is_Numeric_Value=0000000036}', "");
Expect(0, 12978, '\p{Is_Numeric_Value=0000000036}', "");
Expect(1, 12978, '\p{^Is_Numeric_Value=0000000036}', "");
Expect(1, 12978, '\P{Is_Numeric_Value=0000000036}', "");
Expect(0, 12978, '\P{^Is_Numeric_Value=0000000036}', "");
Error('\p{Is_Nv=-/a/0_0_0_0_36}');
Error('\P{Is_Nv=-/a/0_0_0_0_36}');
Expect(1, 12977, '\p{Is_Nv=+000036}', "");
Expect(0, 12977, '\p{^Is_Nv=+000036}', "");
Expect(0, 12977, '\P{Is_Nv=+000036}', "");
Expect(1, 12977, '\P{^Is_Nv=+000036}', "");
Expect(0, 12978, '\p{Is_Nv=+000036}', "");
Expect(1, 12978, '\p{^Is_Nv=+000036}', "");
Expect(1, 12978, '\P{Is_Nv=+000036}', "");
Expect(0, 12978, '\P{^Is_Nv=+000036}', "");
Error('\p{Numeric_Value=_:=0_0_0_037}');
Error('\P{Numeric_Value=_:=0_0_0_037}');
Expect(1, 12978, '\p{Numeric_Value=0_0_0_037}', "");
Expect(0, 12978, '\p{^Numeric_Value=0_0_0_037}', "");
Expect(0, 12978, '\P{Numeric_Value=0_0_0_037}', "");
Expect(1, 12978, '\P{^Numeric_Value=0_0_0_037}', "");
Expect(0, 12979, '\p{Numeric_Value=0_0_0_037}', "");
Expect(1, 12979, '\p{^Numeric_Value=0_0_0_037}', "");
Expect(1, 12979, '\P{Numeric_Value=0_0_0_037}', "");
Expect(0, 12979, '\P{^Numeric_Value=0_0_0_037}', "");
Error('\p{Nv=-000_003_7/a/}');
Error('\P{Nv=-000_003_7/a/}');
Expect(1, 12978, '\p{Nv=00000037}', "");
Expect(0, 12978, '\p{^Nv=00000037}', "");
Expect(0, 12978, '\P{Nv=00000037}', "");
Expect(1, 12978, '\P{^Nv=00000037}', "");
Expect(0, 12979, '\p{Nv=00000037}', "");
Expect(1, 12979, '\p{^Nv=00000037}', "");
Expect(1, 12979, '\P{Nv=00000037}', "");
Expect(0, 12979, '\P{^Nv=00000037}', "");
Error('\p{Is_Numeric_Value: _:=000037}');
Error('\P{Is_Numeric_Value: _:=000037}');
Expect(1, 12978, '\p{Is_Numeric_Value=00_00_00_00_37}', "");
Expect(0, 12978, '\p{^Is_Numeric_Value=00_00_00_00_37}', "");
Expect(0, 12978, '\P{Is_Numeric_Value=00_00_00_00_37}', "");
Expect(1, 12978, '\P{^Is_Numeric_Value=00_00_00_00_37}', "");
Expect(0, 12979, '\p{Is_Numeric_Value=00_00_00_00_37}', "");
Expect(1, 12979, '\p{^Is_Numeric_Value=00_00_00_00_37}', "");
Expect(1, 12979, '\P{Is_Numeric_Value=00_00_00_00_37}', "");
Expect(0, 12979, '\P{^Is_Numeric_Value=00_00_00_00_37}', "");
Error('\p{Is_Nv=	:=003_7}');
Error('\P{Is_Nv=	:=003_7}');
Expect(1, 12978, '\p{Is_Nv: +000_000_000_37}', "");
Expect(0, 12978, '\p{^Is_Nv: +000_000_000_37}', "");
Expect(0, 12978, '\P{Is_Nv: +000_000_000_37}', "");
Expect(1, 12978, '\P{^Is_Nv: +000_000_000_37}', "");
Expect(0, 12979, '\p{Is_Nv: +000_000_000_37}', "");
Expect(1, 12979, '\p{^Is_Nv: +000_000_000_37}', "");
Expect(1, 12979, '\P{Is_Nv: +000_000_000_37}', "");
Expect(0, 12979, '\P{^Is_Nv: +000_000_000_37}', "");
Error('\p{Numeric_Value=_ 000000038:=}');
Error('\P{Numeric_Value=_ 000000038:=}');
Expect(1, 12979, '\p{Numeric_Value=0038}', "");
Expect(0, 12979, '\p{^Numeric_Value=0038}', "");
Expect(0, 12979, '\P{Numeric_Value=0038}', "");
Expect(1, 12979, '\P{^Numeric_Value=0038}', "");
Expect(0, 12980, '\p{Numeric_Value=0038}', "");
Expect(1, 12980, '\p{^Numeric_Value=0038}', "");
Expect(1, 12980, '\P{Numeric_Value=0038}', "");
Expect(0, 12980, '\P{^Numeric_Value=0038}', "");
Error('\p{Nv:   /a/00_00_00_038}');
Error('\P{Nv:   /a/00_00_00_038}');
Expect(1, 12979, '\p{Nv=03_8}', "");
Expect(0, 12979, '\p{^Nv=03_8}', "");
Expect(0, 12979, '\P{Nv=03_8}', "");
Expect(1, 12979, '\P{^Nv=03_8}', "");
Expect(0, 12980, '\p{Nv=03_8}', "");
Expect(1, 12980, '\p{^Nv=03_8}', "");
Expect(1, 12980, '\P{Nv=03_8}', "");
Expect(0, 12980, '\P{^Nv=03_8}', "");
Error('\p{Is_Numeric_Value=:=- +38}');
Error('\P{Is_Numeric_Value=:=- +38}');
Expect(1, 12979, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(0, 12979, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(0, 12979, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(1, 12979, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(0, 12980, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(1, 12980, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(1, 12980, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Expect(0, 12980, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_038}', "");
Error('\p{Is_Nv= :=0000038}');
Error('\P{Is_Nv= :=0000038}');
Expect(1, 12979, '\p{Is_Nv=03_8}', "");
Expect(0, 12979, '\p{^Is_Nv=03_8}', "");
Expect(0, 12979, '\P{Is_Nv=03_8}', "");
Expect(1, 12979, '\P{^Is_Nv=03_8}', "");
Expect(0, 12980, '\p{Is_Nv=03_8}', "");
Expect(1, 12980, '\p{^Is_Nv=03_8}', "");
Expect(1, 12980, '\P{Is_Nv=03_8}', "");
Expect(0, 12980, '\P{^Is_Nv=03_8}', "");
Error('\p{Numeric_Value=:= 	0000000039}');
Error('\P{Numeric_Value=:= 	0000000039}');
Expect(1, 12980, '\p{Numeric_Value=00_00_00_039}', "");
Expect(0, 12980, '\p{^Numeric_Value=00_00_00_039}', "");
Expect(0, 12980, '\P{Numeric_Value=00_00_00_039}', "");
Expect(1, 12980, '\P{^Numeric_Value=00_00_00_039}', "");
Expect(0, 12981, '\p{Numeric_Value=00_00_00_039}', "");
Expect(1, 12981, '\p{^Numeric_Value=00_00_00_039}', "");
Expect(1, 12981, '\P{Numeric_Value=00_00_00_039}', "");
Expect(0, 12981, '\P{^Numeric_Value=00_00_00_039}', "");
Error('\p{Nv:	 _00_00_39:=}');
Error('\P{Nv:	 _00_00_39:=}');
Expect(1, 12980, '\p{Nv=+00_00_00_00_39}', "");
Expect(0, 12980, '\p{^Nv=+00_00_00_00_39}', "");
Expect(0, 12980, '\P{Nv=+00_00_00_00_39}', "");
Expect(1, 12980, '\P{^Nv=+00_00_00_00_39}', "");
Expect(0, 12981, '\p{Nv=+00_00_00_00_39}', "");
Expect(1, 12981, '\p{^Nv=+00_00_00_00_39}', "");
Expect(1, 12981, '\P{Nv=+00_00_00_00_39}', "");
Expect(0, 12981, '\P{^Nv=+00_00_00_00_39}', "");
Error('\p{Is_Numeric_Value=_:=+03_9}');
Error('\P{Is_Numeric_Value=_:=+03_9}');
Expect(1, 12980, '\p{Is_Numeric_Value=00000039}', "");
Expect(0, 12980, '\p{^Is_Numeric_Value=00000039}', "");
Expect(0, 12980, '\P{Is_Numeric_Value=00000039}', "");
Expect(1, 12980, '\P{^Is_Numeric_Value=00000039}', "");
Expect(0, 12981, '\p{Is_Numeric_Value=00000039}', "");
Expect(1, 12981, '\p{^Is_Numeric_Value=00000039}', "");
Expect(1, 12981, '\P{Is_Numeric_Value=00000039}', "");
Expect(0, 12981, '\P{^Is_Numeric_Value=00000039}', "");
Error('\p{Is_Nv=:=_0003_9}');
Error('\P{Is_Nv=:=_0003_9}');
Expect(1, 12980, '\p{Is_Nv=+0000039}', "");
Expect(0, 12980, '\p{^Is_Nv=+0000039}', "");
Expect(0, 12980, '\P{Is_Nv=+0000039}', "");
Expect(1, 12980, '\P{^Is_Nv=+0000039}', "");
Expect(0, 12981, '\p{Is_Nv=+0000039}', "");
Expect(1, 12981, '\p{^Is_Nv=+0000039}', "");
Expect(1, 12981, '\P{Is_Nv=+0000039}', "");
Expect(0, 12981, '\P{^Is_Nv=+0000039}', "");
Error('\p{Numeric_Value=_00004/a/}');
Error('\P{Numeric_Value=_00004/a/}');
Expect(1, 156269, '\p{Numeric_Value=0000004}', "");
Expect(0, 156269, '\p{^Numeric_Value=0000004}', "");
Expect(0, 156269, '\P{Numeric_Value=0000004}', "");
Expect(1, 156269, '\P{^Numeric_Value=0000004}', "");
Expect(0, 156270, '\p{Numeric_Value=0000004}', "");
Expect(1, 156270, '\p{^Numeric_Value=0000004}', "");
Expect(1, 156270, '\P{Numeric_Value=0000004}', "");
Expect(0, 156270, '\P{^Numeric_Value=0000004}', "");
Error('\p{Nv= /a/0_0_0_0_0004}');
Error('\P{Nv= /a/0_0_0_0_0004}');
Expect(1, 156269, '\p{Nv=00004}', "");
Expect(0, 156269, '\p{^Nv=00004}', "");
Expect(0, 156269, '\P{Nv=00004}', "");
Expect(1, 156269, '\P{^Nv=00004}', "");
Expect(0, 156270, '\p{Nv=00004}', "");
Expect(1, 156270, '\p{^Nv=00004}', "");
Expect(1, 156270, '\P{Nv=00004}', "");
Expect(0, 156270, '\P{^Nv=00004}', "");
Error('\p{Is_Numeric_Value=/a/		00004}');
Error('\P{Is_Numeric_Value=/a/		00004}');
Expect(1, 156269, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(0, 156269, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(0, 156269, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(1, 156269, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(0, 156270, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(1, 156270, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(1, 156270, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Expect(0, 156270, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_004}', "");
Error('\p{Is_Nv=:=- 0_0_0_0_0_0_04}');
Error('\P{Is_Nv=:=- 0_0_0_0_0_0_04}');
Expect(1, 156269, '\p{Is_Nv=00_00_4}', "");
Expect(0, 156269, '\p{^Is_Nv=00_00_4}', "");
Expect(0, 156269, '\P{Is_Nv=00_00_4}', "");
Expect(1, 156269, '\P{^Is_Nv=00_00_4}', "");
Expect(0, 156270, '\p{Is_Nv=00_00_4}', "");
Expect(1, 156270, '\p{^Is_Nv=00_00_4}', "");
Expect(1, 156270, '\P{Is_Nv=00_00_4}', "");
Expect(0, 156270, '\P{^Is_Nv=00_00_4}', "");
Error('\p{Numeric_Value=:=--4/0000000005}');
Error('\P{Numeric_Value=:=--4/0000000005}');
Expect(1, 8536, '\p{Numeric_Value=00000004/0000000005}', "");
Expect(0, 8536, '\p{^Numeric_Value=00000004/0000000005}', "");
Expect(0, 8536, '\P{Numeric_Value=00000004/0000000005}', "");
Expect(1, 8536, '\P{^Numeric_Value=00000004/0000000005}', "");
Expect(0, 8537, '\p{Numeric_Value=00000004/0000000005}', "");
Expect(1, 8537, '\p{^Numeric_Value=00000004/0000000005}', "");
Expect(1, 8537, '\P{Numeric_Value=00000004/0000000005}', "");
Expect(0, 8537, '\P{^Numeric_Value=00000004/0000000005}', "");
Expect(1, 8536, '\p{Numeric_Value=0.800}', "");
Expect(0, 8536, '\p{^Numeric_Value=0.800}', "");
Expect(0, 8536, '\P{Numeric_Value=0.800}', "");
Expect(1, 8536, '\P{^Numeric_Value=0.800}', "");
Expect(0, 8537, '\p{Numeric_Value=0.800}', "");
Expect(1, 8537, '\p{^Numeric_Value=0.800}', "");
Expect(1, 8537, '\P{Numeric_Value=0.800}', "");
Expect(0, 8537, '\P{^Numeric_Value=0.800}', "");
Error('\p{Nv=/a/- 004/000000005}');
Error('\P{Nv=/a/- 004/000000005}');
Expect(1, 8536, '\p{Nv=04/5}', "");
Expect(0, 8536, '\p{^Nv=04/5}', "");
Expect(0, 8536, '\P{Nv=04/5}', "");
Expect(1, 8536, '\P{^Nv=04/5}', "");
Expect(0, 8537, '\p{Nv=04/5}', "");
Expect(1, 8537, '\p{^Nv=04/5}', "");
Expect(1, 8537, '\P{Nv=04/5}', "");
Expect(0, 8537, '\P{^Nv=04/5}', "");
Expect(1, 8536, '\p{Nv=0.800}', "");
Expect(0, 8536, '\p{^Nv=0.800}', "");
Expect(0, 8536, '\P{Nv=0.800}', "");
Expect(1, 8536, '\P{^Nv=0.800}', "");
Expect(0, 8537, '\p{Nv=0.800}', "");
Expect(1, 8537, '\p{^Nv=0.800}', "");
Expect(1, 8537, '\P{Nv=0.800}', "");
Expect(0, 8537, '\P{^Nv=0.800}', "");
Error('\p{Is_Numeric_Value=_ 0000000004/0000005/a/}');
Error('\P{Is_Numeric_Value=_ 0000000004/0000005/a/}');
Expect(1, 8536, '\p{Is_Numeric_Value=+04/5}', "");
Expect(0, 8536, '\p{^Is_Numeric_Value=+04/5}', "");
Expect(0, 8536, '\P{Is_Numeric_Value=+04/5}', "");
Expect(1, 8536, '\P{^Is_Numeric_Value=+04/5}', "");
Expect(0, 8537, '\p{Is_Numeric_Value=+04/5}', "");
Expect(1, 8537, '\p{^Is_Numeric_Value=+04/5}', "");
Expect(1, 8537, '\P{Is_Numeric_Value=+04/5}', "");
Expect(0, 8537, '\P{^Is_Numeric_Value=+04/5}', "");
Expect(1, 8536, '\p{Is_Numeric_Value=0.800}', "");
Expect(0, 8536, '\p{^Is_Numeric_Value=0.800}', "");
Expect(0, 8536, '\P{Is_Numeric_Value=0.800}', "");
Expect(1, 8536, '\P{^Is_Numeric_Value=0.800}', "");
Expect(0, 8537, '\p{Is_Numeric_Value=0.800}', "");
Expect(1, 8537, '\p{^Is_Numeric_Value=0.800}', "");
Expect(1, 8537, '\P{Is_Numeric_Value=0.800}', "");
Expect(0, 8537, '\P{^Is_Numeric_Value=0.800}', "");
Error('\p{Is_Nv=/a/		+04/0000005}');
Error('\P{Is_Nv=/a/		+04/0000005}');
Expect(1, 8536, '\p{Is_Nv=+0000000004/05}', "");
Expect(0, 8536, '\p{^Is_Nv=+0000000004/05}', "");
Expect(0, 8536, '\P{Is_Nv=+0000000004/05}', "");
Expect(1, 8536, '\P{^Is_Nv=+0000000004/05}', "");
Expect(0, 8537, '\p{Is_Nv=+0000000004/05}', "");
Expect(1, 8537, '\p{^Is_Nv=+0000000004/05}', "");
Expect(1, 8537, '\P{Is_Nv=+0000000004/05}', "");
Expect(0, 8537, '\P{^Is_Nv=+0000000004/05}', "");
Expect(1, 8536, '\p{Is_Nv=0.800}', "");
Expect(0, 8536, '\p{^Is_Nv=0.800}', "");
Expect(0, 8536, '\P{Is_Nv=0.800}', "");
Expect(1, 8536, '\P{^Is_Nv=0.800}', "");
Expect(0, 8537, '\p{Is_Nv=0.800}', "");
Expect(1, 8537, '\p{^Is_Nv=0.800}', "");
Expect(1, 8537, '\P{Is_Nv=0.800}', "");
Expect(0, 8537, '\P{^Is_Nv=0.800}', "");
Error('\p{Numeric_Value=/a/ -4_0}');
Error('\P{Numeric_Value=/a/ -4_0}');
Expect(1, 133532, '\p{Numeric_Value=+0040}', "");
Expect(0, 133532, '\p{^Numeric_Value=+0040}', "");
Expect(0, 133532, '\P{Numeric_Value=+0040}', "");
Expect(1, 133532, '\P{^Numeric_Value=+0040}', "");
Expect(0, 133533, '\p{Numeric_Value=+0040}', "");
Expect(1, 133533, '\p{^Numeric_Value=+0040}', "");
Expect(1, 133533, '\P{Numeric_Value=+0040}', "");
Expect(0, 133533, '\P{^Numeric_Value=+0040}', "");
Error('\p{Nv=	_+0_0_0_40:=}');
Error('\P{Nv=	_+0_0_0_40:=}');
Expect(1, 133532, '\p{Nv=0_0_0_0_040}', "");
Expect(0, 133532, '\p{^Nv=0_0_0_0_040}', "");
Expect(0, 133532, '\P{Nv=0_0_0_0_040}', "");
Expect(1, 133532, '\P{^Nv=0_0_0_0_040}', "");
Expect(0, 133533, '\p{Nv=0_0_0_0_040}', "");
Expect(1, 133533, '\p{^Nv=0_0_0_0_040}', "");
Expect(1, 133533, '\P{Nv=0_0_0_0_040}', "");
Expect(0, 133533, '\P{^Nv=0_0_0_0_040}', "");
Error('\p{Is_Numeric_Value=/a/_	040}');
Error('\P{Is_Numeric_Value=/a/_	040}');
Expect(1, 133532, '\p{Is_Numeric_Value=000040}', "");
Expect(0, 133532, '\p{^Is_Numeric_Value=000040}', "");
Expect(0, 133532, '\P{Is_Numeric_Value=000040}', "");
Expect(1, 133532, '\P{^Is_Numeric_Value=000040}', "");
Expect(0, 133533, '\p{Is_Numeric_Value=000040}', "");
Expect(1, 133533, '\p{^Is_Numeric_Value=000040}', "");
Expect(1, 133533, '\P{Is_Numeric_Value=000040}', "");
Expect(0, 133533, '\P{^Is_Numeric_Value=000040}', "");
Error('\p{Is_Nv=/a/0_0_40}');
Error('\P{Is_Nv=/a/0_0_40}');
Expect(1, 133532, '\p{Is_Nv=+00040}', "");
Expect(0, 133532, '\p{^Is_Nv=+00040}', "");
Expect(0, 133532, '\P{Is_Nv=+00040}', "");
Expect(1, 133532, '\P{^Is_Nv=+00040}', "");
Expect(0, 133533, '\p{Is_Nv=+00040}', "");
Expect(1, 133533, '\p{^Is_Nv=+00040}', "");
Expect(1, 133533, '\P{Is_Nv=+00040}', "");
Expect(0, 133533, '\P{^Is_Nv=+00040}', "");
Error('\p{Numeric_Value: /a/ _+000000400}');
Error('\P{Numeric_Value: /a/ _+000000400}');
Expect(1, 69237, '\p{Numeric_Value:   0400}', "");
Expect(0, 69237, '\p{^Numeric_Value:   0400}', "");
Expect(0, 69237, '\P{Numeric_Value:   0400}', "");
Expect(1, 69237, '\P{^Numeric_Value:   0400}', "");
Expect(0, 69238, '\p{Numeric_Value:   0400}', "");
Expect(1, 69238, '\p{^Numeric_Value:   0400}', "");
Expect(1, 69238, '\P{Numeric_Value:   0400}', "");
Expect(0, 69238, '\P{^Numeric_Value:   0400}', "");
Error('\p{Nv= /a/40_0}');
Error('\P{Nv= /a/40_0}');
Expect(1, 69237, '\p{Nv:+0_0_0_400}', "");
Expect(0, 69237, '\p{^Nv:+0_0_0_400}', "");
Expect(0, 69237, '\P{Nv:+0_0_0_400}', "");
Expect(1, 69237, '\P{^Nv:+0_0_0_400}', "");
Expect(0, 69238, '\p{Nv:+0_0_0_400}', "");
Expect(1, 69238, '\p{^Nv:+0_0_0_400}', "");
Expect(1, 69238, '\P{Nv:+0_0_0_400}', "");
Expect(0, 69238, '\P{^Nv:+0_0_0_400}', "");
Error('\p{Is_Numeric_Value= _0040_0:=}');
Error('\P{Is_Numeric_Value= _0040_0:=}');
Expect(1, 69237, '\p{Is_Numeric_Value:	+000000000400}', "");
Expect(0, 69237, '\p{^Is_Numeric_Value:	+000000000400}', "");
Expect(0, 69237, '\P{Is_Numeric_Value:	+000000000400}', "");
Expect(1, 69237, '\P{^Is_Numeric_Value:	+000000000400}', "");
Expect(0, 69238, '\p{Is_Numeric_Value:	+000000000400}', "");
Expect(1, 69238, '\p{^Is_Numeric_Value:	+000000000400}', "");
Expect(1, 69238, '\P{Is_Numeric_Value:	+000000000400}', "");
Expect(0, 69238, '\P{^Is_Numeric_Value:	+000000000400}', "");
Error('\p{Is_Nv= _000000000400:=}');
Error('\P{Is_Nv= _000000000400:=}');
Expect(1, 69237, '\p{Is_Nv=+00000000400}', "");
Expect(0, 69237, '\p{^Is_Nv=+00000000400}', "");
Expect(0, 69237, '\P{Is_Nv=+00000000400}', "");
Expect(1, 69237, '\P{^Is_Nv=+00000000400}', "");
Expect(0, 69238, '\p{Is_Nv=+00000000400}', "");
Expect(1, 69238, '\p{^Is_Nv=+00000000400}', "");
Expect(1, 69238, '\P{Is_Nv=+00000000400}', "");
Expect(0, 69238, '\P{^Is_Nv=+00000000400}', "");
Error('\p{Numeric_Value=:=	 +04_00_0}');
Error('\P{Numeric_Value=:=	 +04_00_0}');
Expect(1, 65829, '\p{Numeric_Value=+0000000004000}', "");
Expect(0, 65829, '\p{^Numeric_Value=+0000000004000}', "");
Expect(0, 65829, '\P{Numeric_Value=+0000000004000}', "");
Expect(1, 65829, '\P{^Numeric_Value=+0000000004000}', "");
Expect(0, 65830, '\p{Numeric_Value=+0000000004000}', "");
Expect(1, 65830, '\p{^Numeric_Value=+0000000004000}', "");
Expect(1, 65830, '\P{Numeric_Value=+0000000004000}', "");
Expect(0, 65830, '\P{^Numeric_Value=+0000000004000}', "");
Error('\p{Nv=_/a/0_0_0_0_0_0_0_04000}');
Error('\P{Nv=_/a/0_0_0_0_0_0_0_04000}');
Expect(1, 65829, '\p{Nv=00_00_00_00_04_000}', "");
Expect(0, 65829, '\p{^Nv=00_00_00_00_04_000}', "");
Expect(0, 65829, '\P{Nv=00_00_00_00_04_000}', "");
Expect(1, 65829, '\P{^Nv=00_00_00_00_04_000}', "");
Expect(0, 65830, '\p{Nv=00_00_00_00_04_000}', "");
Expect(1, 65830, '\p{^Nv=00_00_00_00_04_000}', "");
Expect(1, 65830, '\P{Nv=00_00_00_00_04_000}', "");
Expect(0, 65830, '\P{^Nv=00_00_00_00_04_000}', "");
Error('\p{Is_Numeric_Value=:=00_00_00_00_04_000}');
Error('\P{Is_Numeric_Value=:=00_00_00_00_04_000}');
Expect(1, 65829, '\p{Is_Numeric_Value=000000400_0}', "");
Expect(0, 65829, '\p{^Is_Numeric_Value=000000400_0}', "");
Expect(0, 65829, '\P{Is_Numeric_Value=000000400_0}', "");
Expect(1, 65829, '\P{^Is_Numeric_Value=000000400_0}', "");
Expect(0, 65830, '\p{Is_Numeric_Value=000000400_0}', "");
Expect(1, 65830, '\p{^Is_Numeric_Value=000000400_0}', "");
Expect(1, 65830, '\P{Is_Numeric_Value=000000400_0}', "");
Expect(0, 65830, '\P{^Is_Numeric_Value=000000400_0}', "");
Error('\p{Is_Nv=_ 0000004000:=}');
Error('\P{Is_Nv=_ 0000004000:=}');
Expect(1, 65829, '\p{Is_Nv: 00004000}', "");
Expect(0, 65829, '\p{^Is_Nv: 00004000}', "");
Expect(0, 65829, '\P{Is_Nv: 00004000}', "");
Expect(1, 65829, '\P{^Is_Nv: 00004000}', "");
Expect(0, 65830, '\p{Is_Nv: 00004000}', "");
Expect(1, 65830, '\p{^Is_Nv: 00004000}', "");
Expect(1, 65830, '\P{Is_Nv: 00004000}', "");
Expect(0, 65830, '\P{^Is_Nv: 00004000}', "");
Error('\p{Numeric_Value=__+004_000_0:=}');
Error('\P{Numeric_Value=__+004_000_0:=}');
Expect(1, 65838, '\p{Numeric_Value=0000040000}', "");
Expect(0, 65838, '\p{^Numeric_Value=0000040000}', "");
Expect(0, 65838, '\P{Numeric_Value=0000040000}', "");
Expect(1, 65838, '\P{^Numeric_Value=0000040000}', "");
Expect(0, 65839, '\p{Numeric_Value=0000040000}', "");
Expect(1, 65839, '\p{^Numeric_Value=0000040000}', "");
Expect(1, 65839, '\P{Numeric_Value=0000040000}', "");
Expect(0, 65839, '\P{^Numeric_Value=0000040000}', "");
Error('\p{Nv=:=00000040000}');
Error('\P{Nv=:=00000040000}');
Expect(1, 65838, '\p{Nv=000000040000}', "");
Expect(0, 65838, '\p{^Nv=000000040000}', "");
Expect(0, 65838, '\P{Nv=000000040000}', "");
Expect(1, 65838, '\P{^Nv=000000040000}', "");
Expect(0, 65839, '\p{Nv=000000040000}', "");
Expect(1, 65839, '\p{^Nv=000000040000}', "");
Expect(1, 65839, '\P{Nv=000000040000}', "");
Expect(0, 65839, '\P{^Nv=000000040000}', "");
Error('\p{Is_Numeric_Value=:=-	0000000040000}');
Error('\P{Is_Numeric_Value=:=-	0000000040000}');
Expect(1, 65838, '\p{Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(0, 65838, '\p{^Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(0, 65838, '\P{Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(1, 65838, '\P{^Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(0, 65839, '\p{Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(1, 65839, '\p{^Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(1, 65839, '\P{Is_Numeric_Value=+0_0_4_0_0_00}', "");
Expect(0, 65839, '\P{^Is_Numeric_Value=+0_0_4_0_0_00}', "");
Error('\p{Is_Nv=:=-000_004_000_0}');
Error('\P{Is_Nv=:=-000_004_000_0}');
Expect(1, 65838, '\p{Is_Nv=00_04_00_00}', "");
Expect(0, 65838, '\p{^Is_Nv=00_04_00_00}', "");
Expect(0, 65838, '\P{Is_Nv=00_04_00_00}', "");
Expect(1, 65838, '\P{^Is_Nv=00_04_00_00}', "");
Expect(0, 65839, '\p{Is_Nv=00_04_00_00}', "");
Expect(1, 65839, '\p{^Is_Nv=00_04_00_00}', "");
Expect(1, 65839, '\P{Is_Nv=00_04_00_00}', "");
Expect(0, 65839, '\P{^Is_Nv=00_04_00_00}', "");
Error('\p{Numeric_Value= /a/041}');
Error('\P{Numeric_Value= /a/041}');
Expect(1, 12982, '\p{Numeric_Value=04_1}', "");
Expect(0, 12982, '\p{^Numeric_Value=04_1}', "");
Expect(0, 12982, '\P{Numeric_Value=04_1}', "");
Expect(1, 12982, '\P{^Numeric_Value=04_1}', "");
Expect(0, 12983, '\p{Numeric_Value=04_1}', "");
Expect(1, 12983, '\p{^Numeric_Value=04_1}', "");
Expect(1, 12983, '\P{Numeric_Value=04_1}', "");
Expect(0, 12983, '\P{^Numeric_Value=04_1}', "");
Error('\p{Nv:   _:=00041}');
Error('\P{Nv:   _:=00041}');
Expect(1, 12982, '\p{Nv=00041}', "");
Expect(0, 12982, '\p{^Nv=00041}', "");
Expect(0, 12982, '\P{Nv=00041}', "");
Expect(1, 12982, '\P{^Nv=00041}', "");
Expect(0, 12983, '\p{Nv=00041}', "");
Expect(1, 12983, '\p{^Nv=00041}', "");
Expect(1, 12983, '\P{Nv=00041}', "");
Expect(0, 12983, '\P{^Nv=00041}', "");
Error('\p{Is_Numeric_Value=_:=000_000_41}');
Error('\P{Is_Numeric_Value=_:=000_000_41}');
Expect(1, 12982, '\p{Is_Numeric_Value=4_1}', "");
Expect(0, 12982, '\p{^Is_Numeric_Value=4_1}', "");
Expect(0, 12982, '\P{Is_Numeric_Value=4_1}', "");
Expect(1, 12982, '\P{^Is_Numeric_Value=4_1}', "");
Expect(0, 12983, '\p{Is_Numeric_Value=4_1}', "");
Expect(1, 12983, '\p{^Is_Numeric_Value=4_1}', "");
Expect(1, 12983, '\P{Is_Numeric_Value=4_1}', "");
Expect(0, 12983, '\P{^Is_Numeric_Value=4_1}', "");
Error('\p{Is_Nv: -	+041:=}');
Error('\P{Is_Nv: -	+041:=}');
Expect(1, 12982, '\p{Is_Nv=+041}', "");
Expect(0, 12982, '\p{^Is_Nv=+041}', "");
Expect(0, 12982, '\P{Is_Nv=+041}', "");
Expect(1, 12982, '\P{^Is_Nv=+041}', "");
Expect(0, 12983, '\p{Is_Nv=+041}', "");
Expect(1, 12983, '\p{^Is_Nv=+041}', "");
Expect(1, 12983, '\P{Is_Nv=+041}', "");
Expect(0, 12983, '\P{^Is_Nv=+041}', "");
Error('\p{Numeric_Value=:=	_4_2}');
Error('\P{Numeric_Value=:=	_4_2}');
Expect(1, 12983, '\p{Numeric_Value:000000042}', "");
Expect(0, 12983, '\p{^Numeric_Value:000000042}', "");
Expect(0, 12983, '\P{Numeric_Value:000000042}', "");
Expect(1, 12983, '\P{^Numeric_Value:000000042}', "");
Expect(0, 12984, '\p{Numeric_Value:000000042}', "");
Expect(1, 12984, '\p{^Numeric_Value:000000042}', "");
Expect(1, 12984, '\P{Numeric_Value:000000042}', "");
Expect(0, 12984, '\P{^Numeric_Value:000000042}', "");
Error('\p{Nv: 	/a/0_0_0_0_042}');
Error('\P{Nv: 	/a/0_0_0_0_042}');
Expect(1, 12983, '\p{Nv=00042}', "");
Expect(0, 12983, '\p{^Nv=00042}', "");
Expect(0, 12983, '\P{Nv=00042}', "");
Expect(1, 12983, '\P{^Nv=00042}', "");
Expect(0, 12984, '\p{Nv=00042}', "");
Expect(1, 12984, '\p{^Nv=00042}', "");
Expect(1, 12984, '\P{Nv=00042}', "");
Expect(0, 12984, '\P{^Nv=00042}', "");
Error('\p{Is_Numeric_Value=-:=00_00_00_00_042}');
Error('\P{Is_Numeric_Value=-:=00_00_00_00_042}');
Expect(1, 12983, '\p{Is_Numeric_Value=42}', "");
Expect(0, 12983, '\p{^Is_Numeric_Value=42}', "");
Expect(0, 12983, '\P{Is_Numeric_Value=42}', "");
Expect(1, 12983, '\P{^Is_Numeric_Value=42}', "");
Expect(0, 12984, '\p{Is_Numeric_Value=42}', "");
Expect(1, 12984, '\p{^Is_Numeric_Value=42}', "");
Expect(1, 12984, '\P{Is_Numeric_Value=42}', "");
Expect(0, 12984, '\P{^Is_Numeric_Value=42}', "");
Error('\p{Is_Nv= 4_2:=}');
Error('\P{Is_Nv= 4_2:=}');
Expect(1, 12983, '\p{Is_Nv=0_0_0_0_0_0_42}', "");
Expect(0, 12983, '\p{^Is_Nv=0_0_0_0_0_0_42}', "");
Expect(0, 12983, '\P{Is_Nv=0_0_0_0_0_0_42}', "");
Expect(1, 12983, '\P{^Is_Nv=0_0_0_0_0_0_42}', "");
Expect(0, 12984, '\p{Is_Nv=0_0_0_0_0_0_42}', "");
Expect(1, 12984, '\p{^Is_Nv=0_0_0_0_0_0_42}', "");
Expect(1, 12984, '\P{Is_Nv=0_0_0_0_0_0_42}', "");
Expect(0, 12984, '\P{^Is_Nv=0_0_0_0_0_0_42}', "");
Error('\p{Numeric_Value= :=000_000_43}');
Error('\P{Numeric_Value= :=000_000_43}');
Expect(1, 12984, '\p{Numeric_Value=0000004_3}', "");
Expect(0, 12984, '\p{^Numeric_Value=0000004_3}', "");
Expect(0, 12984, '\P{Numeric_Value=0000004_3}', "");
Expect(1, 12984, '\P{^Numeric_Value=0000004_3}', "");
Expect(0, 12985, '\p{Numeric_Value=0000004_3}', "");
Expect(1, 12985, '\p{^Numeric_Value=0000004_3}', "");
Expect(1, 12985, '\P{Numeric_Value=0000004_3}', "");
Expect(0, 12985, '\P{^Numeric_Value=0000004_3}', "");
Error('\p{Nv=_/a/00004_3}');
Error('\P{Nv=_/a/00004_3}');
Expect(1, 12984, '\p{Nv=0000000043}', "");
Expect(0, 12984, '\p{^Nv=0000000043}', "");
Expect(0, 12984, '\P{Nv=0000000043}', "");
Expect(1, 12984, '\P{^Nv=0000000043}', "");
Expect(0, 12985, '\p{Nv=0000000043}', "");
Expect(1, 12985, '\p{^Nv=0000000043}', "");
Expect(1, 12985, '\P{Nv=0000000043}', "");
Expect(0, 12985, '\P{^Nv=0000000043}', "");
Error('\p{Is_Numeric_Value:	_-0_0_0_0_43:=}');
Error('\P{Is_Numeric_Value:	_-0_0_0_0_43:=}');
Expect(1, 12984, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(0, 12984, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(0, 12984, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(1, 12984, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(0, 12985, '\p{Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(1, 12985, '\p{^Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(1, 12985, '\P{Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Expect(0, 12985, '\P{^Is_Numeric_Value=0_0_0_0_0_0_0_43}', "");
Error('\p{Is_Nv=--000_000_43:=}');
Error('\P{Is_Nv=--000_000_43:=}');
Expect(1, 12984, '\p{Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(0, 12984, '\p{^Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(0, 12984, '\P{Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(1, 12984, '\P{^Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(0, 12985, '\p{Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(1, 12985, '\p{^Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(1, 12985, '\P{Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Expect(0, 12985, '\P{^Is_Nv=+0_0_0_0_0_0_0_0_043}', "");
Error('\p{Numeric_Value:- 0432000/a/}');
Error('\P{Numeric_Value:- 0432000/a/}');
Expect(1, 74803, '\p{Numeric_Value=0000000432000}', "");
Expect(0, 74803, '\p{^Numeric_Value=0000000432000}', "");
Expect(0, 74803, '\P{Numeric_Value=0000000432000}', "");
Expect(1, 74803, '\P{^Numeric_Value=0000000432000}', "");
Expect(0, 74804, '\p{Numeric_Value=0000000432000}', "");
Expect(1, 74804, '\p{^Numeric_Value=0000000432000}', "");
Expect(1, 74804, '\P{Numeric_Value=0000000432000}', "");
Expect(0, 74804, '\P{^Numeric_Value=0000000432000}', "");
Error('\p{Nv=/a/--4_3_2_000}');
Error('\P{Nv=/a/--4_3_2_000}');
Expect(1, 74803, '\p{Nv=000000432000}', "");
Expect(0, 74803, '\p{^Nv=000000432000}', "");
Expect(0, 74803, '\P{Nv=000000432000}', "");
Expect(1, 74803, '\P{^Nv=000000432000}', "");
Expect(0, 74804, '\p{Nv=000000432000}', "");
Expect(1, 74804, '\p{^Nv=000000432000}', "");
Expect(1, 74804, '\P{Nv=000000432000}', "");
Expect(0, 74804, '\P{^Nv=000000432000}', "");
Error('\p{Is_Numeric_Value=:= +0000432000}');
Error('\P{Is_Numeric_Value=:= +0000432000}');
Expect(1, 74803, '\p{Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(0, 74803, '\p{^Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(0, 74803, '\P{Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(1, 74803, '\P{^Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(0, 74804, '\p{Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(1, 74804, '\p{^Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(1, 74804, '\P{Is_Numeric_Value=+00_00_04_32_00_0}', "");
Expect(0, 74804, '\P{^Is_Numeric_Value=+00_00_04_32_00_0}', "");
Error('\p{Is_Nv=	:=+000000432000}');
Error('\P{Is_Nv=	:=+000000432000}');
Expect(1, 74803, '\p{Is_Nv=000432000}', "");
Expect(0, 74803, '\p{^Is_Nv=000432000}', "");
Expect(0, 74803, '\P{Is_Nv=000432000}', "");
Expect(1, 74803, '\P{^Is_Nv=000432000}', "");
Expect(0, 74804, '\p{Is_Nv=000432000}', "");
Expect(1, 74804, '\p{^Is_Nv=000432000}', "");
Expect(1, 74804, '\P{Is_Nv=000432000}', "");
Expect(0, 74804, '\P{^Is_Nv=000432000}', "");
Error('\p{Numeric_Value=_-0_0_0_0_0_0_0_0_044/a/}');
Error('\P{Numeric_Value=_-0_0_0_0_0_0_0_0_044/a/}');
Expect(1, 12985, '\p{Numeric_Value=+0044}', "");
Expect(0, 12985, '\p{^Numeric_Value=+0044}', "");
Expect(0, 12985, '\P{Numeric_Value=+0044}', "");
Expect(1, 12985, '\P{^Numeric_Value=+0044}', "");
Expect(0, 12986, '\p{Numeric_Value=+0044}', "");
Expect(1, 12986, '\p{^Numeric_Value=+0044}', "");
Expect(1, 12986, '\P{Numeric_Value=+0044}', "");
Expect(0, 12986, '\P{^Numeric_Value=+0044}', "");
Error('\p{Nv=:=+0000044}');
Error('\P{Nv=:=+0000044}');
Expect(1, 12985, '\p{Nv=+44}', "");
Expect(0, 12985, '\p{^Nv=+44}', "");
Expect(0, 12985, '\P{Nv=+44}', "");
Expect(1, 12985, '\P{^Nv=+44}', "");
Expect(0, 12986, '\p{Nv=+44}', "");
Expect(1, 12986, '\p{^Nv=+44}', "");
Expect(1, 12986, '\P{Nv=+44}', "");
Expect(0, 12986, '\P{^Nv=+44}', "");
Error('\p{Is_Numeric_Value=/a/_ 0_0_0_0_0_0_44}');
Error('\P{Is_Numeric_Value=/a/_ 0_0_0_0_0_0_44}');
Expect(1, 12985, '\p{Is_Numeric_Value=0000044}', "");
Expect(0, 12985, '\p{^Is_Numeric_Value=0000044}', "");
Expect(0, 12985, '\P{Is_Numeric_Value=0000044}', "");
Expect(1, 12985, '\P{^Is_Numeric_Value=0000044}', "");
Expect(0, 12986, '\p{Is_Numeric_Value=0000044}', "");
Expect(1, 12986, '\p{^Is_Numeric_Value=0000044}', "");
Expect(1, 12986, '\P{Is_Numeric_Value=0000044}', "");
Expect(0, 12986, '\P{^Is_Numeric_Value=0000044}', "");
Error('\p{Is_Nv=_00000044:=}');
Error('\P{Is_Nv=_00000044:=}');
Expect(1, 12985, '\p{Is_Nv=00044}', "");
Expect(0, 12985, '\p{^Is_Nv=00044}', "");
Expect(0, 12985, '\P{Is_Nv=00044}', "");
Expect(1, 12985, '\P{^Is_Nv=00044}', "");
Expect(0, 12986, '\p{Is_Nv=00044}', "");
Expect(1, 12986, '\p{^Is_Nv=00044}', "");
Expect(1, 12986, '\P{Is_Nv=00044}', "");
Expect(0, 12986, '\P{^Is_Nv=00044}', "");
Error('\p{Numeric_Value=/a/		00045}');
Error('\P{Numeric_Value=/a/		00045}');
Expect(1, 12986, '\p{Numeric_Value=045}', "");
Expect(0, 12986, '\p{^Numeric_Value=045}', "");
Expect(0, 12986, '\P{Numeric_Value=045}', "");
Expect(1, 12986, '\P{^Numeric_Value=045}', "");
Expect(0, 12987, '\p{Numeric_Value=045}', "");
Expect(1, 12987, '\p{^Numeric_Value=045}', "");
Expect(1, 12987, '\P{Numeric_Value=045}', "");
Expect(0, 12987, '\P{^Numeric_Value=045}', "");
Error('\p{Nv=/a/	+045}');
Error('\P{Nv=/a/	+045}');
Expect(1, 12986, '\p{Nv=0004_5}', "");
Expect(0, 12986, '\p{^Nv=0004_5}', "");
Expect(0, 12986, '\P{Nv=0004_5}', "");
Expect(1, 12986, '\P{^Nv=0004_5}', "");
Expect(0, 12987, '\p{Nv=0004_5}', "");
Expect(1, 12987, '\p{^Nv=0004_5}', "");
Expect(1, 12987, '\P{Nv=0004_5}', "");
Expect(0, 12987, '\P{^Nv=0004_5}', "");
Error('\p{Is_Numeric_Value=__00045:=}');
Error('\P{Is_Numeric_Value=__00045:=}');
Expect(1, 12986, '\p{Is_Numeric_Value=04_5}', "");
Expect(0, 12986, '\p{^Is_Numeric_Value=04_5}', "");
Expect(0, 12986, '\P{Is_Numeric_Value=04_5}', "");
Expect(1, 12986, '\P{^Is_Numeric_Value=04_5}', "");
Expect(0, 12987, '\p{Is_Numeric_Value=04_5}', "");
Expect(1, 12987, '\p{^Is_Numeric_Value=04_5}', "");
Expect(1, 12987, '\P{Is_Numeric_Value=04_5}', "");
Expect(0, 12987, '\P{^Is_Numeric_Value=04_5}', "");
Error('\p{Is_Nv:/a/		00_04_5}');
Error('\P{Is_Nv:/a/		00_04_5}');
Expect(1, 12986, '\p{Is_Nv=000045}', "");
Expect(0, 12986, '\p{^Is_Nv=000045}', "");
Expect(0, 12986, '\P{Is_Nv=000045}', "");
Expect(1, 12986, '\P{^Is_Nv=000045}', "");
Expect(0, 12987, '\p{Is_Nv=000045}', "");
Expect(1, 12987, '\p{^Is_Nv=000045}', "");
Expect(1, 12987, '\P{Is_Nv=000045}', "");
Expect(0, 12987, '\P{^Is_Nv=000045}', "");
Error('\p{Numeric_Value= :=0000000046}');
Error('\P{Numeric_Value= :=0000000046}');
Expect(1, 12987, '\p{Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(0, 12987, '\p{^Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(0, 12987, '\P{Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(1, 12987, '\P{^Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(0, 12988, '\p{Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(1, 12988, '\p{^Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(1, 12988, '\P{Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Expect(0, 12988, '\P{^Numeric_Value:+0_0_0_0_0_0_0_0_46}', "");
Error('\p{Nv=	/a/046}');
Error('\P{Nv=	/a/046}');
Expect(1, 12987, '\p{Nv=+4_6}', "");
Expect(0, 12987, '\p{^Nv=+4_6}', "");
Expect(0, 12987, '\P{Nv=+4_6}', "");
Expect(1, 12987, '\P{^Nv=+4_6}', "");
Expect(0, 12988, '\p{Nv=+4_6}', "");
Expect(1, 12988, '\p{^Nv=+4_6}', "");
Expect(1, 12988, '\P{Nv=+4_6}', "");
Expect(0, 12988, '\P{^Nv=+4_6}', "");
Error('\p{Is_Numeric_Value=  +0000000046:=}');
Error('\P{Is_Numeric_Value=  +0000000046:=}');
Expect(1, 12987, '\p{Is_Numeric_Value=+000046}', "");
Expect(0, 12987, '\p{^Is_Numeric_Value=+000046}', "");
Expect(0, 12987, '\P{Is_Numeric_Value=+000046}', "");
Expect(1, 12987, '\P{^Is_Numeric_Value=+000046}', "");
Expect(0, 12988, '\p{Is_Numeric_Value=+000046}', "");
Expect(1, 12988, '\p{^Is_Numeric_Value=+000046}', "");
Expect(1, 12988, '\P{Is_Numeric_Value=+000046}', "");
Expect(0, 12988, '\P{^Is_Numeric_Value=+000046}', "");
Error('\p{Is_Nv= 	0_0_0_0_0046:=}');
Error('\P{Is_Nv= 	0_0_0_0_0046:=}');
Expect(1, 12987, '\p{Is_Nv=0000004_6}', "");
Expect(0, 12987, '\p{^Is_Nv=0000004_6}', "");
Expect(0, 12987, '\P{Is_Nv=0000004_6}', "");
Expect(1, 12987, '\P{^Is_Nv=0000004_6}', "");
Expect(0, 12988, '\p{Is_Nv=0000004_6}', "");
Expect(1, 12988, '\p{^Is_Nv=0000004_6}', "");
Expect(1, 12988, '\P{Is_Nv=0000004_6}', "");
Expect(0, 12988, '\P{^Is_Nv=0000004_6}', "");
Error('\p{Numeric_Value=	 047:=}');
Error('\P{Numeric_Value=	 047:=}');
Expect(1, 12988, '\p{Numeric_Value=00_00_00_00_04_7}', "");
Expect(0, 12988, '\p{^Numeric_Value=00_00_00_00_04_7}', "");
Expect(0, 12988, '\P{Numeric_Value=00_00_00_00_04_7}', "");
Expect(1, 12988, '\P{^Numeric_Value=00_00_00_00_04_7}', "");
Expect(0, 12989, '\p{Numeric_Value=00_00_00_00_04_7}', "");
Expect(1, 12989, '\p{^Numeric_Value=00_00_00_00_04_7}', "");
Expect(1, 12989, '\P{Numeric_Value=00_00_00_00_04_7}', "");
Expect(0, 12989, '\P{^Numeric_Value=00_00_00_00_04_7}', "");
Error('\p{Nv=/a/+000047}');
Error('\P{Nv=/a/+000047}');
Expect(1, 12988, '\p{Nv=000047}', "");
Expect(0, 12988, '\p{^Nv=000047}', "");
Expect(0, 12988, '\P{Nv=000047}', "");
Expect(1, 12988, '\P{^Nv=000047}', "");
Expect(0, 12989, '\p{Nv=000047}', "");
Expect(1, 12989, '\p{^Nv=000047}', "");
Expect(1, 12989, '\P{Nv=000047}', "");
Expect(0, 12989, '\P{^Nv=000047}', "");
Error('\p{Is_Numeric_Value=		+0_0_0_0_0_0_0_0047/a/}');
Error('\P{Is_Numeric_Value=		+0_0_0_0_0_0_0_0047/a/}');
Expect(1, 12988, '\p{Is_Numeric_Value=047}', "");
Expect(0, 12988, '\p{^Is_Numeric_Value=047}', "");
Expect(0, 12988, '\P{Is_Numeric_Value=047}', "");
Expect(1, 12988, '\P{^Is_Numeric_Value=047}', "");
Expect(0, 12989, '\p{Is_Numeric_Value=047}', "");
Expect(1, 12989, '\p{^Is_Numeric_Value=047}', "");
Expect(1, 12989, '\P{Is_Numeric_Value=047}', "");
Expect(0, 12989, '\P{^Is_Numeric_Value=047}', "");
Error('\p{Is_Nv=	 +0_0_0_0_47/a/}');
Error('\P{Is_Nv=	 +0_0_0_0_47/a/}');
Expect(1, 12988, '\p{Is_Nv=04_7}', "");
Expect(0, 12988, '\p{^Is_Nv=04_7}', "");
Expect(0, 12988, '\P{Is_Nv=04_7}', "");
Expect(1, 12988, '\P{^Is_Nv=04_7}', "");
Expect(0, 12989, '\p{Is_Nv=04_7}', "");
Expect(1, 12989, '\p{^Is_Nv=04_7}', "");
Expect(1, 12989, '\P{Is_Nv=04_7}', "");
Expect(0, 12989, '\P{^Is_Nv=04_7}', "");
Error('\p{Numeric_Value:	+04_8/a/}');
Error('\P{Numeric_Value:	+04_8/a/}');
Expect(1, 12989, '\p{Numeric_Value=+00_04_8}', "");
Expect(0, 12989, '\p{^Numeric_Value=+00_04_8}', "");
Expect(0, 12989, '\P{Numeric_Value=+00_04_8}', "");
Expect(1, 12989, '\P{^Numeric_Value=+00_04_8}', "");
Expect(0, 12990, '\p{Numeric_Value=+00_04_8}', "");
Expect(1, 12990, '\p{^Numeric_Value=+00_04_8}', "");
Expect(1, 12990, '\P{Numeric_Value=+00_04_8}', "");
Expect(0, 12990, '\P{^Numeric_Value=+00_04_8}', "");
Error('\p{Nv=/a/ +4_8}');
Error('\P{Nv=/a/ +4_8}');
Expect(1, 12989, '\p{Nv=+00000000048}', "");
Expect(0, 12989, '\p{^Nv=+00000000048}', "");
Expect(0, 12989, '\P{Nv=+00000000048}', "");
Expect(1, 12989, '\P{^Nv=+00000000048}', "");
Expect(0, 12990, '\p{Nv=+00000000048}', "");
Expect(1, 12990, '\p{^Nv=+00000000048}', "");
Expect(1, 12990, '\P{Nv=+00000000048}', "");
Expect(0, 12990, '\P{^Nv=+00000000048}', "");
Error('\p{Is_Numeric_Value=:=		00000048}');
Error('\P{Is_Numeric_Value=:=		00000048}');
Expect(1, 12989, '\p{Is_Numeric_Value=+000048}', "");
Expect(0, 12989, '\p{^Is_Numeric_Value=+000048}', "");
Expect(0, 12989, '\P{Is_Numeric_Value=+000048}', "");
Expect(1, 12989, '\P{^Is_Numeric_Value=+000048}', "");
Expect(0, 12990, '\p{Is_Numeric_Value=+000048}', "");
Expect(1, 12990, '\p{^Is_Numeric_Value=+000048}', "");
Expect(1, 12990, '\P{Is_Numeric_Value=+000048}', "");
Expect(0, 12990, '\P{^Is_Numeric_Value=+000048}', "");
Error('\p{Is_Nv=-_+0_0_0_0_0_0_0_0_48/a/}');
Error('\P{Is_Nv=-_+0_0_0_0_0_0_0_0_48/a/}');
Expect(1, 12989, '\p{Is_Nv=0_0_0_0_0_00048}', "");
Expect(0, 12989, '\p{^Is_Nv=0_0_0_0_0_00048}', "");
Expect(0, 12989, '\P{Is_Nv=0_0_0_0_0_00048}', "");
Expect(1, 12989, '\P{^Is_Nv=0_0_0_0_0_00048}', "");
Expect(0, 12990, '\p{Is_Nv=0_0_0_0_0_00048}', "");
Expect(1, 12990, '\p{^Is_Nv=0_0_0_0_0_00048}', "");
Expect(1, 12990, '\P{Is_Nv=0_0_0_0_0_00048}', "");
Expect(0, 12990, '\P{^Is_Nv=0_0_0_0_0_00048}', "");
Error('\p{Numeric_Value=/a/+0000004_9}');
Error('\P{Numeric_Value=/a/+0000004_9}');
Expect(1, 12990, '\p{Numeric_Value=000000049}', "");
Expect(0, 12990, '\p{^Numeric_Value=000000049}', "");
Expect(0, 12990, '\P{Numeric_Value=000000049}', "");
Expect(1, 12990, '\P{^Numeric_Value=000000049}', "");
Expect(0, 12991, '\p{Numeric_Value=000000049}', "");
Expect(1, 12991, '\p{^Numeric_Value=000000049}', "");
Expect(1, 12991, '\P{Numeric_Value=000000049}', "");
Expect(0, 12991, '\P{^Numeric_Value=000000049}', "");
Error('\p{Nv= 	0000_0000_49/a/}');
Error('\P{Nv= 	0000_0000_49/a/}');
Expect(1, 12990, '\p{Nv=0000_0004_9}', "");
Expect(0, 12990, '\p{^Nv=0000_0004_9}', "");
Expect(0, 12990, '\P{Nv=0000_0004_9}', "");
Expect(1, 12990, '\P{^Nv=0000_0004_9}', "");
Expect(0, 12991, '\p{Nv=0000_0004_9}', "");
Expect(1, 12991, '\p{^Nv=0000_0004_9}', "");
Expect(1, 12991, '\P{Nv=0000_0004_9}', "");
Expect(0, 12991, '\P{^Nv=0000_0004_9}', "");
Error('\p{Is_Numeric_Value=/a/ -+0_0_0_0_0_049}');
Error('\P{Is_Numeric_Value=/a/ -+0_0_0_0_0_049}');
Expect(1, 12990, '\p{Is_Numeric_Value=049}', "");
Expect(0, 12990, '\p{^Is_Numeric_Value=049}', "");
Expect(0, 12990, '\P{Is_Numeric_Value=049}', "");
Expect(1, 12990, '\P{^Is_Numeric_Value=049}', "");
Expect(0, 12991, '\p{Is_Numeric_Value=049}', "");
Expect(1, 12991, '\p{^Is_Numeric_Value=049}', "");
Expect(1, 12991, '\P{Is_Numeric_Value=049}', "");
Expect(0, 12991, '\P{^Is_Numeric_Value=049}', "");
Error('\p{Is_Nv=/a/	+00049}');
Error('\P{Is_Nv=/a/	+00049}');
Expect(1, 12990, '\p{Is_Nv=00_00_00_049}', "");
Expect(0, 12990, '\p{^Is_Nv=00_00_00_049}', "");
Expect(0, 12990, '\P{Is_Nv=00_00_00_049}', "");
Expect(1, 12990, '\P{^Is_Nv=00_00_00_049}', "");
Expect(0, 12991, '\p{Is_Nv=00_00_00_049}', "");
Expect(1, 12991, '\p{^Is_Nv=00_00_00_049}', "");
Expect(1, 12991, '\P{Is_Nv=00_00_00_049}', "");
Expect(0, 12991, '\P{^Is_Nv=00_00_00_049}', "");
Error('\p{Numeric_Value=_/a/0005}');
Error('\P{Numeric_Value=_/a/0005}');
Expect(1, 131361, '\p{Numeric_Value=0000000005}', "");
Expect(0, 131361, '\p{^Numeric_Value=0000000005}', "");
Expect(0, 131361, '\P{Numeric_Value=0000000005}', "");
Expect(1, 131361, '\P{^Numeric_Value=0000000005}', "");
Expect(0, 131362, '\p{Numeric_Value=0000000005}', "");
Expect(1, 131362, '\p{^Numeric_Value=0000000005}', "");
Expect(1, 131362, '\P{Numeric_Value=0000000005}', "");
Expect(0, 131362, '\P{^Numeric_Value=0000000005}', "");
Error('\p{Nv=:=00_00_05}');
Error('\P{Nv=:=00_00_05}');
Expect(1, 131361, '\p{Nv=000005}', "");
Expect(0, 131361, '\p{^Nv=000005}', "");
Expect(0, 131361, '\P{Nv=000005}', "");
Expect(1, 131361, '\P{^Nv=000005}', "");
Expect(0, 131362, '\p{Nv=000005}', "");
Expect(1, 131362, '\p{^Nv=000005}', "");
Expect(1, 131362, '\P{Nv=000005}', "");
Expect(0, 131362, '\P{^Nv=000005}', "");
Error('\p{Is_Numeric_Value=_-+0_5:=}');
Error('\P{Is_Numeric_Value=_-+0_5:=}');
Expect(1, 131361, '\p{Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(0, 131361, '\p{^Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(0, 131361, '\P{Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(1, 131361, '\P{^Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(0, 131362, '\p{Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(1, 131362, '\p{^Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(1, 131362, '\P{Is_Numeric_Value=0_0_0_0_0_005}', "");
Expect(0, 131362, '\P{^Is_Numeric_Value=0_0_0_0_0_005}', "");
Error('\p{Is_Nv=_-+0000_5/a/}');
Error('\P{Is_Nv=_-+0000_5/a/}');
Expect(1, 131361, '\p{Is_Nv=0005}', "");
Expect(0, 131361, '\p{^Is_Nv=0005}', "");
Expect(0, 131361, '\P{Is_Nv=0005}', "");
Expect(1, 131361, '\P{^Is_Nv=0005}', "");
Expect(0, 131362, '\p{Is_Nv=0005}', "");
Expect(1, 131362, '\p{^Is_Nv=0005}', "");
Expect(1, 131362, '\P{Is_Nv=0005}', "");
Expect(0, 131362, '\P{^Is_Nv=0005}', "");
Error('\p{Numeric_Value=-_+05/00000002/a/}');
Error('\P{Numeric_Value=-_+05/00000002/a/}');
Expect(1, 3884, '\p{Numeric_Value=0005/00000002}', "");
Expect(0, 3884, '\p{^Numeric_Value=0005/00000002}', "");
Expect(0, 3884, '\P{Numeric_Value=0005/00000002}', "");
Expect(1, 3884, '\P{^Numeric_Value=0005/00000002}', "");
Expect(0, 3885, '\p{Numeric_Value=0005/00000002}', "");
Expect(1, 3885, '\p{^Numeric_Value=0005/00000002}', "");
Expect(1, 3885, '\P{Numeric_Value=0005/00000002}', "");
Expect(0, 3885, '\P{^Numeric_Value=0005/00000002}', "");
Expect(1, 3884, '\p{Numeric_Value=2.500}', "");
Expect(0, 3884, '\p{^Numeric_Value=2.500}', "");
Expect(0, 3884, '\P{Numeric_Value=2.500}', "");
Expect(1, 3884, '\P{^Numeric_Value=2.500}', "");
Expect(0, 3885, '\p{Numeric_Value=2.500}', "");
Expect(1, 3885, '\p{^Numeric_Value=2.500}', "");
Expect(1, 3885, '\P{Numeric_Value=2.500}', "");
Expect(0, 3885, '\P{^Numeric_Value=2.500}', "");
Error('\p{Nv= /a/0000000005/00002}');
Error('\P{Nv= /a/0000000005/00002}');
Expect(1, 3884, '\p{Nv=0000000005/0002}', "");
Expect(0, 3884, '\p{^Nv=0000000005/0002}', "");
Expect(0, 3884, '\P{Nv=0000000005/0002}', "");
Expect(1, 3884, '\P{^Nv=0000000005/0002}', "");
Expect(0, 3885, '\p{Nv=0000000005/0002}', "");
Expect(1, 3885, '\p{^Nv=0000000005/0002}', "");
Expect(1, 3885, '\P{Nv=0000000005/0002}', "");
Expect(0, 3885, '\P{^Nv=0000000005/0002}', "");
Expect(1, 3884, '\p{Nv=2.500}', "");
Expect(0, 3884, '\p{^Nv=2.500}', "");
Expect(0, 3884, '\P{Nv=2.500}', "");
Expect(1, 3884, '\P{^Nv=2.500}', "");
Expect(0, 3885, '\p{Nv=2.500}', "");
Expect(1, 3885, '\p{^Nv=2.500}', "");
Expect(1, 3885, '\P{Nv=2.500}', "");
Expect(0, 3885, '\P{^Nv=2.500}', "");
Error('\p{Is_Numeric_Value=-0005/000000002/a/}');
Error('\P{Is_Numeric_Value=-0005/000000002/a/}');
Expect(1, 3884, '\p{Is_Numeric_Value=5/000000002}', "");
Expect(0, 3884, '\p{^Is_Numeric_Value=5/000000002}', "");
Expect(0, 3884, '\P{Is_Numeric_Value=5/000000002}', "");
Expect(1, 3884, '\P{^Is_Numeric_Value=5/000000002}', "");
Expect(0, 3885, '\p{Is_Numeric_Value=5/000000002}', "");
Expect(1, 3885, '\p{^Is_Numeric_Value=5/000000002}', "");
Expect(1, 3885, '\P{Is_Numeric_Value=5/000000002}', "");
Expect(0, 3885, '\P{^Is_Numeric_Value=5/000000002}', "");
Expect(1, 3884, '\p{Is_Numeric_Value=2.500}', "");
Expect(0, 3884, '\p{^Is_Numeric_Value=2.500}', "");
Expect(0, 3884, '\P{Is_Numeric_Value=2.500}', "");
Expect(1, 3884, '\P{^Is_Numeric_Value=2.500}', "");
Expect(0, 3885, '\p{Is_Numeric_Value=2.500}', "");
Expect(1, 3885, '\p{^Is_Numeric_Value=2.500}', "");
Expect(1, 3885, '\P{Is_Numeric_Value=2.500}', "");
Expect(0, 3885, '\P{^Is_Numeric_Value=2.500}', "");
Error('\p{Is_Nv=_05/000002:=}');
Error('\P{Is_Nv=_05/000002:=}');
Expect(1, 3884, '\p{Is_Nv=+05/2}', "");
Expect(0, 3884, '\p{^Is_Nv=+05/2}', "");
Expect(0, 3884, '\P{Is_Nv=+05/2}', "");
Expect(1, 3884, '\P{^Is_Nv=+05/2}', "");
Expect(0, 3885, '\p{Is_Nv=+05/2}', "");
Expect(1, 3885, '\p{^Is_Nv=+05/2}', "");
Expect(1, 3885, '\P{Is_Nv=+05/2}', "");
Expect(0, 3885, '\P{^Is_Nv=+05/2}', "");
Expect(1, 3884, '\p{Is_Nv:   2.500}', "");
Expect(0, 3884, '\p{^Is_Nv:   2.500}', "");
Expect(0, 3884, '\P{Is_Nv:   2.500}', "");
Expect(1, 3884, '\P{^Is_Nv:   2.500}', "");
Expect(0, 3885, '\p{Is_Nv:   2.500}', "");
Expect(1, 3885, '\p{^Is_Nv:   2.500}', "");
Expect(1, 3885, '\P{Is_Nv:   2.500}', "");
Expect(0, 3885, '\P{^Is_Nv:   2.500}', "");
Error('\p{Numeric_Value=/a/__0000005/0000000006}');
Error('\P{Numeric_Value=/a/__0000005/0000000006}');
Expect(1, 74844, '\p{Numeric_Value=0005/000000006}', "");
Expect(0, 74844, '\p{^Numeric_Value=0005/000000006}', "");
Expect(0, 74844, '\P{Numeric_Value=0005/000000006}', "");
Expect(1, 74844, '\P{^Numeric_Value=0005/000000006}', "");
Expect(0, 74845, '\p{Numeric_Value=0005/000000006}', "");
Expect(1, 74845, '\p{^Numeric_Value=0005/000000006}', "");
Expect(1, 74845, '\P{Numeric_Value=0005/000000006}', "");
Expect(0, 74845, '\P{^Numeric_Value=0005/000000006}', "");
Error('\p{Numeric_Value=0.83}');
Error('\P{Numeric_Value=0.83}');
Expect(1, 74844, '\p{Numeric_Value=0.833}', "");
Expect(0, 74844, '\p{^Numeric_Value=0.833}', "");
Expect(0, 74844, '\P{Numeric_Value=0.833}', "");
Expect(1, 74844, '\P{^Numeric_Value=0.833}', "");
Expect(0, 74845, '\p{Numeric_Value=0.833}', "");
Expect(1, 74845, '\p{^Numeric_Value=0.833}', "");
Expect(1, 74845, '\P{Numeric_Value=0.833}', "");
Expect(0, 74845, '\P{^Numeric_Value=0.833}', "");
Error('\p{Nv=:=__0000005/06}');
Error('\P{Nv=:=__0000005/06}');
Expect(1, 74844, '\p{Nv=00000005/0000000006}', "");
Expect(0, 74844, '\p{^Nv=00000005/0000000006}', "");
Expect(0, 74844, '\P{Nv=00000005/0000000006}', "");
Expect(1, 74844, '\P{^Nv=00000005/0000000006}', "");
Expect(0, 74845, '\p{Nv=00000005/0000000006}', "");
Expect(1, 74845, '\p{^Nv=00000005/0000000006}', "");
Expect(1, 74845, '\P{Nv=00000005/0000000006}', "");
Expect(0, 74845, '\P{^Nv=00000005/0000000006}', "");
Error('\p{Nv=0.83}');
Error('\P{Nv=0.83}');
Expect(1, 74844, '\p{Nv=0.833}', "");
Expect(0, 74844, '\p{^Nv=0.833}', "");
Expect(0, 74844, '\P{Nv=0.833}', "");
Expect(1, 74844, '\P{^Nv=0.833}', "");
Expect(0, 74845, '\p{Nv=0.833}', "");
Expect(1, 74845, '\p{^Nv=0.833}', "");
Expect(1, 74845, '\P{Nv=0.833}', "");
Expect(0, 74845, '\P{^Nv=0.833}', "");
Error('\p{Is_Numeric_Value=/a/	0005/006}');
Error('\P{Is_Numeric_Value=/a/	0005/006}');
Expect(1, 74844, '\p{Is_Numeric_Value=000000005/00000006}', "");
Expect(0, 74844, '\p{^Is_Numeric_Value=000000005/00000006}', "");
Expect(0, 74844, '\P{Is_Numeric_Value=000000005/00000006}', "");
Expect(1, 74844, '\P{^Is_Numeric_Value=000000005/00000006}', "");
Expect(0, 74845, '\p{Is_Numeric_Value=000000005/00000006}', "");
Expect(1, 74845, '\p{^Is_Numeric_Value=000000005/00000006}', "");
Expect(1, 74845, '\P{Is_Numeric_Value=000000005/00000006}', "");
Expect(0, 74845, '\P{^Is_Numeric_Value=000000005/00000006}', "");
Error('\p{Is_Numeric_Value=0.83}');
Error('\P{Is_Numeric_Value=0.83}');
Expect(1, 74844, '\p{Is_Numeric_Value=0.833}', "");
Expect(0, 74844, '\p{^Is_Numeric_Value=0.833}', "");
Expect(0, 74844, '\P{Is_Numeric_Value=0.833}', "");
Expect(1, 74844, '\P{^Is_Numeric_Value=0.833}', "");
Expect(0, 74845, '\p{Is_Numeric_Value=0.833}', "");
Expect(1, 74845, '\p{^Is_Numeric_Value=0.833}', "");
Expect(1, 74845, '\P{Is_Numeric_Value=0.833}', "");
Expect(0, 74845, '\P{^Is_Numeric_Value=0.833}', "");
Error('\p{Is_Nv=_/a/000000005/00000006}');
Error('\P{Is_Nv=_/a/000000005/00000006}');
Expect(1, 74844, '\p{Is_Nv=005/000000006}', "");
Expect(0, 74844, '\p{^Is_Nv=005/000000006}', "");
Expect(0, 74844, '\P{Is_Nv=005/000000006}', "");
Expect(1, 74844, '\P{^Is_Nv=005/000000006}', "");
Expect(0, 74845, '\p{Is_Nv=005/000000006}', "");
Expect(1, 74845, '\p{^Is_Nv=005/000000006}', "");
Expect(1, 74845, '\P{Is_Nv=005/000000006}', "");
Expect(0, 74845, '\P{^Is_Nv=005/000000006}', "");
Error('\p{Is_Nv=0.83}');
Error('\P{Is_Nv=0.83}');
Expect(1, 74844, '\p{Is_Nv=0.833}', "");
Expect(0, 74844, '\p{^Is_Nv=0.833}', "");
Expect(0, 74844, '\P{Is_Nv=0.833}', "");
Expect(1, 74844, '\P{^Is_Nv=0.833}', "");
Expect(0, 74845, '\p{Is_Nv=0.833}', "");
Expect(1, 74845, '\p{^Is_Nv=0.833}', "");
Expect(1, 74845, '\P{Is_Nv=0.833}', "");
Expect(0, 74845, '\P{^Is_Nv=0.833}', "");
Error('\p{Numeric_Value=	-0005/0008/a/}');
Error('\P{Numeric_Value=	-0005/0008/a/}');
Expect(1, 8541, '\p{Numeric_Value=05/000008}', "");
Expect(0, 8541, '\p{^Numeric_Value=05/000008}', "");
Expect(0, 8541, '\P{Numeric_Value=05/000008}', "");
Expect(1, 8541, '\P{^Numeric_Value=05/000008}', "");
Expect(0, 8542, '\p{Numeric_Value=05/000008}', "");
Expect(1, 8542, '\p{^Numeric_Value=05/000008}', "");
Expect(1, 8542, '\P{Numeric_Value=05/000008}', "");
Expect(0, 8542, '\P{^Numeric_Value=05/000008}', "");
Error('\p{Numeric_Value=0.63}');
Error('\P{Numeric_Value=0.63}');
Expect(1, 8541, '\p{Numeric_Value=0.625}', "");
Expect(0, 8541, '\p{^Numeric_Value=0.625}', "");
Expect(0, 8541, '\P{Numeric_Value=0.625}', "");
Expect(1, 8541, '\P{^Numeric_Value=0.625}', "");
Expect(0, 8542, '\p{Numeric_Value=0.625}', "");
Expect(1, 8542, '\p{^Numeric_Value=0.625}', "");
Expect(1, 8542, '\P{Numeric_Value=0.625}', "");
Expect(0, 8542, '\P{^Numeric_Value=0.625}', "");
Error('\p{Nv= 005/000008:=}');
Error('\P{Nv= 005/000008:=}');
Expect(1, 8541, '\p{Nv=5/0000000008}', "");
Expect(0, 8541, '\p{^Nv=5/0000000008}', "");
Expect(0, 8541, '\P{Nv=5/0000000008}', "");
Expect(1, 8541, '\P{^Nv=5/0000000008}', "");
Expect(0, 8542, '\p{Nv=5/0000000008}', "");
Expect(1, 8542, '\p{^Nv=5/0000000008}', "");
Expect(1, 8542, '\P{Nv=5/0000000008}', "");
Expect(0, 8542, '\P{^Nv=5/0000000008}', "");
Error('\p{Nv=0.63}');
Error('\P{Nv=0.63}');
Expect(1, 8541, '\p{Nv=0.625}', "");
Expect(0, 8541, '\p{^Nv=0.625}', "");
Expect(0, 8541, '\P{Nv=0.625}', "");
Expect(1, 8541, '\P{^Nv=0.625}', "");
Expect(0, 8542, '\p{Nv=0.625}', "");
Expect(1, 8542, '\p{^Nv=0.625}', "");
Expect(1, 8542, '\P{Nv=0.625}', "");
Expect(0, 8542, '\P{^Nv=0.625}', "");
Error('\p{Is_Numeric_Value= :=000005/0000000008}');
Error('\P{Is_Numeric_Value= :=000005/0000000008}');
Expect(1, 8541, '\p{Is_Numeric_Value=5/0008}', "");
Expect(0, 8541, '\p{^Is_Numeric_Value=5/0008}', "");
Expect(0, 8541, '\P{Is_Numeric_Value=5/0008}', "");
Expect(1, 8541, '\P{^Is_Numeric_Value=5/0008}', "");
Expect(0, 8542, '\p{Is_Numeric_Value=5/0008}', "");
Expect(1, 8542, '\p{^Is_Numeric_Value=5/0008}', "");
Expect(1, 8542, '\P{Is_Numeric_Value=5/0008}', "");
Expect(0, 8542, '\P{^Is_Numeric_Value=5/0008}', "");
Error('\p{Is_Numeric_Value=0.63}');
Error('\P{Is_Numeric_Value=0.63}');
Expect(1, 8541, '\p{Is_Numeric_Value=0.625}', "");
Expect(0, 8541, '\p{^Is_Numeric_Value=0.625}', "");
Expect(0, 8541, '\P{Is_Numeric_Value=0.625}', "");
Expect(1, 8541, '\P{^Is_Numeric_Value=0.625}', "");
Expect(0, 8542, '\p{Is_Numeric_Value=0.625}', "");
Expect(1, 8542, '\p{^Is_Numeric_Value=0.625}', "");
Expect(1, 8542, '\P{Is_Numeric_Value=0.625}', "");
Expect(0, 8542, '\P{^Is_Numeric_Value=0.625}', "");
Error('\p{Is_Nv=:= 	00005/0008}');
Error('\P{Is_Nv=:= 	00005/0008}');
Expect(1, 8541, '\p{Is_Nv=05/0000008}', "");
Expect(0, 8541, '\p{^Is_Nv=05/0000008}', "");
Expect(0, 8541, '\P{Is_Nv=05/0000008}', "");
Expect(1, 8541, '\P{^Is_Nv=05/0000008}', "");
Expect(0, 8542, '\p{Is_Nv=05/0000008}', "");
Expect(1, 8542, '\p{^Is_Nv=05/0000008}', "");
Expect(1, 8542, '\P{Is_Nv=05/0000008}', "");
Expect(0, 8542, '\P{^Is_Nv=05/0000008}', "");
Error('\p{Is_Nv=0.63}');
Error('\P{Is_Nv=0.63}');
Expect(1, 8541, '\p{Is_Nv=0.625}', "");
Expect(0, 8541, '\p{^Is_Nv=0.625}', "");
Expect(0, 8541, '\P{Is_Nv=0.625}', "");
Expect(1, 8541, '\P{^Is_Nv=0.625}', "");
Expect(0, 8542, '\p{Is_Nv=0.625}', "");
Expect(1, 8542, '\p{^Is_Nv=0.625}', "");
Expect(1, 8542, '\P{Is_Nv=0.625}', "");
Expect(0, 8542, '\P{^Is_Nv=0.625}', "");
Error('\p{Numeric_Value=		0000050:=}');
Error('\P{Numeric_Value=		0000050:=}');
Expect(1, 119661, '\p{Numeric_Value=+0050}', "");
Expect(0, 119661, '\p{^Numeric_Value=+0050}', "");
Expect(0, 119661, '\P{Numeric_Value=+0050}', "");
Expect(1, 119661, '\P{^Numeric_Value=+0050}', "");
Expect(0, 119662, '\p{Numeric_Value=+0050}', "");
Expect(1, 119662, '\p{^Numeric_Value=+0050}', "");
Expect(1, 119662, '\P{Numeric_Value=+0050}', "");
Expect(0, 119662, '\P{^Numeric_Value=+0050}', "");
Error('\p{Nv=/a/	0_0_0_0_0_0_0050}');
Error('\P{Nv=/a/	0_0_0_0_0_0_0050}');
Expect(1, 119661, '\p{Nv=00000005_0}', "");
Expect(0, 119661, '\p{^Nv=00000005_0}', "");
Expect(0, 119661, '\P{Nv=00000005_0}', "");
Expect(1, 119661, '\P{^Nv=00000005_0}', "");
Expect(0, 119662, '\p{Nv=00000005_0}', "");
Expect(1, 119662, '\p{^Nv=00000005_0}', "");
Expect(1, 119662, '\P{Nv=00000005_0}', "");
Expect(0, 119662, '\P{^Nv=00000005_0}', "");
Error('\p{Is_Numeric_Value=	 50:=}');
Error('\P{Is_Numeric_Value=	 50:=}');
Expect(1, 119661, '\p{Is_Numeric_Value=0_0_50}', "");
Expect(0, 119661, '\p{^Is_Numeric_Value=0_0_50}', "");
Expect(0, 119661, '\P{Is_Numeric_Value=0_0_50}', "");
Expect(1, 119661, '\P{^Is_Numeric_Value=0_0_50}', "");
Expect(0, 119662, '\p{Is_Numeric_Value=0_0_50}', "");
Expect(1, 119662, '\p{^Is_Numeric_Value=0_0_50}', "");
Expect(1, 119662, '\P{Is_Numeric_Value=0_0_50}', "");
Expect(0, 119662, '\P{^Is_Numeric_Value=0_0_50}', "");
Error('\p{Is_Nv=/a/ -050}');
Error('\P{Is_Nv=/a/ -050}');
Expect(1, 119661, '\p{Is_Nv=+00000000050}', "");
Expect(0, 119661, '\p{^Is_Nv=+00000000050}', "");
Expect(0, 119661, '\P{Is_Nv=+00000000050}', "");
Expect(1, 119661, '\P{^Is_Nv=+00000000050}', "");
Expect(0, 119662, '\p{Is_Nv=+00000000050}', "");
Expect(1, 119662, '\p{^Is_Nv=+00000000050}', "");
Expect(1, 119662, '\P{Is_Nv=+00000000050}', "");
Expect(0, 119662, '\P{^Is_Nv=+00000000050}', "");
Error('\p{Numeric_Value: /a/000500}');
Error('\P{Numeric_Value: /a/000500}');
Expect(1, 69238, '\p{Numeric_Value=0_0_0_0_0_500}', "");
Expect(0, 69238, '\p{^Numeric_Value=0_0_0_0_0_500}', "");
Expect(0, 69238, '\P{Numeric_Value=0_0_0_0_0_500}', "");
Expect(1, 69238, '\P{^Numeric_Value=0_0_0_0_0_500}', "");
Expect(0, 69239, '\p{Numeric_Value=0_0_0_0_0_500}', "");
Expect(1, 69239, '\p{^Numeric_Value=0_0_0_0_0_500}', "");
Expect(1, 69239, '\P{Numeric_Value=0_0_0_0_0_500}', "");
Expect(0, 69239, '\P{^Numeric_Value=0_0_0_0_0_500}', "");
Error('\p{Nv:   /a/	 00000500}');
Error('\P{Nv:   /a/	 00000500}');
Expect(1, 69238, '\p{Nv=000000500}', "");
Expect(0, 69238, '\p{^Nv=000000500}', "");
Expect(0, 69238, '\P{Nv=000000500}', "");
Expect(1, 69238, '\P{^Nv=000000500}', "");
Expect(0, 69239, '\p{Nv=000000500}', "");
Expect(1, 69239, '\p{^Nv=000000500}', "");
Expect(1, 69239, '\P{Nv=000000500}', "");
Expect(0, 69239, '\P{^Nv=000000500}', "");
Error('\p{Is_Numeric_Value=:=  0500}');
Error('\P{Is_Numeric_Value=:=  0500}');
Expect(1, 69238, '\p{Is_Numeric_Value=+0000000050_0}', "");
Expect(0, 69238, '\p{^Is_Numeric_Value=+0000000050_0}', "");
Expect(0, 69238, '\P{Is_Numeric_Value=+0000000050_0}', "");
Expect(1, 69238, '\P{^Is_Numeric_Value=+0000000050_0}', "");
Expect(0, 69239, '\p{Is_Numeric_Value=+0000000050_0}', "");
Expect(1, 69239, '\p{^Is_Numeric_Value=+0000000050_0}', "");
Expect(1, 69239, '\P{Is_Numeric_Value=+0000000050_0}', "");
Expect(0, 69239, '\P{^Is_Numeric_Value=+0000000050_0}', "");
Error('\p{Is_Nv=:=_0000050_0}');
Error('\P{Is_Nv=:=_0000050_0}');
Expect(1, 69238, '\p{Is_Nv=+500}', "");
Expect(0, 69238, '\p{^Is_Nv=+500}', "");
Expect(0, 69238, '\P{Is_Nv=+500}', "");
Expect(1, 69238, '\P{^Is_Nv=+500}', "");
Expect(0, 69239, '\p{Is_Nv=+500}', "");
Expect(1, 69239, '\p{^Is_Nv=+500}', "");
Expect(1, 69239, '\P{Is_Nv=+500}', "");
Expect(0, 69239, '\P{^Is_Nv=+500}', "");
Error('\p{Numeric_Value=_	00_00_00_05_00_0/a/}');
Error('\P{Numeric_Value=_	00_00_00_05_00_0/a/}');
Expect(1, 65906, '\p{Numeric_Value=000005000}', "");
Expect(0, 65906, '\p{^Numeric_Value=000005000}', "");
Expect(0, 65906, '\P{Numeric_Value=000005000}', "");
Expect(1, 65906, '\P{^Numeric_Value=000005000}', "");
Expect(0, 65907, '\p{Numeric_Value=000005000}', "");
Expect(1, 65907, '\p{^Numeric_Value=000005000}', "");
Expect(1, 65907, '\P{Numeric_Value=000005000}', "");
Expect(0, 65907, '\P{^Numeric_Value=000005000}', "");
Error('\p{Nv=	-000000005000/a/}');
Error('\P{Nv=	-000000005000/a/}');
Expect(1, 65906, '\p{Nv=+00500_0}', "");
Expect(0, 65906, '\p{^Nv=+00500_0}', "");
Expect(0, 65906, '\P{Nv=+00500_0}', "");
Expect(1, 65906, '\P{^Nv=+00500_0}', "");
Expect(0, 65907, '\p{Nv=+00500_0}', "");
Expect(1, 65907, '\p{^Nv=+00500_0}', "");
Expect(1, 65907, '\P{Nv=+00500_0}', "");
Expect(0, 65907, '\P{^Nv=+00500_0}', "");
Error('\p{Is_Numeric_Value=	+00500_0:=}');
Error('\P{Is_Numeric_Value=	+00500_0:=}');
Expect(1, 65906, '\p{Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(0, 65906, '\p{^Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(0, 65906, '\P{Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(1, 65906, '\P{^Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(0, 65907, '\p{Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(1, 65907, '\p{^Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(1, 65907, '\P{Is_Numeric_Value=0_0_0_0_5_000}', "");
Expect(0, 65907, '\P{^Is_Numeric_Value=0_0_0_0_5_000}', "");
Error('\p{Is_Nv:  	00000000500_0/a/}');
Error('\P{Is_Nv:  	00000000500_0/a/}');
Expect(1, 65906, '\p{Is_Nv:0_0_5_000}', "");
Expect(0, 65906, '\p{^Is_Nv:0_0_5_000}', "");
Expect(0, 65906, '\P{Is_Nv:0_0_5_000}', "");
Expect(1, 65906, '\P{^Is_Nv:0_0_5_000}', "");
Expect(0, 65907, '\p{Is_Nv:0_0_5_000}', "");
Expect(1, 65907, '\p{^Is_Nv:0_0_5_000}', "");
Expect(1, 65907, '\P{Is_Nv:0_0_5_000}', "");
Expect(0, 65907, '\P{^Is_Nv:0_0_5_000}', "");
Error('\p{Numeric_Value=/a/		0050000}');
Error('\P{Numeric_Value=/a/		0050000}');
Expect(1, 65878, '\p{Numeric_Value=+000050000}', "");
Expect(0, 65878, '\p{^Numeric_Value=+000050000}', "");
Expect(0, 65878, '\P{Numeric_Value=+000050000}', "");
Expect(1, 65878, '\P{^Numeric_Value=+000050000}', "");
Expect(0, 65879, '\p{Numeric_Value=+000050000}', "");
Expect(1, 65879, '\p{^Numeric_Value=+000050000}', "");
Expect(1, 65879, '\P{Numeric_Value=+000050000}', "");
Expect(0, 65879, '\P{^Numeric_Value=+000050000}', "");
Error('\p{Nv=/a/_	000000050000}');
Error('\P{Nv=/a/_	000000050000}');
Expect(1, 65878, '\p{Nv=000005000_0}', "");
Expect(0, 65878, '\p{^Nv=000005000_0}', "");
Expect(0, 65878, '\P{Nv=000005000_0}', "");
Expect(1, 65878, '\P{^Nv=000005000_0}', "");
Expect(0, 65879, '\p{Nv=000005000_0}', "");
Expect(1, 65879, '\p{^Nv=000005000_0}', "");
Expect(1, 65879, '\P{Nv=000005000_0}', "");
Expect(0, 65879, '\P{^Nv=000005000_0}', "");
Error('\p{Is_Numeric_Value= /a/+05000_0}');
Error('\P{Is_Numeric_Value= /a/+05000_0}');
Expect(1, 65878, '\p{Is_Numeric_Value=0000050000}', "");
Expect(0, 65878, '\p{^Is_Numeric_Value=0000050000}', "");
Expect(0, 65878, '\P{Is_Numeric_Value=0000050000}', "");
Expect(1, 65878, '\P{^Is_Numeric_Value=0000050000}', "");
Expect(0, 65879, '\p{Is_Numeric_Value=0000050000}', "");
Expect(1, 65879, '\p{^Is_Numeric_Value=0000050000}', "");
Expect(1, 65879, '\P{Is_Numeric_Value=0000050000}', "");
Expect(0, 65879, '\P{^Is_Numeric_Value=0000050000}', "");
Error('\p{Is_Nv= _+0_0_0_0_5_0_000:=}');
Error('\P{Is_Nv= _+0_0_0_0_5_0_000:=}');
Expect(1, 65878, '\p{Is_Nv=0000050000}', "");
Expect(0, 65878, '\p{^Is_Nv=0000050000}', "");
Expect(0, 65878, '\P{Is_Nv=0000050000}', "");
Expect(1, 65878, '\P{^Is_Nv=0000050000}', "");
Expect(0, 65879, '\p{Is_Nv=0000050000}', "");
Expect(1, 65879, '\p{^Is_Nv=0000050000}', "");
Expect(1, 65879, '\P{Is_Nv=0000050000}', "");
Expect(0, 65879, '\P{^Is_Nv=0000050000}', "");
Error('\p{Numeric_Value:	0_0_0_06/a/}');
Error('\P{Numeric_Value:	0_0_0_06/a/}');
Expect(1, 133866, '\p{Numeric_Value=+0006}', "");
Expect(0, 133866, '\p{^Numeric_Value=+0006}', "");
Expect(0, 133866, '\P{Numeric_Value=+0006}', "");
Expect(1, 133866, '\P{^Numeric_Value=+0006}', "");
Expect(0, 133867, '\p{Numeric_Value=+0006}', "");
Expect(1, 133867, '\p{^Numeric_Value=+0006}', "");
Expect(1, 133867, '\P{Numeric_Value=+0006}', "");
Expect(0, 133867, '\P{^Numeric_Value=+0006}', "");
Error('\p{Nv=_:=+006}');
Error('\P{Nv=_:=+006}');
Expect(1, 133866, '\p{Nv:+00006}', "");
Expect(0, 133866, '\p{^Nv:+00006}', "");
Expect(0, 133866, '\P{Nv:+00006}', "");
Expect(1, 133866, '\P{^Nv:+00006}', "");
Expect(0, 133867, '\p{Nv:+00006}', "");
Expect(1, 133867, '\p{^Nv:+00006}', "");
Expect(1, 133867, '\P{Nv:+00006}', "");
Expect(0, 133867, '\P{^Nv:+00006}', "");
Error('\p{Is_Numeric_Value=-/a/+00_00_00_06}');
Error('\P{Is_Numeric_Value=-/a/+00_00_00_06}');
Expect(1, 133866, '\p{Is_Numeric_Value=006}', "");
Expect(0, 133866, '\p{^Is_Numeric_Value=006}', "");
Expect(0, 133866, '\P{Is_Numeric_Value=006}', "");
Expect(1, 133866, '\P{^Is_Numeric_Value=006}', "");
Expect(0, 133867, '\p{Is_Numeric_Value=006}', "");
Expect(1, 133867, '\p{^Is_Numeric_Value=006}', "");
Expect(1, 133867, '\P{Is_Numeric_Value=006}', "");
Expect(0, 133867, '\P{^Is_Numeric_Value=006}', "");
Error('\p{Is_Nv=:=--0006}');
Error('\P{Is_Nv=:=--0006}');
Expect(1, 133866, '\p{Is_Nv=0000_6}', "");
Expect(0, 133866, '\p{^Is_Nv=0000_6}', "");
Expect(0, 133866, '\P{Is_Nv=0000_6}', "");
Expect(1, 133866, '\P{^Is_Nv=0000_6}', "");
Expect(0, 133867, '\p{Is_Nv=0000_6}', "");
Expect(1, 133867, '\p{^Is_Nv=0000_6}', "");
Expect(1, 133867, '\P{Is_Nv=0000_6}', "");
Expect(0, 133867, '\P{^Is_Nv=0000_6}', "");
Error('\p{Numeric_Value=:= 0000006_0}');
Error('\P{Numeric_Value=:= 0000006_0}');
Expect(1, 119662, '\p{Numeric_Value=+060}', "");
Expect(0, 119662, '\p{^Numeric_Value=+060}', "");
Expect(0, 119662, '\P{Numeric_Value=+060}', "");
Expect(1, 119662, '\P{^Numeric_Value=+060}', "");
Expect(0, 119663, '\p{Numeric_Value=+060}', "");
Expect(1, 119663, '\p{^Numeric_Value=+060}', "");
Expect(1, 119663, '\P{Numeric_Value=+060}', "");
Expect(0, 119663, '\P{^Numeric_Value=+060}', "");
Error('\p{Nv=	_6_0/a/}');
Error('\P{Nv=	_6_0/a/}');
Expect(1, 119662, '\p{Nv=+006_0}', "");
Expect(0, 119662, '\p{^Nv=+006_0}', "");
Expect(0, 119662, '\P{Nv=+006_0}', "");
Expect(1, 119662, '\P{^Nv=+006_0}', "");
Expect(0, 119663, '\p{Nv=+006_0}', "");
Expect(1, 119663, '\p{^Nv=+006_0}', "");
Expect(1, 119663, '\P{Nv=+006_0}', "");
Expect(0, 119663, '\P{^Nv=+006_0}', "");
Error('\p{Is_Numeric_Value=_/a/00000060}');
Error('\P{Is_Numeric_Value=_/a/00000060}');
Expect(1, 119662, '\p{Is_Numeric_Value=6_0}', "");
Expect(0, 119662, '\p{^Is_Numeric_Value=6_0}', "");
Expect(0, 119662, '\P{Is_Numeric_Value=6_0}', "");
Expect(1, 119662, '\P{^Is_Numeric_Value=6_0}', "");
Expect(0, 119663, '\p{Is_Numeric_Value=6_0}', "");
Expect(1, 119663, '\p{^Is_Numeric_Value=6_0}', "");
Expect(1, 119663, '\P{Is_Numeric_Value=6_0}', "");
Expect(0, 119663, '\P{^Is_Numeric_Value=6_0}', "");
Error('\p{Is_Nv=		+06_0:=}');
Error('\P{Is_Nv=		+06_0:=}');
Expect(1, 119662, '\p{Is_Nv=06_0}', "");
Expect(0, 119662, '\p{^Is_Nv=06_0}', "");
Expect(0, 119662, '\P{Is_Nv=06_0}', "");
Expect(1, 119662, '\P{^Is_Nv=06_0}', "");
Expect(0, 119663, '\p{Is_Nv=06_0}', "");
Expect(1, 119663, '\p{^Is_Nv=06_0}', "");
Expect(1, 119663, '\P{Is_Nv=06_0}', "");
Expect(0, 119663, '\P{^Is_Nv=06_0}', "");
Error('\p{Numeric_Value:     000000000600/a/}');
Error('\P{Numeric_Value:     000000000600/a/}');
Expect(1, 69239, '\p{Numeric_Value=00000600}', "");
Expect(0, 69239, '\p{^Numeric_Value=00000600}', "");
Expect(0, 69239, '\P{Numeric_Value=00000600}', "");
Expect(1, 69239, '\P{^Numeric_Value=00000600}', "");
Expect(0, 69240, '\p{Numeric_Value=00000600}', "");
Expect(1, 69240, '\p{^Numeric_Value=00000600}', "");
Expect(1, 69240, '\P{Numeric_Value=00000600}', "");
Expect(0, 69240, '\P{^Numeric_Value=00000600}', "");
Error('\p{Nv=	-+00000000600/a/}');
Error('\P{Nv=	-+00000000600/a/}');
Expect(1, 69239, '\p{Nv=+0_6_00}', "");
Expect(0, 69239, '\p{^Nv=+0_6_00}', "");
Expect(0, 69239, '\P{Nv=+0_6_00}', "");
Expect(1, 69239, '\P{^Nv=+0_6_00}', "");
Expect(0, 69240, '\p{Nv=+0_6_00}', "");
Expect(1, 69240, '\p{^Nv=+0_6_00}', "");
Expect(1, 69240, '\P{Nv=+0_6_00}', "");
Expect(0, 69240, '\P{^Nv=+0_6_00}', "");
Error('\p{Is_Numeric_Value:_/a/000_006_00}');
Error('\P{Is_Numeric_Value:_/a/000_006_00}');
Expect(1, 69239, '\p{Is_Numeric_Value=0000000600}', "");
Expect(0, 69239, '\p{^Is_Numeric_Value=0000000600}', "");
Expect(0, 69239, '\P{Is_Numeric_Value=0000000600}', "");
Expect(1, 69239, '\P{^Is_Numeric_Value=0000000600}', "");
Expect(0, 69240, '\p{Is_Numeric_Value=0000000600}', "");
Expect(1, 69240, '\p{^Is_Numeric_Value=0000000600}', "");
Expect(1, 69240, '\P{Is_Numeric_Value=0000000600}', "");
Expect(0, 69240, '\P{^Is_Numeric_Value=0000000600}', "");
Error('\p{Is_Nv=	 +000000000600:=}');
Error('\P{Is_Nv=	 +000000000600:=}');
Expect(1, 69239, '\p{Is_Nv=+0_0_6_00}', "");
Expect(0, 69239, '\p{^Is_Nv=+0_0_6_00}', "");
Expect(0, 69239, '\P{Is_Nv=+0_0_6_00}', "");
Expect(1, 69239, '\P{^Is_Nv=+0_0_6_00}', "");
Expect(0, 69240, '\p{Is_Nv=+0_0_6_00}', "");
Expect(1, 69240, '\p{^Is_Nv=+0_0_6_00}', "");
Expect(1, 69240, '\P{Is_Nv=+0_0_6_00}', "");
Expect(0, 69240, '\P{^Is_Nv=+0_0_6_00}', "");
Error('\p{Numeric_Value=:=_ +0_0_0_0_0_0_0_6_000}');
Error('\P{Numeric_Value=:=_ +0_0_0_0_0_0_0_6_000}');
Expect(1, 65831, '\p{Numeric_Value=+6000}', "");
Expect(0, 65831, '\p{^Numeric_Value=+6000}', "");
Expect(0, 65831, '\P{Numeric_Value=+6000}', "");
Expect(1, 65831, '\P{^Numeric_Value=+6000}', "");
Expect(0, 65832, '\p{Numeric_Value=+6000}', "");
Expect(1, 65832, '\p{^Numeric_Value=+6000}', "");
Expect(1, 65832, '\P{Numeric_Value=+6000}', "");
Expect(0, 65832, '\P{^Numeric_Value=+6000}', "");
Error('\p{Nv= /a/00006000}');
Error('\P{Nv= /a/00006000}');
Expect(1, 65831, '\p{Nv=+06000}', "");
Expect(0, 65831, '\p{^Nv=+06000}', "");
Expect(0, 65831, '\P{Nv=+06000}', "");
Expect(1, 65831, '\P{^Nv=+06000}', "");
Expect(0, 65832, '\p{Nv=+06000}', "");
Expect(1, 65832, '\p{^Nv=+06000}', "");
Expect(1, 65832, '\P{Nv=+06000}', "");
Expect(0, 65832, '\P{^Nv=+06000}', "");
Error('\p{Is_Numeric_Value=/a/600_0}');
Error('\P{Is_Numeric_Value=/a/600_0}');
Expect(1, 65831, '\p{Is_Numeric_Value=6000}', "");
Expect(0, 65831, '\p{^Is_Numeric_Value=6000}', "");
Expect(0, 65831, '\P{Is_Numeric_Value=6000}', "");
Expect(1, 65831, '\P{^Is_Numeric_Value=6000}', "");
Expect(0, 65832, '\p{Is_Numeric_Value=6000}', "");
Expect(1, 65832, '\p{^Is_Numeric_Value=6000}', "");
Expect(1, 65832, '\P{Is_Numeric_Value=6000}', "");
Expect(0, 65832, '\P{^Is_Numeric_Value=6000}', "");
Error('\p{Is_Nv=_0600_0:=}');
Error('\P{Is_Nv=_0600_0:=}');
Expect(1, 65831, '\p{Is_Nv:   000000600_0}', "");
Expect(0, 65831, '\p{^Is_Nv:   000000600_0}', "");
Expect(0, 65831, '\P{Is_Nv:   000000600_0}', "");
Expect(1, 65831, '\P{^Is_Nv:   000000600_0}', "");
Expect(0, 65832, '\p{Is_Nv:   000000600_0}', "");
Expect(1, 65832, '\p{^Is_Nv:   000000600_0}', "");
Expect(1, 65832, '\P{Is_Nv:   000000600_0}', "");
Expect(0, 65832, '\P{^Is_Nv:   000000600_0}', "");
Error('\p{Numeric_Value=_:=0_0_0_0_0_0_0_6_0_0_00}');
Error('\P{Numeric_Value=_:=0_0_0_0_0_0_0_6_0_0_00}');
Expect(1, 65840, '\p{Numeric_Value=00_00_06_00_00}', "");
Expect(0, 65840, '\p{^Numeric_Value=00_00_06_00_00}', "");
Expect(0, 65840, '\P{Numeric_Value=00_00_06_00_00}', "");
Expect(1, 65840, '\P{^Numeric_Value=00_00_06_00_00}', "");
Expect(0, 65841, '\p{Numeric_Value=00_00_06_00_00}', "");
Expect(1, 65841, '\p{^Numeric_Value=00_00_06_00_00}', "");
Expect(1, 65841, '\P{Numeric_Value=00_00_06_00_00}', "");
Expect(0, 65841, '\P{^Numeric_Value=00_00_06_00_00}', "");
Error('\p{Nv=__0060000:=}');
Error('\P{Nv=__0060000:=}');
Expect(1, 65840, '\p{Nv: 000000006000_0}', "");
Expect(0, 65840, '\p{^Nv: 000000006000_0}', "");
Expect(0, 65840, '\P{Nv: 000000006000_0}', "");
Expect(1, 65840, '\P{^Nv: 000000006000_0}', "");
Expect(0, 65841, '\p{Nv: 000000006000_0}', "");
Expect(1, 65841, '\p{^Nv: 000000006000_0}', "");
Expect(1, 65841, '\P{Nv: 000000006000_0}', "");
Expect(0, 65841, '\P{^Nv: 000000006000_0}', "");
Error('\p{Is_Numeric_Value=	:=+00000060000}');
Error('\P{Is_Numeric_Value=	:=+00000060000}');
Expect(1, 65840, '\p{Is_Numeric_Value=0000000060000}', "");
Expect(0, 65840, '\p{^Is_Numeric_Value=0000000060000}', "");
Expect(0, 65840, '\P{Is_Numeric_Value=0000000060000}', "");
Expect(1, 65840, '\P{^Is_Numeric_Value=0000000060000}', "");
Expect(0, 65841, '\p{Is_Numeric_Value=0000000060000}', "");
Expect(1, 65841, '\p{^Is_Numeric_Value=0000000060000}', "");
Expect(1, 65841, '\P{Is_Numeric_Value=0000000060000}', "");
Expect(0, 65841, '\P{^Is_Numeric_Value=0000000060000}', "");
Error('\p{Is_Nv= /a/+0_0_0_0_6_0_000}');
Error('\P{Is_Nv= /a/+0_0_0_0_6_0_000}');
Expect(1, 65840, '\p{Is_Nv=000000060000}', "");
Expect(0, 65840, '\p{^Is_Nv=000000060000}', "");
Expect(0, 65840, '\P{Is_Nv=000000060000}', "");
Expect(1, 65840, '\P{^Is_Nv=000000060000}', "");
Expect(0, 65841, '\p{Is_Nv=000000060000}', "");
Expect(1, 65841, '\p{^Is_Nv=000000060000}', "");
Expect(1, 65841, '\P{Is_Nv=000000060000}', "");
Expect(0, 65841, '\P{^Is_Nv=000000060000}', "");
Error('\p{Numeric_Value=/a/__+000000_7}');
Error('\P{Numeric_Value=/a/__+000000_7}');
Expect(1, 131073, '\p{Numeric_Value:   000007}', "");
Expect(0, 131073, '\p{^Numeric_Value:   000007}', "");
Expect(0, 131073, '\P{Numeric_Value:   000007}', "");
Expect(1, 131073, '\P{^Numeric_Value:   000007}', "");
Expect(0, 131074, '\p{Numeric_Value:   000007}', "");
Expect(1, 131074, '\p{^Numeric_Value:   000007}', "");
Expect(1, 131074, '\P{Numeric_Value:   000007}', "");
Expect(0, 131074, '\P{^Numeric_Value:   000007}', "");
Error('\p{Nv=:= 	0007}');
Error('\P{Nv=:= 	0007}');
Expect(1, 131073, '\p{Nv:+7}', "");
Expect(0, 131073, '\p{^Nv:+7}', "");
Expect(0, 131073, '\P{Nv:+7}', "");
Expect(1, 131073, '\P{^Nv:+7}', "");
Expect(0, 131074, '\p{Nv:+7}', "");
Expect(1, 131074, '\p{^Nv:+7}', "");
Expect(1, 131074, '\P{Nv:+7}', "");
Expect(0, 131074, '\P{^Nv:+7}', "");
Error('\p{Is_Numeric_Value:-:=00_00_00_007}');
Error('\P{Is_Numeric_Value:-:=00_00_00_007}');
Expect(1, 131073, '\p{Is_Numeric_Value=0007}', "");
Expect(0, 131073, '\p{^Is_Numeric_Value=0007}', "");
Expect(0, 131073, '\P{Is_Numeric_Value=0007}', "");
Expect(1, 131073, '\P{^Is_Numeric_Value=0007}', "");
Expect(0, 131074, '\p{Is_Numeric_Value=0007}', "");
Expect(1, 131074, '\p{^Is_Numeric_Value=0007}', "");
Expect(1, 131074, '\P{Is_Numeric_Value=0007}', "");
Expect(0, 131074, '\P{^Is_Numeric_Value=0007}', "");
Error('\p{Is_Nv=/a/	_0_0_0_0_0_07}');
Error('\P{Is_Nv=/a/	_0_0_0_0_0_07}');
Expect(1, 131073, '\p{Is_Nv=0007}', "");
Expect(0, 131073, '\p{^Is_Nv=0007}', "");
Expect(0, 131073, '\P{Is_Nv=0007}', "");
Expect(1, 131073, '\P{^Is_Nv=0007}', "");
Expect(0, 131074, '\p{Is_Nv=0007}', "");
Expect(1, 131074, '\p{^Is_Nv=0007}', "");
Expect(1, 131074, '\P{Is_Nv=0007}', "");
Expect(0, 131074, '\P{^Is_Nv=0007}', "");
Error('\p{Numeric_Value:	 000007/0002/a/}');
Error('\P{Numeric_Value:	 000007/0002/a/}');
Expect(1, 3885, '\p{Numeric_Value:	7/2}', "");
Expect(0, 3885, '\p{^Numeric_Value:	7/2}', "");
Expect(0, 3885, '\P{Numeric_Value:	7/2}', "");
Expect(1, 3885, '\P{^Numeric_Value:	7/2}', "");
Expect(0, 3886, '\p{Numeric_Value:	7/2}', "");
Expect(1, 3886, '\p{^Numeric_Value:	7/2}', "");
Expect(1, 3886, '\P{Numeric_Value:	7/2}', "");
Expect(0, 3886, '\P{^Numeric_Value:	7/2}', "");
Expect(1, 3885, '\p{Numeric_Value=3.500}', "");
Expect(0, 3885, '\p{^Numeric_Value=3.500}', "");
Expect(0, 3885, '\P{Numeric_Value=3.500}', "");
Expect(1, 3885, '\P{^Numeric_Value=3.500}', "");
Expect(0, 3886, '\p{Numeric_Value=3.500}', "");
Expect(1, 3886, '\p{^Numeric_Value=3.500}', "");
Expect(1, 3886, '\P{Numeric_Value=3.500}', "");
Expect(0, 3886, '\P{^Numeric_Value=3.500}', "");
Error('\p{Nv=	-+0007/00002/a/}');
Error('\P{Nv=	-+0007/00002/a/}');
Expect(1, 3885, '\p{Nv=+7/000002}', "");
Expect(0, 3885, '\p{^Nv=+7/000002}', "");
Expect(0, 3885, '\P{Nv=+7/000002}', "");
Expect(1, 3885, '\P{^Nv=+7/000002}', "");
Expect(0, 3886, '\p{Nv=+7/000002}', "");
Expect(1, 3886, '\p{^Nv=+7/000002}', "");
Expect(1, 3886, '\P{Nv=+7/000002}', "");
Expect(0, 3886, '\P{^Nv=+7/000002}', "");
Expect(1, 3885, '\p{Nv=3.500}', "");
Expect(0, 3885, '\p{^Nv=3.500}', "");
Expect(0, 3885, '\P{Nv=3.500}', "");
Expect(1, 3885, '\P{^Nv=3.500}', "");
Expect(0, 3886, '\p{Nv=3.500}', "");
Expect(1, 3886, '\p{^Nv=3.500}', "");
Expect(1, 3886, '\P{Nv=3.500}', "");
Expect(0, 3886, '\P{^Nv=3.500}', "");
Error('\p{Is_Numeric_Value=	/a/0007/00000002}');
Error('\P{Is_Numeric_Value=	/a/0007/00000002}');
Expect(1, 3885, '\p{Is_Numeric_Value=00000007/2}', "");
Expect(0, 3885, '\p{^Is_Numeric_Value=00000007/2}', "");
Expect(0, 3885, '\P{Is_Numeric_Value=00000007/2}', "");
Expect(1, 3885, '\P{^Is_Numeric_Value=00000007/2}', "");
Expect(0, 3886, '\p{Is_Numeric_Value=00000007/2}', "");
Expect(1, 3886, '\p{^Is_Numeric_Value=00000007/2}', "");
Expect(1, 3886, '\P{Is_Numeric_Value=00000007/2}', "");
Expect(0, 3886, '\P{^Is_Numeric_Value=00000007/2}', "");
Expect(1, 3885, '\p{Is_Numeric_Value:	3.500}', "");
Expect(0, 3885, '\p{^Is_Numeric_Value:	3.500}', "");
Expect(0, 3885, '\P{Is_Numeric_Value:	3.500}', "");
Expect(1, 3885, '\P{^Is_Numeric_Value:	3.500}', "");
Expect(0, 3886, '\p{Is_Numeric_Value:	3.500}', "");
Expect(1, 3886, '\p{^Is_Numeric_Value:	3.500}', "");
Expect(1, 3886, '\P{Is_Numeric_Value:	3.500}', "");
Expect(0, 3886, '\P{^Is_Numeric_Value:	3.500}', "");
Error('\p{Is_Nv=_ 07/00000002/a/}');
Error('\P{Is_Nv=_ 07/00000002/a/}');
Expect(1, 3885, '\p{Is_Nv=07/000000002}', "");
Expect(0, 3885, '\p{^Is_Nv=07/000000002}', "");
Expect(0, 3885, '\P{Is_Nv=07/000000002}', "");
Expect(1, 3885, '\P{^Is_Nv=07/000000002}', "");
Expect(0, 3886, '\p{Is_Nv=07/000000002}', "");
Expect(1, 3886, '\p{^Is_Nv=07/000000002}', "");
Expect(1, 3886, '\P{Is_Nv=07/000000002}', "");
Expect(0, 3886, '\P{^Is_Nv=07/000000002}', "");
Expect(1, 3885, '\p{Is_Nv=3.500}', "");
Expect(0, 3885, '\p{^Is_Nv=3.500}', "");
Expect(0, 3885, '\P{Is_Nv=3.500}', "");
Expect(1, 3885, '\P{^Is_Nv=3.500}', "");
Expect(0, 3886, '\p{Is_Nv=3.500}', "");
Expect(1, 3886, '\p{^Is_Nv=3.500}', "");
Expect(1, 3886, '\P{Is_Nv=3.500}', "");
Expect(0, 3886, '\P{^Is_Nv=3.500}', "");
Error('\p{Numeric_Value=	_00007/0008/a/}');
Error('\P{Numeric_Value=	_00007/0008/a/}');
Expect(1, 8542, '\p{Numeric_Value=7/0000008}', "");
Expect(0, 8542, '\p{^Numeric_Value=7/0000008}', "");
Expect(0, 8542, '\P{Numeric_Value=7/0000008}', "");
Expect(1, 8542, '\P{^Numeric_Value=7/0000008}', "");
Expect(0, 8543, '\p{Numeric_Value=7/0000008}', "");
Expect(1, 8543, '\p{^Numeric_Value=7/0000008}', "");
Expect(1, 8543, '\P{Numeric_Value=7/0000008}', "");
Expect(0, 8543, '\P{^Numeric_Value=7/0000008}', "");
Error('\p{Numeric_Value=0.9}');
Error('\P{Numeric_Value=0.9}');
Error('\p{Numeric_Value=0.88}');
Error('\P{Numeric_Value=0.88}');
Expect(1, 8542, '\p{Numeric_Value=0.875}', "");
Expect(0, 8542, '\p{^Numeric_Value=0.875}', "");
Expect(0, 8542, '\P{Numeric_Value=0.875}', "");
Expect(1, 8542, '\P{^Numeric_Value=0.875}', "");
Expect(0, 8543, '\p{Numeric_Value=0.875}', "");
Expect(1, 8543, '\p{^Numeric_Value=0.875}', "");
Expect(1, 8543, '\P{Numeric_Value=0.875}', "");
Expect(0, 8543, '\P{^Numeric_Value=0.875}', "");
Error('\p{Nv=_-+7/000008:=}');
Error('\P{Nv=_-+7/000008:=}');
Expect(1, 8542, '\p{Nv=000007/8}', "");
Expect(0, 8542, '\p{^Nv=000007/8}', "");
Expect(0, 8542, '\P{Nv=000007/8}', "");
Expect(1, 8542, '\P{^Nv=000007/8}', "");
Expect(0, 8543, '\p{Nv=000007/8}', "");
Expect(1, 8543, '\p{^Nv=000007/8}', "");
Expect(1, 8543, '\P{Nv=000007/8}', "");
Expect(0, 8543, '\P{^Nv=000007/8}', "");
Error('\p{Nv=0.9}');
Error('\P{Nv=0.9}');
Error('\p{Nv:	0.88}');
Error('\P{Nv:	0.88}');
Expect(1, 8542, '\p{Nv=0.875}', "");
Expect(0, 8542, '\p{^Nv=0.875}', "");
Expect(0, 8542, '\P{Nv=0.875}', "");
Expect(1, 8542, '\P{^Nv=0.875}', "");
Expect(0, 8543, '\p{Nv=0.875}', "");
Expect(1, 8543, '\p{^Nv=0.875}', "");
Expect(1, 8543, '\P{Nv=0.875}', "");
Expect(0, 8543, '\P{^Nv=0.875}', "");
Error('\p{Is_Numeric_Value:--0000000007/008:=}');
Error('\P{Is_Numeric_Value:--0000000007/008:=}');
Expect(1, 8542, '\p{Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8542, '\p{^Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8542, '\P{Is_Numeric_Value=00007/000000008}', "");
Expect(1, 8542, '\P{^Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8543, '\p{Is_Numeric_Value=00007/000000008}', "");
Expect(1, 8543, '\p{^Is_Numeric_Value=00007/000000008}', "");
Expect(1, 8543, '\P{Is_Numeric_Value=00007/000000008}', "");
Expect(0, 8543, '\P{^Is_Numeric_Value=00007/000000008}', "");
Error('\p{Is_Numeric_Value=0.9}');
Error('\P{Is_Numeric_Value=0.9}');
Error('\p{Is_Numeric_Value=0.88}');
Error('\P{Is_Numeric_Value=0.88}');
Expect(1, 8542, '\p{Is_Numeric_Value=0.875}', "");
Expect(0, 8542, '\p{^Is_Numeric_Value=0.875}', "");
Expect(0, 8542, '\P{Is_Numeric_Value=0.875}', "");
Expect(1, 8542, '\P{^Is_Numeric_Value=0.875}', "");
Expect(0, 8543, '\p{Is_Numeric_Value=0.875}', "");
Expect(1, 8543, '\p{^Is_Numeric_Value=0.875}', "");
Expect(1, 8543, '\P{Is_Numeric_Value=0.875}', "");
Expect(0, 8543, '\P{^Is_Numeric_Value=0.875}', "");
Error('\p{Is_Nv=-	+000000007/008/a/}');
Error('\P{Is_Nv=-	+000000007/008/a/}');
Expect(1, 8542, '\p{Is_Nv=00007/0000008}', "");
Expect(0, 8542, '\p{^Is_Nv=00007/0000008}', "");
Expect(0, 8542, '\P{Is_Nv=00007/0000008}', "");
Expect(1, 8542, '\P{^Is_Nv=00007/0000008}', "");
Expect(0, 8543, '\p{Is_Nv=00007/0000008}', "");
Expect(1, 8543, '\p{^Is_Nv=00007/0000008}', "");
Expect(1, 8543, '\P{Is_Nv=00007/0000008}', "");
Expect(0, 8543, '\P{^Is_Nv=00007/0000008}', "");
Error('\p{Is_Nv=0.9}');
Error('\P{Is_Nv=0.9}');
Error('\p{Is_Nv=0.88}');
Error('\P{Is_Nv=0.88}');
Expect(1, 8542, '\p{Is_Nv=0.875}', "");
Expect(0, 8542, '\p{^Is_Nv=0.875}', "");
Expect(0, 8542, '\P{Is_Nv=0.875}', "");
Expect(1, 8542, '\P{^Is_Nv=0.875}', "");
Expect(0, 8543, '\p{Is_Nv=0.875}', "");
Expect(1, 8543, '\p{^Is_Nv=0.875}', "");
Expect(1, 8543, '\P{Is_Nv=0.875}', "");
Expect(0, 8543, '\P{^Is_Nv=0.875}', "");
Error('\p{Numeric_Value= -0_0_70:=}');
Error('\P{Numeric_Value= -0_0_70:=}');
Expect(1, 119663, '\p{Numeric_Value=0000070}', "");
Expect(0, 119663, '\p{^Numeric_Value=0000070}', "");
Expect(0, 119663, '\P{Numeric_Value=0000070}', "");
Expect(1, 119663, '\P{^Numeric_Value=0000070}', "");
Expect(0, 119664, '\p{Numeric_Value=0000070}', "");
Expect(1, 119664, '\p{^Numeric_Value=0000070}', "");
Expect(1, 119664, '\P{Numeric_Value=0000070}', "");
Expect(0, 119664, '\P{^Numeric_Value=0000070}', "");
Error('\p{Nv=/a/_	+070}');
Error('\P{Nv=/a/_	+070}');
Expect(1, 119663, '\p{Nv=000070}', "");
Expect(0, 119663, '\p{^Nv=000070}', "");
Expect(0, 119663, '\P{Nv=000070}', "");
Expect(1, 119663, '\P{^Nv=000070}', "");
Expect(0, 119664, '\p{Nv=000070}', "");
Expect(1, 119664, '\p{^Nv=000070}', "");
Expect(1, 119664, '\P{Nv=000070}', "");
Expect(0, 119664, '\P{^Nv=000070}', "");
Error('\p{Is_Numeric_Value=-_0_0_0_0_0_0_0070/a/}');
Error('\P{Is_Numeric_Value=-_0_0_0_0_0_0_0070/a/}');
Expect(1, 119663, '\p{Is_Numeric_Value=+00_00_00_70}', "");
Expect(0, 119663, '\p{^Is_Numeric_Value=+00_00_00_70}', "");
Expect(0, 119663, '\P{Is_Numeric_Value=+00_00_00_70}', "");
Expect(1, 119663, '\P{^Is_Numeric_Value=+00_00_00_70}', "");
Expect(0, 119664, '\p{Is_Numeric_Value=+00_00_00_70}', "");
Expect(1, 119664, '\p{^Is_Numeric_Value=+00_00_00_70}', "");
Expect(1, 119664, '\P{Is_Numeric_Value=+00_00_00_70}', "");
Expect(0, 119664, '\P{^Is_Numeric_Value=+00_00_00_70}', "");
Error('\p{Is_Nv=/a/-	0_0_0_070}');
Error('\P{Is_Nv=/a/-	0_0_0_070}');
Expect(1, 119663, '\p{Is_Nv: 00000070}', "");
Expect(0, 119663, '\p{^Is_Nv: 00000070}', "");
Expect(0, 119663, '\P{Is_Nv: 00000070}', "");
Expect(1, 119663, '\P{^Is_Nv: 00000070}', "");
Expect(0, 119664, '\p{Is_Nv: 00000070}', "");
Expect(1, 119664, '\p{^Is_Nv: 00000070}', "");
Expect(1, 119664, '\P{Is_Nv: 00000070}', "");
Expect(0, 119664, '\P{^Is_Nv: 00000070}', "");
Error('\p{Numeric_Value=/a/		00000700}');
Error('\P{Numeric_Value=/a/		00000700}');
Expect(1, 69240, '\p{Numeric_Value=0_7_00}', "");
Expect(0, 69240, '\p{^Numeric_Value=0_7_00}', "");
Expect(0, 69240, '\P{Numeric_Value=0_7_00}', "");
Expect(1, 69240, '\P{^Numeric_Value=0_7_00}', "");
Expect(0, 69241, '\p{Numeric_Value=0_7_00}', "");
Expect(1, 69241, '\p{^Numeric_Value=0_7_00}', "");
Expect(1, 69241, '\P{Numeric_Value=0_7_00}', "");
Expect(0, 69241, '\P{^Numeric_Value=0_7_00}', "");
Error('\p{Nv=_:=70_0}');
Error('\P{Nv=_:=70_0}');
Expect(1, 69240, '\p{Nv=+000000000700}', "");
Expect(0, 69240, '\p{^Nv=+000000000700}', "");
Expect(0, 69240, '\P{Nv=+000000000700}', "");
Expect(1, 69240, '\P{^Nv=+000000000700}', "");
Expect(0, 69241, '\p{Nv=+000000000700}', "");
Expect(1, 69241, '\p{^Nv=+000000000700}', "");
Expect(1, 69241, '\P{Nv=+000000000700}', "");
Expect(0, 69241, '\P{^Nv=+000000000700}', "");
Error('\p{Is_Numeric_Value= /a/0000700}');
Error('\P{Is_Numeric_Value= /a/0000700}');
Expect(1, 69240, '\p{Is_Numeric_Value=+0000_0070_0}', "");
Expect(0, 69240, '\p{^Is_Numeric_Value=+0000_0070_0}', "");
Expect(0, 69240, '\P{Is_Numeric_Value=+0000_0070_0}', "");
Expect(1, 69240, '\P{^Is_Numeric_Value=+0000_0070_0}', "");
Expect(0, 69241, '\p{Is_Numeric_Value=+0000_0070_0}', "");
Expect(1, 69241, '\p{^Is_Numeric_Value=+0000_0070_0}', "");
Expect(1, 69241, '\P{Is_Numeric_Value=+0000_0070_0}', "");
Expect(0, 69241, '\P{^Is_Numeric_Value=+0000_0070_0}', "");
Error('\p{Is_Nv=/a/-0000_0007_00}');
Error('\P{Is_Nv=/a/-0000_0007_00}');
Expect(1, 69240, '\p{Is_Nv=+0000000700}', "");
Expect(0, 69240, '\p{^Is_Nv=+0000000700}', "");
Expect(0, 69240, '\P{Is_Nv=+0000000700}', "");
Expect(1, 69240, '\P{^Is_Nv=+0000000700}', "");
Expect(0, 69241, '\p{Is_Nv=+0000000700}', "");
Expect(1, 69241, '\p{^Is_Nv=+0000000700}', "");
Expect(1, 69241, '\P{Is_Nv=+0000000700}', "");
Expect(0, 69241, '\P{^Is_Nv=+0000000700}', "");
Error('\p{Numeric_Value=/a/000000000700_0}');
Error('\P{Numeric_Value=/a/000000000700_0}');
Expect(1, 65832, '\p{Numeric_Value=0000000007000}', "");
Expect(0, 65832, '\p{^Numeric_Value=0000000007000}', "");
Expect(0, 65832, '\P{Numeric_Value=0000000007000}', "");
Expect(1, 65832, '\P{^Numeric_Value=0000000007000}', "");
Expect(0, 65833, '\p{Numeric_Value=0000000007000}', "");
Expect(1, 65833, '\p{^Numeric_Value=0000000007000}', "");
Expect(1, 65833, '\P{Numeric_Value=0000000007000}', "");
Expect(0, 65833, '\P{^Numeric_Value=0000000007000}', "");
Error('\p{Nv=-/a/0_0_0_0_0_0_0_0_0_7_000}');
Error('\P{Nv=-/a/0_0_0_0_0_0_0_0_0_7_000}');
Expect(1, 65832, '\p{Nv=0_0_0_7_000}', "");
Expect(0, 65832, '\p{^Nv=0_0_0_7_000}', "");
Expect(0, 65832, '\P{Nv=0_0_0_7_000}', "");
Expect(1, 65832, '\P{^Nv=0_0_0_7_000}', "");
Expect(0, 65833, '\p{Nv=0_0_0_7_000}', "");
Expect(1, 65833, '\p{^Nv=0_0_0_7_000}', "");
Expect(1, 65833, '\P{Nv=0_0_0_7_000}', "");
Expect(0, 65833, '\P{^Nv=0_0_0_7_000}', "");
Error('\p{Is_Numeric_Value=_	7_0_00:=}');
Error('\P{Is_Numeric_Value=_	7_0_00:=}');
Expect(1, 65832, '\p{Is_Numeric_Value:0000007000}', "");
Expect(0, 65832, '\p{^Is_Numeric_Value:0000007000}', "");
Expect(0, 65832, '\P{Is_Numeric_Value:0000007000}', "");
Expect(1, 65832, '\P{^Is_Numeric_Value:0000007000}', "");
Expect(0, 65833, '\p{Is_Numeric_Value:0000007000}', "");
Expect(1, 65833, '\p{^Is_Numeric_Value:0000007000}', "");
Expect(1, 65833, '\P{Is_Numeric_Value:0000007000}', "");
Expect(0, 65833, '\P{^Is_Numeric_Value:0000007000}', "");
Error('\p{Is_Nv=:=_ 0007000}');
Error('\P{Is_Nv=:=_ 0007000}');
Expect(1, 65832, '\p{Is_Nv=+0007000}', "");
Expect(0, 65832, '\p{^Is_Nv=+0007000}', "");
Expect(0, 65832, '\P{Is_Nv=+0007000}', "");
Expect(1, 65832, '\P{^Is_Nv=+0007000}', "");
Expect(0, 65833, '\p{Is_Nv=+0007000}', "");
Expect(1, 65833, '\p{^Is_Nv=+0007000}', "");
Expect(1, 65833, '\P{Is_Nv=+0007000}', "");
Expect(0, 65833, '\P{^Is_Nv=+0007000}', "");
Error('\p{Numeric_Value=	_0000070000/a/}');
Error('\P{Numeric_Value=	_0000070000/a/}');
Expect(1, 65841, '\p{Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(0, 65841, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(0, 65841, '\P{Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(1, 65841, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(0, 65842, '\p{Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(1, 65842, '\p{^Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(1, 65842, '\P{Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Expect(0, 65842, '\P{^Numeric_Value=0_0_0_0_0_0_0_0_0_7_0_000}', "");
Error('\p{Nv=-/a/+70000}');
Error('\P{Nv=-/a/+70000}');
Expect(1, 65841, '\p{Nv=+0000000070000}', "");
Expect(0, 65841, '\p{^Nv=+0000000070000}', "");
Expect(0, 65841, '\P{Nv=+0000000070000}', "");
Expect(1, 65841, '\P{^Nv=+0000000070000}', "");
Expect(0, 65842, '\p{Nv=+0000000070000}', "");
Expect(1, 65842, '\p{^Nv=+0000000070000}', "");
Expect(1, 65842, '\P{Nv=+0000000070000}', "");
Expect(0, 65842, '\P{^Nv=+0000000070000}', "");
Error('\p{Is_Numeric_Value:/a/0000000070000}');
Error('\P{Is_Numeric_Value:/a/0000000070000}');
Expect(1, 65841, '\p{Is_Numeric_Value=+000070000}', "");
Expect(0, 65841, '\p{^Is_Numeric_Value=+000070000}', "");
Expect(0, 65841, '\P{Is_Numeric_Value=+000070000}', "");
Expect(1, 65841, '\P{^Is_Numeric_Value=+000070000}', "");
Expect(0, 65842, '\p{Is_Numeric_Value=+000070000}', "");
Expect(1, 65842, '\p{^Is_Numeric_Value=+000070000}', "");
Expect(1, 65842, '\P{Is_Numeric_Value=+000070000}', "");
Expect(0, 65842, '\P{^Is_Numeric_Value=+000070000}', "");
Error('\p{Is_Nv= -070000:=}');
Error('\P{Is_Nv= -070000:=}');
Expect(1, 65841, '\p{Is_Nv=00000000070000}', "");
Expect(0, 65841, '\p{^Is_Nv=00000000070000}', "");
Expect(0, 65841, '\P{Is_Nv=00000000070000}', "");
Expect(1, 65841, '\P{^Is_Nv=00000000070000}', "");
Expect(0, 65842, '\p{Is_Nv=00000000070000}', "");
Expect(1, 65842, '\p{^Is_Nv=00000000070000}', "");
Expect(1, 65842, '\P{Is_Nv=00000000070000}', "");
Expect(0, 65842, '\P{^Is_Nv=00000000070000}', "");
Error('\p{Numeric_Value= :=000_000_08}');
Error('\P{Numeric_Value= :=000_000_08}');
Expect(1, 127241, '\p{Numeric_Value=00_8}', "");
Expect(0, 127241, '\p{^Numeric_Value=00_8}', "");
Expect(0, 127241, '\P{Numeric_Value=00_8}', "");
Expect(1, 127241, '\P{^Numeric_Value=00_8}', "");
Expect(0, 127242, '\p{Numeric_Value=00_8}', "");
Expect(1, 127242, '\p{^Numeric_Value=00_8}', "");
Expect(1, 127242, '\P{Numeric_Value=00_8}', "");
Expect(0, 127242, '\P{^Numeric_Value=00_8}', "");
Error('\p{Nv=-+000000000_8/a/}');
Error('\P{Nv=-+000000000_8/a/}');
Expect(1, 127241, '\p{Nv=000_000_08}', "");
Expect(0, 127241, '\p{^Nv=000_000_08}', "");
Expect(0, 127241, '\P{Nv=000_000_08}', "");
Expect(1, 127241, '\P{^Nv=000_000_08}', "");
Expect(0, 127242, '\p{Nv=000_000_08}', "");
Expect(1, 127242, '\p{^Nv=000_000_08}', "");
Expect(1, 127242, '\P{Nv=000_000_08}', "");
Expect(0, 127242, '\P{^Nv=000_000_08}', "");
Error('\p{Is_Numeric_Value=_+0000000008:=}');
Error('\P{Is_Numeric_Value=_+0000000008:=}');
Expect(1, 127241, '\p{Is_Numeric_Value=0000000_8}', "");
Expect(0, 127241, '\p{^Is_Numeric_Value=0000000_8}', "");
Expect(0, 127241, '\P{Is_Numeric_Value=0000000_8}', "");
Expect(1, 127241, '\P{^Is_Numeric_Value=0000000_8}', "");
Expect(0, 127242, '\p{Is_Numeric_Value=0000000_8}', "");
Expect(1, 127242, '\p{^Is_Numeric_Value=0000000_8}', "");
Expect(1, 127242, '\P{Is_Numeric_Value=0000000_8}', "");
Expect(0, 127242, '\P{^Is_Numeric_Value=0000000_8}', "");
Error('\p{Is_Nv=/a/	08}');
Error('\P{Is_Nv=/a/	08}');
Expect(1, 127241, '\p{Is_Nv=008}', "");
Expect(0, 127241, '\p{^Is_Nv=008}', "");
Expect(0, 127241, '\P{Is_Nv=008}', "");
Expect(1, 127241, '\P{^Is_Nv=008}', "");
Expect(0, 127242, '\p{Is_Nv=008}', "");
Expect(1, 127242, '\p{^Is_Nv=008}', "");
Expect(1, 127242, '\P{Is_Nv=008}', "");
Expect(0, 127242, '\P{^Is_Nv=008}', "");
Error('\p{Numeric_Value=		00080/a/}');
Error('\P{Numeric_Value=		00080/a/}');
Expect(1, 119664, '\p{Numeric_Value=+0080}', "");
Expect(0, 119664, '\p{^Numeric_Value=+0080}', "");
Expect(0, 119664, '\P{Numeric_Value=+0080}', "");
Expect(1, 119664, '\P{^Numeric_Value=+0080}', "");
Expect(0, 119665, '\p{Numeric_Value=+0080}', "");
Expect(1, 119665, '\p{^Numeric_Value=+0080}', "");
Expect(1, 119665, '\P{Numeric_Value=+0080}', "");
Expect(0, 119665, '\P{^Numeric_Value=+0080}', "");
Error('\p{Nv= :=000000080}');
Error('\P{Nv= :=000000080}');
Expect(1, 119664, '\p{Nv=+00000080}', "");
Expect(0, 119664, '\p{^Nv=+00000080}', "");
Expect(0, 119664, '\P{Nv=+00000080}', "");
Expect(1, 119664, '\P{^Nv=+00000080}', "");
Expect(0, 119665, '\p{Nv=+00000080}', "");
Expect(1, 119665, '\p{^Nv=+00000080}', "");
Expect(1, 119665, '\P{Nv=+00000080}', "");
Expect(0, 119665, '\P{^Nv=+00000080}', "");
Error('\p{Is_Numeric_Value=_/a/0_0_0_0_0080}');
Error('\P{Is_Numeric_Value=_/a/0_0_0_0_0080}');
Expect(1, 119664, '\p{Is_Numeric_Value=0080}', "");
Expect(0, 119664, '\p{^Is_Numeric_Value=0080}', "");
Expect(0, 119664, '\P{Is_Numeric_Value=0080}', "");
Expect(1, 119664, '\P{^Is_Numeric_Value=0080}', "");
Expect(0, 119665, '\p{Is_Numeric_Value=0080}', "");
Expect(1, 119665, '\p{^Is_Numeric_Value=0080}', "");
Expect(1, 119665, '\P{Is_Numeric_Value=0080}', "");
Expect(0, 119665, '\P{^Is_Numeric_Value=0080}', "");
Error('\p{Is_Nv=/a/- 008_0}');
Error('\P{Is_Nv=/a/- 008_0}');
Expect(1, 119664, '\p{Is_Nv=+0_0_0_0_0_80}', "");
Expect(0, 119664, '\p{^Is_Nv=+0_0_0_0_0_80}', "");
Expect(0, 119664, '\P{Is_Nv=+0_0_0_0_0_80}', "");
Expect(1, 119664, '\P{^Is_Nv=+0_0_0_0_0_80}', "");
Expect(0, 119665, '\p{Is_Nv=+0_0_0_0_0_80}', "");
Expect(1, 119665, '\p{^Is_Nv=+0_0_0_0_0_80}', "");
Expect(1, 119665, '\P{Is_Nv=+0_0_0_0_0_80}', "");
Expect(0, 119665, '\P{^Is_Nv=+0_0_0_0_0_80}', "");
Error('\p{Numeric_Value=_/a/00000800}');
Error('\P{Numeric_Value=_/a/00000800}');
Expect(1, 69241, '\p{Numeric_Value=0_0_8_00}', "");
Expect(0, 69241, '\p{^Numeric_Value=0_0_8_00}', "");
Expect(0, 69241, '\P{Numeric_Value=0_0_8_00}', "");
Expect(1, 69241, '\P{^Numeric_Value=0_0_8_00}', "");
Expect(0, 69242, '\p{Numeric_Value=0_0_8_00}', "");
Expect(1, 69242, '\p{^Numeric_Value=0_0_8_00}', "");
Expect(1, 69242, '\P{Numeric_Value=0_0_8_00}', "");
Expect(0, 69242, '\P{^Numeric_Value=0_0_8_00}', "");
Error('\p{Nv=:=-+00000000800}');
Error('\P{Nv=:=-+00000000800}');
Expect(1, 69241, '\p{Nv=+0_0_0_0_0_0_000800}', "");
Expect(0, 69241, '\p{^Nv=+0_0_0_0_0_0_000800}', "");
Expect(0, 69241, '\P{Nv=+0_0_0_0_0_0_000800}', "");
Expect(1, 69241, '\P{^Nv=+0_0_0_0_0_0_000800}', "");
Expect(0, 69242, '\p{Nv=+0_0_0_0_0_0_000800}', "");
Expect(1, 69242, '\p{^Nv=+0_0_0_0_0_0_000800}', "");
Expect(1, 69242, '\P{Nv=+0_0_0_0_0_0_000800}', "");
Expect(0, 69242, '\P{^Nv=+0_0_0_0_0_0_000800}', "");
Error('\p{Is_Numeric_Value=/a/00000000800}');
Error('\P{Is_Numeric_Value=/a/00000000800}');
Expect(1, 69241, '\p{Is_Numeric_Value=+800}', "");
Expect(0, 69241, '\p{^Is_Numeric_Value=+800}', "");
Expect(0, 69241, '\P{Is_Numeric_Value=+800}', "");
Expect(1, 69241, '\P{^Is_Numeric_Value=+800}', "");
Expect(0, 69242, '\p{Is_Numeric_Value=+800}', "");
Expect(1, 69242, '\p{^Is_Numeric_Value=+800}', "");
Expect(1, 69242, '\P{Is_Numeric_Value=+800}', "");
Expect(0, 69242, '\P{^Is_Numeric_Value=+800}', "");
Error('\p{Is_Nv= 	+0000000800/a/}');
Error('\P{Is_Nv= 	+0000000800/a/}');
Expect(1, 69241, '\p{Is_Nv=00000000800}', "");
Expect(0, 69241, '\p{^Is_Nv=00000000800}', "");
Expect(0, 69241, '\P{Is_Nv=00000000800}', "");
Expect(1, 69241, '\P{^Is_Nv=00000000800}', "");
Expect(0, 69242, '\p{Is_Nv=00000000800}', "");
Expect(1, 69242, '\p{^Is_Nv=00000000800}', "");
Expect(1, 69242, '\P{Is_Nv=00000000800}', "");
Expect(0, 69242, '\P{^Is_Nv=00000000800}', "");
Error('\p{Numeric_Value=-00_00_00_80_00/a/}');
Error('\P{Numeric_Value=-00_00_00_80_00/a/}');
Expect(1, 65833, '\p{Numeric_Value=000008000}', "");
Expect(0, 65833, '\p{^Numeric_Value=000008000}', "");
Expect(0, 65833, '\P{Numeric_Value=000008000}', "");
Expect(1, 65833, '\P{^Numeric_Value=000008000}', "");
Expect(0, 65834, '\p{Numeric_Value=000008000}', "");
Expect(1, 65834, '\p{^Numeric_Value=000008000}', "");
Expect(1, 65834, '\P{Numeric_Value=000008000}', "");
Expect(0, 65834, '\P{^Numeric_Value=000008000}', "");
Error('\p{Nv=:=_-00800_0}');
Error('\P{Nv=:=_-00800_0}');
Expect(1, 65833, '\p{Nv=00_00_00_80_00}', "");
Expect(0, 65833, '\p{^Nv=00_00_00_80_00}', "");
Expect(0, 65833, '\P{Nv=00_00_00_80_00}', "");
Expect(1, 65833, '\P{^Nv=00_00_00_80_00}', "");
Expect(0, 65834, '\p{Nv=00_00_00_80_00}', "");
Expect(1, 65834, '\p{^Nv=00_00_00_80_00}', "");
Expect(1, 65834, '\P{Nv=00_00_00_80_00}', "");
Expect(0, 65834, '\P{^Nv=00_00_00_80_00}', "");
Error('\p{Is_Numeric_Value=_:=000000008000}');
Error('\P{Is_Numeric_Value=_:=000000008000}');
Expect(1, 65833, '\p{Is_Numeric_Value=8000}', "");
Expect(0, 65833, '\p{^Is_Numeric_Value=8000}', "");
Expect(0, 65833, '\P{Is_Numeric_Value=8000}', "");
Expect(1, 65833, '\P{^Is_Numeric_Value=8000}', "");
Expect(0, 65834, '\p{Is_Numeric_Value=8000}', "");
Expect(1, 65834, '\p{^Is_Numeric_Value=8000}', "");
Expect(1, 65834, '\P{Is_Numeric_Value=8000}', "");
Expect(0, 65834, '\P{^Is_Numeric_Value=8000}', "");
Error('\p{Is_Nv=/a/	+8000}');
Error('\P{Is_Nv=/a/	+8000}');
Expect(1, 65833, '\p{Is_Nv=00008000}', "");
Expect(0, 65833, '\p{^Is_Nv=00008000}', "");
Expect(0, 65833, '\P{Is_Nv=00008000}', "");
Expect(1, 65833, '\P{^Is_Nv=00008000}', "");
Expect(0, 65834, '\p{Is_Nv=00008000}', "");
Expect(1, 65834, '\p{^Is_Nv=00008000}', "");
Expect(1, 65834, '\P{Is_Nv=00008000}', "");
Expect(0, 65834, '\P{^Is_Nv=00008000}', "");
Error('\p{Numeric_Value=/a/	-08000_0}');
Error('\P{Numeric_Value=/a/	-08000_0}');
Expect(1, 65842, '\p{Numeric_Value=0080000}', "");
Expect(0, 65842, '\p{^Numeric_Value=0080000}', "");
Expect(0, 65842, '\P{Numeric_Value=0080000}', "");
Expect(1, 65842, '\P{^Numeric_Value=0080000}', "");
Expect(0, 65843, '\p{Numeric_Value=0080000}', "");
Expect(1, 65843, '\p{^Numeric_Value=0080000}', "");
Expect(1, 65843, '\P{Numeric_Value=0080000}', "");
Expect(0, 65843, '\P{^Numeric_Value=0080000}', "");
Error('\p{Nv=-:=+00000080000}');
Error('\P{Nv=-:=+00000080000}');
Expect(1, 65842, '\p{Nv=+80000}', "");
Expect(0, 65842, '\p{^Nv=+80000}', "");
Expect(0, 65842, '\P{Nv=+80000}', "");
Expect(1, 65842, '\P{^Nv=+80000}', "");
Expect(0, 65843, '\p{Nv=+80000}', "");
Expect(1, 65843, '\p{^Nv=+80000}', "");
Expect(1, 65843, '\P{Nv=+80000}', "");
Expect(0, 65843, '\P{^Nv=+80000}', "");
Error('\p{Is_Numeric_Value=_/a/00080000}');
Error('\P{Is_Numeric_Value=_/a/00080000}');
Expect(1, 65842, '\p{Is_Numeric_Value=+08000_0}', "");
Expect(0, 65842, '\p{^Is_Numeric_Value=+08000_0}', "");
Expect(0, 65842, '\P{Is_Numeric_Value=+08000_0}', "");
Expect(1, 65842, '\P{^Is_Numeric_Value=+08000_0}', "");
Expect(0, 65843, '\p{Is_Numeric_Value=+08000_0}', "");
Expect(1, 65843, '\p{^Is_Numeric_Value=+08000_0}', "");
Expect(1, 65843, '\P{Is_Numeric_Value=+08000_0}', "");
Expect(0, 65843, '\P{^Is_Numeric_Value=+08000_0}', "");
Error('\p{Is_Nv::=_000_008_000_0}');
Error('\P{Is_Nv::=_000_008_000_0}');
Expect(1, 65842, '\p{Is_Nv:   +80000}', "");
Expect(0, 65842, '\p{^Is_Nv:   +80000}', "");
Expect(0, 65842, '\P{Is_Nv:   +80000}', "");
Expect(1, 65842, '\P{^Is_Nv:   +80000}', "");
Expect(0, 65843, '\p{Is_Nv:   +80000}', "");
Expect(1, 65843, '\p{^Is_Nv:   +80000}', "");
Expect(1, 65843, '\P{Is_Nv:   +80000}', "");
Expect(0, 65843, '\P{^Is_Nv:   +80000}', "");
Error('\p{Numeric_Value=:=-+09}');
Error('\P{Numeric_Value=:=-+09}');
Expect(1, 194704, '\p{Numeric_Value=00009}', "");
Expect(0, 194704, '\p{^Numeric_Value=00009}', "");
Expect(0, 194704, '\P{Numeric_Value=00009}', "");
Expect(1, 194704, '\P{^Numeric_Value=00009}', "");
Expect(0, 194705, '\p{Numeric_Value=00009}', "");
Expect(1, 194705, '\p{^Numeric_Value=00009}', "");
Expect(1, 194705, '\P{Numeric_Value=00009}', "");
Expect(0, 194705, '\P{^Numeric_Value=00009}', "");
Error('\p{Nv=:=	+009}');
Error('\P{Nv=:=	+009}');
Expect(1, 194704, '\p{Nv=0_0_0_0_0_09}', "");
Expect(0, 194704, '\p{^Nv=0_0_0_0_0_09}', "");
Expect(0, 194704, '\P{Nv=0_0_0_0_0_09}', "");
Expect(1, 194704, '\P{^Nv=0_0_0_0_0_09}', "");
Expect(0, 194705, '\p{Nv=0_0_0_0_0_09}', "");
Expect(1, 194705, '\p{^Nv=0_0_0_0_0_09}', "");
Expect(1, 194705, '\P{Nv=0_0_0_0_0_09}', "");
Expect(0, 194705, '\P{^Nv=0_0_0_0_0_09}', "");
Error('\p{Is_Numeric_Value= :=+0_0_0_0_0_0_0_0_09}');
Error('\P{Is_Numeric_Value= :=+0_0_0_0_0_0_0_0_09}');
Expect(1, 194704, '\p{Is_Numeric_Value=000009}', "");
Expect(0, 194704, '\p{^Is_Numeric_Value=000009}', "");
Expect(0, 194704, '\P{Is_Numeric_Value=000009}', "");
Expect(1, 194704, '\P{^Is_Numeric_Value=000009}', "");
Expect(0, 194705, '\p{Is_Numeric_Value=000009}', "");
Expect(1, 194705, '\p{^Is_Numeric_Value=000009}', "");
Expect(1, 194705, '\P{Is_Numeric_Value=000009}', "");
Expect(0, 194705, '\P{^Is_Numeric_Value=000009}', "");
Error('\p{Is_Nv=:=- 000000009}');
Error('\P{Is_Nv=:=- 000000009}');
Expect(1, 194704, '\p{Is_Nv=0_0_0_0_09}', "");
Expect(0, 194704, '\p{^Is_Nv=0_0_0_0_09}', "");
Expect(0, 194704, '\P{Is_Nv=0_0_0_0_09}', "");
Expect(1, 194704, '\P{^Is_Nv=0_0_0_0_09}', "");
Expect(0, 194705, '\p{Is_Nv=0_0_0_0_09}', "");
Expect(1, 194705, '\p{^Is_Nv=0_0_0_0_09}', "");
Expect(1, 194705, '\P{Is_Nv=0_0_0_0_09}', "");
Expect(0, 194705, '\P{^Is_Nv=0_0_0_0_09}', "");
Error('\p{Numeric_Value=/a/  0000000009/0000000002}');
Error('\P{Numeric_Value=/a/  0000000009/0000000002}');
Expect(1, 3886, '\p{Numeric_Value=0009/0000000002}', "");
Expect(0, 3886, '\p{^Numeric_Value=0009/0000000002}', "");
Expect(0, 3886, '\P{Numeric_Value=0009/0000000002}', "");
Expect(1, 3886, '\P{^Numeric_Value=0009/0000000002}', "");
Expect(0, 3887, '\p{Numeric_Value=0009/0000000002}', "");
Expect(1, 3887, '\p{^Numeric_Value=0009/0000000002}', "");
Expect(1, 3887, '\P{Numeric_Value=0009/0000000002}', "");
Expect(0, 3887, '\P{^Numeric_Value=0009/0000000002}', "");
Expect(1, 3886, '\p{Numeric_Value=4.500}', "");
Expect(0, 3886, '\p{^Numeric_Value=4.500}', "");
Expect(0, 3886, '\P{Numeric_Value=4.500}', "");
Expect(1, 3886, '\P{^Numeric_Value=4.500}', "");
Expect(0, 3887, '\p{Numeric_Value=4.500}', "");
Expect(1, 3887, '\p{^Numeric_Value=4.500}', "");
Expect(1, 3887, '\P{Numeric_Value=4.500}', "");
Expect(0, 3887, '\P{^Numeric_Value=4.500}', "");
Error('\p{Nv=	/a/009/2}');
Error('\P{Nv=	/a/009/2}');
Expect(1, 3886, '\p{Nv=000009/002}', "");
Expect(0, 3886, '\p{^Nv=000009/002}', "");
Expect(0, 3886, '\P{Nv=000009/002}', "");
Expect(1, 3886, '\P{^Nv=000009/002}', "");
Expect(0, 3887, '\p{Nv=000009/002}', "");
Expect(1, 3887, '\p{^Nv=000009/002}', "");
Expect(1, 3887, '\P{Nv=000009/002}', "");
Expect(0, 3887, '\P{^Nv=000009/002}', "");
Expect(1, 3886, '\p{Nv=4.500}', "");
Expect(0, 3886, '\p{^Nv=4.500}', "");
Expect(0, 3886, '\P{Nv=4.500}', "");
Expect(1, 3886, '\P{^Nv=4.500}', "");
Expect(0, 3887, '\p{Nv=4.500}', "");
Expect(1, 3887, '\p{^Nv=4.500}', "");
Expect(1, 3887, '\P{Nv=4.500}', "");
Expect(0, 3887, '\P{^Nv=4.500}', "");
Error('\p{Is_Numeric_Value=	_000009/02:=}');
Error('\P{Is_Numeric_Value=	_000009/02:=}');
Expect(1, 3886, '\p{Is_Numeric_Value=9/000002}', "");
Expect(0, 3886, '\p{^Is_Numeric_Value=9/000002}', "");
Expect(0, 3886, '\P{Is_Numeric_Value=9/000002}', "");
Expect(1, 3886, '\P{^Is_Numeric_Value=9/000002}', "");
Expect(0, 3887, '\p{Is_Numeric_Value=9/000002}', "");
Expect(1, 3887, '\p{^Is_Numeric_Value=9/000002}', "");
Expect(1, 3887, '\P{Is_Numeric_Value=9/000002}', "");
Expect(0, 3887, '\P{^Is_Numeric_Value=9/000002}', "");
Expect(1, 3886, '\p{Is_Numeric_Value=4.500}', "");
Expect(0, 3886, '\p{^Is_Numeric_Value=4.500}', "");
Expect(0, 3886, '\P{Is_Numeric_Value=4.500}', "");
Expect(1, 3886, '\P{^Is_Numeric_Value=4.500}', "");
Expect(0, 3887, '\p{Is_Numeric_Value=4.500}', "");
Expect(1, 3887, '\p{^Is_Numeric_Value=4.500}', "");
Expect(1, 3887, '\P{Is_Numeric_Value=4.500}', "");
Expect(0, 3887, '\P{^Is_Numeric_Value=4.500}', "");
Error('\p{Is_Nv=/a/-	0009/0002}');
Error('\P{Is_Nv=/a/-	0009/0002}');
Expect(1, 3886, '\p{Is_Nv=000009/000002}', "");
Expect(0, 3886, '\p{^Is_Nv=000009/000002}', "");
Expect(0, 3886, '\P{Is_Nv=000009/000002}', "");
Expect(1, 3886, '\P{^Is_Nv=000009/000002}', "");
Expect(0, 3887, '\p{Is_Nv=000009/000002}', "");
Expect(1, 3887, '\p{^Is_Nv=000009/000002}', "");
Expect(1, 3887, '\P{Is_Nv=000009/000002}', "");
Expect(0, 3887, '\P{^Is_Nv=000009/000002}', "");
Expect(1, 3886, '\p{Is_Nv=4.500}', "");
Expect(0, 3886, '\p{^Is_Nv=4.500}', "");
Expect(0, 3886, '\P{Is_Nv=4.500}', "");
Expect(1, 3886, '\P{^Is_Nv=4.500}', "");
Expect(0, 3887, '\p{Is_Nv=4.500}', "");
Expect(1, 3887, '\p{^Is_Nv=4.500}', "");
Expect(1, 3887, '\P{Is_Nv=4.500}', "");
Expect(0, 3887, '\P{^Is_Nv=4.500}', "");
Error('\p{Numeric_Value=__00000000090:=}');
Error('\P{Numeric_Value=__00000000090:=}');
Expect(1, 119665, '\p{Numeric_Value=+90}', "");
Expect(0, 119665, '\p{^Numeric_Value=+90}', "");
Expect(0, 119665, '\P{Numeric_Value=+90}', "");
Expect(1, 119665, '\P{^Numeric_Value=+90}', "");
Expect(0, 119666, '\p{Numeric_Value=+90}', "");
Expect(1, 119666, '\p{^Numeric_Value=+90}', "");
Expect(1, 119666, '\P{Numeric_Value=+90}', "");
Expect(0, 119666, '\P{^Numeric_Value=+90}', "");
Error('\p{Nv:	:=9_0}');
Error('\P{Nv:	:=9_0}');
Expect(1, 119665, '\p{Nv=+0000009_0}', "");
Expect(0, 119665, '\p{^Nv=+0000009_0}', "");
Expect(0, 119665, '\P{Nv=+0000009_0}', "");
Expect(1, 119665, '\P{^Nv=+0000009_0}', "");
Expect(0, 119666, '\p{Nv=+0000009_0}', "");
Expect(1, 119666, '\p{^Nv=+0000009_0}', "");
Expect(1, 119666, '\P{Nv=+0000009_0}', "");
Expect(0, 119666, '\P{^Nv=+0000009_0}', "");
Error('\p{Is_Numeric_Value=:= -0_0_90}');
Error('\P{Is_Numeric_Value=:= -0_0_90}');
Expect(1, 119665, '\p{Is_Numeric_Value=090}', "");
Expect(0, 119665, '\p{^Is_Numeric_Value=090}', "");
Expect(0, 119665, '\P{Is_Numeric_Value=090}', "");
Expect(1, 119665, '\P{^Is_Numeric_Value=090}', "");
Expect(0, 119666, '\p{Is_Numeric_Value=090}', "");
Expect(1, 119666, '\p{^Is_Numeric_Value=090}', "");
Expect(1, 119666, '\P{Is_Numeric_Value=090}', "");
Expect(0, 119666, '\P{^Is_Numeric_Value=090}', "");
Error('\p{Is_Nv=:= _090}');
Error('\P{Is_Nv=:= _090}');
Expect(1, 119665, '\p{Is_Nv=00000000090}', "");
Expect(0, 119665, '\p{^Is_Nv=00000000090}', "");
Expect(0, 119665, '\P{Is_Nv=00000000090}', "");
Expect(1, 119665, '\P{^Is_Nv=00000000090}', "");
Expect(0, 119666, '\p{Is_Nv=00000000090}', "");
Expect(1, 119666, '\p{^Is_Nv=00000000090}', "");
Expect(1, 119666, '\P{Is_Nv=00000000090}', "");
Expect(0, 119666, '\P{^Is_Nv=00000000090}', "");
Error('\p{Numeric_Value=		000900/a/}');
Error('\P{Numeric_Value=		000900/a/}');
Expect(1, 69242, '\p{Numeric_Value=00000000090_0}', "");
Expect(0, 69242, '\p{^Numeric_Value=00000000090_0}', "");
Expect(0, 69242, '\P{Numeric_Value=00000000090_0}', "");
Expect(1, 69242, '\P{^Numeric_Value=00000000090_0}', "");
Expect(0, 69243, '\p{Numeric_Value=00000000090_0}', "");
Expect(1, 69243, '\p{^Numeric_Value=00000000090_0}', "");
Expect(1, 69243, '\P{Numeric_Value=00000000090_0}', "");
Expect(0, 69243, '\P{^Numeric_Value=00000000090_0}', "");
Error('\p{Nv: _+00_00_09_00:=}');
Error('\P{Nv: _+00_00_09_00:=}');
Expect(1, 69242, '\p{Nv=0_0_0_0_0_900}', "");
Expect(0, 69242, '\p{^Nv=0_0_0_0_0_900}', "");
Expect(0, 69242, '\P{Nv=0_0_0_0_0_900}', "");
Expect(1, 69242, '\P{^Nv=0_0_0_0_0_900}', "");
Expect(0, 69243, '\p{Nv=0_0_0_0_0_900}', "");
Expect(1, 69243, '\p{^Nv=0_0_0_0_0_900}', "");
Expect(1, 69243, '\P{Nv=0_0_0_0_0_900}', "");
Expect(0, 69243, '\P{^Nv=0_0_0_0_0_900}', "");
Error('\p{Is_Numeric_Value=:=	 0_0_0_0_0_0_0_9_00}');
Error('\P{Is_Numeric_Value=:=	 0_0_0_0_0_0_0_9_00}');
Expect(1, 69242, '\p{Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(0, 69242, '\p{^Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(0, 69242, '\P{Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(1, 69242, '\P{^Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(0, 69243, '\p{Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(1, 69243, '\p{^Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(1, 69243, '\P{Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Expect(0, 69243, '\P{^Is_Numeric_Value=+0_0_0_0_0_9_00}', "");
Error('\p{Is_Nv:	/a/00000000900}');
Error('\P{Is_Nv:	/a/00000000900}');
Expect(1, 69242, '\p{Is_Nv:	+0900}', "");
Expect(0, 69242, '\p{^Is_Nv:	+0900}', "");
Expect(0, 69242, '\P{Is_Nv:	+0900}', "");
Expect(1, 69242, '\P{^Is_Nv:	+0900}', "");
Expect(0, 69243, '\p{Is_Nv:	+0900}', "");
Expect(1, 69243, '\p{^Is_Nv:	+0900}', "");
Expect(1, 69243, '\P{Is_Nv:	+0900}', "");
Expect(0, 69243, '\P{^Is_Nv:	+0900}', "");
Error('\p{Numeric_Value=/a/- 9000}');
Error('\P{Numeric_Value=/a/- 9000}');
Expect(1, 65834, '\p{Numeric_Value=+00000009000}', "");
Expect(0, 65834, '\p{^Numeric_Value=+00000009000}', "");
Expect(0, 65834, '\P{Numeric_Value=+00000009000}', "");
Expect(1, 65834, '\P{^Numeric_Value=+00000009000}', "");
Expect(0, 65835, '\p{Numeric_Value=+00000009000}', "");
Expect(1, 65835, '\p{^Numeric_Value=+00000009000}', "");
Expect(1, 65835, '\P{Numeric_Value=+00000009000}', "");
Expect(0, 65835, '\P{^Numeric_Value=+00000009000}', "");
Error('\p{Nv=__+0_0_0_0_0_0_9000/a/}');
Error('\P{Nv=__+0_0_0_0_0_0_9000/a/}');
Expect(1, 65834, '\p{Nv=+9000}', "");
Expect(0, 65834, '\p{^Nv=+9000}', "");
Expect(0, 65834, '\P{Nv=+9000}', "");
Expect(1, 65834, '\P{^Nv=+9000}', "");
Expect(0, 65835, '\p{Nv=+9000}', "");
Expect(1, 65835, '\p{^Nv=+9000}', "");
Expect(1, 65835, '\P{Nv=+9000}', "");
Expect(0, 65835, '\P{^Nv=+9000}', "");
Error('\p{Is_Numeric_Value= /a/00000009000}');
Error('\P{Is_Numeric_Value= /a/00000009000}');
Expect(1, 65834, '\p{Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(0, 65834, '\p{^Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(0, 65834, '\P{Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(1, 65834, '\P{^Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(0, 65835, '\p{Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(1, 65835, '\p{^Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(1, 65835, '\P{Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Expect(0, 65835, '\P{^Is_Numeric_Value=+0_0_0_0_9_0_00}', "");
Error('\p{Is_Nv=- 0_0_0_9_0_00:=}');
Error('\P{Is_Nv=- 0_0_0_9_0_00:=}');
Expect(1, 65834, '\p{Is_Nv=+00009000}', "");
Expect(0, 65834, '\p{^Is_Nv=+00009000}', "");
Expect(0, 65834, '\P{Is_Nv=+00009000}', "");
Expect(1, 65834, '\P{^Is_Nv=+00009000}', "");
Expect(0, 65835, '\p{Is_Nv=+00009000}', "");
Expect(1, 65835, '\p{^Is_Nv=+00009000}', "");
Expect(1, 65835, '\P{Is_Nv=+00009000}', "");
Expect(0, 65835, '\P{^Is_Nv=+00009000}', "");
Error('\p{Numeric_Value=_-0_0_0_0_0_0_0_0_0_9_0_000:=}');
Error('\P{Numeric_Value=_-0_0_0_0_0_0_0_0_0_9_0_000:=}');
Expect(1, 65843, '\p{Numeric_Value=0009000_0}', "");
Expect(0, 65843, '\p{^Numeric_Value=0009000_0}', "");
Expect(0, 65843, '\P{Numeric_Value=0009000_0}', "");
Expect(1, 65843, '\P{^Numeric_Value=0009000_0}', "");
Expect(0, 65844, '\p{Numeric_Value=0009000_0}', "");
Expect(1, 65844, '\p{^Numeric_Value=0009000_0}', "");
Expect(1, 65844, '\P{Numeric_Value=0009000_0}', "");
Expect(0, 65844, '\P{^Numeric_Value=0009000_0}', "");
Error('\p{Nv=/a/+000090000}');
Error('\P{Nv=/a/+000090000}');
Expect(1, 65843, '\p{Nv=000000090000}', "");
Expect(0, 65843, '\p{^Nv=000000090000}', "");
Expect(0, 65843, '\P{Nv=000000090000}', "");
Expect(1, 65843, '\P{^Nv=000000090000}', "");
Expect(0, 65844, '\p{Nv=000000090000}', "");
Expect(1, 65844, '\p{^Nv=000000090000}', "");
Expect(1, 65844, '\P{Nv=000000090000}', "");
Expect(0, 65844, '\P{^Nv=000000090000}', "");
Error('\p{Is_Numeric_Value=0_0_0_0_0_0_0_9_0000:=}');
Error('\P{Is_Numeric_Value=0_0_0_0_0_0_0_9_0000:=}');
Expect(1, 65843, '\p{Is_Numeric_Value=000090000}', "");
Expect(0, 65843, '\p{^Is_Numeric_Value=000090000}', "");
Expect(0, 65843, '\P{Is_Numeric_Value=000090000}', "");
Expect(1, 65843, '\P{^Is_Numeric_Value=000090000}', "");
Expect(0, 65844, '\p{Is_Numeric_Value=000090000}', "");
Expect(1, 65844, '\p{^Is_Numeric_Value=000090000}', "");
Expect(1, 65844, '\P{Is_Numeric_Value=000090000}', "");
Expect(0, 65844, '\P{^Is_Numeric_Value=000090000}', "");
Error('\p{Is_Nv=_:=0090000}');
Error('\P{Is_Nv=_:=0090000}');
Expect(1, 65843, '\p{Is_Nv=000090000}', "");
Expect(0, 65843, '\p{^Is_Nv=000090000}', "");
Expect(0, 65843, '\P{Is_Nv=000090000}', "");
Expect(1, 65843, '\P{^Is_Nv=000090000}', "");
Expect(0, 65844, '\p{Is_Nv=000090000}', "");
Expect(1, 65844, '\p{^Is_Nv=000090000}', "");
Expect(1, 65844, '\P{Is_Nv=000090000}', "");
Expect(0, 65844, '\P{^Is_Nv=000090000}', "");
Error('\p{Numeric_Value=-_NaN/a/}');
Error('\P{Numeric_Value=-_NaN/a/}');
Expect(1, 194705, '\p{Numeric_Value=nan}', "");
Expect(0, 194705, '\p{^Numeric_Value=nan}', "");
Expect(0, 194705, '\P{Numeric_Value=nan}', "");
Expect(1, 194705, '\P{^Numeric_Value=nan}', "");
Expect(0, 194704, '\p{Numeric_Value=nan}', "");
Expect(1, 194704, '\p{^Numeric_Value=nan}', "");
Expect(1, 194704, '\P{Numeric_Value=nan}', "");
Expect(0, 194704, '\P{^Numeric_Value=nan}', "");
Expect(1, 194705, '\p{Numeric_Value=  NaN}', "");
Expect(0, 194705, '\p{^Numeric_Value=  NaN}', "");
Expect(0, 194705, '\P{Numeric_Value=  NaN}', "");
Expect(1, 194705, '\P{^Numeric_Value=  NaN}', "");
Expect(0, 194704, '\p{Numeric_Value=  NaN}', "");
Expect(1, 194704, '\p{^Numeric_Value=  NaN}', "");
Expect(1, 194704, '\P{Numeric_Value=  NaN}', "");
Expect(0, 194704, '\P{^Numeric_Value=  NaN}', "");
Error('\p{Nv=  nan:=}');
Error('\P{Nv=  nan:=}');
Expect(1, 194705, '\p{Nv=nan}', "");
Expect(0, 194705, '\p{^Nv=nan}', "");
Expect(0, 194705, '\P{Nv=nan}', "");
Expect(1, 194705, '\P{^Nv=nan}', "");
Expect(0, 194704, '\p{Nv=nan}', "");
Expect(1, 194704, '\p{^Nv=nan}', "");
Expect(1, 194704, '\P{Nv=nan}', "");
Expect(0, 194704, '\P{^Nv=nan}', "");
Expect(1, 194705, '\p{Nv=	NaN}', "");
Expect(0, 194705, '\p{^Nv=	NaN}', "");
Expect(0, 194705, '\P{Nv=	NaN}', "");
Expect(1, 194705, '\P{^Nv=	NaN}', "");
Expect(0, 194704, '\p{Nv=	NaN}', "");
Expect(1, 194704, '\p{^Nv=	NaN}', "");
Expect(1, 194704, '\P{Nv=	NaN}', "");
Expect(0, 194704, '\P{^Nv=	NaN}', "");
Error('\p{Is_Numeric_Value: 	/a/nan}');
Error('\P{Is_Numeric_Value: 	/a/nan}');
Expect(1, 194705, '\p{Is_Numeric_Value=nan}', "");
Expect(0, 194705, '\p{^Is_Numeric_Value=nan}', "");
Expect(0, 194705, '\P{Is_Numeric_Value=nan}', "");
Expect(1, 194705, '\P{^Is_Numeric_Value=nan}', "");
Expect(0, 194704, '\p{Is_Numeric_Value=nan}', "");
Expect(1, 194704, '\p{^Is_Numeric_Value=nan}', "");
Expect(1, 194704, '\P{Is_Numeric_Value=nan}', "");
Expect(0, 194704, '\P{^Is_Numeric_Value=nan}', "");
Expect(1, 194705, '\p{Is_Numeric_Value=-	NaN}', "");
Expect(0, 194705, '\p{^Is_Numeric_Value=-	NaN}', "");
Expect(0, 194705, '\P{Is_Numeric_Value=-	NaN}', "");
Expect(1, 194705, '\P{^Is_Numeric_Value=-	NaN}', "");
Expect(0, 194704, '\p{Is_Numeric_Value=-	NaN}', "");
Expect(1, 194704, '\p{^Is_Numeric_Value=-	NaN}', "");
Expect(1, 194704, '\P{Is_Numeric_Value=-	NaN}', "");
Expect(0, 194704, '\P{^Is_Numeric_Value=-	NaN}', "");
Error('\p{Is_Nv=:=-NAN}');
Error('\P{Is_Nv=:=-NAN}');
Expect(1, 194705, '\p{Is_Nv=nan}', "");
Expect(0, 194705, '\p{^Is_Nv=nan}', "");
Expect(0, 194705, '\P{Is_Nv=nan}', "");
Expect(1, 194705, '\P{^Is_Nv=nan}', "");
Expect(0, 194704, '\p{Is_Nv=nan}', "");
Expect(1, 194704, '\p{^Is_Nv=nan}', "");
Expect(1, 194704, '\P{Is_Nv=nan}', "");
Expect(0, 194704, '\P{^Is_Nv=nan}', "");
Expect(1, 194705, '\p{Is_Nv:_-NAN}', "");
Expect(0, 194705, '\p{^Is_Nv:_-NAN}', "");
Expect(0, 194705, '\P{Is_Nv:_-NAN}', "");
Expect(1, 194705, '\P{^Is_Nv:_-NAN}', "");
Expect(0, 194704, '\p{Is_Nv:_-NAN}', "");
Expect(1, 194704, '\p{^Is_Nv:_-NAN}', "");
Expect(1, 194704, '\P{Is_Nv:_-NAN}', "");
Expect(0, 194704, '\P{^Is_Nv:_-NAN}', "");
Error('\p{		ASCII/a/}');
Error('\P{		ASCII/a/}');
Expect(1, 127, '\p{ascii}', "");
Expect(0, 127, '\p{^ascii}', "");
Expect(0, 127, '\P{ascii}', "");
Expect(1, 127, '\P{^ascii}', "");
Expect(0, 128, '\p{ascii}', "");
Expect(1, 128, '\p{^ascii}', "");
Expect(1, 128, '\P{ascii}', "");
Expect(0, 128, '\P{^ascii}', "");
Expect(1, 127, '\p{	_ASCII}', "");
Expect(0, 127, '\p{^	_ASCII}', "");
Expect(0, 127, '\P{	_ASCII}', "");
Expect(1, 127, '\P{^	_ASCII}', "");
Expect(0, 128, '\p{	_ASCII}', "");
Expect(1, 128, '\p{^	_ASCII}', "");
Expect(1, 128, '\P{	_ASCII}', "");
Expect(0, 128, '\P{^	_ASCII}', "");
Error('\p{_is_ASCII:=}');
Error('\P{_is_ASCII:=}');
Expect(1, 127, '\p{isascii}', "");
Expect(0, 127, '\p{^isascii}', "");
Expect(0, 127, '\P{isascii}', "");
Expect(1, 127, '\P{^isascii}', "");
Expect(0, 128, '\p{isascii}', "");
Expect(1, 128, '\p{^isascii}', "");
Expect(1, 128, '\P{isascii}', "");
Expect(0, 128, '\P{^isascii}', "");
Expect(1, 127, '\p{-	is_ASCII}', "");
Expect(0, 127, '\p{^-	is_ASCII}', "");
Expect(0, 127, '\P{-	is_ASCII}', "");
Expect(1, 127, '\P{^-	is_ASCII}', "");
Expect(0, 128, '\p{-	is_ASCII}', "");
Expect(1, 128, '\p{^-	is_ASCII}', "");
Expect(1, 128, '\P{-	is_ASCII}', "");
Expect(0, 128, '\P{^-	is_ASCII}', "");
Error('\p{__Basic_Latin:=}');
Error('\P{__Basic_Latin:=}');
Expect(1, 127, '\p{basiclatin}', "");
Expect(0, 127, '\p{^basiclatin}', "");
Expect(0, 127, '\P{basiclatin}', "");
Expect(1, 127, '\P{^basiclatin}', "");
Expect(0, 128, '\p{basiclatin}', "");
Expect(1, 128, '\p{^basiclatin}', "");
Expect(1, 128, '\P{basiclatin}', "");
Expect(0, 128, '\P{^basiclatin}', "");
Expect(1, 127, '\p{-basic_Latin}', "");
Expect(0, 127, '\p{^-basic_Latin}', "");
Expect(0, 127, '\P{-basic_Latin}', "");
Expect(1, 127, '\P{^-basic_Latin}', "");
Expect(0, 128, '\p{-basic_Latin}', "");
Expect(1, 128, '\p{^-basic_Latin}', "");
Expect(1, 128, '\P{-basic_Latin}', "");
Expect(0, 128, '\P{^-basic_Latin}', "");
Error('\p{-:=is_basic_Latin}');
Error('\P{-:=is_basic_Latin}');
Expect(1, 127, '\p{isbasiclatin}', "");
Expect(0, 127, '\p{^isbasiclatin}', "");
Expect(0, 127, '\P{isbasiclatin}', "");
Expect(1, 127, '\P{^isbasiclatin}', "");
Expect(0, 128, '\p{isbasiclatin}', "");
Expect(1, 128, '\p{^isbasiclatin}', "");
Expect(1, 128, '\P{isbasiclatin}', "");
Expect(0, 128, '\P{^isbasiclatin}', "");
Expect(1, 127, '\p{	 Is_Basic_latin}', "");
Expect(0, 127, '\p{^	 Is_Basic_latin}', "");
Expect(0, 127, '\P{	 Is_Basic_latin}', "");
Expect(1, 127, '\P{^	 Is_Basic_latin}', "");
Expect(0, 128, '\p{	 Is_Basic_latin}', "");
Expect(1, 128, '\p{^	 Is_Basic_latin}', "");
Expect(1, 128, '\P{	 Is_Basic_latin}', "");
Expect(0, 128, '\P{^	 Is_Basic_latin}', "");
Error('\p{	/a/In_Basic_Latin}');
Error('\P{	/a/In_Basic_Latin}');
Expect(1, 127, '\p{inbasiclatin}', "");
Expect(0, 127, '\p{^inbasiclatin}', "");
Expect(0, 127, '\P{inbasiclatin}', "");
Expect(1, 127, '\P{^inbasiclatin}', "");
Expect(0, 128, '\p{inbasiclatin}', "");
Expect(1, 128, '\p{^inbasiclatin}', "");
Expect(1, 128, '\P{inbasiclatin}', "");
Expect(0, 128, '\P{^inbasiclatin}', "");
Expect(1, 127, '\p{_In_Basic_Latin}', "");
Expect(0, 127, '\p{^_In_Basic_Latin}', "");
Expect(0, 127, '\P{_In_Basic_Latin}', "");
Expect(1, 127, '\P{^_In_Basic_Latin}', "");
Expect(0, 128, '\p{_In_Basic_Latin}', "");
Expect(1, 128, '\p{^_In_Basic_Latin}', "");
Expect(1, 128, '\P{_In_Basic_Latin}', "");
Expect(0, 128, '\P{^_In_Basic_Latin}', "");
Error('\p{/a/	in_ascii}');
Error('\P{/a/	in_ascii}');
Expect(1, 127, '\p{inascii}', "");
Expect(0, 127, '\p{^inascii}', "");
Expect(0, 127, '\P{inascii}', "");
Expect(1, 127, '\P{^inascii}', "");
Expect(0, 128, '\p{inascii}', "");
Expect(1, 128, '\p{^inascii}', "");
Expect(1, 128, '\P{inascii}', "");
Expect(0, 128, '\P{^inascii}', "");
Expect(1, 127, '\p{In_ASCII}', "");
Expect(0, 127, '\p{^In_ASCII}', "");
Expect(0, 127, '\P{In_ASCII}', "");
Expect(1, 127, '\P{^In_ASCII}', "");
Expect(0, 128, '\p{In_ASCII}', "");
Expect(1, 128, '\p{^In_ASCII}', "");
Expect(1, 128, '\P{In_ASCII}', "");
Expect(0, 128, '\P{^In_ASCII}', "");
Error('\p{-/a/Aegean_Numbers}');
Error('\P{-/a/Aegean_Numbers}');
Expect(1, 65855, '\p{aegeannumbers}', "");
Expect(0, 65855, '\p{^aegeannumbers}', "");
Expect(0, 65855, '\P{aegeannumbers}', "");
Expect(1, 65855, '\P{^aegeannumbers}', "");
Expect(0, 65856, '\p{aegeannumbers}', "");
Expect(1, 65856, '\p{^aegeannumbers}', "");
Expect(1, 65856, '\P{aegeannumbers}', "");
Expect(0, 65856, '\P{^aegeannumbers}', "");
Expect(1, 65855, '\p{	aegean_numbers}', "");
Expect(0, 65855, '\p{^	aegean_numbers}', "");
Expect(0, 65855, '\P{	aegean_numbers}', "");
Expect(1, 65855, '\P{^	aegean_numbers}', "");
Expect(0, 65856, '\p{	aegean_numbers}', "");
Expect(1, 65856, '\p{^	aegean_numbers}', "");
Expect(1, 65856, '\P{	aegean_numbers}', "");
Expect(0, 65856, '\P{^	aegean_numbers}', "");
Error('\p{	 is_Aegean_NUMBERS/a/}');
Error('\P{	 is_Aegean_NUMBERS/a/}');
Expect(1, 65855, '\p{isaegeannumbers}', "");
Expect(0, 65855, '\p{^isaegeannumbers}', "");
Expect(0, 65855, '\P{isaegeannumbers}', "");
Expect(1, 65855, '\P{^isaegeannumbers}', "");
Expect(0, 65856, '\p{isaegeannumbers}', "");
Expect(1, 65856, '\p{^isaegeannumbers}', "");
Expect(1, 65856, '\P{isaegeannumbers}', "");
Expect(0, 65856, '\P{^isaegeannumbers}', "");
Expect(1, 65855, '\p{  IS_Aegean_Numbers}', "");
Expect(0, 65855, '\p{^  IS_Aegean_Numbers}', "");
Expect(0, 65855, '\P{  IS_Aegean_Numbers}', "");
Expect(1, 65855, '\P{^  IS_Aegean_Numbers}', "");
Expect(0, 65856, '\p{  IS_Aegean_Numbers}', "");
Expect(1, 65856, '\p{^  IS_Aegean_Numbers}', "");
Expect(1, 65856, '\P{  IS_Aegean_Numbers}', "");
Expect(0, 65856, '\P{^  IS_Aegean_Numbers}', "");
Error('\p{__In_AEGEAN_Numbers/a/}');
Error('\P{__In_AEGEAN_Numbers/a/}');
Expect(1, 65855, '\p{inaegeannumbers}', "");
Expect(0, 65855, '\p{^inaegeannumbers}', "");
Expect(0, 65855, '\P{inaegeannumbers}', "");
Expect(1, 65855, '\P{^inaegeannumbers}', "");
Expect(0, 65856, '\p{inaegeannumbers}', "");
Expect(1, 65856, '\p{^inaegeannumbers}', "");
Expect(1, 65856, '\P{inaegeannumbers}', "");
Expect(0, 65856, '\P{^inaegeannumbers}', "");
Expect(1, 65855, '\p{	-IN_Aegean_NUMBERS}', "");
Expect(0, 65855, '\p{^	-IN_Aegean_NUMBERS}', "");
Expect(0, 65855, '\P{	-IN_Aegean_NUMBERS}', "");
Expect(1, 65855, '\P{^	-IN_Aegean_NUMBERS}', "");
Expect(0, 65856, '\p{	-IN_Aegean_NUMBERS}', "");
Expect(1, 65856, '\p{^	-IN_Aegean_NUMBERS}', "");
Expect(1, 65856, '\P{	-IN_Aegean_NUMBERS}', "");
Expect(0, 65856, '\P{^	-IN_Aegean_NUMBERS}', "");
Error('\p{ :=Alchemical_Symbols}');
Error('\P{ :=Alchemical_Symbols}');
Expect(1, 128895, '\p{alchemicalsymbols}', "");
Expect(0, 128895, '\p{^alchemicalsymbols}', "");
Expect(0, 128895, '\P{alchemicalsymbols}', "");
Expect(1, 128895, '\P{^alchemicalsymbols}', "");
Expect(0, 128896, '\p{alchemicalsymbols}', "");
Expect(1, 128896, '\p{^alchemicalsymbols}', "");
Expect(1, 128896, '\P{alchemicalsymbols}', "");
Expect(0, 128896, '\P{^alchemicalsymbols}', "");
Expect(1, 128895, '\p{_Alchemical_SYMBOLS}', "");
Expect(0, 128895, '\p{^_Alchemical_SYMBOLS}', "");
Expect(0, 128895, '\P{_Alchemical_SYMBOLS}', "");
Expect(1, 128895, '\P{^_Alchemical_SYMBOLS}', "");
Expect(0, 128896, '\p{_Alchemical_SYMBOLS}', "");
Expect(1, 128896, '\p{^_Alchemical_SYMBOLS}', "");
Expect(1, 128896, '\P{_Alchemical_SYMBOLS}', "");
Expect(0, 128896, '\P{^_Alchemical_SYMBOLS}', "");
Error('\p{- IS_Alchemical_SYMBOLS:=}');
Error('\P{- IS_Alchemical_SYMBOLS:=}');
Expect(1, 128895, '\p{isalchemicalsymbols}', "");
Expect(0, 128895, '\p{^isalchemicalsymbols}', "");
Expect(0, 128895, '\P{isalchemicalsymbols}', "");
Expect(1, 128895, '\P{^isalchemicalsymbols}', "");
Expect(0, 128896, '\p{isalchemicalsymbols}', "");
Expect(1, 128896, '\p{^isalchemicalsymbols}', "");
Expect(1, 128896, '\P{isalchemicalsymbols}', "");
Expect(0, 128896, '\P{^isalchemicalsymbols}', "");
Expect(1, 128895, '\p{	_IS_ALCHEMICAL_symbols}', "");
Expect(0, 128895, '\p{^	_IS_ALCHEMICAL_symbols}', "");
Expect(0, 128895, '\P{	_IS_ALCHEMICAL_symbols}', "");
Expect(1, 128895, '\P{^	_IS_ALCHEMICAL_symbols}', "");
Expect(0, 128896, '\p{	_IS_ALCHEMICAL_symbols}', "");
Expect(1, 128896, '\p{^	_IS_ALCHEMICAL_symbols}', "");
Expect(1, 128896, '\P{	_IS_ALCHEMICAL_symbols}', "");
Expect(0, 128896, '\P{^	_IS_ALCHEMICAL_symbols}', "");
Error('\p{ IN_alchemical_Symbols/a/}');
Error('\P{ IN_alchemical_Symbols/a/}');
Expect(1, 128895, '\p{inalchemicalsymbols}', "");
Expect(0, 128895, '\p{^inalchemicalsymbols}', "");
Expect(0, 128895, '\P{inalchemicalsymbols}', "");
Expect(1, 128895, '\P{^inalchemicalsymbols}', "");
Expect(0, 128896, '\p{inalchemicalsymbols}', "");
Expect(1, 128896, '\p{^inalchemicalsymbols}', "");
Expect(1, 128896, '\P{inalchemicalsymbols}', "");
Expect(0, 128896, '\P{^inalchemicalsymbols}', "");
Expect(1, 128895, '\p{_ In_Alchemical_symbols}', "");
Expect(0, 128895, '\p{^_ In_Alchemical_symbols}', "");
Expect(0, 128895, '\P{_ In_Alchemical_symbols}', "");
Expect(1, 128895, '\P{^_ In_Alchemical_symbols}', "");
Expect(0, 128896, '\p{_ In_Alchemical_symbols}', "");
Expect(1, 128896, '\p{^_ In_Alchemical_symbols}', "");
Expect(1, 128896, '\P{_ In_Alchemical_symbols}', "");
Expect(0, 128896, '\P{^_ In_Alchemical_symbols}', "");
Error('\p{	-Alchemical/a/}');
Error('\P{	-Alchemical/a/}');
Expect(1, 128895, '\p{alchemical}', "");
Expect(0, 128895, '\p{^alchemical}', "");
Expect(0, 128895, '\P{alchemical}', "");
Expect(1, 128895, '\P{^alchemical}', "");
Expect(0, 128896, '\p{alchemical}', "");
Expect(1, 128896, '\p{^alchemical}', "");
Expect(1, 128896, '\P{alchemical}', "");
Expect(0, 128896, '\P{^alchemical}', "");
Expect(1, 128895, '\p{ 	Alchemical}', "");
Expect(0, 128895, '\p{^ 	Alchemical}', "");
Expect(0, 128895, '\P{ 	Alchemical}', "");
Expect(1, 128895, '\P{^ 	Alchemical}', "");
Expect(0, 128896, '\p{ 	Alchemical}', "");
Expect(1, 128896, '\p{^ 	Alchemical}', "");
Expect(1, 128896, '\P{ 	Alchemical}', "");
Expect(0, 128896, '\P{^ 	Alchemical}', "");
Error('\p{IS_Alchemical:=}');
Error('\P{IS_Alchemical:=}');
Expect(1, 128895, '\p{isalchemical}', "");
Expect(0, 128895, '\p{^isalchemical}', "");
Expect(0, 128895, '\P{isalchemical}', "");
Expect(1, 128895, '\P{^isalchemical}', "");
Expect(0, 128896, '\p{isalchemical}', "");
Expect(1, 128896, '\p{^isalchemical}', "");
Expect(1, 128896, '\P{isalchemical}', "");
Expect(0, 128896, '\P{^isalchemical}', "");
Expect(1, 128895, '\p{	Is_Alchemical}', "");
Expect(0, 128895, '\p{^	Is_Alchemical}', "");
Expect(0, 128895, '\P{	Is_Alchemical}', "");
Expect(1, 128895, '\P{^	Is_Alchemical}', "");
Expect(0, 128896, '\p{	Is_Alchemical}', "");
Expect(1, 128896, '\p{^	Is_Alchemical}', "");
Expect(1, 128896, '\P{	Is_Alchemical}', "");
Expect(0, 128896, '\P{^	Is_Alchemical}', "");
Error('\p{	 In_ALCHEMICAL:=}');
Error('\P{	 In_ALCHEMICAL:=}');
Expect(1, 128895, '\p{inalchemical}', "");
Expect(0, 128895, '\p{^inalchemical}', "");
Expect(0, 128895, '\P{inalchemical}', "");
Expect(1, 128895, '\P{^inalchemical}', "");
Expect(0, 128896, '\p{inalchemical}', "");
Expect(1, 128896, '\p{^inalchemical}', "");
Expect(1, 128896, '\P{inalchemical}', "");
Expect(0, 128896, '\P{^inalchemical}', "");
Expect(1, 128895, '\p{	-in_alchemical}', "");
Expect(0, 128895, '\p{^	-in_alchemical}', "");
Expect(0, 128895, '\P{	-in_alchemical}', "");
Expect(1, 128895, '\P{^	-in_alchemical}', "");
Expect(0, 128896, '\p{	-in_alchemical}', "");
Expect(1, 128896, '\p{^	-in_alchemical}', "");
Expect(1, 128896, '\P{	-in_alchemical}', "");
Expect(0, 128896, '\P{^	-in_alchemical}', "");
Error('\p{/a/	 ALNUM}');
Error('\P{/a/	 ALNUM}');
Expect(1, 195101, '\p{alnum}', "");
Expect(0, 195101, '\p{^alnum}', "");
Expect(0, 195101, '\P{alnum}', "");
Expect(1, 195101, '\P{^alnum}', "");
Expect(0, 195102, '\p{alnum}', "");
Expect(1, 195102, '\p{^alnum}', "");
Expect(1, 195102, '\P{alnum}', "");
Expect(0, 195102, '\P{^alnum}', "");
Expect(1, 195101, '\p{__Alnum}', "");
Expect(0, 195101, '\p{^__Alnum}', "");
Expect(0, 195101, '\P{__Alnum}', "");
Expect(1, 195101, '\P{^__Alnum}', "");
Expect(0, 195102, '\p{__Alnum}', "");
Expect(1, 195102, '\p{^__Alnum}', "");
Expect(1, 195102, '\P{__Alnum}', "");
Expect(0, 195102, '\P{^__Alnum}', "");
Error('\p{_:=XPosixAlnum}');
Error('\P{_:=XPosixAlnum}');
Expect(1, 195101, '\p{xposixalnum}', "");
Expect(0, 195101, '\p{^xposixalnum}', "");
Expect(0, 195101, '\P{xposixalnum}', "");
Expect(1, 195101, '\P{^xposixalnum}', "");
Expect(0, 195102, '\p{xposixalnum}', "");
Expect(1, 195102, '\p{^xposixalnum}', "");
Expect(1, 195102, '\P{xposixalnum}', "");
Expect(0, 195102, '\P{^xposixalnum}', "");
Expect(1, 195101, '\p{ XPosixAlnum}', "");
Expect(0, 195101, '\p{^ XPosixAlnum}', "");
Expect(0, 195101, '\P{ XPosixAlnum}', "");
Expect(1, 195101, '\P{^ XPosixAlnum}', "");
Expect(0, 195102, '\p{ XPosixAlnum}', "");
Expect(1, 195102, '\p{^ XPosixAlnum}', "");
Expect(1, 195102, '\P{ XPosixAlnum}', "");
Expect(0, 195102, '\P{^ XPosixAlnum}', "");
Error('\p{:=-	Is_Alnum}');
Error('\P{:=-	Is_Alnum}');
Expect(1, 195101, '\p{isalnum}', "");
Expect(0, 195101, '\p{^isalnum}', "");
Expect(0, 195101, '\P{isalnum}', "");
Expect(1, 195101, '\P{^isalnum}', "");
Expect(0, 195102, '\p{isalnum}', "");
Expect(1, 195102, '\p{^isalnum}', "");
Expect(1, 195102, '\P{isalnum}', "");
Expect(0, 195102, '\P{^isalnum}', "");
Expect(1, 195101, '\p{_IS_alnum}', "");
Expect(0, 195101, '\p{^_IS_alnum}', "");
Expect(0, 195101, '\P{_IS_alnum}', "");
Expect(1, 195101, '\P{^_IS_alnum}', "");
Expect(0, 195102, '\p{_IS_alnum}', "");
Expect(1, 195102, '\p{^_IS_alnum}', "");
Expect(1, 195102, '\P{_IS_alnum}', "");
Expect(0, 195102, '\P{^_IS_alnum}', "");
Error('\p{_:=Is_xposixalnum}');
Error('\P{_:=Is_xposixalnum}');
Expect(1, 195101, '\p{isxposixalnum}', "");
Expect(0, 195101, '\p{^isxposixalnum}', "");
Expect(0, 195101, '\P{isxposixalnum}', "");
Expect(1, 195101, '\P{^isxposixalnum}', "");
Expect(0, 195102, '\p{isxposixalnum}', "");
Expect(1, 195102, '\p{^isxposixalnum}', "");
Expect(1, 195102, '\P{isxposixalnum}', "");
Expect(0, 195102, '\P{^isxposixalnum}', "");
Expect(1, 195101, '\p{_ IS_xposixalnum}', "");
Expect(0, 195101, '\p{^_ IS_xposixalnum}', "");
Expect(0, 195101, '\P{_ IS_xposixalnum}', "");
Expect(1, 195101, '\P{^_ IS_xposixalnum}', "");
Expect(0, 195102, '\p{_ IS_xposixalnum}', "");
Expect(1, 195102, '\p{^_ IS_xposixalnum}', "");
Expect(1, 195102, '\P{_ IS_xposixalnum}', "");
Expect(0, 195102, '\P{^_ IS_xposixalnum}', "");
Error('\p{-/a/Alpha}');
Error('\P{-/a/Alpha}');
Expect(1, 195101, '\p{alpha}', "");
Expect(0, 195101, '\p{^alpha}', "");
Expect(0, 195101, '\P{alpha}', "");
Expect(1, 195101, '\P{^alpha}', "");
Expect(0, 195102, '\p{alpha}', "");
Expect(1, 195102, '\p{^alpha}', "");
Expect(1, 195102, '\P{alpha}', "");
Expect(0, 195102, '\P{^alpha}', "");
Expect(1, 195101, '\p{- ALPHA}', "");
Expect(0, 195101, '\p{^- ALPHA}', "");
Expect(0, 195101, '\P{- ALPHA}', "");
Expect(1, 195101, '\P{^- ALPHA}', "");
Expect(0, 195102, '\p{- ALPHA}', "");
Expect(1, 195102, '\p{^- ALPHA}', "");
Expect(1, 195102, '\P{- ALPHA}', "");
Expect(0, 195102, '\P{^- ALPHA}', "");
Error('\p{_:=xposixalpha}');
Error('\P{_:=xposixalpha}');
Expect(1, 195101, '\p{xposixalpha}', "");
Expect(0, 195101, '\p{^xposixalpha}', "");
Expect(0, 195101, '\P{xposixalpha}', "");
Expect(1, 195101, '\P{^xposixalpha}', "");
Expect(0, 195102, '\p{xposixalpha}', "");
Expect(1, 195102, '\p{^xposixalpha}', "");
Expect(1, 195102, '\P{xposixalpha}', "");
Expect(0, 195102, '\P{^xposixalpha}', "");
Expect(1, 195101, '\p{ -XPosixAlpha}', "");
Expect(0, 195101, '\p{^ -XPosixAlpha}', "");
Expect(0, 195101, '\P{ -XPosixAlpha}', "");
Expect(1, 195101, '\P{^ -XPosixAlpha}', "");
Expect(0, 195102, '\p{ -XPosixAlpha}', "");
Expect(1, 195102, '\p{^ -XPosixAlpha}', "");
Expect(1, 195102, '\P{ -XPosixAlpha}', "");
Expect(0, 195102, '\P{^ -XPosixAlpha}', "");
Error('\p{	:=Is_Alpha}');
Error('\P{	:=Is_Alpha}');
Expect(1, 195101, '\p{isalpha}', "");
Expect(0, 195101, '\p{^isalpha}', "");
Expect(0, 195101, '\P{isalpha}', "");
Expect(1, 195101, '\P{^isalpha}', "");
Expect(0, 195102, '\p{isalpha}', "");
Expect(1, 195102, '\p{^isalpha}', "");
Expect(1, 195102, '\P{isalpha}', "");
Expect(0, 195102, '\P{^isalpha}', "");
Expect(1, 195101, '\p{	_Is_ALPHA}', "");
Expect(0, 195101, '\p{^	_Is_ALPHA}', "");
Expect(0, 195101, '\P{	_Is_ALPHA}', "");
Expect(1, 195101, '\P{^	_Is_ALPHA}', "");
Expect(0, 195102, '\p{	_Is_ALPHA}', "");
Expect(1, 195102, '\p{^	_Is_ALPHA}', "");
Expect(1, 195102, '\P{	_Is_ALPHA}', "");
Expect(0, 195102, '\P{^	_Is_ALPHA}', "");
Error('\p{/a/ Is_XPosixAlpha}');
Error('\P{/a/ Is_XPosixAlpha}');
Expect(1, 195101, '\p{isxposixalpha}', "");
Expect(0, 195101, '\p{^isxposixalpha}', "");
Expect(0, 195101, '\P{isxposixalpha}', "");
Expect(1, 195101, '\P{^isxposixalpha}', "");
Expect(0, 195102, '\p{isxposixalpha}', "");
Expect(1, 195102, '\p{^isxposixalpha}', "");
Expect(1, 195102, '\P{isxposixalpha}', "");
Expect(0, 195102, '\P{^isxposixalpha}', "");
Expect(1, 195101, '\p{_is_XPosixAlpha}', "");
Expect(0, 195101, '\p{^_is_XPosixAlpha}', "");
Expect(0, 195101, '\P{_is_XPosixAlpha}', "");
Expect(1, 195101, '\P{^_is_XPosixAlpha}', "");
Expect(0, 195102, '\p{_is_XPosixAlpha}', "");
Expect(1, 195102, '\p{^_is_XPosixAlpha}', "");
Expect(1, 195102, '\P{_is_XPosixAlpha}', "");
Expect(0, 195102, '\P{^_is_XPosixAlpha}', "");
Error('\p{:=-	alphabetic}');
Error('\P{:=-	alphabetic}');
Expect(1, 195101, '\p{alphabetic}', "");
Expect(0, 195101, '\p{^alphabetic}', "");
Expect(0, 195101, '\P{alphabetic}', "");
Expect(1, 195101, '\P{^alphabetic}', "");
Expect(0, 195102, '\p{alphabetic}', "");
Expect(1, 195102, '\p{^alphabetic}', "");
Expect(1, 195102, '\P{alphabetic}', "");
Expect(0, 195102, '\P{^alphabetic}', "");
Expect(1, 195101, '\p{- Alphabetic}', "");
Expect(0, 195101, '\p{^- Alphabetic}', "");
Expect(0, 195101, '\P{- Alphabetic}', "");
Expect(1, 195101, '\P{^- Alphabetic}', "");
Expect(0, 195102, '\p{- Alphabetic}', "");
Expect(1, 195102, '\p{^- Alphabetic}', "");
Expect(1, 195102, '\P{- Alphabetic}', "");
Expect(0, 195102, '\P{^- Alphabetic}', "");
Error('\p{/a/_	is_Alphabetic}');
Error('\P{/a/_	is_Alphabetic}');
Expect(1, 195101, '\p{isalphabetic}', "");
Expect(0, 195101, '\p{^isalphabetic}', "");
Expect(0, 195101, '\P{isalphabetic}', "");
Expect(1, 195101, '\P{^isalphabetic}', "");
Expect(0, 195102, '\p{isalphabetic}', "");
Expect(1, 195102, '\p{^isalphabetic}', "");
Expect(1, 195102, '\P{isalphabetic}', "");
Expect(0, 195102, '\P{^isalphabetic}', "");
Expect(1, 195101, '\p{ 	Is_Alphabetic}', "");
Expect(0, 195101, '\p{^ 	Is_Alphabetic}', "");
Expect(0, 195101, '\P{ 	Is_Alphabetic}', "");
Expect(1, 195101, '\P{^ 	Is_Alphabetic}', "");
Expect(0, 195102, '\p{ 	Is_Alphabetic}', "");
Expect(1, 195102, '\p{^ 	Is_Alphabetic}', "");
Expect(1, 195102, '\P{ 	Is_Alphabetic}', "");
Expect(0, 195102, '\P{^ 	Is_Alphabetic}', "");
Error('\p{:=_ ALPHABETIC_PRESENTATION_forms}');
Error('\P{:=_ ALPHABETIC_PRESENTATION_forms}');
Expect(1, 64335, '\p{alphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^alphabeticpresentationforms}', "");
Expect(0, 64335, '\P{alphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^alphabeticpresentationforms}', "");
Expect(0, 64336, '\p{alphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^alphabeticpresentationforms}', "");
Expect(1, 64336, '\P{alphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^alphabeticpresentationforms}', "");
Expect(1, 64335, '\p{	Alphabetic_Presentation_FORMS}', "");
Expect(0, 64335, '\p{^	Alphabetic_Presentation_FORMS}', "");
Expect(0, 64335, '\P{	Alphabetic_Presentation_FORMS}', "");
Expect(1, 64335, '\P{^	Alphabetic_Presentation_FORMS}', "");
Expect(0, 64336, '\p{	Alphabetic_Presentation_FORMS}', "");
Expect(1, 64336, '\p{^	Alphabetic_Presentation_FORMS}', "");
Expect(1, 64336, '\P{	Alphabetic_Presentation_FORMS}', "");
Expect(0, 64336, '\P{^	Alphabetic_Presentation_FORMS}', "");
Error('\p{_is_alphabetic_presentation_FORMS:=}');
Error('\P{_is_alphabetic_presentation_FORMS:=}');
Expect(1, 64335, '\p{isalphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^isalphabeticpresentationforms}', "");
Expect(0, 64335, '\P{isalphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^isalphabeticpresentationforms}', "");
Expect(0, 64336, '\p{isalphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^isalphabeticpresentationforms}', "");
Expect(1, 64336, '\P{isalphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^isalphabeticpresentationforms}', "");
Expect(1, 64335, '\p{ -is_alphabetic_Presentation_Forms}', "");
Expect(0, 64335, '\p{^ -is_alphabetic_Presentation_Forms}', "");
Expect(0, 64335, '\P{ -is_alphabetic_Presentation_Forms}', "");
Expect(1, 64335, '\P{^ -is_alphabetic_Presentation_Forms}', "");
Expect(0, 64336, '\p{ -is_alphabetic_Presentation_Forms}', "");
Expect(1, 64336, '\p{^ -is_alphabetic_Presentation_Forms}', "");
Expect(1, 64336, '\P{ -is_alphabetic_Presentation_Forms}', "");
Expect(0, 64336, '\P{^ -is_alphabetic_Presentation_Forms}', "");
Error('\p{/a/	 IN_Alphabetic_presentation_Forms}');
Error('\P{/a/	 IN_Alphabetic_presentation_Forms}');
Expect(1, 64335, '\p{inalphabeticpresentationforms}', "");
Expect(0, 64335, '\p{^inalphabeticpresentationforms}', "");
Expect(0, 64335, '\P{inalphabeticpresentationforms}', "");
Expect(1, 64335, '\P{^inalphabeticpresentationforms}', "");
Expect(0, 64336, '\p{inalphabeticpresentationforms}', "");
Expect(1, 64336, '\p{^inalphabeticpresentationforms}', "");
Expect(1, 64336, '\P{inalphabeticpresentationforms}', "");
Expect(0, 64336, '\P{^inalphabeticpresentationforms}', "");
Expect(1, 64335, '\p{-In_alphabetic_Presentation_forms}', "");
Expect(0, 64335, '\p{^-In_alphabetic_Presentation_forms}', "");
Expect(0, 64335, '\P{-In_alphabetic_Presentation_forms}', "");
Expect(1, 64335, '\P{^-In_alphabetic_Presentation_forms}', "");
Expect(0, 64336, '\p{-In_alphabetic_Presentation_forms}', "");
Expect(1, 64336, '\p{^-In_alphabetic_Presentation_forms}', "");
Expect(1, 64336, '\P{-In_alphabetic_Presentation_forms}', "");
Expect(0, 64336, '\P{^-In_alphabetic_Presentation_forms}', "");
Error('\p{/a/-_ALPHABETIC_PF}');
Error('\P{/a/-_ALPHABETIC_PF}');
Expect(1, 64335, '\p{alphabeticpf}', "");
Expect(0, 64335, '\p{^alphabeticpf}', "");
Expect(0, 64335, '\P{alphabeticpf}', "");
Expect(1, 64335, '\P{^alphabeticpf}', "");
Expect(0, 64336, '\p{alphabeticpf}', "");
Expect(1, 64336, '\p{^alphabeticpf}', "");
Expect(1, 64336, '\P{alphabeticpf}', "");
Expect(0, 64336, '\P{^alphabeticpf}', "");
Expect(1, 64335, '\p{--Alphabetic_PF}', "");
Expect(0, 64335, '\p{^--Alphabetic_PF}', "");
Expect(0, 64335, '\P{--Alphabetic_PF}', "");
Expect(1, 64335, '\P{^--Alphabetic_PF}', "");
Expect(0, 64336, '\p{--Alphabetic_PF}', "");
Expect(1, 64336, '\p{^--Alphabetic_PF}', "");
Expect(1, 64336, '\P{--Alphabetic_PF}', "");
Expect(0, 64336, '\P{^--Alphabetic_PF}', "");
Error('\p{- Is_alphabetic_PF/a/}');
Error('\P{- Is_alphabetic_PF/a/}');
Expect(1, 64335, '\p{isalphabeticpf}', "");
Expect(0, 64335, '\p{^isalphabeticpf}', "");
Expect(0, 64335, '\P{isalphabeticpf}', "");
Expect(1, 64335, '\P{^isalphabeticpf}', "");
Expect(0, 64336, '\p{isalphabeticpf}', "");
Expect(1, 64336, '\p{^isalphabeticpf}', "");
Expect(1, 64336, '\P{isalphabeticpf}', "");
Expect(0, 64336, '\P{^isalphabeticpf}', "");
Expect(1, 64335, '\p{-_IS_alphabetic_PF}', "");
Expect(0, 64335, '\p{^-_IS_alphabetic_PF}', "");
Expect(0, 64335, '\P{-_IS_alphabetic_PF}', "");
Expect(1, 64335, '\P{^-_IS_alphabetic_PF}', "");
Expect(0, 64336, '\p{-_IS_alphabetic_PF}', "");
Expect(1, 64336, '\p{^-_IS_alphabetic_PF}', "");
Expect(1, 64336, '\P{-_IS_alphabetic_PF}', "");
Expect(0, 64336, '\P{^-_IS_alphabetic_PF}', "");
Error('\p{/a/- IN_Alphabetic_PF}');
Error('\P{/a/- IN_Alphabetic_PF}');
Expect(1, 64335, '\p{inalphabeticpf}', "");
Expect(0, 64335, '\p{^inalphabeticpf}', "");
Expect(0, 64335, '\P{inalphabeticpf}', "");
Expect(1, 64335, '\P{^inalphabeticpf}', "");
Expect(0, 64336, '\p{inalphabeticpf}', "");
Expect(1, 64336, '\p{^inalphabeticpf}', "");
Expect(1, 64336, '\P{inalphabeticpf}', "");
Expect(0, 64336, '\P{^inalphabeticpf}', "");
Expect(1, 64335, '\p{	In_alphabetic_PF}', "");
Expect(0, 64335, '\p{^	In_alphabetic_PF}', "");
Expect(0, 64335, '\P{	In_alphabetic_PF}', "");
Expect(1, 64335, '\P{^	In_alphabetic_PF}', "");
Expect(0, 64336, '\p{	In_alphabetic_PF}', "");
Expect(1, 64336, '\p{^	In_alphabetic_PF}', "");
Expect(1, 64336, '\P{	In_alphabetic_PF}', "");
Expect(0, 64336, '\P{^	In_alphabetic_PF}', "");
Error('\p{-ANCIENT_GREEK_MUSICAL_Notation:=}');
Error('\P{-ANCIENT_GREEK_MUSICAL_Notation:=}');
Expect(1, 119375, '\p{ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^ancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^ancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{ancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^ancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(0, 119375, '\p{^-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(0, 119375, '\P{-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(1, 119375, '\P{^-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(0, 119376, '\p{-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(1, 119376, '\p{^-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(1, 119376, '\P{-Ancient_GREEK_MUSICAL_NOTATION}', "");
Expect(0, 119376, '\P{^-Ancient_GREEK_MUSICAL_NOTATION}', "");
Error('\p{:=IS_ancient_greek_Musical_Notation}');
Error('\P{:=IS_ancient_greek_Musical_Notation}');
Expect(1, 119375, '\p{isancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^isancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{isancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^isancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{isancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^isancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{isancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^isancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(0, 119375, '\p{^_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(0, 119375, '\P{_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(1, 119375, '\P{^_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(0, 119376, '\p{_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(1, 119376, '\p{^_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(1, 119376, '\P{_Is_Ancient_GREEK_musical_NOTATION}', "");
Expect(0, 119376, '\P{^_Is_Ancient_GREEK_musical_NOTATION}', "");
Error('\p{:= -In_ANCIENT_GREEK_Musical_NOTATION}');
Error('\P{:= -In_ANCIENT_GREEK_Musical_NOTATION}');
Expect(1, 119375, '\p{inancientgreekmusicalnotation}', "");
Expect(0, 119375, '\p{^inancientgreekmusicalnotation}', "");
Expect(0, 119375, '\P{inancientgreekmusicalnotation}', "");
Expect(1, 119375, '\P{^inancientgreekmusicalnotation}', "");
Expect(0, 119376, '\p{inancientgreekmusicalnotation}', "");
Expect(1, 119376, '\p{^inancientgreekmusicalnotation}', "");
Expect(1, 119376, '\P{inancientgreekmusicalnotation}', "");
Expect(0, 119376, '\P{^inancientgreekmusicalnotation}', "");
Expect(1, 119375, '\p{-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(0, 119375, '\p{^-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(0, 119375, '\P{-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(1, 119375, '\P{^-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(0, 119376, '\p{-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(1, 119376, '\p{^-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(1, 119376, '\P{-in_Ancient_GREEK_MUSICAL_Notation}', "");
Expect(0, 119376, '\P{^-in_Ancient_GREEK_MUSICAL_Notation}', "");
Error('\p{/a/ ANCIENT_greek_MUSIC}');
Error('\P{/a/ ANCIENT_greek_MUSIC}');
Expect(1, 119375, '\p{ancientgreekmusic}', "");
Expect(0, 119375, '\p{^ancientgreekmusic}', "");
Expect(0, 119375, '\P{ancientgreekmusic}', "");
Expect(1, 119375, '\P{^ancientgreekmusic}', "");
Expect(0, 119376, '\p{ancientgreekmusic}', "");
Expect(1, 119376, '\p{^ancientgreekmusic}', "");
Expect(1, 119376, '\P{ancientgreekmusic}', "");
Expect(0, 119376, '\P{^ancientgreekmusic}', "");
Expect(1, 119375, '\p{ 	ancient_greek_Music}', "");
Expect(0, 119375, '\p{^ 	ancient_greek_Music}', "");
Expect(0, 119375, '\P{ 	ancient_greek_Music}', "");
Expect(1, 119375, '\P{^ 	ancient_greek_Music}', "");
Expect(0, 119376, '\p{ 	ancient_greek_Music}', "");
Expect(1, 119376, '\p{^ 	ancient_greek_Music}', "");
Expect(1, 119376, '\P{ 	ancient_greek_Music}', "");
Expect(0, 119376, '\P{^ 	ancient_greek_Music}', "");
Error('\p{	 IS_ANCIENT_Greek_music/a/}');
Error('\P{	 IS_ANCIENT_Greek_music/a/}');
Expect(1, 119375, '\p{isancientgreekmusic}', "");
Expect(0, 119375, '\p{^isancientgreekmusic}', "");
Expect(0, 119375, '\P{isancientgreekmusic}', "");
Expect(1, 119375, '\P{^isancientgreekmusic}', "");
Expect(0, 119376, '\p{isancientgreekmusic}', "");
Expect(1, 119376, '\p{^isancientgreekmusic}', "");
Expect(1, 119376, '\P{isancientgreekmusic}', "");
Expect(0, 119376, '\P{^isancientgreekmusic}', "");
Expect(1, 119375, '\p{-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(0, 119375, '\p{^-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(0, 119375, '\P{-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(1, 119375, '\P{^-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(0, 119376, '\p{-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(1, 119376, '\p{^-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(1, 119376, '\P{-_Is_ANCIENT_Greek_MUSIC}', "");
Expect(0, 119376, '\P{^-_Is_ANCIENT_Greek_MUSIC}', "");
Error('\p{-/a/in_Ancient_greek_MUSIC}');
Error('\P{-/a/in_Ancient_greek_MUSIC}');
Expect(1, 119375, '\p{inancientgreekmusic}', "");
Expect(0, 119375, '\p{^inancientgreekmusic}', "");
Expect(0, 119375, '\P{inancientgreekmusic}', "");
Expect(1, 119375, '\P{^inancientgreekmusic}', "");
Expect(0, 119376, '\p{inancientgreekmusic}', "");
Expect(1, 119376, '\p{^inancientgreekmusic}', "");
Expect(1, 119376, '\P{inancientgreekmusic}', "");
Expect(0, 119376, '\P{^inancientgreekmusic}', "");
Expect(1, 119375, '\p{		In_Ancient_greek_Music}', "");
Expect(0, 119375, '\p{^		In_Ancient_greek_Music}', "");
Expect(0, 119375, '\P{		In_Ancient_greek_Music}', "");
Expect(1, 119375, '\P{^		In_Ancient_greek_Music}', "");
Expect(0, 119376, '\p{		In_Ancient_greek_Music}', "");
Expect(1, 119376, '\p{^		In_Ancient_greek_Music}', "");
Expect(1, 119376, '\P{		In_Ancient_greek_Music}', "");
Expect(0, 119376, '\P{^		In_Ancient_greek_Music}', "");
Error('\p{_ Ancient_Greek_numbers/a/}');
Error('\P{_ Ancient_Greek_numbers/a/}');
Expect(1, 65935, '\p{ancientgreeknumbers}', "");
Expect(0, 65935, '\p{^ancientgreeknumbers}', "");
Expect(0, 65935, '\P{ancientgreeknumbers}', "");
Expect(1, 65935, '\P{^ancientgreeknumbers}', "");
Expect(0, 65936, '\p{ancientgreeknumbers}', "");
Expect(1, 65936, '\p{^ancientgreeknumbers}', "");
Expect(1, 65936, '\P{ancientgreeknumbers}', "");
Expect(0, 65936, '\P{^ancientgreeknumbers}', "");
Expect(1, 65935, '\p{ ancient_Greek_numbers}', "");
Expect(0, 65935, '\p{^ ancient_Greek_numbers}', "");
Expect(0, 65935, '\P{ ancient_Greek_numbers}', "");
Expect(1, 65935, '\P{^ ancient_Greek_numbers}', "");
Expect(0, 65936, '\p{ ancient_Greek_numbers}', "");
Expect(1, 65936, '\p{^ ancient_Greek_numbers}', "");
Expect(1, 65936, '\P{ ancient_Greek_numbers}', "");
Expect(0, 65936, '\P{^ ancient_Greek_numbers}', "");
Error('\p{-/a/Is_Ancient_Greek_numbers}');
Error('\P{-/a/Is_Ancient_Greek_numbers}');
Expect(1, 65935, '\p{isancientgreeknumbers}', "");
Expect(0, 65935, '\p{^isancientgreeknumbers}', "");
Expect(0, 65935, '\P{isancientgreeknumbers}', "");
Expect(1, 65935, '\P{^isancientgreeknumbers}', "");
Expect(0, 65936, '\p{isancientgreeknumbers}', "");
Expect(1, 65936, '\p{^isancientgreeknumbers}', "");
Expect(1, 65936, '\P{isancientgreeknumbers}', "");
Expect(0, 65936, '\P{^isancientgreeknumbers}', "");
Expect(1, 65935, '\p{-	Is_ANCIENT_Greek_numbers}', "");
Expect(0, 65935, '\p{^-	Is_ANCIENT_Greek_numbers}', "");
Expect(0, 65935, '\P{-	Is_ANCIENT_Greek_numbers}', "");
Expect(1, 65935, '\P{^-	Is_ANCIENT_Greek_numbers}', "");
Expect(0, 65936, '\p{-	Is_ANCIENT_Greek_numbers}', "");
Expect(1, 65936, '\p{^-	Is_ANCIENT_Greek_numbers}', "");
Expect(1, 65936, '\P{-	Is_ANCIENT_Greek_numbers}', "");
Expect(0, 65936, '\P{^-	Is_ANCIENT_Greek_numbers}', "");
Error('\p{:=_	In_Ancient_greek_numbers}');
Error('\P{:=_	In_Ancient_greek_numbers}');
Expect(1, 65935, '\p{inancientgreeknumbers}', "");
Expect(0, 65935, '\p{^inancientgreeknumbers}', "");
Expect(0, 65935, '\P{inancientgreeknumbers}', "");
Expect(1, 65935, '\P{^inancientgreeknumbers}', "");
Expect(0, 65936, '\p{inancientgreeknumbers}', "");
Expect(1, 65936, '\p{^inancientgreeknumbers}', "");
Expect(1, 65936, '\P{inancientgreeknumbers}', "");
Expect(0, 65936, '\P{^inancientgreeknumbers}', "");
Expect(1, 65935, '\p{_	IN_Ancient_greek_numbers}', "");
Expect(0, 65935, '\p{^_	IN_Ancient_greek_numbers}', "");
Expect(0, 65935, '\P{_	IN_Ancient_greek_numbers}', "");
Expect(1, 65935, '\P{^_	IN_Ancient_greek_numbers}', "");
Expect(0, 65936, '\p{_	IN_Ancient_greek_numbers}', "");
Expect(1, 65936, '\p{^_	IN_Ancient_greek_numbers}', "");
Expect(1, 65936, '\P{_	IN_Ancient_greek_numbers}', "");
Expect(0, 65936, '\P{^_	IN_Ancient_greek_numbers}', "");
Error('\p{/a/-Ancient_SYMBOLS}');
Error('\P{/a/-Ancient_SYMBOLS}');
Expect(1, 65999, '\p{ancientsymbols}', "");
Expect(0, 65999, '\p{^ancientsymbols}', "");
Expect(0, 65999, '\P{ancientsymbols}', "");
Expect(1, 65999, '\P{^ancientsymbols}', "");
Expect(0, 66000, '\p{ancientsymbols}', "");
Expect(1, 66000, '\p{^ancientsymbols}', "");
Expect(1, 66000, '\P{ancientsymbols}', "");
Expect(0, 66000, '\P{^ancientsymbols}', "");
Expect(1, 65999, '\p{	ancient_Symbols}', "");
Expect(0, 65999, '\p{^	ancient_Symbols}', "");
Expect(0, 65999, '\P{	ancient_Symbols}', "");
Expect(1, 65999, '\P{^	ancient_Symbols}', "");
Expect(0, 66000, '\p{	ancient_Symbols}', "");
Expect(1, 66000, '\p{^	ancient_Symbols}', "");
Expect(1, 66000, '\P{	ancient_Symbols}', "");
Expect(0, 66000, '\P{^	ancient_Symbols}', "");
Error('\p{:=	-IS_Ancient_Symbols}');
Error('\P{:=	-IS_Ancient_Symbols}');
Expect(1, 65999, '\p{isancientsymbols}', "");
Expect(0, 65999, '\p{^isancientsymbols}', "");
Expect(0, 65999, '\P{isancientsymbols}', "");
Expect(1, 65999, '\P{^isancientsymbols}', "");
Expect(0, 66000, '\p{isancientsymbols}', "");
Expect(1, 66000, '\p{^isancientsymbols}', "");
Expect(1, 66000, '\P{isancientsymbols}', "");
Expect(0, 66000, '\P{^isancientsymbols}', "");
Expect(1, 65999, '\p{-	IS_Ancient_Symbols}', "");
Expect(0, 65999, '\p{^-	IS_Ancient_Symbols}', "");
Expect(0, 65999, '\P{-	IS_Ancient_Symbols}', "");
Expect(1, 65999, '\P{^-	IS_Ancient_Symbols}', "");
Expect(0, 66000, '\p{-	IS_Ancient_Symbols}', "");
Expect(1, 66000, '\p{^-	IS_Ancient_Symbols}', "");
Expect(1, 66000, '\P{-	IS_Ancient_Symbols}', "");
Expect(0, 66000, '\P{^-	IS_Ancient_Symbols}', "");
Error('\p{	 IN_Ancient_Symbols/a/}');
Error('\P{	 IN_Ancient_Symbols/a/}');
Expect(1, 65999, '\p{inancientsymbols}', "");
Expect(0, 65999, '\p{^inancientsymbols}', "");
Expect(0, 65999, '\P{inancientsymbols}', "");
Expect(1, 65999, '\P{^inancientsymbols}', "");
Expect(0, 66000, '\p{inancientsymbols}', "");
Expect(1, 66000, '\p{^inancientsymbols}', "");
Expect(1, 66000, '\P{inancientsymbols}', "");
Expect(0, 66000, '\P{^inancientsymbols}', "");
Expect(1, 65999, '\p{-In_ANCIENT_SYMBOLS}', "");
Expect(0, 65999, '\p{^-In_ANCIENT_SYMBOLS}', "");
Expect(0, 65999, '\P{-In_ANCIENT_SYMBOLS}', "");
Expect(1, 65999, '\P{^-In_ANCIENT_SYMBOLS}', "");
Expect(0, 66000, '\p{-In_ANCIENT_SYMBOLS}', "");
Expect(1, 66000, '\p{^-In_ANCIENT_SYMBOLS}', "");
Expect(1, 66000, '\P{-In_ANCIENT_SYMBOLS}', "");
Expect(0, 66000, '\P{^-In_ANCIENT_SYMBOLS}', "");
Error('\p{-	Any:=}');
Error('\P{-	Any:=}');
Expect(1, 1, '\p{any}', "");
Expect(0, 1, '\p{^any}', "");
Expect(0, 1, '\P{any}', "");
Expect(1, 1, '\P{^any}', "");
Expect(1, 1, '\p{	-Any}', "");
Expect(0, 1, '\p{^	-Any}', "");
Expect(0, 1, '\P{	-Any}', "");
Expect(1, 1, '\P{^	-Any}', "");
Error('\p{	-All:=}');
Error('\P{	-All:=}');
Expect(1, 1, '\p{all}', "");
Expect(0, 1, '\p{^all}', "");
Expect(0, 1, '\P{all}', "");
Expect(1, 1, '\P{^all}', "");
Expect(1, 1, '\p{-ALL}', "");
Expect(0, 1, '\p{^-ALL}', "");
Expect(0, 1, '\P{-ALL}', "");
Expect(1, 1, '\P{^-ALL}', "");
Error('\p{-_is_any:=}');
Error('\P{-_is_any:=}');
Expect(1, 1, '\p{isany}', "");
Expect(0, 1, '\p{^isany}', "");
Expect(0, 1, '\P{isany}', "");
Expect(1, 1, '\P{^isany}', "");
Expect(1, 1, '\p{--is_any}', "");
Expect(0, 1, '\p{^--is_any}', "");
Expect(0, 1, '\P{--is_any}', "");
Expect(1, 1, '\P{^--is_any}', "");
Error('\p{/a/__is_All}');
Error('\P{/a/__is_All}');
Expect(1, 1, '\p{isall}', "");
Expect(0, 1, '\p{^isall}', "");
Expect(0, 1, '\P{isall}', "");
Expect(1, 1, '\P{^isall}', "");
Expect(1, 1, '\p{ 	is_all}', "");
Expect(0, 1, '\p{^ 	is_all}', "");
Expect(0, 1, '\P{ 	is_all}', "");
Expect(1, 1, '\P{^ 	is_all}', "");
Error('\p{		ARABIC/a/}');
Error('\P{		ARABIC/a/}');
Expect(1, 126705, '\p{arabic}', "");
Expect(0, 126705, '\p{^arabic}', "");
Expect(0, 126705, '\P{arabic}', "");
Expect(1, 126705, '\P{^arabic}', "");
Expect(0, 126706, '\p{arabic}', "");
Expect(1, 126706, '\p{^arabic}', "");
Expect(1, 126706, '\P{arabic}', "");
Expect(0, 126706, '\P{^arabic}', "");
Expect(1, 126705, '\p{ Arabic}', "");
Expect(0, 126705, '\p{^ Arabic}', "");
Expect(0, 126705, '\P{ Arabic}', "");
Expect(1, 126705, '\P{^ Arabic}', "");
Expect(0, 126706, '\p{ Arabic}', "");
Expect(1, 126706, '\p{^ Arabic}', "");
Expect(1, 126706, '\P{ Arabic}', "");
Expect(0, 126706, '\P{^ Arabic}', "");
Error('\p{:=--Is_Arabic}');
Error('\P{:=--Is_Arabic}');
Expect(1, 126705, '\p{isarabic}', "");
Expect(0, 126705, '\p{^isarabic}', "");
Expect(0, 126705, '\P{isarabic}', "");
Expect(1, 126705, '\P{^isarabic}', "");
Expect(0, 126706, '\p{isarabic}', "");
Expect(1, 126706, '\p{^isarabic}', "");
Expect(1, 126706, '\P{isarabic}', "");
Expect(0, 126706, '\P{^isarabic}', "");
Expect(1, 126705, '\p{	 Is_Arabic}', "");
Expect(0, 126705, '\p{^	 Is_Arabic}', "");
Expect(0, 126705, '\P{	 Is_Arabic}', "");
Expect(1, 126705, '\P{^	 Is_Arabic}', "");
Expect(0, 126706, '\p{	 Is_Arabic}', "");
Expect(1, 126706, '\p{^	 Is_Arabic}', "");
Expect(1, 126706, '\P{	 Is_Arabic}', "");
Expect(0, 126706, '\P{^	 Is_Arabic}', "");
Error('\p{_arab:=}');
Error('\P{_arab:=}');
Expect(1, 126705, '\p{arab}', "");
Expect(0, 126705, '\p{^arab}', "");
Expect(0, 126705, '\P{arab}', "");
Expect(1, 126705, '\P{^arab}', "");
Expect(0, 126706, '\p{arab}', "");
Expect(1, 126706, '\p{^arab}', "");
Expect(1, 126706, '\P{arab}', "");
Expect(0, 126706, '\P{^arab}', "");
Expect(1, 126705, '\p{-Arab}', "");
Expect(0, 126705, '\p{^-Arab}', "");
Expect(0, 126705, '\P{-Arab}', "");
Expect(1, 126705, '\P{^-Arab}', "");
Expect(0, 126706, '\p{-Arab}', "");
Expect(1, 126706, '\p{^-Arab}', "");
Expect(1, 126706, '\P{-Arab}', "");
Expect(0, 126706, '\P{^-Arab}', "");
Error('\p{ :=IS_ARAB}');
Error('\P{ :=IS_ARAB}');
Expect(1, 126705, '\p{isarab}', "");
Expect(0, 126705, '\p{^isarab}', "");
Expect(0, 126705, '\P{isarab}', "");
Expect(1, 126705, '\P{^isarab}', "");
Expect(0, 126706, '\p{isarab}', "");
Expect(1, 126706, '\p{^isarab}', "");
Expect(1, 126706, '\P{isarab}', "");
Expect(0, 126706, '\P{^isarab}', "");
Expect(1, 126705, '\p{  Is_Arab}', "");
Expect(0, 126705, '\p{^  Is_Arab}', "");
Expect(0, 126705, '\P{  Is_Arab}', "");
Expect(1, 126705, '\P{^  Is_Arab}', "");
Expect(0, 126706, '\p{  Is_Arab}', "");
Expect(1, 126706, '\p{^  Is_Arab}', "");
Expect(1, 126706, '\P{  Is_Arab}', "");
Expect(0, 126706, '\P{^  Is_Arab}', "");
Error('\p{_/a/ARABIC_extended_A}');
Error('\P{_/a/ARABIC_extended_A}');
Expect(1, 2303, '\p{arabicextendeda}', "");
Expect(0, 2303, '\p{^arabicextendeda}', "");
Expect(0, 2303, '\P{arabicextendeda}', "");
Expect(1, 2303, '\P{^arabicextendeda}', "");
Expect(0, 2304, '\p{arabicextendeda}', "");
Expect(1, 2304, '\p{^arabicextendeda}', "");
Expect(1, 2304, '\P{arabicextendeda}', "");
Expect(0, 2304, '\P{^arabicextendeda}', "");
Expect(1, 2303, '\p{	Arabic_extended_A}', "");
Expect(0, 2303, '\p{^	Arabic_extended_A}', "");
Expect(0, 2303, '\P{	Arabic_extended_A}', "");
Expect(1, 2303, '\P{^	Arabic_extended_A}', "");
Expect(0, 2304, '\p{	Arabic_extended_A}', "");
Expect(1, 2304, '\p{^	Arabic_extended_A}', "");
Expect(1, 2304, '\P{	Arabic_extended_A}', "");
Expect(0, 2304, '\P{^	Arabic_extended_A}', "");
Error('\p{	:=is_Arabic_Extended_A}');
Error('\P{	:=is_Arabic_Extended_A}');
Expect(1, 2303, '\p{isarabicextendeda}', "");
Expect(0, 2303, '\p{^isarabicextendeda}', "");
Expect(0, 2303, '\P{isarabicextendeda}', "");
Expect(1, 2303, '\P{^isarabicextendeda}', "");
Expect(0, 2304, '\p{isarabicextendeda}', "");
Expect(1, 2304, '\p{^isarabicextendeda}', "");
Expect(1, 2304, '\P{isarabicextendeda}', "");
Expect(0, 2304, '\P{^isarabicextendeda}', "");
Expect(1, 2303, '\p{_	IS_Arabic_extended_a}', "");
Expect(0, 2303, '\p{^_	IS_Arabic_extended_a}', "");
Expect(0, 2303, '\P{_	IS_Arabic_extended_a}', "");
Expect(1, 2303, '\P{^_	IS_Arabic_extended_a}', "");
Expect(0, 2304, '\p{_	IS_Arabic_extended_a}', "");
Expect(1, 2304, '\p{^_	IS_Arabic_extended_a}', "");
Expect(1, 2304, '\P{_	IS_Arabic_extended_a}', "");
Expect(0, 2304, '\P{^_	IS_Arabic_extended_a}', "");
Error('\p{:=In_arabic_Extended_A}');
Error('\P{:=In_arabic_Extended_A}');
Expect(1, 2303, '\p{inarabicextendeda}', "");
Expect(0, 2303, '\p{^inarabicextendeda}', "");
Expect(0, 2303, '\P{inarabicextendeda}', "");
Expect(1, 2303, '\P{^inarabicextendeda}', "");
Expect(0, 2304, '\p{inarabicextendeda}', "");
Expect(1, 2304, '\p{^inarabicextendeda}', "");
Expect(1, 2304, '\P{inarabicextendeda}', "");
Expect(0, 2304, '\P{^inarabicextendeda}', "");
Expect(1, 2303, '\p{--in_Arabic_EXTENDED_a}', "");
Expect(0, 2303, '\p{^--in_Arabic_EXTENDED_a}', "");
Expect(0, 2303, '\P{--in_Arabic_EXTENDED_a}', "");
Expect(1, 2303, '\P{^--in_Arabic_EXTENDED_a}', "");
Expect(0, 2304, '\p{--in_Arabic_EXTENDED_a}', "");
Expect(1, 2304, '\p{^--in_Arabic_EXTENDED_a}', "");
Expect(1, 2304, '\P{--in_Arabic_EXTENDED_a}', "");
Expect(0, 2304, '\P{^--in_Arabic_EXTENDED_a}', "");
Error('\p{__Arabic_Ext_A:=}');
Error('\P{__Arabic_Ext_A:=}');
Expect(1, 2303, '\p{arabicexta}', "");
Expect(0, 2303, '\p{^arabicexta}', "");
Expect(0, 2303, '\P{arabicexta}', "");
Expect(1, 2303, '\P{^arabicexta}', "");
Expect(0, 2304, '\p{arabicexta}', "");
Expect(1, 2304, '\p{^arabicexta}', "");
Expect(1, 2304, '\P{arabicexta}', "");
Expect(0, 2304, '\P{^arabicexta}', "");
Expect(1, 2303, '\p{Arabic_EXT_A}', "");
Expect(0, 2303, '\p{^Arabic_EXT_A}', "");
Expect(0, 2303, '\P{Arabic_EXT_A}', "");
Expect(1, 2303, '\P{^Arabic_EXT_A}', "");
Expect(0, 2304, '\p{Arabic_EXT_A}', "");
Expect(1, 2304, '\p{^Arabic_EXT_A}', "");
Expect(1, 2304, '\P{Arabic_EXT_A}', "");
Expect(0, 2304, '\P{^Arabic_EXT_A}', "");
Error('\p{	 Is_Arabic_ext_a:=}');
Error('\P{	 Is_Arabic_ext_a:=}');
Expect(1, 2303, '\p{isarabicexta}', "");
Expect(0, 2303, '\p{^isarabicexta}', "");
Expect(0, 2303, '\P{isarabicexta}', "");
Expect(1, 2303, '\P{^isarabicexta}', "");
Expect(0, 2304, '\p{isarabicexta}', "");
Expect(1, 2304, '\p{^isarabicexta}', "");
Expect(1, 2304, '\P{isarabicexta}', "");
Expect(0, 2304, '\P{^isarabicexta}', "");
Expect(1, 2303, '\p{-Is_arabic_EXT_a}', "");
Expect(0, 2303, '\p{^-Is_arabic_EXT_a}', "");
Expect(0, 2303, '\P{-Is_arabic_EXT_a}', "");
Expect(1, 2303, '\P{^-Is_arabic_EXT_a}', "");
Expect(0, 2304, '\p{-Is_arabic_EXT_a}', "");
Expect(1, 2304, '\p{^-Is_arabic_EXT_a}', "");
Expect(1, 2304, '\P{-Is_arabic_EXT_a}', "");
Expect(0, 2304, '\P{^-Is_arabic_EXT_a}', "");
Error('\p{:=_IN_Arabic_EXT_A}');
Error('\P{:=_IN_Arabic_EXT_A}');
Expect(1, 2303, '\p{inarabicexta}', "");
Expect(0, 2303, '\p{^inarabicexta}', "");
Expect(0, 2303, '\P{inarabicexta}', "");
Expect(1, 2303, '\P{^inarabicexta}', "");
Expect(0, 2304, '\p{inarabicexta}', "");
Expect(1, 2304, '\p{^inarabicexta}', "");
Expect(1, 2304, '\P{inarabicexta}', "");
Expect(0, 2304, '\P{^inarabicexta}', "");
Expect(1, 2303, '\p{ In_arabic_Ext_A}', "");
Expect(0, 2303, '\p{^ In_arabic_Ext_A}', "");
Expect(0, 2303, '\P{ In_arabic_Ext_A}', "");
Expect(1, 2303, '\P{^ In_arabic_Ext_A}', "");
Expect(0, 2304, '\p{ In_arabic_Ext_A}', "");
Expect(1, 2304, '\p{^ In_arabic_Ext_A}', "");
Expect(1, 2304, '\P{ In_arabic_Ext_A}', "");
Expect(0, 2304, '\P{^ In_arabic_Ext_A}', "");
Error('\p{/a/_ ARABIC_Mathematical_Alphabetic_Symbols}');
Error('\P{/a/_ ARABIC_Mathematical_Alphabetic_Symbols}');
Expect(1, 126719, '\p{arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{arabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^arabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126719, '\p{^-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126719, '\P{-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126719, '\P{^-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126720, '\p{-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126720, '\p{^-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126720, '\P{-Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126720, '\P{^-Arabic_mathematical_Alphabetic_symbols}', "");
Error('\p{/a/  Is_ARABIC_mathematical_alphabetic_symbols}');
Error('\P{/a/  Is_ARABIC_mathematical_alphabetic_symbols}');
Expect(1, 126719, '\p{isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{isarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^isarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126719, '\p{^__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126719, '\P{__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126719, '\P{^__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126720, '\p{__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126720, '\p{^__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(1, 126720, '\P{__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Expect(0, 126720, '\P{^__IS_Arabic_mathematical_Alphabetic_symbols}', "");
Error('\p{ /a/IN_ARABIC_Mathematical_Alphabetic_symbols}');
Error('\P{ /a/IN_ARABIC_Mathematical_Alphabetic_symbols}');
Expect(1, 126719, '\p{inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\p{^inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126719, '\P{inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\P{^inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\p{inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\p{^inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126720, '\P{inarabicmathematicalalphabeticsymbols}', "");
Expect(0, 126720, '\P{^inarabicmathematicalalphabeticsymbols}', "");
Expect(1, 126719, '\p{ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126719, '\p{^ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126719, '\P{ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(1, 126719, '\P{^ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126720, '\p{ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(1, 126720, '\p{^ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(1, 126720, '\P{ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Expect(0, 126720, '\P{^ in_ARABIC_Mathematical_Alphabetic_SYMBOLS}', "");
Error('\p{/a/	arabic_Math}');
Error('\P{/a/	arabic_Math}');
Expect(1, 126719, '\p{arabicmath}', "");
Expect(0, 126719, '\p{^arabicmath}', "");
Expect(0, 126719, '\P{arabicmath}', "");
Expect(1, 126719, '\P{^arabicmath}', "");
Expect(0, 126720, '\p{arabicmath}', "");
Expect(1, 126720, '\p{^arabicmath}', "");
Expect(1, 126720, '\P{arabicmath}', "");
Expect(0, 126720, '\P{^arabicmath}', "");
Expect(1, 126719, '\p{__Arabic_Math}', "");
Expect(0, 126719, '\p{^__Arabic_Math}', "");
Expect(0, 126719, '\P{__Arabic_Math}', "");
Expect(1, 126719, '\P{^__Arabic_Math}', "");
Expect(0, 126720, '\p{__Arabic_Math}', "");
Expect(1, 126720, '\p{^__Arabic_Math}', "");
Expect(1, 126720, '\P{__Arabic_Math}', "");
Expect(0, 126720, '\P{^__Arabic_Math}', "");
Error('\p{	-Is_Arabic_Math:=}');
Error('\P{	-Is_Arabic_Math:=}');
Expect(1, 126719, '\p{isarabicmath}', "");
Expect(0, 126719, '\p{^isarabicmath}', "");
Expect(0, 126719, '\P{isarabicmath}', "");
Expect(1, 126719, '\P{^isarabicmath}', "");
Expect(0, 126720, '\p{isarabicmath}', "");
Expect(1, 126720, '\p{^isarabicmath}', "");
Expect(1, 126720, '\P{isarabicmath}', "");
Expect(0, 126720, '\P{^isarabicmath}', "");
Expect(1, 126719, '\p{	-IS_ARABIC_Math}', "");
Expect(0, 126719, '\p{^	-IS_ARABIC_Math}', "");
Expect(0, 126719, '\P{	-IS_ARABIC_Math}', "");
Expect(1, 126719, '\P{^	-IS_ARABIC_Math}', "");
Expect(0, 126720, '\p{	-IS_ARABIC_Math}', "");
Expect(1, 126720, '\p{^	-IS_ARABIC_Math}', "");
Expect(1, 126720, '\P{	-IS_ARABIC_Math}', "");
Expect(0, 126720, '\P{^	-IS_ARABIC_Math}', "");
Error('\p{:=In_arabic_MATH}');
Error('\P{:=In_arabic_MATH}');
Expect(1, 126719, '\p{inarabicmath}', "");
Expect(0, 126719, '\p{^inarabicmath}', "");
Expect(0, 126719, '\P{inarabicmath}', "");
Expect(1, 126719, '\P{^inarabicmath}', "");
Expect(0, 126720, '\p{inarabicmath}', "");
Expect(1, 126720, '\p{^inarabicmath}', "");
Expect(1, 126720, '\P{inarabicmath}', "");
Expect(0, 126720, '\P{^inarabicmath}', "");
Expect(1, 126719, '\p{_	in_ARABIC_MATH}', "");
Expect(0, 126719, '\p{^_	in_ARABIC_MATH}', "");
Expect(0, 126719, '\P{_	in_ARABIC_MATH}', "");
Expect(1, 126719, '\P{^_	in_ARABIC_MATH}', "");
Expect(0, 126720, '\p{_	in_ARABIC_MATH}', "");
Expect(1, 126720, '\p{^_	in_ARABIC_MATH}', "");
Expect(1, 126720, '\P{_	in_ARABIC_MATH}', "");
Expect(0, 126720, '\P{^_	in_ARABIC_MATH}', "");
Error('\p{:=	 Arabic_Presentation_FORMS_A}');
Error('\P{:=	 Arabic_Presentation_FORMS_A}');
Expect(1, 65023, '\p{arabicpresentationformsa}', "");
Expect(0, 65023, '\p{^arabicpresentationformsa}', "");
Expect(0, 65023, '\P{arabicpresentationformsa}', "");
Expect(1, 65023, '\P{^arabicpresentationformsa}', "");
Expect(0, 65024, '\p{arabicpresentationformsa}', "");
Expect(1, 65024, '\p{^arabicpresentationformsa}', "");
Expect(1, 65024, '\P{arabicpresentationformsa}', "");
Expect(0, 65024, '\P{^arabicpresentationformsa}', "");
Expect(1, 65023, '\p{		Arabic_PRESENTATION_forms_A}', "");
Expect(0, 65023, '\p{^		Arabic_PRESENTATION_forms_A}', "");
Expect(0, 65023, '\P{		Arabic_PRESENTATION_forms_A}', "");
Expect(1, 65023, '\P{^		Arabic_PRESENTATION_forms_A}', "");
Expect(0, 65024, '\p{		Arabic_PRESENTATION_forms_A}', "");
Expect(1, 65024, '\p{^		Arabic_PRESENTATION_forms_A}', "");
Expect(1, 65024, '\P{		Arabic_PRESENTATION_forms_A}', "");
Expect(0, 65024, '\P{^		Arabic_PRESENTATION_forms_A}', "");
Error('\p{:=-	Is_Arabic_PRESENTATION_forms_A}');
Error('\P{:=-	Is_Arabic_PRESENTATION_forms_A}');
Expect(1, 65023, '\p{isarabicpresentationformsa}', "");
Expect(0, 65023, '\p{^isarabicpresentationformsa}', "");
Expect(0, 65023, '\P{isarabicpresentationformsa}', "");
Expect(1, 65023, '\P{^isarabicpresentationformsa}', "");
Expect(0, 65024, '\p{isarabicpresentationformsa}', "");
Expect(1, 65024, '\p{^isarabicpresentationformsa}', "");
Expect(1, 65024, '\P{isarabicpresentationformsa}', "");
Expect(0, 65024, '\P{^isarabicpresentationformsa}', "");
Expect(1, 65023, '\p{ Is_Arabic_Presentation_forms_A}', "");
Expect(0, 65023, '\p{^ Is_Arabic_Presentation_forms_A}', "");
Expect(0, 65023, '\P{ Is_Arabic_Presentation_forms_A}', "");
Expect(1, 65023, '\P{^ Is_Arabic_Presentation_forms_A}', "");
Expect(0, 65024, '\p{ Is_Arabic_Presentation_forms_A}', "");
Expect(1, 65024, '\p{^ Is_Arabic_Presentation_forms_A}', "");
Expect(1, 65024, '\P{ Is_Arabic_Presentation_forms_A}', "");
Expect(0, 65024, '\P{^ Is_Arabic_Presentation_forms_A}', "");
Error('\p{/a/_-In_Arabic_presentation_FORMS_A}');
Error('\P{/a/_-In_Arabic_presentation_FORMS_A}');
Expect(1, 65023, '\p{inarabicpresentationformsa}', "");
Expect(0, 65023, '\p{^inarabicpresentationformsa}', "");
Expect(0, 65023, '\P{inarabicpresentationformsa}', "");
Expect(1, 65023, '\P{^inarabicpresentationformsa}', "");
Expect(0, 65024, '\p{inarabicpresentationformsa}', "");
Expect(1, 65024, '\p{^inarabicpresentationformsa}', "");
Expect(1, 65024, '\P{inarabicpresentationformsa}', "");
Expect(0, 65024, '\P{^inarabicpresentationformsa}', "");
Expect(1, 65023, '\p{-_IN_Arabic_Presentation_forms_A}', "");
Expect(0, 65023, '\p{^-_IN_Arabic_Presentation_forms_A}', "");
Expect(0, 65023, '\P{-_IN_Arabic_Presentation_forms_A}', "");
Expect(1, 65023, '\P{^-_IN_Arabic_Presentation_forms_A}', "");
Expect(0, 65024, '\p{-_IN_Arabic_Presentation_forms_A}', "");
Expect(1, 65024, '\p{^-_IN_Arabic_Presentation_forms_A}', "");
Expect(1, 65024, '\P{-_IN_Arabic_Presentation_forms_A}', "");
Expect(0, 65024, '\P{^-_IN_Arabic_Presentation_forms_A}', "");
Error('\p{/a/_	Arabic_PF_A}');
Error('\P{/a/_	Arabic_PF_A}');
Expect(1, 65023, '\p{arabicpfa}', "");
Expect(0, 65023, '\p{^arabicpfa}', "");
Expect(0, 65023, '\P{arabicpfa}', "");
Expect(1, 65023, '\P{^arabicpfa}', "");
Expect(0, 65024, '\p{arabicpfa}', "");
Expect(1, 65024, '\p{^arabicpfa}', "");
Expect(1, 65024, '\P{arabicpfa}', "");
Expect(0, 65024, '\P{^arabicpfa}', "");
Expect(1, 65023, '\p{--ARABIC_PF_a}', "");
Expect(0, 65023, '\p{^--ARABIC_PF_a}', "");
Expect(0, 65023, '\P{--ARABIC_PF_a}', "");
Expect(1, 65023, '\P{^--ARABIC_PF_a}', "");
Expect(0, 65024, '\p{--ARABIC_PF_a}', "");
Expect(1, 65024, '\p{^--ARABIC_PF_a}', "");
Expect(1, 65024, '\P{--ARABIC_PF_a}', "");
Expect(0, 65024, '\P{^--ARABIC_PF_a}', "");
Error('\p{--Is_arabic_PF_a/a/}');
Error('\P{--Is_arabic_PF_a/a/}');
Expect(1, 65023, '\p{isarabicpfa}', "");
Expect(0, 65023, '\p{^isarabicpfa}', "");
Expect(0, 65023, '\P{isarabicpfa}', "");
Expect(1, 65023, '\P{^isarabicpfa}', "");
Expect(0, 65024, '\p{isarabicpfa}', "");
Expect(1, 65024, '\p{^isarabicpfa}', "");
Expect(1, 65024, '\P{isarabicpfa}', "");
Expect(0, 65024, '\P{^isarabicpfa}', "");
Expect(1, 65023, '\p{ _is_Arabic_PF_A}', "");
Expect(0, 65023, '\p{^ _is_Arabic_PF_A}', "");
Expect(0, 65023, '\P{ _is_Arabic_PF_A}', "");
Expect(1, 65023, '\P{^ _is_Arabic_PF_A}', "");
Expect(0, 65024, '\p{ _is_Arabic_PF_A}', "");
Expect(1, 65024, '\p{^ _is_Arabic_PF_A}', "");
Expect(1, 65024, '\P{ _is_Arabic_PF_A}', "");
Expect(0, 65024, '\P{^ _is_Arabic_PF_A}', "");
Error('\p{:=	-In_Arabic_PF_A}');
Error('\P{:=	-In_Arabic_PF_A}');
Expect(1, 65023, '\p{inarabicpfa}', "");
Expect(0, 65023, '\p{^inarabicpfa}', "");
Expect(0, 65023, '\P{inarabicpfa}', "");
Expect(1, 65023, '\P{^inarabicpfa}', "");
Expect(0, 65024, '\p{inarabicpfa}', "");
Expect(1, 65024, '\p{^inarabicpfa}', "");
Expect(1, 65024, '\P{inarabicpfa}', "");
Expect(0, 65024, '\P{^inarabicpfa}', "");
Expect(1, 65023, '\p{	 IN_Arabic_PF_A}', "");
Expect(0, 65023, '\p{^	 IN_Arabic_PF_A}', "");
Expect(0, 65023, '\P{	 IN_Arabic_PF_A}', "");
Expect(1, 65023, '\P{^	 IN_Arabic_PF_A}', "");
Expect(0, 65024, '\p{	 IN_Arabic_PF_A}', "");
Expect(1, 65024, '\p{^	 IN_Arabic_PF_A}', "");
Expect(1, 65024, '\P{	 IN_Arabic_PF_A}', "");
Expect(0, 65024, '\P{^	 IN_Arabic_PF_A}', "");
Error('\p{-/a/Arabic_presentation_Forms_b}');
Error('\P{-/a/Arabic_presentation_Forms_b}');
Expect(1, 65279, '\p{arabicpresentationformsb}', "");
Expect(0, 65279, '\p{^arabicpresentationformsb}', "");
Expect(0, 65279, '\P{arabicpresentationformsb}', "");
Expect(1, 65279, '\P{^arabicpresentationformsb}', "");
Expect(0, 65280, '\p{arabicpresentationformsb}', "");
Expect(1, 65280, '\p{^arabicpresentationformsb}', "");
Expect(1, 65280, '\P{arabicpresentationformsb}', "");
Expect(0, 65280, '\P{^arabicpresentationformsb}', "");
Expect(1, 65279, '\p{_ARABIC_Presentation_forms_B}', "");
Expect(0, 65279, '\p{^_ARABIC_Presentation_forms_B}', "");
Expect(0, 65279, '\P{_ARABIC_Presentation_forms_B}', "");
Expect(1, 65279, '\P{^_ARABIC_Presentation_forms_B}', "");
Expect(0, 65280, '\p{_ARABIC_Presentation_forms_B}', "");
Expect(1, 65280, '\p{^_ARABIC_Presentation_forms_B}', "");
Expect(1, 65280, '\P{_ARABIC_Presentation_forms_B}', "");
Expect(0, 65280, '\P{^_ARABIC_Presentation_forms_B}', "");
Error('\p{-_is_Arabic_Presentation_Forms_B/a/}');
Error('\P{-_is_Arabic_Presentation_Forms_B/a/}');
Expect(1, 65279, '\p{isarabicpresentationformsb}', "");
Expect(0, 65279, '\p{^isarabicpresentationformsb}', "");
Expect(0, 65279, '\P{isarabicpresentationformsb}', "");
Expect(1, 65279, '\P{^isarabicpresentationformsb}', "");
Expect(0, 65280, '\p{isarabicpresentationformsb}', "");
Expect(1, 65280, '\p{^isarabicpresentationformsb}', "");
Expect(1, 65280, '\P{isarabicpresentationformsb}', "");
Expect(0, 65280, '\P{^isarabicpresentationformsb}', "");
Expect(1, 65279, '\p{	Is_ARABIC_Presentation_forms_B}', "");
Expect(0, 65279, '\p{^	Is_ARABIC_Presentation_forms_B}', "");
Expect(0, 65279, '\P{	Is_ARABIC_Presentation_forms_B}', "");
Expect(1, 65279, '\P{^	Is_ARABIC_Presentation_forms_B}', "");
Expect(0, 65280, '\p{	Is_ARABIC_Presentation_forms_B}', "");
Expect(1, 65280, '\p{^	Is_ARABIC_Presentation_forms_B}', "");
Expect(1, 65280, '\P{	Is_ARABIC_Presentation_forms_B}', "");
Expect(0, 65280, '\P{^	Is_ARABIC_Presentation_forms_B}', "");
Error('\p{	/a/IN_ARABIC_presentation_Forms_B}');
Error('\P{	/a/IN_ARABIC_presentation_Forms_B}');
Expect(1, 65279, '\p{inarabicpresentationformsb}', "");
Expect(0, 65279, '\p{^inarabicpresentationformsb}', "");
Expect(0, 65279, '\P{inarabicpresentationformsb}', "");
Expect(1, 65279, '\P{^inarabicpresentationformsb}', "");
Expect(0, 65280, '\p{inarabicpresentationformsb}', "");
Expect(1, 65280, '\p{^inarabicpresentationformsb}', "");
Expect(1, 65280, '\P{inarabicpresentationformsb}', "");
Expect(0, 65280, '\P{^inarabicpresentationformsb}', "");
Expect(1, 65279, '\p{- In_Arabic_Presentation_forms_B}', "");
Expect(0, 65279, '\p{^- In_Arabic_Presentation_forms_B}', "");
Expect(0, 65279, '\P{- In_Arabic_Presentation_forms_B}', "");
Expect(1, 65279, '\P{^- In_Arabic_Presentation_forms_B}', "");
Expect(0, 65280, '\p{- In_Arabic_Presentation_forms_B}', "");
Expect(1, 65280, '\p{^- In_Arabic_Presentation_forms_B}', "");
Expect(1, 65280, '\P{- In_Arabic_Presentation_forms_B}', "");
Expect(0, 65280, '\P{^- In_Arabic_Presentation_forms_B}', "");
Error('\p{ arabic_PF_b/a/}');
Error('\P{ arabic_PF_b/a/}');
Expect(1, 65279, '\p{arabicpfb}', "");
Expect(0, 65279, '\p{^arabicpfb}', "");
Expect(0, 65279, '\P{arabicpfb}', "");
Expect(1, 65279, '\P{^arabicpfb}', "");
Expect(0, 65280, '\p{arabicpfb}', "");
Expect(1, 65280, '\p{^arabicpfb}', "");
Expect(1, 65280, '\P{arabicpfb}', "");
Expect(0, 65280, '\P{^arabicpfb}', "");
Expect(1, 65279, '\p{ _arabic_pf_b}', "");
Expect(0, 65279, '\p{^ _arabic_pf_b}', "");
Expect(0, 65279, '\P{ _arabic_pf_b}', "");
Expect(1, 65279, '\P{^ _arabic_pf_b}', "");
Expect(0, 65280, '\p{ _arabic_pf_b}', "");
Expect(1, 65280, '\p{^ _arabic_pf_b}', "");
Expect(1, 65280, '\P{ _arabic_pf_b}', "");
Expect(0, 65280, '\P{^ _arabic_pf_b}', "");
Error('\p{/a/ IS_Arabic_PF_B}');
Error('\P{/a/ IS_Arabic_PF_B}');
Expect(1, 65279, '\p{isarabicpfb}', "");
Expect(0, 65279, '\p{^isarabicpfb}', "");
Expect(0, 65279, '\P{isarabicpfb}', "");
Expect(1, 65279, '\P{^isarabicpfb}', "");
Expect(0, 65280, '\p{isarabicpfb}', "");
Expect(1, 65280, '\p{^isarabicpfb}', "");
Expect(1, 65280, '\P{isarabicpfb}', "");
Expect(0, 65280, '\P{^isarabicpfb}', "");
Expect(1, 65279, '\p{	 Is_Arabic_pf_B}', "");
Expect(0, 65279, '\p{^	 Is_Arabic_pf_B}', "");
Expect(0, 65279, '\P{	 Is_Arabic_pf_B}', "");
Expect(1, 65279, '\P{^	 Is_Arabic_pf_B}', "");
Expect(0, 65280, '\p{	 Is_Arabic_pf_B}', "");
Expect(1, 65280, '\p{^	 Is_Arabic_pf_B}', "");
Expect(1, 65280, '\P{	 Is_Arabic_pf_B}', "");
Expect(0, 65280, '\P{^	 Is_Arabic_pf_B}', "");
Error('\p{	IN_Arabic_PF_B:=}');
Error('\P{	IN_Arabic_PF_B:=}');
Expect(1, 65279, '\p{inarabicpfb}', "");
Expect(0, 65279, '\p{^inarabicpfb}', "");
Expect(0, 65279, '\P{inarabicpfb}', "");
Expect(1, 65279, '\P{^inarabicpfb}', "");
Expect(0, 65280, '\p{inarabicpfb}', "");
Expect(1, 65280, '\p{^inarabicpfb}', "");
Expect(1, 65280, '\P{inarabicpfb}', "");
Expect(0, 65280, '\P{^inarabicpfb}', "");
Expect(1, 65279, '\p{_	in_Arabic_PF_B}', "");
Expect(0, 65279, '\p{^_	in_Arabic_PF_B}', "");
Expect(0, 65279, '\P{_	in_Arabic_PF_B}', "");
Expect(1, 65279, '\P{^_	in_Arabic_PF_B}', "");
Expect(0, 65280, '\p{_	in_Arabic_PF_B}', "");
Expect(1, 65280, '\p{^_	in_Arabic_PF_B}', "");
Expect(1, 65280, '\P{_	in_Arabic_PF_B}', "");
Expect(0, 65280, '\P{^_	in_Arabic_PF_B}', "");
Error('\p{- ARABIC_supplement:=}');
Error('\P{- ARABIC_supplement:=}');
Expect(1, 1919, '\p{arabicsupplement}', "");
Expect(0, 1919, '\p{^arabicsupplement}', "");
Expect(0, 1919, '\P{arabicsupplement}', "");
Expect(1, 1919, '\P{^arabicsupplement}', "");
Expect(0, 1920, '\p{arabicsupplement}', "");
Expect(1, 1920, '\p{^arabicsupplement}', "");
Expect(1, 1920, '\P{arabicsupplement}', "");
Expect(0, 1920, '\P{^arabicsupplement}', "");
Expect(1, 1919, '\p{_Arabic_supplement}', "");
Expect(0, 1919, '\p{^_Arabic_supplement}', "");
Expect(0, 1919, '\P{_Arabic_supplement}', "");
Expect(1, 1919, '\P{^_Arabic_supplement}', "");
Expect(0, 1920, '\p{_Arabic_supplement}', "");
Expect(1, 1920, '\p{^_Arabic_supplement}', "");
Expect(1, 1920, '\P{_Arabic_supplement}', "");
Expect(0, 1920, '\P{^_Arabic_supplement}', "");
Error('\p{/a/--Is_ARABIC_Supplement}');
Error('\P{/a/--Is_ARABIC_Supplement}');
Expect(1, 1919, '\p{isarabicsupplement}', "");
Expect(0, 1919, '\p{^isarabicsupplement}', "");
Expect(0, 1919, '\P{isarabicsupplement}', "");
Expect(1, 1919, '\P{^isarabicsupplement}', "");
Expect(0, 1920, '\p{isarabicsupplement}', "");
Expect(1, 1920, '\p{^isarabicsupplement}', "");
Expect(1, 1920, '\P{isarabicsupplement}', "");
Expect(0, 1920, '\P{^isarabicsupplement}', "");
Expect(1, 1919, '\p{- IS_ARABIC_Supplement}', "");
Expect(0, 1919, '\p{^- IS_ARABIC_Supplement}', "");
Expect(0, 1919, '\P{- IS_ARABIC_Supplement}', "");
Expect(1, 1919, '\P{^- IS_ARABIC_Supplement}', "");
Expect(0, 1920, '\p{- IS_ARABIC_Supplement}', "");
Expect(1, 1920, '\p{^- IS_ARABIC_Supplement}', "");
Expect(1, 1920, '\P{- IS_ARABIC_Supplement}', "");
Expect(0, 1920, '\P{^- IS_ARABIC_Supplement}', "");
Error('\p{	_In_Arabic_SUPPLEMENT:=}');
Error('\P{	_In_Arabic_SUPPLEMENT:=}');
Expect(1, 1919, '\p{inarabicsupplement}', "");
Expect(0, 1919, '\p{^inarabicsupplement}', "");
Expect(0, 1919, '\P{inarabicsupplement}', "");
Expect(1, 1919, '\P{^inarabicsupplement}', "");
Expect(0, 1920, '\p{inarabicsupplement}', "");
Expect(1, 1920, '\p{^inarabicsupplement}', "");
Expect(1, 1920, '\P{inarabicsupplement}', "");
Expect(0, 1920, '\P{^inarabicsupplement}', "");
Expect(1, 1919, '\p{-_in_ARABIC_Supplement}', "");
Expect(0, 1919, '\p{^-_in_ARABIC_Supplement}', "");
Expect(0, 1919, '\P{-_in_ARABIC_Supplement}', "");
Expect(1, 1919, '\P{^-_in_ARABIC_Supplement}', "");
Expect(0, 1920, '\p{-_in_ARABIC_Supplement}', "");
Expect(1, 1920, '\p{^-_in_ARABIC_Supplement}', "");
Expect(1, 1920, '\P{-_in_ARABIC_Supplement}', "");
Expect(0, 1920, '\P{^-_in_ARABIC_Supplement}', "");
Error('\p{-_ARABIC_sup/a/}');
Error('\P{-_ARABIC_sup/a/}');
Expect(1, 1919, '\p{arabicsup}', "");
Expect(0, 1919, '\p{^arabicsup}', "");
Expect(0, 1919, '\P{arabicsup}', "");
Expect(1, 1919, '\P{^arabicsup}', "");
Expect(0, 1920, '\p{arabicsup}', "");
Expect(1, 1920, '\p{^arabicsup}', "");
Expect(1, 1920, '\P{arabicsup}', "");
Expect(0, 1920, '\P{^arabicsup}', "");
Expect(1, 1919, '\p{-	ARABIC_Sup}', "");
Expect(0, 1919, '\p{^-	ARABIC_Sup}', "");
Expect(0, 1919, '\P{-	ARABIC_Sup}', "");
Expect(1, 1919, '\P{^-	ARABIC_Sup}', "");
Expect(0, 1920, '\p{-	ARABIC_Sup}', "");
Expect(1, 1920, '\p{^-	ARABIC_Sup}', "");
Expect(1, 1920, '\P{-	ARABIC_Sup}', "");
Expect(0, 1920, '\P{^-	ARABIC_Sup}', "");
Error('\p{/a/-_IS_Arabic_sup}');
Error('\P{/a/-_IS_Arabic_sup}');
Expect(1, 1919, '\p{isarabicsup}', "");
Expect(0, 1919, '\p{^isarabicsup}', "");
Expect(0, 1919, '\P{isarabicsup}', "");
Expect(1, 1919, '\P{^isarabicsup}', "");
Expect(0, 1920, '\p{isarabicsup}', "");
Expect(1, 1920, '\p{^isarabicsup}', "");
Expect(1, 1920, '\P{isarabicsup}', "");
Expect(0, 1920, '\P{^isarabicsup}', "");
Expect(1, 1919, '\p{_Is_ARABIC_SUP}', "");
Expect(0, 1919, '\p{^_Is_ARABIC_SUP}', "");
Expect(0, 1919, '\P{_Is_ARABIC_SUP}', "");
Expect(1, 1919, '\P{^_Is_ARABIC_SUP}', "");
Expect(0, 1920, '\p{_Is_ARABIC_SUP}', "");
Expect(1, 1920, '\p{^_Is_ARABIC_SUP}', "");
Expect(1, 1920, '\P{_Is_ARABIC_SUP}', "");
Expect(0, 1920, '\P{^_Is_ARABIC_SUP}', "");
Error('\p{-in_Arabic_SUP:=}');
Error('\P{-in_Arabic_SUP:=}');
Expect(1, 1919, '\p{inarabicsup}', "");
Expect(0, 1919, '\p{^inarabicsup}', "");
Expect(0, 1919, '\P{inarabicsup}', "");
Expect(1, 1919, '\P{^inarabicsup}', "");
Expect(0, 1920, '\p{inarabicsup}', "");
Expect(1, 1920, '\p{^inarabicsup}', "");
Expect(1, 1920, '\P{inarabicsup}', "");
Expect(0, 1920, '\P{^inarabicsup}', "");
Expect(1, 1919, '\p{_ In_Arabic_SUP}', "");
Expect(0, 1919, '\p{^_ In_Arabic_SUP}', "");
Expect(0, 1919, '\P{_ In_Arabic_SUP}', "");
Expect(1, 1919, '\P{^_ In_Arabic_SUP}', "");
Expect(0, 1920, '\p{_ In_Arabic_SUP}', "");
Expect(1, 1920, '\p{^_ In_Arabic_SUP}', "");
Expect(1, 1920, '\P{_ In_Arabic_SUP}', "");
Expect(0, 1920, '\P{^_ In_Arabic_SUP}', "");
Error('\p{ ARMENIAN/a/}');
Error('\P{ ARMENIAN/a/}');
Expect(1, 64279, '\p{armenian}', "");
Expect(0, 64279, '\p{^armenian}', "");
Expect(0, 64279, '\P{armenian}', "");
Expect(1, 64279, '\P{^armenian}', "");
Expect(0, 64280, '\p{armenian}', "");
Expect(1, 64280, '\p{^armenian}', "");
Expect(1, 64280, '\P{armenian}', "");
Expect(0, 64280, '\P{^armenian}', "");
Expect(1, 64279, '\p{	_Armenian}', "");
Expect(0, 64279, '\p{^	_Armenian}', "");
Expect(0, 64279, '\P{	_Armenian}', "");
Expect(1, 64279, '\P{^	_Armenian}', "");
Expect(0, 64280, '\p{	_Armenian}', "");
Expect(1, 64280, '\p{^	_Armenian}', "");
Expect(1, 64280, '\P{	_Armenian}', "");
Expect(0, 64280, '\P{^	_Armenian}', "");
Error('\p{__Is_ARMENIAN:=}');
Error('\P{__Is_ARMENIAN:=}');
Expect(1, 64279, '\p{isarmenian}', "");
Expect(0, 64279, '\p{^isarmenian}', "");
Expect(0, 64279, '\P{isarmenian}', "");
Expect(1, 64279, '\P{^isarmenian}', "");
Expect(0, 64280, '\p{isarmenian}', "");
Expect(1, 64280, '\p{^isarmenian}', "");
Expect(1, 64280, '\P{isarmenian}', "");
Expect(0, 64280, '\P{^isarmenian}', "");
Expect(1, 64279, '\p{_-IS_Armenian}', "");
Expect(0, 64279, '\p{^_-IS_Armenian}', "");
Expect(0, 64279, '\P{_-IS_Armenian}', "");
Expect(1, 64279, '\P{^_-IS_Armenian}', "");
Expect(0, 64280, '\p{_-IS_Armenian}', "");
Expect(1, 64280, '\p{^_-IS_Armenian}', "");
Expect(1, 64280, '\P{_-IS_Armenian}', "");
Expect(0, 64280, '\P{^_-IS_Armenian}', "");
Error('\p{_:=Armn}');
Error('\P{_:=Armn}');
Expect(1, 64279, '\p{armn}', "");
Expect(0, 64279, '\p{^armn}', "");
Expect(0, 64279, '\P{armn}', "");
Expect(1, 64279, '\P{^armn}', "");
Expect(0, 64280, '\p{armn}', "");
Expect(1, 64280, '\p{^armn}', "");
Expect(1, 64280, '\P{armn}', "");
Expect(0, 64280, '\P{^armn}', "");
Expect(1, 64279, '\p{ -ARMN}', "");
Expect(0, 64279, '\p{^ -ARMN}', "");
Expect(0, 64279, '\P{ -ARMN}', "");
Expect(1, 64279, '\P{^ -ARMN}', "");
Expect(0, 64280, '\p{ -ARMN}', "");
Expect(1, 64280, '\p{^ -ARMN}', "");
Expect(1, 64280, '\P{ -ARMN}', "");
Expect(0, 64280, '\P{^ -ARMN}', "");
Error('\p{IS_armn:=}');
Error('\P{IS_armn:=}');
Expect(1, 64279, '\p{isarmn}', "");
Expect(0, 64279, '\p{^isarmn}', "");
Expect(0, 64279, '\P{isarmn}', "");
Expect(1, 64279, '\P{^isarmn}', "");
Expect(0, 64280, '\p{isarmn}', "");
Expect(1, 64280, '\p{^isarmn}', "");
Expect(1, 64280, '\P{isarmn}', "");
Expect(0, 64280, '\P{^isarmn}', "");
Expect(1, 64279, '\p{_	Is_Armn}', "");
Expect(0, 64279, '\p{^_	Is_Armn}', "");
Expect(0, 64279, '\P{_	Is_Armn}', "");
Expect(1, 64279, '\P{^_	Is_Armn}', "");
Expect(0, 64280, '\p{_	Is_Armn}', "");
Expect(1, 64280, '\p{^_	Is_Armn}', "");
Expect(1, 64280, '\P{_	Is_Armn}', "");
Expect(0, 64280, '\P{^_	Is_Armn}', "");
Error('\p{:=ARROWS}');
Error('\P{:=ARROWS}');
Expect(1, 8703, '\p{arrows}', "");
Expect(0, 8703, '\p{^arrows}', "");
Expect(0, 8703, '\P{arrows}', "");
Expect(1, 8703, '\P{^arrows}', "");
Expect(0, 8704, '\p{arrows}', "");
Expect(1, 8704, '\p{^arrows}', "");
Expect(1, 8704, '\P{arrows}', "");
Expect(0, 8704, '\P{^arrows}', "");
Expect(1, 8703, '\p{	 Arrows}', "");
Expect(0, 8703, '\p{^	 Arrows}', "");
Expect(0, 8703, '\P{	 Arrows}', "");
Expect(1, 8703, '\P{^	 Arrows}', "");
Expect(0, 8704, '\p{	 Arrows}', "");
Expect(1, 8704, '\p{^	 Arrows}', "");
Expect(1, 8704, '\P{	 Arrows}', "");
Expect(0, 8704, '\P{^	 Arrows}', "");
Error('\p{/a/Is_Arrows}');
Error('\P{/a/Is_Arrows}');
Expect(1, 8703, '\p{isarrows}', "");
Expect(0, 8703, '\p{^isarrows}', "");
Expect(0, 8703, '\P{isarrows}', "");
Expect(1, 8703, '\P{^isarrows}', "");
Expect(0, 8704, '\p{isarrows}', "");
Expect(1, 8704, '\p{^isarrows}', "");
Expect(1, 8704, '\P{isarrows}', "");
Expect(0, 8704, '\P{^isarrows}', "");
Expect(1, 8703, '\p{ Is_arrows}', "");
Expect(0, 8703, '\p{^ Is_arrows}', "");
Expect(0, 8703, '\P{ Is_arrows}', "");
Expect(1, 8703, '\P{^ Is_arrows}', "");
Expect(0, 8704, '\p{ Is_arrows}', "");
Expect(1, 8704, '\p{^ Is_arrows}', "");
Expect(1, 8704, '\P{ Is_arrows}', "");
Expect(0, 8704, '\P{^ Is_arrows}', "");
Error('\p{:=		In_Arrows}');
Error('\P{:=		In_Arrows}');
Expect(1, 8703, '\p{inarrows}', "");
Expect(0, 8703, '\p{^inarrows}', "");
Expect(0, 8703, '\P{inarrows}', "");
Expect(1, 8703, '\P{^inarrows}', "");
Expect(0, 8704, '\p{inarrows}', "");
Expect(1, 8704, '\p{^inarrows}', "");
Expect(1, 8704, '\P{inarrows}', "");
Expect(0, 8704, '\P{^inarrows}', "");
Expect(1, 8703, '\p{In_Arrows}', "");
Expect(0, 8703, '\p{^In_Arrows}', "");
Expect(0, 8703, '\P{In_Arrows}', "");
Expect(1, 8703, '\P{^In_Arrows}', "");
Expect(0, 8704, '\p{In_Arrows}', "");
Expect(1, 8704, '\p{^In_Arrows}', "");
Expect(1, 8704, '\P{In_Arrows}', "");
Expect(0, 8704, '\P{^In_Arrows}', "");
Error('\p{	 ASSIGNED:=}');
Error('\P{	 ASSIGNED:=}');
Expect(1, 1114109, '\p{assigned}', "");
Expect(0, 1114109, '\p{^assigned}', "");
Expect(0, 1114109, '\P{assigned}', "");
Expect(1, 1114109, '\P{^assigned}', "");
Expect(0, 918000, '\p{assigned}', "");
Expect(1, 918000, '\p{^assigned}', "");
Expect(1, 918000, '\P{assigned}', "");
Expect(0, 918000, '\P{^assigned}', "");
Expect(1, 1114109, '\p{-ASSIGNED}', "");
Expect(0, 1114109, '\p{^-ASSIGNED}', "");
Expect(0, 1114109, '\P{-ASSIGNED}', "");
Expect(1, 1114109, '\P{^-ASSIGNED}', "");
Expect(0, 918000, '\p{-ASSIGNED}', "");
Expect(1, 918000, '\p{^-ASSIGNED}', "");
Expect(1, 918000, '\P{-ASSIGNED}', "");
Expect(0, 918000, '\P{^-ASSIGNED}', "");
Error('\p{_/a/IS_ASSIGNED}');
Error('\P{_/a/IS_ASSIGNED}');
Expect(1, 1114109, '\p{isassigned}', "");
Expect(0, 1114109, '\p{^isassigned}', "");
Expect(0, 1114109, '\P{isassigned}', "");
Expect(1, 1114109, '\P{^isassigned}', "");
Expect(0, 918000, '\p{isassigned}', "");
Expect(1, 918000, '\p{^isassigned}', "");
Expect(1, 918000, '\P{isassigned}', "");
Expect(0, 918000, '\P{^isassigned}', "");
Expect(1, 1114109, '\p{_	Is_Assigned}', "");
Expect(0, 1114109, '\p{^_	Is_Assigned}', "");
Expect(0, 1114109, '\P{_	Is_Assigned}', "");
Expect(1, 1114109, '\P{^_	Is_Assigned}', "");
Expect(0, 918000, '\p{_	Is_Assigned}', "");
Expect(1, 918000, '\p{^_	Is_Assigned}', "");
Expect(1, 918000, '\P{_	Is_Assigned}', "");
Expect(0, 918000, '\P{^_	Is_Assigned}', "");
Error('\p{-:=Avestan}');
Error('\P{-:=Avestan}');
Expect(1, 68415, '\p{avestan}', "");
Expect(0, 68415, '\p{^avestan}', "");
Expect(0, 68415, '\P{avestan}', "");
Expect(1, 68415, '\P{^avestan}', "");
Expect(0, 68416, '\p{avestan}', "");
Expect(1, 68416, '\p{^avestan}', "");
Expect(1, 68416, '\P{avestan}', "");
Expect(0, 68416, '\P{^avestan}', "");
Expect(1, 68415, '\p{  AVESTAN}', "");
Expect(0, 68415, '\p{^  AVESTAN}', "");
Expect(0, 68415, '\P{  AVESTAN}', "");
Expect(1, 68415, '\P{^  AVESTAN}', "");
Expect(0, 68416, '\p{  AVESTAN}', "");
Expect(1, 68416, '\p{^  AVESTAN}', "");
Expect(1, 68416, '\P{  AVESTAN}', "");
Expect(0, 68416, '\P{^  AVESTAN}', "");
Error('\p{_ IS_Avestan/a/}');
Error('\P{_ IS_Avestan/a/}');
Expect(1, 68415, '\p{isavestan}', "");
Expect(0, 68415, '\p{^isavestan}', "");
Expect(0, 68415, '\P{isavestan}', "");
Expect(1, 68415, '\P{^isavestan}', "");
Expect(0, 68416, '\p{isavestan}', "");
Expect(1, 68416, '\p{^isavestan}', "");
Expect(1, 68416, '\P{isavestan}', "");
Expect(0, 68416, '\P{^isavestan}', "");
Expect(1, 68415, '\p{-is_Avestan}', "");
Expect(0, 68415, '\p{^-is_Avestan}', "");
Expect(0, 68415, '\P{-is_Avestan}', "");
Expect(1, 68415, '\P{^-is_Avestan}', "");
Expect(0, 68416, '\p{-is_Avestan}', "");
Expect(1, 68416, '\p{^-is_Avestan}', "");
Expect(1, 68416, '\P{-is_Avestan}', "");
Expect(0, 68416, '\P{^-is_Avestan}', "");
Error('\p{/a/_AVST}');
Error('\P{/a/_AVST}');
Expect(1, 68415, '\p{avst}', "");
Expect(0, 68415, '\p{^avst}', "");
Expect(0, 68415, '\P{avst}', "");
Expect(1, 68415, '\P{^avst}', "");
Expect(0, 68416, '\p{avst}', "");
Expect(1, 68416, '\p{^avst}', "");
Expect(1, 68416, '\P{avst}', "");
Expect(0, 68416, '\P{^avst}', "");
Expect(1, 68415, '\p{_Avst}', "");
Expect(0, 68415, '\p{^_Avst}', "");
Expect(0, 68415, '\P{_Avst}', "");
Expect(1, 68415, '\P{^_Avst}', "");
Expect(0, 68416, '\p{_Avst}', "");
Expect(1, 68416, '\p{^_Avst}', "");
Expect(1, 68416, '\P{_Avst}', "");
Expect(0, 68416, '\P{^_Avst}', "");
Error('\p{/a/is_Avst}');
Error('\P{/a/is_Avst}');
Expect(1, 68415, '\p{isavst}', "");
Expect(0, 68415, '\p{^isavst}', "");
Expect(0, 68415, '\P{isavst}', "");
Expect(1, 68415, '\P{^isavst}', "");
Expect(0, 68416, '\p{isavst}', "");
Expect(1, 68416, '\p{^isavst}', "");
Expect(1, 68416, '\P{isavst}', "");
Expect(0, 68416, '\P{^isavst}', "");
Expect(1, 68415, '\p{ IS_Avst}', "");
Expect(0, 68415, '\p{^ IS_Avst}', "");
Expect(0, 68415, '\P{ IS_Avst}', "");
Expect(1, 68415, '\P{^ IS_Avst}', "");
Expect(0, 68416, '\p{ IS_Avst}', "");
Expect(1, 68416, '\p{^ IS_Avst}', "");
Expect(1, 68416, '\P{ IS_Avst}', "");
Expect(0, 68416, '\P{^ IS_Avst}', "");
Error('\p{ 	Balinese:=}');
Error('\P{ 	Balinese:=}');
Expect(1, 7036, '\p{balinese}', "");
Expect(0, 7036, '\p{^balinese}', "");
Expect(0, 7036, '\P{balinese}', "");
Expect(1, 7036, '\P{^balinese}', "");
Expect(0, 7037, '\p{balinese}', "");
Expect(1, 7037, '\p{^balinese}', "");
Expect(1, 7037, '\P{balinese}', "");
Expect(0, 7037, '\P{^balinese}', "");
Expect(1, 7036, '\p{  balinese}', "");
Expect(0, 7036, '\p{^  balinese}', "");
Expect(0, 7036, '\P{  balinese}', "");
Expect(1, 7036, '\P{^  balinese}', "");
Expect(0, 7037, '\p{  balinese}', "");
Expect(1, 7037, '\p{^  balinese}', "");
Expect(1, 7037, '\P{  balinese}', "");
Expect(0, 7037, '\P{^  balinese}', "");
Error('\p{_ Is_Balinese:=}');
Error('\P{_ Is_Balinese:=}');
Expect(1, 7036, '\p{isbalinese}', "");
Expect(0, 7036, '\p{^isbalinese}', "");
Expect(0, 7036, '\P{isbalinese}', "");
Expect(1, 7036, '\P{^isbalinese}', "");
Expect(0, 7037, '\p{isbalinese}', "");
Expect(1, 7037, '\p{^isbalinese}', "");
Expect(1, 7037, '\P{isbalinese}', "");
Expect(0, 7037, '\P{^isbalinese}', "");
Expect(1, 7036, '\p{ _IS_Balinese}', "");
Expect(0, 7036, '\p{^ _IS_Balinese}', "");
Expect(0, 7036, '\P{ _IS_Balinese}', "");
Expect(1, 7036, '\P{^ _IS_Balinese}', "");
Expect(0, 7037, '\p{ _IS_Balinese}', "");
Expect(1, 7037, '\p{^ _IS_Balinese}', "");
Expect(1, 7037, '\P{ _IS_Balinese}', "");
Expect(0, 7037, '\P{^ _IS_Balinese}', "");
Error('\p{	bali/a/}');
Error('\P{	bali/a/}');
Expect(1, 7036, '\p{bali}', "");
Expect(0, 7036, '\p{^bali}', "");
Expect(0, 7036, '\P{bali}', "");
Expect(1, 7036, '\P{^bali}', "");
Expect(0, 7037, '\p{bali}', "");
Expect(1, 7037, '\p{^bali}', "");
Expect(1, 7037, '\P{bali}', "");
Expect(0, 7037, '\P{^bali}', "");
Expect(1, 7036, '\p{_Bali}', "");
Expect(0, 7036, '\p{^_Bali}', "");
Expect(0, 7036, '\P{_Bali}', "");
Expect(1, 7036, '\P{^_Bali}', "");
Expect(0, 7037, '\p{_Bali}', "");
Expect(1, 7037, '\p{^_Bali}', "");
Expect(1, 7037, '\P{_Bali}', "");
Expect(0, 7037, '\P{^_Bali}', "");
Error('\p{:=is_Bali}');
Error('\P{:=is_Bali}');
Expect(1, 7036, '\p{isbali}', "");
Expect(0, 7036, '\p{^isbali}', "");
Expect(0, 7036, '\P{isbali}', "");
Expect(1, 7036, '\P{^isbali}', "");
Expect(0, 7037, '\p{isbali}', "");
Expect(1, 7037, '\p{^isbali}', "");
Expect(1, 7037, '\P{isbali}', "");
Expect(0, 7037, '\P{^isbali}', "");
Expect(1, 7036, '\p{_Is_bali}', "");
Expect(0, 7036, '\p{^_Is_bali}', "");
Expect(0, 7036, '\P{_Is_bali}', "");
Expect(1, 7036, '\P{^_Is_bali}', "");
Expect(0, 7037, '\p{_Is_bali}', "");
Expect(1, 7037, '\p{^_Is_bali}', "");
Expect(1, 7037, '\P{_Is_bali}', "");
Expect(0, 7037, '\P{^_Is_bali}', "");
Error('\p{-_Bamum/a/}');
Error('\P{-_Bamum/a/}');
Expect(1, 92728, '\p{bamum}', "");
Expect(0, 92728, '\p{^bamum}', "");
Expect(0, 92728, '\P{bamum}', "");
Expect(1, 92728, '\P{^bamum}', "");
Expect(0, 92729, '\p{bamum}', "");
Expect(1, 92729, '\p{^bamum}', "");
Expect(1, 92729, '\P{bamum}', "");
Expect(0, 92729, '\P{^bamum}', "");
Expect(1, 92728, '\p{ Bamum}', "");
Expect(0, 92728, '\p{^ Bamum}', "");
Expect(0, 92728, '\P{ Bamum}', "");
Expect(1, 92728, '\P{^ Bamum}', "");
Expect(0, 92729, '\p{ Bamum}', "");
Expect(1, 92729, '\p{^ Bamum}', "");
Expect(1, 92729, '\P{ Bamum}', "");
Expect(0, 92729, '\P{^ Bamum}', "");
Error('\p{-Is_bamum:=}');
Error('\P{-Is_bamum:=}');
Expect(1, 92728, '\p{isbamum}', "");
Expect(0, 92728, '\p{^isbamum}', "");
Expect(0, 92728, '\P{isbamum}', "");
Expect(1, 92728, '\P{^isbamum}', "");
Expect(0, 92729, '\p{isbamum}', "");
Expect(1, 92729, '\p{^isbamum}', "");
Expect(1, 92729, '\P{isbamum}', "");
Expect(0, 92729, '\P{^isbamum}', "");
Expect(1, 92728, '\p{-Is_bamum}', "");
Expect(0, 92728, '\p{^-Is_bamum}', "");
Expect(0, 92728, '\P{-Is_bamum}', "");
Expect(1, 92728, '\P{^-Is_bamum}', "");
Expect(0, 92729, '\p{-Is_bamum}', "");
Expect(1, 92729, '\p{^-Is_bamum}', "");
Expect(1, 92729, '\P{-Is_bamum}', "");
Expect(0, 92729, '\P{^-Is_bamum}', "");
Error('\p{ :=BAMU}');
Error('\P{ :=BAMU}');
Expect(1, 92728, '\p{bamu}', "");
Expect(0, 92728, '\p{^bamu}', "");
Expect(0, 92728, '\P{bamu}', "");
Expect(1, 92728, '\P{^bamu}', "");
Expect(0, 92729, '\p{bamu}', "");
Expect(1, 92729, '\p{^bamu}', "");
Expect(1, 92729, '\P{bamu}', "");
Expect(0, 92729, '\P{^bamu}', "");
Expect(1, 92728, '\p{--Bamu}', "");
Expect(0, 92728, '\p{^--Bamu}', "");
Expect(0, 92728, '\P{--Bamu}', "");
Expect(1, 92728, '\P{^--Bamu}', "");
Expect(0, 92729, '\p{--Bamu}', "");
Expect(1, 92729, '\p{^--Bamu}', "");
Expect(1, 92729, '\P{--Bamu}', "");
Expect(0, 92729, '\P{^--Bamu}', "");
Error('\p{:=	IS_Bamu}');
Error('\P{:=	IS_Bamu}');
Expect(1, 92728, '\p{isbamu}', "");
Expect(0, 92728, '\p{^isbamu}', "");
Expect(0, 92728, '\P{isbamu}', "");
Expect(1, 92728, '\P{^isbamu}', "");
Expect(0, 92729, '\p{isbamu}', "");
Expect(1, 92729, '\p{^isbamu}', "");
Expect(1, 92729, '\P{isbamu}', "");
Expect(0, 92729, '\P{^isbamu}', "");
Expect(1, 92728, '\p{_IS_BAMU}', "");
Expect(0, 92728, '\p{^_IS_BAMU}', "");
Expect(0, 92728, '\P{_IS_BAMU}', "");
Expect(1, 92728, '\P{^_IS_BAMU}', "");
Expect(0, 92729, '\p{_IS_BAMU}', "");
Expect(1, 92729, '\p{^_IS_BAMU}', "");
Expect(1, 92729, '\P{_IS_BAMU}', "");
Expect(0, 92729, '\P{^_IS_BAMU}', "");
Error('\p{	 Bamum_SUPPLEMENT:=}');
Error('\P{	 Bamum_SUPPLEMENT:=}');
Expect(1, 92735, '\p{bamumsupplement}', "");
Expect(0, 92735, '\p{^bamumsupplement}', "");
Expect(0, 92735, '\P{bamumsupplement}', "");
Expect(1, 92735, '\P{^bamumsupplement}', "");
Expect(0, 92736, '\p{bamumsupplement}', "");
Expect(1, 92736, '\p{^bamumsupplement}', "");
Expect(1, 92736, '\P{bamumsupplement}', "");
Expect(0, 92736, '\P{^bamumsupplement}', "");
Expect(1, 92735, '\p{ 	Bamum_SUPPLEMENT}', "");
Expect(0, 92735, '\p{^ 	Bamum_SUPPLEMENT}', "");
Expect(0, 92735, '\P{ 	Bamum_SUPPLEMENT}', "");
Expect(1, 92735, '\P{^ 	Bamum_SUPPLEMENT}', "");
Expect(0, 92736, '\p{ 	Bamum_SUPPLEMENT}', "");
Expect(1, 92736, '\p{^ 	Bamum_SUPPLEMENT}', "");
Expect(1, 92736, '\P{ 	Bamum_SUPPLEMENT}', "");
Expect(0, 92736, '\P{^ 	Bamum_SUPPLEMENT}', "");
Error('\p{-Is_Bamum_SUPPLEMENT/a/}');
Error('\P{-Is_Bamum_SUPPLEMENT/a/}');
Expect(1, 92735, '\p{isbamumsupplement}', "");
Expect(0, 92735, '\p{^isbamumsupplement}', "");
Expect(0, 92735, '\P{isbamumsupplement}', "");
Expect(1, 92735, '\P{^isbamumsupplement}', "");
Expect(0, 92736, '\p{isbamumsupplement}', "");
Expect(1, 92736, '\p{^isbamumsupplement}', "");
Expect(1, 92736, '\P{isbamumsupplement}', "");
Expect(0, 92736, '\P{^isbamumsupplement}', "");
Expect(1, 92735, '\p{_-is_Bamum_Supplement}', "");
Expect(0, 92735, '\p{^_-is_Bamum_Supplement}', "");
Expect(0, 92735, '\P{_-is_Bamum_Supplement}', "");
Expect(1, 92735, '\P{^_-is_Bamum_Supplement}', "");
Expect(0, 92736, '\p{_-is_Bamum_Supplement}', "");
Expect(1, 92736, '\p{^_-is_Bamum_Supplement}', "");
Expect(1, 92736, '\P{_-is_Bamum_Supplement}', "");
Expect(0, 92736, '\P{^_-is_Bamum_Supplement}', "");
Error('\p{	:=In_BAMUM_Supplement}');
Error('\P{	:=In_BAMUM_Supplement}');
Expect(1, 92735, '\p{inbamumsupplement}', "");
Expect(0, 92735, '\p{^inbamumsupplement}', "");
Expect(0, 92735, '\P{inbamumsupplement}', "");
Expect(1, 92735, '\P{^inbamumsupplement}', "");
Expect(0, 92736, '\p{inbamumsupplement}', "");
Expect(1, 92736, '\p{^inbamumsupplement}', "");
Expect(1, 92736, '\P{inbamumsupplement}', "");
Expect(0, 92736, '\P{^inbamumsupplement}', "");
Expect(1, 92735, '\p{In_Bamum_Supplement}', "");
Expect(0, 92735, '\p{^In_Bamum_Supplement}', "");
Expect(0, 92735, '\P{In_Bamum_Supplement}', "");
Expect(1, 92735, '\P{^In_Bamum_Supplement}', "");
Expect(0, 92736, '\p{In_Bamum_Supplement}', "");
Expect(1, 92736, '\p{^In_Bamum_Supplement}', "");
Expect(1, 92736, '\P{In_Bamum_Supplement}', "");
Expect(0, 92736, '\P{^In_Bamum_Supplement}', "");
Error('\p{_/a/BAMUM_SUP}');
Error('\P{_/a/BAMUM_SUP}');
Expect(1, 92735, '\p{bamumsup}', "");
Expect(0, 92735, '\p{^bamumsup}', "");
Expect(0, 92735, '\P{bamumsup}', "");
Expect(1, 92735, '\P{^bamumsup}', "");
Expect(0, 92736, '\p{bamumsup}', "");
Expect(1, 92736, '\p{^bamumsup}', "");
Expect(1, 92736, '\P{bamumsup}', "");
Expect(0, 92736, '\P{^bamumsup}', "");
Expect(1, 92735, '\p{-Bamum_sup}', "");
Expect(0, 92735, '\p{^-Bamum_sup}', "");
Expect(0, 92735, '\P{-Bamum_sup}', "");
Expect(1, 92735, '\P{^-Bamum_sup}', "");
Expect(0, 92736, '\p{-Bamum_sup}', "");
Expect(1, 92736, '\p{^-Bamum_sup}', "");
Expect(1, 92736, '\P{-Bamum_sup}', "");
Expect(0, 92736, '\P{^-Bamum_sup}', "");
Error('\p{	/a/IS_bamum_Sup}');
Error('\P{	/a/IS_bamum_Sup}');
Expect(1, 92735, '\p{isbamumsup}', "");
Expect(0, 92735, '\p{^isbamumsup}', "");
Expect(0, 92735, '\P{isbamumsup}', "");
Expect(1, 92735, '\P{^isbamumsup}', "");
Expect(0, 92736, '\p{isbamumsup}', "");
Expect(1, 92736, '\p{^isbamumsup}', "");
Expect(1, 92736, '\P{isbamumsup}', "");
Expect(0, 92736, '\P{^isbamumsup}', "");
Expect(1, 92735, '\p{__Is_Bamum_SUP}', "");
Expect(0, 92735, '\p{^__Is_Bamum_SUP}', "");
Expect(0, 92735, '\P{__Is_Bamum_SUP}', "");
Expect(1, 92735, '\P{^__Is_Bamum_SUP}', "");
Expect(0, 92736, '\p{__Is_Bamum_SUP}', "");
Expect(1, 92736, '\p{^__Is_Bamum_SUP}', "");
Expect(1, 92736, '\P{__Is_Bamum_SUP}', "");
Expect(0, 92736, '\P{^__Is_Bamum_SUP}', "");
Error('\p{-:=IN_Bamum_sup}');
Error('\P{-:=IN_Bamum_sup}');
Expect(1, 92735, '\p{inbamumsup}', "");
Expect(0, 92735, '\p{^inbamumsup}', "");
Expect(0, 92735, '\P{inbamumsup}', "");
Expect(1, 92735, '\P{^inbamumsup}', "");
Expect(0, 92736, '\p{inbamumsup}', "");
Expect(1, 92736, '\p{^inbamumsup}', "");
Expect(1, 92736, '\P{inbamumsup}', "");
Expect(0, 92736, '\P{^inbamumsup}', "");
Expect(1, 92735, '\p{ In_BAMUM_Sup}', "");
Expect(0, 92735, '\p{^ In_BAMUM_Sup}', "");
Expect(0, 92735, '\P{ In_BAMUM_Sup}', "");
Expect(1, 92735, '\P{^ In_BAMUM_Sup}', "");
Expect(0, 92736, '\p{ In_BAMUM_Sup}', "");
Expect(1, 92736, '\p{^ In_BAMUM_Sup}', "");
Expect(1, 92736, '\P{ In_BAMUM_Sup}', "");
Expect(0, 92736, '\P{^ In_BAMUM_Sup}', "");
Error('\p{/a/	 batak}');
Error('\P{/a/	 batak}');
Expect(1, 7167, '\p{batak}', "");
Expect(0, 7167, '\p{^batak}', "");
Expect(0, 7167, '\P{batak}', "");
Expect(1, 7167, '\P{^batak}', "");
Expect(0, 7168, '\p{batak}', "");
Expect(1, 7168, '\p{^batak}', "");
Expect(1, 7168, '\P{batak}', "");
Expect(0, 7168, '\P{^batak}', "");
Expect(1, 7167, '\p{--Batak}', "");
Expect(0, 7167, '\p{^--Batak}', "");
Expect(0, 7167, '\P{--Batak}', "");
Expect(1, 7167, '\P{^--Batak}', "");
Expect(0, 7168, '\p{--Batak}', "");
Expect(1, 7168, '\p{^--Batak}', "");
Expect(1, 7168, '\P{--Batak}', "");
Expect(0, 7168, '\P{^--Batak}', "");
Error('\p{-Is_Batak/a/}');
Error('\P{-Is_Batak/a/}');
Expect(1, 7167, '\p{isbatak}', "");
Expect(0, 7167, '\p{^isbatak}', "");
Expect(0, 7167, '\P{isbatak}', "");
Expect(1, 7167, '\P{^isbatak}', "");
Expect(0, 7168, '\p{isbatak}', "");
Expect(1, 7168, '\p{^isbatak}', "");
Expect(1, 7168, '\P{isbatak}', "");
Expect(0, 7168, '\P{^isbatak}', "");
Expect(1, 7167, '\p{ is_batak}', "");
Expect(0, 7167, '\p{^ is_batak}', "");
Expect(0, 7167, '\P{ is_batak}', "");
Expect(1, 7167, '\P{^ is_batak}', "");
Expect(0, 7168, '\p{ is_batak}', "");
Expect(1, 7168, '\p{^ is_batak}', "");
Expect(1, 7168, '\P{ is_batak}', "");
Expect(0, 7168, '\P{^ is_batak}', "");
Error('\p{ /a/batk}');
Error('\P{ /a/batk}');
Expect(1, 7167, '\p{batk}', "");
Expect(0, 7167, '\p{^batk}', "");
Expect(0, 7167, '\P{batk}', "");
Expect(1, 7167, '\P{^batk}', "");
Expect(0, 7168, '\p{batk}', "");
Expect(1, 7168, '\p{^batk}', "");
Expect(1, 7168, '\P{batk}', "");
Expect(0, 7168, '\P{^batk}', "");
Expect(1, 7167, '\p{ _Batk}', "");
Expect(0, 7167, '\p{^ _Batk}', "");
Expect(0, 7167, '\P{ _Batk}', "");
Expect(1, 7167, '\P{^ _Batk}', "");
Expect(0, 7168, '\p{ _Batk}', "");
Expect(1, 7168, '\p{^ _Batk}', "");
Expect(1, 7168, '\P{ _Batk}', "");
Expect(0, 7168, '\P{^ _Batk}', "");
Error('\p{ _Is_BATK:=}');
Error('\P{ _Is_BATK:=}');
Expect(1, 7167, '\p{isbatk}', "");
Expect(0, 7167, '\p{^isbatk}', "");
Expect(0, 7167, '\P{isbatk}', "");
Expect(1, 7167, '\P{^isbatk}', "");
Expect(0, 7168, '\p{isbatk}', "");
Expect(1, 7168, '\p{^isbatk}', "");
Expect(1, 7168, '\P{isbatk}', "");
Expect(0, 7168, '\P{^isbatk}', "");
Expect(1, 7167, '\p{ _Is_Batk}', "");
Expect(0, 7167, '\p{^ _Is_Batk}', "");
Expect(0, 7167, '\P{ _Is_Batk}', "");
Expect(1, 7167, '\P{^ _Is_Batk}', "");
Expect(0, 7168, '\p{ _Is_Batk}', "");
Expect(1, 7168, '\p{^ _Is_Batk}', "");
Expect(1, 7168, '\P{ _Is_Batk}', "");
Expect(0, 7168, '\P{^ _Is_Batk}', "");
Error('\p{/a/	bengali}');
Error('\P{/a/	bengali}');
Expect(1, 2555, '\p{bengali}', "");
Expect(0, 2555, '\p{^bengali}', "");
Expect(0, 2555, '\P{bengali}', "");
Expect(1, 2555, '\P{^bengali}', "");
Expect(0, 2556, '\p{bengali}', "");
Expect(1, 2556, '\p{^bengali}', "");
Expect(1, 2556, '\P{bengali}', "");
Expect(0, 2556, '\P{^bengali}', "");
Expect(1, 2555, '\p{ Bengali}', "");
Expect(0, 2555, '\p{^ Bengali}', "");
Expect(0, 2555, '\P{ Bengali}', "");
Expect(1, 2555, '\P{^ Bengali}', "");
Expect(0, 2556, '\p{ Bengali}', "");
Expect(1, 2556, '\p{^ Bengali}', "");
Expect(1, 2556, '\P{ Bengali}', "");
Expect(0, 2556, '\P{^ Bengali}', "");
Error('\p{_-Is_Bengali:=}');
Error('\P{_-Is_Bengali:=}');
Expect(1, 2555, '\p{isbengali}', "");
Expect(0, 2555, '\p{^isbengali}', "");
Expect(0, 2555, '\P{isbengali}', "");
Expect(1, 2555, '\P{^isbengali}', "");
Expect(0, 2556, '\p{isbengali}', "");
Expect(1, 2556, '\p{^isbengali}', "");
Expect(1, 2556, '\P{isbengali}', "");
Expect(0, 2556, '\P{^isbengali}', "");
Expect(1, 2555, '\p{ -Is_Bengali}', "");
Expect(0, 2555, '\p{^ -Is_Bengali}', "");
Expect(0, 2555, '\P{ -Is_Bengali}', "");
Expect(1, 2555, '\P{^ -Is_Bengali}', "");
Expect(0, 2556, '\p{ -Is_Bengali}', "");
Expect(1, 2556, '\p{^ -Is_Bengali}', "");
Expect(1, 2556, '\P{ -Is_Bengali}', "");
Expect(0, 2556, '\P{^ -Is_Bengali}', "");
Error('\p{ :=beng}');
Error('\P{ :=beng}');
Expect(1, 2555, '\p{beng}', "");
Expect(0, 2555, '\p{^beng}', "");
Expect(0, 2555, '\P{beng}', "");
Expect(1, 2555, '\P{^beng}', "");
Expect(0, 2556, '\p{beng}', "");
Expect(1, 2556, '\p{^beng}', "");
Expect(1, 2556, '\P{beng}', "");
Expect(0, 2556, '\P{^beng}', "");
Error('\p{/a/ _IS_Beng}');
Error('\P{/a/ _IS_Beng}');
Expect(1, 2555, '\p{isbeng}', "");
Expect(0, 2555, '\p{^isbeng}', "");
Expect(0, 2555, '\P{isbeng}', "");
Expect(1, 2555, '\P{^isbeng}', "");
Expect(0, 2556, '\p{isbeng}', "");
Expect(1, 2556, '\p{^isbeng}', "");
Expect(1, 2556, '\P{isbeng}', "");
Expect(0, 2556, '\P{^isbeng}', "");
Expect(1, 2555, '\p{is_BENG}', "");
Expect(0, 2555, '\p{^is_BENG}', "");
Expect(0, 2555, '\P{is_BENG}', "");
Expect(1, 2555, '\P{^is_BENG}', "");
Expect(0, 2556, '\p{is_BENG}', "");
Expect(1, 2556, '\p{^is_BENG}', "");
Expect(1, 2556, '\P{is_BENG}', "");
Expect(0, 2556, '\P{^is_BENG}', "");
Error('\p{__BIDI_control:=}');
Error('\P{__BIDI_control:=}');
Expect(1, 8238, '\p{bidicontrol}', "");
Expect(0, 8238, '\p{^bidicontrol}', "");
Expect(0, 8238, '\P{bidicontrol}', "");
Expect(1, 8238, '\P{^bidicontrol}', "");
Expect(0, 8239, '\p{bidicontrol}', "");
Expect(1, 8239, '\p{^bidicontrol}', "");
Expect(1, 8239, '\P{bidicontrol}', "");
Expect(0, 8239, '\P{^bidicontrol}', "");
Expect(1, 8238, '\p{	 bidi_control}', "");
Expect(0, 8238, '\p{^	 bidi_control}', "");
Expect(0, 8238, '\P{	 bidi_control}', "");
Expect(1, 8238, '\P{^	 bidi_control}', "");
Expect(0, 8239, '\p{	 bidi_control}', "");
Expect(1, 8239, '\p{^	 bidi_control}', "");
Expect(1, 8239, '\P{	 bidi_control}', "");
Expect(0, 8239, '\P{^	 bidi_control}', "");
Error('\p{_ IS_Bidi_control:=}');
Error('\P{_ IS_Bidi_control:=}');
Expect(1, 8238, '\p{isbidicontrol}', "");
Expect(0, 8238, '\p{^isbidicontrol}', "");
Expect(0, 8238, '\P{isbidicontrol}', "");
Expect(1, 8238, '\P{^isbidicontrol}', "");
Expect(0, 8239, '\p{isbidicontrol}', "");
Expect(1, 8239, '\p{^isbidicontrol}', "");
Expect(1, 8239, '\P{isbidicontrol}', "");
Expect(0, 8239, '\P{^isbidicontrol}', "");
Expect(1, 8238, '\p{is_BIDI_control}', "");
Expect(0, 8238, '\p{^is_BIDI_control}', "");
Expect(0, 8238, '\P{is_BIDI_control}', "");
Expect(1, 8238, '\P{^is_BIDI_control}', "");
Expect(0, 8239, '\p{is_BIDI_control}', "");
Expect(1, 8239, '\p{^is_BIDI_control}', "");
Expect(1, 8239, '\P{is_BIDI_control}', "");
Expect(0, 8239, '\P{^is_BIDI_control}', "");
Error('\p{ Bidi_c/a/}');
Error('\P{ Bidi_c/a/}');
Expect(1, 8238, '\p{bidic}', "");
Expect(0, 8238, '\p{^bidic}', "");
Expect(0, 8238, '\P{bidic}', "");
Expect(1, 8238, '\P{^bidic}', "");
Expect(0, 8239, '\p{bidic}', "");
Expect(1, 8239, '\p{^bidic}', "");
Expect(1, 8239, '\P{bidic}', "");
Expect(0, 8239, '\P{^bidic}', "");
Expect(1, 8238, '\p{- BIDI_c}', "");
Expect(0, 8238, '\p{^- BIDI_c}', "");
Expect(0, 8238, '\P{- BIDI_c}', "");
Expect(1, 8238, '\P{^- BIDI_c}', "");
Expect(0, 8239, '\p{- BIDI_c}', "");
Expect(1, 8239, '\p{^- BIDI_c}', "");
Expect(1, 8239, '\P{- BIDI_c}', "");
Expect(0, 8239, '\P{^- BIDI_c}', "");
Error('\p{-/a/Is_bidi_C}');
Error('\P{-/a/Is_bidi_C}');
Expect(1, 8238, '\p{isbidic}', "");
Expect(0, 8238, '\p{^isbidic}', "");
Expect(0, 8238, '\P{isbidic}', "");
Expect(1, 8238, '\P{^isbidic}', "");
Expect(0, 8239, '\p{isbidic}', "");
Expect(1, 8239, '\p{^isbidic}', "");
Expect(1, 8239, '\P{isbidic}', "");
Expect(0, 8239, '\P{^isbidic}', "");
Expect(1, 8238, '\p{		IS_Bidi_C}', "");
Expect(0, 8238, '\p{^		IS_Bidi_C}', "");
Expect(0, 8238, '\P{		IS_Bidi_C}', "");
Expect(1, 8238, '\P{^		IS_Bidi_C}', "");
Expect(0, 8239, '\p{		IS_Bidi_C}', "");
Expect(1, 8239, '\p{^		IS_Bidi_C}', "");
Expect(1, 8239, '\P{		IS_Bidi_C}', "");
Expect(0, 8239, '\P{^		IS_Bidi_C}', "");
Error('\p{/a/--Bidi_mirrored}');
Error('\P{/a/--Bidi_mirrored}');
Expect(1, 120771, '\p{bidimirrored}', "");
Expect(0, 120771, '\p{^bidimirrored}', "");
Expect(0, 120771, '\P{bidimirrored}', "");
Expect(1, 120771, '\P{^bidimirrored}', "");
Expect(0, 120772, '\p{bidimirrored}', "");
Expect(1, 120772, '\p{^bidimirrored}', "");
Expect(1, 120772, '\P{bidimirrored}', "");
Expect(0, 120772, '\P{^bidimirrored}', "");
Expect(1, 120771, '\p{_BIDI_mirrored}', "");
Expect(0, 120771, '\p{^_BIDI_mirrored}', "");
Expect(0, 120771, '\P{_BIDI_mirrored}', "");
Expect(1, 120771, '\P{^_BIDI_mirrored}', "");
Expect(0, 120772, '\p{_BIDI_mirrored}', "");
Expect(1, 120772, '\p{^_BIDI_mirrored}', "");
Expect(1, 120772, '\P{_BIDI_mirrored}', "");
Expect(0, 120772, '\P{^_BIDI_mirrored}', "");
Error('\p{_/a/Is_BIDI_MIRRORED}');
Error('\P{_/a/Is_BIDI_MIRRORED}');
Expect(1, 120771, '\p{isbidimirrored}', "");
Expect(0, 120771, '\p{^isbidimirrored}', "");
Expect(0, 120771, '\P{isbidimirrored}', "");
Expect(1, 120771, '\P{^isbidimirrored}', "");
Expect(0, 120772, '\p{isbidimirrored}', "");
Expect(1, 120772, '\p{^isbidimirrored}', "");
Expect(1, 120772, '\P{isbidimirrored}', "");
Expect(0, 120772, '\P{^isbidimirrored}', "");
Expect(1, 120771, '\p{--IS_BIDI_Mirrored}', "");
Expect(0, 120771, '\p{^--IS_BIDI_Mirrored}', "");
Expect(0, 120771, '\P{--IS_BIDI_Mirrored}', "");
Expect(1, 120771, '\P{^--IS_BIDI_Mirrored}', "");
Expect(0, 120772, '\p{--IS_BIDI_Mirrored}', "");
Expect(1, 120772, '\p{^--IS_BIDI_Mirrored}', "");
Expect(1, 120772, '\P{--IS_BIDI_Mirrored}', "");
Expect(0, 120772, '\P{^--IS_BIDI_Mirrored}', "");
Error('\p{_:=BIDI_M}');
Error('\P{_:=BIDI_M}');
Expect(1, 120771, '\p{bidim}', "");
Expect(0, 120771, '\p{^bidim}', "");
Expect(0, 120771, '\P{bidim}', "");
Expect(1, 120771, '\P{^bidim}', "");
Expect(0, 120772, '\p{bidim}', "");
Expect(1, 120772, '\p{^bidim}', "");
Expect(1, 120772, '\P{bidim}', "");
Expect(0, 120772, '\P{^bidim}', "");
Expect(1, 120771, '\p{__Bidi_m}', "");
Expect(0, 120771, '\p{^__Bidi_m}', "");
Expect(0, 120771, '\P{__Bidi_m}', "");
Expect(1, 120771, '\P{^__Bidi_m}', "");
Expect(0, 120772, '\p{__Bidi_m}', "");
Expect(1, 120772, '\p{^__Bidi_m}', "");
Expect(1, 120772, '\P{__Bidi_m}', "");
Expect(0, 120772, '\P{^__Bidi_m}', "");
Error('\p{:=Is_Bidi_M}');
Error('\P{:=Is_Bidi_M}');
Expect(1, 120771, '\p{isbidim}', "");
Expect(0, 120771, '\p{^isbidim}', "");
Expect(0, 120771, '\P{isbidim}', "");
Expect(1, 120771, '\P{^isbidim}', "");
Expect(0, 120772, '\p{isbidim}', "");
Expect(1, 120772, '\p{^isbidim}', "");
Expect(1, 120772, '\P{isbidim}', "");
Expect(0, 120772, '\P{^isbidim}', "");
Expect(1, 120771, '\p{ Is_bidi_M}', "");
Expect(0, 120771, '\p{^ Is_bidi_M}', "");
Expect(0, 120771, '\P{ Is_bidi_M}', "");
Expect(1, 120771, '\P{^ Is_bidi_M}', "");
Expect(0, 120772, '\p{ Is_bidi_M}', "");
Expect(1, 120772, '\p{^ Is_bidi_M}', "");
Expect(1, 120772, '\P{ Is_bidi_M}', "");
Expect(0, 120772, '\P{^ Is_bidi_M}', "");
Error('\p{ /a/blank}');
Error('\P{ /a/blank}');
Expect(1, 12288, '\p{blank}', "");
Expect(0, 12288, '\p{^blank}', "");
Expect(0, 12288, '\P{blank}', "");
Expect(1, 12288, '\P{^blank}', "");
Expect(0, 12289, '\p{blank}', "");
Expect(1, 12289, '\p{^blank}', "");
Expect(1, 12289, '\P{blank}', "");
Expect(0, 12289, '\P{^blank}', "");
Expect(1, 12288, '\p{ 	BLANK}', "");
Expect(0, 12288, '\p{^ 	BLANK}', "");
Expect(0, 12288, '\P{ 	BLANK}', "");
Expect(1, 12288, '\P{^ 	BLANK}', "");
Expect(0, 12289, '\p{ 	BLANK}', "");
Expect(1, 12289, '\p{^ 	BLANK}', "");
Expect(1, 12289, '\P{ 	BLANK}', "");
Expect(0, 12289, '\P{^ 	BLANK}', "");
Error('\p{/a/	horizspace}');
Error('\P{/a/	horizspace}');
Expect(1, 12288, '\p{horizspace}', "");
Expect(0, 12288, '\p{^horizspace}', "");
Expect(0, 12288, '\P{horizspace}', "");
Expect(1, 12288, '\P{^horizspace}', "");
Expect(0, 12289, '\p{horizspace}', "");
Expect(1, 12289, '\p{^horizspace}', "");
Expect(1, 12289, '\P{horizspace}', "");
Expect(0, 12289, '\P{^horizspace}', "");
Expect(1, 12288, '\p{HORIZSPACE}', "");
Expect(0, 12288, '\p{^HORIZSPACE}', "");
Expect(0, 12288, '\P{HORIZSPACE}', "");
Expect(1, 12288, '\P{^HORIZSPACE}', "");
Expect(0, 12289, '\p{HORIZSPACE}', "");
Expect(1, 12289, '\p{^HORIZSPACE}', "");
Expect(1, 12289, '\P{HORIZSPACE}', "");
Expect(0, 12289, '\P{^HORIZSPACE}', "");
Error('\p{  XPOSIXBLANK:=}');
Error('\P{  XPOSIXBLANK:=}');
Expect(1, 12288, '\p{xposixblank}', "");
Expect(0, 12288, '\p{^xposixblank}', "");
Expect(0, 12288, '\P{xposixblank}', "");
Expect(1, 12288, '\P{^xposixblank}', "");
Expect(0, 12289, '\p{xposixblank}', "");
Expect(1, 12289, '\p{^xposixblank}', "");
Expect(1, 12289, '\P{xposixblank}', "");
Expect(0, 12289, '\P{^xposixblank}', "");
Expect(1, 12288, '\p{_-XPosixBlank}', "");
Expect(0, 12288, '\p{^_-XPosixBlank}', "");
Expect(0, 12288, '\P{_-XPosixBlank}', "");
Expect(1, 12288, '\P{^_-XPosixBlank}', "");
Expect(0, 12289, '\p{_-XPosixBlank}', "");
Expect(1, 12289, '\p{^_-XPosixBlank}', "");
Expect(1, 12289, '\P{_-XPosixBlank}', "");
Expect(0, 12289, '\P{^_-XPosixBlank}', "");
Error('\p{_/a/Is_Blank}');
Error('\P{_/a/Is_Blank}');
Expect(1, 12288, '\p{isblank}', "");
Expect(0, 12288, '\p{^isblank}', "");
Expect(0, 12288, '\P{isblank}', "");
Expect(1, 12288, '\P{^isblank}', "");
Expect(0, 12289, '\p{isblank}', "");
Expect(1, 12289, '\p{^isblank}', "");
Expect(1, 12289, '\P{isblank}', "");
Expect(0, 12289, '\P{^isblank}', "");
Expect(1, 12288, '\p{		IS_Blank}', "");
Expect(0, 12288, '\p{^		IS_Blank}', "");
Expect(0, 12288, '\P{		IS_Blank}', "");
Expect(1, 12288, '\P{^		IS_Blank}', "");
Expect(0, 12289, '\p{		IS_Blank}', "");
Expect(1, 12289, '\p{^		IS_Blank}', "");
Expect(1, 12289, '\P{		IS_Blank}', "");
Expect(0, 12289, '\P{^		IS_Blank}', "");
Error('\p{	/a/IS_HorizSpace}');
Error('\P{	/a/IS_HorizSpace}');
Expect(1, 12288, '\p{ishorizspace}', "");
Expect(0, 12288, '\p{^ishorizspace}', "");
Expect(0, 12288, '\P{ishorizspace}', "");
Expect(1, 12288, '\P{^ishorizspace}', "");
Expect(0, 12289, '\p{ishorizspace}', "");
Expect(1, 12289, '\p{^ishorizspace}', "");
Expect(1, 12289, '\P{ishorizspace}', "");
Expect(0, 12289, '\P{^ishorizspace}', "");
Expect(1, 12288, '\p{-_Is_HorizSpace}', "");
Expect(0, 12288, '\p{^-_Is_HorizSpace}', "");
Expect(0, 12288, '\P{-_Is_HorizSpace}', "");
Expect(1, 12288, '\P{^-_Is_HorizSpace}', "");
Expect(0, 12289, '\p{-_Is_HorizSpace}', "");
Expect(1, 12289, '\p{^-_Is_HorizSpace}', "");
Expect(1, 12289, '\P{-_Is_HorizSpace}', "");
Expect(0, 12289, '\P{^-_Is_HorizSpace}', "");
Error('\p{/a/ Is_XPosixBlank}');
Error('\P{/a/ Is_XPosixBlank}');
Expect(1, 12288, '\p{isxposixblank}', "");
Expect(0, 12288, '\p{^isxposixblank}', "");
Expect(0, 12288, '\P{isxposixblank}', "");
Expect(1, 12288, '\P{^isxposixblank}', "");
Expect(0, 12289, '\p{isxposixblank}', "");
Expect(1, 12289, '\p{^isxposixblank}', "");
Expect(1, 12289, '\P{isxposixblank}', "");
Expect(0, 12289, '\P{^isxposixblank}', "");
Expect(1, 12288, '\p{		Is_xposixblank}', "");
Expect(0, 12288, '\p{^		Is_xposixblank}', "");
Expect(0, 12288, '\P{		Is_xposixblank}', "");
Expect(1, 12288, '\P{^		Is_xposixblank}', "");
Expect(0, 12289, '\p{		Is_xposixblank}', "");
Expect(1, 12289, '\p{^		Is_xposixblank}', "");
Expect(1, 12289, '\P{		Is_xposixblank}', "");
Expect(0, 12289, '\P{^		Is_xposixblank}', "");
Error('\p{/a/-_BLOCK_ELEMENTS}');
Error('\P{/a/-_BLOCK_ELEMENTS}');
Expect(1, 9631, '\p{blockelements}', "");
Expect(0, 9631, '\p{^blockelements}', "");
Expect(0, 9631, '\P{blockelements}', "");
Expect(1, 9631, '\P{^blockelements}', "");
Expect(0, 9632, '\p{blockelements}', "");
Expect(1, 9632, '\p{^blockelements}', "");
Expect(1, 9632, '\P{blockelements}', "");
Expect(0, 9632, '\P{^blockelements}', "");
Expect(1, 9631, '\p{	 BLOCK_Elements}', "");
Expect(0, 9631, '\p{^	 BLOCK_Elements}', "");
Expect(0, 9631, '\P{	 BLOCK_Elements}', "");
Expect(1, 9631, '\P{^	 BLOCK_Elements}', "");
Expect(0, 9632, '\p{	 BLOCK_Elements}', "");
Expect(1, 9632, '\p{^	 BLOCK_Elements}', "");
Expect(1, 9632, '\P{	 BLOCK_Elements}', "");
Expect(0, 9632, '\P{^	 BLOCK_Elements}', "");
Error('\p{/a/-Is_block_Elements}');
Error('\P{/a/-Is_block_Elements}');
Expect(1, 9631, '\p{isblockelements}', "");
Expect(0, 9631, '\p{^isblockelements}', "");
Expect(0, 9631, '\P{isblockelements}', "");
Expect(1, 9631, '\P{^isblockelements}', "");
Expect(0, 9632, '\p{isblockelements}', "");
Expect(1, 9632, '\p{^isblockelements}', "");
Expect(1, 9632, '\P{isblockelements}', "");
Expect(0, 9632, '\P{^isblockelements}', "");
Expect(1, 9631, '\p{	-IS_Block_Elements}', "");
Expect(0, 9631, '\p{^	-IS_Block_Elements}', "");
Expect(0, 9631, '\P{	-IS_Block_Elements}', "");
Expect(1, 9631, '\P{^	-IS_Block_Elements}', "");
Expect(0, 9632, '\p{	-IS_Block_Elements}', "");
Expect(1, 9632, '\p{^	-IS_Block_Elements}', "");
Expect(1, 9632, '\P{	-IS_Block_Elements}', "");
Expect(0, 9632, '\P{^	-IS_Block_Elements}', "");
Error('\p{-In_BLOCK_ELEMENTS:=}');
Error('\P{-In_BLOCK_ELEMENTS:=}');
Expect(1, 9631, '\p{inblockelements}', "");
Expect(0, 9631, '\p{^inblockelements}', "");
Expect(0, 9631, '\P{inblockelements}', "");
Expect(1, 9631, '\P{^inblockelements}', "");
Expect(0, 9632, '\p{inblockelements}', "");
Expect(1, 9632, '\p{^inblockelements}', "");
Expect(1, 9632, '\P{inblockelements}', "");
Expect(0, 9632, '\P{^inblockelements}', "");
Expect(1, 9631, '\p{__in_BLOCK_ELEMENTS}', "");
Expect(0, 9631, '\p{^__in_BLOCK_ELEMENTS}', "");
Expect(0, 9631, '\P{__in_BLOCK_ELEMENTS}', "");
Expect(1, 9631, '\P{^__in_BLOCK_ELEMENTS}', "");
Expect(0, 9632, '\p{__in_BLOCK_ELEMENTS}', "");
Expect(1, 9632, '\p{^__in_BLOCK_ELEMENTS}', "");
Expect(1, 9632, '\P{__in_BLOCK_ELEMENTS}', "");
Expect(0, 9632, '\P{^__in_BLOCK_ELEMENTS}', "");
Error('\p{:= BOPOMOFO}');
Error('\P{:= BOPOMOFO}');
Expect(1, 12730, '\p{bopomofo}', "");
Expect(0, 12730, '\p{^bopomofo}', "");
Expect(0, 12730, '\P{bopomofo}', "");
Expect(1, 12730, '\P{^bopomofo}', "");
Expect(0, 12731, '\p{bopomofo}', "");
Expect(1, 12731, '\p{^bopomofo}', "");
Expect(1, 12731, '\P{bopomofo}', "");
Expect(0, 12731, '\P{^bopomofo}', "");
Expect(1, 12730, '\p{__BOPOMOFO}', "");
Expect(0, 12730, '\p{^__BOPOMOFO}', "");
Expect(0, 12730, '\P{__BOPOMOFO}', "");
Expect(1, 12730, '\P{^__BOPOMOFO}', "");
Expect(0, 12731, '\p{__BOPOMOFO}', "");
Expect(1, 12731, '\p{^__BOPOMOFO}', "");
Expect(1, 12731, '\P{__BOPOMOFO}', "");
Expect(0, 12731, '\P{^__BOPOMOFO}', "");
Error('\p{:=  IS_BOPOMOFO}');
Error('\P{:=  IS_BOPOMOFO}');
Expect(1, 12730, '\p{isbopomofo}', "");
Expect(0, 12730, '\p{^isbopomofo}', "");
Expect(0, 12730, '\P{isbopomofo}', "");
Expect(1, 12730, '\P{^isbopomofo}', "");
Expect(0, 12731, '\p{isbopomofo}', "");
Expect(1, 12731, '\p{^isbopomofo}', "");
Expect(1, 12731, '\P{isbopomofo}', "");
Expect(0, 12731, '\P{^isbopomofo}', "");
Expect(1, 12730, '\p{		IS_Bopomofo}', "");
Expect(0, 12730, '\p{^		IS_Bopomofo}', "");
Expect(0, 12730, '\P{		IS_Bopomofo}', "");
Expect(1, 12730, '\P{^		IS_Bopomofo}', "");
Expect(0, 12731, '\p{		IS_Bopomofo}', "");
Expect(1, 12731, '\p{^		IS_Bopomofo}', "");
Expect(1, 12731, '\P{		IS_Bopomofo}', "");
Expect(0, 12731, '\P{^		IS_Bopomofo}', "");
Error('\p{:=-BOPO}');
Error('\P{:=-BOPO}');
Expect(1, 12730, '\p{bopo}', "");
Expect(0, 12730, '\p{^bopo}', "");
Expect(0, 12730, '\P{bopo}', "");
Expect(1, 12730, '\P{^bopo}', "");
Expect(0, 12731, '\p{bopo}', "");
Expect(1, 12731, '\p{^bopo}', "");
Expect(1, 12731, '\P{bopo}', "");
Expect(0, 12731, '\P{^bopo}', "");
Expect(1, 12730, '\p{	Bopo}', "");
Expect(0, 12730, '\p{^	Bopo}', "");
Expect(0, 12730, '\P{	Bopo}', "");
Expect(1, 12730, '\P{^	Bopo}', "");
Expect(0, 12731, '\p{	Bopo}', "");
Expect(1, 12731, '\p{^	Bopo}', "");
Expect(1, 12731, '\P{	Bopo}', "");
Expect(0, 12731, '\P{^	Bopo}', "");
Error('\p{:=_is_Bopo}');
Error('\P{:=_is_Bopo}');
Expect(1, 12730, '\p{isbopo}', "");
Expect(0, 12730, '\p{^isbopo}', "");
Expect(0, 12730, '\P{isbopo}', "");
Expect(1, 12730, '\P{^isbopo}', "");
Expect(0, 12731, '\p{isbopo}', "");
Expect(1, 12731, '\p{^isbopo}', "");
Expect(1, 12731, '\P{isbopo}', "");
Expect(0, 12731, '\P{^isbopo}', "");
Expect(1, 12730, '\p{	is_BOPO}', "");
Expect(0, 12730, '\p{^	is_BOPO}', "");
Expect(0, 12730, '\P{	is_BOPO}', "");
Expect(1, 12730, '\P{^	is_BOPO}', "");
Expect(0, 12731, '\p{	is_BOPO}', "");
Expect(1, 12731, '\p{^	is_BOPO}', "");
Expect(1, 12731, '\P{	is_BOPO}', "");
Expect(0, 12731, '\P{^	is_BOPO}', "");
Error('\p{_BOPOMOFO_extended/a/}');
Error('\P{_BOPOMOFO_extended/a/}');
Expect(1, 12735, '\p{bopomofoextended}', "");
Expect(0, 12735, '\p{^bopomofoextended}', "");
Expect(0, 12735, '\P{bopomofoextended}', "");
Expect(1, 12735, '\P{^bopomofoextended}', "");
Expect(0, 12736, '\p{bopomofoextended}', "");
Expect(1, 12736, '\p{^bopomofoextended}', "");
Expect(1, 12736, '\P{bopomofoextended}', "");
Expect(0, 12736, '\P{^bopomofoextended}', "");
Expect(1, 12735, '\p{_BOPOMOFO_Extended}', "");
Expect(0, 12735, '\p{^_BOPOMOFO_Extended}', "");
Expect(0, 12735, '\P{_BOPOMOFO_Extended}', "");
Expect(1, 12735, '\P{^_BOPOMOFO_Extended}', "");
Expect(0, 12736, '\p{_BOPOMOFO_Extended}', "");
Expect(1, 12736, '\p{^_BOPOMOFO_Extended}', "");
Expect(1, 12736, '\P{_BOPOMOFO_Extended}', "");
Expect(0, 12736, '\P{^_BOPOMOFO_Extended}', "");
Error('\p{_ Is_Bopomofo_Extended:=}');
Error('\P{_ Is_Bopomofo_Extended:=}');
Expect(1, 12735, '\p{isbopomofoextended}', "");
Expect(0, 12735, '\p{^isbopomofoextended}', "");
Expect(0, 12735, '\P{isbopomofoextended}', "");
Expect(1, 12735, '\P{^isbopomofoextended}', "");
Expect(0, 12736, '\p{isbopomofoextended}', "");
Expect(1, 12736, '\p{^isbopomofoextended}', "");
Expect(1, 12736, '\P{isbopomofoextended}', "");
Expect(0, 12736, '\P{^isbopomofoextended}', "");
Expect(1, 12735, '\p{__Is_bopomofo_EXTENDED}', "");
Expect(0, 12735, '\p{^__Is_bopomofo_EXTENDED}', "");
Expect(0, 12735, '\P{__Is_bopomofo_EXTENDED}', "");
Expect(1, 12735, '\P{^__Is_bopomofo_EXTENDED}', "");
Expect(0, 12736, '\p{__Is_bopomofo_EXTENDED}', "");
Expect(1, 12736, '\p{^__Is_bopomofo_EXTENDED}', "");
Expect(1, 12736, '\P{__Is_bopomofo_EXTENDED}', "");
Expect(0, 12736, '\P{^__Is_bopomofo_EXTENDED}', "");
Error('\p{_/a/in_Bopomofo_EXTENDED}');
Error('\P{_/a/in_Bopomofo_EXTENDED}');
Expect(1, 12735, '\p{inbopomofoextended}', "");
Expect(0, 12735, '\p{^inbopomofoextended}', "");
Expect(0, 12735, '\P{inbopomofoextended}', "");
Expect(1, 12735, '\P{^inbopomofoextended}', "");
Expect(0, 12736, '\p{inbopomofoextended}', "");
Expect(1, 12736, '\p{^inbopomofoextended}', "");
Expect(1, 12736, '\P{inbopomofoextended}', "");
Expect(0, 12736, '\P{^inbopomofoextended}', "");
Expect(1, 12735, '\p{ 	IN_Bopomofo_Extended}', "");
Expect(0, 12735, '\p{^ 	IN_Bopomofo_Extended}', "");
Expect(0, 12735, '\P{ 	IN_Bopomofo_Extended}', "");
Expect(1, 12735, '\P{^ 	IN_Bopomofo_Extended}', "");
Expect(0, 12736, '\p{ 	IN_Bopomofo_Extended}', "");
Expect(1, 12736, '\p{^ 	IN_Bopomofo_Extended}', "");
Expect(1, 12736, '\P{ 	IN_Bopomofo_Extended}', "");
Expect(0, 12736, '\P{^ 	IN_Bopomofo_Extended}', "");
Error('\p{	:=BOPOMOFO_ext}');
Error('\P{	:=BOPOMOFO_ext}');
Expect(1, 12735, '\p{bopomofoext}', "");
Expect(0, 12735, '\p{^bopomofoext}', "");
Expect(0, 12735, '\P{bopomofoext}', "");
Expect(1, 12735, '\P{^bopomofoext}', "");
Expect(0, 12736, '\p{bopomofoext}', "");
Expect(1, 12736, '\p{^bopomofoext}', "");
Expect(1, 12736, '\P{bopomofoext}', "");
Expect(0, 12736, '\P{^bopomofoext}', "");
Expect(1, 12735, '\p{_-bopomofo_Ext}', "");
Expect(0, 12735, '\p{^_-bopomofo_Ext}', "");
Expect(0, 12735, '\P{_-bopomofo_Ext}', "");
Expect(1, 12735, '\P{^_-bopomofo_Ext}', "");
Expect(0, 12736, '\p{_-bopomofo_Ext}', "");
Expect(1, 12736, '\p{^_-bopomofo_Ext}', "");
Expect(1, 12736, '\P{_-bopomofo_Ext}', "");
Expect(0, 12736, '\P{^_-bopomofo_Ext}', "");
Error('\p{/a/Is_BOPOMOFO_Ext}');
Error('\P{/a/Is_BOPOMOFO_Ext}');
Expect(1, 12735, '\p{isbopomofoext}', "");
Expect(0, 12735, '\p{^isbopomofoext}', "");
Expect(0, 12735, '\P{isbopomofoext}', "");
Expect(1, 12735, '\P{^isbopomofoext}', "");
Expect(0, 12736, '\p{isbopomofoext}', "");
Expect(1, 12736, '\p{^isbopomofoext}', "");
Expect(1, 12736, '\P{isbopomofoext}', "");
Expect(0, 12736, '\P{^isbopomofoext}', "");
Expect(1, 12735, '\p{ 	Is_Bopomofo_Ext}', "");
Expect(0, 12735, '\p{^ 	Is_Bopomofo_Ext}', "");
Expect(0, 12735, '\P{ 	Is_Bopomofo_Ext}', "");
Expect(1, 12735, '\P{^ 	Is_Bopomofo_Ext}', "");
Expect(0, 12736, '\p{ 	Is_Bopomofo_Ext}', "");
Expect(1, 12736, '\p{^ 	Is_Bopomofo_Ext}', "");
Expect(1, 12736, '\P{ 	Is_Bopomofo_Ext}', "");
Expect(0, 12736, '\P{^ 	Is_Bopomofo_Ext}', "");
Error('\p{	/a/IN_bopomofo_EXT}');
Error('\P{	/a/IN_bopomofo_EXT}');
Expect(1, 12735, '\p{inbopomofoext}', "");
Expect(0, 12735, '\p{^inbopomofoext}', "");
Expect(0, 12735, '\P{inbopomofoext}', "");
Expect(1, 12735, '\P{^inbopomofoext}', "");
Expect(0, 12736, '\p{inbopomofoext}', "");
Expect(1, 12736, '\p{^inbopomofoext}', "");
Expect(1, 12736, '\P{inbopomofoext}', "");
Expect(0, 12736, '\P{^inbopomofoext}', "");
Expect(1, 12735, '\p{__In_Bopomofo_Ext}', "");
Expect(0, 12735, '\p{^__In_Bopomofo_Ext}', "");
Expect(0, 12735, '\P{__In_Bopomofo_Ext}', "");
Expect(1, 12735, '\P{^__In_Bopomofo_Ext}', "");
Expect(0, 12736, '\p{__In_Bopomofo_Ext}', "");
Expect(1, 12736, '\p{^__In_Bopomofo_Ext}', "");
Expect(1, 12736, '\P{__In_Bopomofo_Ext}', "");
Expect(0, 12736, '\P{^__In_Bopomofo_Ext}', "");
Error('\p{-_box_DRAWING/a/}');
Error('\P{-_box_DRAWING/a/}');
Expect(1, 9599, '\p{boxdrawing}', "");
Expect(0, 9599, '\p{^boxdrawing}', "");
Expect(0, 9599, '\P{boxdrawing}', "");
Expect(1, 9599, '\P{^boxdrawing}', "");
Expect(0, 9600, '\p{boxdrawing}', "");
Expect(1, 9600, '\p{^boxdrawing}', "");
Expect(1, 9600, '\P{boxdrawing}', "");
Expect(0, 9600, '\P{^boxdrawing}', "");
Expect(1, 9599, '\p{	Box_Drawing}', "");
Expect(0, 9599, '\p{^	Box_Drawing}', "");
Expect(0, 9599, '\P{	Box_Drawing}', "");
Expect(1, 9599, '\P{^	Box_Drawing}', "");
Expect(0, 9600, '\p{	Box_Drawing}', "");
Expect(1, 9600, '\p{^	Box_Drawing}', "");
Expect(1, 9600, '\P{	Box_Drawing}', "");
Expect(0, 9600, '\P{^	Box_Drawing}', "");
Error('\p{_/a/is_Box_drawing}');
Error('\P{_/a/is_Box_drawing}');
Expect(1, 9599, '\p{isboxdrawing}', "");
Expect(0, 9599, '\p{^isboxdrawing}', "");
Expect(0, 9599, '\P{isboxdrawing}', "");
Expect(1, 9599, '\P{^isboxdrawing}', "");
Expect(0, 9600, '\p{isboxdrawing}', "");
Expect(1, 9600, '\p{^isboxdrawing}', "");
Expect(1, 9600, '\P{isboxdrawing}', "");
Expect(0, 9600, '\P{^isboxdrawing}', "");
Expect(1, 9599, '\p{_ Is_Box_Drawing}', "");
Expect(0, 9599, '\p{^_ Is_Box_Drawing}', "");
Expect(0, 9599, '\P{_ Is_Box_Drawing}', "");
Expect(1, 9599, '\P{^_ Is_Box_Drawing}', "");
Expect(0, 9600, '\p{_ Is_Box_Drawing}', "");
Expect(1, 9600, '\p{^_ Is_Box_Drawing}', "");
Expect(1, 9600, '\P{_ Is_Box_Drawing}', "");
Expect(0, 9600, '\P{^_ Is_Box_Drawing}', "");
Error('\p{/a/	In_box_Drawing}');
Error('\P{/a/	In_box_Drawing}');
Expect(1, 9599, '\p{inboxdrawing}', "");
Expect(0, 9599, '\p{^inboxdrawing}', "");
Expect(0, 9599, '\P{inboxdrawing}', "");
Expect(1, 9599, '\P{^inboxdrawing}', "");
Expect(0, 9600, '\p{inboxdrawing}', "");
Expect(1, 9600, '\p{^inboxdrawing}', "");
Expect(1, 9600, '\P{inboxdrawing}', "");
Expect(0, 9600, '\P{^inboxdrawing}', "");
Expect(1, 9599, '\p{	IN_Box_drawing}', "");
Expect(0, 9599, '\p{^	IN_Box_drawing}', "");
Expect(0, 9599, '\P{	IN_Box_drawing}', "");
Expect(1, 9599, '\P{^	IN_Box_drawing}', "");
Expect(0, 9600, '\p{	IN_Box_drawing}', "");
Expect(1, 9600, '\p{^	IN_Box_drawing}', "");
Expect(1, 9600, '\P{	IN_Box_drawing}', "");
Expect(0, 9600, '\P{^	IN_Box_drawing}', "");
Error('\p{/a/- brahmi}');
Error('\P{/a/- brahmi}');
Expect(1, 69743, '\p{brahmi}', "");
Expect(0, 69743, '\p{^brahmi}', "");
Expect(0, 69743, '\P{brahmi}', "");
Expect(1, 69743, '\P{^brahmi}', "");
Expect(0, 69744, '\p{brahmi}', "");
Expect(1, 69744, '\p{^brahmi}', "");
Expect(1, 69744, '\P{brahmi}', "");
Expect(0, 69744, '\P{^brahmi}', "");
Expect(1, 69743, '\p{	Brahmi}', "");
Expect(0, 69743, '\p{^	Brahmi}', "");
Expect(0, 69743, '\P{	Brahmi}', "");
Expect(1, 69743, '\P{^	Brahmi}', "");
Expect(0, 69744, '\p{	Brahmi}', "");
Expect(1, 69744, '\p{^	Brahmi}', "");
Expect(1, 69744, '\P{	Brahmi}', "");
Expect(0, 69744, '\P{^	Brahmi}', "");
Error('\p{:=Is_Brahmi}');
Error('\P{:=Is_Brahmi}');
Expect(1, 69743, '\p{isbrahmi}', "");
Expect(0, 69743, '\p{^isbrahmi}', "");
Expect(0, 69743, '\P{isbrahmi}', "");
Expect(1, 69743, '\P{^isbrahmi}', "");
Expect(0, 69744, '\p{isbrahmi}', "");
Expect(1, 69744, '\p{^isbrahmi}', "");
Expect(1, 69744, '\P{isbrahmi}', "");
Expect(0, 69744, '\P{^isbrahmi}', "");
Expect(1, 69743, '\p{		IS_brahmi}', "");
Expect(0, 69743, '\p{^		IS_brahmi}', "");
Expect(0, 69743, '\P{		IS_brahmi}', "");
Expect(1, 69743, '\P{^		IS_brahmi}', "");
Expect(0, 69744, '\p{		IS_brahmi}', "");
Expect(1, 69744, '\p{^		IS_brahmi}', "");
Expect(1, 69744, '\P{		IS_brahmi}', "");
Expect(0, 69744, '\P{^		IS_brahmi}', "");
Error('\p{:=--Brah}');
Error('\P{:=--Brah}');
Expect(1, 69743, '\p{brah}', "");
Expect(0, 69743, '\p{^brah}', "");
Expect(0, 69743, '\P{brah}', "");
Expect(1, 69743, '\P{^brah}', "");
Expect(0, 69744, '\p{brah}', "");
Expect(1, 69744, '\p{^brah}', "");
Expect(1, 69744, '\P{brah}', "");
Expect(0, 69744, '\P{^brah}', "");
Expect(1, 69743, '\p{	-Brah}', "");
Expect(0, 69743, '\p{^	-Brah}', "");
Expect(0, 69743, '\P{	-Brah}', "");
Expect(1, 69743, '\P{^	-Brah}', "");
Expect(0, 69744, '\p{	-Brah}', "");
Expect(1, 69744, '\p{^	-Brah}', "");
Expect(1, 69744, '\P{	-Brah}', "");
Expect(0, 69744, '\P{^	-Brah}', "");
Error('\p{/a/-IS_BRAH}');
Error('\P{/a/-IS_BRAH}');
Expect(1, 69743, '\p{isbrah}', "");
Expect(0, 69743, '\p{^isbrah}', "");
Expect(0, 69743, '\P{isbrah}', "");
Expect(1, 69743, '\P{^isbrah}', "");
Expect(0, 69744, '\p{isbrah}', "");
Expect(1, 69744, '\p{^isbrah}', "");
Expect(1, 69744, '\P{isbrah}', "");
Expect(0, 69744, '\P{^isbrah}', "");
Expect(1, 69743, '\p{  Is_Brah}', "");
Expect(0, 69743, '\p{^  Is_Brah}', "");
Expect(0, 69743, '\P{  Is_Brah}', "");
Expect(1, 69743, '\P{^  Is_Brah}', "");
Expect(0, 69744, '\p{  Is_Brah}', "");
Expect(1, 69744, '\p{^  Is_Brah}', "");
Expect(1, 69744, '\P{  Is_Brah}', "");
Expect(0, 69744, '\P{^  Is_Brah}', "");
Error('\p{__BRAILLE/a/}');
Error('\P{__BRAILLE/a/}');
Expect(1, 10495, '\p{braille}', "");
Expect(0, 10495, '\p{^braille}', "");
Expect(0, 10495, '\P{braille}', "");
Expect(1, 10495, '\P{^braille}', "");
Expect(0, 10496, '\p{braille}', "");
Expect(1, 10496, '\p{^braille}', "");
Expect(1, 10496, '\P{braille}', "");
Expect(0, 10496, '\P{^braille}', "");
Expect(1, 10495, '\p{-Braille}', "");
Expect(0, 10495, '\p{^-Braille}', "");
Expect(0, 10495, '\P{-Braille}', "");
Expect(1, 10495, '\P{^-Braille}', "");
Expect(0, 10496, '\p{-Braille}', "");
Expect(1, 10496, '\p{^-Braille}', "");
Expect(1, 10496, '\P{-Braille}', "");
Expect(0, 10496, '\P{^-Braille}', "");
Error('\p{/a/Is_BRAILLE}');
Error('\P{/a/Is_BRAILLE}');
Expect(1, 10495, '\p{isbraille}', "");
Expect(0, 10495, '\p{^isbraille}', "");
Expect(0, 10495, '\P{isbraille}', "");
Expect(1, 10495, '\P{^isbraille}', "");
Expect(0, 10496, '\p{isbraille}', "");
Expect(1, 10496, '\p{^isbraille}', "");
Expect(1, 10496, '\P{isbraille}', "");
Expect(0, 10496, '\P{^isbraille}', "");
Expect(1, 10495, '\p{-	IS_Braille}', "");
Expect(0, 10495, '\p{^-	IS_Braille}', "");
Expect(0, 10495, '\P{-	IS_Braille}', "");
Expect(1, 10495, '\P{^-	IS_Braille}', "");
Expect(0, 10496, '\p{-	IS_Braille}', "");
Expect(1, 10496, '\p{^-	IS_Braille}', "");
Expect(1, 10496, '\P{-	IS_Braille}', "");
Expect(0, 10496, '\P{^-	IS_Braille}', "");
Error('\p{:=Brai}');
Error('\P{:=Brai}');
Expect(1, 10495, '\p{brai}', "");
Expect(0, 10495, '\p{^brai}', "");
Expect(0, 10495, '\P{brai}', "");
Expect(1, 10495, '\P{^brai}', "");
Expect(0, 10496, '\p{brai}', "");
Expect(1, 10496, '\p{^brai}', "");
Expect(1, 10496, '\P{brai}', "");
Expect(0, 10496, '\P{^brai}', "");
Expect(1, 10495, '\p{ 	brai}', "");
Expect(0, 10495, '\p{^ 	brai}', "");
Expect(0, 10495, '\P{ 	brai}', "");
Expect(1, 10495, '\P{^ 	brai}', "");
Expect(0, 10496, '\p{ 	brai}', "");
Expect(1, 10496, '\p{^ 	brai}', "");
Expect(1, 10496, '\P{ 	brai}', "");
Expect(0, 10496, '\P{^ 	brai}', "");
Error('\p{ Is_BRAI:=}');
Error('\P{ Is_BRAI:=}');
Expect(1, 10495, '\p{isbrai}', "");
Expect(0, 10495, '\p{^isbrai}', "");
Expect(0, 10495, '\P{isbrai}', "");
Expect(1, 10495, '\P{^isbrai}', "");
Expect(0, 10496, '\p{isbrai}', "");
Expect(1, 10496, '\p{^isbrai}', "");
Expect(1, 10496, '\P{isbrai}', "");
Expect(0, 10496, '\P{^isbrai}', "");
Expect(1, 10495, '\p{-Is_Brai}', "");
Expect(0, 10495, '\p{^-Is_Brai}', "");
Expect(0, 10495, '\P{-Is_Brai}', "");
Expect(1, 10495, '\P{^-Is_Brai}', "");
Expect(0, 10496, '\p{-Is_Brai}', "");
Expect(1, 10496, '\p{^-Is_Brai}', "");
Expect(1, 10496, '\P{-Is_Brai}', "");
Expect(0, 10496, '\P{^-Is_Brai}', "");
Error('\p{	Braille_Patterns/a/}');
Error('\P{	Braille_Patterns/a/}');
Expect(1, 10495, '\p{braillepatterns}', "");
Expect(0, 10495, '\p{^braillepatterns}', "");
Expect(0, 10495, '\P{braillepatterns}', "");
Expect(1, 10495, '\P{^braillepatterns}', "");
Expect(0, 10496, '\p{braillepatterns}', "");
Expect(1, 10496, '\p{^braillepatterns}', "");
Expect(1, 10496, '\P{braillepatterns}', "");
Expect(0, 10496, '\P{^braillepatterns}', "");
Expect(1, 10495, '\p{_Braille_PATTERNS}', "");
Expect(0, 10495, '\p{^_Braille_PATTERNS}', "");
Expect(0, 10495, '\P{_Braille_PATTERNS}', "");
Expect(1, 10495, '\P{^_Braille_PATTERNS}', "");
Expect(0, 10496, '\p{_Braille_PATTERNS}', "");
Expect(1, 10496, '\p{^_Braille_PATTERNS}', "");
Expect(1, 10496, '\P{_Braille_PATTERNS}', "");
Expect(0, 10496, '\P{^_Braille_PATTERNS}', "");
Error('\p{_:=is_braille_PATTERNS}');
Error('\P{_:=is_braille_PATTERNS}');
Expect(1, 10495, '\p{isbraillepatterns}', "");
Expect(0, 10495, '\p{^isbraillepatterns}', "");
Expect(0, 10495, '\P{isbraillepatterns}', "");
Expect(1, 10495, '\P{^isbraillepatterns}', "");
Expect(0, 10496, '\p{isbraillepatterns}', "");
Expect(1, 10496, '\p{^isbraillepatterns}', "");
Expect(1, 10496, '\P{isbraillepatterns}', "");
Expect(0, 10496, '\P{^isbraillepatterns}', "");
Expect(1, 10495, '\p{-	is_Braille_patterns}', "");
Expect(0, 10495, '\p{^-	is_Braille_patterns}', "");
Expect(0, 10495, '\P{-	is_Braille_patterns}', "");
Expect(1, 10495, '\P{^-	is_Braille_patterns}', "");
Expect(0, 10496, '\p{-	is_Braille_patterns}', "");
Expect(1, 10496, '\p{^-	is_Braille_patterns}', "");
Expect(1, 10496, '\P{-	is_Braille_patterns}', "");
Expect(0, 10496, '\P{^-	is_Braille_patterns}', "");
Error('\p{:=__In_braille_patterns}');
Error('\P{:=__In_braille_patterns}');
Expect(1, 10495, '\p{inbraillepatterns}', "");
Expect(0, 10495, '\p{^inbraillepatterns}', "");
Expect(0, 10495, '\P{inbraillepatterns}', "");
Expect(1, 10495, '\P{^inbraillepatterns}', "");
Expect(0, 10496, '\p{inbraillepatterns}', "");
Expect(1, 10496, '\p{^inbraillepatterns}', "");
Expect(1, 10496, '\P{inbraillepatterns}', "");
Expect(0, 10496, '\P{^inbraillepatterns}', "");
Expect(1, 10495, '\p{_in_Braille_patterns}', "");
Expect(0, 10495, '\p{^_in_Braille_patterns}', "");
Expect(0, 10495, '\P{_in_Braille_patterns}', "");
Expect(1, 10495, '\P{^_in_Braille_patterns}', "");
Expect(0, 10496, '\p{_in_Braille_patterns}', "");
Expect(1, 10496, '\p{^_in_Braille_patterns}', "");
Expect(1, 10496, '\P{_in_Braille_patterns}', "");
Expect(0, 10496, '\P{^_in_Braille_patterns}', "");
Error('\p{/a/-	IN_Braille}');
Error('\P{/a/-	IN_Braille}');
Expect(1, 10495, '\p{inbraille}', "");
Expect(0, 10495, '\p{^inbraille}', "");
Expect(0, 10495, '\P{inbraille}', "");
Expect(1, 10495, '\P{^inbraille}', "");
Expect(0, 10496, '\p{inbraille}', "");
Expect(1, 10496, '\p{^inbraille}', "");
Expect(1, 10496, '\P{inbraille}', "");
Expect(0, 10496, '\P{^inbraille}', "");
Expect(1, 10495, '\p{	In_Braille}', "");
Expect(0, 10495, '\p{^	In_Braille}', "");
Expect(0, 10495, '\P{	In_Braille}', "");
Expect(1, 10495, '\P{^	In_Braille}', "");
Expect(0, 10496, '\p{	In_Braille}', "");
Expect(1, 10496, '\p{^	In_Braille}', "");
Expect(1, 10496, '\P{	In_Braille}', "");
Expect(0, 10496, '\P{^	In_Braille}', "");
Error('\p{ :=BUGINESE}');
Error('\P{ :=BUGINESE}');
Expect(1, 6687, '\p{buginese}', "");
Expect(0, 6687, '\p{^buginese}', "");
Expect(0, 6687, '\P{buginese}', "");
Expect(1, 6687, '\P{^buginese}', "");
Expect(0, 6688, '\p{buginese}', "");
Expect(1, 6688, '\p{^buginese}', "");
Expect(1, 6688, '\P{buginese}', "");
Expect(0, 6688, '\P{^buginese}', "");
Expect(1, 6687, '\p{-Buginese}', "");
Expect(0, 6687, '\p{^-Buginese}', "");
Expect(0, 6687, '\P{-Buginese}', "");
Expect(1, 6687, '\P{^-Buginese}', "");
Expect(0, 6688, '\p{-Buginese}', "");
Expect(1, 6688, '\p{^-Buginese}', "");
Expect(1, 6688, '\P{-Buginese}', "");
Expect(0, 6688, '\P{^-Buginese}', "");
Error('\p{:=__IS_Buginese}');
Error('\P{:=__IS_Buginese}');
Expect(1, 6687, '\p{isbuginese}', "");
Expect(0, 6687, '\p{^isbuginese}', "");
Expect(0, 6687, '\P{isbuginese}', "");
Expect(1, 6687, '\P{^isbuginese}', "");
Expect(0, 6688, '\p{isbuginese}', "");
Expect(1, 6688, '\p{^isbuginese}', "");
Expect(1, 6688, '\P{isbuginese}', "");
Expect(0, 6688, '\P{^isbuginese}', "");
Expect(1, 6687, '\p{	IS_Buginese}', "");
Expect(0, 6687, '\p{^	IS_Buginese}', "");
Expect(0, 6687, '\P{	IS_Buginese}', "");
Expect(1, 6687, '\P{^	IS_Buginese}', "");
Expect(0, 6688, '\p{	IS_Buginese}', "");
Expect(1, 6688, '\p{^	IS_Buginese}', "");
Expect(1, 6688, '\P{	IS_Buginese}', "");
Expect(0, 6688, '\P{^	IS_Buginese}', "");
Error('\p{	/a/bugi}');
Error('\P{	/a/bugi}');
Expect(1, 6687, '\p{bugi}', "");
Expect(0, 6687, '\p{^bugi}', "");
Expect(0, 6687, '\P{bugi}', "");
Expect(1, 6687, '\P{^bugi}', "");
Expect(0, 6688, '\p{bugi}', "");
Expect(1, 6688, '\p{^bugi}', "");
Expect(1, 6688, '\P{bugi}', "");
Expect(0, 6688, '\P{^bugi}', "");
Expect(1, 6687, '\p{-	bugi}', "");
Expect(0, 6687, '\p{^-	bugi}', "");
Expect(0, 6687, '\P{-	bugi}', "");
Expect(1, 6687, '\P{^-	bugi}', "");
Expect(0, 6688, '\p{-	bugi}', "");
Expect(1, 6688, '\p{^-	bugi}', "");
Expect(1, 6688, '\P{-	bugi}', "");
Expect(0, 6688, '\P{^-	bugi}', "");
Error('\p{	Is_bugi:=}');
Error('\P{	Is_bugi:=}');
Expect(1, 6687, '\p{isbugi}', "");
Expect(0, 6687, '\p{^isbugi}', "");
Expect(0, 6687, '\P{isbugi}', "");
Expect(1, 6687, '\P{^isbugi}', "");
Expect(0, 6688, '\p{isbugi}', "");
Expect(1, 6688, '\p{^isbugi}', "");
Expect(1, 6688, '\P{isbugi}', "");
Expect(0, 6688, '\P{^isbugi}', "");
Expect(1, 6687, '\p{-_IS_BUGI}', "");
Expect(0, 6687, '\p{^-_IS_BUGI}', "");
Expect(0, 6687, '\P{-_IS_BUGI}', "");
Expect(1, 6687, '\P{^-_IS_BUGI}', "");
Expect(0, 6688, '\p{-_IS_BUGI}', "");
Expect(1, 6688, '\p{^-_IS_BUGI}', "");
Expect(1, 6688, '\P{-_IS_BUGI}', "");
Expect(0, 6688, '\P{^-_IS_BUGI}', "");
Error('\p{:=_ buhid}');
Error('\P{:=_ buhid}');
Expect(1, 5971, '\p{buhid}', "");
Expect(0, 5971, '\p{^buhid}', "");
Expect(0, 5971, '\P{buhid}', "");
Expect(1, 5971, '\P{^buhid}', "");
Expect(0, 5972, '\p{buhid}', "");
Expect(1, 5972, '\p{^buhid}', "");
Expect(1, 5972, '\P{buhid}', "");
Expect(0, 5972, '\P{^buhid}', "");
Expect(1, 5971, '\p{  buhid}', "");
Expect(0, 5971, '\p{^  buhid}', "");
Expect(0, 5971, '\P{  buhid}', "");
Expect(1, 5971, '\P{^  buhid}', "");
Expect(0, 5972, '\p{  buhid}', "");
Expect(1, 5972, '\p{^  buhid}', "");
Expect(1, 5972, '\P{  buhid}', "");
Expect(0, 5972, '\P{^  buhid}', "");
Error('\p{:=-is_Buhid}');
Error('\P{:=-is_Buhid}');
Expect(1, 5971, '\p{isbuhid}', "");
Expect(0, 5971, '\p{^isbuhid}', "");
Expect(0, 5971, '\P{isbuhid}', "");
Expect(1, 5971, '\P{^isbuhid}', "");
Expect(0, 5972, '\p{isbuhid}', "");
Expect(1, 5972, '\p{^isbuhid}', "");
Expect(1, 5972, '\P{isbuhid}', "");
Expect(0, 5972, '\P{^isbuhid}', "");
Expect(1, 5971, '\p{_-Is_Buhid}', "");
Expect(0, 5971, '\p{^_-Is_Buhid}', "");
Expect(0, 5971, '\P{_-Is_Buhid}', "");
Expect(1, 5971, '\P{^_-Is_Buhid}', "");
Expect(0, 5972, '\p{_-Is_Buhid}', "");
Expect(1, 5972, '\p{^_-Is_Buhid}', "");
Expect(1, 5972, '\P{_-Is_Buhid}', "");
Expect(0, 5972, '\P{^_-Is_Buhid}', "");
Error('\p{--BUHD:=}');
Error('\P{--BUHD:=}');
Expect(1, 5971, '\p{buhd}', "");
Expect(0, 5971, '\p{^buhd}', "");
Expect(0, 5971, '\P{buhd}', "");
Expect(1, 5971, '\P{^buhd}', "");
Expect(0, 5972, '\p{buhd}', "");
Expect(1, 5972, '\p{^buhd}', "");
Expect(1, 5972, '\P{buhd}', "");
Expect(0, 5972, '\P{^buhd}', "");
Expect(1, 5971, '\p{ _buhd}', "");
Expect(0, 5971, '\p{^ _buhd}', "");
Expect(0, 5971, '\P{ _buhd}', "");
Expect(1, 5971, '\P{^ _buhd}', "");
Expect(0, 5972, '\p{ _buhd}', "");
Expect(1, 5972, '\p{^ _buhd}', "");
Expect(1, 5972, '\P{ _buhd}', "");
Expect(0, 5972, '\P{^ _buhd}', "");
Error('\p{/a/-IS_buhd}');
Error('\P{/a/-IS_buhd}');
Expect(1, 5971, '\p{isbuhd}', "");
Expect(0, 5971, '\p{^isbuhd}', "");
Expect(0, 5971, '\P{isbuhd}', "");
Expect(1, 5971, '\P{^isbuhd}', "");
Expect(0, 5972, '\p{isbuhd}', "");
Expect(1, 5972, '\p{^isbuhd}', "");
Expect(1, 5972, '\P{isbuhd}', "");
Expect(0, 5972, '\P{^isbuhd}', "");
Expect(1, 5971, '\p{-Is_BUHD}', "");
Expect(0, 5971, '\p{^-Is_BUHD}', "");
Expect(0, 5971, '\P{-Is_BUHD}', "");
Expect(1, 5971, '\P{^-Is_BUHD}', "");
Expect(0, 5972, '\p{-Is_BUHD}', "");
Expect(1, 5972, '\p{^-Is_BUHD}', "");
Expect(1, 5972, '\P{-Is_BUHD}', "");
Expect(0, 5972, '\P{^-Is_BUHD}', "");
Error('\p{_:=BYZANTINE_Musical_Symbols}');
Error('\P{_:=BYZANTINE_Musical_Symbols}');
Expect(1, 119039, '\p{byzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^byzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{byzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^byzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{byzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^byzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{byzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^byzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{-_Byzantine_Musical_SYMBOLS}', "");
Expect(0, 119039, '\p{^-_Byzantine_Musical_SYMBOLS}', "");
Expect(0, 119039, '\P{-_Byzantine_Musical_SYMBOLS}', "");
Expect(1, 119039, '\P{^-_Byzantine_Musical_SYMBOLS}', "");
Expect(0, 119040, '\p{-_Byzantine_Musical_SYMBOLS}', "");
Expect(1, 119040, '\p{^-_Byzantine_Musical_SYMBOLS}', "");
Expect(1, 119040, '\P{-_Byzantine_Musical_SYMBOLS}', "");
Expect(0, 119040, '\P{^-_Byzantine_Musical_SYMBOLS}', "");
Error('\p{_-is_Byzantine_musical_symbols/a/}');
Error('\P{_-is_Byzantine_musical_symbols/a/}');
Expect(1, 119039, '\p{isbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^isbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{isbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^isbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{isbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^isbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{isbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^isbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{		is_Byzantine_Musical_symbols}', "");
Expect(0, 119039, '\p{^		is_Byzantine_Musical_symbols}', "");
Expect(0, 119039, '\P{		is_Byzantine_Musical_symbols}', "");
Expect(1, 119039, '\P{^		is_Byzantine_Musical_symbols}', "");
Expect(0, 119040, '\p{		is_Byzantine_Musical_symbols}', "");
Expect(1, 119040, '\p{^		is_Byzantine_Musical_symbols}', "");
Expect(1, 119040, '\P{		is_Byzantine_Musical_symbols}', "");
Expect(0, 119040, '\P{^		is_Byzantine_Musical_symbols}', "");
Error('\p{-In_BYZANTINE_Musical_symbols/a/}');
Error('\P{-In_BYZANTINE_Musical_symbols/a/}');
Expect(1, 119039, '\p{inbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\p{^inbyzantinemusicalsymbols}', "");
Expect(0, 119039, '\P{inbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\P{^inbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\p{inbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\p{^inbyzantinemusicalsymbols}', "");
Expect(1, 119040, '\P{inbyzantinemusicalsymbols}', "");
Expect(0, 119040, '\P{^inbyzantinemusicalsymbols}', "");
Expect(1, 119039, '\p{		In_byzantine_MUSICAL_symbols}', "");
Expect(0, 119039, '\p{^		In_byzantine_MUSICAL_symbols}', "");
Expect(0, 119039, '\P{		In_byzantine_MUSICAL_symbols}', "");
Expect(1, 119039, '\P{^		In_byzantine_MUSICAL_symbols}', "");
Expect(0, 119040, '\p{		In_byzantine_MUSICAL_symbols}', "");
Expect(1, 119040, '\p{^		In_byzantine_MUSICAL_symbols}', "");
Expect(1, 119040, '\P{		In_byzantine_MUSICAL_symbols}', "");
Expect(0, 119040, '\P{^		In_byzantine_MUSICAL_symbols}', "");
Error('\p{:=_-BYZANTINE_MUSIC}');
Error('\P{:=_-BYZANTINE_MUSIC}');
Expect(1, 119039, '\p{byzantinemusic}', "");
Expect(0, 119039, '\p{^byzantinemusic}', "");
Expect(0, 119039, '\P{byzantinemusic}', "");
Expect(1, 119039, '\P{^byzantinemusic}', "");
Expect(0, 119040, '\p{byzantinemusic}', "");
Expect(1, 119040, '\p{^byzantinemusic}', "");
Expect(1, 119040, '\P{byzantinemusic}', "");
Expect(0, 119040, '\P{^byzantinemusic}', "");
Expect(1, 119039, '\p{ -BYZANTINE_music}', "");
Expect(0, 119039, '\p{^ -BYZANTINE_music}', "");
Expect(0, 119039, '\P{ -BYZANTINE_music}', "");
Expect(1, 119039, '\P{^ -BYZANTINE_music}', "");
Expect(0, 119040, '\p{ -BYZANTINE_music}', "");
Expect(1, 119040, '\p{^ -BYZANTINE_music}', "");
Expect(1, 119040, '\P{ -BYZANTINE_music}', "");
Expect(0, 119040, '\P{^ -BYZANTINE_music}', "");
Error('\p{_Is_Byzantine_Music:=}');
Error('\P{_Is_Byzantine_Music:=}');
Expect(1, 119039, '\p{isbyzantinemusic}', "");
Expect(0, 119039, '\p{^isbyzantinemusic}', "");
Expect(0, 119039, '\P{isbyzantinemusic}', "");
Expect(1, 119039, '\P{^isbyzantinemusic}', "");
Expect(0, 119040, '\p{isbyzantinemusic}', "");
Expect(1, 119040, '\p{^isbyzantinemusic}', "");
Expect(1, 119040, '\P{isbyzantinemusic}', "");
Expect(0, 119040, '\P{^isbyzantinemusic}', "");
Expect(1, 119039, '\p{_-IS_Byzantine_Music}', "");
Expect(0, 119039, '\p{^_-IS_Byzantine_Music}', "");
Expect(0, 119039, '\P{_-IS_Byzantine_Music}', "");
Expect(1, 119039, '\P{^_-IS_Byzantine_Music}', "");
Expect(0, 119040, '\p{_-IS_Byzantine_Music}', "");
Expect(1, 119040, '\p{^_-IS_Byzantine_Music}', "");
Expect(1, 119040, '\P{_-IS_Byzantine_Music}', "");
Expect(0, 119040, '\P{^_-IS_Byzantine_Music}', "");
Error('\p{ :=In_Byzantine_Music}');
Error('\P{ :=In_Byzantine_Music}');
Expect(1, 119039, '\p{inbyzantinemusic}', "");
Expect(0, 119039, '\p{^inbyzantinemusic}', "");
Expect(0, 119039, '\P{inbyzantinemusic}', "");
Expect(1, 119039, '\P{^inbyzantinemusic}', "");
Expect(0, 119040, '\p{inbyzantinemusic}', "");
Expect(1, 119040, '\p{^inbyzantinemusic}', "");
Expect(1, 119040, '\P{inbyzantinemusic}', "");
Expect(0, 119040, '\P{^inbyzantinemusic}', "");
Expect(1, 119039, '\p{ IN_byzantine_Music}', "");
Expect(0, 119039, '\p{^ IN_byzantine_Music}', "");
Expect(0, 119039, '\P{ IN_byzantine_Music}', "");
Expect(1, 119039, '\P{^ IN_byzantine_Music}', "");
Expect(0, 119040, '\p{ IN_byzantine_Music}', "");
Expect(1, 119040, '\p{^ IN_byzantine_Music}', "");
Expect(1, 119040, '\P{ IN_byzantine_Music}', "");
Expect(0, 119040, '\P{^ IN_byzantine_Music}', "");
Error('\p{  cjk_Compatibility:=}');
Error('\P{  cjk_Compatibility:=}');
Expect(1, 13311, '\p{cjkcompatibility}', "");
Expect(0, 13311, '\p{^cjkcompatibility}', "");
Expect(0, 13311, '\P{cjkcompatibility}', "");
Expect(1, 13311, '\P{^cjkcompatibility}', "");
Expect(0, 13312, '\p{cjkcompatibility}', "");
Expect(1, 13312, '\p{^cjkcompatibility}', "");
Expect(1, 13312, '\P{cjkcompatibility}', "");
Expect(0, 13312, '\P{^cjkcompatibility}', "");
Expect(1, 13311, '\p{-CJK_compatibility}', "");
Expect(0, 13311, '\p{^-CJK_compatibility}', "");
Expect(0, 13311, '\P{-CJK_compatibility}', "");
Expect(1, 13311, '\P{^-CJK_compatibility}', "");
Expect(0, 13312, '\p{-CJK_compatibility}', "");
Expect(1, 13312, '\p{^-CJK_compatibility}', "");
Expect(1, 13312, '\P{-CJK_compatibility}', "");
Expect(0, 13312, '\P{^-CJK_compatibility}', "");
Error('\p{/a/--IS_CJK_compatibility}');
Error('\P{/a/--IS_CJK_compatibility}');
Expect(1, 13311, '\p{iscjkcompatibility}', "");
Expect(0, 13311, '\p{^iscjkcompatibility}', "");
Expect(0, 13311, '\P{iscjkcompatibility}', "");
Expect(1, 13311, '\P{^iscjkcompatibility}', "");
Expect(0, 13312, '\p{iscjkcompatibility}', "");
Expect(1, 13312, '\p{^iscjkcompatibility}', "");
Expect(1, 13312, '\P{iscjkcompatibility}', "");
Expect(0, 13312, '\P{^iscjkcompatibility}', "");
Expect(1, 13311, '\p{_IS_CJK_compatibility}', "");
Expect(0, 13311, '\p{^_IS_CJK_compatibility}', "");
Expect(0, 13311, '\P{_IS_CJK_compatibility}', "");
Expect(1, 13311, '\P{^_IS_CJK_compatibility}', "");
Expect(0, 13312, '\p{_IS_CJK_compatibility}', "");
Expect(1, 13312, '\p{^_IS_CJK_compatibility}', "");
Expect(1, 13312, '\P{_IS_CJK_compatibility}', "");
Expect(0, 13312, '\P{^_IS_CJK_compatibility}', "");
Error('\p{-In_cjk_Compatibility:=}');
Error('\P{-In_cjk_Compatibility:=}');
Expect(1, 13311, '\p{incjkcompatibility}', "");
Expect(0, 13311, '\p{^incjkcompatibility}', "");
Expect(0, 13311, '\P{incjkcompatibility}', "");
Expect(1, 13311, '\P{^incjkcompatibility}', "");
Expect(0, 13312, '\p{incjkcompatibility}', "");
Expect(1, 13312, '\p{^incjkcompatibility}', "");
Expect(1, 13312, '\P{incjkcompatibility}', "");
Expect(0, 13312, '\P{^incjkcompatibility}', "");
Expect(1, 13311, '\p{_	in_CJK_compatibility}', "");
Expect(0, 13311, '\p{^_	in_CJK_compatibility}', "");
Expect(0, 13311, '\P{_	in_CJK_compatibility}', "");
Expect(1, 13311, '\P{^_	in_CJK_compatibility}', "");
Expect(0, 13312, '\p{_	in_CJK_compatibility}', "");
Expect(1, 13312, '\p{^_	in_CJK_compatibility}', "");
Expect(1, 13312, '\P{_	in_CJK_compatibility}', "");
Expect(0, 13312, '\P{^_	in_CJK_compatibility}', "");
Error('\p{/a/ cjk_Compat}');
Error('\P{/a/ cjk_Compat}');
Expect(1, 13311, '\p{cjkcompat}', "");
Expect(0, 13311, '\p{^cjkcompat}', "");
Expect(0, 13311, '\P{cjkcompat}', "");
Expect(1, 13311, '\P{^cjkcompat}', "");
Expect(0, 13312, '\p{cjkcompat}', "");
Expect(1, 13312, '\p{^cjkcompat}', "");
Expect(1, 13312, '\P{cjkcompat}', "");
Expect(0, 13312, '\P{^cjkcompat}', "");
Expect(1, 13311, '\p{CJK_compat}', "");
Expect(0, 13311, '\p{^CJK_compat}', "");
Expect(0, 13311, '\P{CJK_compat}', "");
Expect(1, 13311, '\P{^CJK_compat}', "");
Expect(0, 13312, '\p{CJK_compat}', "");
Expect(1, 13312, '\p{^CJK_compat}', "");
Expect(1, 13312, '\P{CJK_compat}', "");
Expect(0, 13312, '\P{^CJK_compat}', "");
Error('\p{/a/-Is_CJK_compat}');
Error('\P{/a/-Is_CJK_compat}');
Expect(1, 13311, '\p{iscjkcompat}', "");
Expect(0, 13311, '\p{^iscjkcompat}', "");
Expect(0, 13311, '\P{iscjkcompat}', "");
Expect(1, 13311, '\P{^iscjkcompat}', "");
Expect(0, 13312, '\p{iscjkcompat}', "");
Expect(1, 13312, '\p{^iscjkcompat}', "");
Expect(1, 13312, '\P{iscjkcompat}', "");
Expect(0, 13312, '\P{^iscjkcompat}', "");
Expect(1, 13311, '\p{		Is_CJK_COMPAT}', "");
Expect(0, 13311, '\p{^		Is_CJK_COMPAT}', "");
Expect(0, 13311, '\P{		Is_CJK_COMPAT}', "");
Expect(1, 13311, '\P{^		Is_CJK_COMPAT}', "");
Expect(0, 13312, '\p{		Is_CJK_COMPAT}', "");
Expect(1, 13312, '\p{^		Is_CJK_COMPAT}', "");
Expect(1, 13312, '\P{		Is_CJK_COMPAT}', "");
Expect(0, 13312, '\P{^		Is_CJK_COMPAT}', "");
Error('\p{-/a/IN_CJK_Compat}');
Error('\P{-/a/IN_CJK_Compat}');
Expect(1, 13311, '\p{incjkcompat}', "");
Expect(0, 13311, '\p{^incjkcompat}', "");
Expect(0, 13311, '\P{incjkcompat}', "");
Expect(1, 13311, '\P{^incjkcompat}', "");
Expect(0, 13312, '\p{incjkcompat}', "");
Expect(1, 13312, '\p{^incjkcompat}', "");
Expect(1, 13312, '\P{incjkcompat}', "");
Expect(0, 13312, '\P{^incjkcompat}', "");
Expect(1, 13311, '\p{-in_CJK_Compat}', "");
Expect(0, 13311, '\p{^-in_CJK_Compat}', "");
Expect(0, 13311, '\P{-in_CJK_Compat}', "");
Expect(1, 13311, '\P{^-in_CJK_Compat}', "");
Expect(0, 13312, '\p{-in_CJK_Compat}', "");
Expect(1, 13312, '\p{^-in_CJK_Compat}', "");
Expect(1, 13312, '\P{-in_CJK_Compat}', "");
Expect(0, 13312, '\P{^-in_CJK_Compat}', "");
Error('\p{/a/ -cjk_compatibility_Forms}');
Error('\P{/a/ -cjk_compatibility_Forms}');
Expect(1, 65103, '\p{cjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^cjkcompatibilityforms}', "");
Expect(0, 65103, '\P{cjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^cjkcompatibilityforms}', "");
Expect(0, 65104, '\p{cjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^cjkcompatibilityforms}', "");
Expect(1, 65104, '\P{cjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^cjkcompatibilityforms}', "");
Expect(1, 65103, '\p{_CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\p{^_CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\P{_CJK_Compatibility_FORMS}', "");
Expect(1, 65103, '\P{^_CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\p{_CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\p{^_CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\P{_CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\P{^_CJK_Compatibility_FORMS}', "");
Error('\p{:=_Is_cjk_Compatibility_forms}');
Error('\P{:=_Is_cjk_Compatibility_forms}');
Expect(1, 65103, '\p{iscjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^iscjkcompatibilityforms}', "");
Expect(0, 65103, '\P{iscjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^iscjkcompatibilityforms}', "");
Expect(0, 65104, '\p{iscjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^iscjkcompatibilityforms}', "");
Expect(1, 65104, '\P{iscjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^iscjkcompatibilityforms}', "");
Expect(1, 65103, '\p{- Is_CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\p{^- Is_CJK_Compatibility_FORMS}', "");
Expect(0, 65103, '\P{- Is_CJK_Compatibility_FORMS}', "");
Expect(1, 65103, '\P{^- Is_CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\p{- Is_CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\p{^- Is_CJK_Compatibility_FORMS}', "");
Expect(1, 65104, '\P{- Is_CJK_Compatibility_FORMS}', "");
Expect(0, 65104, '\P{^- Is_CJK_Compatibility_FORMS}', "");
Error('\p{_/a/In_CJK_COMPATIBILITY_forms}');
Error('\P{_/a/In_CJK_COMPATIBILITY_forms}');
Expect(1, 65103, '\p{incjkcompatibilityforms}', "");
Expect(0, 65103, '\p{^incjkcompatibilityforms}', "");
Expect(0, 65103, '\P{incjkcompatibilityforms}', "");
Expect(1, 65103, '\P{^incjkcompatibilityforms}', "");
Expect(0, 65104, '\p{incjkcompatibilityforms}', "");
Expect(1, 65104, '\p{^incjkcompatibilityforms}', "");
Expect(1, 65104, '\P{incjkcompatibilityforms}', "");
Expect(0, 65104, '\P{^incjkcompatibilityforms}', "");
Expect(1, 65103, '\p{	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65103, '\p{^	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65103, '\P{	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65103, '\P{^	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65104, '\p{	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65104, '\p{^	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(1, 65104, '\P{	_In_CJK_COMPATIBILITY_FORMS}', "");
Expect(0, 65104, '\P{^	_In_CJK_COMPATIBILITY_FORMS}', "");
Error('\p{_:=CJK_COMPAT_forms}');
Error('\P{_:=CJK_COMPAT_forms}');
Expect(1, 65103, '\p{cjkcompatforms}', "");
Expect(0, 65103, '\p{^cjkcompatforms}', "");
Expect(0, 65103, '\P{cjkcompatforms}', "");
Expect(1, 65103, '\P{^cjkcompatforms}', "");
Expect(0, 65104, '\p{cjkcompatforms}', "");
Expect(1, 65104, '\p{^cjkcompatforms}', "");
Expect(1, 65104, '\P{cjkcompatforms}', "");
Expect(0, 65104, '\P{^cjkcompatforms}', "");
Expect(1, 65103, '\p{  CJK_compat_Forms}', "");
Expect(0, 65103, '\p{^  CJK_compat_Forms}', "");
Expect(0, 65103, '\P{  CJK_compat_Forms}', "");
Expect(1, 65103, '\P{^  CJK_compat_Forms}', "");
Expect(0, 65104, '\p{  CJK_compat_Forms}', "");
Expect(1, 65104, '\p{^  CJK_compat_Forms}', "");
Expect(1, 65104, '\P{  CJK_compat_Forms}', "");
Expect(0, 65104, '\P{^  CJK_compat_Forms}', "");
Error('\p{-/a/Is_CJK_compat_FORMS}');
Error('\P{-/a/Is_CJK_compat_FORMS}');
Expect(1, 65103, '\p{iscjkcompatforms}', "");
Expect(0, 65103, '\p{^iscjkcompatforms}', "");
Expect(0, 65103, '\P{iscjkcompatforms}', "");
Expect(1, 65103, '\P{^iscjkcompatforms}', "");
Expect(0, 65104, '\p{iscjkcompatforms}', "");
Expect(1, 65104, '\p{^iscjkcompatforms}', "");
Expect(1, 65104, '\P{iscjkcompatforms}', "");
Expect(0, 65104, '\P{^iscjkcompatforms}', "");
Expect(1, 65103, '\p{Is_cjk_COMPAT_FORMS}', "");
Expect(0, 65103, '\p{^Is_cjk_COMPAT_FORMS}', "");
Expect(0, 65103, '\P{Is_cjk_COMPAT_FORMS}', "");
Expect(1, 65103, '\P{^Is_cjk_COMPAT_FORMS}', "");
Expect(0, 65104, '\p{Is_cjk_COMPAT_FORMS}', "");
Expect(1, 65104, '\p{^Is_cjk_COMPAT_FORMS}', "");
Expect(1, 65104, '\P{Is_cjk_COMPAT_FORMS}', "");
Expect(0, 65104, '\P{^Is_cjk_COMPAT_FORMS}', "");
Error('\p{ IN_cjk_compat_forms/a/}');
Error('\P{ IN_cjk_compat_forms/a/}');
Expect(1, 65103, '\p{incjkcompatforms}', "");
Expect(0, 65103, '\p{^incjkcompatforms}', "");
Expect(0, 65103, '\P{incjkcompatforms}', "");
Expect(1, 65103, '\P{^incjkcompatforms}', "");
Expect(0, 65104, '\p{incjkcompatforms}', "");
Expect(1, 65104, '\p{^incjkcompatforms}', "");
Expect(1, 65104, '\P{incjkcompatforms}', "");
Expect(0, 65104, '\P{^incjkcompatforms}', "");
Expect(1, 65103, '\p{--In_cjk_compat_forms}', "");
Expect(0, 65103, '\p{^--In_cjk_compat_forms}', "");
Expect(0, 65103, '\P{--In_cjk_compat_forms}', "");
Expect(1, 65103, '\P{^--In_cjk_compat_forms}', "");
Expect(0, 65104, '\p{--In_cjk_compat_forms}', "");
Expect(1, 65104, '\p{^--In_cjk_compat_forms}', "");
Expect(1, 65104, '\P{--In_cjk_compat_forms}', "");
Expect(0, 65104, '\P{^--In_cjk_compat_forms}', "");
Error('\p{/a/-	CJK_compatibility_IDEOGRAPHS}');
Error('\P{/a/-	CJK_compatibility_IDEOGRAPHS}');
Expect(1, 64255, '\p{cjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^cjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{cjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^cjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{cjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^cjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{cjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^cjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(0, 64255, '\p{^ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(0, 64255, '\P{ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(1, 64255, '\P{^ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(0, 64256, '\p{ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(1, 64256, '\p{^ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(1, 64256, '\P{ 	cjk_COMPATIBILITY_ideographs}', "");
Expect(0, 64256, '\P{^ 	cjk_COMPATIBILITY_ideographs}', "");
Error('\p{/a/ Is_CJK_compatibility_ideographs}');
Error('\P{/a/ Is_CJK_compatibility_ideographs}');
Expect(1, 64255, '\p{iscjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^iscjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{iscjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^iscjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{iscjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^iscjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{iscjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^iscjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{_ is_CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\p{^_ is_CJK_Compatibility_Ideographs}', "");
Expect(0, 64255, '\P{_ is_CJK_Compatibility_Ideographs}', "");
Expect(1, 64255, '\P{^_ is_CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\p{_ is_CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\p{^_ is_CJK_Compatibility_Ideographs}', "");
Expect(1, 64256, '\P{_ is_CJK_Compatibility_Ideographs}', "");
Expect(0, 64256, '\P{^_ is_CJK_Compatibility_Ideographs}', "");
Error('\p{	_In_CJK_Compatibility_IDEOGRAPHS/a/}');
Error('\P{	_In_CJK_Compatibility_IDEOGRAPHS/a/}');
Expect(1, 64255, '\p{incjkcompatibilityideographs}', "");
Expect(0, 64255, '\p{^incjkcompatibilityideographs}', "");
Expect(0, 64255, '\P{incjkcompatibilityideographs}', "");
Expect(1, 64255, '\P{^incjkcompatibilityideographs}', "");
Expect(0, 64256, '\p{incjkcompatibilityideographs}', "");
Expect(1, 64256, '\p{^incjkcompatibilityideographs}', "");
Expect(1, 64256, '\P{incjkcompatibilityideographs}', "");
Expect(0, 64256, '\P{^incjkcompatibilityideographs}', "");
Expect(1, 64255, '\p{- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(0, 64255, '\p{^- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(0, 64255, '\P{- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(1, 64255, '\P{^- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(0, 64256, '\p{- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(1, 64256, '\p{^- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(1, 64256, '\P{- In_CJK_compatibility_IDEOGRAPHS}', "");
Expect(0, 64256, '\P{^- In_CJK_compatibility_IDEOGRAPHS}', "");
Error('\p{/a/ -cjk_compat_ideographs}');
Error('\P{/a/ -cjk_compat_ideographs}');
Expect(1, 64255, '\p{cjkcompatideographs}', "");
Expect(0, 64255, '\p{^cjkcompatideographs}', "");
Expect(0, 64255, '\P{cjkcompatideographs}', "");
Expect(1, 64255, '\P{^cjkcompatideographs}', "");
Expect(0, 64256, '\p{cjkcompatideographs}', "");
Expect(1, 64256, '\p{^cjkcompatideographs}', "");
Expect(1, 64256, '\P{cjkcompatideographs}', "");
Expect(0, 64256, '\P{^cjkcompatideographs}', "");
Expect(1, 64255, '\p{_CJK_COMPAT_Ideographs}', "");
Expect(0, 64255, '\p{^_CJK_COMPAT_Ideographs}', "");
Expect(0, 64255, '\P{_CJK_COMPAT_Ideographs}', "");
Expect(1, 64255, '\P{^_CJK_COMPAT_Ideographs}', "");
Expect(0, 64256, '\p{_CJK_COMPAT_Ideographs}', "");
Expect(1, 64256, '\p{^_CJK_COMPAT_Ideographs}', "");
Expect(1, 64256, '\P{_CJK_COMPAT_Ideographs}', "");
Expect(0, 64256, '\P{^_CJK_COMPAT_Ideographs}', "");
Error('\p{:=-IS_CJK_COMPAT_Ideographs}');
Error('\P{:=-IS_CJK_COMPAT_Ideographs}');
Expect(1, 64255, '\p{iscjkcompatideographs}', "");
Expect(0, 64255, '\p{^iscjkcompatideographs}', "");
Expect(0, 64255, '\P{iscjkcompatideographs}', "");
Expect(1, 64255, '\P{^iscjkcompatideographs}', "");
Expect(0, 64256, '\p{iscjkcompatideographs}', "");
Expect(1, 64256, '\p{^iscjkcompatideographs}', "");
Expect(1, 64256, '\P{iscjkcompatideographs}', "");
Expect(0, 64256, '\P{^iscjkcompatideographs}', "");
Expect(1, 64255, '\p{--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(0, 64255, '\p{^--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(0, 64255, '\P{--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(1, 64255, '\P{^--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(0, 64256, '\p{--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(1, 64256, '\p{^--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(1, 64256, '\P{--Is_cjk_Compat_IDEOGRAPHS}', "");
Expect(0, 64256, '\P{^--Is_cjk_Compat_IDEOGRAPHS}', "");
Error('\p{_/a/In_CJK_Compat_Ideographs}');
Error('\P{_/a/In_CJK_Compat_Ideographs}');
Expect(1, 64255, '\p{incjkcompatideographs}', "");
Expect(0, 64255, '\p{^incjkcompatideographs}', "");
Expect(0, 64255, '\P{incjkcompatideographs}', "");
Expect(1, 64255, '\P{^incjkcompatideographs}', "");
Expect(0, 64256, '\p{incjkcompatideographs}', "");
Expect(1, 64256, '\p{^incjkcompatideographs}', "");
Expect(1, 64256, '\P{incjkcompatideographs}', "");
Expect(0, 64256, '\P{^incjkcompatideographs}', "");
Expect(1, 64255, '\p{_-In_cjk_Compat_ideographs}', "");
Expect(0, 64255, '\p{^_-In_cjk_Compat_ideographs}', "");
Expect(0, 64255, '\P{_-In_cjk_Compat_ideographs}', "");
Expect(1, 64255, '\P{^_-In_cjk_Compat_ideographs}', "");
Expect(0, 64256, '\p{_-In_cjk_Compat_ideographs}', "");
Expect(1, 64256, '\p{^_-In_cjk_Compat_ideographs}', "");
Expect(1, 64256, '\P{_-In_cjk_Compat_ideographs}', "");
Expect(0, 64256, '\P{^_-In_cjk_Compat_ideographs}', "");
Error('\p{_ CJK_Compatibility_ideographs_Supplement:=}');
Error('\P{_ CJK_Compatibility_ideographs_Supplement:=}');
Expect(1, 195103, '\p{cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^cjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^cjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{cjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^cjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\p{^	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\P{	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(1, 195103, '\P{^	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\p{	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\p{^	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\P{	 CJK_Compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\P{^	 CJK_Compatibility_ideographs_Supplement}', "");
Error('\p{__IS_CJK_Compatibility_ideographs_Supplement/a/}');
Error('\P{__IS_CJK_Compatibility_ideographs_Supplement/a/}');
Expect(1, 195103, '\p{iscjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^iscjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{iscjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^iscjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{iscjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^iscjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{iscjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^iscjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\p{^  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(0, 195103, '\P{  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(1, 195103, '\P{^  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\p{  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\p{^  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(1, 195104, '\P{  Is_CJK_compatibility_ideographs_Supplement}', "");
Expect(0, 195104, '\P{^  Is_CJK_compatibility_ideographs_Supplement}', "");
Error('\p{:= -In_cjk_compatibility_IDEOGRAPHS_supplement}');
Error('\P{:= -In_cjk_compatibility_IDEOGRAPHS_supplement}');
Expect(1, 195103, '\p{incjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\p{^incjkcompatibilityideographssupplement}', "");
Expect(0, 195103, '\P{incjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\P{^incjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\p{incjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\p{^incjkcompatibilityideographssupplement}', "");
Expect(1, 195104, '\P{incjkcompatibilityideographssupplement}', "");
Expect(0, 195104, '\P{^incjkcompatibilityideographssupplement}', "");
Expect(1, 195103, '\p{ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195103, '\p{^ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195103, '\P{ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195103, '\P{^ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195104, '\p{ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195104, '\p{^ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(1, 195104, '\P{ In_cjk_Compatibility_Ideographs_Supplement}', "");
Expect(0, 195104, '\P{^ In_cjk_Compatibility_Ideographs_Supplement}', "");
Error('\p{ /a/cjk_compat_Ideographs_Sup}');
Error('\P{ /a/cjk_compat_Ideographs_Sup}');
Expect(1, 195103, '\p{cjkcompatideographssup}', "");
Expect(0, 195103, '\p{^cjkcompatideographssup}', "");
Expect(0, 195103, '\P{cjkcompatideographssup}', "");
Expect(1, 195103, '\P{^cjkcompatideographssup}', "");
Expect(0, 195104, '\p{cjkcompatideographssup}', "");
Expect(1, 195104, '\p{^cjkcompatideographssup}', "");
Expect(1, 195104, '\P{cjkcompatideographssup}', "");
Expect(0, 195104, '\P{^cjkcompatideographssup}', "");
Expect(1, 195103, '\p{-_cjk_compat_Ideographs_Sup}', "");
Expect(0, 195103, '\p{^-_cjk_compat_Ideographs_Sup}', "");
Expect(0, 195103, '\P{-_cjk_compat_Ideographs_Sup}', "");
Expect(1, 195103, '\P{^-_cjk_compat_Ideographs_Sup}', "");
Expect(0, 195104, '\p{-_cjk_compat_Ideographs_Sup}', "");
Expect(1, 195104, '\p{^-_cjk_compat_Ideographs_Sup}', "");
Expect(1, 195104, '\P{-_cjk_compat_Ideographs_Sup}', "");
Expect(0, 195104, '\P{^-_cjk_compat_Ideographs_Sup}', "");
Error('\p{ _is_CJK_COMPAT_Ideographs_SUP/a/}');
Error('\P{ _is_CJK_COMPAT_Ideographs_SUP/a/}');
Expect(1, 195103, '\p{iscjkcompatideographssup}', "");
Expect(0, 195103, '\p{^iscjkcompatideographssup}', "");
Expect(0, 195103, '\P{iscjkcompatideographssup}', "");
Expect(1, 195103, '\P{^iscjkcompatideographssup}', "");
Expect(0, 195104, '\p{iscjkcompatideographssup}', "");
Expect(1, 195104, '\p{^iscjkcompatideographssup}', "");
Expect(1, 195104, '\P{iscjkcompatideographssup}', "");
Expect(0, 195104, '\P{^iscjkcompatideographssup}', "");
Expect(1, 195103, '\p{_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(0, 195103, '\p{^_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(0, 195103, '\P{_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(1, 195103, '\P{^_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(0, 195104, '\p{_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(1, 195104, '\p{^_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(1, 195104, '\P{_-is_CJK_COMPAT_Ideographs_sup}', "");
Expect(0, 195104, '\P{^_-is_CJK_COMPAT_Ideographs_sup}', "");
Error('\p{/a/_In_cjk_COMPAT_IDEOGRAPHS_sup}');
Error('\P{/a/_In_cjk_COMPAT_IDEOGRAPHS_sup}');
Expect(1, 195103, '\p{incjkcompatideographssup}', "");
Expect(0, 195103, '\p{^incjkcompatideographssup}', "");
Expect(0, 195103, '\P{incjkcompatideographssup}', "");
Expect(1, 195103, '\P{^incjkcompatideographssup}', "");
Expect(0, 195104, '\p{incjkcompatideographssup}', "");
Expect(1, 195104, '\p{^incjkcompatideographssup}', "");
Expect(1, 195104, '\P{incjkcompatideographssup}', "");
Expect(0, 195104, '\P{^incjkcompatideographssup}', "");
Expect(1, 195103, '\p{In_CJK_Compat_Ideographs_Sup}', "");
Expect(0, 195103, '\p{^In_CJK_Compat_Ideographs_Sup}', "");
Expect(0, 195103, '\P{In_CJK_Compat_Ideographs_Sup}', "");
Expect(1, 195103, '\P{^In_CJK_Compat_Ideographs_Sup}', "");
Expect(0, 195104, '\p{In_CJK_Compat_Ideographs_Sup}', "");
Expect(1, 195104, '\p{^In_CJK_Compat_Ideographs_Sup}', "");
Expect(1, 195104, '\P{In_CJK_Compat_Ideographs_Sup}', "");
Expect(0, 195104, '\P{^In_CJK_Compat_Ideographs_Sup}', "");
Error('\p{	:=CJK_radicals_supplement}');
Error('\P{	:=CJK_radicals_supplement}');
Expect(1, 12031, '\p{cjkradicalssupplement}', "");
Expect(0, 12031, '\p{^cjkradicalssupplement}', "");
Expect(0, 12031, '\P{cjkradicalssupplement}', "");
Expect(1, 12031, '\P{^cjkradicalssupplement}', "");
Expect(0, 12032, '\p{cjkradicalssupplement}', "");
Expect(1, 12032, '\p{^cjkradicalssupplement}', "");
Expect(1, 12032, '\P{cjkradicalssupplement}', "");
Expect(0, 12032, '\P{^cjkradicalssupplement}', "");
Expect(1, 12031, '\p{-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12031, '\p{^-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12031, '\P{-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12031, '\P{^-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12032, '\p{-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12032, '\p{^-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(1, 12032, '\P{-	CJK_RADICALS_SUPPLEMENT}', "");
Expect(0, 12032, '\P{^-	CJK_RADICALS_SUPPLEMENT}', "");
Error('\p{:= 	IS_cjk_Radicals_Supplement}');
Error('\P{:= 	IS_cjk_Radicals_Supplement}');
Expect(1, 12031, '\p{iscjkradicalssupplement}', "");
Expect(0, 12031, '\p{^iscjkradicalssupplement}', "");
Expect(0, 12031, '\P{iscjkradicalssupplement}', "");
Expect(1, 12031, '\P{^iscjkradicalssupplement}', "");
Expect(0, 12032, '\p{iscjkradicalssupplement}', "");
Expect(1, 12032, '\p{^iscjkradicalssupplement}', "");
Expect(1, 12032, '\P{iscjkradicalssupplement}', "");
Expect(0, 12032, '\P{^iscjkradicalssupplement}', "");
Expect(1, 12031, '\p{_is_CJK_Radicals_supplement}', "");
Expect(0, 12031, '\p{^_is_CJK_Radicals_supplement}', "");
Expect(0, 12031, '\P{_is_CJK_Radicals_supplement}', "");
Expect(1, 12031, '\P{^_is_CJK_Radicals_supplement}', "");
Expect(0, 12032, '\p{_is_CJK_Radicals_supplement}', "");
Expect(1, 12032, '\p{^_is_CJK_Radicals_supplement}', "");
Expect(1, 12032, '\P{_is_CJK_Radicals_supplement}', "");
Expect(0, 12032, '\P{^_is_CJK_Radicals_supplement}', "");
Error('\p{-_In_CJK_radicals_SUPPLEMENT:=}');
Error('\P{-_In_CJK_radicals_SUPPLEMENT:=}');
Expect(1, 12031, '\p{incjkradicalssupplement}', "");
Expect(0, 12031, '\p{^incjkradicalssupplement}', "");
Expect(0, 12031, '\P{incjkradicalssupplement}', "");
Expect(1, 12031, '\P{^incjkradicalssupplement}', "");
Expect(0, 12032, '\p{incjkradicalssupplement}', "");
Expect(1, 12032, '\p{^incjkradicalssupplement}', "");
Expect(1, 12032, '\P{incjkradicalssupplement}', "");
Expect(0, 12032, '\P{^incjkradicalssupplement}', "");
Expect(1, 12031, '\p{	 IN_CJK_Radicals_Supplement}', "");
Expect(0, 12031, '\p{^	 IN_CJK_Radicals_Supplement}', "");
Expect(0, 12031, '\P{	 IN_CJK_Radicals_Supplement}', "");
Expect(1, 12031, '\P{^	 IN_CJK_Radicals_Supplement}', "");
Expect(0, 12032, '\p{	 IN_CJK_Radicals_Supplement}', "");
Expect(1, 12032, '\p{^	 IN_CJK_Radicals_Supplement}', "");
Expect(1, 12032, '\P{	 IN_CJK_Radicals_Supplement}', "");
Expect(0, 12032, '\P{^	 IN_CJK_Radicals_Supplement}', "");
Error('\p{_cjk_Radicals_Sup/a/}');
Error('\P{_cjk_Radicals_Sup/a/}');
Expect(1, 12031, '\p{cjkradicalssup}', "");
Expect(0, 12031, '\p{^cjkradicalssup}', "");
Expect(0, 12031, '\P{cjkradicalssup}', "");
Expect(1, 12031, '\P{^cjkradicalssup}', "");
Expect(0, 12032, '\p{cjkradicalssup}', "");
Expect(1, 12032, '\p{^cjkradicalssup}', "");
Expect(1, 12032, '\P{cjkradicalssup}', "");
Expect(0, 12032, '\P{^cjkradicalssup}', "");
Expect(1, 12031, '\p{-cjk_RADICALS_Sup}', "");
Expect(0, 12031, '\p{^-cjk_RADICALS_Sup}', "");
Expect(0, 12031, '\P{-cjk_RADICALS_Sup}', "");
Expect(1, 12031, '\P{^-cjk_RADICALS_Sup}', "");
Expect(0, 12032, '\p{-cjk_RADICALS_Sup}', "");
Expect(1, 12032, '\p{^-cjk_RADICALS_Sup}', "");
Expect(1, 12032, '\P{-cjk_RADICALS_Sup}', "");
Expect(0, 12032, '\P{^-cjk_RADICALS_Sup}', "");
Error('\p{:= IS_CJK_Radicals_SUP}');
Error('\P{:= IS_CJK_Radicals_SUP}');
Expect(1, 12031, '\p{iscjkradicalssup}', "");
Expect(0, 12031, '\p{^iscjkradicalssup}', "");
Expect(0, 12031, '\P{iscjkradicalssup}', "");
Expect(1, 12031, '\P{^iscjkradicalssup}', "");
Expect(0, 12032, '\p{iscjkradicalssup}', "");
Expect(1, 12032, '\p{^iscjkradicalssup}', "");
Expect(1, 12032, '\P{iscjkradicalssup}', "");
Expect(0, 12032, '\P{^iscjkradicalssup}', "");
Expect(1, 12031, '\p{-_is_CJK_Radicals_Sup}', "");
Expect(0, 12031, '\p{^-_is_CJK_Radicals_Sup}', "");
Expect(0, 12031, '\P{-_is_CJK_Radicals_Sup}', "");
Expect(1, 12031, '\P{^-_is_CJK_Radicals_Sup}', "");
Expect(0, 12032, '\p{-_is_CJK_Radicals_Sup}', "");
Expect(1, 12032, '\p{^-_is_CJK_Radicals_Sup}', "");
Expect(1, 12032, '\P{-_is_CJK_Radicals_Sup}', "");
Expect(0, 12032, '\P{^-_is_CJK_Radicals_Sup}', "");
Error('\p{--in_CJK_Radicals_sup/a/}');
Error('\P{--in_CJK_Radicals_sup/a/}');
Expect(1, 12031, '\p{incjkradicalssup}', "");
Expect(0, 12031, '\p{^incjkradicalssup}', "");
Expect(0, 12031, '\P{incjkradicalssup}', "");
Expect(1, 12031, '\P{^incjkradicalssup}', "");
Expect(0, 12032, '\p{incjkradicalssup}', "");
Expect(1, 12032, '\p{^incjkradicalssup}', "");
Expect(1, 12032, '\P{incjkradicalssup}', "");
Expect(0, 12032, '\P{^incjkradicalssup}', "");
Expect(1, 12031, '\p{		In_CJK_Radicals_Sup}', "");
Expect(0, 12031, '\p{^		In_CJK_Radicals_Sup}', "");
Expect(0, 12031, '\P{		In_CJK_Radicals_Sup}', "");
Expect(1, 12031, '\P{^		In_CJK_Radicals_Sup}', "");
Expect(0, 12032, '\p{		In_CJK_Radicals_Sup}', "");
Expect(1, 12032, '\p{^		In_CJK_Radicals_Sup}', "");
Expect(1, 12032, '\P{		In_CJK_Radicals_Sup}', "");
Expect(0, 12032, '\P{^		In_CJK_Radicals_Sup}', "");
Error('\p{-:=CJK_Strokes}');
Error('\P{-:=CJK_Strokes}');
Expect(1, 12783, '\p{cjkstrokes}', "");
Expect(0, 12783, '\p{^cjkstrokes}', "");
Expect(0, 12783, '\P{cjkstrokes}', "");
Expect(1, 12783, '\P{^cjkstrokes}', "");
Expect(0, 12784, '\p{cjkstrokes}', "");
Expect(1, 12784, '\p{^cjkstrokes}', "");
Expect(1, 12784, '\P{cjkstrokes}', "");
Expect(0, 12784, '\P{^cjkstrokes}', "");
Expect(1, 12783, '\p{	_CJK_Strokes}', "");
Expect(0, 12783, '\p{^	_CJK_Strokes}', "");
Expect(0, 12783, '\P{	_CJK_Strokes}', "");
Expect(1, 12783, '\P{^	_CJK_Strokes}', "");
Expect(0, 12784, '\p{	_CJK_Strokes}', "");
Expect(1, 12784, '\p{^	_CJK_Strokes}', "");
Expect(1, 12784, '\P{	_CJK_Strokes}', "");
Expect(0, 12784, '\P{^	_CJK_Strokes}', "");
Error('\p{/a/ Is_CJK_STROKES}');
Error('\P{/a/ Is_CJK_STROKES}');
Expect(1, 12783, '\p{iscjkstrokes}', "");
Expect(0, 12783, '\p{^iscjkstrokes}', "");
Expect(0, 12783, '\P{iscjkstrokes}', "");
Expect(1, 12783, '\P{^iscjkstrokes}', "");
Expect(0, 12784, '\p{iscjkstrokes}', "");
Expect(1, 12784, '\p{^iscjkstrokes}', "");
Expect(1, 12784, '\P{iscjkstrokes}', "");
Expect(0, 12784, '\P{^iscjkstrokes}', "");
Expect(1, 12783, '\p{_is_CJK_Strokes}', "");
Expect(0, 12783, '\p{^_is_CJK_Strokes}', "");
Expect(0, 12783, '\P{_is_CJK_Strokes}', "");
Expect(1, 12783, '\P{^_is_CJK_Strokes}', "");
Expect(0, 12784, '\p{_is_CJK_Strokes}', "");
Expect(1, 12784, '\p{^_is_CJK_Strokes}', "");
Expect(1, 12784, '\P{_is_CJK_Strokes}', "");
Expect(0, 12784, '\P{^_is_CJK_Strokes}', "");
Error('\p{-In_CJK_strokes/a/}');
Error('\P{-In_CJK_strokes/a/}');
Expect(1, 12783, '\p{incjkstrokes}', "");
Expect(0, 12783, '\p{^incjkstrokes}', "");
Expect(0, 12783, '\P{incjkstrokes}', "");
Expect(1, 12783, '\P{^incjkstrokes}', "");
Expect(0, 12784, '\p{incjkstrokes}', "");
Expect(1, 12784, '\p{^incjkstrokes}', "");
Expect(1, 12784, '\P{incjkstrokes}', "");
Expect(0, 12784, '\P{^incjkstrokes}', "");
Expect(1, 12783, '\p{	_IN_CJK_strokes}', "");
Expect(0, 12783, '\p{^	_IN_CJK_strokes}', "");
Expect(0, 12783, '\P{	_IN_CJK_strokes}', "");
Expect(1, 12783, '\P{^	_IN_CJK_strokes}', "");
Expect(0, 12784, '\p{	_IN_CJK_strokes}', "");
Expect(1, 12784, '\p{^	_IN_CJK_strokes}', "");
Expect(1, 12784, '\P{	_IN_CJK_strokes}', "");
Expect(0, 12784, '\P{^	_IN_CJK_strokes}', "");
Error('\p{	/a/CJK_SYMBOLS_AND_Punctuation}');
Error('\P{	/a/CJK_SYMBOLS_AND_Punctuation}');
Expect(1, 12351, '\p{cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^cjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^cjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{cjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^cjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(0, 12351, '\p{^-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(0, 12351, '\P{-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(1, 12351, '\P{^-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(0, 12352, '\p{-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(1, 12352, '\p{^-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(1, 12352, '\P{-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Expect(0, 12352, '\P{^-_cjk_SYMBOLS_And_PUNCTUATION}', "");
Error('\p{-:=is_CJK_symbols_and_Punctuation}');
Error('\P{-:=is_CJK_symbols_and_Punctuation}');
Expect(1, 12351, '\p{iscjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^iscjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{iscjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^iscjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{iscjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^iscjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{iscjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^iscjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(0, 12351, '\p{^-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(0, 12351, '\P{-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(1, 12351, '\P{^-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(0, 12352, '\p{-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(1, 12352, '\p{^-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(1, 12352, '\P{-Is_cjk_symbols_AND_PUNCTUATION}', "");
Expect(0, 12352, '\P{^-Is_cjk_symbols_AND_PUNCTUATION}', "");
Error('\p{-/a/In_CJK_Symbols_And_PUNCTUATION}');
Error('\P{-/a/In_CJK_Symbols_And_PUNCTUATION}');
Expect(1, 12351, '\p{incjksymbolsandpunctuation}', "");
Expect(0, 12351, '\p{^incjksymbolsandpunctuation}', "");
Expect(0, 12351, '\P{incjksymbolsandpunctuation}', "");
Expect(1, 12351, '\P{^incjksymbolsandpunctuation}', "");
Expect(0, 12352, '\p{incjksymbolsandpunctuation}', "");
Expect(1, 12352, '\p{^incjksymbolsandpunctuation}', "");
Expect(1, 12352, '\P{incjksymbolsandpunctuation}', "");
Expect(0, 12352, '\P{^incjksymbolsandpunctuation}', "");
Expect(1, 12351, '\p{_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12351, '\p{^_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12351, '\P{_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(1, 12351, '\P{^_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12352, '\p{_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(1, 12352, '\p{^_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(1, 12352, '\P{_ IN_CJK_Symbols_and_Punctuation}', "");
Expect(0, 12352, '\P{^_ IN_CJK_Symbols_and_Punctuation}', "");
Error('\p{/a/_CJK_Symbols}');
Error('\P{/a/_CJK_Symbols}');
Expect(1, 12351, '\p{cjksymbols}', "");
Expect(0, 12351, '\p{^cjksymbols}', "");
Expect(0, 12351, '\P{cjksymbols}', "");
Expect(1, 12351, '\P{^cjksymbols}', "");
Expect(0, 12352, '\p{cjksymbols}', "");
Expect(1, 12352, '\p{^cjksymbols}', "");
Expect(1, 12352, '\P{cjksymbols}', "");
Expect(0, 12352, '\P{^cjksymbols}', "");
Expect(1, 12351, '\p{	cjk_symbols}', "");
Expect(0, 12351, '\p{^	cjk_symbols}', "");
Expect(0, 12351, '\P{	cjk_symbols}', "");
Expect(1, 12351, '\P{^	cjk_symbols}', "");
Expect(0, 12352, '\p{	cjk_symbols}', "");
Expect(1, 12352, '\p{^	cjk_symbols}', "");
Expect(1, 12352, '\P{	cjk_symbols}', "");
Expect(0, 12352, '\P{^	cjk_symbols}', "");
Error('\p{	-is_CJK_Symbols:=}');
Error('\P{	-is_CJK_Symbols:=}');
Expect(1, 12351, '\p{iscjksymbols}', "");
Expect(0, 12351, '\p{^iscjksymbols}', "");
Expect(0, 12351, '\P{iscjksymbols}', "");
Expect(1, 12351, '\P{^iscjksymbols}', "");
Expect(0, 12352, '\p{iscjksymbols}', "");
Expect(1, 12352, '\p{^iscjksymbols}', "");
Expect(1, 12352, '\P{iscjksymbols}', "");
Expect(0, 12352, '\P{^iscjksymbols}', "");
Expect(1, 12351, '\p{_	Is_CJK_symbols}', "");
Expect(0, 12351, '\p{^_	Is_CJK_symbols}', "");
Expect(0, 12351, '\P{_	Is_CJK_symbols}', "");
Expect(1, 12351, '\P{^_	Is_CJK_symbols}', "");
Expect(0, 12352, '\p{_	Is_CJK_symbols}', "");
Expect(1, 12352, '\p{^_	Is_CJK_symbols}', "");
Expect(1, 12352, '\P{_	Is_CJK_symbols}', "");
Expect(0, 12352, '\P{^_	Is_CJK_symbols}', "");
Error('\p{_/a/In_CJK_symbols}');
Error('\P{_/a/In_CJK_symbols}');
Expect(1, 12351, '\p{incjksymbols}', "");
Expect(0, 12351, '\p{^incjksymbols}', "");
Expect(0, 12351, '\P{incjksymbols}', "");
Expect(1, 12351, '\P{^incjksymbols}', "");
Expect(0, 12352, '\p{incjksymbols}', "");
Expect(1, 12352, '\p{^incjksymbols}', "");
Expect(1, 12352, '\P{incjksymbols}', "");
Expect(0, 12352, '\P{^incjksymbols}', "");
Expect(1, 12351, '\p{	_in_CJK_Symbols}', "");
Expect(0, 12351, '\p{^	_in_CJK_Symbols}', "");
Expect(0, 12351, '\P{	_in_CJK_Symbols}', "");
Expect(1, 12351, '\P{^	_in_CJK_Symbols}', "");
Expect(0, 12352, '\p{	_in_CJK_Symbols}', "");
Expect(1, 12352, '\p{^	_in_CJK_Symbols}', "");
Expect(1, 12352, '\P{	_in_CJK_Symbols}', "");
Expect(0, 12352, '\P{^	_in_CJK_Symbols}', "");
Error('\p{__cjk_Unified_ideographs:=}');
Error('\P{__cjk_Unified_ideographs:=}');
Expect(1, 40959, '\p{cjkunifiedideographs}', "");
Expect(0, 40959, '\p{^cjkunifiedideographs}', "");
Expect(0, 40959, '\P{cjkunifiedideographs}', "");
Expect(1, 40959, '\P{^cjkunifiedideographs}', "");
Expect(0, 40960, '\p{cjkunifiedideographs}', "");
Expect(1, 40960, '\p{^cjkunifiedideographs}', "");
Expect(1, 40960, '\P{cjkunifiedideographs}', "");
Expect(0, 40960, '\P{^cjkunifiedideographs}', "");
Expect(1, 40959, '\p{cjk_Unified_IDEOGRAPHS}', "");
Expect(0, 40959, '\p{^cjk_Unified_IDEOGRAPHS}', "");
Expect(0, 40959, '\P{cjk_Unified_IDEOGRAPHS}', "");
Expect(1, 40959, '\P{^cjk_Unified_IDEOGRAPHS}', "");
Expect(0, 40960, '\p{cjk_Unified_IDEOGRAPHS}', "");
Expect(1, 40960, '\p{^cjk_Unified_IDEOGRAPHS}', "");
Expect(1, 40960, '\P{cjk_Unified_IDEOGRAPHS}', "");
Expect(0, 40960, '\P{^cjk_Unified_IDEOGRAPHS}', "");
Error('\p{/a/ 	is_CJK_Unified_IDEOGRAPHS}');
Error('\P{/a/ 	is_CJK_Unified_IDEOGRAPHS}');
Expect(1, 40959, '\p{iscjkunifiedideographs}', "");
Expect(0, 40959, '\p{^iscjkunifiedideographs}', "");
Expect(0, 40959, '\P{iscjkunifiedideographs}', "");
Expect(1, 40959, '\P{^iscjkunifiedideographs}', "");
Expect(0, 40960, '\p{iscjkunifiedideographs}', "");
Expect(1, 40960, '\p{^iscjkunifiedideographs}', "");
Expect(1, 40960, '\P{iscjkunifiedideographs}', "");
Expect(0, 40960, '\P{^iscjkunifiedideographs}', "");
Expect(1, 40959, '\p{_is_cjk_Unified_Ideographs}', "");
Expect(0, 40959, '\p{^_is_cjk_Unified_Ideographs}', "");
Expect(0, 40959, '\P{_is_cjk_Unified_Ideographs}', "");
Expect(1, 40959, '\P{^_is_cjk_Unified_Ideographs}', "");
Expect(0, 40960, '\p{_is_cjk_Unified_Ideographs}', "");
Expect(1, 40960, '\p{^_is_cjk_Unified_Ideographs}', "");
Expect(1, 40960, '\P{_is_cjk_Unified_Ideographs}', "");
Expect(0, 40960, '\P{^_is_cjk_Unified_Ideographs}', "");
Error('\p{:=in_CJK_UNIFIED_IDEOGRAPHS}');
Error('\P{:=in_CJK_UNIFIED_IDEOGRAPHS}');
Expect(1, 40959, '\p{incjkunifiedideographs}', "");
Expect(0, 40959, '\p{^incjkunifiedideographs}', "");
Expect(0, 40959, '\P{incjkunifiedideographs}', "");
Expect(1, 40959, '\P{^incjkunifiedideographs}', "");
Expect(0, 40960, '\p{incjkunifiedideographs}', "");
Expect(1, 40960, '\p{^incjkunifiedideographs}', "");
Expect(1, 40960, '\P{incjkunifiedideographs}', "");
Expect(0, 40960, '\P{^incjkunifiedideographs}', "");
Expect(1, 40959, '\p{-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(0, 40959, '\p{^-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(0, 40959, '\P{-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(1, 40959, '\P{^-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(0, 40960, '\p{-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(1, 40960, '\p{^-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(1, 40960, '\P{-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Expect(0, 40960, '\P{^-In_CJK_UNIFIED_IDEOGRAPHS}', "");
Error('\p{:=	CJK}');
Error('\P{:=	CJK}');
Expect(1, 40959, '\p{cjk}', "");
Expect(0, 40959, '\p{^cjk}', "");
Expect(0, 40959, '\P{cjk}', "");
Expect(1, 40959, '\P{^cjk}', "");
Expect(0, 40960, '\p{cjk}', "");
Expect(1, 40960, '\p{^cjk}', "");
Expect(1, 40960, '\P{cjk}', "");
Expect(0, 40960, '\P{^cjk}', "");
Expect(1, 40959, '\p{__CJK}', "");
Expect(0, 40959, '\p{^__CJK}', "");
Expect(0, 40959, '\P{__CJK}', "");
Expect(1, 40959, '\P{^__CJK}', "");
Expect(0, 40960, '\p{__CJK}', "");
Expect(1, 40960, '\p{^__CJK}', "");
Expect(1, 40960, '\P{__CJK}', "");
Expect(0, 40960, '\P{^__CJK}', "");
Error('\p{	:=Is_cjk}');
Error('\P{	:=Is_cjk}');
Expect(1, 40959, '\p{iscjk}', "");
Expect(0, 40959, '\p{^iscjk}', "");
Expect(0, 40959, '\P{iscjk}', "");
Expect(1, 40959, '\P{^iscjk}', "");
Expect(0, 40960, '\p{iscjk}', "");
Expect(1, 40960, '\p{^iscjk}', "");
Expect(1, 40960, '\P{iscjk}', "");
Expect(0, 40960, '\P{^iscjk}', "");
Expect(1, 40959, '\p{_Is_CJK}', "");
Expect(0, 40959, '\p{^_Is_CJK}', "");
Expect(0, 40959, '\P{_Is_CJK}', "");
Expect(1, 40959, '\P{^_Is_CJK}', "");
Expect(0, 40960, '\p{_Is_CJK}', "");
Expect(1, 40960, '\p{^_Is_CJK}', "");
Expect(1, 40960, '\P{_Is_CJK}', "");
Expect(0, 40960, '\P{^_Is_CJK}', "");
Error('\p{	:=In_CJK}');
Error('\P{	:=In_CJK}');
Expect(1, 40959, '\p{incjk}', "");
Expect(0, 40959, '\p{^incjk}', "");
Expect(0, 40959, '\P{incjk}', "");
Expect(1, 40959, '\P{^incjk}', "");
Expect(0, 40960, '\p{incjk}', "");
Expect(1, 40960, '\p{^incjk}', "");
Expect(1, 40960, '\P{incjk}', "");
Expect(0, 40960, '\P{^incjk}', "");
Expect(1, 40959, '\p{	-In_CJK}', "");
Expect(0, 40959, '\p{^	-In_CJK}', "");
Expect(0, 40959, '\P{	-In_CJK}', "");
Expect(1, 40959, '\P{^	-In_CJK}', "");
Expect(0, 40960, '\p{	-In_CJK}', "");
Expect(1, 40960, '\p{^	-In_CJK}', "");
Expect(1, 40960, '\P{	-In_CJK}', "");
Expect(0, 40960, '\P{^	-In_CJK}', "");
Error('\p{:= CJK_Unified_ideographs_Extension_a}');
Error('\P{:= CJK_Unified_ideographs_Extension_a}');
Expect(1, 19903, '\p{cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^cjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^cjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{cjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^cjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(0, 19903, '\p{^		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(0, 19903, '\P{		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(1, 19903, '\P{^		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(0, 19904, '\p{		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(1, 19904, '\p{^		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(1, 19904, '\P{		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Expect(0, 19904, '\P{^		CJK_UNIFIED_Ideographs_EXTENSION_a}', "");
Error('\p{/a/IS_CJK_UNIFIED_Ideographs_EXTENSION_A}');
Error('\P{/a/IS_CJK_UNIFIED_Ideographs_EXTENSION_A}');
Expect(1, 19903, '\p{iscjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^iscjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{iscjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^iscjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{iscjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^iscjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{iscjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^iscjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(0, 19903, '\p{^IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(0, 19903, '\P{IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(1, 19903, '\P{^IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(0, 19904, '\p{IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(1, 19904, '\p{^IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(1, 19904, '\P{IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Expect(0, 19904, '\P{^IS_CJK_UNIFIED_ideographs_Extension_a}', "");
Error('\p{/a/	 In_CJK_unified_Ideographs_Extension_A}');
Error('\P{/a/	 In_CJK_unified_Ideographs_Extension_A}');
Expect(1, 19903, '\p{incjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\p{^incjkunifiedideographsextensiona}', "");
Expect(0, 19903, '\P{incjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\P{^incjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\p{incjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\p{^incjkunifiedideographsextensiona}', "");
Expect(1, 19904, '\P{incjkunifiedideographsextensiona}', "");
Expect(0, 19904, '\P{^incjkunifiedideographsextensiona}', "");
Expect(1, 19903, '\p{--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(0, 19903, '\p{^--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(0, 19903, '\P{--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(1, 19903, '\P{^--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(0, 19904, '\p{--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(1, 19904, '\p{^--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(1, 19904, '\P{--in_cjk_Unified_Ideographs_Extension_A}', "");
Expect(0, 19904, '\P{^--in_cjk_Unified_Ideographs_Extension_A}', "");
Error('\p{/a/	-CJK_Ext_A}');
Error('\P{/a/	-CJK_Ext_A}');
Expect(1, 19903, '\p{cjkexta}', "");
Expect(0, 19903, '\p{^cjkexta}', "");
Expect(0, 19903, '\P{cjkexta}', "");
Expect(1, 19903, '\P{^cjkexta}', "");
Expect(0, 19904, '\p{cjkexta}', "");
Expect(1, 19904, '\p{^cjkexta}', "");
Expect(1, 19904, '\P{cjkexta}', "");
Expect(0, 19904, '\P{^cjkexta}', "");
Expect(1, 19903, '\p{	_CJK_ext_A}', "");
Expect(0, 19903, '\p{^	_CJK_ext_A}', "");
Expect(0, 19903, '\P{	_CJK_ext_A}', "");
Expect(1, 19903, '\P{^	_CJK_ext_A}', "");
Expect(0, 19904, '\p{	_CJK_ext_A}', "");
Expect(1, 19904, '\p{^	_CJK_ext_A}', "");
Expect(1, 19904, '\P{	_CJK_ext_A}', "");
Expect(0, 19904, '\P{^	_CJK_ext_A}', "");
Error('\p{		Is_CJK_ext_a/a/}');
Error('\P{		Is_CJK_ext_a/a/}');
Expect(1, 19903, '\p{iscjkexta}', "");
Expect(0, 19903, '\p{^iscjkexta}', "");
Expect(0, 19903, '\P{iscjkexta}', "");
Expect(1, 19903, '\P{^iscjkexta}', "");
Expect(0, 19904, '\p{iscjkexta}', "");
Expect(1, 19904, '\p{^iscjkexta}', "");
Expect(1, 19904, '\P{iscjkexta}', "");
Expect(0, 19904, '\P{^iscjkexta}', "");
Expect(1, 19903, '\p{	-is_CJK_EXT_a}', "");
Expect(0, 19903, '\p{^	-is_CJK_EXT_a}', "");
Expect(0, 19903, '\P{	-is_CJK_EXT_a}', "");
Expect(1, 19903, '\P{^	-is_CJK_EXT_a}', "");
Expect(0, 19904, '\p{	-is_CJK_EXT_a}', "");
Expect(1, 19904, '\p{^	-is_CJK_EXT_a}', "");
Expect(1, 19904, '\P{	-is_CJK_EXT_a}', "");
Expect(0, 19904, '\P{^	-is_CJK_EXT_a}', "");
Error('\p{	:=in_CJK_Ext_a}');
Error('\P{	:=in_CJK_Ext_a}');
Expect(1, 19903, '\p{incjkexta}', "");
Expect(0, 19903, '\p{^incjkexta}', "");
Expect(0, 19903, '\P{incjkexta}', "");
Expect(1, 19903, '\P{^incjkexta}', "");
Expect(0, 19904, '\p{incjkexta}', "");
Expect(1, 19904, '\p{^incjkexta}', "");
Expect(1, 19904, '\P{incjkexta}', "");
Expect(0, 19904, '\P{^incjkexta}', "");
Expect(1, 19903, '\p{	in_CJK_ext_A}', "");
Expect(0, 19903, '\p{^	in_CJK_ext_A}', "");
Expect(0, 19903, '\P{	in_CJK_ext_A}', "");
Expect(1, 19903, '\P{^	in_CJK_ext_A}', "");
Expect(0, 19904, '\p{	in_CJK_ext_A}', "");
Expect(1, 19904, '\p{^	in_CJK_ext_A}', "");
Expect(1, 19904, '\P{	in_CJK_ext_A}', "");
Expect(0, 19904, '\P{^	in_CJK_ext_A}', "");
Error('\p{_	CJK_unified_IDEOGRAPHS_extension_B/a/}');
Error('\P{_	CJK_unified_IDEOGRAPHS_extension_B/a/}');
Expect(1, 173791, '\p{cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^cjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^cjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{cjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^cjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(0, 173791, '\p{^	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(0, 173791, '\P{	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(1, 173791, '\P{^	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(0, 173792, '\p{	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(1, 173792, '\p{^	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(1, 173792, '\P{	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Expect(0, 173792, '\P{^	_CJK_UNIFIED_IDEOGRAPHS_Extension_B}', "");
Error('\p{	_IS_CJK_unified_ideographs_Extension_B:=}');
Error('\P{	_IS_CJK_unified_ideographs_Extension_B:=}');
Expect(1, 173791, '\p{iscjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^iscjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{iscjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^iscjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{iscjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^iscjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{iscjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^iscjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(0, 173791, '\p{^_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(0, 173791, '\P{_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(1, 173791, '\P{^_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(0, 173792, '\p{_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(1, 173792, '\p{^_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(1, 173792, '\P{_is_CJK_Unified_Ideographs_Extension_B}', "");
Expect(0, 173792, '\P{^_is_CJK_Unified_Ideographs_Extension_B}', "");
Error('\p{/a/-_In_CJK_UNIFIED_IDEOGRAPHS_Extension_B}');
Error('\P{/a/-_In_CJK_UNIFIED_IDEOGRAPHS_Extension_B}');
Expect(1, 173791, '\p{incjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\p{^incjkunifiedideographsextensionb}', "");
Expect(0, 173791, '\P{incjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\P{^incjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\p{incjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\p{^incjkunifiedideographsextensionb}', "");
Expect(1, 173792, '\P{incjkunifiedideographsextensionb}', "");
Expect(0, 173792, '\P{^incjkunifiedideographsextensionb}', "");
Expect(1, 173791, '\p{	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(0, 173791, '\p{^	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(0, 173791, '\P{	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(1, 173791, '\P{^	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(0, 173792, '\p{	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(1, 173792, '\p{^	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(1, 173792, '\P{	_In_CJK_unified_Ideographs_Extension_B}', "");
Expect(0, 173792, '\P{^	_In_CJK_unified_Ideographs_Extension_B}', "");
Error('\p{	/a/CJK_Ext_B}');
Error('\P{	/a/CJK_Ext_B}');
Expect(1, 173791, '\p{cjkextb}', "");
Expect(0, 173791, '\p{^cjkextb}', "");
Expect(0, 173791, '\P{cjkextb}', "");
Expect(1, 173791, '\P{^cjkextb}', "");
Expect(0, 173792, '\p{cjkextb}', "");
Expect(1, 173792, '\p{^cjkextb}', "");
Expect(1, 173792, '\P{cjkextb}', "");
Expect(0, 173792, '\P{^cjkextb}', "");
Expect(1, 173791, '\p{CJK_Ext_b}', "");
Expect(0, 173791, '\p{^CJK_Ext_b}', "");
Expect(0, 173791, '\P{CJK_Ext_b}', "");
Expect(1, 173791, '\P{^CJK_Ext_b}', "");
Expect(0, 173792, '\p{CJK_Ext_b}', "");
Expect(1, 173792, '\p{^CJK_Ext_b}', "");
Expect(1, 173792, '\P{CJK_Ext_b}', "");
Expect(0, 173792, '\P{^CJK_Ext_b}', "");
Error('\p{_ IS_CJK_EXT_b/a/}');
Error('\P{_ IS_CJK_EXT_b/a/}');
Expect(1, 173791, '\p{iscjkextb}', "");
Expect(0, 173791, '\p{^iscjkextb}', "");
Expect(0, 173791, '\P{iscjkextb}', "");
Expect(1, 173791, '\P{^iscjkextb}', "");
Expect(0, 173792, '\p{iscjkextb}', "");
Expect(1, 173792, '\p{^iscjkextb}', "");
Expect(1, 173792, '\P{iscjkextb}', "");
Expect(0, 173792, '\P{^iscjkextb}', "");
Expect(1, 173791, '\p{_Is_cjk_Ext_B}', "");
Expect(0, 173791, '\p{^_Is_cjk_Ext_B}', "");
Expect(0, 173791, '\P{_Is_cjk_Ext_B}', "");
Expect(1, 173791, '\P{^_Is_cjk_Ext_B}', "");
Expect(0, 173792, '\p{_Is_cjk_Ext_B}', "");
Expect(1, 173792, '\p{^_Is_cjk_Ext_B}', "");
Expect(1, 173792, '\P{_Is_cjk_Ext_B}', "");
Expect(0, 173792, '\P{^_Is_cjk_Ext_B}', "");
Error('\p{/a/ In_cjk_ext_B}');
Error('\P{/a/ In_cjk_ext_B}');
Expect(1, 173791, '\p{incjkextb}', "");
Expect(0, 173791, '\p{^incjkextb}', "");
Expect(0, 173791, '\P{incjkextb}', "");
Expect(1, 173791, '\P{^incjkextb}', "");
Expect(0, 173792, '\p{incjkextb}', "");
Expect(1, 173792, '\p{^incjkextb}', "");
Expect(1, 173792, '\P{incjkextb}', "");
Expect(0, 173792, '\P{^incjkextb}', "");
Expect(1, 173791, '\p{IN_CJK_Ext_B}', "");
Expect(0, 173791, '\p{^IN_CJK_Ext_B}', "");
Expect(0, 173791, '\P{IN_CJK_Ext_B}', "");
Expect(1, 173791, '\P{^IN_CJK_Ext_B}', "");
Expect(0, 173792, '\p{IN_CJK_Ext_B}', "");
Expect(1, 173792, '\p{^IN_CJK_Ext_B}', "");
Expect(1, 173792, '\P{IN_CJK_Ext_B}', "");
Expect(0, 173792, '\P{^IN_CJK_Ext_B}', "");
Error('\p{CJK_Unified_Ideographs_extension_C:=}');
Error('\P{CJK_Unified_Ideographs_extension_C:=}');
Expect(1, 177983, '\p{cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^cjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^cjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{cjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^cjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(0, 177983, '\p{^ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(0, 177983, '\P{ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(1, 177983, '\P{^ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(0, 177984, '\p{ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(1, 177984, '\p{^ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(1, 177984, '\P{ 	CJK_Unified_Ideographs_extension_c}', "");
Expect(0, 177984, '\P{^ 	CJK_Unified_Ideographs_extension_c}', "");
Error('\p{	-Is_CJK_Unified_IDEOGRAPHS_Extension_C:=}');
Error('\P{	-Is_CJK_Unified_IDEOGRAPHS_Extension_C:=}');
Expect(1, 177983, '\p{iscjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^iscjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{iscjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^iscjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{iscjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^iscjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{iscjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^iscjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\p{^-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177983, '\P{-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(1, 177983, '\P{^-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\p{-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\p{^-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(1, 177984, '\P{-is_CJK_unified_Ideographs_Extension_C}', "");
Expect(0, 177984, '\P{^-is_CJK_unified_Ideographs_Extension_C}', "");
Error('\p{	/a/In_CJK_unified_ideographs_Extension_c}');
Error('\P{	/a/In_CJK_unified_ideographs_Extension_c}');
Expect(1, 177983, '\p{incjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\p{^incjkunifiedideographsextensionc}', "");
Expect(0, 177983, '\P{incjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\P{^incjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\p{incjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\p{^incjkunifiedideographsextensionc}', "");
Expect(1, 177984, '\P{incjkunifiedideographsextensionc}', "");
Expect(0, 177984, '\P{^incjkunifiedideographsextensionc}', "");
Expect(1, 177983, '\p{ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(0, 177983, '\p{^ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(0, 177983, '\P{ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(1, 177983, '\P{^ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(0, 177984, '\p{ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(1, 177984, '\p{^ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(1, 177984, '\P{ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Expect(0, 177984, '\P{^ In_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C}', "");
Error('\p{:=-CJK_Ext_C}');
Error('\P{:=-CJK_Ext_C}');
Expect(1, 177983, '\p{cjkextc}', "");
Expect(0, 177983, '\p{^cjkextc}', "");
Expect(0, 177983, '\P{cjkextc}', "");
Expect(1, 177983, '\P{^cjkextc}', "");
Expect(0, 177984, '\p{cjkextc}', "");
Expect(1, 177984, '\p{^cjkextc}', "");
Expect(1, 177984, '\P{cjkextc}', "");
Expect(0, 177984, '\P{^cjkextc}', "");
Expect(1, 177983, '\p{ cjk_Ext_C}', "");
Expect(0, 177983, '\p{^ cjk_Ext_C}', "");
Expect(0, 177983, '\P{ cjk_Ext_C}', "");
Expect(1, 177983, '\P{^ cjk_Ext_C}', "");
Expect(0, 177984, '\p{ cjk_Ext_C}', "");
Expect(1, 177984, '\p{^ cjk_Ext_C}', "");
Expect(1, 177984, '\P{ cjk_Ext_C}', "");
Expect(0, 177984, '\P{^ cjk_Ext_C}', "");
Error('\p{/a/ -is_CJK_EXT_c}');
Error('\P{/a/ -is_CJK_EXT_c}');
Expect(1, 177983, '\p{iscjkextc}', "");
Expect(0, 177983, '\p{^iscjkextc}', "");
Expect(0, 177983, '\P{iscjkextc}', "");
Expect(1, 177983, '\P{^iscjkextc}', "");
Expect(0, 177984, '\p{iscjkextc}', "");
Expect(1, 177984, '\p{^iscjkextc}', "");
Expect(1, 177984, '\P{iscjkextc}', "");
Expect(0, 177984, '\P{^iscjkextc}', "");
Expect(1, 177983, '\p{  Is_CJK_ext_c}', "");
Expect(0, 177983, '\p{^  Is_CJK_ext_c}', "");
Expect(0, 177983, '\P{  Is_CJK_ext_c}', "");
Expect(1, 177983, '\P{^  Is_CJK_ext_c}', "");
Expect(0, 177984, '\p{  Is_CJK_ext_c}', "");
Expect(1, 177984, '\p{^  Is_CJK_ext_c}', "");
Expect(1, 177984, '\P{  Is_CJK_ext_c}', "");
Expect(0, 177984, '\P{^  Is_CJK_ext_c}', "");
Error('\p{:=_-In_CJK_Ext_c}');
Error('\P{:=_-In_CJK_Ext_c}');
Expect(1, 177983, '\p{incjkextc}', "");
Expect(0, 177983, '\p{^incjkextc}', "");
Expect(0, 177983, '\P{incjkextc}', "");
Expect(1, 177983, '\P{^incjkextc}', "");
Expect(0, 177984, '\p{incjkextc}', "");
Expect(1, 177984, '\p{^incjkextc}', "");
Expect(1, 177984, '\P{incjkextc}', "");
Expect(0, 177984, '\P{^incjkextc}', "");
Expect(1, 177983, '\p{		IN_CJK_Ext_C}', "");
Expect(0, 177983, '\p{^		IN_CJK_Ext_C}', "");
Expect(0, 177983, '\P{		IN_CJK_Ext_C}', "");
Expect(1, 177983, '\P{^		IN_CJK_Ext_C}', "");
Expect(0, 177984, '\p{		IN_CJK_Ext_C}', "");
Expect(1, 177984, '\p{^		IN_CJK_Ext_C}', "");
Expect(1, 177984, '\P{		IN_CJK_Ext_C}', "");
Expect(0, 177984, '\P{^		IN_CJK_Ext_C}', "");
Error('\p{-_CJK_Unified_Ideographs_EXTENSION_D/a/}');
Error('\P{-_CJK_Unified_Ideographs_EXTENSION_D/a/}');
Expect(1, 178207, '\p{cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^cjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^cjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{cjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^cjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(0, 178207, '\p{^--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(0, 178207, '\P{--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(1, 178207, '\P{^--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(0, 178208, '\p{--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(1, 178208, '\p{^--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(1, 178208, '\P{--CJK_Unified_Ideographs_EXTENSION_d}', "");
Expect(0, 178208, '\P{^--CJK_Unified_Ideographs_EXTENSION_d}', "");
Error('\p{ /a/Is_cjk_unified_Ideographs_Extension_D}');
Error('\P{ /a/Is_cjk_unified_Ideographs_Extension_D}');
Expect(1, 178207, '\p{iscjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^iscjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{iscjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^iscjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{iscjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^iscjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{iscjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^iscjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178207, '\p{^_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178207, '\P{_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(1, 178207, '\P{^_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178208, '\p{_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(1, 178208, '\p{^_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(1, 178208, '\P{_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Expect(0, 178208, '\P{^_-Is_CJK_Unified_Ideographs_EXTENSION_D}', "");
Error('\p{_	In_CJK_unified_ideographs_EXTENSION_D/a/}');
Error('\P{_	In_CJK_unified_ideographs_EXTENSION_D/a/}');
Expect(1, 178207, '\p{incjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\p{^incjkunifiedideographsextensiond}', "");
Expect(0, 178207, '\P{incjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\P{^incjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\p{incjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\p{^incjkunifiedideographsextensiond}', "");
Expect(1, 178208, '\P{incjkunifiedideographsextensiond}', "");
Expect(0, 178208, '\P{^incjkunifiedideographsextensiond}', "");
Expect(1, 178207, '\p{-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(0, 178207, '\p{^-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(0, 178207, '\P{-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(1, 178207, '\P{^-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(0, 178208, '\p{-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(1, 178208, '\p{^-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(1, 178208, '\P{-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Expect(0, 178208, '\P{^-_in_cjk_Unified_ideographs_EXTENSION_D}', "");
Error('\p{:= CJK_Ext_d}');
Error('\P{:= CJK_Ext_d}');
Expect(1, 178207, '\p{cjkextd}', "");
Expect(0, 178207, '\p{^cjkextd}', "");
Expect(0, 178207, '\P{cjkextd}', "");
Expect(1, 178207, '\P{^cjkextd}', "");
Expect(0, 178208, '\p{cjkextd}', "");
Expect(1, 178208, '\p{^cjkextd}', "");
Expect(1, 178208, '\P{cjkextd}', "");
Expect(0, 178208, '\P{^cjkextd}', "");
Expect(1, 178207, '\p{	CJK_Ext_d}', "");
Expect(0, 178207, '\p{^	CJK_Ext_d}', "");
Expect(0, 178207, '\P{	CJK_Ext_d}', "");
Expect(1, 178207, '\P{^	CJK_Ext_d}', "");
Expect(0, 178208, '\p{	CJK_Ext_d}', "");
Expect(1, 178208, '\p{^	CJK_Ext_d}', "");
Expect(1, 178208, '\P{	CJK_Ext_d}', "");
Expect(0, 178208, '\P{^	CJK_Ext_d}', "");
Error('\p{-_IS_cjk_Ext_D/a/}');
Error('\P{-_IS_cjk_Ext_D/a/}');
Expect(1, 178207, '\p{iscjkextd}', "");
Expect(0, 178207, '\p{^iscjkextd}', "");
Expect(0, 178207, '\P{iscjkextd}', "");
Expect(1, 178207, '\P{^iscjkextd}', "");
Expect(0, 178208, '\p{iscjkextd}', "");
Expect(1, 178208, '\p{^iscjkextd}', "");
Expect(1, 178208, '\P{iscjkextd}', "");
Expect(0, 178208, '\P{^iscjkextd}', "");
Expect(1, 178207, '\p{	_is_cjk_ext_D}', "");
Expect(0, 178207, '\p{^	_is_cjk_ext_D}', "");
Expect(0, 178207, '\P{	_is_cjk_ext_D}', "");
Expect(1, 178207, '\P{^	_is_cjk_ext_D}', "");
Expect(0, 178208, '\p{	_is_cjk_ext_D}', "");
Expect(1, 178208, '\p{^	_is_cjk_ext_D}', "");
Expect(1, 178208, '\P{	_is_cjk_ext_D}', "");
Expect(0, 178208, '\P{^	_is_cjk_ext_D}', "");
Error('\p{-/a/in_CJK_EXT_D}');
Error('\P{-/a/in_CJK_EXT_D}');
Expect(1, 178207, '\p{incjkextd}', "");
Expect(0, 178207, '\p{^incjkextd}', "");
Expect(0, 178207, '\P{incjkextd}', "");
Expect(1, 178207, '\P{^incjkextd}', "");
Expect(0, 178208, '\p{incjkextd}', "");
Expect(1, 178208, '\p{^incjkextd}', "");
Expect(1, 178208, '\P{incjkextd}', "");
Expect(0, 178208, '\P{^incjkextd}', "");
Expect(1, 178207, '\p{_	in_CJK_EXT_D}', "");
Expect(0, 178207, '\p{^_	in_CJK_EXT_D}', "");
Expect(0, 178207, '\P{_	in_CJK_EXT_D}', "");
Expect(1, 178207, '\P{^_	in_CJK_EXT_D}', "");
Expect(0, 178208, '\p{_	in_CJK_EXT_D}', "");
Expect(1, 178208, '\p{^_	in_CJK_EXT_D}', "");
Expect(1, 178208, '\P{_	in_CJK_EXT_D}', "");
Expect(0, 178208, '\P{^_	in_CJK_EXT_D}', "");
Error('\p{	:=canadian_ABORIGINAL}');
Error('\P{	:=canadian_ABORIGINAL}');
Expect(1, 6389, '\p{canadianaboriginal}', "");
Expect(0, 6389, '\p{^canadianaboriginal}', "");
Expect(0, 6389, '\P{canadianaboriginal}', "");
Expect(1, 6389, '\P{^canadianaboriginal}', "");
Expect(0, 6390, '\p{canadianaboriginal}', "");
Expect(1, 6390, '\p{^canadianaboriginal}', "");
Expect(1, 6390, '\P{canadianaboriginal}', "");
Expect(0, 6390, '\P{^canadianaboriginal}', "");
Expect(1, 6389, '\p{	-Canadian_Aboriginal}', "");
Expect(0, 6389, '\p{^	-Canadian_Aboriginal}', "");
Expect(0, 6389, '\P{	-Canadian_Aboriginal}', "");
Expect(1, 6389, '\P{^	-Canadian_Aboriginal}', "");
Expect(0, 6390, '\p{	-Canadian_Aboriginal}', "");
Expect(1, 6390, '\p{^	-Canadian_Aboriginal}', "");
Expect(1, 6390, '\P{	-Canadian_Aboriginal}', "");
Expect(0, 6390, '\P{^	-Canadian_Aboriginal}', "");
Error('\p{_ IS_canadian_Aboriginal/a/}');
Error('\P{_ IS_canadian_Aboriginal/a/}');
Expect(1, 6389, '\p{iscanadianaboriginal}', "");
Expect(0, 6389, '\p{^iscanadianaboriginal}', "");
Expect(0, 6389, '\P{iscanadianaboriginal}', "");
Expect(1, 6389, '\P{^iscanadianaboriginal}', "");
Expect(0, 6390, '\p{iscanadianaboriginal}', "");
Expect(1, 6390, '\p{^iscanadianaboriginal}', "");
Expect(1, 6390, '\P{iscanadianaboriginal}', "");
Expect(0, 6390, '\P{^iscanadianaboriginal}', "");
Expect(1, 6389, '\p{	IS_CANADIAN_Aboriginal}', "");
Expect(0, 6389, '\p{^	IS_CANADIAN_Aboriginal}', "");
Expect(0, 6389, '\P{	IS_CANADIAN_Aboriginal}', "");
Expect(1, 6389, '\P{^	IS_CANADIAN_Aboriginal}', "");
Expect(0, 6390, '\p{	IS_CANADIAN_Aboriginal}', "");
Expect(1, 6390, '\p{^	IS_CANADIAN_Aboriginal}', "");
Expect(1, 6390, '\P{	IS_CANADIAN_Aboriginal}', "");
Expect(0, 6390, '\P{^	IS_CANADIAN_Aboriginal}', "");
Error('\p{ /a/Cans}');
Error('\P{ /a/Cans}');
Expect(1, 6389, '\p{cans}', "");
Expect(0, 6389, '\p{^cans}', "");
Expect(0, 6389, '\P{cans}', "");
Expect(1, 6389, '\P{^cans}', "");
Expect(0, 6390, '\p{cans}', "");
Expect(1, 6390, '\p{^cans}', "");
Expect(1, 6390, '\P{cans}', "");
Expect(0, 6390, '\P{^cans}', "");
Expect(1, 6389, '\p{	 Cans}', "");
Expect(0, 6389, '\p{^	 Cans}', "");
Expect(0, 6389, '\P{	 Cans}', "");
Expect(1, 6389, '\P{^	 Cans}', "");
Expect(0, 6390, '\p{	 Cans}', "");
Expect(1, 6390, '\p{^	 Cans}', "");
Expect(1, 6390, '\P{	 Cans}', "");
Expect(0, 6390, '\P{^	 Cans}', "");
Error('\p{	:=Is_CANS}');
Error('\P{	:=Is_CANS}');
Expect(1, 6389, '\p{iscans}', "");
Expect(0, 6389, '\p{^iscans}', "");
Expect(0, 6389, '\P{iscans}', "");
Expect(1, 6389, '\P{^iscans}', "");
Expect(0, 6390, '\p{iscans}', "");
Expect(1, 6390, '\p{^iscans}', "");
Expect(1, 6390, '\P{iscans}', "");
Expect(0, 6390, '\P{^iscans}', "");
Expect(1, 6389, '\p{-_IS_Cans}', "");
Expect(0, 6389, '\p{^-_IS_Cans}', "");
Expect(0, 6389, '\P{-_IS_Cans}', "");
Expect(1, 6389, '\P{^-_IS_Cans}', "");
Expect(0, 6390, '\p{-_IS_Cans}', "");
Expect(1, 6390, '\p{^-_IS_Cans}', "");
Expect(1, 6390, '\P{-_IS_Cans}', "");
Expect(0, 6390, '\P{^-_IS_Cans}', "");
Error('\p{-CARIAN/a/}');
Error('\P{-CARIAN/a/}');
Expect(1, 66256, '\p{carian}', "");
Expect(0, 66256, '\p{^carian}', "");
Expect(0, 66256, '\P{carian}', "");
Expect(1, 66256, '\P{^carian}', "");
Expect(0, 66257, '\p{carian}', "");
Expect(1, 66257, '\p{^carian}', "");
Expect(1, 66257, '\P{carian}', "");
Expect(0, 66257, '\P{^carian}', "");
Expect(1, 66256, '\p{_ Carian}', "");
Expect(0, 66256, '\p{^_ Carian}', "");
Expect(0, 66256, '\P{_ Carian}', "");
Expect(1, 66256, '\P{^_ Carian}', "");
Expect(0, 66257, '\p{_ Carian}', "");
Expect(1, 66257, '\p{^_ Carian}', "");
Expect(1, 66257, '\P{_ Carian}', "");
Expect(0, 66257, '\P{^_ Carian}', "");
Error('\p{/a/- Is_Carian}');
Error('\P{/a/- Is_Carian}');
Expect(1, 66256, '\p{iscarian}', "");
Expect(0, 66256, '\p{^iscarian}', "");
Expect(0, 66256, '\P{iscarian}', "");
Expect(1, 66256, '\P{^iscarian}', "");
Expect(0, 66257, '\p{iscarian}', "");
Expect(1, 66257, '\p{^iscarian}', "");
Expect(1, 66257, '\P{iscarian}', "");
Expect(0, 66257, '\P{^iscarian}', "");
Expect(1, 66256, '\p{_	IS_CARIAN}', "");
Expect(0, 66256, '\p{^_	IS_CARIAN}', "");
Expect(0, 66256, '\P{_	IS_CARIAN}', "");
Expect(1, 66256, '\P{^_	IS_CARIAN}', "");
Expect(0, 66257, '\p{_	IS_CARIAN}', "");
Expect(1, 66257, '\p{^_	IS_CARIAN}', "");
Expect(1, 66257, '\P{_	IS_CARIAN}', "");
Expect(0, 66257, '\P{^_	IS_CARIAN}', "");
Error('\p{/a/_ CARI}');
Error('\P{/a/_ CARI}');
Expect(1, 66256, '\p{cari}', "");
Expect(0, 66256, '\p{^cari}', "");
Expect(0, 66256, '\P{cari}', "");
Expect(1, 66256, '\P{^cari}', "");
Expect(0, 66257, '\p{cari}', "");
Expect(1, 66257, '\p{^cari}', "");
Expect(1, 66257, '\P{cari}', "");
Expect(0, 66257, '\P{^cari}', "");
Expect(1, 66256, '\p{ _Cari}', "");
Expect(0, 66256, '\p{^ _Cari}', "");
Expect(0, 66256, '\P{ _Cari}', "");
Expect(1, 66256, '\P{^ _Cari}', "");
Expect(0, 66257, '\p{ _Cari}', "");
Expect(1, 66257, '\p{^ _Cari}', "");
Expect(1, 66257, '\P{ _Cari}', "");
Expect(0, 66257, '\P{^ _Cari}', "");
Error('\p{_Is_Cari:=}');
Error('\P{_Is_Cari:=}');
Expect(1, 66256, '\p{iscari}', "");
Expect(0, 66256, '\p{^iscari}', "");
Expect(0, 66256, '\P{iscari}', "");
Expect(1, 66256, '\P{^iscari}', "");
Expect(0, 66257, '\p{iscari}', "");
Expect(1, 66257, '\p{^iscari}', "");
Expect(1, 66257, '\P{iscari}', "");
Expect(0, 66257, '\P{^iscari}', "");
Expect(1, 66256, '\p{ _Is_Cari}', "");
Expect(0, 66256, '\p{^ _Is_Cari}', "");
Expect(0, 66256, '\P{ _Is_Cari}', "");
Expect(1, 66256, '\P{^ _Is_Cari}', "");
Expect(0, 66257, '\p{ _Is_Cari}', "");
Expect(1, 66257, '\p{^ _Is_Cari}', "");
Expect(1, 66257, '\P{ _Is_Cari}', "");
Expect(0, 66257, '\P{^ _Is_Cari}', "");
Error('\p{--Cased/a/}');
Error('\P{--Cased/a/}');
Expect(1, 120779, '\p{cased}', "");
Expect(0, 120779, '\p{^cased}', "");
Expect(0, 120779, '\P{cased}', "");
Expect(1, 120779, '\P{^cased}', "");
Expect(0, 120780, '\p{cased}', "");
Expect(1, 120780, '\p{^cased}', "");
Expect(1, 120780, '\P{cased}', "");
Expect(0, 120780, '\P{^cased}', "");
Expect(1, 120779, '\p{ -CASED}', "");
Expect(0, 120779, '\p{^ -CASED}', "");
Expect(0, 120779, '\P{ -CASED}', "");
Expect(1, 120779, '\P{^ -CASED}', "");
Expect(0, 120780, '\p{ -CASED}', "");
Expect(1, 120780, '\p{^ -CASED}', "");
Expect(1, 120780, '\P{ -CASED}', "");
Expect(0, 120780, '\P{^ -CASED}', "");
Error('\p{-Is_Cased:=}');
Error('\P{-Is_Cased:=}');
Expect(1, 120779, '\p{iscased}', "");
Expect(0, 120779, '\p{^iscased}', "");
Expect(0, 120779, '\P{iscased}', "");
Expect(1, 120779, '\P{^iscased}', "");
Expect(0, 120780, '\p{iscased}', "");
Expect(1, 120780, '\p{^iscased}', "");
Expect(1, 120780, '\P{iscased}', "");
Expect(0, 120780, '\P{^iscased}', "");
Expect(1, 120779, '\p{	Is_cased}', "");
Expect(0, 120779, '\p{^	Is_cased}', "");
Expect(0, 120779, '\P{	Is_cased}', "");
Expect(1, 120779, '\P{^	Is_cased}', "");
Expect(0, 120780, '\p{	Is_cased}', "");
Expect(1, 120780, '\p{^	Is_cased}', "");
Expect(1, 120780, '\P{	Is_cased}', "");
Expect(0, 120780, '\P{^	Is_cased}', "");
Error('\p{:=_CASED_LETTER}');
Error('\P{:=_CASED_LETTER}');
Expect(1, 120779, '\p{casedletter}', "");
Expect(0, 120779, '\p{^casedletter}', "");
Expect(0, 120779, '\P{casedletter}', "");
Expect(1, 120779, '\P{^casedletter}', "");
Expect(0, 120780, '\p{casedletter}', "");
Expect(1, 120780, '\p{^casedletter}', "");
Expect(1, 120780, '\P{casedletter}', "");
Expect(0, 120780, '\P{^casedletter}', "");
Expect(1, 120779, '\p{	_Cased_Letter}', "");
Expect(0, 120779, '\p{^	_Cased_Letter}', "");
Expect(0, 120779, '\P{	_Cased_Letter}', "");
Expect(1, 120779, '\P{^	_Cased_Letter}', "");
Expect(0, 120780, '\p{	_Cased_Letter}', "");
Expect(1, 120780, '\p{^	_Cased_Letter}', "");
Expect(1, 120780, '\P{	_Cased_Letter}', "");
Expect(0, 120780, '\P{^	_Cased_Letter}', "");
Error('\p{_Is_Cased_Letter:=}');
Error('\P{_Is_Cased_Letter:=}');
Expect(1, 120779, '\p{iscasedletter}', "");
Expect(0, 120779, '\p{^iscasedletter}', "");
Expect(0, 120779, '\P{iscasedletter}', "");
Expect(1, 120779, '\P{^iscasedletter}', "");
Expect(0, 120780, '\p{iscasedletter}', "");
Expect(1, 120780, '\p{^iscasedletter}', "");
Expect(1, 120780, '\P{iscasedletter}', "");
Expect(0, 120780, '\P{^iscasedletter}', "");
Expect(1, 120779, '\p{	is_CASED_letter}', "");
Expect(0, 120779, '\p{^	is_CASED_letter}', "");
Expect(0, 120779, '\P{	is_CASED_letter}', "");
Expect(1, 120779, '\P{^	is_CASED_letter}', "");
Expect(0, 120780, '\p{	is_CASED_letter}', "");
Expect(1, 120780, '\p{^	is_CASED_letter}', "");
Expect(1, 120780, '\P{	is_CASED_letter}', "");
Expect(0, 120780, '\P{^	is_CASED_letter}', "");
Error('\p{-LC:=}');
Error('\P{-LC:=}');
Expect(1, 120779, '\p{lc}', "");
Expect(0, 120779, '\p{^lc}', "");
Expect(0, 120779, '\P{lc}', "");
Expect(1, 120779, '\P{^lc}', "");
Expect(0, 120780, '\p{lc}', "");
Expect(1, 120780, '\p{^lc}', "");
Expect(1, 120780, '\P{lc}', "");
Expect(0, 120780, '\P{^lc}', "");
Expect(1, 120779, '\p{ LC}', "");
Expect(0, 120779, '\p{^ LC}', "");
Expect(0, 120779, '\P{ LC}', "");
Expect(1, 120779, '\P{^ LC}', "");
Expect(0, 120780, '\p{ LC}', "");
Expect(1, 120780, '\p{^ LC}', "");
Expect(1, 120780, '\P{ LC}', "");
Expect(0, 120780, '\P{^ LC}', "");
Error('\p{_	Is_lc:=}');
Error('\P{_	Is_lc:=}');
Expect(1, 120779, '\p{islc}', "");
Expect(0, 120779, '\p{^islc}', "");
Expect(0, 120779, '\P{islc}', "");
Expect(1, 120779, '\P{^islc}', "");
Expect(0, 120780, '\p{islc}', "");
Expect(1, 120780, '\p{^islc}', "");
Expect(1, 120780, '\P{islc}', "");
Expect(0, 120780, '\P{^islc}', "");
Expect(1, 120779, '\p{	Is_LC}', "");
Expect(0, 120779, '\p{^	Is_LC}', "");
Expect(0, 120779, '\P{	Is_LC}', "");
Expect(1, 120779, '\P{^	Is_LC}', "");
Expect(0, 120780, '\p{	Is_LC}', "");
Expect(1, 120780, '\p{^	Is_LC}', "");
Expect(1, 120780, '\P{	Is_LC}', "");
Expect(0, 120780, '\P{^	Is_LC}', "");
Error('\p{ :=l_}');
Error('\P{ :=l_}');
Expect(1, 120779, '\p{l_}', "");
Expect(0, 120779, '\p{^l_}', "");
Expect(0, 120779, '\P{l_}', "");
Expect(1, 120779, '\P{^l_}', "");
Expect(0, 120780, '\p{l_}', "");
Expect(1, 120780, '\p{^l_}', "");
Expect(1, 120780, '\P{l_}', "");
Expect(0, 120780, '\P{^l_}', "");
Expect(1, 120779, '\p{		L_}', "");
Expect(0, 120779, '\p{^		L_}', "");
Expect(0, 120779, '\P{		L_}', "");
Expect(1, 120779, '\P{^		L_}', "");
Expect(0, 120780, '\p{		L_}', "");
Expect(1, 120780, '\p{^		L_}', "");
Expect(1, 120780, '\P{		L_}', "");
Expect(0, 120780, '\P{^		L_}', "");
Error('\p{ /a/IS_L_}');
Error('\P{ /a/IS_L_}');
Expect(1, 120779, '\p{isl_}', "");
Expect(0, 120779, '\p{^isl_}', "");
Expect(0, 120779, '\P{isl_}', "");
Expect(1, 120779, '\P{^isl_}', "");
Expect(0, 120780, '\p{isl_}', "");
Expect(1, 120780, '\p{^isl_}', "");
Expect(1, 120780, '\P{isl_}', "");
Expect(0, 120780, '\P{^isl_}', "");
Expect(1, 120779, '\p{--Is_L_}', "");
Expect(0, 120779, '\p{^--Is_L_}', "");
Expect(0, 120779, '\P{--Is_L_}', "");
Expect(1, 120779, '\P{^--Is_L_}', "");
Expect(0, 120780, '\p{--Is_L_}', "");
Expect(1, 120780, '\p{^--Is_L_}', "");
Expect(1, 120780, '\P{--Is_L_}', "");
Expect(0, 120780, '\P{^--Is_L_}', "");
Error('\p{-:=l&}');
Error('\P{-:=l&}');
Expect(1, 120779, '\p{l&}', "");
Expect(0, 120779, '\p{^l&}', "");
Expect(0, 120779, '\P{l&}', "");
Expect(1, 120779, '\P{^l&}', "");
Expect(0, 120780, '\p{l&}', "");
Expect(1, 120780, '\p{^l&}', "");
Expect(1, 120780, '\P{l&}', "");
Expect(0, 120780, '\P{^l&}', "");
Expect(1, 120779, '\p{ -L&}', "");
Expect(0, 120779, '\p{^ -L&}', "");
Expect(0, 120779, '\P{ -L&}', "");
Expect(1, 120779, '\P{^ -L&}', "");
Expect(0, 120780, '\p{ -L&}', "");
Expect(1, 120780, '\p{^ -L&}', "");
Expect(1, 120780, '\P{ -L&}', "");
Expect(0, 120780, '\P{^ -L&}', "");
Error('\p{:=IS_L&}');
Error('\P{:=IS_L&}');
Expect(1, 120779, '\p{isl&}', "");
Expect(0, 120779, '\p{^isl&}', "");
Expect(0, 120779, '\P{isl&}', "");
Expect(1, 120779, '\P{^isl&}', "");
Expect(0, 120780, '\p{isl&}', "");
Expect(1, 120780, '\p{^isl&}', "");
Expect(1, 120780, '\P{isl&}', "");
Expect(0, 120780, '\P{^isl&}', "");
Expect(1, 120779, '\p{ 	Is_l&}', "");
Expect(0, 120779, '\p{^ 	Is_l&}', "");
Expect(0, 120779, '\P{ 	Is_l&}', "");
Expect(1, 120779, '\P{^ 	Is_l&}', "");
Expect(0, 120780, '\p{ 	Is_l&}', "");
Expect(1, 120780, '\p{^ 	Is_l&}', "");
Expect(1, 120780, '\P{ 	Is_l&}', "");
Expect(0, 120780, '\P{^ 	Is_l&}', "");
Error('\p{:=-CHAKMA}');
Error('\P{:=-CHAKMA}');
Expect(1, 69955, '\p{chakma}', "");
Expect(0, 69955, '\p{^chakma}', "");
Expect(0, 69955, '\P{chakma}', "");
Expect(1, 69955, '\P{^chakma}', "");
Expect(0, 69956, '\p{chakma}', "");
Expect(1, 69956, '\p{^chakma}', "");
Expect(1, 69956, '\P{chakma}', "");
Expect(0, 69956, '\P{^chakma}', "");
Error('\p{/a/	_Is_Chakma}');
Error('\P{/a/	_Is_Chakma}');
Expect(1, 69955, '\p{ischakma}', "");
Expect(0, 69955, '\p{^ischakma}', "");
Expect(0, 69955, '\P{ischakma}', "");
Expect(1, 69955, '\P{^ischakma}', "");
Expect(0, 69956, '\p{ischakma}', "");
Expect(1, 69956, '\p{^ischakma}', "");
Expect(1, 69956, '\P{ischakma}', "");
Expect(0, 69956, '\P{^ischakma}', "");
Expect(1, 69955, '\p{	-Is_Chakma}', "");
Expect(0, 69955, '\p{^	-Is_Chakma}', "");
Expect(0, 69955, '\P{	-Is_Chakma}', "");
Expect(1, 69955, '\P{^	-Is_Chakma}', "");
Expect(0, 69956, '\p{	-Is_Chakma}', "");
Expect(1, 69956, '\p{^	-Is_Chakma}', "");
Expect(1, 69956, '\P{	-Is_Chakma}', "");
Expect(0, 69956, '\P{^	-Is_Chakma}', "");
Error('\p{ Cakm/a/}');
Error('\P{ Cakm/a/}');
Expect(1, 69955, '\p{cakm}', "");
Expect(0, 69955, '\p{^cakm}', "");
Expect(0, 69955, '\P{cakm}', "");
Expect(1, 69955, '\P{^cakm}', "");
Expect(0, 69956, '\p{cakm}', "");
Expect(1, 69956, '\p{^cakm}', "");
Expect(1, 69956, '\P{cakm}', "");
Expect(0, 69956, '\P{^cakm}', "");
Expect(1, 69955, '\p{_CAKM}', "");
Expect(0, 69955, '\p{^_CAKM}', "");
Expect(0, 69955, '\P{_CAKM}', "");
Expect(1, 69955, '\P{^_CAKM}', "");
Expect(0, 69956, '\p{_CAKM}', "");
Expect(1, 69956, '\p{^_CAKM}', "");
Expect(1, 69956, '\P{_CAKM}', "");
Expect(0, 69956, '\P{^_CAKM}', "");
Error('\p{- IS_Cakm:=}');
Error('\P{- IS_Cakm:=}');
Expect(1, 69955, '\p{iscakm}', "");
Expect(0, 69955, '\p{^iscakm}', "");
Expect(0, 69955, '\P{iscakm}', "");
Expect(1, 69955, '\P{^iscakm}', "");
Expect(0, 69956, '\p{iscakm}', "");
Expect(1, 69956, '\p{^iscakm}', "");
Expect(1, 69956, '\P{iscakm}', "");
Expect(0, 69956, '\P{^iscakm}', "");
Expect(1, 69955, '\p{	is_cakm}', "");
Expect(0, 69955, '\p{^	is_cakm}', "");
Expect(0, 69955, '\P{	is_cakm}', "");
Expect(1, 69955, '\P{^	is_cakm}', "");
Expect(0, 69956, '\p{	is_cakm}', "");
Expect(1, 69956, '\p{^	is_cakm}', "");
Expect(1, 69956, '\P{	is_cakm}', "");
Expect(0, 69956, '\P{^	is_cakm}', "");
Error('\p{/a/Cham}');
Error('\P{/a/Cham}');
Expect(1, 43615, '\p{cham}', "");
Expect(0, 43615, '\p{^cham}', "");
Expect(0, 43615, '\P{cham}', "");
Expect(1, 43615, '\P{^cham}', "");
Expect(0, 43616, '\p{cham}', "");
Expect(1, 43616, '\p{^cham}', "");
Expect(1, 43616, '\P{cham}', "");
Expect(0, 43616, '\P{^cham}', "");
Expect(1, 43615, '\p{_	cham}', "");
Expect(0, 43615, '\p{^_	cham}', "");
Expect(0, 43615, '\P{_	cham}', "");
Expect(1, 43615, '\P{^_	cham}', "");
Expect(0, 43616, '\p{_	cham}', "");
Expect(1, 43616, '\p{^_	cham}', "");
Expect(1, 43616, '\P{_	cham}', "");
Expect(0, 43616, '\P{^_	cham}', "");
Error('\p{/a/	_Is_CHAM}');
Error('\P{/a/	_Is_CHAM}');
Expect(1, 43615, '\p{ischam}', "");
Expect(0, 43615, '\p{^ischam}', "");
Expect(0, 43615, '\P{ischam}', "");
Expect(1, 43615, '\P{^ischam}', "");
Expect(0, 43616, '\p{ischam}', "");
Expect(1, 43616, '\p{^ischam}', "");
Expect(1, 43616, '\P{ischam}', "");
Expect(0, 43616, '\P{^ischam}', "");
Expect(1, 43615, '\p{-_Is_Cham}', "");
Expect(0, 43615, '\p{^-_Is_Cham}', "");
Expect(0, 43615, '\P{-_Is_Cham}', "");
Expect(1, 43615, '\P{^-_Is_Cham}', "");
Expect(0, 43616, '\p{-_Is_Cham}', "");
Expect(1, 43616, '\p{^-_Is_Cham}', "");
Expect(1, 43616, '\P{-_Is_Cham}', "");
Expect(0, 43616, '\P{^-_Is_Cham}', "");
Error('\p{__changes_When_Casefolded/a/}');
Error('\P{__changes_When_Casefolded/a/}');
Expect(1, 66599, '\p{changeswhencasefolded}', "");
Expect(0, 66599, '\p{^changeswhencasefolded}', "");
Expect(0, 66599, '\P{changeswhencasefolded}', "");
Expect(1, 66599, '\P{^changeswhencasefolded}', "");
Expect(0, 66600, '\p{changeswhencasefolded}', "");
Expect(1, 66600, '\p{^changeswhencasefolded}', "");
Expect(1, 66600, '\P{changeswhencasefolded}', "");
Expect(0, 66600, '\P{^changeswhencasefolded}', "");
Expect(1, 66599, '\p{ changes_When_casefolded}', "");
Expect(0, 66599, '\p{^ changes_When_casefolded}', "");
Expect(0, 66599, '\P{ changes_When_casefolded}', "");
Expect(1, 66599, '\P{^ changes_When_casefolded}', "");
Expect(0, 66600, '\p{ changes_When_casefolded}', "");
Expect(1, 66600, '\p{^ changes_When_casefolded}', "");
Expect(1, 66600, '\P{ changes_When_casefolded}', "");
Expect(0, 66600, '\P{^ changes_When_casefolded}', "");
Error('\p{_ Is_Changes_WHEN_CASEFOLDED/a/}');
Error('\P{_ Is_Changes_WHEN_CASEFOLDED/a/}');
Expect(1, 66599, '\p{ischangeswhencasefolded}', "");
Expect(0, 66599, '\p{^ischangeswhencasefolded}', "");
Expect(0, 66599, '\P{ischangeswhencasefolded}', "");
Expect(1, 66599, '\P{^ischangeswhencasefolded}', "");
Expect(0, 66600, '\p{ischangeswhencasefolded}', "");
Expect(1, 66600, '\p{^ischangeswhencasefolded}', "");
Expect(1, 66600, '\P{ischangeswhencasefolded}', "");
Expect(0, 66600, '\P{^ischangeswhencasefolded}', "");
Expect(1, 66599, '\p{-IS_CHANGES_when_CASEFOLDED}', "");
Expect(0, 66599, '\p{^-IS_CHANGES_when_CASEFOLDED}', "");
Expect(0, 66599, '\P{-IS_CHANGES_when_CASEFOLDED}', "");
Expect(1, 66599, '\P{^-IS_CHANGES_when_CASEFOLDED}', "");
Expect(0, 66600, '\p{-IS_CHANGES_when_CASEFOLDED}', "");
Expect(1, 66600, '\p{^-IS_CHANGES_when_CASEFOLDED}', "");
Expect(1, 66600, '\P{-IS_CHANGES_when_CASEFOLDED}', "");
Expect(0, 66600, '\P{^-IS_CHANGES_when_CASEFOLDED}', "");
Error('\p{:=-_cwcf}');
Error('\P{:=-_cwcf}');
Expect(1, 66599, '\p{cwcf}', "");
Expect(0, 66599, '\p{^cwcf}', "");
Expect(0, 66599, '\P{cwcf}', "");
Expect(1, 66599, '\P{^cwcf}', "");
Expect(0, 66600, '\p{cwcf}', "");
Expect(1, 66600, '\p{^cwcf}', "");
Expect(1, 66600, '\P{cwcf}', "");
Expect(0, 66600, '\P{^cwcf}', "");
Expect(1, 66599, '\p{CWCF}', "");
Expect(0, 66599, '\p{^CWCF}', "");
Expect(0, 66599, '\P{CWCF}', "");
Expect(1, 66599, '\P{^CWCF}', "");
Expect(0, 66600, '\p{CWCF}', "");
Expect(1, 66600, '\p{^CWCF}', "");
Expect(1, 66600, '\P{CWCF}', "");
Expect(0, 66600, '\P{^CWCF}', "");
Error('\p{ 	Is_CWCF:=}');
Error('\P{ 	Is_CWCF:=}');
Expect(1, 66599, '\p{iscwcf}', "");
Expect(0, 66599, '\p{^iscwcf}', "");
Expect(0, 66599, '\P{iscwcf}', "");
Expect(1, 66599, '\P{^iscwcf}', "");
Expect(0, 66600, '\p{iscwcf}', "");
Expect(1, 66600, '\p{^iscwcf}', "");
Expect(1, 66600, '\P{iscwcf}', "");
Expect(0, 66600, '\P{^iscwcf}', "");
Expect(1, 66599, '\p{_ is_cwcf}', "");
Expect(0, 66599, '\p{^_ is_cwcf}', "");
Expect(0, 66599, '\P{_ is_cwcf}', "");
Expect(1, 66599, '\P{^_ is_cwcf}', "");
Expect(0, 66600, '\p{_ is_cwcf}', "");
Expect(1, 66600, '\p{^_ is_cwcf}', "");
Expect(1, 66600, '\P{_ is_cwcf}', "");
Expect(0, 66600, '\P{^_ is_cwcf}', "");
Error('\p{:=	 Changes_when_Casemapped}');
Error('\P{:=	 Changes_when_Casemapped}');
Expect(1, 66639, '\p{changeswhencasemapped}', "");
Expect(0, 66639, '\p{^changeswhencasemapped}', "");
Expect(0, 66639, '\P{changeswhencasemapped}', "");
Expect(1, 66639, '\P{^changeswhencasemapped}', "");
Expect(0, 66640, '\p{changeswhencasemapped}', "");
Expect(1, 66640, '\p{^changeswhencasemapped}', "");
Expect(1, 66640, '\P{changeswhencasemapped}', "");
Expect(0, 66640, '\P{^changeswhencasemapped}', "");
Expect(1, 66639, '\p{_Changes_when_casemapped}', "");
Expect(0, 66639, '\p{^_Changes_when_casemapped}', "");
Expect(0, 66639, '\P{_Changes_when_casemapped}', "");
Expect(1, 66639, '\P{^_Changes_when_casemapped}', "");
Expect(0, 66640, '\p{_Changes_when_casemapped}', "");
Expect(1, 66640, '\p{^_Changes_when_casemapped}', "");
Expect(1, 66640, '\P{_Changes_when_casemapped}', "");
Expect(0, 66640, '\P{^_Changes_when_casemapped}', "");
Error('\p{_/a/is_changes_When_Casemapped}');
Error('\P{_/a/is_changes_When_Casemapped}');
Expect(1, 66639, '\p{ischangeswhencasemapped}', "");
Expect(0, 66639, '\p{^ischangeswhencasemapped}', "");
Expect(0, 66639, '\P{ischangeswhencasemapped}', "");
Expect(1, 66639, '\P{^ischangeswhencasemapped}', "");
Expect(0, 66640, '\p{ischangeswhencasemapped}', "");
Expect(1, 66640, '\p{^ischangeswhencasemapped}', "");
Expect(1, 66640, '\P{ischangeswhencasemapped}', "");
Expect(0, 66640, '\P{^ischangeswhencasemapped}', "");
Expect(1, 66639, '\p{		Is_CHANGES_When_CASEMAPPED}', "");
Expect(0, 66639, '\p{^		Is_CHANGES_When_CASEMAPPED}', "");
Expect(0, 66639, '\P{		Is_CHANGES_When_CASEMAPPED}', "");
Expect(1, 66639, '\P{^		Is_CHANGES_When_CASEMAPPED}', "");
Expect(0, 66640, '\p{		Is_CHANGES_When_CASEMAPPED}', "");
Expect(1, 66640, '\p{^		Is_CHANGES_When_CASEMAPPED}', "");
Expect(1, 66640, '\P{		Is_CHANGES_When_CASEMAPPED}', "");
Expect(0, 66640, '\P{^		Is_CHANGES_When_CASEMAPPED}', "");
Error('\p{_ cwcm:=}');
Error('\P{_ cwcm:=}');
Expect(1, 66639, '\p{cwcm}', "");
Expect(0, 66639, '\p{^cwcm}', "");
Expect(0, 66639, '\P{cwcm}', "");
Expect(1, 66639, '\P{^cwcm}', "");
Expect(0, 66640, '\p{cwcm}', "");
Expect(1, 66640, '\p{^cwcm}', "");
Expect(1, 66640, '\P{cwcm}', "");
Expect(0, 66640, '\P{^cwcm}', "");
Expect(1, 66639, '\p{  cwcm}', "");
Expect(0, 66639, '\p{^  cwcm}', "");
Expect(0, 66639, '\P{  cwcm}', "");
Expect(1, 66639, '\P{^  cwcm}', "");
Expect(0, 66640, '\p{  cwcm}', "");
Expect(1, 66640, '\p{^  cwcm}', "");
Expect(1, 66640, '\P{  cwcm}', "");
Expect(0, 66640, '\P{^  cwcm}', "");
Error('\p{:=_	Is_CWCM}');
Error('\P{:=_	Is_CWCM}');
Expect(1, 66639, '\p{iscwcm}', "");
Expect(0, 66639, '\p{^iscwcm}', "");
Expect(0, 66639, '\P{iscwcm}', "");
Expect(1, 66639, '\P{^iscwcm}', "");
Expect(0, 66640, '\p{iscwcm}', "");
Expect(1, 66640, '\p{^iscwcm}', "");
Expect(1, 66640, '\P{iscwcm}', "");
Expect(0, 66640, '\P{^iscwcm}', "");
Expect(1, 66639, '\p{ is_CWCM}', "");
Expect(0, 66639, '\p{^ is_CWCM}', "");
Expect(0, 66639, '\P{ is_CWCM}', "");
Expect(1, 66639, '\P{^ is_CWCM}', "");
Expect(0, 66640, '\p{ is_CWCM}', "");
Expect(1, 66640, '\p{^ is_CWCM}', "");
Expect(1, 66640, '\P{ is_CWCM}', "");
Expect(0, 66640, '\P{^ is_CWCM}', "");
Error('\p{:=Changes_WHEN_lowercased}');
Error('\P{:=Changes_WHEN_lowercased}');
Expect(1, 66599, '\p{changeswhenlowercased}', "");
Expect(0, 66599, '\p{^changeswhenlowercased}', "");
Expect(0, 66599, '\P{changeswhenlowercased}', "");
Expect(1, 66599, '\P{^changeswhenlowercased}', "");
Expect(0, 66600, '\p{changeswhenlowercased}', "");
Expect(1, 66600, '\p{^changeswhenlowercased}', "");
Expect(1, 66600, '\P{changeswhenlowercased}', "");
Expect(0, 66600, '\P{^changeswhenlowercased}', "");
Expect(1, 66599, '\p{-_Changes_When_Lowercased}', "");
Expect(0, 66599, '\p{^-_Changes_When_Lowercased}', "");
Expect(0, 66599, '\P{-_Changes_When_Lowercased}', "");
Expect(1, 66599, '\P{^-_Changes_When_Lowercased}', "");
Expect(0, 66600, '\p{-_Changes_When_Lowercased}', "");
Expect(1, 66600, '\p{^-_Changes_When_Lowercased}', "");
Expect(1, 66600, '\P{-_Changes_When_Lowercased}', "");
Expect(0, 66600, '\P{^-_Changes_When_Lowercased}', "");
Error('\p{ :=Is_Changes_When_lowercased}');
Error('\P{ :=Is_Changes_When_lowercased}');
Expect(1, 66599, '\p{ischangeswhenlowercased}', "");
Expect(0, 66599, '\p{^ischangeswhenlowercased}', "");
Expect(0, 66599, '\P{ischangeswhenlowercased}', "");
Expect(1, 66599, '\P{^ischangeswhenlowercased}', "");
Expect(0, 66600, '\p{ischangeswhenlowercased}', "");
Expect(1, 66600, '\p{^ischangeswhenlowercased}', "");
Expect(1, 66600, '\P{ischangeswhenlowercased}', "");
Expect(0, 66600, '\P{^ischangeswhenlowercased}', "");
Expect(1, 66599, '\p{_	IS_changes_when_lowercased}', "");
Expect(0, 66599, '\p{^_	IS_changes_when_lowercased}', "");
Expect(0, 66599, '\P{_	IS_changes_when_lowercased}', "");
Expect(1, 66599, '\P{^_	IS_changes_when_lowercased}', "");
Expect(0, 66600, '\p{_	IS_changes_when_lowercased}', "");
Expect(1, 66600, '\p{^_	IS_changes_when_lowercased}', "");
Expect(1, 66600, '\P{_	IS_changes_when_lowercased}', "");
Expect(0, 66600, '\P{^_	IS_changes_when_lowercased}', "");
Error('\p{	 CWL:=}');
Error('\P{	 CWL:=}');
Expect(1, 66599, '\p{cwl}', "");
Expect(0, 66599, '\p{^cwl}', "");
Expect(0, 66599, '\P{cwl}', "");
Expect(1, 66599, '\P{^cwl}', "");
Expect(0, 66600, '\p{cwl}', "");
Expect(1, 66600, '\p{^cwl}', "");
Expect(1, 66600, '\P{cwl}', "");
Expect(0, 66600, '\P{^cwl}', "");
Expect(1, 66599, '\p{	-CWL}', "");
Expect(0, 66599, '\p{^	-CWL}', "");
Expect(0, 66599, '\P{	-CWL}', "");
Expect(1, 66599, '\P{^	-CWL}', "");
Expect(0, 66600, '\p{	-CWL}', "");
Expect(1, 66600, '\p{^	-CWL}', "");
Expect(1, 66600, '\P{	-CWL}', "");
Expect(0, 66600, '\P{^	-CWL}', "");
Error('\p{  IS_CWL/a/}');
Error('\P{  IS_CWL/a/}');
Expect(1, 66599, '\p{iscwl}', "");
Expect(0, 66599, '\p{^iscwl}', "");
Expect(0, 66599, '\P{iscwl}', "");
Expect(1, 66599, '\P{^iscwl}', "");
Expect(0, 66600, '\p{iscwl}', "");
Expect(1, 66600, '\p{^iscwl}', "");
Expect(1, 66600, '\P{iscwl}', "");
Expect(0, 66600, '\P{^iscwl}', "");
Expect(1, 66599, '\p{_	Is_CWL}', "");
Expect(0, 66599, '\p{^_	Is_CWL}', "");
Expect(0, 66599, '\P{_	Is_CWL}', "");
Expect(1, 66599, '\P{^_	Is_CWL}', "");
Expect(0, 66600, '\p{_	Is_CWL}', "");
Expect(1, 66600, '\p{^_	Is_CWL}', "");
Expect(1, 66600, '\P{_	Is_CWL}', "");
Expect(0, 66600, '\P{^_	Is_CWL}', "");
Error('\p{/a/Changes_WHEN_NFKC_CASEFOLDED}');
Error('\P{/a/Changes_WHEN_NFKC_CASEFOLDED}');
Expect(1, 921599, '\p{changeswhennfkccasefolded}', "");
Expect(0, 921599, '\p{^changeswhennfkccasefolded}', "");
Expect(0, 921599, '\P{changeswhennfkccasefolded}', "");
Expect(1, 921599, '\P{^changeswhennfkccasefolded}', "");
Expect(0, 921600, '\p{changeswhennfkccasefolded}', "");
Expect(1, 921600, '\p{^changeswhennfkccasefolded}', "");
Expect(1, 921600, '\P{changeswhennfkccasefolded}', "");
Expect(0, 921600, '\P{^changeswhennfkccasefolded}', "");
Expect(1, 921599, '\p{	 Changes_When_nfkc_Casefolded}', "");
Expect(0, 921599, '\p{^	 Changes_When_nfkc_Casefolded}', "");
Expect(0, 921599, '\P{	 Changes_When_nfkc_Casefolded}', "");
Expect(1, 921599, '\P{^	 Changes_When_nfkc_Casefolded}', "");
Expect(0, 921600, '\p{	 Changes_When_nfkc_Casefolded}', "");
Expect(1, 921600, '\p{^	 Changes_When_nfkc_Casefolded}', "");
Expect(1, 921600, '\P{	 Changes_When_nfkc_Casefolded}', "");
Expect(0, 921600, '\P{^	 Changes_When_nfkc_Casefolded}', "");
Error('\p{	_is_Changes_When_NFKC_CASEFOLDED:=}');
Error('\P{	_is_Changes_When_NFKC_CASEFOLDED:=}');
Expect(1, 921599, '\p{ischangeswhennfkccasefolded}', "");
Expect(0, 921599, '\p{^ischangeswhennfkccasefolded}', "");
Expect(0, 921599, '\P{ischangeswhennfkccasefolded}', "");
Expect(1, 921599, '\P{^ischangeswhennfkccasefolded}', "");
Expect(0, 921600, '\p{ischangeswhennfkccasefolded}', "");
Expect(1, 921600, '\p{^ischangeswhennfkccasefolded}', "");
Expect(1, 921600, '\P{ischangeswhennfkccasefolded}', "");
Expect(0, 921600, '\P{^ischangeswhennfkccasefolded}', "");
Expect(1, 921599, '\p{_is_changes_when_NFKC_Casefolded}', "");
Expect(0, 921599, '\p{^_is_changes_when_NFKC_Casefolded}', "");
Expect(0, 921599, '\P{_is_changes_when_NFKC_Casefolded}', "");
Expect(1, 921599, '\P{^_is_changes_when_NFKC_Casefolded}', "");
Expect(0, 921600, '\p{_is_changes_when_NFKC_Casefolded}', "");
Expect(1, 921600, '\p{^_is_changes_when_NFKC_Casefolded}', "");
Expect(1, 921600, '\P{_is_changes_when_NFKC_Casefolded}', "");
Expect(0, 921600, '\P{^_is_changes_when_NFKC_Casefolded}', "");
Error('\p{ 	CWKCF:=}');
Error('\P{ 	CWKCF:=}');
Expect(1, 921599, '\p{cwkcf}', "");
Expect(0, 921599, '\p{^cwkcf}', "");
Expect(0, 921599, '\P{cwkcf}', "");
Expect(1, 921599, '\P{^cwkcf}', "");
Expect(0, 921600, '\p{cwkcf}', "");
Expect(1, 921600, '\p{^cwkcf}', "");
Expect(1, 921600, '\P{cwkcf}', "");
Expect(0, 921600, '\P{^cwkcf}', "");
Expect(1, 921599, '\p{-	CWKCF}', "");
Expect(0, 921599, '\p{^-	CWKCF}', "");
Expect(0, 921599, '\P{-	CWKCF}', "");
Expect(1, 921599, '\P{^-	CWKCF}', "");
Expect(0, 921600, '\p{-	CWKCF}', "");
Expect(1, 921600, '\p{^-	CWKCF}', "");
Expect(1, 921600, '\P{-	CWKCF}', "");
Expect(0, 921600, '\P{^-	CWKCF}', "");
Error('\p{:= _Is_cwkcf}');
Error('\P{:= _Is_cwkcf}');
Expect(1, 921599, '\p{iscwkcf}', "");
Expect(0, 921599, '\p{^iscwkcf}', "");
Expect(0, 921599, '\P{iscwkcf}', "");
Expect(1, 921599, '\P{^iscwkcf}', "");
Expect(0, 921600, '\p{iscwkcf}', "");
Expect(1, 921600, '\p{^iscwkcf}', "");
Expect(1, 921600, '\P{iscwkcf}', "");
Expect(0, 921600, '\P{^iscwkcf}', "");
Expect(1, 921599, '\p{- is_CWKCF}', "");
Expect(0, 921599, '\p{^- is_CWKCF}', "");
Expect(0, 921599, '\P{- is_CWKCF}', "");
Expect(1, 921599, '\P{^- is_CWKCF}', "");
Expect(0, 921600, '\p{- is_CWKCF}', "");
Expect(1, 921600, '\p{^- is_CWKCF}', "");
Expect(1, 921600, '\P{- is_CWKCF}', "");
Expect(0, 921600, '\P{^- is_CWKCF}', "");
Error('\p{-/a/Changes_When_Titlecased}');
Error('\P{-/a/Changes_When_Titlecased}');
Expect(1, 66639, '\p{changeswhentitlecased}', "");
Expect(0, 66639, '\p{^changeswhentitlecased}', "");
Expect(0, 66639, '\P{changeswhentitlecased}', "");
Expect(1, 66639, '\P{^changeswhentitlecased}', "");
Expect(0, 66640, '\p{changeswhentitlecased}', "");
Expect(1, 66640, '\p{^changeswhentitlecased}', "");
Expect(1, 66640, '\P{changeswhentitlecased}', "");
Expect(0, 66640, '\P{^changeswhentitlecased}', "");
Expect(1, 66639, '\p{_ Changes_When_TITLECASED}', "");
Expect(0, 66639, '\p{^_ Changes_When_TITLECASED}', "");
Expect(0, 66639, '\P{_ Changes_When_TITLECASED}', "");
Expect(1, 66639, '\P{^_ Changes_When_TITLECASED}', "");
Expect(0, 66640, '\p{_ Changes_When_TITLECASED}', "");
Expect(1, 66640, '\p{^_ Changes_When_TITLECASED}', "");
Expect(1, 66640, '\P{_ Changes_When_TITLECASED}', "");
Expect(0, 66640, '\P{^_ Changes_When_TITLECASED}', "");
Error('\p{__Is_changes_When_TITLECASED:=}');
Error('\P{__Is_changes_When_TITLECASED:=}');
Expect(1, 66639, '\p{ischangeswhentitlecased}', "");
Expect(0, 66639, '\p{^ischangeswhentitlecased}', "");
Expect(0, 66639, '\P{ischangeswhentitlecased}', "");
Expect(1, 66639, '\P{^ischangeswhentitlecased}', "");
Expect(0, 66640, '\p{ischangeswhentitlecased}', "");
Expect(1, 66640, '\p{^ischangeswhentitlecased}', "");
Expect(1, 66640, '\P{ischangeswhentitlecased}', "");
Expect(0, 66640, '\P{^ischangeswhentitlecased}', "");
Expect(1, 66639, '\p{-_is_Changes_when_Titlecased}', "");
Expect(0, 66639, '\p{^-_is_Changes_when_Titlecased}', "");
Expect(0, 66639, '\P{-_is_Changes_when_Titlecased}', "");
Expect(1, 66639, '\P{^-_is_Changes_when_Titlecased}', "");
Expect(0, 66640, '\p{-_is_Changes_when_Titlecased}', "");
Expect(1, 66640, '\p{^-_is_Changes_when_Titlecased}', "");
Expect(1, 66640, '\P{-_is_Changes_when_Titlecased}', "");
Expect(0, 66640, '\P{^-_is_Changes_when_Titlecased}', "");
Error('\p{	:=CWT}');
Error('\P{	:=CWT}');
Expect(1, 66639, '\p{cwt}', "");
Expect(0, 66639, '\p{^cwt}', "");
Expect(0, 66639, '\P{cwt}', "");
Expect(1, 66639, '\P{^cwt}', "");
Expect(0, 66640, '\p{cwt}', "");
Expect(1, 66640, '\p{^cwt}', "");
Expect(1, 66640, '\P{cwt}', "");
Expect(0, 66640, '\P{^cwt}', "");
Expect(1, 66639, '\p{	CWT}', "");
Expect(0, 66639, '\p{^	CWT}', "");
Expect(0, 66639, '\P{	CWT}', "");
Expect(1, 66639, '\P{^	CWT}', "");
Expect(0, 66640, '\p{	CWT}', "");
Expect(1, 66640, '\p{^	CWT}', "");
Expect(1, 66640, '\P{	CWT}', "");
Expect(0, 66640, '\P{^	CWT}', "");
Error('\p{:= IS_CWT}');
Error('\P{:= IS_CWT}');
Expect(1, 66639, '\p{iscwt}', "");
Expect(0, 66639, '\p{^iscwt}', "");
Expect(0, 66639, '\P{iscwt}', "");
Expect(1, 66639, '\P{^iscwt}', "");
Expect(0, 66640, '\p{iscwt}', "");
Expect(1, 66640, '\p{^iscwt}', "");
Expect(1, 66640, '\P{iscwt}', "");
Expect(0, 66640, '\P{^iscwt}', "");
Expect(1, 66639, '\p{-Is_cwt}', "");
Expect(0, 66639, '\p{^-Is_cwt}', "");
Expect(0, 66639, '\P{-Is_cwt}', "");
Expect(1, 66639, '\P{^-Is_cwt}', "");
Expect(0, 66640, '\p{-Is_cwt}', "");
Expect(1, 66640, '\p{^-Is_cwt}', "");
Expect(1, 66640, '\P{-Is_cwt}', "");
Expect(0, 66640, '\P{^-Is_cwt}', "");
Error('\p{_	changes_When_uppercased:=}');
Error('\P{_	changes_When_uppercased:=}');
Expect(1, 66639, '\p{changeswhenuppercased}', "");
Expect(0, 66639, '\p{^changeswhenuppercased}', "");
Expect(0, 66639, '\P{changeswhenuppercased}', "");
Expect(1, 66639, '\P{^changeswhenuppercased}', "");
Expect(0, 66640, '\p{changeswhenuppercased}', "");
Expect(1, 66640, '\p{^changeswhenuppercased}', "");
Expect(1, 66640, '\P{changeswhenuppercased}', "");
Expect(0, 66640, '\P{^changeswhenuppercased}', "");
Expect(1, 66639, '\p{_-changes_WHEN_uppercased}', "");
Expect(0, 66639, '\p{^_-changes_WHEN_uppercased}', "");
Expect(0, 66639, '\P{_-changes_WHEN_uppercased}', "");
Expect(1, 66639, '\P{^_-changes_WHEN_uppercased}', "");
Expect(0, 66640, '\p{_-changes_WHEN_uppercased}', "");
Expect(1, 66640, '\p{^_-changes_WHEN_uppercased}', "");
Expect(1, 66640, '\P{_-changes_WHEN_uppercased}', "");
Expect(0, 66640, '\P{^_-changes_WHEN_uppercased}', "");
Error('\p{/a/ 	is_Changes_when_Uppercased}');
Error('\P{/a/ 	is_Changes_when_Uppercased}');
Expect(1, 66639, '\p{ischangeswhenuppercased}', "");
Expect(0, 66639, '\p{^ischangeswhenuppercased}', "");
Expect(0, 66639, '\P{ischangeswhenuppercased}', "");
Expect(1, 66639, '\P{^ischangeswhenuppercased}', "");
Expect(0, 66640, '\p{ischangeswhenuppercased}', "");
Expect(1, 66640, '\p{^ischangeswhenuppercased}', "");
Expect(1, 66640, '\P{ischangeswhenuppercased}', "");
Expect(0, 66640, '\P{^ischangeswhenuppercased}', "");
Expect(1, 66639, '\p{__Is_changes_When_Uppercased}', "");
Expect(0, 66639, '\p{^__Is_changes_When_Uppercased}', "");
Expect(0, 66639, '\P{__Is_changes_When_Uppercased}', "");
Expect(1, 66639, '\P{^__Is_changes_When_Uppercased}', "");
Expect(0, 66640, '\p{__Is_changes_When_Uppercased}', "");
Expect(1, 66640, '\p{^__Is_changes_When_Uppercased}', "");
Expect(1, 66640, '\P{__Is_changes_When_Uppercased}', "");
Expect(0, 66640, '\P{^__Is_changes_When_Uppercased}', "");
Error('\p{ :=CWU}');
Error('\P{ :=CWU}');
Expect(1, 66639, '\p{cwu}', "");
Expect(0, 66639, '\p{^cwu}', "");
Expect(0, 66639, '\P{cwu}', "");
Expect(1, 66639, '\P{^cwu}', "");
Expect(0, 66640, '\p{cwu}', "");
Expect(1, 66640, '\p{^cwu}', "");
Expect(1, 66640, '\P{cwu}', "");
Expect(0, 66640, '\P{^cwu}', "");
Expect(1, 66639, '\p{_ CWU}', "");
Expect(0, 66639, '\p{^_ CWU}', "");
Expect(0, 66639, '\P{_ CWU}', "");
Expect(1, 66639, '\P{^_ CWU}', "");
Expect(0, 66640, '\p{_ CWU}', "");
Expect(1, 66640, '\p{^_ CWU}', "");
Expect(1, 66640, '\P{_ CWU}', "");
Expect(0, 66640, '\P{^_ CWU}', "");
Error('\p{/a/_ is_CWU}');
Error('\P{/a/_ is_CWU}');
Expect(1, 66639, '\p{iscwu}', "");
Expect(0, 66639, '\p{^iscwu}', "");
Expect(0, 66639, '\P{iscwu}', "");
Expect(1, 66639, '\P{^iscwu}', "");
Expect(0, 66640, '\p{iscwu}', "");
Expect(1, 66640, '\p{^iscwu}', "");
Expect(1, 66640, '\P{iscwu}', "");
Expect(0, 66640, '\P{^iscwu}', "");
Expect(1, 66639, '\p{ is_CWU}', "");
Expect(0, 66639, '\p{^ is_CWU}', "");
Expect(0, 66639, '\P{ is_CWU}', "");
Expect(1, 66639, '\P{^ is_CWU}', "");
Expect(0, 66640, '\p{ is_CWU}', "");
Expect(1, 66640, '\p{^ is_CWU}', "");
Expect(1, 66640, '\P{ is_CWU}', "");
Expect(0, 66640, '\P{^ is_CWU}', "");
Error('\p{ :=cherokee}');
Error('\P{ :=cherokee}');
Expect(1, 5108, '\p{cherokee}', "");
Expect(0, 5108, '\p{^cherokee}', "");
Expect(0, 5108, '\P{cherokee}', "");
Expect(1, 5108, '\P{^cherokee}', "");
Expect(0, 5109, '\p{cherokee}', "");
Expect(1, 5109, '\p{^cherokee}', "");
Expect(1, 5109, '\P{cherokee}', "");
Expect(0, 5109, '\P{^cherokee}', "");
Expect(1, 5108, '\p{ _Cherokee}', "");
Expect(0, 5108, '\p{^ _Cherokee}', "");
Expect(0, 5108, '\P{ _Cherokee}', "");
Expect(1, 5108, '\P{^ _Cherokee}', "");
Expect(0, 5109, '\p{ _Cherokee}', "");
Expect(1, 5109, '\p{^ _Cherokee}', "");
Expect(1, 5109, '\P{ _Cherokee}', "");
Expect(0, 5109, '\P{^ _Cherokee}', "");
Error('\p{/a/	 is_CHEROKEE}');
Error('\P{/a/	 is_CHEROKEE}');
Expect(1, 5108, '\p{ischerokee}', "");
Expect(0, 5108, '\p{^ischerokee}', "");
Expect(0, 5108, '\P{ischerokee}', "");
Expect(1, 5108, '\P{^ischerokee}', "");
Expect(0, 5109, '\p{ischerokee}', "");
Expect(1, 5109, '\p{^ischerokee}', "");
Expect(1, 5109, '\P{ischerokee}', "");
Expect(0, 5109, '\P{^ischerokee}', "");
Expect(1, 5108, '\p{ is_cherokee}', "");
Expect(0, 5108, '\p{^ is_cherokee}', "");
Expect(0, 5108, '\P{ is_cherokee}', "");
Expect(1, 5108, '\P{^ is_cherokee}', "");
Expect(0, 5109, '\p{ is_cherokee}', "");
Expect(1, 5109, '\p{^ is_cherokee}', "");
Expect(1, 5109, '\P{ is_cherokee}', "");
Expect(0, 5109, '\P{^ is_cherokee}', "");
Error('\p{		cher/a/}');
Error('\P{		cher/a/}');
Expect(1, 5108, '\p{cher}', "");
Expect(0, 5108, '\p{^cher}', "");
Expect(0, 5108, '\P{cher}', "");
Expect(1, 5108, '\P{^cher}', "");
Expect(0, 5109, '\p{cher}', "");
Expect(1, 5109, '\p{^cher}', "");
Expect(1, 5109, '\P{cher}', "");
Expect(0, 5109, '\P{^cher}', "");
Expect(1, 5108, '\p{_-Cher}', "");
Expect(0, 5108, '\p{^_-Cher}', "");
Expect(0, 5108, '\P{_-Cher}', "");
Expect(1, 5108, '\P{^_-Cher}', "");
Expect(0, 5109, '\p{_-Cher}', "");
Expect(1, 5109, '\p{^_-Cher}', "");
Expect(1, 5109, '\P{_-Cher}', "");
Expect(0, 5109, '\P{^_-Cher}', "");
Error('\p{:= IS_Cher}');
Error('\P{:= IS_Cher}');
Expect(1, 5108, '\p{ischer}', "");
Expect(0, 5108, '\p{^ischer}', "");
Expect(0, 5108, '\P{ischer}', "");
Expect(1, 5108, '\P{^ischer}', "");
Expect(0, 5109, '\p{ischer}', "");
Expect(1, 5109, '\p{^ischer}', "");
Expect(1, 5109, '\P{ischer}', "");
Expect(0, 5109, '\P{^ischer}', "");
Expect(1, 5108, '\p{	-Is_cher}', "");
Expect(0, 5108, '\p{^	-Is_cher}', "");
Expect(0, 5108, '\P{	-Is_cher}', "");
Expect(1, 5108, '\P{^	-Is_cher}', "");
Expect(0, 5109, '\p{	-Is_cher}', "");
Expect(1, 5109, '\p{^	-Is_cher}', "");
Expect(1, 5109, '\P{	-Is_cher}', "");
Expect(0, 5109, '\P{^	-Is_cher}', "");
Error('\p{-/a/CLOSE_Punctuation}');
Error('\P{-/a/CLOSE_Punctuation}');
Expect(1, 65379, '\p{closepunctuation}', "");
Expect(0, 65379, '\p{^closepunctuation}', "");
Expect(0, 65379, '\P{closepunctuation}', "");
Expect(1, 65379, '\P{^closepunctuation}', "");
Expect(0, 65380, '\p{closepunctuation}', "");
Expect(1, 65380, '\p{^closepunctuation}', "");
Expect(1, 65380, '\P{closepunctuation}', "");
Expect(0, 65380, '\P{^closepunctuation}', "");
Expect(1, 65379, '\p{__close_PUNCTUATION}', "");
Expect(0, 65379, '\p{^__close_PUNCTUATION}', "");
Expect(0, 65379, '\P{__close_PUNCTUATION}', "");
Expect(1, 65379, '\P{^__close_PUNCTUATION}', "");
Expect(0, 65380, '\p{__close_PUNCTUATION}', "");
Expect(1, 65380, '\p{^__close_PUNCTUATION}', "");
Expect(1, 65380, '\P{__close_PUNCTUATION}', "");
Expect(0, 65380, '\P{^__close_PUNCTUATION}', "");
Error('\p{:=--is_Close_Punctuation}');
Error('\P{:=--is_Close_Punctuation}');
Expect(1, 65379, '\p{isclosepunctuation}', "");
Expect(0, 65379, '\p{^isclosepunctuation}', "");
Expect(0, 65379, '\P{isclosepunctuation}', "");
Expect(1, 65379, '\P{^isclosepunctuation}', "");
Expect(0, 65380, '\p{isclosepunctuation}', "");
Expect(1, 65380, '\p{^isclosepunctuation}', "");
Expect(1, 65380, '\P{isclosepunctuation}', "");
Expect(0, 65380, '\P{^isclosepunctuation}', "");
Expect(1, 65379, '\p{-	IS_close_Punctuation}', "");
Expect(0, 65379, '\p{^-	IS_close_Punctuation}', "");
Expect(0, 65379, '\P{-	IS_close_Punctuation}', "");
Expect(1, 65379, '\P{^-	IS_close_Punctuation}', "");
Expect(0, 65380, '\p{-	IS_close_Punctuation}', "");
Expect(1, 65380, '\p{^-	IS_close_Punctuation}', "");
Expect(1, 65380, '\P{-	IS_close_Punctuation}', "");
Expect(0, 65380, '\P{^-	IS_close_Punctuation}', "");
Error('\p{:=	-PE}');
Error('\P{:=	-PE}');
Expect(1, 65379, '\p{pe}', "");
Expect(0, 65379, '\p{^pe}', "");
Expect(0, 65379, '\P{pe}', "");
Expect(1, 65379, '\P{^pe}', "");
Expect(0, 65380, '\p{pe}', "");
Expect(1, 65380, '\p{^pe}', "");
Expect(1, 65380, '\P{pe}', "");
Expect(0, 65380, '\P{^pe}', "");
Expect(1, 65379, '\p{  Pe}', "");
Expect(0, 65379, '\p{^  Pe}', "");
Expect(0, 65379, '\P{  Pe}', "");
Expect(1, 65379, '\P{^  Pe}', "");
Expect(0, 65380, '\p{  Pe}', "");
Expect(1, 65380, '\p{^  Pe}', "");
Expect(1, 65380, '\P{  Pe}', "");
Expect(0, 65380, '\P{^  Pe}', "");
Error('\p{_Is_pe:=}');
Error('\P{_Is_pe:=}');
Expect(1, 65379, '\p{ispe}', "");
Expect(0, 65379, '\p{^ispe}', "");
Expect(0, 65379, '\P{ispe}', "");
Expect(1, 65379, '\P{^ispe}', "");
Expect(0, 65380, '\p{ispe}', "");
Expect(1, 65380, '\p{^ispe}', "");
Expect(1, 65380, '\P{ispe}', "");
Expect(0, 65380, '\P{^ispe}', "");
Expect(1, 65379, '\p{_	IS_Pe}', "");
Expect(0, 65379, '\p{^_	IS_Pe}', "");
Expect(0, 65379, '\P{_	IS_Pe}', "");
Expect(1, 65379, '\P{^_	IS_Pe}', "");
Expect(0, 65380, '\p{_	IS_Pe}', "");
Expect(1, 65380, '\p{^_	IS_Pe}', "");
Expect(1, 65380, '\P{_	IS_Pe}', "");
Expect(0, 65380, '\P{^_	IS_Pe}', "");
Error('\p{		CNTRL/a/}');
Error('\P{		CNTRL/a/}');
Expect(1, 159, '\p{cntrl}', "");
Expect(0, 159, '\p{^cntrl}', "");
Expect(0, 159, '\P{cntrl}', "");
Expect(1, 159, '\P{^cntrl}', "");
Expect(0, 160, '\p{cntrl}', "");
Expect(1, 160, '\p{^cntrl}', "");
Expect(1, 160, '\P{cntrl}', "");
Expect(0, 160, '\P{^cntrl}', "");
Expect(1, 159, '\p{	Cntrl}', "");
Expect(0, 159, '\p{^	Cntrl}', "");
Expect(0, 159, '\P{	Cntrl}', "");
Expect(1, 159, '\P{^	Cntrl}', "");
Expect(0, 160, '\p{	Cntrl}', "");
Expect(1, 160, '\p{^	Cntrl}', "");
Expect(1, 160, '\P{	Cntrl}', "");
Expect(0, 160, '\P{^	Cntrl}', "");
Error('\p{ _xposixcntrl:=}');
Error('\P{ _xposixcntrl:=}');
Expect(1, 159, '\p{xposixcntrl}', "");
Expect(0, 159, '\p{^xposixcntrl}', "");
Expect(0, 159, '\P{xposixcntrl}', "");
Expect(1, 159, '\P{^xposixcntrl}', "");
Expect(0, 160, '\p{xposixcntrl}', "");
Expect(1, 160, '\p{^xposixcntrl}', "");
Expect(1, 160, '\P{xposixcntrl}', "");
Expect(0, 160, '\P{^xposixcntrl}', "");
Expect(1, 159, '\p{_XPOSIXCNTRL}', "");
Expect(0, 159, '\p{^_XPOSIXCNTRL}', "");
Expect(0, 159, '\P{_XPOSIXCNTRL}', "");
Expect(1, 159, '\P{^_XPOSIXCNTRL}', "");
Expect(0, 160, '\p{_XPOSIXCNTRL}', "");
Expect(1, 160, '\p{^_XPOSIXCNTRL}', "");
Expect(1, 160, '\P{_XPOSIXCNTRL}', "");
Expect(0, 160, '\P{^_XPOSIXCNTRL}', "");
Error('\p{/a/IS_Cntrl}');
Error('\P{/a/IS_Cntrl}');
Expect(1, 159, '\p{iscntrl}', "");
Expect(0, 159, '\p{^iscntrl}', "");
Expect(0, 159, '\P{iscntrl}', "");
Expect(1, 159, '\P{^iscntrl}', "");
Expect(0, 160, '\p{iscntrl}', "");
Expect(1, 160, '\p{^iscntrl}', "");
Expect(1, 160, '\P{iscntrl}', "");
Expect(0, 160, '\P{^iscntrl}', "");
Expect(1, 159, '\p{ -Is_Cntrl}', "");
Expect(0, 159, '\p{^ -Is_Cntrl}', "");
Expect(0, 159, '\P{ -Is_Cntrl}', "");
Expect(1, 159, '\P{^ -Is_Cntrl}', "");
Expect(0, 160, '\p{ -Is_Cntrl}', "");
Expect(1, 160, '\p{^ -Is_Cntrl}', "");
Expect(1, 160, '\P{ -Is_Cntrl}', "");
Expect(0, 160, '\P{^ -Is_Cntrl}', "");
Error('\p{	:=IS_xposixcntrl}');
Error('\P{	:=IS_xposixcntrl}');
Expect(1, 159, '\p{isxposixcntrl}', "");
Expect(0, 159, '\p{^isxposixcntrl}', "");
Expect(0, 159, '\P{isxposixcntrl}', "");
Expect(1, 159, '\P{^isxposixcntrl}', "");
Expect(0, 160, '\p{isxposixcntrl}', "");
Expect(1, 160, '\p{^isxposixcntrl}', "");
Expect(1, 160, '\P{isxposixcntrl}', "");
Expect(0, 160, '\P{^isxposixcntrl}', "");
Expect(1, 159, '\p{_IS_XPOSIXCNTRL}', "");
Expect(0, 159, '\p{^_IS_XPOSIXCNTRL}', "");
Expect(0, 159, '\P{_IS_XPOSIXCNTRL}', "");
Expect(1, 159, '\P{^_IS_XPOSIXCNTRL}', "");
Expect(0, 160, '\p{_IS_XPOSIXCNTRL}', "");
Expect(1, 160, '\p{^_IS_XPOSIXCNTRL}', "");
Expect(1, 160, '\P{_IS_XPOSIXCNTRL}', "");
Expect(0, 160, '\P{^_IS_XPOSIXCNTRL}', "");
Error('\p{/a/		CONTROL}');
Error('\P{/a/		CONTROL}');
Expect(1, 159, '\p{control}', "");
Expect(0, 159, '\p{^control}', "");
Expect(0, 159, '\P{control}', "");
Expect(1, 159, '\P{^control}', "");
Expect(0, 160, '\p{control}', "");
Expect(1, 160, '\p{^control}', "");
Expect(1, 160, '\P{control}', "");
Expect(0, 160, '\P{^control}', "");
Expect(1, 159, '\p{ Control}', "");
Expect(0, 159, '\p{^ Control}', "");
Expect(0, 159, '\P{ Control}', "");
Expect(1, 159, '\P{^ Control}', "");
Expect(0, 160, '\p{ Control}', "");
Expect(1, 160, '\p{^ Control}', "");
Expect(1, 160, '\P{ Control}', "");
Expect(0, 160, '\P{^ Control}', "");
Error('\p{ 	is_Control/a/}');
Error('\P{ 	is_Control/a/}');
Expect(1, 159, '\p{iscontrol}', "");
Expect(0, 159, '\p{^iscontrol}', "");
Expect(0, 159, '\P{iscontrol}', "");
Expect(1, 159, '\P{^iscontrol}', "");
Expect(0, 160, '\p{iscontrol}', "");
Expect(1, 160, '\p{^iscontrol}', "");
Expect(1, 160, '\P{iscontrol}', "");
Expect(0, 160, '\P{^iscontrol}', "");
Expect(1, 159, '\p{-IS_Control}', "");
Expect(0, 159, '\p{^-IS_Control}', "");
Expect(0, 159, '\P{-IS_Control}', "");
Expect(1, 159, '\P{^-IS_Control}', "");
Expect(0, 160, '\p{-IS_Control}', "");
Expect(1, 160, '\p{^-IS_Control}', "");
Expect(1, 160, '\P{-IS_Control}', "");
Expect(0, 160, '\P{^-IS_Control}', "");
Error('\p{/a/	Cc}');
Error('\P{/a/	Cc}');
Expect(1, 159, '\p{cc}', "");
Expect(0, 159, '\p{^cc}', "");
Expect(0, 159, '\P{cc}', "");
Expect(1, 159, '\P{^cc}', "");
Expect(0, 160, '\p{cc}', "");
Expect(1, 160, '\p{^cc}', "");
Expect(1, 160, '\P{cc}', "");
Expect(0, 160, '\P{^cc}', "");
Expect(1, 159, '\p{	-Cc}', "");
Expect(0, 159, '\p{^	-Cc}', "");
Expect(0, 159, '\P{	-Cc}', "");
Expect(1, 159, '\P{^	-Cc}', "");
Expect(0, 160, '\p{	-Cc}', "");
Expect(1, 160, '\p{^	-Cc}', "");
Expect(1, 160, '\P{	-Cc}', "");
Expect(0, 160, '\P{^	-Cc}', "");
Error('\p{ :=IS_Cc}');
Error('\P{ :=IS_Cc}');
Expect(1, 159, '\p{iscc}', "");
Expect(0, 159, '\p{^iscc}', "");
Expect(0, 159, '\P{iscc}', "");
Expect(1, 159, '\P{^iscc}', "");
Expect(0, 160, '\p{iscc}', "");
Expect(1, 160, '\p{^iscc}', "");
Expect(1, 160, '\P{iscc}', "");
Expect(0, 160, '\P{^iscc}', "");
Expect(1, 159, '\p{_ Is_Cc}', "");
Expect(0, 159, '\p{^_ Is_Cc}', "");
Expect(0, 159, '\P{_ Is_Cc}', "");
Expect(1, 159, '\P{^_ Is_Cc}', "");
Expect(0, 160, '\p{_ Is_Cc}', "");
Expect(1, 160, '\p{^_ Is_Cc}', "");
Expect(1, 160, '\P{_ Is_Cc}', "");
Expect(0, 160, '\P{^_ Is_Cc}', "");
Error('\p{	:=combining_diacritical_Marks}');
Error('\P{	:=combining_diacritical_Marks}');
Expect(1, 879, '\p{combiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^combiningdiacriticalmarks}', "");
Expect(0, 879, '\P{combiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^combiningdiacriticalmarks}', "");
Expect(0, 880, '\p{combiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^combiningdiacriticalmarks}', "");
Expect(1, 880, '\P{combiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^combiningdiacriticalmarks}', "");
Expect(1, 879, '\p{Combining_diacritical_Marks}', "");
Expect(0, 879, '\p{^Combining_diacritical_Marks}', "");
Expect(0, 879, '\P{Combining_diacritical_Marks}', "");
Expect(1, 879, '\P{^Combining_diacritical_Marks}', "");
Expect(0, 880, '\p{Combining_diacritical_Marks}', "");
Expect(1, 880, '\p{^Combining_diacritical_Marks}', "");
Expect(1, 880, '\P{Combining_diacritical_Marks}', "");
Expect(0, 880, '\P{^Combining_diacritical_Marks}', "");
Error('\p{	-Is_Combining_Diacritical_marks:=}');
Error('\P{	-Is_Combining_Diacritical_marks:=}');
Expect(1, 879, '\p{iscombiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^iscombiningdiacriticalmarks}', "");
Expect(0, 879, '\P{iscombiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^iscombiningdiacriticalmarks}', "");
Expect(0, 880, '\p{iscombiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^iscombiningdiacriticalmarks}', "");
Expect(1, 880, '\P{iscombiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^iscombiningdiacriticalmarks}', "");
Expect(1, 879, '\p{ _Is_combining_Diacritical_Marks}', "");
Expect(0, 879, '\p{^ _Is_combining_Diacritical_Marks}', "");
Expect(0, 879, '\P{ _Is_combining_Diacritical_Marks}', "");
Expect(1, 879, '\P{^ _Is_combining_Diacritical_Marks}', "");
Expect(0, 880, '\p{ _Is_combining_Diacritical_Marks}', "");
Expect(1, 880, '\p{^ _Is_combining_Diacritical_Marks}', "");
Expect(1, 880, '\P{ _Is_combining_Diacritical_Marks}', "");
Expect(0, 880, '\P{^ _Is_combining_Diacritical_Marks}', "");
Error('\p{:=	In_Combining_DIACRITICAL_Marks}');
Error('\P{:=	In_Combining_DIACRITICAL_Marks}');
Expect(1, 879, '\p{incombiningdiacriticalmarks}', "");
Expect(0, 879, '\p{^incombiningdiacriticalmarks}', "");
Expect(0, 879, '\P{incombiningdiacriticalmarks}', "");
Expect(1, 879, '\P{^incombiningdiacriticalmarks}', "");
Expect(0, 880, '\p{incombiningdiacriticalmarks}', "");
Expect(1, 880, '\p{^incombiningdiacriticalmarks}', "");
Expect(1, 880, '\P{incombiningdiacriticalmarks}', "");
Expect(0, 880, '\P{^incombiningdiacriticalmarks}', "");
Expect(1, 879, '\p{	_IN_Combining_diacritical_Marks}', "");
Expect(0, 879, '\p{^	_IN_Combining_diacritical_Marks}', "");
Expect(0, 879, '\P{	_IN_Combining_diacritical_Marks}', "");
Expect(1, 879, '\P{^	_IN_Combining_diacritical_Marks}', "");
Expect(0, 880, '\p{	_IN_Combining_diacritical_Marks}', "");
Expect(1, 880, '\p{^	_IN_Combining_diacritical_Marks}', "");
Expect(1, 880, '\P{	_IN_Combining_diacritical_Marks}', "");
Expect(0, 880, '\P{^	_IN_Combining_diacritical_Marks}', "");
Error('\p{ :=DIACRITICALS}');
Error('\P{ :=DIACRITICALS}');
Expect(1, 879, '\p{diacriticals}', "");
Expect(0, 879, '\p{^diacriticals}', "");
Expect(0, 879, '\P{diacriticals}', "");
Expect(1, 879, '\P{^diacriticals}', "");
Expect(0, 880, '\p{diacriticals}', "");
Expect(1, 880, '\p{^diacriticals}', "");
Expect(1, 880, '\P{diacriticals}', "");
Expect(0, 880, '\P{^diacriticals}', "");
Expect(1, 879, '\p{-diacriticals}', "");
Expect(0, 879, '\p{^-diacriticals}', "");
Expect(0, 879, '\P{-diacriticals}', "");
Expect(1, 879, '\P{^-diacriticals}', "");
Expect(0, 880, '\p{-diacriticals}', "");
Expect(1, 880, '\p{^-diacriticals}', "");
Expect(1, 880, '\P{-diacriticals}', "");
Expect(0, 880, '\P{^-diacriticals}', "");
Error('\p{:=	IS_Diacriticals}');
Error('\P{:=	IS_Diacriticals}');
Expect(1, 879, '\p{isdiacriticals}', "");
Expect(0, 879, '\p{^isdiacriticals}', "");
Expect(0, 879, '\P{isdiacriticals}', "");
Expect(1, 879, '\P{^isdiacriticals}', "");
Expect(0, 880, '\p{isdiacriticals}', "");
Expect(1, 880, '\p{^isdiacriticals}', "");
Expect(1, 880, '\P{isdiacriticals}', "");
Expect(0, 880, '\P{^isdiacriticals}', "");
Expect(1, 879, '\p{	_IS_DIACRITICALS}', "");
Expect(0, 879, '\p{^	_IS_DIACRITICALS}', "");
Expect(0, 879, '\P{	_IS_DIACRITICALS}', "");
Expect(1, 879, '\P{^	_IS_DIACRITICALS}', "");
Expect(0, 880, '\p{	_IS_DIACRITICALS}', "");
Expect(1, 880, '\p{^	_IS_DIACRITICALS}', "");
Expect(1, 880, '\P{	_IS_DIACRITICALS}', "");
Expect(0, 880, '\P{^	_IS_DIACRITICALS}', "");
Error('\p{/a/In_Diacriticals}');
Error('\P{/a/In_Diacriticals}');
Expect(1, 879, '\p{indiacriticals}', "");
Expect(0, 879, '\p{^indiacriticals}', "");
Expect(0, 879, '\P{indiacriticals}', "");
Expect(1, 879, '\P{^indiacriticals}', "");
Expect(0, 880, '\p{indiacriticals}', "");
Expect(1, 880, '\p{^indiacriticals}', "");
Expect(1, 880, '\P{indiacriticals}', "");
Expect(0, 880, '\P{^indiacriticals}', "");
Expect(1, 879, '\p{_-In_diacriticals}', "");
Expect(0, 879, '\p{^_-In_diacriticals}', "");
Expect(0, 879, '\P{_-In_diacriticals}', "");
Expect(1, 879, '\P{^_-In_diacriticals}', "");
Expect(0, 880, '\p{_-In_diacriticals}', "");
Expect(1, 880, '\p{^_-In_diacriticals}', "");
Expect(1, 880, '\P{_-In_diacriticals}', "");
Expect(0, 880, '\P{^_-In_diacriticals}', "");
Error('\p{_-COMBINING_diacritical_MARKS_for_Symbols/a/}');
Error('\P{_-COMBINING_diacritical_MARKS_for_Symbols/a/}');
Expect(1, 8447, '\p{combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{combiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^combiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8447, '\p{^	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8447, '\P{	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8447, '\P{^	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8448, '\p{	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8448, '\p{^	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(1, 8448, '\P{	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Expect(0, 8448, '\P{^	-Combining_Diacritical_Marks_For_SYMBOLS}', "");
Error('\p{__Is_Combining_diacritical_Marks_For_SYMBOLS:=}');
Error('\P{__Is_Combining_diacritical_Marks_For_SYMBOLS:=}');
Expect(1, 8447, '\p{iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{iscombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^iscombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8447, '\p{^-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8447, '\P{-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(1, 8447, '\P{^-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8448, '\p{-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(1, 8448, '\p{^-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(1, 8448, '\P{-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Expect(0, 8448, '\P{^-	Is_combining_diacritical_MARKS_For_SYMBOLS}', "");
Error('\p{-:=in_combining_diacritical_Marks_For_SYMBOLS}');
Error('\P{-:=in_combining_diacritical_Marks_For_SYMBOLS}');
Expect(1, 8447, '\p{incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\p{^incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8447, '\P{incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\P{^incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\p{incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\p{^incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8448, '\P{incombiningdiacriticalmarksforsymbols}', "");
Expect(0, 8448, '\P{^incombiningdiacriticalmarksforsymbols}', "");
Expect(1, 8447, '\p{-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(0, 8447, '\p{^-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(0, 8447, '\P{-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(1, 8447, '\P{^-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(0, 8448, '\p{-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(1, 8448, '\p{^-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(1, 8448, '\P{-in_Combining_Diacritical_Marks_For_symbols}', "");
Expect(0, 8448, '\P{^-in_Combining_Diacritical_Marks_For_symbols}', "");
Error('\p{_/a/Diacriticals_For_symbols}');
Error('\P{_/a/Diacriticals_For_symbols}');
Expect(1, 8447, '\p{diacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^diacriticalsforsymbols}', "");
Expect(0, 8447, '\P{diacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^diacriticalsforsymbols}', "");
Expect(0, 8448, '\p{diacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^diacriticalsforsymbols}', "");
Expect(1, 8448, '\P{diacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^diacriticalsforsymbols}', "");
Expect(1, 8447, '\p{_ Diacriticals_For_SYMBOLS}', "");
Expect(0, 8447, '\p{^_ Diacriticals_For_SYMBOLS}', "");
Expect(0, 8447, '\P{_ Diacriticals_For_SYMBOLS}', "");
Expect(1, 8447, '\P{^_ Diacriticals_For_SYMBOLS}', "");
Expect(0, 8448, '\p{_ Diacriticals_For_SYMBOLS}', "");
Expect(1, 8448, '\p{^_ Diacriticals_For_SYMBOLS}', "");
Expect(1, 8448, '\P{_ Diacriticals_For_SYMBOLS}', "");
Expect(0, 8448, '\P{^_ Diacriticals_For_SYMBOLS}', "");
Error('\p{:=_-IS_DIACRITICALS_For_Symbols}');
Error('\P{:=_-IS_DIACRITICALS_For_Symbols}');
Expect(1, 8447, '\p{isdiacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^isdiacriticalsforsymbols}', "");
Expect(0, 8447, '\P{isdiacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^isdiacriticalsforsymbols}', "");
Expect(0, 8448, '\p{isdiacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^isdiacriticalsforsymbols}', "");
Expect(1, 8448, '\P{isdiacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^isdiacriticalsforsymbols}', "");
Expect(1, 8447, '\p{		Is_diacriticals_for_Symbols}', "");
Expect(0, 8447, '\p{^		Is_diacriticals_for_Symbols}', "");
Expect(0, 8447, '\P{		Is_diacriticals_for_Symbols}', "");
Expect(1, 8447, '\P{^		Is_diacriticals_for_Symbols}', "");
Expect(0, 8448, '\p{		Is_diacriticals_for_Symbols}', "");
Expect(1, 8448, '\p{^		Is_diacriticals_for_Symbols}', "");
Expect(1, 8448, '\P{		Is_diacriticals_for_Symbols}', "");
Expect(0, 8448, '\P{^		Is_diacriticals_for_Symbols}', "");
Error('\p{:=In_Diacriticals_For_Symbols}');
Error('\P{:=In_Diacriticals_For_Symbols}');
Expect(1, 8447, '\p{indiacriticalsforsymbols}', "");
Expect(0, 8447, '\p{^indiacriticalsforsymbols}', "");
Expect(0, 8447, '\P{indiacriticalsforsymbols}', "");
Expect(1, 8447, '\P{^indiacriticalsforsymbols}', "");
Expect(0, 8448, '\p{indiacriticalsforsymbols}', "");
Expect(1, 8448, '\p{^indiacriticalsforsymbols}', "");
Expect(1, 8448, '\P{indiacriticalsforsymbols}', "");
Expect(0, 8448, '\P{^indiacriticalsforsymbols}', "");
Expect(1, 8447, '\p{		In_diacriticals_For_symbols}', "");
Expect(0, 8447, '\p{^		In_diacriticals_For_symbols}', "");
Expect(0, 8447, '\P{		In_diacriticals_For_symbols}', "");
Expect(1, 8447, '\P{^		In_diacriticals_For_symbols}', "");
Expect(0, 8448, '\p{		In_diacriticals_For_symbols}', "");
Expect(1, 8448, '\p{^		In_diacriticals_For_symbols}', "");
Expect(1, 8448, '\P{		In_diacriticals_For_symbols}', "");
Expect(0, 8448, '\P{^		In_diacriticals_For_symbols}', "");
Error('\p{:=-Combining_Marks_for_symbols}');
Error('\P{:=-Combining_Marks_for_symbols}');
Expect(1, 8447, '\p{combiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^combiningmarksforsymbols}', "");
Expect(0, 8447, '\P{combiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^combiningmarksforsymbols}', "");
Expect(0, 8448, '\p{combiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^combiningmarksforsymbols}', "");
Expect(1, 8448, '\P{combiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^combiningmarksforsymbols}', "");
Expect(1, 8447, '\p{  COMBINING_Marks_FOR_symbols}', "");
Expect(0, 8447, '\p{^  COMBINING_Marks_FOR_symbols}', "");
Expect(0, 8447, '\P{  COMBINING_Marks_FOR_symbols}', "");
Expect(1, 8447, '\P{^  COMBINING_Marks_FOR_symbols}', "");
Expect(0, 8448, '\p{  COMBINING_Marks_FOR_symbols}', "");
Expect(1, 8448, '\p{^  COMBINING_Marks_FOR_symbols}', "");
Expect(1, 8448, '\P{  COMBINING_Marks_FOR_symbols}', "");
Expect(0, 8448, '\P{^  COMBINING_Marks_FOR_symbols}', "");
Error('\p{:=  is_Combining_MARKS_for_SYMBOLS}');
Error('\P{:=  is_Combining_MARKS_for_SYMBOLS}');
Expect(1, 8447, '\p{iscombiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^iscombiningmarksforsymbols}', "");
Expect(0, 8447, '\P{iscombiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^iscombiningmarksforsymbols}', "");
Expect(0, 8448, '\p{iscombiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^iscombiningmarksforsymbols}', "");
Expect(1, 8448, '\P{iscombiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^iscombiningmarksforsymbols}', "");
Expect(1, 8447, '\p{	 Is_Combining_Marks_for_symbols}', "");
Expect(0, 8447, '\p{^	 Is_Combining_Marks_for_symbols}', "");
Expect(0, 8447, '\P{	 Is_Combining_Marks_for_symbols}', "");
Expect(1, 8447, '\P{^	 Is_Combining_Marks_for_symbols}', "");
Expect(0, 8448, '\p{	 Is_Combining_Marks_for_symbols}', "");
Expect(1, 8448, '\p{^	 Is_Combining_Marks_for_symbols}', "");
Expect(1, 8448, '\P{	 Is_Combining_Marks_for_symbols}', "");
Expect(0, 8448, '\P{^	 Is_Combining_Marks_for_symbols}', "");
Error('\p{/a/-	in_Combining_Marks_For_Symbols}');
Error('\P{/a/-	in_Combining_Marks_For_Symbols}');
Expect(1, 8447, '\p{incombiningmarksforsymbols}', "");
Expect(0, 8447, '\p{^incombiningmarksforsymbols}', "");
Expect(0, 8447, '\P{incombiningmarksforsymbols}', "");
Expect(1, 8447, '\P{^incombiningmarksforsymbols}', "");
Expect(0, 8448, '\p{incombiningmarksforsymbols}', "");
Expect(1, 8448, '\p{^incombiningmarksforsymbols}', "");
Expect(1, 8448, '\P{incombiningmarksforsymbols}', "");
Expect(0, 8448, '\P{^incombiningmarksforsymbols}', "");
Expect(1, 8447, '\p{_ In_combining_Marks_for_Symbols}', "");
Expect(0, 8447, '\p{^_ In_combining_Marks_for_Symbols}', "");
Expect(0, 8447, '\P{_ In_combining_Marks_for_Symbols}', "");
Expect(1, 8447, '\P{^_ In_combining_Marks_for_Symbols}', "");
Expect(0, 8448, '\p{_ In_combining_Marks_for_Symbols}', "");
Expect(1, 8448, '\p{^_ In_combining_Marks_for_Symbols}', "");
Expect(1, 8448, '\P{_ In_combining_Marks_for_Symbols}', "");
Expect(0, 8448, '\P{^_ In_combining_Marks_for_Symbols}', "");
Error('\p{:=combining_diacritical_MARKS_SUPPLEMENT}');
Error('\P{:=combining_diacritical_MARKS_SUPPLEMENT}');
Expect(1, 7679, '\p{combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^combiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^combiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{combiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^combiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7679, '\p{^ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7679, '\P{ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(1, 7679, '\P{^ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7680, '\p{ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(1, 7680, '\p{^ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(1, 7680, '\P{ Combining_Diacritical_marks_SUPPLEMENT}', "");
Expect(0, 7680, '\P{^ Combining_Diacritical_marks_SUPPLEMENT}', "");
Error('\p{/a/Is_Combining_Diacritical_MARKS_Supplement}');
Error('\P{/a/Is_Combining_Diacritical_MARKS_Supplement}');
Expect(1, 7679, '\p{iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{iscombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^iscombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(0, 7679, '\p{^_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(0, 7679, '\P{_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(1, 7679, '\P{^_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(0, 7680, '\p{_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(1, 7680, '\p{^_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(1, 7680, '\P{_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Expect(0, 7680, '\P{^_	is_combining_Diacritical_Marks_SUPPLEMENT}', "");
Error('\p{	/a/In_combining_diacritical_marks_Supplement}');
Error('\P{	/a/In_combining_diacritical_marks_Supplement}');
Expect(1, 7679, '\p{incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\p{^incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7679, '\P{incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\P{^incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\p{incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\p{^incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7680, '\P{incombiningdiacriticalmarkssupplement}', "");
Expect(0, 7680, '\P{^incombiningdiacriticalmarkssupplement}', "");
Expect(1, 7679, '\p{In_Combining_diacritical_Marks_supplement}', "");
Expect(0, 7679, '\p{^In_Combining_diacritical_Marks_supplement}', "");
Expect(0, 7679, '\P{In_Combining_diacritical_Marks_supplement}', "");
Expect(1, 7679, '\P{^In_Combining_diacritical_Marks_supplement}', "");
Expect(0, 7680, '\p{In_Combining_diacritical_Marks_supplement}', "");
Expect(1, 7680, '\p{^In_Combining_diacritical_Marks_supplement}', "");
Expect(1, 7680, '\P{In_Combining_diacritical_Marks_supplement}', "");
Expect(0, 7680, '\P{^In_Combining_diacritical_Marks_supplement}', "");
Error('\p{:= diacriticals_sup}');
Error('\P{:= diacriticals_sup}');
Expect(1, 7679, '\p{diacriticalssup}', "");
Expect(0, 7679, '\p{^diacriticalssup}', "");
Expect(0, 7679, '\P{diacriticalssup}', "");
Expect(1, 7679, '\P{^diacriticalssup}', "");
Expect(0, 7680, '\p{diacriticalssup}', "");
Expect(1, 7680, '\p{^diacriticalssup}', "");
Expect(1, 7680, '\P{diacriticalssup}', "");
Expect(0, 7680, '\P{^diacriticalssup}', "");
Expect(1, 7679, '\p{_Diacriticals_SUP}', "");
Expect(0, 7679, '\p{^_Diacriticals_SUP}', "");
Expect(0, 7679, '\P{_Diacriticals_SUP}', "");
Expect(1, 7679, '\P{^_Diacriticals_SUP}', "");
Expect(0, 7680, '\p{_Diacriticals_SUP}', "");
Expect(1, 7680, '\p{^_Diacriticals_SUP}', "");
Expect(1, 7680, '\P{_Diacriticals_SUP}', "");
Expect(0, 7680, '\P{^_Diacriticals_SUP}', "");
Error('\p{	Is_Diacriticals_SUP:=}');
Error('\P{	Is_Diacriticals_SUP:=}');
Expect(1, 7679, '\p{isdiacriticalssup}', "");
Expect(0, 7679, '\p{^isdiacriticalssup}', "");
Expect(0, 7679, '\P{isdiacriticalssup}', "");
Expect(1, 7679, '\P{^isdiacriticalssup}', "");
Expect(0, 7680, '\p{isdiacriticalssup}', "");
Expect(1, 7680, '\p{^isdiacriticalssup}', "");
Expect(1, 7680, '\P{isdiacriticalssup}', "");
Expect(0, 7680, '\P{^isdiacriticalssup}', "");
Expect(1, 7679, '\p{-_Is_Diacriticals_Sup}', "");
Expect(0, 7679, '\p{^-_Is_Diacriticals_Sup}', "");
Expect(0, 7679, '\P{-_Is_Diacriticals_Sup}', "");
Expect(1, 7679, '\P{^-_Is_Diacriticals_Sup}', "");
Expect(0, 7680, '\p{-_Is_Diacriticals_Sup}', "");
Expect(1, 7680, '\p{^-_Is_Diacriticals_Sup}', "");
Expect(1, 7680, '\P{-_Is_Diacriticals_Sup}', "");
Expect(0, 7680, '\P{^-_Is_Diacriticals_Sup}', "");
Error('\p{	-IN_DIACRITICALS_Sup/a/}');
Error('\P{	-IN_DIACRITICALS_Sup/a/}');
Expect(1, 7679, '\p{indiacriticalssup}', "");
Expect(0, 7679, '\p{^indiacriticalssup}', "");
Expect(0, 7679, '\P{indiacriticalssup}', "");
Expect(1, 7679, '\P{^indiacriticalssup}', "");
Expect(0, 7680, '\p{indiacriticalssup}', "");
Expect(1, 7680, '\p{^indiacriticalssup}', "");
Expect(1, 7680, '\P{indiacriticalssup}', "");
Expect(0, 7680, '\P{^indiacriticalssup}', "");
Expect(1, 7679, '\p{- In_diacriticals_sup}', "");
Expect(0, 7679, '\p{^- In_diacriticals_sup}', "");
Expect(0, 7679, '\P{- In_diacriticals_sup}', "");
Expect(1, 7679, '\P{^- In_diacriticals_sup}', "");
Expect(0, 7680, '\p{- In_diacriticals_sup}', "");
Expect(1, 7680, '\p{^- In_diacriticals_sup}', "");
Expect(1, 7680, '\P{- In_diacriticals_sup}', "");
Expect(0, 7680, '\P{^- In_diacriticals_sup}', "");
Error('\p{-_Combining_Half_MARKS:=}');
Error('\P{-_Combining_Half_MARKS:=}');
Expect(1, 65071, '\p{combininghalfmarks}', "");
Expect(0, 65071, '\p{^combininghalfmarks}', "");
Expect(0, 65071, '\P{combininghalfmarks}', "");
Expect(1, 65071, '\P{^combininghalfmarks}', "");
Expect(0, 65072, '\p{combininghalfmarks}', "");
Expect(1, 65072, '\p{^combininghalfmarks}', "");
Expect(1, 65072, '\P{combininghalfmarks}', "");
Expect(0, 65072, '\P{^combininghalfmarks}', "");
Expect(1, 65071, '\p{ 	Combining_Half_Marks}', "");
Expect(0, 65071, '\p{^ 	Combining_Half_Marks}', "");
Expect(0, 65071, '\P{ 	Combining_Half_Marks}', "");
Expect(1, 65071, '\P{^ 	Combining_Half_Marks}', "");
Expect(0, 65072, '\p{ 	Combining_Half_Marks}', "");
Expect(1, 65072, '\p{^ 	Combining_Half_Marks}', "");
Expect(1, 65072, '\P{ 	Combining_Half_Marks}', "");
Expect(0, 65072, '\P{^ 	Combining_Half_Marks}', "");
Error('\p{:=- is_COMBINING_half_marks}');
Error('\P{:=- is_COMBINING_half_marks}');
Expect(1, 65071, '\p{iscombininghalfmarks}', "");
Expect(0, 65071, '\p{^iscombininghalfmarks}', "");
Expect(0, 65071, '\P{iscombininghalfmarks}', "");
Expect(1, 65071, '\P{^iscombininghalfmarks}', "");
Expect(0, 65072, '\p{iscombininghalfmarks}', "");
Expect(1, 65072, '\p{^iscombininghalfmarks}', "");
Expect(1, 65072, '\P{iscombininghalfmarks}', "");
Expect(0, 65072, '\P{^iscombininghalfmarks}', "");
Expect(1, 65071, '\p{IS_COMBINING_half_Marks}', "");
Expect(0, 65071, '\p{^IS_COMBINING_half_Marks}', "");
Expect(0, 65071, '\P{IS_COMBINING_half_Marks}', "");
Expect(1, 65071, '\P{^IS_COMBINING_half_Marks}', "");
Expect(0, 65072, '\p{IS_COMBINING_half_Marks}', "");
Expect(1, 65072, '\p{^IS_COMBINING_half_Marks}', "");
Expect(1, 65072, '\P{IS_COMBINING_half_Marks}', "");
Expect(0, 65072, '\P{^IS_COMBINING_half_Marks}', "");
Error('\p{_ In_Combining_half_Marks/a/}');
Error('\P{_ In_Combining_half_Marks/a/}');
Expect(1, 65071, '\p{incombininghalfmarks}', "");
Expect(0, 65071, '\p{^incombininghalfmarks}', "");
Expect(0, 65071, '\P{incombininghalfmarks}', "");
Expect(1, 65071, '\P{^incombininghalfmarks}', "");
Expect(0, 65072, '\p{incombininghalfmarks}', "");
Expect(1, 65072, '\p{^incombininghalfmarks}', "");
Expect(1, 65072, '\P{incombininghalfmarks}', "");
Expect(0, 65072, '\P{^incombininghalfmarks}', "");
Expect(1, 65071, '\p{	In_combining_Half_marks}', "");
Expect(0, 65071, '\p{^	In_combining_Half_marks}', "");
Expect(0, 65071, '\P{	In_combining_Half_marks}', "");
Expect(1, 65071, '\P{^	In_combining_Half_marks}', "");
Expect(0, 65072, '\p{	In_combining_Half_marks}', "");
Expect(1, 65072, '\p{^	In_combining_Half_marks}', "");
Expect(1, 65072, '\P{	In_combining_Half_marks}', "");
Expect(0, 65072, '\P{^	In_combining_Half_marks}', "");
Error('\p{	Half_Marks:=}');
Error('\P{	Half_Marks:=}');
Expect(1, 65071, '\p{halfmarks}', "");
Expect(0, 65071, '\p{^halfmarks}', "");
Expect(0, 65071, '\P{halfmarks}', "");
Expect(1, 65071, '\P{^halfmarks}', "");
Expect(0, 65072, '\p{halfmarks}', "");
Expect(1, 65072, '\p{^halfmarks}', "");
Expect(1, 65072, '\P{halfmarks}', "");
Expect(0, 65072, '\P{^halfmarks}', "");
Expect(1, 65071, '\p{-	Half_MARKS}', "");
Expect(0, 65071, '\p{^-	Half_MARKS}', "");
Expect(0, 65071, '\P{-	Half_MARKS}', "");
Expect(1, 65071, '\P{^-	Half_MARKS}', "");
Expect(0, 65072, '\p{-	Half_MARKS}', "");
Expect(1, 65072, '\p{^-	Half_MARKS}', "");
Expect(1, 65072, '\P{-	Half_MARKS}', "");
Expect(0, 65072, '\P{^-	Half_MARKS}', "");
Error('\p{ 	Is_Half_MARKS:=}');
Error('\P{ 	Is_Half_MARKS:=}');
Expect(1, 65071, '\p{ishalfmarks}', "");
Expect(0, 65071, '\p{^ishalfmarks}', "");
Expect(0, 65071, '\P{ishalfmarks}', "");
Expect(1, 65071, '\P{^ishalfmarks}', "");
Expect(0, 65072, '\p{ishalfmarks}', "");
Expect(1, 65072, '\p{^ishalfmarks}', "");
Expect(1, 65072, '\P{ishalfmarks}', "");
Expect(0, 65072, '\P{^ishalfmarks}', "");
Expect(1, 65071, '\p{--is_HALF_Marks}', "");
Expect(0, 65071, '\p{^--is_HALF_Marks}', "");
Expect(0, 65071, '\P{--is_HALF_Marks}', "");
Expect(1, 65071, '\P{^--is_HALF_Marks}', "");
Expect(0, 65072, '\p{--is_HALF_Marks}', "");
Expect(1, 65072, '\p{^--is_HALF_Marks}', "");
Expect(1, 65072, '\P{--is_HALF_Marks}', "");
Expect(0, 65072, '\P{^--is_HALF_Marks}', "");
Error('\p{__In_Half_marks:=}');
Error('\P{__In_Half_marks:=}');
Expect(1, 65071, '\p{inhalfmarks}', "");
Expect(0, 65071, '\p{^inhalfmarks}', "");
Expect(0, 65071, '\P{inhalfmarks}', "");
Expect(1, 65071, '\P{^inhalfmarks}', "");
Expect(0, 65072, '\p{inhalfmarks}', "");
Expect(1, 65072, '\p{^inhalfmarks}', "");
Expect(1, 65072, '\P{inhalfmarks}', "");
Expect(0, 65072, '\P{^inhalfmarks}', "");
Expect(1, 65071, '\p{  In_half_marks}', "");
Expect(0, 65071, '\p{^  In_half_marks}', "");
Expect(0, 65071, '\P{  In_half_marks}', "");
Expect(1, 65071, '\P{^  In_half_marks}', "");
Expect(0, 65072, '\p{  In_half_marks}', "");
Expect(1, 65072, '\p{^  In_half_marks}', "");
Expect(1, 65072, '\P{  In_half_marks}', "");
Expect(0, 65072, '\P{^  In_half_marks}', "");
Error('\p{	:=COMMON}');
Error('\P{	:=COMMON}');
Expect(1, 917631, '\p{common}', "");
Expect(0, 917631, '\p{^common}', "");
Expect(0, 917631, '\P{common}', "");
Expect(1, 917631, '\P{^common}', "");
Expect(0, 917632, '\p{common}', "");
Expect(1, 917632, '\p{^common}', "");
Expect(1, 917632, '\P{common}', "");
Expect(0, 917632, '\P{^common}', "");
Expect(1, 917631, '\p{_common}', "");
Expect(0, 917631, '\p{^_common}', "");
Expect(0, 917631, '\P{_common}', "");
Expect(1, 917631, '\P{^_common}', "");
Expect(0, 917632, '\p{_common}', "");
Expect(1, 917632, '\p{^_common}', "");
Expect(1, 917632, '\P{_common}', "");
Expect(0, 917632, '\P{^_common}', "");
Error('\p{-:=is_common}');
Error('\P{-:=is_common}');
Expect(1, 917631, '\p{iscommon}', "");
Expect(0, 917631, '\p{^iscommon}', "");
Expect(0, 917631, '\P{iscommon}', "");
Expect(1, 917631, '\P{^iscommon}', "");
Expect(0, 917632, '\p{iscommon}', "");
Expect(1, 917632, '\p{^iscommon}', "");
Expect(1, 917632, '\P{iscommon}', "");
Expect(0, 917632, '\P{^iscommon}', "");
Expect(1, 917631, '\p{__Is_Common}', "");
Expect(0, 917631, '\p{^__Is_Common}', "");
Expect(0, 917631, '\P{__Is_Common}', "");
Expect(1, 917631, '\P{^__Is_Common}', "");
Expect(0, 917632, '\p{__Is_Common}', "");
Expect(1, 917632, '\p{^__Is_Common}', "");
Expect(1, 917632, '\P{__Is_Common}', "");
Expect(0, 917632, '\P{^__Is_Common}', "");
Error('\p{ Zyyy/a/}');
Error('\P{ Zyyy/a/}');
Expect(1, 917631, '\p{zyyy}', "");
Expect(0, 917631, '\p{^zyyy}', "");
Expect(0, 917631, '\P{zyyy}', "");
Expect(1, 917631, '\P{^zyyy}', "");
Expect(0, 917632, '\p{zyyy}', "");
Expect(1, 917632, '\p{^zyyy}', "");
Expect(1, 917632, '\P{zyyy}', "");
Expect(0, 917632, '\P{^zyyy}', "");
Expect(1, 917631, '\p{_Zyyy}', "");
Expect(0, 917631, '\p{^_Zyyy}', "");
Expect(0, 917631, '\P{_Zyyy}', "");
Expect(1, 917631, '\P{^_Zyyy}', "");
Expect(0, 917632, '\p{_Zyyy}', "");
Expect(1, 917632, '\p{^_Zyyy}', "");
Expect(1, 917632, '\P{_Zyyy}', "");
Expect(0, 917632, '\P{^_Zyyy}', "");
Error('\p{_/a/Is_ZYYY}');
Error('\P{_/a/Is_ZYYY}');
Expect(1, 917631, '\p{iszyyy}', "");
Expect(0, 917631, '\p{^iszyyy}', "");
Expect(0, 917631, '\P{iszyyy}', "");
Expect(1, 917631, '\P{^iszyyy}', "");
Expect(0, 917632, '\p{iszyyy}', "");
Expect(1, 917632, '\p{^iszyyy}', "");
Expect(1, 917632, '\P{iszyyy}', "");
Expect(0, 917632, '\P{^iszyyy}', "");
Expect(1, 917631, '\p{		is_ZYYY}', "");
Expect(0, 917631, '\p{^		is_ZYYY}', "");
Expect(0, 917631, '\P{		is_ZYYY}', "");
Expect(1, 917631, '\P{^		is_ZYYY}', "");
Expect(0, 917632, '\p{		is_ZYYY}', "");
Expect(1, 917632, '\p{^		is_ZYYY}', "");
Expect(1, 917632, '\P{		is_ZYYY}', "");
Expect(0, 917632, '\P{^		is_ZYYY}', "");
Error('\p{	/a/common_Indic_Number_forms}');
Error('\P{	/a/common_Indic_Number_forms}');
Expect(1, 43071, '\p{commonindicnumberforms}', "");
Expect(0, 43071, '\p{^commonindicnumberforms}', "");
Expect(0, 43071, '\P{commonindicnumberforms}', "");
Expect(1, 43071, '\P{^commonindicnumberforms}', "");
Expect(0, 43072, '\p{commonindicnumberforms}', "");
Expect(1, 43072, '\p{^commonindicnumberforms}', "");
Expect(1, 43072, '\P{commonindicnumberforms}', "");
Expect(0, 43072, '\P{^commonindicnumberforms}', "");
Expect(1, 43071, '\p{-	Common_indic_number_forms}', "");
Expect(0, 43071, '\p{^-	Common_indic_number_forms}', "");
Expect(0, 43071, '\P{-	Common_indic_number_forms}', "");
Expect(1, 43071, '\P{^-	Common_indic_number_forms}', "");
Expect(0, 43072, '\p{-	Common_indic_number_forms}', "");
Expect(1, 43072, '\p{^-	Common_indic_number_forms}', "");
Expect(1, 43072, '\P{-	Common_indic_number_forms}', "");
Expect(0, 43072, '\P{^-	Common_indic_number_forms}', "");
Error('\p{/a/_-Is_COMMON_Indic_number_FORMS}');
Error('\P{/a/_-Is_COMMON_Indic_number_FORMS}');
Expect(1, 43071, '\p{iscommonindicnumberforms}', "");
Expect(0, 43071, '\p{^iscommonindicnumberforms}', "");
Expect(0, 43071, '\P{iscommonindicnumberforms}', "");
Expect(1, 43071, '\P{^iscommonindicnumberforms}', "");
Expect(0, 43072, '\p{iscommonindicnumberforms}', "");
Expect(1, 43072, '\p{^iscommonindicnumberforms}', "");
Expect(1, 43072, '\P{iscommonindicnumberforms}', "");
Expect(0, 43072, '\P{^iscommonindicnumberforms}', "");
Expect(1, 43071, '\p{-_is_Common_indic_Number_Forms}', "");
Expect(0, 43071, '\p{^-_is_Common_indic_Number_Forms}', "");
Expect(0, 43071, '\P{-_is_Common_indic_Number_Forms}', "");
Expect(1, 43071, '\P{^-_is_Common_indic_Number_Forms}', "");
Expect(0, 43072, '\p{-_is_Common_indic_Number_Forms}', "");
Expect(1, 43072, '\p{^-_is_Common_indic_Number_Forms}', "");
Expect(1, 43072, '\P{-_is_Common_indic_Number_Forms}', "");
Expect(0, 43072, '\P{^-_is_Common_indic_Number_Forms}', "");
Error('\p{_:=In_Common_INDIC_number_forms}');
Error('\P{_:=In_Common_INDIC_number_forms}');
Expect(1, 43071, '\p{incommonindicnumberforms}', "");
Expect(0, 43071, '\p{^incommonindicnumberforms}', "");
Expect(0, 43071, '\P{incommonindicnumberforms}', "");
Expect(1, 43071, '\P{^incommonindicnumberforms}', "");
Expect(0, 43072, '\p{incommonindicnumberforms}', "");
Expect(1, 43072, '\p{^incommonindicnumberforms}', "");
Expect(1, 43072, '\P{incommonindicnumberforms}', "");
Expect(0, 43072, '\P{^incommonindicnumberforms}', "");
Expect(1, 43071, '\p{--in_Common_Indic_number_FORMS}', "");
Expect(0, 43071, '\p{^--in_Common_Indic_number_FORMS}', "");
Expect(0, 43071, '\P{--in_Common_Indic_number_FORMS}', "");
Expect(1, 43071, '\P{^--in_Common_Indic_number_FORMS}', "");
Expect(0, 43072, '\p{--in_Common_Indic_number_FORMS}', "");
Expect(1, 43072, '\p{^--in_Common_Indic_number_FORMS}', "");
Expect(1, 43072, '\P{--in_Common_Indic_number_FORMS}', "");
Expect(0, 43072, '\P{^--in_Common_Indic_number_FORMS}', "");
Error('\p{:=-	Indic_NUMBER_forms}');
Error('\P{:=-	Indic_NUMBER_forms}');
Expect(1, 43071, '\p{indicnumberforms}', "");
Expect(0, 43071, '\p{^indicnumberforms}', "");
Expect(0, 43071, '\P{indicnumberforms}', "");
Expect(1, 43071, '\P{^indicnumberforms}', "");
Expect(0, 43072, '\p{indicnumberforms}', "");
Expect(1, 43072, '\p{^indicnumberforms}', "");
Expect(1, 43072, '\P{indicnumberforms}', "");
Expect(0, 43072, '\P{^indicnumberforms}', "");
Expect(1, 43071, '\p{-Indic_Number_Forms}', "");
Expect(0, 43071, '\p{^-Indic_Number_Forms}', "");
Expect(0, 43071, '\P{-Indic_Number_Forms}', "");
Expect(1, 43071, '\P{^-Indic_Number_Forms}', "");
Expect(0, 43072, '\p{-Indic_Number_Forms}', "");
Expect(1, 43072, '\p{^-Indic_Number_Forms}', "");
Expect(1, 43072, '\P{-Indic_Number_Forms}', "");
Expect(0, 43072, '\P{^-Indic_Number_Forms}', "");
Error('\p{  IS_indic_Number_FORMS/a/}');
Error('\P{  IS_indic_Number_FORMS/a/}');
Expect(1, 43071, '\p{isindicnumberforms}', "");
Expect(0, 43071, '\p{^isindicnumberforms}', "");
Expect(0, 43071, '\P{isindicnumberforms}', "");
Expect(1, 43071, '\P{^isindicnumberforms}', "");
Expect(0, 43072, '\p{isindicnumberforms}', "");
Expect(1, 43072, '\p{^isindicnumberforms}', "");
Expect(1, 43072, '\P{isindicnumberforms}', "");
Expect(0, 43072, '\P{^isindicnumberforms}', "");
Expect(1, 43071, '\p{ IS_INDIC_Number_Forms}', "");
Expect(0, 43071, '\p{^ IS_INDIC_Number_Forms}', "");
Expect(0, 43071, '\P{ IS_INDIC_Number_Forms}', "");
Expect(1, 43071, '\P{^ IS_INDIC_Number_Forms}', "");
Expect(0, 43072, '\p{ IS_INDIC_Number_Forms}', "");
Expect(1, 43072, '\p{^ IS_INDIC_Number_Forms}', "");
Expect(1, 43072, '\P{ IS_INDIC_Number_Forms}', "");
Expect(0, 43072, '\P{^ IS_INDIC_Number_Forms}', "");
Error('\p{/a/	 in_indic_number_FORMS}');
Error('\P{/a/	 in_indic_number_FORMS}');
Expect(1, 43071, '\p{inindicnumberforms}', "");
Expect(0, 43071, '\p{^inindicnumberforms}', "");
Expect(0, 43071, '\P{inindicnumberforms}', "");
Expect(1, 43071, '\P{^inindicnumberforms}', "");
Expect(0, 43072, '\p{inindicnumberforms}', "");
Expect(1, 43072, '\p{^inindicnumberforms}', "");
Expect(1, 43072, '\P{inindicnumberforms}', "");
Expect(0, 43072, '\P{^inindicnumberforms}', "");
Expect(1, 43071, '\p{	in_Indic_NUMBER_Forms}', "");
Expect(0, 43071, '\p{^	in_Indic_NUMBER_Forms}', "");
Expect(0, 43071, '\P{	in_Indic_NUMBER_Forms}', "");
Expect(1, 43071, '\P{^	in_Indic_NUMBER_Forms}', "");
Expect(0, 43072, '\p{	in_Indic_NUMBER_Forms}', "");
Expect(1, 43072, '\p{^	in_Indic_NUMBER_Forms}', "");
Expect(1, 43072, '\P{	in_Indic_NUMBER_Forms}', "");
Expect(0, 43072, '\P{^	in_Indic_NUMBER_Forms}', "");
Error('\p{:=-	Composition_Exclusion}');
Error('\P{:=-	Composition_Exclusion}');
Expect(1, 119232, '\p{compositionexclusion}', "");
Expect(0, 119232, '\p{^compositionexclusion}', "");
Expect(0, 119232, '\P{compositionexclusion}', "");
Expect(1, 119232, '\P{^compositionexclusion}', "");
Expect(0, 119233, '\p{compositionexclusion}', "");
Expect(1, 119233, '\p{^compositionexclusion}', "");
Expect(1, 119233, '\P{compositionexclusion}', "");
Expect(0, 119233, '\P{^compositionexclusion}', "");
Expect(1, 119232, '\p{__Composition_exclusion}', "");
Expect(0, 119232, '\p{^__Composition_exclusion}', "");
Expect(0, 119232, '\P{__Composition_exclusion}', "");
Expect(1, 119232, '\P{^__Composition_exclusion}', "");
Expect(0, 119233, '\p{__Composition_exclusion}', "");
Expect(1, 119233, '\p{^__Composition_exclusion}', "");
Expect(1, 119233, '\P{__Composition_exclusion}', "");
Expect(0, 119233, '\P{^__Composition_exclusion}', "");
Error('\p{	 Is_COMPOSITION_Exclusion/a/}');
Error('\P{	 Is_COMPOSITION_Exclusion/a/}');
Expect(1, 119232, '\p{iscompositionexclusion}', "");
Expect(0, 119232, '\p{^iscompositionexclusion}', "");
Expect(0, 119232, '\P{iscompositionexclusion}', "");
Expect(1, 119232, '\P{^iscompositionexclusion}', "");
Expect(0, 119233, '\p{iscompositionexclusion}', "");
Expect(1, 119233, '\p{^iscompositionexclusion}', "");
Expect(1, 119233, '\P{iscompositionexclusion}', "");
Expect(0, 119233, '\P{^iscompositionexclusion}', "");
Expect(1, 119232, '\p{__IS_COMPOSITION_exclusion}', "");
Expect(0, 119232, '\p{^__IS_COMPOSITION_exclusion}', "");
Expect(0, 119232, '\P{__IS_COMPOSITION_exclusion}', "");
Expect(1, 119232, '\P{^__IS_COMPOSITION_exclusion}', "");
Expect(0, 119233, '\p{__IS_COMPOSITION_exclusion}', "");
Expect(1, 119233, '\p{^__IS_COMPOSITION_exclusion}', "");
Expect(1, 119233, '\P{__IS_COMPOSITION_exclusion}', "");
Expect(0, 119233, '\P{^__IS_COMPOSITION_exclusion}', "");
Error('\p{/a/-	ce}');
Error('\P{/a/-	ce}');
Expect(1, 119232, '\p{ce}', "");
Expect(0, 119232, '\p{^ce}', "");
Expect(0, 119232, '\P{ce}', "");
Expect(1, 119232, '\P{^ce}', "");
Expect(0, 119233, '\p{ce}', "");
Expect(1, 119233, '\p{^ce}', "");
Expect(1, 119233, '\P{ce}', "");
Expect(0, 119233, '\P{^ce}', "");
Expect(1, 119232, '\p{	CE}', "");
Expect(0, 119232, '\p{^	CE}', "");
Expect(0, 119232, '\P{	CE}', "");
Expect(1, 119232, '\P{^	CE}', "");
Expect(0, 119233, '\p{	CE}', "");
Expect(1, 119233, '\p{^	CE}', "");
Expect(1, 119233, '\P{	CE}', "");
Expect(0, 119233, '\P{^	CE}', "");
Error('\p{_:=Is_ce}');
Error('\P{_:=Is_ce}');
Expect(1, 119232, '\p{isce}', "");
Expect(0, 119232, '\p{^isce}', "");
Expect(0, 119232, '\P{isce}', "");
Expect(1, 119232, '\P{^isce}', "");
Expect(0, 119233, '\p{isce}', "");
Expect(1, 119233, '\p{^isce}', "");
Expect(1, 119233, '\P{isce}', "");
Expect(0, 119233, '\P{^isce}', "");
Expect(1, 119232, '\p{__is_CE}', "");
Expect(0, 119232, '\p{^__is_CE}', "");
Expect(0, 119232, '\P{__is_CE}', "");
Expect(1, 119232, '\P{^__is_CE}', "");
Expect(0, 119233, '\p{__is_CE}', "");
Expect(1, 119233, '\p{^__is_CE}', "");
Expect(1, 119233, '\P{__is_CE}', "");
Expect(0, 119233, '\P{^__is_CE}', "");
Error('\p{:=_	CONNECTOR_punctuation}');
Error('\P{:=_	CONNECTOR_punctuation}');
Expect(1, 65343, '\p{connectorpunctuation}', "");
Expect(0, 65343, '\p{^connectorpunctuation}', "");
Expect(0, 65343, '\P{connectorpunctuation}', "");
Expect(1, 65343, '\P{^connectorpunctuation}', "");
Expect(0, 65344, '\p{connectorpunctuation}', "");
Expect(1, 65344, '\p{^connectorpunctuation}', "");
Expect(1, 65344, '\P{connectorpunctuation}', "");
Expect(0, 65344, '\P{^connectorpunctuation}', "");
Expect(1, 65343, '\p{--Connector_Punctuation}', "");
Expect(0, 65343, '\p{^--Connector_Punctuation}', "");
Expect(0, 65343, '\P{--Connector_Punctuation}', "");
Expect(1, 65343, '\P{^--Connector_Punctuation}', "");
Expect(0, 65344, '\p{--Connector_Punctuation}', "");
Expect(1, 65344, '\p{^--Connector_Punctuation}', "");
Expect(1, 65344, '\P{--Connector_Punctuation}', "");
Expect(0, 65344, '\P{^--Connector_Punctuation}', "");
Error('\p{_ Is_Connector_Punctuation/a/}');
Error('\P{_ Is_Connector_Punctuation/a/}');
Expect(1, 65343, '\p{isconnectorpunctuation}', "");
Expect(0, 65343, '\p{^isconnectorpunctuation}', "");
Expect(0, 65343, '\P{isconnectorpunctuation}', "");
Expect(1, 65343, '\P{^isconnectorpunctuation}', "");
Expect(0, 65344, '\p{isconnectorpunctuation}', "");
Expect(1, 65344, '\p{^isconnectorpunctuation}', "");
Expect(1, 65344, '\P{isconnectorpunctuation}', "");
Expect(0, 65344, '\P{^isconnectorpunctuation}', "");
Expect(1, 65343, '\p{IS_connector_punctuation}', "");
Expect(0, 65343, '\p{^IS_connector_punctuation}', "");
Expect(0, 65343, '\P{IS_connector_punctuation}', "");
Expect(1, 65343, '\P{^IS_connector_punctuation}', "");
Expect(0, 65344, '\p{IS_connector_punctuation}', "");
Expect(1, 65344, '\p{^IS_connector_punctuation}', "");
Expect(1, 65344, '\P{IS_connector_punctuation}', "");
Expect(0, 65344, '\P{^IS_connector_punctuation}', "");
Error('\p{:=PC}');
Error('\P{:=PC}');
Expect(1, 65343, '\p{pc}', "");
Expect(0, 65343, '\p{^pc}', "");
Expect(0, 65343, '\P{pc}', "");
Expect(1, 65343, '\P{^pc}', "");
Expect(0, 65344, '\p{pc}', "");
Expect(1, 65344, '\p{^pc}', "");
Expect(1, 65344, '\P{pc}', "");
Expect(0, 65344, '\P{^pc}', "");
Expect(1, 65343, '\p{_	PC}', "");
Expect(0, 65343, '\p{^_	PC}', "");
Expect(0, 65343, '\P{_	PC}', "");
Expect(1, 65343, '\P{^_	PC}', "");
Expect(0, 65344, '\p{_	PC}', "");
Expect(1, 65344, '\p{^_	PC}', "");
Expect(1, 65344, '\P{_	PC}', "");
Expect(0, 65344, '\P{^_	PC}', "");
Error('\p{_	is_Pc/a/}');
Error('\P{_	is_Pc/a/}');
Expect(1, 65343, '\p{ispc}', "");
Expect(0, 65343, '\p{^ispc}', "");
Expect(0, 65343, '\P{ispc}', "");
Expect(1, 65343, '\P{^ispc}', "");
Expect(0, 65344, '\p{ispc}', "");
Expect(1, 65344, '\p{^ispc}', "");
Expect(1, 65344, '\P{ispc}', "");
Expect(0, 65344, '\P{^ispc}', "");
Expect(1, 65343, '\p{  IS_PC}', "");
Expect(0, 65343, '\p{^  IS_PC}', "");
Expect(0, 65343, '\P{  IS_PC}', "");
Expect(1, 65343, '\P{^  IS_PC}', "");
Expect(0, 65344, '\p{  IS_PC}', "");
Expect(1, 65344, '\p{^  IS_PC}', "");
Expect(1, 65344, '\P{  IS_PC}', "");
Expect(0, 65344, '\P{^  IS_PC}', "");
Error('\p{/a/-_Control_Pictures}');
Error('\P{/a/-_Control_Pictures}');
Expect(1, 9279, '\p{controlpictures}', "");
Expect(0, 9279, '\p{^controlpictures}', "");
Expect(0, 9279, '\P{controlpictures}', "");
Expect(1, 9279, '\P{^controlpictures}', "");
Expect(0, 9280, '\p{controlpictures}', "");
Expect(1, 9280, '\p{^controlpictures}', "");
Expect(1, 9280, '\P{controlpictures}', "");
Expect(0, 9280, '\P{^controlpictures}', "");
Expect(1, 9279, '\p{ 	control_Pictures}', "");
Expect(0, 9279, '\p{^ 	control_Pictures}', "");
Expect(0, 9279, '\P{ 	control_Pictures}', "");
Expect(1, 9279, '\P{^ 	control_Pictures}', "");
Expect(0, 9280, '\p{ 	control_Pictures}', "");
Expect(1, 9280, '\p{^ 	control_Pictures}', "");
Expect(1, 9280, '\P{ 	control_Pictures}', "");
Expect(0, 9280, '\P{^ 	control_Pictures}', "");
Error('\p{/a/	Is_Control_Pictures}');
Error('\P{/a/	Is_Control_Pictures}');
Expect(1, 9279, '\p{iscontrolpictures}', "");
Expect(0, 9279, '\p{^iscontrolpictures}', "");
Expect(0, 9279, '\P{iscontrolpictures}', "");
Expect(1, 9279, '\P{^iscontrolpictures}', "");
Expect(0, 9280, '\p{iscontrolpictures}', "");
Expect(1, 9280, '\p{^iscontrolpictures}', "");
Expect(1, 9280, '\P{iscontrolpictures}', "");
Expect(0, 9280, '\P{^iscontrolpictures}', "");
Expect(1, 9279, '\p{	-is_control_PICTURES}', "");
Expect(0, 9279, '\p{^	-is_control_PICTURES}', "");
Expect(0, 9279, '\P{	-is_control_PICTURES}', "");
Expect(1, 9279, '\P{^	-is_control_PICTURES}', "");
Expect(0, 9280, '\p{	-is_control_PICTURES}', "");
Expect(1, 9280, '\p{^	-is_control_PICTURES}', "");
Expect(1, 9280, '\P{	-is_control_PICTURES}', "");
Expect(0, 9280, '\P{^	-is_control_PICTURES}', "");
Error('\p{:= In_CONTROL_PICTURES}');
Error('\P{:= In_CONTROL_PICTURES}');
Expect(1, 9279, '\p{incontrolpictures}', "");
Expect(0, 9279, '\p{^incontrolpictures}', "");
Expect(0, 9279, '\P{incontrolpictures}', "");
Expect(1, 9279, '\P{^incontrolpictures}', "");
Expect(0, 9280, '\p{incontrolpictures}', "");
Expect(1, 9280, '\p{^incontrolpictures}', "");
Expect(1, 9280, '\P{incontrolpictures}', "");
Expect(0, 9280, '\P{^incontrolpictures}', "");
Expect(1, 9279, '\p{In_Control_Pictures}', "");
Expect(0, 9279, '\p{^In_Control_Pictures}', "");
Expect(0, 9279, '\P{In_Control_Pictures}', "");
Expect(1, 9279, '\P{^In_Control_Pictures}', "");
Expect(0, 9280, '\p{In_Control_Pictures}', "");
Expect(1, 9280, '\p{^In_Control_Pictures}', "");
Expect(1, 9280, '\P{In_Control_Pictures}', "");
Expect(0, 9280, '\P{^In_Control_Pictures}', "");
Error('\p{_ Coptic:=}');
Error('\P{_ Coptic:=}');
Expect(1, 11519, '\p{coptic}', "");
Expect(0, 11519, '\p{^coptic}', "");
Expect(0, 11519, '\P{coptic}', "");
Expect(1, 11519, '\P{^coptic}', "");
Expect(0, 11520, '\p{coptic}', "");
Expect(1, 11520, '\p{^coptic}', "");
Expect(1, 11520, '\P{coptic}', "");
Expect(0, 11520, '\P{^coptic}', "");
Expect(1, 11519, '\p{ coptic}', "");
Expect(0, 11519, '\p{^ coptic}', "");
Expect(0, 11519, '\P{ coptic}', "");
Expect(1, 11519, '\P{^ coptic}', "");
Expect(0, 11520, '\p{ coptic}', "");
Expect(1, 11520, '\p{^ coptic}', "");
Expect(1, 11520, '\P{ coptic}', "");
Expect(0, 11520, '\P{^ coptic}', "");
Error('\p{:=-Is_Coptic}');
Error('\P{:=-Is_Coptic}');
Expect(1, 11519, '\p{iscoptic}', "");
Expect(0, 11519, '\p{^iscoptic}', "");
Expect(0, 11519, '\P{iscoptic}', "");
Expect(1, 11519, '\P{^iscoptic}', "");
Expect(0, 11520, '\p{iscoptic}', "");
Expect(1, 11520, '\p{^iscoptic}', "");
Expect(1, 11520, '\P{iscoptic}', "");
Expect(0, 11520, '\P{^iscoptic}', "");
Expect(1, 11519, '\p{_IS_Coptic}', "");
Expect(0, 11519, '\p{^_IS_Coptic}', "");
Expect(0, 11519, '\P{_IS_Coptic}', "");
Expect(1, 11519, '\P{^_IS_Coptic}', "");
Expect(0, 11520, '\p{_IS_Coptic}', "");
Expect(1, 11520, '\p{^_IS_Coptic}', "");
Expect(1, 11520, '\P{_IS_Coptic}', "");
Expect(0, 11520, '\P{^_IS_Coptic}', "");
Error('\p{:=COPT}');
Error('\P{:=COPT}');
Expect(1, 11519, '\p{copt}', "");
Expect(0, 11519, '\p{^copt}', "");
Expect(0, 11519, '\P{copt}', "");
Expect(1, 11519, '\P{^copt}', "");
Expect(0, 11520, '\p{copt}', "");
Expect(1, 11520, '\p{^copt}', "");
Expect(1, 11520, '\P{copt}', "");
Expect(0, 11520, '\P{^copt}', "");
Expect(1, 11519, '\p{-	Copt}', "");
Expect(0, 11519, '\p{^-	Copt}', "");
Expect(0, 11519, '\P{-	Copt}', "");
Expect(1, 11519, '\P{^-	Copt}', "");
Expect(0, 11520, '\p{-	Copt}', "");
Expect(1, 11520, '\p{^-	Copt}', "");
Expect(1, 11520, '\P{-	Copt}', "");
Expect(0, 11520, '\P{^-	Copt}', "");
Error('\p{ :=Is_copt}');
Error('\P{ :=Is_copt}');
Expect(1, 11519, '\p{iscopt}', "");
Expect(0, 11519, '\p{^iscopt}', "");
Expect(0, 11519, '\P{iscopt}', "");
Expect(1, 11519, '\P{^iscopt}', "");
Expect(0, 11520, '\p{iscopt}', "");
Expect(1, 11520, '\p{^iscopt}', "");
Expect(1, 11520, '\P{iscopt}', "");
Expect(0, 11520, '\P{^iscopt}', "");
Expect(1, 11519, '\p{		Is_copt}', "");
Expect(0, 11519, '\p{^		Is_copt}', "");
Expect(0, 11519, '\P{		Is_copt}', "");
Expect(1, 11519, '\P{^		Is_copt}', "");
Expect(0, 11520, '\p{		Is_copt}', "");
Expect(1, 11520, '\p{^		Is_copt}', "");
Expect(1, 11520, '\P{		Is_copt}', "");
Expect(0, 11520, '\P{^		Is_copt}', "");
Error('\p{/a/-_qaac}');
Error('\P{/a/-_qaac}');
Expect(1, 11519, '\p{qaac}', "");
Expect(0, 11519, '\p{^qaac}', "");
Expect(0, 11519, '\P{qaac}', "");
Expect(1, 11519, '\P{^qaac}', "");
Expect(0, 11520, '\p{qaac}', "");
Expect(1, 11520, '\p{^qaac}', "");
Expect(1, 11520, '\P{qaac}', "");
Expect(0, 11520, '\P{^qaac}', "");
Expect(1, 11519, '\p{ -qaac}', "");
Expect(0, 11519, '\p{^ -qaac}', "");
Expect(0, 11519, '\P{ -qaac}', "");
Expect(1, 11519, '\P{^ -qaac}', "");
Expect(0, 11520, '\p{ -qaac}', "");
Expect(1, 11520, '\p{^ -qaac}', "");
Expect(1, 11520, '\P{ -qaac}', "");
Expect(0, 11520, '\P{^ -qaac}', "");
Error('\p{ Is_qaac:=}');
Error('\P{ Is_qaac:=}');
Expect(1, 11519, '\p{isqaac}', "");
Expect(0, 11519, '\p{^isqaac}', "");
Expect(0, 11519, '\P{isqaac}', "");
Expect(1, 11519, '\P{^isqaac}', "");
Expect(0, 11520, '\p{isqaac}', "");
Expect(1, 11520, '\p{^isqaac}', "");
Expect(1, 11520, '\P{isqaac}', "");
Expect(0, 11520, '\P{^isqaac}', "");
Expect(1, 11519, '\p{ -Is_Qaac}', "");
Expect(0, 11519, '\p{^ -Is_Qaac}', "");
Expect(0, 11519, '\P{ -Is_Qaac}', "");
Expect(1, 11519, '\P{^ -Is_Qaac}', "");
Expect(0, 11520, '\p{ -Is_Qaac}', "");
Expect(1, 11520, '\p{^ -Is_Qaac}', "");
Expect(1, 11520, '\P{ -Is_Qaac}', "");
Expect(0, 11520, '\P{^ -Is_Qaac}', "");
Error('\p{ counting_ROD_NUMERALS:=}');
Error('\P{ counting_ROD_NUMERALS:=}');
Expect(1, 119679, '\p{countingrodnumerals}', "");
Expect(0, 119679, '\p{^countingrodnumerals}', "");
Expect(0, 119679, '\P{countingrodnumerals}', "");
Expect(1, 119679, '\P{^countingrodnumerals}', "");
Expect(0, 119680, '\p{countingrodnumerals}', "");
Expect(1, 119680, '\p{^countingrodnumerals}', "");
Expect(1, 119680, '\P{countingrodnumerals}', "");
Expect(0, 119680, '\P{^countingrodnumerals}', "");
Expect(1, 119679, '\p{_	Counting_Rod_Numerals}', "");
Expect(0, 119679, '\p{^_	Counting_Rod_Numerals}', "");
Expect(0, 119679, '\P{_	Counting_Rod_Numerals}', "");
Expect(1, 119679, '\P{^_	Counting_Rod_Numerals}', "");
Expect(0, 119680, '\p{_	Counting_Rod_Numerals}', "");
Expect(1, 119680, '\p{^_	Counting_Rod_Numerals}', "");
Expect(1, 119680, '\P{_	Counting_Rod_Numerals}', "");
Expect(0, 119680, '\P{^_	Counting_Rod_Numerals}', "");
Error('\p{  IS_COUNTING_rod_NUMERALS/a/}');
Error('\P{  IS_COUNTING_rod_NUMERALS/a/}');
Expect(1, 119679, '\p{iscountingrodnumerals}', "");
Expect(0, 119679, '\p{^iscountingrodnumerals}', "");
Expect(0, 119679, '\P{iscountingrodnumerals}', "");
Expect(1, 119679, '\P{^iscountingrodnumerals}', "");
Expect(0, 119680, '\p{iscountingrodnumerals}', "");
Expect(1, 119680, '\p{^iscountingrodnumerals}', "");
Expect(1, 119680, '\P{iscountingrodnumerals}', "");
Expect(0, 119680, '\P{^iscountingrodnumerals}', "");
Expect(1, 119679, '\p{__IS_Counting_rod_numerals}', "");
Expect(0, 119679, '\p{^__IS_Counting_rod_numerals}', "");
Expect(0, 119679, '\P{__IS_Counting_rod_numerals}', "");
Expect(1, 119679, '\P{^__IS_Counting_rod_numerals}', "");
Expect(0, 119680, '\p{__IS_Counting_rod_numerals}', "");
Expect(1, 119680, '\p{^__IS_Counting_rod_numerals}', "");
Expect(1, 119680, '\P{__IS_Counting_rod_numerals}', "");
Expect(0, 119680, '\P{^__IS_Counting_rod_numerals}', "");
Error('\p{:=	_IN_Counting_Rod_Numerals}');
Error('\P{:=	_IN_Counting_Rod_Numerals}');
Expect(1, 119679, '\p{incountingrodnumerals}', "");
Expect(0, 119679, '\p{^incountingrodnumerals}', "");
Expect(0, 119679, '\P{incountingrodnumerals}', "");
Expect(1, 119679, '\P{^incountingrodnumerals}', "");
Expect(0, 119680, '\p{incountingrodnumerals}', "");
Expect(1, 119680, '\p{^incountingrodnumerals}', "");
Expect(1, 119680, '\P{incountingrodnumerals}', "");
Expect(0, 119680, '\P{^incountingrodnumerals}', "");
Expect(1, 119679, '\p{in_COUNTING_ROD_numerals}', "");
Expect(0, 119679, '\p{^in_COUNTING_ROD_numerals}', "");
Expect(0, 119679, '\P{in_COUNTING_ROD_numerals}', "");
Expect(1, 119679, '\P{^in_COUNTING_ROD_numerals}', "");
Expect(0, 119680, '\p{in_COUNTING_ROD_numerals}', "");
Expect(1, 119680, '\p{^in_COUNTING_ROD_numerals}', "");
Expect(1, 119680, '\P{in_COUNTING_ROD_numerals}', "");
Expect(0, 119680, '\P{^in_COUNTING_ROD_numerals}', "");
Error('\p{:=		Counting_rod}');
Error('\P{:=		Counting_rod}');
Expect(1, 119679, '\p{countingrod}', "");
Expect(0, 119679, '\p{^countingrod}', "");
Expect(0, 119679, '\P{countingrod}', "");
Expect(1, 119679, '\P{^countingrod}', "");
Expect(0, 119680, '\p{countingrod}', "");
Expect(1, 119680, '\p{^countingrod}', "");
Expect(1, 119680, '\P{countingrod}', "");
Expect(0, 119680, '\P{^countingrod}', "");
Expect(1, 119679, '\p{	Counting_Rod}', "");
Expect(0, 119679, '\p{^	Counting_Rod}', "");
Expect(0, 119679, '\P{	Counting_Rod}', "");
Expect(1, 119679, '\P{^	Counting_Rod}', "");
Expect(0, 119680, '\p{	Counting_Rod}', "");
Expect(1, 119680, '\p{^	Counting_Rod}', "");
Expect(1, 119680, '\P{	Counting_Rod}', "");
Expect(0, 119680, '\P{^	Counting_Rod}', "");
Error('\p{-/a/Is_counting_Rod}');
Error('\P{-/a/Is_counting_Rod}');
Expect(1, 119679, '\p{iscountingrod}', "");
Expect(0, 119679, '\p{^iscountingrod}', "");
Expect(0, 119679, '\P{iscountingrod}', "");
Expect(1, 119679, '\P{^iscountingrod}', "");
Expect(0, 119680, '\p{iscountingrod}', "");
Expect(1, 119680, '\p{^iscountingrod}', "");
Expect(1, 119680, '\P{iscountingrod}', "");
Expect(0, 119680, '\P{^iscountingrod}', "");
Expect(1, 119679, '\p{-is_Counting_Rod}', "");
Expect(0, 119679, '\p{^-is_Counting_Rod}', "");
Expect(0, 119679, '\P{-is_Counting_Rod}', "");
Expect(1, 119679, '\P{^-is_Counting_Rod}', "");
Expect(0, 119680, '\p{-is_Counting_Rod}', "");
Expect(1, 119680, '\p{^-is_Counting_Rod}', "");
Expect(1, 119680, '\P{-is_Counting_Rod}', "");
Expect(0, 119680, '\P{^-is_Counting_Rod}', "");
Error('\p{	In_COUNTING_Rod:=}');
Error('\P{	In_COUNTING_Rod:=}');
Expect(1, 119679, '\p{incountingrod}', "");
Expect(0, 119679, '\p{^incountingrod}', "");
Expect(0, 119679, '\P{incountingrod}', "");
Expect(1, 119679, '\P{^incountingrod}', "");
Expect(0, 119680, '\p{incountingrod}', "");
Expect(1, 119680, '\p{^incountingrod}', "");
Expect(1, 119680, '\P{incountingrod}', "");
Expect(0, 119680, '\P{^incountingrod}', "");
Expect(1, 119679, '\p{__in_Counting_rod}', "");
Expect(0, 119679, '\p{^__in_Counting_rod}', "");
Expect(0, 119679, '\P{__in_Counting_rod}', "");
Expect(1, 119679, '\P{^__in_Counting_rod}', "");
Expect(0, 119680, '\p{__in_Counting_rod}', "");
Expect(1, 119680, '\p{^__in_Counting_rod}', "");
Expect(1, 119680, '\P{__in_Counting_rod}', "");
Expect(0, 119680, '\P{^__in_Counting_rod}', "");
Error('\p{__Cuneiform/a/}');
Error('\P{__Cuneiform/a/}');
Expect(1, 74867, '\p{cuneiform}', "");
Expect(0, 74867, '\p{^cuneiform}', "");
Expect(0, 74867, '\P{cuneiform}', "");
Expect(1, 74867, '\P{^cuneiform}', "");
Expect(0, 74868, '\p{cuneiform}', "");
Expect(1, 74868, '\p{^cuneiform}', "");
Expect(1, 74868, '\P{cuneiform}', "");
Expect(0, 74868, '\P{^cuneiform}', "");
Expect(1, 74867, '\p{__Cuneiform}', "");
Expect(0, 74867, '\p{^__Cuneiform}', "");
Expect(0, 74867, '\P{__Cuneiform}', "");
Expect(1, 74867, '\P{^__Cuneiform}', "");
Expect(0, 74868, '\p{__Cuneiform}', "");
Expect(1, 74868, '\p{^__Cuneiform}', "");
Expect(1, 74868, '\P{__Cuneiform}', "");
Expect(0, 74868, '\P{^__Cuneiform}', "");
Error('\p{/a/	is_Cuneiform}');
Error('\P{/a/	is_Cuneiform}');
Expect(1, 74867, '\p{iscuneiform}', "");
Expect(0, 74867, '\p{^iscuneiform}', "");
Expect(0, 74867, '\P{iscuneiform}', "");
Expect(1, 74867, '\P{^iscuneiform}', "");
Expect(0, 74868, '\p{iscuneiform}', "");
Expect(1, 74868, '\p{^iscuneiform}', "");
Expect(1, 74868, '\P{iscuneiform}', "");
Expect(0, 74868, '\P{^iscuneiform}', "");
Expect(1, 74867, '\p{- Is_Cuneiform}', "");
Expect(0, 74867, '\p{^- Is_Cuneiform}', "");
Expect(0, 74867, '\P{- Is_Cuneiform}', "");
Expect(1, 74867, '\P{^- Is_Cuneiform}', "");
Expect(0, 74868, '\p{- Is_Cuneiform}', "");
Expect(1, 74868, '\p{^- Is_Cuneiform}', "");
Expect(1, 74868, '\P{- Is_Cuneiform}', "");
Expect(0, 74868, '\P{^- Is_Cuneiform}', "");
Error('\p{_/a/Xsux}');
Error('\P{_/a/Xsux}');
Expect(1, 74867, '\p{xsux}', "");
Expect(0, 74867, '\p{^xsux}', "");
Expect(0, 74867, '\P{xsux}', "");
Expect(1, 74867, '\P{^xsux}', "");
Expect(0, 74868, '\p{xsux}', "");
Expect(1, 74868, '\p{^xsux}', "");
Expect(1, 74868, '\P{xsux}', "");
Expect(0, 74868, '\P{^xsux}', "");
Expect(1, 74867, '\p{-XSUX}', "");
Expect(0, 74867, '\p{^-XSUX}', "");
Expect(0, 74867, '\P{-XSUX}', "");
Expect(1, 74867, '\P{^-XSUX}', "");
Expect(0, 74868, '\p{-XSUX}', "");
Expect(1, 74868, '\p{^-XSUX}', "");
Expect(1, 74868, '\P{-XSUX}', "");
Expect(0, 74868, '\P{^-XSUX}', "");
Error('\p{:=_ Is_XSUX}');
Error('\P{:=_ Is_XSUX}');
Expect(1, 74867, '\p{isxsux}', "");
Expect(0, 74867, '\p{^isxsux}', "");
Expect(0, 74867, '\P{isxsux}', "");
Expect(1, 74867, '\P{^isxsux}', "");
Expect(0, 74868, '\p{isxsux}', "");
Expect(1, 74868, '\p{^isxsux}', "");
Expect(1, 74868, '\P{isxsux}', "");
Expect(0, 74868, '\P{^isxsux}', "");
Expect(1, 74867, '\p{-is_xsux}', "");
Expect(0, 74867, '\p{^-is_xsux}', "");
Expect(0, 74867, '\P{-is_xsux}', "");
Expect(1, 74867, '\P{^-is_xsux}', "");
Expect(0, 74868, '\p{-is_xsux}', "");
Expect(1, 74868, '\p{^-is_xsux}', "");
Expect(1, 74868, '\P{-is_xsux}', "");
Expect(0, 74868, '\P{^-is_xsux}', "");
Error('\p{:=	cuneiform_Numbers_And_PUNCTUATION}');
Error('\P{:=	cuneiform_Numbers_And_PUNCTUATION}');
Expect(1, 74879, '\p{cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^cuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^cuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{cuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^cuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(0, 74879, '\p{^CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(0, 74879, '\P{CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(1, 74879, '\P{^CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(0, 74880, '\p{CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(1, 74880, '\p{^CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(1, 74880, '\P{CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Expect(0, 74880, '\P{^CUNEIFORM_Numbers_AND_PUNCTUATION}', "");
Error('\p{_	Is_Cuneiform_Numbers_And_Punctuation:=}');
Error('\P{_	Is_Cuneiform_Numbers_And_Punctuation:=}');
Expect(1, 74879, '\p{iscuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^iscuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{iscuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^iscuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{iscuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^iscuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{iscuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^iscuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(0, 74879, '\p{^_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(0, 74879, '\P{_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(1, 74879, '\P{^_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(0, 74880, '\p{_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(1, 74880, '\p{^_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(1, 74880, '\P{_IS_cuneiform_numbers_AND_punctuation}', "");
Expect(0, 74880, '\P{^_IS_cuneiform_numbers_AND_punctuation}', "");
Error('\p{	:=IN_cuneiform_numbers_And_Punctuation}');
Error('\P{	:=IN_cuneiform_numbers_And_Punctuation}');
Expect(1, 74879, '\p{incuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\p{^incuneiformnumbersandpunctuation}', "");
Expect(0, 74879, '\P{incuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\P{^incuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\p{incuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\p{^incuneiformnumbersandpunctuation}', "");
Expect(1, 74880, '\P{incuneiformnumbersandpunctuation}', "");
Expect(0, 74880, '\P{^incuneiformnumbersandpunctuation}', "");
Expect(1, 74879, '\p{in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74879, '\p{^in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74879, '\P{in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(1, 74879, '\P{^in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74880, '\p{in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(1, 74880, '\p{^in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(1, 74880, '\P{in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Expect(0, 74880, '\P{^in_CUNEIFORM_Numbers_And_PUNCTUATION}', "");
Error('\p{_/a/Cuneiform_Numbers}');
Error('\P{_/a/Cuneiform_Numbers}');
Expect(1, 74879, '\p{cuneiformnumbers}', "");
Expect(0, 74879, '\p{^cuneiformnumbers}', "");
Expect(0, 74879, '\P{cuneiformnumbers}', "");
Expect(1, 74879, '\P{^cuneiformnumbers}', "");
Expect(0, 74880, '\p{cuneiformnumbers}', "");
Expect(1, 74880, '\p{^cuneiformnumbers}', "");
Expect(1, 74880, '\P{cuneiformnumbers}', "");
Expect(0, 74880, '\P{^cuneiformnumbers}', "");
Expect(1, 74879, '\p{	_cuneiform_numbers}', "");
Expect(0, 74879, '\p{^	_cuneiform_numbers}', "");
Expect(0, 74879, '\P{	_cuneiform_numbers}', "");
Expect(1, 74879, '\P{^	_cuneiform_numbers}', "");
Expect(0, 74880, '\p{	_cuneiform_numbers}', "");
Expect(1, 74880, '\p{^	_cuneiform_numbers}', "");
Expect(1, 74880, '\P{	_cuneiform_numbers}', "");
Expect(0, 74880, '\P{^	_cuneiform_numbers}', "");
Error('\p{/a/IS_CUNEIFORM_Numbers}');
Error('\P{/a/IS_CUNEIFORM_Numbers}');
Expect(1, 74879, '\p{iscuneiformnumbers}', "");
Expect(0, 74879, '\p{^iscuneiformnumbers}', "");
Expect(0, 74879, '\P{iscuneiformnumbers}', "");
Expect(1, 74879, '\P{^iscuneiformnumbers}', "");
Expect(0, 74880, '\p{iscuneiformnumbers}', "");
Expect(1, 74880, '\p{^iscuneiformnumbers}', "");
Expect(1, 74880, '\P{iscuneiformnumbers}', "");
Expect(0, 74880, '\P{^iscuneiformnumbers}', "");
Expect(1, 74879, '\p{_ IS_Cuneiform_Numbers}', "");
Expect(0, 74879, '\p{^_ IS_Cuneiform_Numbers}', "");
Expect(0, 74879, '\P{_ IS_Cuneiform_Numbers}', "");
Expect(1, 74879, '\P{^_ IS_Cuneiform_Numbers}', "");
Expect(0, 74880, '\p{_ IS_Cuneiform_Numbers}', "");
Expect(1, 74880, '\p{^_ IS_Cuneiform_Numbers}', "");
Expect(1, 74880, '\P{_ IS_Cuneiform_Numbers}', "");
Expect(0, 74880, '\P{^_ IS_Cuneiform_Numbers}', "");
Error('\p{ 	in_Cuneiform_Numbers:=}');
Error('\P{ 	in_Cuneiform_Numbers:=}');
Expect(1, 74879, '\p{incuneiformnumbers}', "");
Expect(0, 74879, '\p{^incuneiformnumbers}', "");
Expect(0, 74879, '\P{incuneiformnumbers}', "");
Expect(1, 74879, '\P{^incuneiformnumbers}', "");
Expect(0, 74880, '\p{incuneiformnumbers}', "");
Expect(1, 74880, '\p{^incuneiformnumbers}', "");
Expect(1, 74880, '\P{incuneiformnumbers}', "");
Expect(0, 74880, '\P{^incuneiformnumbers}', "");
Expect(1, 74879, '\p{--In_cuneiform_NUMBERS}', "");
Expect(0, 74879, '\p{^--In_cuneiform_NUMBERS}', "");
Expect(0, 74879, '\P{--In_cuneiform_NUMBERS}', "");
Expect(1, 74879, '\P{^--In_cuneiform_NUMBERS}', "");
Expect(0, 74880, '\p{--In_cuneiform_NUMBERS}', "");
Expect(1, 74880, '\p{^--In_cuneiform_NUMBERS}', "");
Expect(1, 74880, '\P{--In_cuneiform_NUMBERS}', "");
Expect(0, 74880, '\P{^--In_cuneiform_NUMBERS}', "");
Error('\p{/a/Currency_Symbol}');
Error('\P{/a/Currency_Symbol}');
Expect(1, 65510, '\p{currencysymbol}', "");
Expect(0, 65510, '\p{^currencysymbol}', "");
Expect(0, 65510, '\P{currencysymbol}', "");
Expect(1, 65510, '\P{^currencysymbol}', "");
Expect(0, 65511, '\p{currencysymbol}', "");
Expect(1, 65511, '\p{^currencysymbol}', "");
Expect(1, 65511, '\P{currencysymbol}', "");
Expect(0, 65511, '\P{^currencysymbol}', "");
Expect(1, 65510, '\p{- Currency_Symbol}', "");
Expect(0, 65510, '\p{^- Currency_Symbol}', "");
Expect(0, 65510, '\P{- Currency_Symbol}', "");
Expect(1, 65510, '\P{^- Currency_Symbol}', "");
Expect(0, 65511, '\p{- Currency_Symbol}', "");
Expect(1, 65511, '\p{^- Currency_Symbol}', "");
Expect(1, 65511, '\P{- Currency_Symbol}', "");
Expect(0, 65511, '\P{^- Currency_Symbol}', "");
Error('\p{	 IS_Currency_SYMBOL/a/}');
Error('\P{	 IS_Currency_SYMBOL/a/}');
Expect(1, 65510, '\p{iscurrencysymbol}', "");
Expect(0, 65510, '\p{^iscurrencysymbol}', "");
Expect(0, 65510, '\P{iscurrencysymbol}', "");
Expect(1, 65510, '\P{^iscurrencysymbol}', "");
Expect(0, 65511, '\p{iscurrencysymbol}', "");
Expect(1, 65511, '\p{^iscurrencysymbol}', "");
Expect(1, 65511, '\P{iscurrencysymbol}', "");
Expect(0, 65511, '\P{^iscurrencysymbol}', "");
Expect(1, 65510, '\p{	_IS_Currency_Symbol}', "");
Expect(0, 65510, '\p{^	_IS_Currency_Symbol}', "");
Expect(0, 65510, '\P{	_IS_Currency_Symbol}', "");
Expect(1, 65510, '\P{^	_IS_Currency_Symbol}', "");
Expect(0, 65511, '\p{	_IS_Currency_Symbol}', "");
Expect(1, 65511, '\p{^	_IS_Currency_Symbol}', "");
Expect(1, 65511, '\P{	_IS_Currency_Symbol}', "");
Expect(0, 65511, '\P{^	_IS_Currency_Symbol}', "");
Error('\p{	:=Sc}');
Error('\P{	:=Sc}');
Expect(1, 65510, '\p{sc}', "");
Expect(0, 65510, '\p{^sc}', "");
Expect(0, 65510, '\P{sc}', "");
Expect(1, 65510, '\P{^sc}', "");
Expect(0, 65511, '\p{sc}', "");
Expect(1, 65511, '\p{^sc}', "");
Expect(1, 65511, '\P{sc}', "");
Expect(0, 65511, '\P{^sc}', "");
Expect(1, 65510, '\p{ _SC}', "");
Expect(0, 65510, '\p{^ _SC}', "");
Expect(0, 65510, '\P{ _SC}', "");
Expect(1, 65510, '\P{^ _SC}', "");
Expect(0, 65511, '\p{ _SC}', "");
Expect(1, 65511, '\p{^ _SC}', "");
Expect(1, 65511, '\P{ _SC}', "");
Expect(0, 65511, '\P{^ _SC}', "");
Error('\p{	-is_SC:=}');
Error('\P{	-is_SC:=}');
Expect(1, 65510, '\p{issc}', "");
Expect(0, 65510, '\p{^issc}', "");
Expect(0, 65510, '\P{issc}', "");
Expect(1, 65510, '\P{^issc}', "");
Expect(0, 65511, '\p{issc}', "");
Expect(1, 65511, '\p{^issc}', "");
Expect(1, 65511, '\P{issc}', "");
Expect(0, 65511, '\P{^issc}', "");
Expect(1, 65510, '\p{ -Is_Sc}', "");
Expect(0, 65510, '\p{^ -Is_Sc}', "");
Expect(0, 65510, '\P{ -Is_Sc}', "");
Expect(1, 65510, '\P{^ -Is_Sc}', "");
Expect(0, 65511, '\p{ -Is_Sc}', "");
Expect(1, 65511, '\p{^ -Is_Sc}', "");
Expect(1, 65511, '\P{ -Is_Sc}', "");
Expect(0, 65511, '\P{^ -Is_Sc}', "");
Error('\p{/a/ CURRENCY_Symbols}');
Error('\P{/a/ CURRENCY_Symbols}');
Expect(1, 8399, '\p{currencysymbols}', "");
Expect(0, 8399, '\p{^currencysymbols}', "");
Expect(0, 8399, '\P{currencysymbols}', "");
Expect(1, 8399, '\P{^currencysymbols}', "");
Expect(0, 8400, '\p{currencysymbols}', "");
Expect(1, 8400, '\p{^currencysymbols}', "");
Expect(1, 8400, '\P{currencysymbols}', "");
Expect(0, 8400, '\P{^currencysymbols}', "");
Expect(1, 8399, '\p{ _Currency_Symbols}', "");
Expect(0, 8399, '\p{^ _Currency_Symbols}', "");
Expect(0, 8399, '\P{ _Currency_Symbols}', "");
Expect(1, 8399, '\P{^ _Currency_Symbols}', "");
Expect(0, 8400, '\p{ _Currency_Symbols}', "");
Expect(1, 8400, '\p{^ _Currency_Symbols}', "");
Expect(1, 8400, '\P{ _Currency_Symbols}', "");
Expect(0, 8400, '\P{^ _Currency_Symbols}', "");
Error('\p{/a/Is_currency_Symbols}');
Error('\P{/a/Is_currency_Symbols}');
Expect(1, 8399, '\p{iscurrencysymbols}', "");
Expect(0, 8399, '\p{^iscurrencysymbols}', "");
Expect(0, 8399, '\P{iscurrencysymbols}', "");
Expect(1, 8399, '\P{^iscurrencysymbols}', "");
Expect(0, 8400, '\p{iscurrencysymbols}', "");
Expect(1, 8400, '\p{^iscurrencysymbols}', "");
Expect(1, 8400, '\P{iscurrencysymbols}', "");
Expect(0, 8400, '\P{^iscurrencysymbols}', "");
Expect(1, 8399, '\p{_	Is_Currency_Symbols}', "");
Expect(0, 8399, '\p{^_	Is_Currency_Symbols}', "");
Expect(0, 8399, '\P{_	Is_Currency_Symbols}', "");
Expect(1, 8399, '\P{^_	Is_Currency_Symbols}', "");
Expect(0, 8400, '\p{_	Is_Currency_Symbols}', "");
Expect(1, 8400, '\p{^_	Is_Currency_Symbols}', "");
Expect(1, 8400, '\P{_	Is_Currency_Symbols}', "");
Expect(0, 8400, '\P{^_	Is_Currency_Symbols}', "");
Error('\p{	:=IN_currency_Symbols}');
Error('\P{	:=IN_currency_Symbols}');
Expect(1, 8399, '\p{incurrencysymbols}', "");
Expect(0, 8399, '\p{^incurrencysymbols}', "");
Expect(0, 8399, '\P{incurrencysymbols}', "");
Expect(1, 8399, '\P{^incurrencysymbols}', "");
Expect(0, 8400, '\p{incurrencysymbols}', "");
Expect(1, 8400, '\p{^incurrencysymbols}', "");
Expect(1, 8400, '\P{incurrencysymbols}', "");
Expect(0, 8400, '\P{^incurrencysymbols}', "");
Expect(1, 8399, '\p{_In_Currency_Symbols}', "");
Expect(0, 8399, '\p{^_In_Currency_Symbols}', "");
Expect(0, 8399, '\P{_In_Currency_Symbols}', "");
Expect(1, 8399, '\P{^_In_Currency_Symbols}', "");
Expect(0, 8400, '\p{_In_Currency_Symbols}', "");
Expect(1, 8400, '\p{^_In_Currency_Symbols}', "");
Expect(1, 8400, '\P{_In_Currency_Symbols}', "");
Expect(0, 8400, '\P{^_In_Currency_Symbols}', "");
Error('\p{/a/ CYPRIOT}');
Error('\P{/a/ CYPRIOT}');
Expect(1, 67647, '\p{cypriot}', "");
Expect(0, 67647, '\p{^cypriot}', "");
Expect(0, 67647, '\P{cypriot}', "");
Expect(1, 67647, '\P{^cypriot}', "");
Expect(0, 67648, '\p{cypriot}', "");
Expect(1, 67648, '\p{^cypriot}', "");
Expect(1, 67648, '\P{cypriot}', "");
Expect(0, 67648, '\P{^cypriot}', "");
Expect(1, 67647, '\p{-_cypriot}', "");
Expect(0, 67647, '\p{^-_cypriot}', "");
Expect(0, 67647, '\P{-_cypriot}', "");
Expect(1, 67647, '\P{^-_cypriot}', "");
Expect(0, 67648, '\p{-_cypriot}', "");
Expect(1, 67648, '\p{^-_cypriot}', "");
Expect(1, 67648, '\P{-_cypriot}', "");
Expect(0, 67648, '\P{^-_cypriot}', "");
Error('\p{:= -Is_Cypriot}');
Error('\P{:= -Is_Cypriot}');
Expect(1, 67647, '\p{iscypriot}', "");
Expect(0, 67647, '\p{^iscypriot}', "");
Expect(0, 67647, '\P{iscypriot}', "");
Expect(1, 67647, '\P{^iscypriot}', "");
Expect(0, 67648, '\p{iscypriot}', "");
Expect(1, 67648, '\p{^iscypriot}', "");
Expect(1, 67648, '\P{iscypriot}', "");
Expect(0, 67648, '\P{^iscypriot}', "");
Expect(1, 67647, '\p{_ Is_CYPRIOT}', "");
Expect(0, 67647, '\p{^_ Is_CYPRIOT}', "");
Expect(0, 67647, '\P{_ Is_CYPRIOT}', "");
Expect(1, 67647, '\P{^_ Is_CYPRIOT}', "");
Expect(0, 67648, '\p{_ Is_CYPRIOT}', "");
Expect(1, 67648, '\p{^_ Is_CYPRIOT}', "");
Expect(1, 67648, '\P{_ Is_CYPRIOT}', "");
Expect(0, 67648, '\P{^_ Is_CYPRIOT}', "");
Error('\p{ 	cprt:=}');
Error('\P{ 	cprt:=}');
Expect(1, 67647, '\p{cprt}', "");
Expect(0, 67647, '\p{^cprt}', "");
Expect(0, 67647, '\P{cprt}', "");
Expect(1, 67647, '\P{^cprt}', "");
Expect(0, 67648, '\p{cprt}', "");
Expect(1, 67648, '\p{^cprt}', "");
Expect(1, 67648, '\P{cprt}', "");
Expect(0, 67648, '\P{^cprt}', "");
Expect(1, 67647, '\p{- CPRT}', "");
Expect(0, 67647, '\p{^- CPRT}', "");
Expect(0, 67647, '\P{- CPRT}', "");
Expect(1, 67647, '\P{^- CPRT}', "");
Expect(0, 67648, '\p{- CPRT}', "");
Expect(1, 67648, '\p{^- CPRT}', "");
Expect(1, 67648, '\P{- CPRT}', "");
Expect(0, 67648, '\P{^- CPRT}', "");
Error('\p{/a/-_Is_cprt}');
Error('\P{/a/-_Is_cprt}');
Expect(1, 67647, '\p{iscprt}', "");
Expect(0, 67647, '\p{^iscprt}', "");
Expect(0, 67647, '\P{iscprt}', "");
Expect(1, 67647, '\P{^iscprt}', "");
Expect(0, 67648, '\p{iscprt}', "");
Expect(1, 67648, '\p{^iscprt}', "");
Expect(1, 67648, '\P{iscprt}', "");
Expect(0, 67648, '\P{^iscprt}', "");
Expect(1, 67647, '\p{_Is_cprt}', "");
Expect(0, 67647, '\p{^_Is_cprt}', "");
Expect(0, 67647, '\P{_Is_cprt}', "");
Expect(1, 67647, '\P{^_Is_cprt}', "");
Expect(0, 67648, '\p{_Is_cprt}', "");
Expect(1, 67648, '\p{^_Is_cprt}', "");
Expect(1, 67648, '\P{_Is_cprt}', "");
Expect(0, 67648, '\P{^_Is_cprt}', "");
Error('\p{/a/Cypriot_syllabary}');
Error('\P{/a/Cypriot_syllabary}');
Expect(1, 67647, '\p{cypriotsyllabary}', "");
Expect(0, 67647, '\p{^cypriotsyllabary}', "");
Expect(0, 67647, '\P{cypriotsyllabary}', "");
Expect(1, 67647, '\P{^cypriotsyllabary}', "");
Expect(0, 67648, '\p{cypriotsyllabary}', "");
Expect(1, 67648, '\p{^cypriotsyllabary}', "");
Expect(1, 67648, '\P{cypriotsyllabary}', "");
Expect(0, 67648, '\P{^cypriotsyllabary}', "");
Expect(1, 67647, '\p{- cypriot_SYLLABARY}', "");
Expect(0, 67647, '\p{^- cypriot_SYLLABARY}', "");
Expect(0, 67647, '\P{- cypriot_SYLLABARY}', "");
Expect(1, 67647, '\P{^- cypriot_SYLLABARY}', "");
Expect(0, 67648, '\p{- cypriot_SYLLABARY}', "");
Expect(1, 67648, '\p{^- cypriot_SYLLABARY}', "");
Expect(1, 67648, '\P{- cypriot_SYLLABARY}', "");
Expect(0, 67648, '\P{^- cypriot_SYLLABARY}', "");
Error('\p{/a/	Is_cypriot_Syllabary}');
Error('\P{/a/	Is_cypriot_Syllabary}');
Expect(1, 67647, '\p{iscypriotsyllabary}', "");
Expect(0, 67647, '\p{^iscypriotsyllabary}', "");
Expect(0, 67647, '\P{iscypriotsyllabary}', "");
Expect(1, 67647, '\P{^iscypriotsyllabary}', "");
Expect(0, 67648, '\p{iscypriotsyllabary}', "");
Expect(1, 67648, '\p{^iscypriotsyllabary}', "");
Expect(1, 67648, '\P{iscypriotsyllabary}', "");
Expect(0, 67648, '\P{^iscypriotsyllabary}', "");
Expect(1, 67647, '\p{  is_cypriot_Syllabary}', "");
Expect(0, 67647, '\p{^  is_cypriot_Syllabary}', "");
Expect(0, 67647, '\P{  is_cypriot_Syllabary}', "");
Expect(1, 67647, '\P{^  is_cypriot_Syllabary}', "");
Expect(0, 67648, '\p{  is_cypriot_Syllabary}', "");
Expect(1, 67648, '\p{^  is_cypriot_Syllabary}', "");
Expect(1, 67648, '\P{  is_cypriot_Syllabary}', "");
Expect(0, 67648, '\P{^  is_cypriot_Syllabary}', "");
Error('\p{:=--in_cypriot_Syllabary}');
Error('\P{:=--in_cypriot_Syllabary}');
Expect(1, 67647, '\p{incypriotsyllabary}', "");
Expect(0, 67647, '\p{^incypriotsyllabary}', "");
Expect(0, 67647, '\P{incypriotsyllabary}', "");
Expect(1, 67647, '\P{^incypriotsyllabary}', "");
Expect(0, 67648, '\p{incypriotsyllabary}', "");
Expect(1, 67648, '\p{^incypriotsyllabary}', "");
Expect(1, 67648, '\P{incypriotsyllabary}', "");
Expect(0, 67648, '\P{^incypriotsyllabary}', "");
Expect(1, 67647, '\p{ 	In_Cypriot_Syllabary}', "");
Expect(0, 67647, '\p{^ 	In_Cypriot_Syllabary}', "");
Expect(0, 67647, '\P{ 	In_Cypriot_Syllabary}', "");
Expect(1, 67647, '\P{^ 	In_Cypriot_Syllabary}', "");
Expect(0, 67648, '\p{ 	In_Cypriot_Syllabary}', "");
Expect(1, 67648, '\p{^ 	In_Cypriot_Syllabary}', "");
Expect(1, 67648, '\P{ 	In_Cypriot_Syllabary}', "");
Expect(0, 67648, '\P{^ 	In_Cypriot_Syllabary}', "");
Error('\p{- CYRILLIC:=}');
Error('\P{- CYRILLIC:=}');
Expect(1, 42655, '\p{cyrillic}', "");
Expect(0, 42655, '\p{^cyrillic}', "");
Expect(0, 42655, '\P{cyrillic}', "");
Expect(1, 42655, '\P{^cyrillic}', "");
Expect(0, 42656, '\p{cyrillic}', "");
Expect(1, 42656, '\p{^cyrillic}', "");
Expect(1, 42656, '\P{cyrillic}', "");
Expect(0, 42656, '\P{^cyrillic}', "");
Expect(1, 42655, '\p{ _Cyrillic}', "");
Expect(0, 42655, '\p{^ _Cyrillic}', "");
Expect(0, 42655, '\P{ _Cyrillic}', "");
Expect(1, 42655, '\P{^ _Cyrillic}', "");
Expect(0, 42656, '\p{ _Cyrillic}', "");
Expect(1, 42656, '\p{^ _Cyrillic}', "");
Expect(1, 42656, '\P{ _Cyrillic}', "");
Expect(0, 42656, '\P{^ _Cyrillic}', "");
Error('\p{:=-	IS_Cyrillic}');
Error('\P{:=-	IS_Cyrillic}');
Expect(1, 42655, '\p{iscyrillic}', "");
Expect(0, 42655, '\p{^iscyrillic}', "");
Expect(0, 42655, '\P{iscyrillic}', "");
Expect(1, 42655, '\P{^iscyrillic}', "");
Expect(0, 42656, '\p{iscyrillic}', "");
Expect(1, 42656, '\p{^iscyrillic}', "");
Expect(1, 42656, '\P{iscyrillic}', "");
Expect(0, 42656, '\P{^iscyrillic}', "");
Expect(1, 42655, '\p{- Is_cyrillic}', "");
Expect(0, 42655, '\p{^- Is_cyrillic}', "");
Expect(0, 42655, '\P{- Is_cyrillic}', "");
Expect(1, 42655, '\P{^- Is_cyrillic}', "");
Expect(0, 42656, '\p{- Is_cyrillic}', "");
Expect(1, 42656, '\p{^- Is_cyrillic}', "");
Expect(1, 42656, '\P{- Is_cyrillic}', "");
Expect(0, 42656, '\P{^- Is_cyrillic}', "");
Error('\p{		Cyrl:=}');
Error('\P{		Cyrl:=}');
Expect(1, 42655, '\p{cyrl}', "");
Expect(0, 42655, '\p{^cyrl}', "");
Expect(0, 42655, '\P{cyrl}', "");
Expect(1, 42655, '\P{^cyrl}', "");
Expect(0, 42656, '\p{cyrl}', "");
Expect(1, 42656, '\p{^cyrl}', "");
Expect(1, 42656, '\P{cyrl}', "");
Expect(0, 42656, '\P{^cyrl}', "");
Expect(1, 42655, '\p{ Cyrl}', "");
Expect(0, 42655, '\p{^ Cyrl}', "");
Expect(0, 42655, '\P{ Cyrl}', "");
Expect(1, 42655, '\P{^ Cyrl}', "");
Expect(0, 42656, '\p{ Cyrl}', "");
Expect(1, 42656, '\p{^ Cyrl}', "");
Expect(1, 42656, '\P{ Cyrl}', "");
Expect(0, 42656, '\P{^ Cyrl}', "");
Error('\p{IS_Cyrl/a/}');
Error('\P{IS_Cyrl/a/}');
Expect(1, 42655, '\p{iscyrl}', "");
Expect(0, 42655, '\p{^iscyrl}', "");
Expect(0, 42655, '\P{iscyrl}', "");
Expect(1, 42655, '\P{^iscyrl}', "");
Expect(0, 42656, '\p{iscyrl}', "");
Expect(1, 42656, '\p{^iscyrl}', "");
Expect(1, 42656, '\P{iscyrl}', "");
Expect(0, 42656, '\P{^iscyrl}', "");
Expect(1, 42655, '\p{  IS_CYRL}', "");
Expect(0, 42655, '\p{^  IS_CYRL}', "");
Expect(0, 42655, '\P{  IS_CYRL}', "");
Expect(1, 42655, '\P{^  IS_CYRL}', "");
Expect(0, 42656, '\p{  IS_CYRL}', "");
Expect(1, 42656, '\p{^  IS_CYRL}', "");
Expect(1, 42656, '\P{  IS_CYRL}', "");
Expect(0, 42656, '\P{^  IS_CYRL}', "");
Error('\p{-Cyrillic_EXTENDED_A/a/}');
Error('\P{-Cyrillic_EXTENDED_A/a/}');
Expect(1, 11775, '\p{cyrillicextendeda}', "");
Expect(0, 11775, '\p{^cyrillicextendeda}', "");
Expect(0, 11775, '\P{cyrillicextendeda}', "");
Expect(1, 11775, '\P{^cyrillicextendeda}', "");
Expect(0, 11776, '\p{cyrillicextendeda}', "");
Expect(1, 11776, '\p{^cyrillicextendeda}', "");
Expect(1, 11776, '\P{cyrillicextendeda}', "");
Expect(0, 11776, '\P{^cyrillicextendeda}', "");
Expect(1, 11775, '\p{--CYRILLIC_Extended_A}', "");
Expect(0, 11775, '\p{^--CYRILLIC_Extended_A}', "");
Expect(0, 11775, '\P{--CYRILLIC_Extended_A}', "");
Expect(1, 11775, '\P{^--CYRILLIC_Extended_A}', "");
Expect(0, 11776, '\p{--CYRILLIC_Extended_A}', "");
Expect(1, 11776, '\p{^--CYRILLIC_Extended_A}', "");
Expect(1, 11776, '\P{--CYRILLIC_Extended_A}', "");
Expect(0, 11776, '\P{^--CYRILLIC_Extended_A}', "");
Error('\p{:=_IS_Cyrillic_Extended_A}');
Error('\P{:=_IS_Cyrillic_Extended_A}');
Expect(1, 11775, '\p{iscyrillicextendeda}', "");
Expect(0, 11775, '\p{^iscyrillicextendeda}', "");
Expect(0, 11775, '\P{iscyrillicextendeda}', "");
Expect(1, 11775, '\P{^iscyrillicextendeda}', "");
Expect(0, 11776, '\p{iscyrillicextendeda}', "");
Expect(1, 11776, '\p{^iscyrillicextendeda}', "");
Expect(1, 11776, '\P{iscyrillicextendeda}', "");
Expect(0, 11776, '\P{^iscyrillicextendeda}', "");
Expect(1, 11775, '\p{ 	Is_Cyrillic_Extended_A}', "");
Expect(0, 11775, '\p{^ 	Is_Cyrillic_Extended_A}', "");
Expect(0, 11775, '\P{ 	Is_Cyrillic_Extended_A}', "");
Expect(1, 11775, '\P{^ 	Is_Cyrillic_Extended_A}', "");
Expect(0, 11776, '\p{ 	Is_Cyrillic_Extended_A}', "");
Expect(1, 11776, '\p{^ 	Is_Cyrillic_Extended_A}', "");
Expect(1, 11776, '\P{ 	Is_Cyrillic_Extended_A}', "");
Expect(0, 11776, '\P{^ 	Is_Cyrillic_Extended_A}', "");
Error('\p{_-IN_Cyrillic_EXTENDED_A/a/}');
Error('\P{_-IN_Cyrillic_EXTENDED_A/a/}');
Expect(1, 11775, '\p{incyrillicextendeda}', "");
Expect(0, 11775, '\p{^incyrillicextendeda}', "");
Expect(0, 11775, '\P{incyrillicextendeda}', "");
Expect(1, 11775, '\P{^incyrillicextendeda}', "");
Expect(0, 11776, '\p{incyrillicextendeda}', "");
Expect(1, 11776, '\p{^incyrillicextendeda}', "");
Expect(1, 11776, '\P{incyrillicextendeda}', "");
Expect(0, 11776, '\P{^incyrillicextendeda}', "");
Expect(1, 11775, '\p{_-In_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11775, '\p{^_-In_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11775, '\P{_-In_CYRILLIC_EXTENDED_A}', "");
Expect(1, 11775, '\P{^_-In_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11776, '\p{_-In_CYRILLIC_EXTENDED_A}', "");
Expect(1, 11776, '\p{^_-In_CYRILLIC_EXTENDED_A}', "");
Expect(1, 11776, '\P{_-In_CYRILLIC_EXTENDED_A}', "");
Expect(0, 11776, '\P{^_-In_CYRILLIC_EXTENDED_A}', "");
Error('\p{:=	 Cyrillic_ext_a}');
Error('\P{:=	 Cyrillic_ext_a}');
Expect(1, 11775, '\p{cyrillicexta}', "");
Expect(0, 11775, '\p{^cyrillicexta}', "");
Expect(0, 11775, '\P{cyrillicexta}', "");
Expect(1, 11775, '\P{^cyrillicexta}', "");
Expect(0, 11776, '\p{cyrillicexta}', "");
Expect(1, 11776, '\p{^cyrillicexta}', "");
Expect(1, 11776, '\P{cyrillicexta}', "");
Expect(0, 11776, '\P{^cyrillicexta}', "");
Expect(1, 11775, '\p{-Cyrillic_Ext_A}', "");
Expect(0, 11775, '\p{^-Cyrillic_Ext_A}', "");
Expect(0, 11775, '\P{-Cyrillic_Ext_A}', "");
Expect(1, 11775, '\P{^-Cyrillic_Ext_A}', "");
Expect(0, 11776, '\p{-Cyrillic_Ext_A}', "");
Expect(1, 11776, '\p{^-Cyrillic_Ext_A}', "");
Expect(1, 11776, '\P{-Cyrillic_Ext_A}', "");
Expect(0, 11776, '\P{^-Cyrillic_Ext_A}', "");
Error('\p{_:=IS_cyrillic_Ext_A}');
Error('\P{_:=IS_cyrillic_Ext_A}');
Expect(1, 11775, '\p{iscyrillicexta}', "");
Expect(0, 11775, '\p{^iscyrillicexta}', "");
Expect(0, 11775, '\P{iscyrillicexta}', "");
Expect(1, 11775, '\P{^iscyrillicexta}', "");
Expect(0, 11776, '\p{iscyrillicexta}', "");
Expect(1, 11776, '\p{^iscyrillicexta}', "");
Expect(1, 11776, '\P{iscyrillicexta}', "");
Expect(0, 11776, '\P{^iscyrillicexta}', "");
Expect(1, 11775, '\p{-_IS_CYRILLIC_Ext_a}', "");
Expect(0, 11775, '\p{^-_IS_CYRILLIC_Ext_a}', "");
Expect(0, 11775, '\P{-_IS_CYRILLIC_Ext_a}', "");
Expect(1, 11775, '\P{^-_IS_CYRILLIC_Ext_a}', "");
Expect(0, 11776, '\p{-_IS_CYRILLIC_Ext_a}', "");
Expect(1, 11776, '\p{^-_IS_CYRILLIC_Ext_a}', "");
Expect(1, 11776, '\P{-_IS_CYRILLIC_Ext_a}', "");
Expect(0, 11776, '\P{^-_IS_CYRILLIC_Ext_a}', "");
Error('\p{_:=In_Cyrillic_EXT_A}');
Error('\P{_:=In_Cyrillic_EXT_A}');
Expect(1, 11775, '\p{incyrillicexta}', "");
Expect(0, 11775, '\p{^incyrillicexta}', "");
Expect(0, 11775, '\P{incyrillicexta}', "");
Expect(1, 11775, '\P{^incyrillicexta}', "");
Expect(0, 11776, '\p{incyrillicexta}', "");
Expect(1, 11776, '\p{^incyrillicexta}', "");
Expect(1, 11776, '\P{incyrillicexta}', "");
Expect(0, 11776, '\P{^incyrillicexta}', "");
Expect(1, 11775, '\p{		in_CYRILLIC_Ext_A}', "");
Expect(0, 11775, '\p{^		in_CYRILLIC_Ext_A}', "");
Expect(0, 11775, '\P{		in_CYRILLIC_Ext_A}', "");
Expect(1, 11775, '\P{^		in_CYRILLIC_Ext_A}', "");
Expect(0, 11776, '\p{		in_CYRILLIC_Ext_A}', "");
Expect(1, 11776, '\p{^		in_CYRILLIC_Ext_A}', "");
Expect(1, 11776, '\P{		in_CYRILLIC_Ext_A}', "");
Expect(0, 11776, '\P{^		in_CYRILLIC_Ext_A}', "");
Error('\p{ -cyrillic_EXTENDED_B:=}');
Error('\P{ -cyrillic_EXTENDED_B:=}');
Expect(1, 42655, '\p{cyrillicextendedb}', "");
Expect(0, 42655, '\p{^cyrillicextendedb}', "");
Expect(0, 42655, '\P{cyrillicextendedb}', "");
Expect(1, 42655, '\P{^cyrillicextendedb}', "");
Expect(0, 42656, '\p{cyrillicextendedb}', "");
Expect(1, 42656, '\p{^cyrillicextendedb}', "");
Expect(1, 42656, '\P{cyrillicextendedb}', "");
Expect(0, 42656, '\P{^cyrillicextendedb}', "");
Expect(1, 42655, '\p{-_Cyrillic_extended_B}', "");
Expect(0, 42655, '\p{^-_Cyrillic_extended_B}', "");
Expect(0, 42655, '\P{-_Cyrillic_extended_B}', "");
Expect(1, 42655, '\P{^-_Cyrillic_extended_B}', "");
Expect(0, 42656, '\p{-_Cyrillic_extended_B}', "");
Expect(1, 42656, '\p{^-_Cyrillic_extended_B}', "");
Expect(1, 42656, '\P{-_Cyrillic_extended_B}', "");
Expect(0, 42656, '\P{^-_Cyrillic_extended_B}', "");
Error('\p{:=--IS_Cyrillic_extended_B}');
Error('\P{:=--IS_Cyrillic_extended_B}');
Expect(1, 42655, '\p{iscyrillicextendedb}', "");
Expect(0, 42655, '\p{^iscyrillicextendedb}', "");
Expect(0, 42655, '\P{iscyrillicextendedb}', "");
Expect(1, 42655, '\P{^iscyrillicextendedb}', "");
Expect(0, 42656, '\p{iscyrillicextendedb}', "");
Expect(1, 42656, '\p{^iscyrillicextendedb}', "");
Expect(1, 42656, '\P{iscyrillicextendedb}', "");
Expect(0, 42656, '\P{^iscyrillicextendedb}', "");
Expect(1, 42655, '\p{_ Is_Cyrillic_extended_B}', "");
Expect(0, 42655, '\p{^_ Is_Cyrillic_extended_B}', "");
Expect(0, 42655, '\P{_ Is_Cyrillic_extended_B}', "");
Expect(1, 42655, '\P{^_ Is_Cyrillic_extended_B}', "");
Expect(0, 42656, '\p{_ Is_Cyrillic_extended_B}', "");
Expect(1, 42656, '\p{^_ Is_Cyrillic_extended_B}', "");
Expect(1, 42656, '\P{_ Is_Cyrillic_extended_B}', "");
Expect(0, 42656, '\P{^_ Is_Cyrillic_extended_B}', "");
Error('\p{  In_Cyrillic_EXTENDED_B/a/}');
Error('\P{  In_Cyrillic_EXTENDED_B/a/}');
Expect(1, 42655, '\p{incyrillicextendedb}', "");
Expect(0, 42655, '\p{^incyrillicextendedb}', "");
Expect(0, 42655, '\P{incyrillicextendedb}', "");
Expect(1, 42655, '\P{^incyrillicextendedb}', "");
Expect(0, 42656, '\p{incyrillicextendedb}', "");
Expect(1, 42656, '\p{^incyrillicextendedb}', "");
Expect(1, 42656, '\P{incyrillicextendedb}', "");
Expect(0, 42656, '\P{^incyrillicextendedb}', "");
Expect(1, 42655, '\p{	In_CYRILLIC_extended_B}', "");
Expect(0, 42655, '\p{^	In_CYRILLIC_extended_B}', "");
Expect(0, 42655, '\P{	In_CYRILLIC_extended_B}', "");
Expect(1, 42655, '\P{^	In_CYRILLIC_extended_B}', "");
Expect(0, 42656, '\p{	In_CYRILLIC_extended_B}', "");
Expect(1, 42656, '\p{^	In_CYRILLIC_extended_B}', "");
Expect(1, 42656, '\P{	In_CYRILLIC_extended_B}', "");
Expect(0, 42656, '\P{^	In_CYRILLIC_extended_B}', "");
Error('\p{	:=CYRILLIC_Ext_B}');
Error('\P{	:=CYRILLIC_Ext_B}');
Expect(1, 42655, '\p{cyrillicextb}', "");
Expect(0, 42655, '\p{^cyrillicextb}', "");
Expect(0, 42655, '\P{cyrillicextb}', "");
Expect(1, 42655, '\P{^cyrillicextb}', "");
Expect(0, 42656, '\p{cyrillicextb}', "");
Expect(1, 42656, '\p{^cyrillicextb}', "");
Expect(1, 42656, '\P{cyrillicextb}', "");
Expect(0, 42656, '\P{^cyrillicextb}', "");
Expect(1, 42655, '\p{	-Cyrillic_Ext_B}', "");
Expect(0, 42655, '\p{^	-Cyrillic_Ext_B}', "");
Expect(0, 42655, '\P{	-Cyrillic_Ext_B}', "");
Expect(1, 42655, '\P{^	-Cyrillic_Ext_B}', "");
Expect(0, 42656, '\p{	-Cyrillic_Ext_B}', "");
Expect(1, 42656, '\p{^	-Cyrillic_Ext_B}', "");
Expect(1, 42656, '\P{	-Cyrillic_Ext_B}', "");
Expect(0, 42656, '\P{^	-Cyrillic_Ext_B}', "");
Error('\p{:=- is_Cyrillic_ext_B}');
Error('\P{:=- is_Cyrillic_ext_B}');
Expect(1, 42655, '\p{iscyrillicextb}', "");
Expect(0, 42655, '\p{^iscyrillicextb}', "");
Expect(0, 42655, '\P{iscyrillicextb}', "");
Expect(1, 42655, '\P{^iscyrillicextb}', "");
Expect(0, 42656, '\p{iscyrillicextb}', "");
Expect(1, 42656, '\p{^iscyrillicextb}', "");
Expect(1, 42656, '\P{iscyrillicextb}', "");
Expect(0, 42656, '\P{^iscyrillicextb}', "");
Expect(1, 42655, '\p{ Is_Cyrillic_Ext_b}', "");
Expect(0, 42655, '\p{^ Is_Cyrillic_Ext_b}', "");
Expect(0, 42655, '\P{ Is_Cyrillic_Ext_b}', "");
Expect(1, 42655, '\P{^ Is_Cyrillic_Ext_b}', "");
Expect(0, 42656, '\p{ Is_Cyrillic_Ext_b}', "");
Expect(1, 42656, '\p{^ Is_Cyrillic_Ext_b}', "");
Expect(1, 42656, '\P{ Is_Cyrillic_Ext_b}', "");
Expect(0, 42656, '\P{^ Is_Cyrillic_Ext_b}', "");
Error('\p{:= in_Cyrillic_Ext_B}');
Error('\P{:= in_Cyrillic_Ext_B}');
Expect(1, 42655, '\p{incyrillicextb}', "");
Expect(0, 42655, '\p{^incyrillicextb}', "");
Expect(0, 42655, '\P{incyrillicextb}', "");
Expect(1, 42655, '\P{^incyrillicextb}', "");
Expect(0, 42656, '\p{incyrillicextb}', "");
Expect(1, 42656, '\p{^incyrillicextb}', "");
Expect(1, 42656, '\P{incyrillicextb}', "");
Expect(0, 42656, '\P{^incyrillicextb}', "");
Expect(1, 42655, '\p{	In_Cyrillic_EXT_B}', "");
Expect(0, 42655, '\p{^	In_Cyrillic_EXT_B}', "");
Expect(0, 42655, '\P{	In_Cyrillic_EXT_B}', "");
Expect(1, 42655, '\P{^	In_Cyrillic_EXT_B}', "");
Expect(0, 42656, '\p{	In_Cyrillic_EXT_B}', "");
Expect(1, 42656, '\p{^	In_Cyrillic_EXT_B}', "");
Expect(1, 42656, '\P{	In_Cyrillic_EXT_B}', "");
Expect(0, 42656, '\P{^	In_Cyrillic_EXT_B}', "");
Error('\p{:= 	cyrillic_Supplement}');
Error('\P{:= 	cyrillic_Supplement}');
Expect(1, 1327, '\p{cyrillicsupplement}', "");
Expect(0, 1327, '\p{^cyrillicsupplement}', "");
Expect(0, 1327, '\P{cyrillicsupplement}', "");
Expect(1, 1327, '\P{^cyrillicsupplement}', "");
Expect(0, 1328, '\p{cyrillicsupplement}', "");
Expect(1, 1328, '\p{^cyrillicsupplement}', "");
Expect(1, 1328, '\P{cyrillicsupplement}', "");
Expect(0, 1328, '\P{^cyrillicsupplement}', "");
Expect(1, 1327, '\p{	Cyrillic_Supplement}', "");
Expect(0, 1327, '\p{^	Cyrillic_Supplement}', "");
Expect(0, 1327, '\P{	Cyrillic_Supplement}', "");
Expect(1, 1327, '\P{^	Cyrillic_Supplement}', "");
Expect(0, 1328, '\p{	Cyrillic_Supplement}', "");
Expect(1, 1328, '\p{^	Cyrillic_Supplement}', "");
Expect(1, 1328, '\P{	Cyrillic_Supplement}', "");
Expect(0, 1328, '\P{^	Cyrillic_Supplement}', "");
Error('\p{:= 	is_CYRILLIC_SUPPLEMENT}');
Error('\P{:= 	is_CYRILLIC_SUPPLEMENT}');
Expect(1, 1327, '\p{iscyrillicsupplement}', "");
Expect(0, 1327, '\p{^iscyrillicsupplement}', "");
Expect(0, 1327, '\P{iscyrillicsupplement}', "");
Expect(1, 1327, '\P{^iscyrillicsupplement}', "");
Expect(0, 1328, '\p{iscyrillicsupplement}', "");
Expect(1, 1328, '\p{^iscyrillicsupplement}', "");
Expect(1, 1328, '\P{iscyrillicsupplement}', "");
Expect(0, 1328, '\P{^iscyrillicsupplement}', "");
Expect(1, 1327, '\p{- Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1327, '\p{^- Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1327, '\P{- Is_Cyrillic_SUPPLEMENT}', "");
Expect(1, 1327, '\P{^- Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1328, '\p{- Is_Cyrillic_SUPPLEMENT}', "");
Expect(1, 1328, '\p{^- Is_Cyrillic_SUPPLEMENT}', "");
Expect(1, 1328, '\P{- Is_Cyrillic_SUPPLEMENT}', "");
Expect(0, 1328, '\P{^- Is_Cyrillic_SUPPLEMENT}', "");
Error('\p{_-In_Cyrillic_Supplement/a/}');
Error('\P{_-In_Cyrillic_Supplement/a/}');
Expect(1, 1327, '\p{incyrillicsupplement}', "");
Expect(0, 1327, '\p{^incyrillicsupplement}', "");
Expect(0, 1327, '\P{incyrillicsupplement}', "");
Expect(1, 1327, '\P{^incyrillicsupplement}', "");
Expect(0, 1328, '\p{incyrillicsupplement}', "");
Expect(1, 1328, '\p{^incyrillicsupplement}', "");
Expect(1, 1328, '\P{incyrillicsupplement}', "");
Expect(0, 1328, '\P{^incyrillicsupplement}', "");
Expect(1, 1327, '\p{- in_Cyrillic_Supplement}', "");
Expect(0, 1327, '\p{^- in_Cyrillic_Supplement}', "");
Expect(0, 1327, '\P{- in_Cyrillic_Supplement}', "");
Expect(1, 1327, '\P{^- in_Cyrillic_Supplement}', "");
Expect(0, 1328, '\p{- in_Cyrillic_Supplement}', "");
Expect(1, 1328, '\p{^- in_Cyrillic_Supplement}', "");
Expect(1, 1328, '\P{- in_Cyrillic_Supplement}', "");
Expect(0, 1328, '\P{^- in_Cyrillic_Supplement}', "");
Error('\p{Cyrillic_SUP/a/}');
Error('\P{Cyrillic_SUP/a/}');
Expect(1, 1327, '\p{cyrillicsup}', "");
Expect(0, 1327, '\p{^cyrillicsup}', "");
Expect(0, 1327, '\P{cyrillicsup}', "");
Expect(1, 1327, '\P{^cyrillicsup}', "");
Expect(0, 1328, '\p{cyrillicsup}', "");
Expect(1, 1328, '\p{^cyrillicsup}', "");
Expect(1, 1328, '\P{cyrillicsup}', "");
Expect(0, 1328, '\P{^cyrillicsup}', "");
Expect(1, 1327, '\p{	_cyrillic_SUP}', "");
Expect(0, 1327, '\p{^	_cyrillic_SUP}', "");
Expect(0, 1327, '\P{	_cyrillic_SUP}', "");
Expect(1, 1327, '\P{^	_cyrillic_SUP}', "");
Expect(0, 1328, '\p{	_cyrillic_SUP}', "");
Expect(1, 1328, '\p{^	_cyrillic_SUP}', "");
Expect(1, 1328, '\P{	_cyrillic_SUP}', "");
Expect(0, 1328, '\P{^	_cyrillic_SUP}', "");
Error('\p{/a/--Is_Cyrillic_SUP}');
Error('\P{/a/--Is_Cyrillic_SUP}');
Expect(1, 1327, '\p{iscyrillicsup}', "");
Expect(0, 1327, '\p{^iscyrillicsup}', "");
Expect(0, 1327, '\P{iscyrillicsup}', "");
Expect(1, 1327, '\P{^iscyrillicsup}', "");
Expect(0, 1328, '\p{iscyrillicsup}', "");
Expect(1, 1328, '\p{^iscyrillicsup}', "");
Expect(1, 1328, '\P{iscyrillicsup}', "");
Expect(0, 1328, '\P{^iscyrillicsup}', "");
Expect(1, 1327, '\p{	 Is_Cyrillic_Sup}', "");
Expect(0, 1327, '\p{^	 Is_Cyrillic_Sup}', "");
Expect(0, 1327, '\P{	 Is_Cyrillic_Sup}', "");
Expect(1, 1327, '\P{^	 Is_Cyrillic_Sup}', "");
Expect(0, 1328, '\p{	 Is_Cyrillic_Sup}', "");
Expect(1, 1328, '\p{^	 Is_Cyrillic_Sup}', "");
Expect(1, 1328, '\P{	 Is_Cyrillic_Sup}', "");
Expect(0, 1328, '\P{^	 Is_Cyrillic_Sup}', "");
Error('\p{IN_CYRILLIC_sup:=}');
Error('\P{IN_CYRILLIC_sup:=}');
Expect(1, 1327, '\p{incyrillicsup}', "");
Expect(0, 1327, '\p{^incyrillicsup}', "");
Expect(0, 1327, '\P{incyrillicsup}', "");
Expect(1, 1327, '\P{^incyrillicsup}', "");
Expect(0, 1328, '\p{incyrillicsup}', "");
Expect(1, 1328, '\p{^incyrillicsup}', "");
Expect(1, 1328, '\P{incyrillicsup}', "");
Expect(0, 1328, '\P{^incyrillicsup}', "");
Expect(1, 1327, '\p{ In_CYRILLIC_Sup}', "");
Expect(0, 1327, '\p{^ In_CYRILLIC_Sup}', "");
Expect(0, 1327, '\P{ In_CYRILLIC_Sup}', "");
Expect(1, 1327, '\P{^ In_CYRILLIC_Sup}', "");
Expect(0, 1328, '\p{ In_CYRILLIC_Sup}', "");
Expect(1, 1328, '\p{^ In_CYRILLIC_Sup}', "");
Expect(1, 1328, '\P{ In_CYRILLIC_Sup}', "");
Expect(0, 1328, '\P{^ In_CYRILLIC_Sup}', "");
Error('\p{:=	-CYRILLIC_Supplementary}');
Error('\P{:=	-CYRILLIC_Supplementary}');
Expect(1, 1327, '\p{cyrillicsupplementary}', "");
Expect(0, 1327, '\p{^cyrillicsupplementary}', "");
Expect(0, 1327, '\P{cyrillicsupplementary}', "");
Expect(1, 1327, '\P{^cyrillicsupplementary}', "");
Expect(0, 1328, '\p{cyrillicsupplementary}', "");
Expect(1, 1328, '\p{^cyrillicsupplementary}', "");
Expect(1, 1328, '\P{cyrillicsupplementary}', "");
Expect(0, 1328, '\P{^cyrillicsupplementary}', "");
Expect(1, 1327, '\p{-_Cyrillic_Supplementary}', "");
Expect(0, 1327, '\p{^-_Cyrillic_Supplementary}', "");
Expect(0, 1327, '\P{-_Cyrillic_Supplementary}', "");
Expect(1, 1327, '\P{^-_Cyrillic_Supplementary}', "");
Expect(0, 1328, '\p{-_Cyrillic_Supplementary}', "");
Expect(1, 1328, '\p{^-_Cyrillic_Supplementary}', "");
Expect(1, 1328, '\P{-_Cyrillic_Supplementary}', "");
Expect(0, 1328, '\P{^-_Cyrillic_Supplementary}', "");
Error('\p{-:=IS_Cyrillic_SUPPLEMENTARY}');
Error('\P{-:=IS_Cyrillic_SUPPLEMENTARY}');
Expect(1, 1327, '\p{iscyrillicsupplementary}', "");
Expect(0, 1327, '\p{^iscyrillicsupplementary}', "");
Expect(0, 1327, '\P{iscyrillicsupplementary}', "");
Expect(1, 1327, '\P{^iscyrillicsupplementary}', "");
Expect(0, 1328, '\p{iscyrillicsupplementary}', "");
Expect(1, 1328, '\p{^iscyrillicsupplementary}', "");
Expect(1, 1328, '\P{iscyrillicsupplementary}', "");
Expect(0, 1328, '\P{^iscyrillicsupplementary}', "");
Expect(1, 1327, '\p{--Is_cyrillic_Supplementary}', "");
Expect(0, 1327, '\p{^--Is_cyrillic_Supplementary}', "");
Expect(0, 1327, '\P{--Is_cyrillic_Supplementary}', "");
Expect(1, 1327, '\P{^--Is_cyrillic_Supplementary}', "");
Expect(0, 1328, '\p{--Is_cyrillic_Supplementary}', "");
Expect(1, 1328, '\p{^--Is_cyrillic_Supplementary}', "");
Expect(1, 1328, '\P{--Is_cyrillic_Supplementary}', "");
Expect(0, 1328, '\P{^--Is_cyrillic_Supplementary}', "");
Error('\p{:=	 IN_cyrillic_supplementary}');
Error('\P{:=	 IN_cyrillic_supplementary}');
Expect(1, 1327, '\p{incyrillicsupplementary}', "");
Expect(0, 1327, '\p{^incyrillicsupplementary}', "");
Expect(0, 1327, '\P{incyrillicsupplementary}', "");
Expect(1, 1327, '\P{^incyrillicsupplementary}', "");
Expect(0, 1328, '\p{incyrillicsupplementary}', "");
Expect(1, 1328, '\p{^incyrillicsupplementary}', "");
Expect(1, 1328, '\P{incyrillicsupplementary}', "");
Expect(0, 1328, '\P{^incyrillicsupplementary}', "");
Expect(1, 1327, '\p{	-IN_cyrillic_Supplementary}', "");
Expect(0, 1327, '\p{^	-IN_cyrillic_Supplementary}', "");
Expect(0, 1327, '\P{	-IN_cyrillic_Supplementary}', "");
Expect(1, 1327, '\P{^	-IN_cyrillic_Supplementary}', "");
Expect(0, 1328, '\p{	-IN_cyrillic_Supplementary}', "");
Expect(1, 1328, '\p{^	-IN_cyrillic_Supplementary}', "");
Expect(1, 1328, '\P{	-IN_cyrillic_Supplementary}', "");
Expect(0, 1328, '\P{^	-IN_cyrillic_Supplementary}', "");
Error('\p{ _Dash/a/}');
Error('\P{ _Dash/a/}');
Expect(1, 65293, '\p{dash}', "");
Expect(0, 65293, '\p{^dash}', "");
Expect(0, 65293, '\P{dash}', "");
Expect(1, 65293, '\P{^dash}', "");
Expect(0, 65294, '\p{dash}', "");
Expect(1, 65294, '\p{^dash}', "");
Expect(1, 65294, '\P{dash}', "");
Expect(0, 65294, '\P{^dash}', "");
Expect(1, 65293, '\p{--dash}', "");
Expect(0, 65293, '\p{^--dash}', "");
Expect(0, 65293, '\P{--dash}', "");
Expect(1, 65293, '\P{^--dash}', "");
Expect(0, 65294, '\p{--dash}', "");
Expect(1, 65294, '\p{^--dash}', "");
Expect(1, 65294, '\P{--dash}', "");
Expect(0, 65294, '\P{^--dash}', "");
Error('\p{-/a/Is_Dash}');
Error('\P{-/a/Is_Dash}');
Expect(1, 65293, '\p{isdash}', "");
Expect(0, 65293, '\p{^isdash}', "");
Expect(0, 65293, '\P{isdash}', "");
Expect(1, 65293, '\P{^isdash}', "");
Expect(0, 65294, '\p{isdash}', "");
Expect(1, 65294, '\p{^isdash}', "");
Expect(1, 65294, '\P{isdash}', "");
Expect(0, 65294, '\P{^isdash}', "");
Expect(1, 65293, '\p{__Is_Dash}', "");
Expect(0, 65293, '\p{^__Is_Dash}', "");
Expect(0, 65293, '\P{__Is_Dash}', "");
Expect(1, 65293, '\P{^__Is_Dash}', "");
Expect(0, 65294, '\p{__Is_Dash}', "");
Expect(1, 65294, '\p{^__Is_Dash}', "");
Expect(1, 65294, '\P{__Is_Dash}', "");
Expect(0, 65294, '\P{^__Is_Dash}', "");
Error('\p{:=-Dash_Punctuation}');
Error('\P{:=-Dash_Punctuation}');
Expect(1, 65293, '\p{dashpunctuation}', "");
Expect(0, 65293, '\p{^dashpunctuation}', "");
Expect(0, 65293, '\P{dashpunctuation}', "");
Expect(1, 65293, '\P{^dashpunctuation}', "");
Expect(0, 65294, '\p{dashpunctuation}', "");
Expect(1, 65294, '\p{^dashpunctuation}', "");
Expect(1, 65294, '\P{dashpunctuation}', "");
Expect(0, 65294, '\P{^dashpunctuation}', "");
Expect(1, 65293, '\p{	Dash_Punctuation}', "");
Expect(0, 65293, '\p{^	Dash_Punctuation}', "");
Expect(0, 65293, '\P{	Dash_Punctuation}', "");
Expect(1, 65293, '\P{^	Dash_Punctuation}', "");
Expect(0, 65294, '\p{	Dash_Punctuation}', "");
Expect(1, 65294, '\p{^	Dash_Punctuation}', "");
Expect(1, 65294, '\P{	Dash_Punctuation}', "");
Expect(0, 65294, '\P{^	Dash_Punctuation}', "");
Error('\p{:=		IS_Dash_Punctuation}');
Error('\P{:=		IS_Dash_Punctuation}');
Expect(1, 65293, '\p{isdashpunctuation}', "");
Expect(0, 65293, '\p{^isdashpunctuation}', "");
Expect(0, 65293, '\P{isdashpunctuation}', "");
Expect(1, 65293, '\P{^isdashpunctuation}', "");
Expect(0, 65294, '\p{isdashpunctuation}', "");
Expect(1, 65294, '\p{^isdashpunctuation}', "");
Expect(1, 65294, '\P{isdashpunctuation}', "");
Expect(0, 65294, '\P{^isdashpunctuation}', "");
Expect(1, 65293, '\p{ Is_Dash_Punctuation}', "");
Expect(0, 65293, '\p{^ Is_Dash_Punctuation}', "");
Expect(0, 65293, '\P{ Is_Dash_Punctuation}', "");
Expect(1, 65293, '\P{^ Is_Dash_Punctuation}', "");
Expect(0, 65294, '\p{ Is_Dash_Punctuation}', "");
Expect(1, 65294, '\p{^ Is_Dash_Punctuation}', "");
Expect(1, 65294, '\P{ Is_Dash_Punctuation}', "");
Expect(0, 65294, '\P{^ Is_Dash_Punctuation}', "");
Error('\p{ /a/Pd}');
Error('\P{ /a/Pd}');
Expect(1, 65293, '\p{pd}', "");
Expect(0, 65293, '\p{^pd}', "");
Expect(0, 65293, '\P{pd}', "");
Expect(1, 65293, '\P{^pd}', "");
Expect(0, 65294, '\p{pd}', "");
Expect(1, 65294, '\p{^pd}', "");
Expect(1, 65294, '\P{pd}', "");
Expect(0, 65294, '\P{^pd}', "");
Expect(1, 65293, '\p{ Pd}', "");
Expect(0, 65293, '\p{^ Pd}', "");
Expect(0, 65293, '\P{ Pd}', "");
Expect(1, 65293, '\P{^ Pd}', "");
Expect(0, 65294, '\p{ Pd}', "");
Expect(1, 65294, '\p{^ Pd}', "");
Expect(1, 65294, '\P{ Pd}', "");
Expect(0, 65294, '\P{^ Pd}', "");
Error('\p{/a/	Is_pd}');
Error('\P{/a/	Is_pd}');
Expect(1, 65293, '\p{ispd}', "");
Expect(0, 65293, '\p{^ispd}', "");
Expect(0, 65293, '\P{ispd}', "");
Expect(1, 65293, '\P{^ispd}', "");
Expect(0, 65294, '\p{ispd}', "");
Expect(1, 65294, '\p{^ispd}', "");
Expect(1, 65294, '\P{ispd}', "");
Expect(0, 65294, '\P{^ispd}', "");
Expect(1, 65293, '\p{--Is_pd}', "");
Expect(0, 65293, '\p{^--Is_pd}', "");
Expect(0, 65293, '\P{--Is_pd}', "");
Expect(1, 65293, '\P{^--Is_pd}', "");
Expect(0, 65294, '\p{--Is_pd}', "");
Expect(1, 65294, '\p{^--Is_pd}', "");
Expect(1, 65294, '\P{--Is_pd}', "");
Expect(0, 65294, '\P{^--Is_pd}', "");
Error('\p{/a/ 	Default_Ignorable_Code_Point}');
Error('\P{/a/ 	Default_Ignorable_Code_Point}');
Expect(1, 921599, '\p{defaultignorablecodepoint}', "");
Expect(0, 921599, '\p{^defaultignorablecodepoint}', "");
Expect(0, 921599, '\P{defaultignorablecodepoint}', "");
Expect(1, 921599, '\P{^defaultignorablecodepoint}', "");
Expect(0, 921600, '\p{defaultignorablecodepoint}', "");
Expect(1, 921600, '\p{^defaultignorablecodepoint}', "");
Expect(1, 921600, '\P{defaultignorablecodepoint}', "");
Expect(0, 921600, '\P{^defaultignorablecodepoint}', "");
Expect(1, 921599, '\p{_Default_ignorable_Code_Point}', "");
Expect(0, 921599, '\p{^_Default_ignorable_Code_Point}', "");
Expect(0, 921599, '\P{_Default_ignorable_Code_Point}', "");
Expect(1, 921599, '\P{^_Default_ignorable_Code_Point}', "");
Expect(0, 921600, '\p{_Default_ignorable_Code_Point}', "");
Expect(1, 921600, '\p{^_Default_ignorable_Code_Point}', "");
Expect(1, 921600, '\P{_Default_ignorable_Code_Point}', "");
Expect(0, 921600, '\P{^_Default_ignorable_Code_Point}', "");
Error('\p{__Is_DEFAULT_IGNORABLE_Code_Point/a/}');
Error('\P{__Is_DEFAULT_IGNORABLE_Code_Point/a/}');
Expect(1, 921599, '\p{isdefaultignorablecodepoint}', "");
Expect(0, 921599, '\p{^isdefaultignorablecodepoint}', "");
Expect(0, 921599, '\P{isdefaultignorablecodepoint}', "");
Expect(1, 921599, '\P{^isdefaultignorablecodepoint}', "");
Expect(0, 921600, '\p{isdefaultignorablecodepoint}', "");
Expect(1, 921600, '\p{^isdefaultignorablecodepoint}', "");
Expect(1, 921600, '\P{isdefaultignorablecodepoint}', "");
Expect(0, 921600, '\P{^isdefaultignorablecodepoint}', "");
Expect(1, 921599, '\p{ -Is_default_IGNORABLE_code_Point}', "");
Expect(0, 921599, '\p{^ -Is_default_IGNORABLE_code_Point}', "");
Expect(0, 921599, '\P{ -Is_default_IGNORABLE_code_Point}', "");
Expect(1, 921599, '\P{^ -Is_default_IGNORABLE_code_Point}', "");
Expect(0, 921600, '\p{ -Is_default_IGNORABLE_code_Point}', "");
Expect(1, 921600, '\p{^ -Is_default_IGNORABLE_code_Point}', "");
Expect(1, 921600, '\P{ -Is_default_IGNORABLE_code_Point}', "");
Expect(0, 921600, '\P{^ -Is_default_IGNORABLE_code_Point}', "");
Error('\p{:=DI}');
Error('\P{:=DI}');
Expect(1, 921599, '\p{di}', "");
Expect(0, 921599, '\p{^di}', "");
Expect(0, 921599, '\P{di}', "");
Expect(1, 921599, '\P{^di}', "");
Expect(0, 921600, '\p{di}', "");
Expect(1, 921600, '\p{^di}', "");
Expect(1, 921600, '\P{di}', "");
Expect(0, 921600, '\P{^di}', "");
Expect(1, 921599, '\p{-_DI}', "");
Expect(0, 921599, '\p{^-_DI}', "");
Expect(0, 921599, '\P{-_DI}', "");
Expect(1, 921599, '\P{^-_DI}', "");
Expect(0, 921600, '\p{-_DI}', "");
Expect(1, 921600, '\p{^-_DI}', "");
Expect(1, 921600, '\P{-_DI}', "");
Expect(0, 921600, '\P{^-_DI}', "");
Error('\p{_:=is_di}');
Error('\P{_:=is_di}');
Expect(1, 921599, '\p{isdi}', "");
Expect(0, 921599, '\p{^isdi}', "");
Expect(0, 921599, '\P{isdi}', "");
Expect(1, 921599, '\P{^isdi}', "");
Expect(0, 921600, '\p{isdi}', "");
Expect(1, 921600, '\p{^isdi}', "");
Expect(1, 921600, '\P{isdi}', "");
Expect(0, 921600, '\P{^isdi}', "");
Expect(1, 921599, '\p{-Is_DI}', "");
Expect(0, 921599, '\p{^-Is_DI}', "");
Expect(0, 921599, '\P{-Is_DI}', "");
Expect(1, 921599, '\P{^-Is_DI}', "");
Expect(0, 921600, '\p{-Is_DI}', "");
Expect(1, 921600, '\p{^-Is_DI}', "");
Expect(1, 921600, '\P{-Is_DI}', "");
Expect(0, 921600, '\P{^-Is_DI}', "");
Error('\p{/a/_Deprecated}');
Error('\P{/a/_Deprecated}');
Expect(1, 917631, '\p{deprecated}', "");
Expect(0, 917631, '\p{^deprecated}', "");
Expect(0, 917631, '\P{deprecated}', "");
Expect(1, 917631, '\P{^deprecated}', "");
Expect(0, 917632, '\p{deprecated}', "");
Expect(1, 917632, '\p{^deprecated}', "");
Expect(1, 917632, '\P{deprecated}', "");
Expect(0, 917632, '\P{^deprecated}', "");
Expect(1, 917631, '\p{ -Deprecated}', "");
Expect(0, 917631, '\p{^ -Deprecated}', "");
Expect(0, 917631, '\P{ -Deprecated}', "");
Expect(1, 917631, '\P{^ -Deprecated}', "");
Expect(0, 917632, '\p{ -Deprecated}', "");
Expect(1, 917632, '\p{^ -Deprecated}', "");
Expect(1, 917632, '\P{ -Deprecated}', "");
Expect(0, 917632, '\P{^ -Deprecated}', "");
Error('\p{/a/is_Deprecated}');
Error('\P{/a/is_Deprecated}');
Expect(1, 917631, '\p{isdeprecated}', "");
Expect(0, 917631, '\p{^isdeprecated}', "");
Expect(0, 917631, '\P{isdeprecated}', "");
Expect(1, 917631, '\P{^isdeprecated}', "");
Expect(0, 917632, '\p{isdeprecated}', "");
Expect(1, 917632, '\p{^isdeprecated}', "");
Expect(1, 917632, '\P{isdeprecated}', "");
Expect(0, 917632, '\P{^isdeprecated}', "");
Expect(1, 917631, '\p{-Is_DEPRECATED}', "");
Expect(0, 917631, '\p{^-Is_DEPRECATED}', "");
Expect(0, 917631, '\P{-Is_DEPRECATED}', "");
Expect(1, 917631, '\P{^-Is_DEPRECATED}', "");
Expect(0, 917632, '\p{-Is_DEPRECATED}', "");
Expect(1, 917632, '\p{^-Is_DEPRECATED}', "");
Expect(1, 917632, '\P{-Is_DEPRECATED}', "");
Expect(0, 917632, '\P{^-Is_DEPRECATED}', "");
Error('\p{ _dep:=}');
Error('\P{ _dep:=}');
Expect(1, 917631, '\p{dep}', "");
Expect(0, 917631, '\p{^dep}', "");
Expect(0, 917631, '\P{dep}', "");
Expect(1, 917631, '\P{^dep}', "");
Expect(0, 917632, '\p{dep}', "");
Expect(1, 917632, '\p{^dep}', "");
Expect(1, 917632, '\P{dep}', "");
Expect(0, 917632, '\P{^dep}', "");
Expect(1, 917631, '\p{- Dep}', "");
Expect(0, 917631, '\p{^- Dep}', "");
Expect(0, 917631, '\P{- Dep}', "");
Expect(1, 917631, '\P{^- Dep}', "");
Expect(0, 917632, '\p{- Dep}', "");
Expect(1, 917632, '\p{^- Dep}', "");
Expect(1, 917632, '\P{- Dep}', "");
Expect(0, 917632, '\P{^- Dep}', "");
Error('\p{ Is_dep:=}');
Error('\P{ Is_dep:=}');
Expect(1, 917631, '\p{isdep}', "");
Expect(0, 917631, '\p{^isdep}', "");
Expect(0, 917631, '\P{isdep}', "");
Expect(1, 917631, '\P{^isdep}', "");
Expect(0, 917632, '\p{isdep}', "");
Expect(1, 917632, '\p{^isdep}', "");
Expect(1, 917632, '\P{isdep}', "");
Expect(0, 917632, '\P{^isdep}', "");
Expect(1, 917631, '\p{ IS_DEP}', "");
Expect(0, 917631, '\p{^ IS_DEP}', "");
Expect(0, 917631, '\P{ IS_DEP}', "");
Expect(1, 917631, '\P{^ IS_DEP}', "");
Expect(0, 917632, '\p{ IS_DEP}', "");
Expect(1, 917632, '\p{^ IS_DEP}', "");
Expect(1, 917632, '\P{ IS_DEP}', "");
Expect(0, 917632, '\P{^ IS_DEP}', "");
Error('\p{:=_-Deseret}');
Error('\P{:=_-Deseret}');
Expect(1, 66639, '\p{deseret}', "");
Expect(0, 66639, '\p{^deseret}', "");
Expect(0, 66639, '\P{deseret}', "");
Expect(1, 66639, '\P{^deseret}', "");
Expect(0, 66640, '\p{deseret}', "");
Expect(1, 66640, '\p{^deseret}', "");
Expect(1, 66640, '\P{deseret}', "");
Expect(0, 66640, '\P{^deseret}', "");
Expect(1, 66639, '\p{	Deseret}', "");
Expect(0, 66639, '\p{^	Deseret}', "");
Expect(0, 66639, '\P{	Deseret}', "");
Expect(1, 66639, '\P{^	Deseret}', "");
Expect(0, 66640, '\p{	Deseret}', "");
Expect(1, 66640, '\p{^	Deseret}', "");
Expect(1, 66640, '\P{	Deseret}', "");
Expect(0, 66640, '\P{^	Deseret}', "");
Error('\p{-Is_deseret/a/}');
Error('\P{-Is_deseret/a/}');
Expect(1, 66639, '\p{isdeseret}', "");
Expect(0, 66639, '\p{^isdeseret}', "");
Expect(0, 66639, '\P{isdeseret}', "");
Expect(1, 66639, '\P{^isdeseret}', "");
Expect(0, 66640, '\p{isdeseret}', "");
Expect(1, 66640, '\p{^isdeseret}', "");
Expect(1, 66640, '\P{isdeseret}', "");
Expect(0, 66640, '\P{^isdeseret}', "");
Expect(1, 66639, '\p{_ Is_DESERET}', "");
Expect(0, 66639, '\p{^_ Is_DESERET}', "");
Expect(0, 66639, '\P{_ Is_DESERET}', "");
Expect(1, 66639, '\P{^_ Is_DESERET}', "");
Expect(0, 66640, '\p{_ Is_DESERET}', "");
Expect(1, 66640, '\p{^_ Is_DESERET}', "");
Expect(1, 66640, '\P{_ Is_DESERET}', "");
Expect(0, 66640, '\P{^_ Is_DESERET}', "");
Error('\p{ -Dsrt:=}');
Error('\P{ -Dsrt:=}');
Expect(1, 66639, '\p{dsrt}', "");
Expect(0, 66639, '\p{^dsrt}', "");
Expect(0, 66639, '\P{dsrt}', "");
Expect(1, 66639, '\P{^dsrt}', "");
Expect(0, 66640, '\p{dsrt}', "");
Expect(1, 66640, '\p{^dsrt}', "");
Expect(1, 66640, '\P{dsrt}', "");
Expect(0, 66640, '\P{^dsrt}', "");
Expect(1, 66639, '\p{-Dsrt}', "");
Expect(0, 66639, '\p{^-Dsrt}', "");
Expect(0, 66639, '\P{-Dsrt}', "");
Expect(1, 66639, '\P{^-Dsrt}', "");
Expect(0, 66640, '\p{-Dsrt}', "");
Expect(1, 66640, '\p{^-Dsrt}', "");
Expect(1, 66640, '\P{-Dsrt}', "");
Expect(0, 66640, '\P{^-Dsrt}', "");
Error('\p{:=_	is_dsrt}');
Error('\P{:=_	is_dsrt}');
Expect(1, 66639, '\p{isdsrt}', "");
Expect(0, 66639, '\p{^isdsrt}', "");
Expect(0, 66639, '\P{isdsrt}', "");
Expect(1, 66639, '\P{^isdsrt}', "");
Expect(0, 66640, '\p{isdsrt}', "");
Expect(1, 66640, '\p{^isdsrt}', "");
Expect(1, 66640, '\P{isdsrt}', "");
Expect(0, 66640, '\P{^isdsrt}', "");
Expect(1, 66639, '\p{ 	Is_DSRT}', "");
Expect(0, 66639, '\p{^ 	Is_DSRT}', "");
Expect(0, 66639, '\P{ 	Is_DSRT}', "");
Expect(1, 66639, '\P{^ 	Is_DSRT}', "");
Expect(0, 66640, '\p{ 	Is_DSRT}', "");
Expect(1, 66640, '\p{^ 	Is_DSRT}', "");
Expect(1, 66640, '\P{ 	Is_DSRT}', "");
Expect(0, 66640, '\P{^ 	Is_DSRT}', "");
Error('\p{:= -Devanagari}');
Error('\P{:= -Devanagari}');
Expect(1, 43259, '\p{devanagari}', "");
Expect(0, 43259, '\p{^devanagari}', "");
Expect(0, 43259, '\P{devanagari}', "");
Expect(1, 43259, '\P{^devanagari}', "");
Expect(0, 43260, '\p{devanagari}', "");
Expect(1, 43260, '\p{^devanagari}', "");
Expect(1, 43260, '\P{devanagari}', "");
Expect(0, 43260, '\P{^devanagari}', "");
Expect(1, 43259, '\p{  Devanagari}', "");
Expect(0, 43259, '\p{^  Devanagari}', "");
Expect(0, 43259, '\P{  Devanagari}', "");
Expect(1, 43259, '\P{^  Devanagari}', "");
Expect(0, 43260, '\p{  Devanagari}', "");
Expect(1, 43260, '\p{^  Devanagari}', "");
Expect(1, 43260, '\P{  Devanagari}', "");
Expect(0, 43260, '\P{^  Devanagari}', "");
Error('\p{/a/--Is_Devanagari}');
Error('\P{/a/--Is_Devanagari}');
Expect(1, 43259, '\p{isdevanagari}', "");
Expect(0, 43259, '\p{^isdevanagari}', "");
Expect(0, 43259, '\P{isdevanagari}', "");
Expect(1, 43259, '\P{^isdevanagari}', "");
Expect(0, 43260, '\p{isdevanagari}', "");
Expect(1, 43260, '\p{^isdevanagari}', "");
Expect(1, 43260, '\P{isdevanagari}', "");
Expect(0, 43260, '\P{^isdevanagari}', "");
Expect(1, 43259, '\p{_	Is_DEVANAGARI}', "");
Expect(0, 43259, '\p{^_	Is_DEVANAGARI}', "");
Expect(0, 43259, '\P{_	Is_DEVANAGARI}', "");
Expect(1, 43259, '\P{^_	Is_DEVANAGARI}', "");
Expect(0, 43260, '\p{_	Is_DEVANAGARI}', "");
Expect(1, 43260, '\p{^_	Is_DEVANAGARI}', "");
Expect(1, 43260, '\P{_	Is_DEVANAGARI}', "");
Expect(0, 43260, '\P{^_	Is_DEVANAGARI}', "");
Error('\p{:=		Deva}');
Error('\P{:=		Deva}');
Expect(1, 43259, '\p{deva}', "");
Expect(0, 43259, '\p{^deva}', "");
Expect(0, 43259, '\P{deva}', "");
Expect(1, 43259, '\P{^deva}', "");
Expect(0, 43260, '\p{deva}', "");
Expect(1, 43260, '\p{^deva}', "");
Expect(1, 43260, '\P{deva}', "");
Expect(0, 43260, '\P{^deva}', "");
Expect(1, 43259, '\p{__DEVA}', "");
Expect(0, 43259, '\p{^__DEVA}', "");
Expect(0, 43259, '\P{__DEVA}', "");
Expect(1, 43259, '\P{^__DEVA}', "");
Expect(0, 43260, '\p{__DEVA}', "");
Expect(1, 43260, '\p{^__DEVA}', "");
Expect(1, 43260, '\P{__DEVA}', "");
Expect(0, 43260, '\P{^__DEVA}', "");
Error('\p{_:=IS_Deva}');
Error('\P{_:=IS_Deva}');
Expect(1, 43259, '\p{isdeva}', "");
Expect(0, 43259, '\p{^isdeva}', "");
Expect(0, 43259, '\P{isdeva}', "");
Expect(1, 43259, '\P{^isdeva}', "");
Expect(0, 43260, '\p{isdeva}', "");
Expect(1, 43260, '\p{^isdeva}', "");
Expect(1, 43260, '\P{isdeva}', "");
Expect(0, 43260, '\P{^isdeva}', "");
Expect(1, 43259, '\p{_ Is_Deva}', "");
Expect(0, 43259, '\p{^_ Is_Deva}', "");
Expect(0, 43259, '\P{_ Is_Deva}', "");
Expect(1, 43259, '\P{^_ Is_Deva}', "");
Expect(0, 43260, '\p{_ Is_Deva}', "");
Expect(1, 43260, '\p{^_ Is_Deva}', "");
Expect(1, 43260, '\P{_ Is_Deva}', "");
Expect(0, 43260, '\P{^_ Is_Deva}', "");
Error('\p{ /a/devanagari_Extended}');
Error('\P{ /a/devanagari_Extended}');
Expect(1, 43263, '\p{devanagariextended}', "");
Expect(0, 43263, '\p{^devanagariextended}', "");
Expect(0, 43263, '\P{devanagariextended}', "");
Expect(1, 43263, '\P{^devanagariextended}', "");
Expect(0, 43264, '\p{devanagariextended}', "");
Expect(1, 43264, '\p{^devanagariextended}', "");
Expect(1, 43264, '\P{devanagariextended}', "");
Expect(0, 43264, '\P{^devanagariextended}', "");
Expect(1, 43263, '\p{ _DEVANAGARI_extended}', "");
Expect(0, 43263, '\p{^ _DEVANAGARI_extended}', "");
Expect(0, 43263, '\P{ _DEVANAGARI_extended}', "");
Expect(1, 43263, '\P{^ _DEVANAGARI_extended}', "");
Expect(0, 43264, '\p{ _DEVANAGARI_extended}', "");
Expect(1, 43264, '\p{^ _DEVANAGARI_extended}', "");
Expect(1, 43264, '\P{ _DEVANAGARI_extended}', "");
Expect(0, 43264, '\P{^ _DEVANAGARI_extended}', "");
Error('\p{	is_DEVANAGARI_extended/a/}');
Error('\P{	is_DEVANAGARI_extended/a/}');
Expect(1, 43263, '\p{isdevanagariextended}', "");
Expect(0, 43263, '\p{^isdevanagariextended}', "");
Expect(0, 43263, '\P{isdevanagariextended}', "");
Expect(1, 43263, '\P{^isdevanagariextended}', "");
Expect(0, 43264, '\p{isdevanagariextended}', "");
Expect(1, 43264, '\p{^isdevanagariextended}', "");
Expect(1, 43264, '\P{isdevanagariextended}', "");
Expect(0, 43264, '\P{^isdevanagariextended}', "");
Expect(1, 43263, '\p{-IS_DEVANAGARI_EXTENDED}', "");
Expect(0, 43263, '\p{^-IS_DEVANAGARI_EXTENDED}', "");
Expect(0, 43263, '\P{-IS_DEVANAGARI_EXTENDED}', "");
Expect(1, 43263, '\P{^-IS_DEVANAGARI_EXTENDED}', "");
Expect(0, 43264, '\p{-IS_DEVANAGARI_EXTENDED}', "");
Expect(1, 43264, '\p{^-IS_DEVANAGARI_EXTENDED}', "");
Expect(1, 43264, '\P{-IS_DEVANAGARI_EXTENDED}', "");
Expect(0, 43264, '\P{^-IS_DEVANAGARI_EXTENDED}', "");
Error('\p{_	IN_DEVANAGARI_Extended/a/}');
Error('\P{_	IN_DEVANAGARI_Extended/a/}');
Expect(1, 43263, '\p{indevanagariextended}', "");
Expect(0, 43263, '\p{^indevanagariextended}', "");
Expect(0, 43263, '\P{indevanagariextended}', "");
Expect(1, 43263, '\P{^indevanagariextended}', "");
Expect(0, 43264, '\p{indevanagariextended}', "");
Expect(1, 43264, '\p{^indevanagariextended}', "");
Expect(1, 43264, '\P{indevanagariextended}', "");
Expect(0, 43264, '\P{^indevanagariextended}', "");
Expect(1, 43263, '\p{-In_Devanagari_Extended}', "");
Expect(0, 43263, '\p{^-In_Devanagari_Extended}', "");
Expect(0, 43263, '\P{-In_Devanagari_Extended}', "");
Expect(1, 43263, '\P{^-In_Devanagari_Extended}', "");
Expect(0, 43264, '\p{-In_Devanagari_Extended}', "");
Expect(1, 43264, '\p{^-In_Devanagari_Extended}', "");
Expect(1, 43264, '\P{-In_Devanagari_Extended}', "");
Expect(0, 43264, '\P{^-In_Devanagari_Extended}', "");
Error('\p{ -Devanagari_ext:=}');
Error('\P{ -Devanagari_ext:=}');
Expect(1, 43263, '\p{devanagariext}', "");
Expect(0, 43263, '\p{^devanagariext}', "");
Expect(0, 43263, '\P{devanagariext}', "");
Expect(1, 43263, '\P{^devanagariext}', "");
Expect(0, 43264, '\p{devanagariext}', "");
Expect(1, 43264, '\p{^devanagariext}', "");
Expect(1, 43264, '\P{devanagariext}', "");
Expect(0, 43264, '\P{^devanagariext}', "");
Expect(1, 43263, '\p{--Devanagari_Ext}', "");
Expect(0, 43263, '\p{^--Devanagari_Ext}', "");
Expect(0, 43263, '\P{--Devanagari_Ext}', "");
Expect(1, 43263, '\P{^--Devanagari_Ext}', "");
Expect(0, 43264, '\p{--Devanagari_Ext}', "");
Expect(1, 43264, '\p{^--Devanagari_Ext}', "");
Expect(1, 43264, '\P{--Devanagari_Ext}', "");
Expect(0, 43264, '\P{^--Devanagari_Ext}', "");
Error('\p{:=-is_devanagari_EXT}');
Error('\P{:=-is_devanagari_EXT}');
Expect(1, 43263, '\p{isdevanagariext}', "");
Expect(0, 43263, '\p{^isdevanagariext}', "");
Expect(0, 43263, '\P{isdevanagariext}', "");
Expect(1, 43263, '\P{^isdevanagariext}', "");
Expect(0, 43264, '\p{isdevanagariext}', "");
Expect(1, 43264, '\p{^isdevanagariext}', "");
Expect(1, 43264, '\P{isdevanagariext}', "");
Expect(0, 43264, '\P{^isdevanagariext}', "");
Expect(1, 43263, '\p{	 Is_Devanagari_EXT}', "");
Expect(0, 43263, '\p{^	 Is_Devanagari_EXT}', "");
Expect(0, 43263, '\P{	 Is_Devanagari_EXT}', "");
Expect(1, 43263, '\P{^	 Is_Devanagari_EXT}', "");
Expect(0, 43264, '\p{	 Is_Devanagari_EXT}', "");
Expect(1, 43264, '\p{^	 Is_Devanagari_EXT}', "");
Expect(1, 43264, '\P{	 Is_Devanagari_EXT}', "");
Expect(0, 43264, '\P{^	 Is_Devanagari_EXT}', "");
Error('\p{/a/_In_devanagari_ext}');
Error('\P{/a/_In_devanagari_ext}');
Expect(1, 43263, '\p{indevanagariext}', "");
Expect(0, 43263, '\p{^indevanagariext}', "");
Expect(0, 43263, '\P{indevanagariext}', "");
Expect(1, 43263, '\P{^indevanagariext}', "");
Expect(0, 43264, '\p{indevanagariext}', "");
Expect(1, 43264, '\p{^indevanagariext}', "");
Expect(1, 43264, '\P{indevanagariext}', "");
Expect(0, 43264, '\P{^indevanagariext}', "");
Expect(1, 43263, '\p{	In_devanagari_Ext}', "");
Expect(0, 43263, '\p{^	In_devanagari_Ext}', "");
Expect(0, 43263, '\P{	In_devanagari_Ext}', "");
Expect(1, 43263, '\P{^	In_devanagari_Ext}', "");
Expect(0, 43264, '\p{	In_devanagari_Ext}', "");
Expect(1, 43264, '\p{^	In_devanagari_Ext}', "");
Expect(1, 43264, '\P{	In_devanagari_Ext}', "");
Expect(0, 43264, '\P{^	In_devanagari_Ext}', "");
Error('\p{		Diacritic:=}');
Error('\P{		Diacritic:=}');
Expect(1, 119213, '\p{diacritic}', "");
Expect(0, 119213, '\p{^diacritic}', "");
Expect(0, 119213, '\P{diacritic}', "");
Expect(1, 119213, '\P{^diacritic}', "");
Expect(0, 119214, '\p{diacritic}', "");
Expect(1, 119214, '\p{^diacritic}', "");
Expect(1, 119214, '\P{diacritic}', "");
Expect(0, 119214, '\P{^diacritic}', "");
Expect(1, 119213, '\p{--DIACRITIC}', "");
Expect(0, 119213, '\p{^--DIACRITIC}', "");
Expect(0, 119213, '\P{--DIACRITIC}', "");
Expect(1, 119213, '\P{^--DIACRITIC}', "");
Expect(0, 119214, '\p{--DIACRITIC}', "");
Expect(1, 119214, '\p{^--DIACRITIC}', "");
Expect(1, 119214, '\P{--DIACRITIC}', "");
Expect(0, 119214, '\P{^--DIACRITIC}', "");
Error('\p{/a/		Is_diacritic}');
Error('\P{/a/		Is_diacritic}');
Expect(1, 119213, '\p{isdiacritic}', "");
Expect(0, 119213, '\p{^isdiacritic}', "");
Expect(0, 119213, '\P{isdiacritic}', "");
Expect(1, 119213, '\P{^isdiacritic}', "");
Expect(0, 119214, '\p{isdiacritic}', "");
Expect(1, 119214, '\p{^isdiacritic}', "");
Expect(1, 119214, '\P{isdiacritic}', "");
Expect(0, 119214, '\P{^isdiacritic}', "");
Expect(1, 119213, '\p{-Is_diacritic}', "");
Expect(0, 119213, '\p{^-Is_diacritic}', "");
Expect(0, 119213, '\P{-Is_diacritic}', "");
Expect(1, 119213, '\P{^-Is_diacritic}', "");
Expect(0, 119214, '\p{-Is_diacritic}', "");
Expect(1, 119214, '\p{^-Is_diacritic}', "");
Expect(1, 119214, '\P{-Is_diacritic}', "");
Expect(0, 119214, '\P{^-Is_diacritic}', "");
Error('\p{-_dia/a/}');
Error('\P{-_dia/a/}');
Expect(1, 119213, '\p{dia}', "");
Expect(0, 119213, '\p{^dia}', "");
Expect(0, 119213, '\P{dia}', "");
Expect(1, 119213, '\P{^dia}', "");
Expect(0, 119214, '\p{dia}', "");
Expect(1, 119214, '\p{^dia}', "");
Expect(1, 119214, '\P{dia}', "");
Expect(0, 119214, '\P{^dia}', "");
Expect(1, 119213, '\p{--dia}', "");
Expect(0, 119213, '\p{^--dia}', "");
Expect(0, 119213, '\P{--dia}', "");
Expect(1, 119213, '\P{^--dia}', "");
Expect(0, 119214, '\p{--dia}', "");
Expect(1, 119214, '\p{^--dia}', "");
Expect(1, 119214, '\P{--dia}', "");
Expect(0, 119214, '\P{^--dia}', "");
Error('\p{ -is_DIA:=}');
Error('\P{ -is_DIA:=}');
Expect(1, 119213, '\p{isdia}', "");
Expect(0, 119213, '\p{^isdia}', "");
Expect(0, 119213, '\P{isdia}', "");
Expect(1, 119213, '\P{^isdia}', "");
Expect(0, 119214, '\p{isdia}', "");
Expect(1, 119214, '\p{^isdia}', "");
Expect(1, 119214, '\P{isdia}', "");
Expect(0, 119214, '\P{^isdia}', "");
Expect(1, 119213, '\p{	 IS_DIA}', "");
Expect(0, 119213, '\p{^	 IS_DIA}', "");
Expect(0, 119213, '\P{	 IS_DIA}', "");
Expect(1, 119213, '\P{^	 IS_DIA}', "");
Expect(0, 119214, '\p{	 IS_DIA}', "");
Expect(1, 119214, '\p{^	 IS_DIA}', "");
Expect(1, 119214, '\P{	 IS_DIA}', "");
Expect(0, 119214, '\P{^	 IS_DIA}', "");
Error('\p{/a/-_digit}');
Error('\P{/a/-_digit}');
Expect(1, 120831, '\p{digit}', "");
Expect(0, 120831, '\p{^digit}', "");
Expect(0, 120831, '\P{digit}', "");
Expect(1, 120831, '\P{^digit}', "");
Expect(0, 120832, '\p{digit}', "");
Expect(1, 120832, '\p{^digit}', "");
Expect(1, 120832, '\P{digit}', "");
Expect(0, 120832, '\P{^digit}', "");
Expect(1, 120831, '\p{_-digit}', "");
Expect(0, 120831, '\p{^_-digit}', "");
Expect(0, 120831, '\P{_-digit}', "");
Expect(1, 120831, '\P{^_-digit}', "");
Expect(0, 120832, '\p{_-digit}', "");
Expect(1, 120832, '\p{^_-digit}', "");
Expect(1, 120832, '\P{_-digit}', "");
Expect(0, 120832, '\P{^_-digit}', "");
Error('\p{- XPosixDigit/a/}');
Error('\P{- XPosixDigit/a/}');
Expect(1, 120831, '\p{xposixdigit}', "");
Expect(0, 120831, '\p{^xposixdigit}', "");
Expect(0, 120831, '\P{xposixdigit}', "");
Expect(1, 120831, '\P{^xposixdigit}', "");
Expect(0, 120832, '\p{xposixdigit}', "");
Expect(1, 120832, '\p{^xposixdigit}', "");
Expect(1, 120832, '\P{xposixdigit}', "");
Expect(0, 120832, '\P{^xposixdigit}', "");
Expect(1, 120831, '\p{_	xposixdigit}', "");
Expect(0, 120831, '\p{^_	xposixdigit}', "");
Expect(0, 120831, '\P{_	xposixdigit}', "");
Expect(1, 120831, '\P{^_	xposixdigit}', "");
Expect(0, 120832, '\p{_	xposixdigit}', "");
Expect(1, 120832, '\p{^_	xposixdigit}', "");
Expect(1, 120832, '\P{_	xposixdigit}', "");
Expect(0, 120832, '\P{^_	xposixdigit}', "");
Error('\p{-:=Is_digit}');
Error('\P{-:=Is_digit}');
Expect(1, 120831, '\p{isdigit}', "");
Expect(0, 120831, '\p{^isdigit}', "");
Expect(0, 120831, '\P{isdigit}', "");
Expect(1, 120831, '\P{^isdigit}', "");
Expect(0, 120832, '\p{isdigit}', "");
Expect(1, 120832, '\p{^isdigit}', "");
Expect(1, 120832, '\P{isdigit}', "");
Expect(0, 120832, '\P{^isdigit}', "");
Expect(1, 120831, '\p{		is_DIGIT}', "");
Expect(0, 120831, '\p{^		is_DIGIT}', "");
Expect(0, 120831, '\P{		is_DIGIT}', "");
Expect(1, 120831, '\P{^		is_DIGIT}', "");
Expect(0, 120832, '\p{		is_DIGIT}', "");
Expect(1, 120832, '\p{^		is_DIGIT}', "");
Expect(1, 120832, '\P{		is_DIGIT}', "");
Expect(0, 120832, '\P{^		is_DIGIT}', "");
Error('\p{-_Is_xposixdigit:=}');
Error('\P{-_Is_xposixdigit:=}');
Expect(1, 120831, '\p{isxposixdigit}', "");
Expect(0, 120831, '\p{^isxposixdigit}', "");
Expect(0, 120831, '\P{isxposixdigit}', "");
Expect(1, 120831, '\P{^isxposixdigit}', "");
Expect(0, 120832, '\p{isxposixdigit}', "");
Expect(1, 120832, '\p{^isxposixdigit}', "");
Expect(1, 120832, '\P{isxposixdigit}', "");
Expect(0, 120832, '\P{^isxposixdigit}', "");
Expect(1, 120831, '\p{_-IS_XPOSIXDIGIT}', "");
Expect(0, 120831, '\p{^_-IS_XPOSIXDIGIT}', "");
Expect(0, 120831, '\P{_-IS_XPOSIXDIGIT}', "");
Expect(1, 120831, '\P{^_-IS_XPOSIXDIGIT}', "");
Expect(0, 120832, '\p{_-IS_XPOSIXDIGIT}', "");
Expect(1, 120832, '\p{^_-IS_XPOSIXDIGIT}', "");
Expect(1, 120832, '\P{_-IS_XPOSIXDIGIT}', "");
Expect(0, 120832, '\P{^_-IS_XPOSIXDIGIT}', "");
Error('\p{	_DECIMAL_Number/a/}');
Error('\P{	_DECIMAL_Number/a/}');
Expect(1, 120831, '\p{decimalnumber}', "");
Expect(0, 120831, '\p{^decimalnumber}', "");
Expect(0, 120831, '\P{decimalnumber}', "");
Expect(1, 120831, '\P{^decimalnumber}', "");
Expect(0, 120832, '\p{decimalnumber}', "");
Expect(1, 120832, '\p{^decimalnumber}', "");
Expect(1, 120832, '\P{decimalnumber}', "");
Expect(0, 120832, '\P{^decimalnumber}', "");
Expect(1, 120831, '\p{Decimal_Number}', "");
Expect(0, 120831, '\p{^Decimal_Number}', "");
Expect(0, 120831, '\P{Decimal_Number}', "");
Expect(1, 120831, '\P{^Decimal_Number}', "");
Expect(0, 120832, '\p{Decimal_Number}', "");
Expect(1, 120832, '\p{^Decimal_Number}', "");
Expect(1, 120832, '\P{Decimal_Number}', "");
Expect(0, 120832, '\P{^Decimal_Number}', "");
Error('\p{	_is_Decimal_Number:=}');
Error('\P{	_is_Decimal_Number:=}');
Expect(1, 120831, '\p{isdecimalnumber}', "");
Expect(0, 120831, '\p{^isdecimalnumber}', "");
Expect(0, 120831, '\P{isdecimalnumber}', "");
Expect(1, 120831, '\P{^isdecimalnumber}', "");
Expect(0, 120832, '\p{isdecimalnumber}', "");
Expect(1, 120832, '\p{^isdecimalnumber}', "");
Expect(1, 120832, '\P{isdecimalnumber}', "");
Expect(0, 120832, '\P{^isdecimalnumber}', "");
Expect(1, 120831, '\p{-IS_Decimal_NUMBER}', "");
Expect(0, 120831, '\p{^-IS_Decimal_NUMBER}', "");
Expect(0, 120831, '\P{-IS_Decimal_NUMBER}', "");
Expect(1, 120831, '\P{^-IS_Decimal_NUMBER}', "");
Expect(0, 120832, '\p{-IS_Decimal_NUMBER}', "");
Expect(1, 120832, '\p{^-IS_Decimal_NUMBER}', "");
Expect(1, 120832, '\P{-IS_Decimal_NUMBER}', "");
Expect(0, 120832, '\P{^-IS_Decimal_NUMBER}', "");
Error('\p{_-nd:=}');
Error('\P{_-nd:=}');
Expect(1, 120831, '\p{nd}', "");
Expect(0, 120831, '\p{^nd}', "");
Expect(0, 120831, '\P{nd}', "");
Expect(1, 120831, '\P{^nd}', "");
Expect(0, 120832, '\p{nd}', "");
Expect(1, 120832, '\p{^nd}', "");
Expect(1, 120832, '\P{nd}', "");
Expect(0, 120832, '\P{^nd}', "");
Expect(1, 120831, '\p{-	Nd}', "");
Expect(0, 120831, '\p{^-	Nd}', "");
Expect(0, 120831, '\P{-	Nd}', "");
Expect(1, 120831, '\P{^-	Nd}', "");
Expect(0, 120832, '\p{-	Nd}', "");
Expect(1, 120832, '\p{^-	Nd}', "");
Expect(1, 120832, '\P{-	Nd}', "");
Expect(0, 120832, '\P{^-	Nd}', "");
Error('\p{--is_ND/a/}');
Error('\P{--is_ND/a/}');
Expect(1, 120831, '\p{isnd}', "");
Expect(0, 120831, '\p{^isnd}', "");
Expect(0, 120831, '\P{isnd}', "");
Expect(1, 120831, '\P{^isnd}', "");
Expect(0, 120832, '\p{isnd}', "");
Expect(1, 120832, '\p{^isnd}', "");
Expect(1, 120832, '\P{isnd}', "");
Expect(0, 120832, '\P{^isnd}', "");
Expect(1, 120831, '\p{__IS_nd}', "");
Expect(0, 120831, '\p{^__IS_nd}', "");
Expect(0, 120831, '\P{__IS_nd}', "");
Expect(1, 120831, '\P{^__IS_nd}', "");
Expect(0, 120832, '\p{__IS_nd}', "");
Expect(1, 120832, '\p{^__IS_nd}', "");
Expect(1, 120832, '\P{__IS_nd}', "");
Expect(0, 120832, '\P{^__IS_nd}', "");
Error('\p{--DINGBATS:=}');
Error('\P{--DINGBATS:=}');
Expect(1, 10175, '\p{dingbats}', "");
Expect(0, 10175, '\p{^dingbats}', "");
Expect(0, 10175, '\P{dingbats}', "");
Expect(1, 10175, '\P{^dingbats}', "");
Expect(0, 10176, '\p{dingbats}', "");
Expect(1, 10176, '\p{^dingbats}', "");
Expect(1, 10176, '\P{dingbats}', "");
Expect(0, 10176, '\P{^dingbats}', "");
Expect(1, 10175, '\p{	-Dingbats}', "");
Expect(0, 10175, '\p{^	-Dingbats}', "");
Expect(0, 10175, '\P{	-Dingbats}', "");
Expect(1, 10175, '\P{^	-Dingbats}', "");
Expect(0, 10176, '\p{	-Dingbats}', "");
Expect(1, 10176, '\p{^	-Dingbats}', "");
Expect(1, 10176, '\P{	-Dingbats}', "");
Expect(0, 10176, '\P{^	-Dingbats}', "");
Error('\p{Is_Dingbats/a/}');
Error('\P{Is_Dingbats/a/}');
Expect(1, 10175, '\p{isdingbats}', "");
Expect(0, 10175, '\p{^isdingbats}', "");
Expect(0, 10175, '\P{isdingbats}', "");
Expect(1, 10175, '\P{^isdingbats}', "");
Expect(0, 10176, '\p{isdingbats}', "");
Expect(1, 10176, '\p{^isdingbats}', "");
Expect(1, 10176, '\P{isdingbats}', "");
Expect(0, 10176, '\P{^isdingbats}', "");
Expect(1, 10175, '\p{ 	Is_dingbats}', "");
Expect(0, 10175, '\p{^ 	Is_dingbats}', "");
Expect(0, 10175, '\P{ 	Is_dingbats}', "");
Expect(1, 10175, '\P{^ 	Is_dingbats}', "");
Expect(0, 10176, '\p{ 	Is_dingbats}', "");
Expect(1, 10176, '\p{^ 	Is_dingbats}', "");
Expect(1, 10176, '\P{ 	Is_dingbats}', "");
Expect(0, 10176, '\P{^ 	Is_dingbats}', "");
Error('\p{:=- in_Dingbats}');
Error('\P{:=- in_Dingbats}');
Expect(1, 10175, '\p{indingbats}', "");
Expect(0, 10175, '\p{^indingbats}', "");
Expect(0, 10175, '\P{indingbats}', "");
Expect(1, 10175, '\P{^indingbats}', "");
Expect(0, 10176, '\p{indingbats}', "");
Expect(1, 10176, '\p{^indingbats}', "");
Expect(1, 10176, '\P{indingbats}', "");
Expect(0, 10176, '\P{^indingbats}', "");
Expect(1, 10175, '\p{ In_DINGBATS}', "");
Expect(0, 10175, '\p{^ In_DINGBATS}', "");
Expect(0, 10175, '\P{ In_DINGBATS}', "");
Expect(1, 10175, '\P{^ In_DINGBATS}', "");
Expect(0, 10176, '\p{ In_DINGBATS}', "");
Expect(1, 10176, '\p{^ In_DINGBATS}', "");
Expect(1, 10176, '\P{ In_DINGBATS}', "");
Expect(0, 10176, '\P{^ In_DINGBATS}', "");
Error('\p{ -DOMINO_Tiles:=}');
Error('\P{ -DOMINO_Tiles:=}');
Expect(1, 127135, '\p{dominotiles}', "");
Expect(0, 127135, '\p{^dominotiles}', "");
Expect(0, 127135, '\P{dominotiles}', "");
Expect(1, 127135, '\P{^dominotiles}', "");
Expect(0, 127136, '\p{dominotiles}', "");
Expect(1, 127136, '\p{^dominotiles}', "");
Expect(1, 127136, '\P{dominotiles}', "");
Expect(0, 127136, '\P{^dominotiles}', "");
Expect(1, 127135, '\p{ Domino_TILES}', "");
Expect(0, 127135, '\p{^ Domino_TILES}', "");
Expect(0, 127135, '\P{ Domino_TILES}', "");
Expect(1, 127135, '\P{^ Domino_TILES}', "");
Expect(0, 127136, '\p{ Domino_TILES}', "");
Expect(1, 127136, '\p{^ Domino_TILES}', "");
Expect(1, 127136, '\P{ Domino_TILES}', "");
Expect(0, 127136, '\P{^ Domino_TILES}', "");
Error('\p{ :=IS_domino_Tiles}');
Error('\P{ :=IS_domino_Tiles}');
Expect(1, 127135, '\p{isdominotiles}', "");
Expect(0, 127135, '\p{^isdominotiles}', "");
Expect(0, 127135, '\P{isdominotiles}', "");
Expect(1, 127135, '\P{^isdominotiles}', "");
Expect(0, 127136, '\p{isdominotiles}', "");
Expect(1, 127136, '\p{^isdominotiles}', "");
Expect(1, 127136, '\P{isdominotiles}', "");
Expect(0, 127136, '\P{^isdominotiles}', "");
Expect(1, 127135, '\p{	Is_Domino_Tiles}', "");
Expect(0, 127135, '\p{^	Is_Domino_Tiles}', "");
Expect(0, 127135, '\P{	Is_Domino_Tiles}', "");
Expect(1, 127135, '\P{^	Is_Domino_Tiles}', "");
Expect(0, 127136, '\p{	Is_Domino_Tiles}', "");
Expect(1, 127136, '\p{^	Is_Domino_Tiles}', "");
Expect(1, 127136, '\P{	Is_Domino_Tiles}', "");
Expect(0, 127136, '\P{^	Is_Domino_Tiles}', "");
Error('\p{	_IN_domino_Tiles/a/}');
Error('\P{	_IN_domino_Tiles/a/}');
Expect(1, 127135, '\p{indominotiles}', "");
Expect(0, 127135, '\p{^indominotiles}', "");
Expect(0, 127135, '\P{indominotiles}', "");
Expect(1, 127135, '\P{^indominotiles}', "");
Expect(0, 127136, '\p{indominotiles}', "");
Expect(1, 127136, '\p{^indominotiles}', "");
Expect(1, 127136, '\P{indominotiles}', "");
Expect(0, 127136, '\P{^indominotiles}', "");
Expect(1, 127135, '\p{	_In_Domino_TILES}', "");
Expect(0, 127135, '\p{^	_In_Domino_TILES}', "");
Expect(0, 127135, '\P{	_In_Domino_TILES}', "");
Expect(1, 127135, '\P{^	_In_Domino_TILES}', "");
Expect(0, 127136, '\p{	_In_Domino_TILES}', "");
Expect(1, 127136, '\p{^	_In_Domino_TILES}', "");
Expect(1, 127136, '\P{	_In_Domino_TILES}', "");
Expect(0, 127136, '\P{^	_In_Domino_TILES}', "");
Error('\p{:=-domino}');
Error('\P{:=-domino}');
Expect(1, 127135, '\p{domino}', "");
Expect(0, 127135, '\p{^domino}', "");
Expect(0, 127135, '\P{domino}', "");
Expect(1, 127135, '\P{^domino}', "");
Expect(0, 127136, '\p{domino}', "");
Expect(1, 127136, '\p{^domino}', "");
Expect(1, 127136, '\P{domino}', "");
Expect(0, 127136, '\P{^domino}', "");
Expect(1, 127135, '\p{- Domino}', "");
Expect(0, 127135, '\p{^- Domino}', "");
Expect(0, 127135, '\P{- Domino}', "");
Expect(1, 127135, '\P{^- Domino}', "");
Expect(0, 127136, '\p{- Domino}', "");
Expect(1, 127136, '\p{^- Domino}', "");
Expect(1, 127136, '\P{- Domino}', "");
Expect(0, 127136, '\P{^- Domino}', "");
Error('\p{	/a/Is_Domino}');
Error('\P{	/a/Is_Domino}');
Expect(1, 127135, '\p{isdomino}', "");
Expect(0, 127135, '\p{^isdomino}', "");
Expect(0, 127135, '\P{isdomino}', "");
Expect(1, 127135, '\P{^isdomino}', "");
Expect(0, 127136, '\p{isdomino}', "");
Expect(1, 127136, '\p{^isdomino}', "");
Expect(1, 127136, '\P{isdomino}', "");
Expect(0, 127136, '\P{^isdomino}', "");
Expect(1, 127135, '\p{_	Is_DOMINO}', "");
Expect(0, 127135, '\p{^_	Is_DOMINO}', "");
Expect(0, 127135, '\P{_	Is_DOMINO}', "");
Expect(1, 127135, '\P{^_	Is_DOMINO}', "");
Expect(0, 127136, '\p{_	Is_DOMINO}', "");
Expect(1, 127136, '\p{^_	Is_DOMINO}', "");
Expect(1, 127136, '\P{_	Is_DOMINO}', "");
Expect(0, 127136, '\P{^_	Is_DOMINO}', "");
Error('\p{ in_domino:=}');
Error('\P{ in_domino:=}');
Expect(1, 127135, '\p{indomino}', "");
Expect(0, 127135, '\p{^indomino}', "");
Expect(0, 127135, '\P{indomino}', "");
Expect(1, 127135, '\P{^indomino}', "");
Expect(0, 127136, '\p{indomino}', "");
Expect(1, 127136, '\p{^indomino}', "");
Expect(1, 127136, '\P{indomino}', "");
Expect(0, 127136, '\P{^indomino}', "");
Expect(1, 127135, '\p{	In_DOMINO}', "");
Expect(0, 127135, '\p{^	In_DOMINO}', "");
Expect(0, 127135, '\P{	In_DOMINO}', "");
Expect(1, 127135, '\P{^	In_DOMINO}', "");
Expect(0, 127136, '\p{	In_DOMINO}', "");
Expect(1, 127136, '\p{^	In_DOMINO}', "");
Expect(1, 127136, '\P{	In_DOMINO}', "");
Expect(0, 127136, '\P{^	In_DOMINO}', "");
Error('\p{	:=Egyptian_HIEROGLYPHS}');
Error('\P{	:=Egyptian_HIEROGLYPHS}');
Expect(1, 78894, '\p{egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{_Egyptian_Hieroglyphs}', "");
Expect(0, 78894, '\p{^_Egyptian_Hieroglyphs}', "");
Expect(0, 78894, '\P{_Egyptian_Hieroglyphs}', "");
Expect(1, 78894, '\P{^_Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{_Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\p{^_Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{_Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{^_Egyptian_Hieroglyphs}', "");
Error('\p{	/a/Is_Egyptian_HIEROGLYPHS}');
Error('\P{	/a/Is_Egyptian_HIEROGLYPHS}');
Expect(1, 78894, '\p{isegyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^isegyptianhieroglyphs}', "");
Expect(0, 78894, '\P{isegyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^isegyptianhieroglyphs}', "");
Expect(0, 78895, '\p{isegyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^isegyptianhieroglyphs}', "");
Expect(1, 78895, '\P{isegyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^isegyptianhieroglyphs}', "");
Expect(1, 78894, '\p{	is_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78894, '\p{^	is_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78894, '\P{	is_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78894, '\P{^	is_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\p{	is_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\p{^	is_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\P{	is_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\P{^	is_EGYPTIAN_Hieroglyphs}', "");
Error('\p{:=-egyp}');
Error('\P{:=-egyp}');
Expect(1, 78894, '\p{egyp}', "");
Expect(0, 78894, '\p{^egyp}', "");
Expect(0, 78894, '\P{egyp}', "");
Expect(1, 78894, '\P{^egyp}', "");
Expect(0, 78895, '\p{egyp}', "");
Expect(1, 78895, '\p{^egyp}', "");
Expect(1, 78895, '\P{egyp}', "");
Expect(0, 78895, '\P{^egyp}', "");
Expect(1, 78894, '\p{_EGYP}', "");
Expect(0, 78894, '\p{^_EGYP}', "");
Expect(0, 78894, '\P{_EGYP}', "");
Expect(1, 78894, '\P{^_EGYP}', "");
Expect(0, 78895, '\p{_EGYP}', "");
Expect(1, 78895, '\p{^_EGYP}', "");
Expect(1, 78895, '\P{_EGYP}', "");
Expect(0, 78895, '\P{^_EGYP}', "");
Error('\p{-Is_egyp:=}');
Error('\P{-Is_egyp:=}');
Expect(1, 78894, '\p{isegyp}', "");
Expect(0, 78894, '\p{^isegyp}', "");
Expect(0, 78894, '\P{isegyp}', "");
Expect(1, 78894, '\P{^isegyp}', "");
Expect(0, 78895, '\p{isegyp}', "");
Expect(1, 78895, '\p{^isegyp}', "");
Expect(1, 78895, '\P{isegyp}', "");
Expect(0, 78895, '\P{^isegyp}', "");
Expect(1, 78894, '\p{_-is_Egyp}', "");
Expect(0, 78894, '\p{^_-is_Egyp}', "");
Expect(0, 78894, '\P{_-is_Egyp}', "");
Expect(1, 78894, '\P{^_-is_Egyp}', "");
Expect(0, 78895, '\p{_-is_Egyp}', "");
Expect(1, 78895, '\p{^_-is_Egyp}', "");
Expect(1, 78895, '\P{_-is_Egyp}', "");
Expect(0, 78895, '\P{^_-is_Egyp}', "");
Error('\p{-Emoticons:=}');
Error('\P{-Emoticons:=}');
Expect(1, 128591, '\p{emoticons}', "");
Expect(0, 128591, '\p{^emoticons}', "");
Expect(0, 128591, '\P{emoticons}', "");
Expect(1, 128591, '\P{^emoticons}', "");
Expect(0, 128592, '\p{emoticons}', "");
Expect(1, 128592, '\p{^emoticons}', "");
Expect(1, 128592, '\P{emoticons}', "");
Expect(0, 128592, '\P{^emoticons}', "");
Expect(1, 128591, '\p{ -Emoticons}', "");
Expect(0, 128591, '\p{^ -Emoticons}', "");
Expect(0, 128591, '\P{ -Emoticons}', "");
Expect(1, 128591, '\P{^ -Emoticons}', "");
Expect(0, 128592, '\p{ -Emoticons}', "");
Expect(1, 128592, '\p{^ -Emoticons}', "");
Expect(1, 128592, '\P{ -Emoticons}', "");
Expect(0, 128592, '\P{^ -Emoticons}', "");
Error('\p{/a/IS_EMOTICONS}');
Error('\P{/a/IS_EMOTICONS}');
Expect(1, 128591, '\p{isemoticons}', "");
Expect(0, 128591, '\p{^isemoticons}', "");
Expect(0, 128591, '\P{isemoticons}', "");
Expect(1, 128591, '\P{^isemoticons}', "");
Expect(0, 128592, '\p{isemoticons}', "");
Expect(1, 128592, '\p{^isemoticons}', "");
Expect(1, 128592, '\P{isemoticons}', "");
Expect(0, 128592, '\P{^isemoticons}', "");
Expect(1, 128591, '\p{_ Is_Emoticons}', "");
Expect(0, 128591, '\p{^_ Is_Emoticons}', "");
Expect(0, 128591, '\P{_ Is_Emoticons}', "");
Expect(1, 128591, '\P{^_ Is_Emoticons}', "");
Expect(0, 128592, '\p{_ Is_Emoticons}', "");
Expect(1, 128592, '\p{^_ Is_Emoticons}', "");
Expect(1, 128592, '\P{_ Is_Emoticons}', "");
Expect(0, 128592, '\P{^_ Is_Emoticons}', "");
Error('\p{	_In_EMOTICONS/a/}');
Error('\P{	_In_EMOTICONS/a/}');
Expect(1, 128591, '\p{inemoticons}', "");
Expect(0, 128591, '\p{^inemoticons}', "");
Expect(0, 128591, '\P{inemoticons}', "");
Expect(1, 128591, '\P{^inemoticons}', "");
Expect(0, 128592, '\p{inemoticons}', "");
Expect(1, 128592, '\p{^inemoticons}', "");
Expect(1, 128592, '\P{inemoticons}', "");
Expect(0, 128592, '\P{^inemoticons}', "");
Expect(1, 128591, '\p{	in_Emoticons}', "");
Expect(0, 128591, '\p{^	in_Emoticons}', "");
Expect(0, 128591, '\P{	in_Emoticons}', "");
Expect(1, 128591, '\P{^	in_Emoticons}', "");
Expect(0, 128592, '\p{	in_Emoticons}', "");
Expect(1, 128592, '\p{^	in_Emoticons}', "");
Expect(1, 128592, '\P{	in_Emoticons}', "");
Expect(0, 128592, '\P{^	in_Emoticons}', "");
Error('\p{:=	 enclosed_ALPHANUMERIC_supplement}');
Error('\P{:=	 enclosed_ALPHANUMERIC_supplement}');
Expect(1, 127487, '\p{enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^enclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^enclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{enclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^enclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{ enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127487, '\p{^ enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127487, '\P{ enclosed_Alphanumeric_Supplement}', "");
Expect(1, 127487, '\P{^ enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127488, '\p{ enclosed_Alphanumeric_Supplement}', "");
Expect(1, 127488, '\p{^ enclosed_Alphanumeric_Supplement}', "");
Expect(1, 127488, '\P{ enclosed_Alphanumeric_Supplement}', "");
Expect(0, 127488, '\P{^ enclosed_Alphanumeric_Supplement}', "");
Error('\p{	:=IS_Enclosed_Alphanumeric_SUPPLEMENT}');
Error('\P{	:=IS_Enclosed_Alphanumeric_SUPPLEMENT}');
Expect(1, 127487, '\p{isenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^isenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{isenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^isenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{isenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^isenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{isenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^isenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(0, 127487, '\p{^-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(0, 127487, '\P{-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(1, 127487, '\P{^-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(0, 127488, '\p{-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(1, 127488, '\p{^-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(1, 127488, '\P{-_Is_Enclosed_alphanumeric_Supplement}', "");
Expect(0, 127488, '\P{^-_Is_Enclosed_alphanumeric_Supplement}', "");
Error('\p{__in_enclosed_Alphanumeric_SUPPLEMENT:=}');
Error('\P{__in_enclosed_Alphanumeric_SUPPLEMENT:=}');
Expect(1, 127487, '\p{inenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\p{^inenclosedalphanumericsupplement}', "");
Expect(0, 127487, '\P{inenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\P{^inenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\p{inenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\p{^inenclosedalphanumericsupplement}', "");
Expect(1, 127488, '\P{inenclosedalphanumericsupplement}', "");
Expect(0, 127488, '\P{^inenclosedalphanumericsupplement}', "");
Expect(1, 127487, '\p{-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127487, '\p{^-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127487, '\P{-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(1, 127487, '\P{^-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127488, '\p{-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(1, 127488, '\p{^-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(1, 127488, '\P{-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Expect(0, 127488, '\P{^-IN_ENCLOSED_Alphanumeric_SUPPLEMENT}', "");
Error('\p{:=enclosed_Alphanum_sup}');
Error('\P{:=enclosed_Alphanum_sup}');
Expect(1, 127487, '\p{enclosedalphanumsup}', "");
Expect(0, 127487, '\p{^enclosedalphanumsup}', "");
Expect(0, 127487, '\P{enclosedalphanumsup}', "");
Expect(1, 127487, '\P{^enclosedalphanumsup}', "");
Expect(0, 127488, '\p{enclosedalphanumsup}', "");
Expect(1, 127488, '\p{^enclosedalphanumsup}', "");
Expect(1, 127488, '\P{enclosedalphanumsup}', "");
Expect(0, 127488, '\P{^enclosedalphanumsup}', "");
Expect(1, 127487, '\p{	ENCLOSED_Alphanum_SUP}', "");
Expect(0, 127487, '\p{^	ENCLOSED_Alphanum_SUP}', "");
Expect(0, 127487, '\P{	ENCLOSED_Alphanum_SUP}', "");
Expect(1, 127487, '\P{^	ENCLOSED_Alphanum_SUP}', "");
Expect(0, 127488, '\p{	ENCLOSED_Alphanum_SUP}', "");
Expect(1, 127488, '\p{^	ENCLOSED_Alphanum_SUP}', "");
Expect(1, 127488, '\P{	ENCLOSED_Alphanum_SUP}', "");
Expect(0, 127488, '\P{^	ENCLOSED_Alphanum_SUP}', "");
Error('\p{/a/_-Is_ENCLOSED_Alphanum_Sup}');
Error('\P{/a/_-Is_ENCLOSED_Alphanum_Sup}');
Expect(1, 127487, '\p{isenclosedalphanumsup}', "");
Expect(0, 127487, '\p{^isenclosedalphanumsup}', "");
Expect(0, 127487, '\P{isenclosedalphanumsup}', "");
Expect(1, 127487, '\P{^isenclosedalphanumsup}', "");
Expect(0, 127488, '\p{isenclosedalphanumsup}', "");
Expect(1, 127488, '\p{^isenclosedalphanumsup}', "");
Expect(1, 127488, '\P{isenclosedalphanumsup}', "");
Expect(0, 127488, '\P{^isenclosedalphanumsup}', "");
Expect(1, 127487, '\p{_ Is_Enclosed_alphanum_Sup}', "");
Expect(0, 127487, '\p{^_ Is_Enclosed_alphanum_Sup}', "");
Expect(0, 127487, '\P{_ Is_Enclosed_alphanum_Sup}', "");
Expect(1, 127487, '\P{^_ Is_Enclosed_alphanum_Sup}', "");
Expect(0, 127488, '\p{_ Is_Enclosed_alphanum_Sup}', "");
Expect(1, 127488, '\p{^_ Is_Enclosed_alphanum_Sup}', "");
Expect(1, 127488, '\P{_ Is_Enclosed_alphanum_Sup}', "");
Expect(0, 127488, '\P{^_ Is_Enclosed_alphanum_Sup}', "");
Error('\p{	:=In_Enclosed_Alphanum_SUP}');
Error('\P{	:=In_Enclosed_Alphanum_SUP}');
Expect(1, 127487, '\p{inenclosedalphanumsup}', "");
Expect(0, 127487, '\p{^inenclosedalphanumsup}', "");
Expect(0, 127487, '\P{inenclosedalphanumsup}', "");
Expect(1, 127487, '\P{^inenclosedalphanumsup}', "");
Expect(0, 127488, '\p{inenclosedalphanumsup}', "");
Expect(1, 127488, '\p{^inenclosedalphanumsup}', "");
Expect(1, 127488, '\P{inenclosedalphanumsup}', "");
Expect(0, 127488, '\P{^inenclosedalphanumsup}', "");
Expect(1, 127487, '\p{-	in_ENCLOSED_alphanum_Sup}', "");
Expect(0, 127487, '\p{^-	in_ENCLOSED_alphanum_Sup}', "");
Expect(0, 127487, '\P{-	in_ENCLOSED_alphanum_Sup}', "");
Expect(1, 127487, '\P{^-	in_ENCLOSED_alphanum_Sup}', "");
Expect(0, 127488, '\p{-	in_ENCLOSED_alphanum_Sup}', "");
Expect(1, 127488, '\p{^-	in_ENCLOSED_alphanum_Sup}', "");
Expect(1, 127488, '\P{-	in_ENCLOSED_alphanum_Sup}', "");
Expect(0, 127488, '\P{^-	in_ENCLOSED_alphanum_Sup}', "");
Error('\p{_ ENCLOSED_Alphanumerics/a/}');
Error('\P{_ ENCLOSED_Alphanumerics/a/}');
Expect(1, 9471, '\p{enclosedalphanumerics}', "");
Expect(0, 9471, '\p{^enclosedalphanumerics}', "");
Expect(0, 9471, '\P{enclosedalphanumerics}', "");
Expect(1, 9471, '\P{^enclosedalphanumerics}', "");
Expect(0, 9472, '\p{enclosedalphanumerics}', "");
Expect(1, 9472, '\p{^enclosedalphanumerics}', "");
Expect(1, 9472, '\P{enclosedalphanumerics}', "");
Expect(0, 9472, '\P{^enclosedalphanumerics}', "");
Expect(1, 9471, '\p{	Enclosed_Alphanumerics}', "");
Expect(0, 9471, '\p{^	Enclosed_Alphanumerics}', "");
Expect(0, 9471, '\P{	Enclosed_Alphanumerics}', "");
Expect(1, 9471, '\P{^	Enclosed_Alphanumerics}', "");
Expect(0, 9472, '\p{	Enclosed_Alphanumerics}', "");
Expect(1, 9472, '\p{^	Enclosed_Alphanumerics}', "");
Expect(1, 9472, '\P{	Enclosed_Alphanumerics}', "");
Expect(0, 9472, '\P{^	Enclosed_Alphanumerics}', "");
Error('\p{/a/-_Is_enclosed_alphanumerics}');
Error('\P{/a/-_Is_enclosed_alphanumerics}');
Expect(1, 9471, '\p{isenclosedalphanumerics}', "");
Expect(0, 9471, '\p{^isenclosedalphanumerics}', "");
Expect(0, 9471, '\P{isenclosedalphanumerics}', "");
Expect(1, 9471, '\P{^isenclosedalphanumerics}', "");
Expect(0, 9472, '\p{isenclosedalphanumerics}', "");
Expect(1, 9472, '\p{^isenclosedalphanumerics}', "");
Expect(1, 9472, '\P{isenclosedalphanumerics}', "");
Expect(0, 9472, '\P{^isenclosedalphanumerics}', "");
Expect(1, 9471, '\p{_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(0, 9471, '\p{^_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(0, 9471, '\P{_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(1, 9471, '\P{^_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(0, 9472, '\p{_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(1, 9472, '\p{^_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(1, 9472, '\P{_-Is_ENCLOSED_ALPHANUMERICS}', "");
Expect(0, 9472, '\P{^_-Is_ENCLOSED_ALPHANUMERICS}', "");
Error('\p{:=-_In_Enclosed_Alphanumerics}');
Error('\P{:=-_In_Enclosed_Alphanumerics}');
Expect(1, 9471, '\p{inenclosedalphanumerics}', "");
Expect(0, 9471, '\p{^inenclosedalphanumerics}', "");
Expect(0, 9471, '\P{inenclosedalphanumerics}', "");
Expect(1, 9471, '\P{^inenclosedalphanumerics}', "");
Expect(0, 9472, '\p{inenclosedalphanumerics}', "");
Expect(1, 9472, '\p{^inenclosedalphanumerics}', "");
Expect(1, 9472, '\P{inenclosedalphanumerics}', "");
Expect(0, 9472, '\P{^inenclosedalphanumerics}', "");
Expect(1, 9471, '\p{_in_ENCLOSED_alphanumerics}', "");
Expect(0, 9471, '\p{^_in_ENCLOSED_alphanumerics}', "");
Expect(0, 9471, '\P{_in_ENCLOSED_alphanumerics}', "");
Expect(1, 9471, '\P{^_in_ENCLOSED_alphanumerics}', "");
Expect(0, 9472, '\p{_in_ENCLOSED_alphanumerics}', "");
Expect(1, 9472, '\p{^_in_ENCLOSED_alphanumerics}', "");
Expect(1, 9472, '\P{_in_ENCLOSED_alphanumerics}', "");
Expect(0, 9472, '\P{^_in_ENCLOSED_alphanumerics}', "");
Error('\p{:=--ENCLOSED_alphanum}');
Error('\P{:=--ENCLOSED_alphanum}');
Expect(1, 9471, '\p{enclosedalphanum}', "");
Expect(0, 9471, '\p{^enclosedalphanum}', "");
Expect(0, 9471, '\P{enclosedalphanum}', "");
Expect(1, 9471, '\P{^enclosedalphanum}', "");
Expect(0, 9472, '\p{enclosedalphanum}', "");
Expect(1, 9472, '\p{^enclosedalphanum}', "");
Expect(1, 9472, '\P{enclosedalphanum}', "");
Expect(0, 9472, '\P{^enclosedalphanum}', "");
Expect(1, 9471, '\p{	-ENCLOSED_Alphanum}', "");
Expect(0, 9471, '\p{^	-ENCLOSED_Alphanum}', "");
Expect(0, 9471, '\P{	-ENCLOSED_Alphanum}', "");
Expect(1, 9471, '\P{^	-ENCLOSED_Alphanum}', "");
Expect(0, 9472, '\p{	-ENCLOSED_Alphanum}', "");
Expect(1, 9472, '\p{^	-ENCLOSED_Alphanum}', "");
Expect(1, 9472, '\P{	-ENCLOSED_Alphanum}', "");
Expect(0, 9472, '\P{^	-ENCLOSED_Alphanum}', "");
Error('\p{_	Is_ENCLOSED_alphanum/a/}');
Error('\P{_	Is_ENCLOSED_alphanum/a/}');
Expect(1, 9471, '\p{isenclosedalphanum}', "");
Expect(0, 9471, '\p{^isenclosedalphanum}', "");
Expect(0, 9471, '\P{isenclosedalphanum}', "");
Expect(1, 9471, '\P{^isenclosedalphanum}', "");
Expect(0, 9472, '\p{isenclosedalphanum}', "");
Expect(1, 9472, '\p{^isenclosedalphanum}', "");
Expect(1, 9472, '\P{isenclosedalphanum}', "");
Expect(0, 9472, '\P{^isenclosedalphanum}', "");
Expect(1, 9471, '\p{-	IS_enclosed_ALPHANUM}', "");
Expect(0, 9471, '\p{^-	IS_enclosed_ALPHANUM}', "");
Expect(0, 9471, '\P{-	IS_enclosed_ALPHANUM}', "");
Expect(1, 9471, '\P{^-	IS_enclosed_ALPHANUM}', "");
Expect(0, 9472, '\p{-	IS_enclosed_ALPHANUM}', "");
Expect(1, 9472, '\p{^-	IS_enclosed_ALPHANUM}', "");
Expect(1, 9472, '\P{-	IS_enclosed_ALPHANUM}', "");
Expect(0, 9472, '\P{^-	IS_enclosed_ALPHANUM}', "");
Error('\p{_in_Enclosed_alphanum:=}');
Error('\P{_in_Enclosed_alphanum:=}');
Expect(1, 9471, '\p{inenclosedalphanum}', "");
Expect(0, 9471, '\p{^inenclosedalphanum}', "");
Expect(0, 9471, '\P{inenclosedalphanum}', "");
Expect(1, 9471, '\P{^inenclosedalphanum}', "");
Expect(0, 9472, '\p{inenclosedalphanum}', "");
Expect(1, 9472, '\p{^inenclosedalphanum}', "");
Expect(1, 9472, '\P{inenclosedalphanum}', "");
Expect(0, 9472, '\P{^inenclosedalphanum}', "");
Expect(1, 9471, '\p{_ IN_Enclosed_alphanum}', "");
Expect(0, 9471, '\p{^_ IN_Enclosed_alphanum}', "");
Expect(0, 9471, '\P{_ IN_Enclosed_alphanum}', "");
Expect(1, 9471, '\P{^_ IN_Enclosed_alphanum}', "");
Expect(0, 9472, '\p{_ IN_Enclosed_alphanum}', "");
Expect(1, 9472, '\p{^_ IN_Enclosed_alphanum}', "");
Expect(1, 9472, '\P{_ IN_Enclosed_alphanum}', "");
Expect(0, 9472, '\P{^_ IN_Enclosed_alphanum}', "");
Error('\p{_	enclosed_CJK_LETTERS_and_MONTHS:=}');
Error('\P{_	enclosed_CJK_LETTERS_and_MONTHS:=}');
Expect(1, 13055, '\p{enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^enclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^enclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{enclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^enclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{_enclosed_CJK_letters_And_months}', "");
Expect(0, 13055, '\p{^_enclosed_CJK_letters_And_months}', "");
Expect(0, 13055, '\P{_enclosed_CJK_letters_And_months}', "");
Expect(1, 13055, '\P{^_enclosed_CJK_letters_And_months}', "");
Expect(0, 13056, '\p{_enclosed_CJK_letters_And_months}', "");
Expect(1, 13056, '\p{^_enclosed_CJK_letters_And_months}', "");
Expect(1, 13056, '\P{_enclosed_CJK_letters_And_months}', "");
Expect(0, 13056, '\P{^_enclosed_CJK_letters_And_months}', "");
Error('\p{-:=IS_Enclosed_CJK_Letters_AND_Months}');
Error('\P{-:=IS_Enclosed_CJK_Letters_AND_Months}');
Expect(1, 13055, '\p{isenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^isenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{isenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^isenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{isenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^isenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{isenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^isenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(0, 13055, '\p{^		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(0, 13055, '\P{		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(1, 13055, '\P{^		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(0, 13056, '\p{		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(1, 13056, '\p{^		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(1, 13056, '\P{		IS_ENCLOSED_cjk_letters_And_months}', "");
Expect(0, 13056, '\P{^		IS_ENCLOSED_cjk_letters_And_months}', "");
Error('\p{ :=In_ENCLOSED_CJK_letters_And_MONTHS}');
Error('\P{ :=In_ENCLOSED_CJK_letters_And_MONTHS}');
Expect(1, 13055, '\p{inenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\p{^inenclosedcjklettersandmonths}', "");
Expect(0, 13055, '\P{inenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\P{^inenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\p{inenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\p{^inenclosedcjklettersandmonths}', "");
Expect(1, 13056, '\P{inenclosedcjklettersandmonths}', "");
Expect(0, 13056, '\P{^inenclosedcjklettersandmonths}', "");
Expect(1, 13055, '\p{ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(0, 13055, '\p{^ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(0, 13055, '\P{ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(1, 13055, '\P{^ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(0, 13056, '\p{ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(1, 13056, '\p{^ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(1, 13056, '\P{ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Expect(0, 13056, '\P{^ -In_enclosed_CJK_Letters_And_MONTHS}', "");
Error('\p{:=-ENCLOSED_cjk}');
Error('\P{:=-ENCLOSED_cjk}');
Expect(1, 13055, '\p{enclosedcjk}', "");
Expect(0, 13055, '\p{^enclosedcjk}', "");
Expect(0, 13055, '\P{enclosedcjk}', "");
Expect(1, 13055, '\P{^enclosedcjk}', "");
Expect(0, 13056, '\p{enclosedcjk}', "");
Expect(1, 13056, '\p{^enclosedcjk}', "");
Expect(1, 13056, '\P{enclosedcjk}', "");
Expect(0, 13056, '\P{^enclosedcjk}', "");
Expect(1, 13055, '\p{ 	enclosed_CJK}', "");
Expect(0, 13055, '\p{^ 	enclosed_CJK}', "");
Expect(0, 13055, '\P{ 	enclosed_CJK}', "");
Expect(1, 13055, '\P{^ 	enclosed_CJK}', "");
Expect(0, 13056, '\p{ 	enclosed_CJK}', "");
Expect(1, 13056, '\p{^ 	enclosed_CJK}', "");
Expect(1, 13056, '\P{ 	enclosed_CJK}', "");
Expect(0, 13056, '\P{^ 	enclosed_CJK}', "");
Error('\p{/a/is_Enclosed_CJK}');
Error('\P{/a/is_Enclosed_CJK}');
Expect(1, 13055, '\p{isenclosedcjk}', "");
Expect(0, 13055, '\p{^isenclosedcjk}', "");
Expect(0, 13055, '\P{isenclosedcjk}', "");
Expect(1, 13055, '\P{^isenclosedcjk}', "");
Expect(0, 13056, '\p{isenclosedcjk}', "");
Expect(1, 13056, '\p{^isenclosedcjk}', "");
Expect(1, 13056, '\P{isenclosedcjk}', "");
Expect(0, 13056, '\P{^isenclosedcjk}', "");
Expect(1, 13055, '\p{	is_Enclosed_cjk}', "");
Expect(0, 13055, '\p{^	is_Enclosed_cjk}', "");
Expect(0, 13055, '\P{	is_Enclosed_cjk}', "");
Expect(1, 13055, '\P{^	is_Enclosed_cjk}', "");
Expect(0, 13056, '\p{	is_Enclosed_cjk}', "");
Expect(1, 13056, '\p{^	is_Enclosed_cjk}', "");
Expect(1, 13056, '\P{	is_Enclosed_cjk}', "");
Expect(0, 13056, '\P{^	is_Enclosed_cjk}', "");
Error('\p{:=_-In_Enclosed_CJK}');
Error('\P{:=_-In_Enclosed_CJK}');
Expect(1, 13055, '\p{inenclosedcjk}', "");
Expect(0, 13055, '\p{^inenclosedcjk}', "");
Expect(0, 13055, '\P{inenclosedcjk}', "");
Expect(1, 13055, '\P{^inenclosedcjk}', "");
Expect(0, 13056, '\p{inenclosedcjk}', "");
Expect(1, 13056, '\p{^inenclosedcjk}', "");
Expect(1, 13056, '\P{inenclosedcjk}', "");
Expect(0, 13056, '\P{^inenclosedcjk}', "");
Expect(1, 13055, '\p{	-In_ENCLOSED_CJK}', "");
Expect(0, 13055, '\p{^	-In_ENCLOSED_CJK}', "");
Expect(0, 13055, '\P{	-In_ENCLOSED_CJK}', "");
Expect(1, 13055, '\P{^	-In_ENCLOSED_CJK}', "");
Expect(0, 13056, '\p{	-In_ENCLOSED_CJK}', "");
Expect(1, 13056, '\p{^	-In_ENCLOSED_CJK}', "");
Expect(1, 13056, '\P{	-In_ENCLOSED_CJK}', "");
Expect(0, 13056, '\P{^	-In_ENCLOSED_CJK}', "");
Error('\p{/a/	 ENCLOSED_ideographic_supplement}');
Error('\P{/a/	 ENCLOSED_ideographic_supplement}');
Expect(1, 127743, '\p{enclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^enclosedideographicsupplement}', "");
Expect(0, 127743, '\P{enclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^enclosedideographicsupplement}', "");
Expect(0, 127744, '\p{enclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^enclosedideographicsupplement}', "");
Expect(1, 127744, '\P{enclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^enclosedideographicsupplement}', "");
Expect(1, 127743, '\p{-_Enclosed_ideographic_supplement}', "");
Expect(0, 127743, '\p{^-_Enclosed_ideographic_supplement}', "");
Expect(0, 127743, '\P{-_Enclosed_ideographic_supplement}', "");
Expect(1, 127743, '\P{^-_Enclosed_ideographic_supplement}', "");
Expect(0, 127744, '\p{-_Enclosed_ideographic_supplement}', "");
Expect(1, 127744, '\p{^-_Enclosed_ideographic_supplement}', "");
Expect(1, 127744, '\P{-_Enclosed_ideographic_supplement}', "");
Expect(0, 127744, '\P{^-_Enclosed_ideographic_supplement}', "");
Error('\p{ :=Is_enclosed_Ideographic_SUPPLEMENT}');
Error('\P{ :=Is_enclosed_Ideographic_SUPPLEMENT}');
Expect(1, 127743, '\p{isenclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^isenclosedideographicsupplement}', "");
Expect(0, 127743, '\P{isenclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^isenclosedideographicsupplement}', "");
Expect(0, 127744, '\p{isenclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^isenclosedideographicsupplement}', "");
Expect(1, 127744, '\P{isenclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^isenclosedideographicsupplement}', "");
Expect(1, 127743, '\p{	_is_enclosed_Ideographic_Supplement}', "");
Expect(0, 127743, '\p{^	_is_enclosed_Ideographic_Supplement}', "");
Expect(0, 127743, '\P{	_is_enclosed_Ideographic_Supplement}', "");
Expect(1, 127743, '\P{^	_is_enclosed_Ideographic_Supplement}', "");
Expect(0, 127744, '\p{	_is_enclosed_Ideographic_Supplement}', "");
Expect(1, 127744, '\p{^	_is_enclosed_Ideographic_Supplement}', "");
Expect(1, 127744, '\P{	_is_enclosed_Ideographic_Supplement}', "");
Expect(0, 127744, '\P{^	_is_enclosed_Ideographic_Supplement}', "");
Error('\p{:=		in_ENCLOSED_ideographic_Supplement}');
Error('\P{:=		in_ENCLOSED_ideographic_Supplement}');
Expect(1, 127743, '\p{inenclosedideographicsupplement}', "");
Expect(0, 127743, '\p{^inenclosedideographicsupplement}', "");
Expect(0, 127743, '\P{inenclosedideographicsupplement}', "");
Expect(1, 127743, '\P{^inenclosedideographicsupplement}', "");
Expect(0, 127744, '\p{inenclosedideographicsupplement}', "");
Expect(1, 127744, '\p{^inenclosedideographicsupplement}', "");
Expect(1, 127744, '\P{inenclosedideographicsupplement}', "");
Expect(0, 127744, '\P{^inenclosedideographicsupplement}', "");
Expect(1, 127743, '\p{	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(0, 127743, '\p{^	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(0, 127743, '\P{	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(1, 127743, '\P{^	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(0, 127744, '\p{	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(1, 127744, '\p{^	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(1, 127744, '\P{	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Expect(0, 127744, '\P{^	In_Enclosed_IDEOGRAPHIC_Supplement}', "");
Error('\p{:=_	Enclosed_Ideographic_sup}');
Error('\P{:=_	Enclosed_Ideographic_sup}');
Expect(1, 127743, '\p{enclosedideographicsup}', "");
Expect(0, 127743, '\p{^enclosedideographicsup}', "");
Expect(0, 127743, '\P{enclosedideographicsup}', "");
Expect(1, 127743, '\P{^enclosedideographicsup}', "");
Expect(0, 127744, '\p{enclosedideographicsup}', "");
Expect(1, 127744, '\p{^enclosedideographicsup}', "");
Expect(1, 127744, '\P{enclosedideographicsup}', "");
Expect(0, 127744, '\P{^enclosedideographicsup}', "");
Expect(1, 127743, '\p{	-enclosed_Ideographic_SUP}', "");
Expect(0, 127743, '\p{^	-enclosed_Ideographic_SUP}', "");
Expect(0, 127743, '\P{	-enclosed_Ideographic_SUP}', "");
Expect(1, 127743, '\P{^	-enclosed_Ideographic_SUP}', "");
Expect(0, 127744, '\p{	-enclosed_Ideographic_SUP}', "");
Expect(1, 127744, '\p{^	-enclosed_Ideographic_SUP}', "");
Expect(1, 127744, '\P{	-enclosed_Ideographic_SUP}', "");
Expect(0, 127744, '\P{^	-enclosed_Ideographic_SUP}', "");
Error('\p{	 Is_ENCLOSED_Ideographic_Sup/a/}');
Error('\P{	 Is_ENCLOSED_Ideographic_Sup/a/}');
Expect(1, 127743, '\p{isenclosedideographicsup}', "");
Expect(0, 127743, '\p{^isenclosedideographicsup}', "");
Expect(0, 127743, '\P{isenclosedideographicsup}', "");
Expect(1, 127743, '\P{^isenclosedideographicsup}', "");
Expect(0, 127744, '\p{isenclosedideographicsup}', "");
Expect(1, 127744, '\p{^isenclosedideographicsup}', "");
Expect(1, 127744, '\P{isenclosedideographicsup}', "");
Expect(0, 127744, '\P{^isenclosedideographicsup}', "");
Expect(1, 127743, '\p{-IS_enclosed_ideographic_SUP}', "");
Expect(0, 127743, '\p{^-IS_enclosed_ideographic_SUP}', "");
Expect(0, 127743, '\P{-IS_enclosed_ideographic_SUP}', "");
Expect(1, 127743, '\P{^-IS_enclosed_ideographic_SUP}', "");
Expect(0, 127744, '\p{-IS_enclosed_ideographic_SUP}', "");
Expect(1, 127744, '\p{^-IS_enclosed_ideographic_SUP}', "");
Expect(1, 127744, '\P{-IS_enclosed_ideographic_SUP}', "");
Expect(0, 127744, '\P{^-IS_enclosed_ideographic_SUP}', "");
Error('\p{_:=In_Enclosed_IDEOGRAPHIC_Sup}');
Error('\P{_:=In_Enclosed_IDEOGRAPHIC_Sup}');
Expect(1, 127743, '\p{inenclosedideographicsup}', "");
Expect(0, 127743, '\p{^inenclosedideographicsup}', "");
Expect(0, 127743, '\P{inenclosedideographicsup}', "");
Expect(1, 127743, '\P{^inenclosedideographicsup}', "");
Expect(0, 127744, '\p{inenclosedideographicsup}', "");
Expect(1, 127744, '\p{^inenclosedideographicsup}', "");
Expect(1, 127744, '\P{inenclosedideographicsup}', "");
Expect(0, 127744, '\P{^inenclosedideographicsup}', "");
Expect(1, 127743, '\p{	IN_Enclosed_ideographic_Sup}', "");
Expect(0, 127743, '\p{^	IN_Enclosed_ideographic_Sup}', "");
Expect(0, 127743, '\P{	IN_Enclosed_ideographic_Sup}', "");
Expect(1, 127743, '\P{^	IN_Enclosed_ideographic_Sup}', "");
Expect(0, 127744, '\p{	IN_Enclosed_ideographic_Sup}', "");
Expect(1, 127744, '\p{^	IN_Enclosed_ideographic_Sup}', "");
Expect(1, 127744, '\P{	IN_Enclosed_ideographic_Sup}', "");
Expect(0, 127744, '\P{^	IN_Enclosed_ideographic_Sup}', "");
Error('\p{-	Enclosing_mark/a/}');
Error('\P{-	Enclosing_mark/a/}');
Expect(1, 42610, '\p{enclosingmark}', "");
Expect(0, 42610, '\p{^enclosingmark}', "");
Expect(0, 42610, '\P{enclosingmark}', "");
Expect(1, 42610, '\P{^enclosingmark}', "");
Expect(0, 42611, '\p{enclosingmark}', "");
Expect(1, 42611, '\p{^enclosingmark}', "");
Expect(1, 42611, '\P{enclosingmark}', "");
Expect(0, 42611, '\P{^enclosingmark}', "");
Expect(1, 42610, '\p{	ENCLOSING_MARK}', "");
Expect(0, 42610, '\p{^	ENCLOSING_MARK}', "");
Expect(0, 42610, '\P{	ENCLOSING_MARK}', "");
Expect(1, 42610, '\P{^	ENCLOSING_MARK}', "");
Expect(0, 42611, '\p{	ENCLOSING_MARK}', "");
Expect(1, 42611, '\p{^	ENCLOSING_MARK}', "");
Expect(1, 42611, '\P{	ENCLOSING_MARK}', "");
Expect(0, 42611, '\P{^	ENCLOSING_MARK}', "");
Error('\p{ /a/IS_Enclosing_MARK}');
Error('\P{ /a/IS_Enclosing_MARK}');
Expect(1, 42610, '\p{isenclosingmark}', "");
Expect(0, 42610, '\p{^isenclosingmark}', "");
Expect(0, 42610, '\P{isenclosingmark}', "");
Expect(1, 42610, '\P{^isenclosingmark}', "");
Expect(0, 42611, '\p{isenclosingmark}', "");
Expect(1, 42611, '\p{^isenclosingmark}', "");
Expect(1, 42611, '\P{isenclosingmark}', "");
Expect(0, 42611, '\P{^isenclosingmark}', "");
Expect(1, 42610, '\p{ Is_Enclosing_mark}', "");
Expect(0, 42610, '\p{^ Is_Enclosing_mark}', "");
Expect(0, 42610, '\P{ Is_Enclosing_mark}', "");
Expect(1, 42610, '\P{^ Is_Enclosing_mark}', "");
Expect(0, 42611, '\p{ Is_Enclosing_mark}', "");
Expect(1, 42611, '\p{^ Is_Enclosing_mark}', "");
Expect(1, 42611, '\P{ Is_Enclosing_mark}', "");
Expect(0, 42611, '\P{^ Is_Enclosing_mark}', "");
Error('\p{	:=Me}');
Error('\P{	:=Me}');
Expect(1, 42610, '\p{me}', "");
Expect(0, 42610, '\p{^me}', "");
Expect(0, 42610, '\P{me}', "");
Expect(1, 42610, '\P{^me}', "");
Expect(0, 42611, '\p{me}', "");
Expect(1, 42611, '\p{^me}', "");
Expect(1, 42611, '\P{me}', "");
Expect(0, 42611, '\P{^me}', "");
Expect(1, 42610, '\p{-Me}', "");
Expect(0, 42610, '\p{^-Me}', "");
Expect(0, 42610, '\P{-Me}', "");
Expect(1, 42610, '\P{^-Me}', "");
Expect(0, 42611, '\p{-Me}', "");
Expect(1, 42611, '\p{^-Me}', "");
Expect(1, 42611, '\P{-Me}', "");
Expect(0, 42611, '\P{^-Me}', "");
Error('\p{/a/-	IS_Me}');
Error('\P{/a/-	IS_Me}');
Expect(1, 42610, '\p{isme}', "");
Expect(0, 42610, '\p{^isme}', "");
Expect(0, 42610, '\P{isme}', "");
Expect(1, 42610, '\P{^isme}', "");
Expect(0, 42611, '\p{isme}', "");
Expect(1, 42611, '\p{^isme}', "");
Expect(1, 42611, '\P{isme}', "");
Expect(0, 42611, '\P{^isme}', "");
Expect(1, 42610, '\p{ -Is_Me}', "");
Expect(0, 42610, '\p{^ -Is_Me}', "");
Expect(0, 42610, '\P{ -Is_Me}', "");
Expect(1, 42610, '\P{^ -Is_Me}', "");
Expect(0, 42611, '\p{ -Is_Me}', "");
Expect(1, 42611, '\p{^ -Is_Me}', "");
Expect(1, 42611, '\P{ -Is_Me}', "");
Expect(0, 42611, '\P{^ -Is_Me}', "");
Error('\p{-ETHIOPIC/a/}');
Error('\P{-ETHIOPIC/a/}');
Expect(1, 43822, '\p{ethiopic}', "");
Expect(0, 43822, '\p{^ethiopic}', "");
Expect(0, 43822, '\P{ethiopic}', "");
Expect(1, 43822, '\P{^ethiopic}', "");
Expect(0, 43823, '\p{ethiopic}', "");
Expect(1, 43823, '\p{^ethiopic}', "");
Expect(1, 43823, '\P{ethiopic}', "");
Expect(0, 43823, '\P{^ethiopic}', "");
Expect(1, 43822, '\p{_Ethiopic}', "");
Expect(0, 43822, '\p{^_Ethiopic}', "");
Expect(0, 43822, '\P{_Ethiopic}', "");
Expect(1, 43822, '\P{^_Ethiopic}', "");
Expect(0, 43823, '\p{_Ethiopic}', "");
Expect(1, 43823, '\p{^_Ethiopic}', "");
Expect(1, 43823, '\P{_Ethiopic}', "");
Expect(0, 43823, '\P{^_Ethiopic}', "");
Error('\p{Is_ethiopic/a/}');
Error('\P{Is_ethiopic/a/}');
Expect(1, 43822, '\p{isethiopic}', "");
Expect(0, 43822, '\p{^isethiopic}', "");
Expect(0, 43822, '\P{isethiopic}', "");
Expect(1, 43822, '\P{^isethiopic}', "");
Expect(0, 43823, '\p{isethiopic}', "");
Expect(1, 43823, '\p{^isethiopic}', "");
Expect(1, 43823, '\P{isethiopic}', "");
Expect(0, 43823, '\P{^isethiopic}', "");
Expect(1, 43822, '\p{	is_ETHIOPIC}', "");
Expect(0, 43822, '\p{^	is_ETHIOPIC}', "");
Expect(0, 43822, '\P{	is_ETHIOPIC}', "");
Expect(1, 43822, '\P{^	is_ETHIOPIC}', "");
Expect(0, 43823, '\p{	is_ETHIOPIC}', "");
Expect(1, 43823, '\p{^	is_ETHIOPIC}', "");
Expect(1, 43823, '\P{	is_ETHIOPIC}', "");
Expect(0, 43823, '\P{^	is_ETHIOPIC}', "");
Error('\p{/a/ ETHI}');
Error('\P{/a/ ETHI}');
Expect(1, 43822, '\p{ethi}', "");
Expect(0, 43822, '\p{^ethi}', "");
Expect(0, 43822, '\P{ethi}', "");
Expect(1, 43822, '\P{^ethi}', "");
Expect(0, 43823, '\p{ethi}', "");
Expect(1, 43823, '\p{^ethi}', "");
Expect(1, 43823, '\P{ethi}', "");
Expect(0, 43823, '\P{^ethi}', "");
Expect(1, 43822, '\p{ Ethi}', "");
Expect(0, 43822, '\p{^ Ethi}', "");
Expect(0, 43822, '\P{ Ethi}', "");
Expect(1, 43822, '\P{^ Ethi}', "");
Expect(0, 43823, '\p{ Ethi}', "");
Expect(1, 43823, '\p{^ Ethi}', "");
Expect(1, 43823, '\P{ Ethi}', "");
Expect(0, 43823, '\P{^ Ethi}', "");
Error('\p{_	is_Ethi/a/}');
Error('\P{_	is_Ethi/a/}');
Expect(1, 43822, '\p{isethi}', "");
Expect(0, 43822, '\p{^isethi}', "");
Expect(0, 43822, '\P{isethi}', "");
Expect(1, 43822, '\P{^isethi}', "");
Expect(0, 43823, '\p{isethi}', "");
Expect(1, 43823, '\p{^isethi}', "");
Expect(1, 43823, '\P{isethi}', "");
Expect(0, 43823, '\P{^isethi}', "");
Expect(1, 43822, '\p{ -IS_ethi}', "");
Expect(0, 43822, '\p{^ -IS_ethi}', "");
Expect(0, 43822, '\P{ -IS_ethi}', "");
Expect(1, 43822, '\P{^ -IS_ethi}', "");
Expect(0, 43823, '\p{ -IS_ethi}', "");
Expect(1, 43823, '\p{^ -IS_ethi}', "");
Expect(1, 43823, '\P{ -IS_ethi}', "");
Expect(0, 43823, '\P{^ -IS_ethi}', "");
Error('\p{	/a/Ethiopic_Extended}');
Error('\P{	/a/Ethiopic_Extended}');
Expect(1, 11743, '\p{ethiopicextended}', "");
Expect(0, 11743, '\p{^ethiopicextended}', "");
Expect(0, 11743, '\P{ethiopicextended}', "");
Expect(1, 11743, '\P{^ethiopicextended}', "");
Expect(0, 11744, '\p{ethiopicextended}', "");
Expect(1, 11744, '\p{^ethiopicextended}', "");
Expect(1, 11744, '\P{ethiopicextended}', "");
Expect(0, 11744, '\P{^ethiopicextended}', "");
Expect(1, 11743, '\p{ _ETHIOPIC_Extended}', "");
Expect(0, 11743, '\p{^ _ETHIOPIC_Extended}', "");
Expect(0, 11743, '\P{ _ETHIOPIC_Extended}', "");
Expect(1, 11743, '\P{^ _ETHIOPIC_Extended}', "");
Expect(0, 11744, '\p{ _ETHIOPIC_Extended}', "");
Expect(1, 11744, '\p{^ _ETHIOPIC_Extended}', "");
Expect(1, 11744, '\P{ _ETHIOPIC_Extended}', "");
Expect(0, 11744, '\P{^ _ETHIOPIC_Extended}', "");
Error('\p{-Is_ethiopic_EXTENDED:=}');
Error('\P{-Is_ethiopic_EXTENDED:=}');
Expect(1, 11743, '\p{isethiopicextended}', "");
Expect(0, 11743, '\p{^isethiopicextended}', "");
Expect(0, 11743, '\P{isethiopicextended}', "");
Expect(1, 11743, '\P{^isethiopicextended}', "");
Expect(0, 11744, '\p{isethiopicextended}', "");
Expect(1, 11744, '\p{^isethiopicextended}', "");
Expect(1, 11744, '\P{isethiopicextended}', "");
Expect(0, 11744, '\P{^isethiopicextended}', "");
Expect(1, 11743, '\p{  Is_ETHIOPIC_Extended}', "");
Expect(0, 11743, '\p{^  Is_ETHIOPIC_Extended}', "");
Expect(0, 11743, '\P{  Is_ETHIOPIC_Extended}', "");
Expect(1, 11743, '\P{^  Is_ETHIOPIC_Extended}', "");
Expect(0, 11744, '\p{  Is_ETHIOPIC_Extended}', "");
Expect(1, 11744, '\p{^  Is_ETHIOPIC_Extended}', "");
Expect(1, 11744, '\P{  Is_ETHIOPIC_Extended}', "");
Expect(0, 11744, '\P{^  Is_ETHIOPIC_Extended}', "");
Error('\p{:= _IN_Ethiopic_Extended}');
Error('\P{:= _IN_Ethiopic_Extended}');
Expect(1, 11743, '\p{inethiopicextended}', "");
Expect(0, 11743, '\p{^inethiopicextended}', "");
Expect(0, 11743, '\P{inethiopicextended}', "");
Expect(1, 11743, '\P{^inethiopicextended}', "");
Expect(0, 11744, '\p{inethiopicextended}', "");
Expect(1, 11744, '\p{^inethiopicextended}', "");
Expect(1, 11744, '\P{inethiopicextended}', "");
Expect(0, 11744, '\P{^inethiopicextended}', "");
Expect(1, 11743, '\p{_in_ethiopic_extended}', "");
Expect(0, 11743, '\p{^_in_ethiopic_extended}', "");
Expect(0, 11743, '\P{_in_ethiopic_extended}', "");
Expect(1, 11743, '\P{^_in_ethiopic_extended}', "");
Expect(0, 11744, '\p{_in_ethiopic_extended}', "");
Expect(1, 11744, '\p{^_in_ethiopic_extended}', "");
Expect(1, 11744, '\P{_in_ethiopic_extended}', "");
Expect(0, 11744, '\P{^_in_ethiopic_extended}', "");
Error('\p{/a/-	Ethiopic_EXT}');
Error('\P{/a/-	Ethiopic_EXT}');
Expect(1, 11743, '\p{ethiopicext}', "");
Expect(0, 11743, '\p{^ethiopicext}', "");
Expect(0, 11743, '\P{ethiopicext}', "");
Expect(1, 11743, '\P{^ethiopicext}', "");
Expect(0, 11744, '\p{ethiopicext}', "");
Expect(1, 11744, '\p{^ethiopicext}', "");
Expect(1, 11744, '\P{ethiopicext}', "");
Expect(0, 11744, '\P{^ethiopicext}', "");
Expect(1, 11743, '\p{--Ethiopic_Ext}', "");
Expect(0, 11743, '\p{^--Ethiopic_Ext}', "");
Expect(0, 11743, '\P{--Ethiopic_Ext}', "");
Expect(1, 11743, '\P{^--Ethiopic_Ext}', "");
Expect(0, 11744, '\p{--Ethiopic_Ext}', "");
Expect(1, 11744, '\p{^--Ethiopic_Ext}', "");
Expect(1, 11744, '\P{--Ethiopic_Ext}', "");
Expect(0, 11744, '\P{^--Ethiopic_Ext}', "");
Error('\p{-:=Is_Ethiopic_Ext}');
Error('\P{-:=Is_Ethiopic_Ext}');
Expect(1, 11743, '\p{isethiopicext}', "");
Expect(0, 11743, '\p{^isethiopicext}', "");
Expect(0, 11743, '\P{isethiopicext}', "");
Expect(1, 11743, '\P{^isethiopicext}', "");
Expect(0, 11744, '\p{isethiopicext}', "");
Expect(1, 11744, '\p{^isethiopicext}', "");
Expect(1, 11744, '\P{isethiopicext}', "");
Expect(0, 11744, '\P{^isethiopicext}', "");
Expect(1, 11743, '\p{  Is_Ethiopic_ext}', "");
Expect(0, 11743, '\p{^  Is_Ethiopic_ext}', "");
Expect(0, 11743, '\P{  Is_Ethiopic_ext}', "");
Expect(1, 11743, '\P{^  Is_Ethiopic_ext}', "");
Expect(0, 11744, '\p{  Is_Ethiopic_ext}', "");
Expect(1, 11744, '\p{^  Is_Ethiopic_ext}', "");
Expect(1, 11744, '\P{  Is_Ethiopic_ext}', "");
Expect(0, 11744, '\P{^  Is_Ethiopic_ext}', "");
Error('\p{:=In_Ethiopic_Ext}');
Error('\P{:=In_Ethiopic_Ext}');
Expect(1, 11743, '\p{inethiopicext}', "");
Expect(0, 11743, '\p{^inethiopicext}', "");
Expect(0, 11743, '\P{inethiopicext}', "");
Expect(1, 11743, '\P{^inethiopicext}', "");
Expect(0, 11744, '\p{inethiopicext}', "");
Expect(1, 11744, '\p{^inethiopicext}', "");
Expect(1, 11744, '\P{inethiopicext}', "");
Expect(0, 11744, '\P{^inethiopicext}', "");
Expect(1, 11743, '\p{_In_Ethiopic_Ext}', "");
Expect(0, 11743, '\p{^_In_Ethiopic_Ext}', "");
Expect(0, 11743, '\P{_In_Ethiopic_Ext}', "");
Expect(1, 11743, '\P{^_In_Ethiopic_Ext}', "");
Expect(0, 11744, '\p{_In_Ethiopic_Ext}', "");
Expect(1, 11744, '\p{^_In_Ethiopic_Ext}', "");
Expect(1, 11744, '\P{_In_Ethiopic_Ext}', "");
Expect(0, 11744, '\P{^_In_Ethiopic_Ext}', "");
Error('\p{_:=ETHIOPIC_Extended_A}');
Error('\P{_:=ETHIOPIC_Extended_A}');
Expect(1, 43823, '\p{ethiopicextendeda}', "");
Expect(0, 43823, '\p{^ethiopicextendeda}', "");
Expect(0, 43823, '\P{ethiopicextendeda}', "");
Expect(1, 43823, '\P{^ethiopicextendeda}', "");
Expect(0, 43824, '\p{ethiopicextendeda}', "");
Expect(1, 43824, '\p{^ethiopicextendeda}', "");
Expect(1, 43824, '\P{ethiopicextendeda}', "");
Expect(0, 43824, '\P{^ethiopicextendeda}', "");
Expect(1, 43823, '\p{-ETHIOPIC_extended_A}', "");
Expect(0, 43823, '\p{^-ETHIOPIC_extended_A}', "");
Expect(0, 43823, '\P{-ETHIOPIC_extended_A}', "");
Expect(1, 43823, '\P{^-ETHIOPIC_extended_A}', "");
Expect(0, 43824, '\p{-ETHIOPIC_extended_A}', "");
Expect(1, 43824, '\p{^-ETHIOPIC_extended_A}', "");
Expect(1, 43824, '\P{-ETHIOPIC_extended_A}', "");
Expect(0, 43824, '\P{^-ETHIOPIC_extended_A}', "");
Error('\p{	Is_Ethiopic_Extended_A/a/}');
Error('\P{	Is_Ethiopic_Extended_A/a/}');
Expect(1, 43823, '\p{isethiopicextendeda}', "");
Expect(0, 43823, '\p{^isethiopicextendeda}', "");
Expect(0, 43823, '\P{isethiopicextendeda}', "");
Expect(1, 43823, '\P{^isethiopicextendeda}', "");
Expect(0, 43824, '\p{isethiopicextendeda}', "");
Expect(1, 43824, '\p{^isethiopicextendeda}', "");
Expect(1, 43824, '\P{isethiopicextendeda}', "");
Expect(0, 43824, '\P{^isethiopicextendeda}', "");
Expect(1, 43823, '\p{	 is_Ethiopic_Extended_a}', "");
Expect(0, 43823, '\p{^	 is_Ethiopic_Extended_a}', "");
Expect(0, 43823, '\P{	 is_Ethiopic_Extended_a}', "");
Expect(1, 43823, '\P{^	 is_Ethiopic_Extended_a}', "");
Expect(0, 43824, '\p{	 is_Ethiopic_Extended_a}', "");
Expect(1, 43824, '\p{^	 is_Ethiopic_Extended_a}', "");
Expect(1, 43824, '\P{	 is_Ethiopic_Extended_a}', "");
Expect(0, 43824, '\P{^	 is_Ethiopic_Extended_a}', "");
Error('\p{:=- In_Ethiopic_EXTENDED_A}');
Error('\P{:=- In_Ethiopic_EXTENDED_A}');
Expect(1, 43823, '\p{inethiopicextendeda}', "");
Expect(0, 43823, '\p{^inethiopicextendeda}', "");
Expect(0, 43823, '\P{inethiopicextendeda}', "");
Expect(1, 43823, '\P{^inethiopicextendeda}', "");
Expect(0, 43824, '\p{inethiopicextendeda}', "");
Expect(1, 43824, '\p{^inethiopicextendeda}', "");
Expect(1, 43824, '\P{inethiopicextendeda}', "");
Expect(0, 43824, '\P{^inethiopicextendeda}', "");
Expect(1, 43823, '\p{ 	In_Ethiopic_extended_A}', "");
Expect(0, 43823, '\p{^ 	In_Ethiopic_extended_A}', "");
Expect(0, 43823, '\P{ 	In_Ethiopic_extended_A}', "");
Expect(1, 43823, '\P{^ 	In_Ethiopic_extended_A}', "");
Expect(0, 43824, '\p{ 	In_Ethiopic_extended_A}', "");
Expect(1, 43824, '\p{^ 	In_Ethiopic_extended_A}', "");
Expect(1, 43824, '\P{ 	In_Ethiopic_extended_A}', "");
Expect(0, 43824, '\P{^ 	In_Ethiopic_extended_A}', "");
Error('\p{_-Ethiopic_ext_A:=}');
Error('\P{_-Ethiopic_ext_A:=}');
Expect(1, 43823, '\p{ethiopicexta}', "");
Expect(0, 43823, '\p{^ethiopicexta}', "");
Expect(0, 43823, '\P{ethiopicexta}', "");
Expect(1, 43823, '\P{^ethiopicexta}', "");
Expect(0, 43824, '\p{ethiopicexta}', "");
Expect(1, 43824, '\p{^ethiopicexta}', "");
Expect(1, 43824, '\P{ethiopicexta}', "");
Expect(0, 43824, '\P{^ethiopicexta}', "");
Expect(1, 43823, '\p{ Ethiopic_Ext_A}', "");
Expect(0, 43823, '\p{^ Ethiopic_Ext_A}', "");
Expect(0, 43823, '\P{ Ethiopic_Ext_A}', "");
Expect(1, 43823, '\P{^ Ethiopic_Ext_A}', "");
Expect(0, 43824, '\p{ Ethiopic_Ext_A}', "");
Expect(1, 43824, '\p{^ Ethiopic_Ext_A}', "");
Expect(1, 43824, '\P{ Ethiopic_Ext_A}', "");
Expect(0, 43824, '\P{^ Ethiopic_Ext_A}', "");
Error('\p{:= -is_Ethiopic_ext_A}');
Error('\P{:= -is_Ethiopic_ext_A}');
Expect(1, 43823, '\p{isethiopicexta}', "");
Expect(0, 43823, '\p{^isethiopicexta}', "");
Expect(0, 43823, '\P{isethiopicexta}', "");
Expect(1, 43823, '\P{^isethiopicexta}', "");
Expect(0, 43824, '\p{isethiopicexta}', "");
Expect(1, 43824, '\p{^isethiopicexta}', "");
Expect(1, 43824, '\P{isethiopicexta}', "");
Expect(0, 43824, '\P{^isethiopicexta}', "");
Expect(1, 43823, '\p{--Is_ETHIOPIC_EXT_A}', "");
Expect(0, 43823, '\p{^--Is_ETHIOPIC_EXT_A}', "");
Expect(0, 43823, '\P{--Is_ETHIOPIC_EXT_A}', "");
Expect(1, 43823, '\P{^--Is_ETHIOPIC_EXT_A}', "");
Expect(0, 43824, '\p{--Is_ETHIOPIC_EXT_A}', "");
Expect(1, 43824, '\p{^--Is_ETHIOPIC_EXT_A}', "");
Expect(1, 43824, '\P{--Is_ETHIOPIC_EXT_A}', "");
Expect(0, 43824, '\P{^--Is_ETHIOPIC_EXT_A}', "");
Error('\p{-/a/In_Ethiopic_ext_A}');
Error('\P{-/a/In_Ethiopic_ext_A}');
Expect(1, 43823, '\p{inethiopicexta}', "");
Expect(0, 43823, '\p{^inethiopicexta}', "");
Expect(0, 43823, '\P{inethiopicexta}', "");
Expect(1, 43823, '\P{^inethiopicexta}', "");
Expect(0, 43824, '\p{inethiopicexta}', "");
Expect(1, 43824, '\p{^inethiopicexta}', "");
Expect(1, 43824, '\P{inethiopicexta}', "");
Expect(0, 43824, '\P{^inethiopicexta}', "");
Expect(1, 43823, '\p{__In_Ethiopic_Ext_A}', "");
Expect(0, 43823, '\p{^__In_Ethiopic_Ext_A}', "");
Expect(0, 43823, '\P{__In_Ethiopic_Ext_A}', "");
Expect(1, 43823, '\P{^__In_Ethiopic_Ext_A}', "");
Expect(0, 43824, '\p{__In_Ethiopic_Ext_A}', "");
Expect(1, 43824, '\p{^__In_Ethiopic_Ext_A}', "");
Expect(1, 43824, '\P{__In_Ethiopic_Ext_A}', "");
Expect(0, 43824, '\P{^__In_Ethiopic_Ext_A}', "");
Error('\p{-Ethiopic_Supplement/a/}');
Error('\P{-Ethiopic_Supplement/a/}');
Expect(1, 5023, '\p{ethiopicsupplement}', "");
Expect(0, 5023, '\p{^ethiopicsupplement}', "");
Expect(0, 5023, '\P{ethiopicsupplement}', "");
Expect(1, 5023, '\P{^ethiopicsupplement}', "");
Expect(0, 5024, '\p{ethiopicsupplement}', "");
Expect(1, 5024, '\p{^ethiopicsupplement}', "");
Expect(1, 5024, '\P{ethiopicsupplement}', "");
Expect(0, 5024, '\P{^ethiopicsupplement}', "");
Expect(1, 5023, '\p{  Ethiopic_supplement}', "");
Expect(0, 5023, '\p{^  Ethiopic_supplement}', "");
Expect(0, 5023, '\P{  Ethiopic_supplement}', "");
Expect(1, 5023, '\P{^  Ethiopic_supplement}', "");
Expect(0, 5024, '\p{  Ethiopic_supplement}', "");
Expect(1, 5024, '\p{^  Ethiopic_supplement}', "");
Expect(1, 5024, '\P{  Ethiopic_supplement}', "");
Expect(0, 5024, '\P{^  Ethiopic_supplement}', "");
Error('\p{	-Is_Ethiopic_supplement:=}');
Error('\P{	-Is_Ethiopic_supplement:=}');
Expect(1, 5023, '\p{isethiopicsupplement}', "");
Expect(0, 5023, '\p{^isethiopicsupplement}', "");
Expect(0, 5023, '\P{isethiopicsupplement}', "");
Expect(1, 5023, '\P{^isethiopicsupplement}', "");
Expect(0, 5024, '\p{isethiopicsupplement}', "");
Expect(1, 5024, '\p{^isethiopicsupplement}', "");
Expect(1, 5024, '\P{isethiopicsupplement}', "");
Expect(0, 5024, '\P{^isethiopicsupplement}', "");
Expect(1, 5023, '\p{-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(0, 5023, '\p{^-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(0, 5023, '\P{-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(1, 5023, '\P{^-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(0, 5024, '\p{-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(1, 5024, '\p{^-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(1, 5024, '\P{-IS_ETHIOPIC_SUPPLEMENT}', "");
Expect(0, 5024, '\P{^-IS_ETHIOPIC_SUPPLEMENT}', "");
Error('\p{/a/In_ethiopic_supplement}');
Error('\P{/a/In_ethiopic_supplement}');
Expect(1, 5023, '\p{inethiopicsupplement}', "");
Expect(0, 5023, '\p{^inethiopicsupplement}', "");
Expect(0, 5023, '\P{inethiopicsupplement}', "");
Expect(1, 5023, '\P{^inethiopicsupplement}', "");
Expect(0, 5024, '\p{inethiopicsupplement}', "");
Expect(1, 5024, '\p{^inethiopicsupplement}', "");
Expect(1, 5024, '\P{inethiopicsupplement}', "");
Expect(0, 5024, '\P{^inethiopicsupplement}', "");
Expect(1, 5023, '\p{__in_Ethiopic_Supplement}', "");
Expect(0, 5023, '\p{^__in_Ethiopic_Supplement}', "");
Expect(0, 5023, '\P{__in_Ethiopic_Supplement}', "");
Expect(1, 5023, '\P{^__in_Ethiopic_Supplement}', "");
Expect(0, 5024, '\p{__in_Ethiopic_Supplement}', "");
Expect(1, 5024, '\p{^__in_Ethiopic_Supplement}', "");
Expect(1, 5024, '\P{__in_Ethiopic_Supplement}', "");
Expect(0, 5024, '\P{^__in_Ethiopic_Supplement}', "");
Error('\p{		ETHIOPIC_sup/a/}');
Error('\P{		ETHIOPIC_sup/a/}');
Expect(1, 5023, '\p{ethiopicsup}', "");
Expect(0, 5023, '\p{^ethiopicsup}', "");
Expect(0, 5023, '\P{ethiopicsup}', "");
Expect(1, 5023, '\P{^ethiopicsup}', "");
Expect(0, 5024, '\p{ethiopicsup}', "");
Expect(1, 5024, '\p{^ethiopicsup}', "");
Expect(1, 5024, '\P{ethiopicsup}', "");
Expect(0, 5024, '\P{^ethiopicsup}', "");
Expect(1, 5023, '\p{	Ethiopic_Sup}', "");
Expect(0, 5023, '\p{^	Ethiopic_Sup}', "");
Expect(0, 5023, '\P{	Ethiopic_Sup}', "");
Expect(1, 5023, '\P{^	Ethiopic_Sup}', "");
Expect(0, 5024, '\p{	Ethiopic_Sup}', "");
Expect(1, 5024, '\p{^	Ethiopic_Sup}', "");
Expect(1, 5024, '\P{	Ethiopic_Sup}', "");
Expect(0, 5024, '\P{^	Ethiopic_Sup}', "");
Error('\p{--Is_ETHIOPIC_SUP:=}');
Error('\P{--Is_ETHIOPIC_SUP:=}');
Expect(1, 5023, '\p{isethiopicsup}', "");
Expect(0, 5023, '\p{^isethiopicsup}', "");
Expect(0, 5023, '\P{isethiopicsup}', "");
Expect(1, 5023, '\P{^isethiopicsup}', "");
Expect(0, 5024, '\p{isethiopicsup}', "");
Expect(1, 5024, '\p{^isethiopicsup}', "");
Expect(1, 5024, '\P{isethiopicsup}', "");
Expect(0, 5024, '\P{^isethiopicsup}', "");
Expect(1, 5023, '\p{_	IS_ETHIOPIC_Sup}', "");
Expect(0, 5023, '\p{^_	IS_ETHIOPIC_Sup}', "");
Expect(0, 5023, '\P{_	IS_ETHIOPIC_Sup}', "");
Expect(1, 5023, '\P{^_	IS_ETHIOPIC_Sup}', "");
Expect(0, 5024, '\p{_	IS_ETHIOPIC_Sup}', "");
Expect(1, 5024, '\p{^_	IS_ETHIOPIC_Sup}', "");
Expect(1, 5024, '\P{_	IS_ETHIOPIC_Sup}', "");
Expect(0, 5024, '\P{^_	IS_ETHIOPIC_Sup}', "");
Error('\p{-	in_ethiopic_Sup:=}');
Error('\P{-	in_ethiopic_Sup:=}');
Expect(1, 5023, '\p{inethiopicsup}', "");
Expect(0, 5023, '\p{^inethiopicsup}', "");
Expect(0, 5023, '\P{inethiopicsup}', "");
Expect(1, 5023, '\P{^inethiopicsup}', "");
Expect(0, 5024, '\p{inethiopicsup}', "");
Expect(1, 5024, '\p{^inethiopicsup}', "");
Expect(1, 5024, '\P{inethiopicsup}', "");
Expect(0, 5024, '\P{^inethiopicsup}', "");
Expect(1, 5023, '\p{ 	in_Ethiopic_SUP}', "");
Expect(0, 5023, '\p{^ 	in_Ethiopic_SUP}', "");
Expect(0, 5023, '\P{ 	in_Ethiopic_SUP}', "");
Expect(1, 5023, '\P{^ 	in_Ethiopic_SUP}', "");
Expect(0, 5024, '\p{ 	in_Ethiopic_SUP}', "");
Expect(1, 5024, '\p{^ 	in_Ethiopic_SUP}', "");
Expect(1, 5024, '\P{ 	in_Ethiopic_SUP}', "");
Expect(0, 5024, '\P{^ 	in_Ethiopic_SUP}', "");
Error('\p{Expands_On_NFC}');
Error('\P{Expands_On_NFC}');
Error('\p{Is_Expands_On_NFC}');
Error('\P{Is_Expands_On_NFC}');
Error('\p{XO_NFC}');
Error('\P{XO_NFC}');
Error('\p{Is_XO_NFC}');
Error('\P{Is_XO_NFC}');
Error('\p{Expands_On_NFD}');
Error('\P{Expands_On_NFD}');
Error('\p{Is_Expands_On_NFD}');
Error('\P{Is_Expands_On_NFD}');
Error('\p{XO_NFD}');
Error('\P{XO_NFD}');
Error('\p{Is_XO_NFD}');
Error('\P{Is_XO_NFD}');
Error('\p{Expands_On_NFKC}');
Error('\P{Expands_On_NFKC}');
Error('\p{Is_Expands_On_NFKC}');
Error('\P{Is_Expands_On_NFKC}');
Error('\p{XO_NFKC}');
Error('\P{XO_NFKC}');
Error('\p{Is_XO_NFKC}');
Error('\P{Is_XO_NFKC}');
Error('\p{Expands_On_NFKD}');
Error('\P{Expands_On_NFKD}');
Error('\p{Is_Expands_On_NFKD}');
Error('\P{Is_Expands_On_NFKD}');
Error('\p{XO_NFKD}');
Error('\P{XO_NFKD}');
Error('\p{Is_XO_NFKD}');
Error('\P{Is_XO_NFKD}');
Error('\p{	:=Extender}');
Error('\P{	:=Extender}');
Expect(1, 65392, '\p{extender}', "");
Expect(0, 65392, '\p{^extender}', "");
Expect(0, 65392, '\P{extender}', "");
Expect(1, 65392, '\P{^extender}', "");
Expect(0, 65393, '\p{extender}', "");
Expect(1, 65393, '\p{^extender}', "");
Expect(1, 65393, '\P{extender}', "");
Expect(0, 65393, '\P{^extender}', "");
Expect(1, 65392, '\p{	EXTENDER}', "");
Expect(0, 65392, '\p{^	EXTENDER}', "");
Expect(0, 65392, '\P{	EXTENDER}', "");
Expect(1, 65392, '\P{^	EXTENDER}', "");
Expect(0, 65393, '\p{	EXTENDER}', "");
Expect(1, 65393, '\p{^	EXTENDER}', "");
Expect(1, 65393, '\P{	EXTENDER}', "");
Expect(0, 65393, '\P{^	EXTENDER}', "");
Error('\p{/a/-	is_extender}');
Error('\P{/a/-	is_extender}');
Expect(1, 65392, '\p{isextender}', "");
Expect(0, 65392, '\p{^isextender}', "");
Expect(0, 65392, '\P{isextender}', "");
Expect(1, 65392, '\P{^isextender}', "");
Expect(0, 65393, '\p{isextender}', "");
Expect(1, 65393, '\p{^isextender}', "");
Expect(1, 65393, '\P{isextender}', "");
Expect(0, 65393, '\P{^isextender}', "");
Expect(1, 65392, '\p{		IS_extender}', "");
Expect(0, 65392, '\p{^		IS_extender}', "");
Expect(0, 65392, '\P{		IS_extender}', "");
Expect(1, 65392, '\P{^		IS_extender}', "");
Expect(0, 65393, '\p{		IS_extender}', "");
Expect(1, 65393, '\p{^		IS_extender}', "");
Expect(1, 65393, '\P{		IS_extender}', "");
Expect(0, 65393, '\P{^		IS_extender}', "");
Error('\p{:=_ Ext}');
Error('\P{:=_ Ext}');
Expect(1, 65392, '\p{ext}', "");
Expect(0, 65392, '\p{^ext}', "");
Expect(0, 65392, '\P{ext}', "");
Expect(1, 65392, '\P{^ext}', "");
Expect(0, 65393, '\p{ext}', "");
Expect(1, 65393, '\p{^ext}', "");
Expect(1, 65393, '\P{ext}', "");
Expect(0, 65393, '\P{^ext}', "");
Expect(1, 65392, '\p{-	EXT}', "");
Expect(0, 65392, '\p{^-	EXT}', "");
Expect(0, 65392, '\P{-	EXT}', "");
Expect(1, 65392, '\P{^-	EXT}', "");
Expect(0, 65393, '\p{-	EXT}', "");
Expect(1, 65393, '\p{^-	EXT}', "");
Expect(1, 65393, '\P{-	EXT}', "");
Expect(0, 65393, '\P{^-	EXT}', "");
Error('\p{:=--Is_Ext}');
Error('\P{:=--Is_Ext}');
Expect(1, 65392, '\p{isext}', "");
Expect(0, 65392, '\p{^isext}', "");
Expect(0, 65392, '\P{isext}', "");
Expect(1, 65392, '\P{^isext}', "");
Expect(0, 65393, '\p{isext}', "");
Expect(1, 65393, '\p{^isext}', "");
Expect(1, 65393, '\P{isext}', "");
Expect(0, 65393, '\P{^isext}', "");
Expect(1, 65392, '\p{		IS_ext}', "");
Expect(0, 65392, '\p{^		IS_ext}', "");
Expect(0, 65392, '\P{		IS_ext}', "");
Expect(1, 65392, '\P{^		IS_ext}', "");
Expect(0, 65393, '\p{		IS_ext}', "");
Expect(1, 65393, '\p{^		IS_ext}', "");
Expect(1, 65393, '\P{		IS_ext}', "");
Expect(0, 65393, '\P{^		IS_ext}', "");
Error('\p{-/a/Final_Punctuation}');
Error('\P{-/a/Final_Punctuation}');
Expect(1, 11809, '\p{finalpunctuation}', "");
Expect(0, 11809, '\p{^finalpunctuation}', "");
Expect(0, 11809, '\P{finalpunctuation}', "");
Expect(1, 11809, '\P{^finalpunctuation}', "");
Expect(0, 11810, '\p{finalpunctuation}', "");
Expect(1, 11810, '\p{^finalpunctuation}', "");
Expect(1, 11810, '\P{finalpunctuation}', "");
Expect(0, 11810, '\P{^finalpunctuation}', "");
Expect(1, 11809, '\p{ Final_Punctuation}', "");
Expect(0, 11809, '\p{^ Final_Punctuation}', "");
Expect(0, 11809, '\P{ Final_Punctuation}', "");
Expect(1, 11809, '\P{^ Final_Punctuation}', "");
Expect(0, 11810, '\p{ Final_Punctuation}', "");
Expect(1, 11810, '\p{^ Final_Punctuation}', "");
Expect(1, 11810, '\P{ Final_Punctuation}', "");
Expect(0, 11810, '\P{^ Final_Punctuation}', "");
Error('\p{_Is_final_punctuation/a/}');
Error('\P{_Is_final_punctuation/a/}');
Expect(1, 11809, '\p{isfinalpunctuation}', "");
Expect(0, 11809, '\p{^isfinalpunctuation}', "");
Expect(0, 11809, '\P{isfinalpunctuation}', "");
Expect(1, 11809, '\P{^isfinalpunctuation}', "");
Expect(0, 11810, '\p{isfinalpunctuation}', "");
Expect(1, 11810, '\p{^isfinalpunctuation}', "");
Expect(1, 11810, '\P{isfinalpunctuation}', "");
Expect(0, 11810, '\P{^isfinalpunctuation}', "");
Expect(1, 11809, '\p{	Is_Final_punctuation}', "");
Expect(0, 11809, '\p{^	Is_Final_punctuation}', "");
Expect(0, 11809, '\P{	Is_Final_punctuation}', "");
Expect(1, 11809, '\P{^	Is_Final_punctuation}', "");
Expect(0, 11810, '\p{	Is_Final_punctuation}', "");
Expect(1, 11810, '\p{^	Is_Final_punctuation}', "");
Expect(1, 11810, '\P{	Is_Final_punctuation}', "");
Expect(0, 11810, '\P{^	Is_Final_punctuation}', "");
Error('\p{	_Pf/a/}');
Error('\P{	_Pf/a/}');
Expect(1, 11809, '\p{pf}', "");
Expect(0, 11809, '\p{^pf}', "");
Expect(0, 11809, '\P{pf}', "");
Expect(1, 11809, '\P{^pf}', "");
Expect(0, 11810, '\p{pf}', "");
Expect(1, 11810, '\p{^pf}', "");
Expect(1, 11810, '\P{pf}', "");
Expect(0, 11810, '\P{^pf}', "");
Expect(1, 11809, '\p{_-PF}', "");
Expect(0, 11809, '\p{^_-PF}', "");
Expect(0, 11809, '\P{_-PF}', "");
Expect(1, 11809, '\P{^_-PF}', "");
Expect(0, 11810, '\p{_-PF}', "");
Expect(1, 11810, '\p{^_-PF}', "");
Expect(1, 11810, '\P{_-PF}', "");
Expect(0, 11810, '\P{^_-PF}', "");
Error('\p{	:=IS_pf}');
Error('\P{	:=IS_pf}');
Expect(1, 11809, '\p{ispf}', "");
Expect(0, 11809, '\p{^ispf}', "");
Expect(0, 11809, '\P{ispf}', "");
Expect(1, 11809, '\P{^ispf}', "");
Expect(0, 11810, '\p{ispf}', "");
Expect(1, 11810, '\p{^ispf}', "");
Expect(1, 11810, '\P{ispf}', "");
Expect(0, 11810, '\P{^ispf}', "");
Expect(1, 11809, '\p{--IS_Pf}', "");
Expect(0, 11809, '\p{^--IS_Pf}', "");
Expect(0, 11809, '\P{--IS_Pf}', "");
Expect(1, 11809, '\P{^--IS_Pf}', "");
Expect(0, 11810, '\p{--IS_Pf}', "");
Expect(1, 11810, '\p{^--IS_Pf}', "");
Expect(1, 11810, '\P{--IS_Pf}', "");
Expect(0, 11810, '\P{^--IS_Pf}', "");
Error('\p{/a/_Format}');
Error('\P{/a/_Format}');
Expect(1, 917631, '\p{format}', "");
Expect(0, 917631, '\p{^format}', "");
Expect(0, 917631, '\P{format}', "");
Expect(1, 917631, '\P{^format}', "");
Expect(0, 917632, '\p{format}', "");
Expect(1, 917632, '\p{^format}', "");
Expect(1, 917632, '\P{format}', "");
Expect(0, 917632, '\P{^format}', "");
Expect(1, 917631, '\p{FORMAT}', "");
Expect(0, 917631, '\p{^FORMAT}', "");
Expect(0, 917631, '\P{FORMAT}', "");
Expect(1, 917631, '\P{^FORMAT}', "");
Expect(0, 917632, '\p{FORMAT}', "");
Expect(1, 917632, '\p{^FORMAT}', "");
Expect(1, 917632, '\P{FORMAT}', "");
Expect(0, 917632, '\P{^FORMAT}', "");
Error('\p{:= Is_Format}');
Error('\P{:= Is_Format}');
Expect(1, 917631, '\p{isformat}', "");
Expect(0, 917631, '\p{^isformat}', "");
Expect(0, 917631, '\P{isformat}', "");
Expect(1, 917631, '\P{^isformat}', "");
Expect(0, 917632, '\p{isformat}', "");
Expect(1, 917632, '\p{^isformat}', "");
Expect(1, 917632, '\P{isformat}', "");
Expect(0, 917632, '\P{^isformat}', "");
Expect(1, 917631, '\p{	is_Format}', "");
Expect(0, 917631, '\p{^	is_Format}', "");
Expect(0, 917631, '\P{	is_Format}', "");
Expect(1, 917631, '\P{^	is_Format}', "");
Expect(0, 917632, '\p{	is_Format}', "");
Expect(1, 917632, '\p{^	is_Format}', "");
Expect(1, 917632, '\P{	is_Format}', "");
Expect(0, 917632, '\P{^	is_Format}', "");
Error('\p{_/a/CF}');
Error('\P{_/a/CF}');
Expect(1, 917631, '\p{cf}', "");
Expect(0, 917631, '\p{^cf}', "");
Expect(0, 917631, '\P{cf}', "");
Expect(1, 917631, '\P{^cf}', "");
Expect(0, 917632, '\p{cf}', "");
Expect(1, 917632, '\p{^cf}', "");
Expect(1, 917632, '\P{cf}', "");
Expect(0, 917632, '\P{^cf}', "");
Expect(1, 917631, '\p{	CF}', "");
Expect(0, 917631, '\p{^	CF}', "");
Expect(0, 917631, '\P{	CF}', "");
Expect(1, 917631, '\P{^	CF}', "");
Expect(0, 917632, '\p{	CF}', "");
Expect(1, 917632, '\p{^	CF}', "");
Expect(1, 917632, '\P{	CF}', "");
Expect(0, 917632, '\P{^	CF}', "");
Error('\p{-:=Is_Cf}');
Error('\P{-:=Is_Cf}');
Expect(1, 917631, '\p{iscf}', "");
Expect(0, 917631, '\p{^iscf}', "");
Expect(0, 917631, '\P{iscf}', "");
Expect(1, 917631, '\P{^iscf}', "");
Expect(0, 917632, '\p{iscf}', "");
Expect(1, 917632, '\p{^iscf}', "");
Expect(1, 917632, '\P{iscf}', "");
Expect(0, 917632, '\P{^iscf}', "");
Expect(1, 917631, '\p{_-Is_Cf}', "");
Expect(0, 917631, '\p{^_-Is_Cf}', "");
Expect(0, 917631, '\P{_-Is_Cf}', "");
Expect(1, 917631, '\P{^_-Is_Cf}', "");
Expect(0, 917632, '\p{_-Is_Cf}', "");
Expect(1, 917632, '\p{^_-Is_Cf}', "");
Expect(1, 917632, '\P{_-Is_Cf}', "");
Expect(0, 917632, '\P{^_-Is_Cf}', "");
Error('\p{:=	Full_composition_Exclusion}');
Error('\P{:=	Full_composition_Exclusion}');
Expect(1, 195101, '\p{fullcompositionexclusion}', "");
Expect(0, 195101, '\p{^fullcompositionexclusion}', "");
Expect(0, 195101, '\P{fullcompositionexclusion}', "");
Expect(1, 195101, '\P{^fullcompositionexclusion}', "");
Expect(0, 195102, '\p{fullcompositionexclusion}', "");
Expect(1, 195102, '\p{^fullcompositionexclusion}', "");
Expect(1, 195102, '\P{fullcompositionexclusion}', "");
Expect(0, 195102, '\P{^fullcompositionexclusion}', "");
Expect(1, 195101, '\p{Full_composition_Exclusion}', "");
Expect(0, 195101, '\p{^Full_composition_Exclusion}', "");
Expect(0, 195101, '\P{Full_composition_Exclusion}', "");
Expect(1, 195101, '\P{^Full_composition_Exclusion}', "");
Expect(0, 195102, '\p{Full_composition_Exclusion}', "");
Expect(1, 195102, '\p{^Full_composition_Exclusion}', "");
Expect(1, 195102, '\P{Full_composition_Exclusion}', "");
Expect(0, 195102, '\P{^Full_composition_Exclusion}', "");
Error('\p{/a/_ Is_full_composition_exclusion}');
Error('\P{/a/_ Is_full_composition_exclusion}');
Expect(1, 195101, '\p{isfullcompositionexclusion}', "");
Expect(0, 195101, '\p{^isfullcompositionexclusion}', "");
Expect(0, 195101, '\P{isfullcompositionexclusion}', "");
Expect(1, 195101, '\P{^isfullcompositionexclusion}', "");
Expect(0, 195102, '\p{isfullcompositionexclusion}', "");
Expect(1, 195102, '\p{^isfullcompositionexclusion}', "");
Expect(1, 195102, '\P{isfullcompositionexclusion}', "");
Expect(0, 195102, '\P{^isfullcompositionexclusion}', "");
Expect(1, 195101, '\p{  Is_Full_Composition_exclusion}', "");
Expect(0, 195101, '\p{^  Is_Full_Composition_exclusion}', "");
Expect(0, 195101, '\P{  Is_Full_Composition_exclusion}', "");
Expect(1, 195101, '\P{^  Is_Full_Composition_exclusion}', "");
Expect(0, 195102, '\p{  Is_Full_Composition_exclusion}', "");
Expect(1, 195102, '\p{^  Is_Full_Composition_exclusion}', "");
Expect(1, 195102, '\P{  Is_Full_Composition_exclusion}', "");
Expect(0, 195102, '\P{^  Is_Full_Composition_exclusion}', "");
Error('\p{ :=Comp_Ex}');
Error('\P{ :=Comp_Ex}');
Expect(1, 195101, '\p{compex}', "");
Expect(0, 195101, '\p{^compex}', "");
Expect(0, 195101, '\P{compex}', "");
Expect(1, 195101, '\P{^compex}', "");
Expect(0, 195102, '\p{compex}', "");
Expect(1, 195102, '\p{^compex}', "");
Expect(1, 195102, '\P{compex}', "");
Expect(0, 195102, '\P{^compex}', "");
Expect(1, 195101, '\p{_comp_Ex}', "");
Expect(0, 195101, '\p{^_comp_Ex}', "");
Expect(0, 195101, '\P{_comp_Ex}', "");
Expect(1, 195101, '\P{^_comp_Ex}', "");
Expect(0, 195102, '\p{_comp_Ex}', "");
Expect(1, 195102, '\p{^_comp_Ex}', "");
Expect(1, 195102, '\P{_comp_Ex}', "");
Expect(0, 195102, '\P{^_comp_Ex}', "");
Error('\p{/a/	_is_Comp_ex}');
Error('\P{/a/	_is_Comp_ex}');
Expect(1, 195101, '\p{iscompex}', "");
Expect(0, 195101, '\p{^iscompex}', "");
Expect(0, 195101, '\P{iscompex}', "");
Expect(1, 195101, '\P{^iscompex}', "");
Expect(0, 195102, '\p{iscompex}', "");
Expect(1, 195102, '\p{^iscompex}', "");
Expect(1, 195102, '\P{iscompex}', "");
Expect(0, 195102, '\P{^iscompex}', "");
Expect(1, 195101, '\p{	 Is_Comp_Ex}', "");
Expect(0, 195101, '\p{^	 Is_Comp_Ex}', "");
Expect(0, 195101, '\P{	 Is_Comp_Ex}', "");
Expect(1, 195101, '\P{^	 Is_Comp_Ex}', "");
Expect(0, 195102, '\p{	 Is_Comp_Ex}', "");
Expect(1, 195102, '\p{^	 Is_Comp_Ex}', "");
Expect(1, 195102, '\P{	 Is_Comp_Ex}', "");
Expect(0, 195102, '\P{^	 Is_Comp_Ex}', "");
Error('\p{/a/__GENERAL_punctuation}');
Error('\P{/a/__GENERAL_punctuation}');
Expect(1, 8303, '\p{generalpunctuation}', "");
Expect(0, 8303, '\p{^generalpunctuation}', "");
Expect(0, 8303, '\P{generalpunctuation}', "");
Expect(1, 8303, '\P{^generalpunctuation}', "");
Expect(0, 8304, '\p{generalpunctuation}', "");
Expect(1, 8304, '\p{^generalpunctuation}', "");
Expect(1, 8304, '\P{generalpunctuation}', "");
Expect(0, 8304, '\P{^generalpunctuation}', "");
Expect(1, 8303, '\p{ general_Punctuation}', "");
Expect(0, 8303, '\p{^ general_Punctuation}', "");
Expect(0, 8303, '\P{ general_Punctuation}', "");
Expect(1, 8303, '\P{^ general_Punctuation}', "");
Expect(0, 8304, '\p{ general_Punctuation}', "");
Expect(1, 8304, '\p{^ general_Punctuation}', "");
Expect(1, 8304, '\P{ general_Punctuation}', "");
Expect(0, 8304, '\P{^ general_Punctuation}', "");
Error('\p{:=_IS_General_Punctuation}');
Error('\P{:=_IS_General_Punctuation}');
Expect(1, 8303, '\p{isgeneralpunctuation}', "");
Expect(0, 8303, '\p{^isgeneralpunctuation}', "");
Expect(0, 8303, '\P{isgeneralpunctuation}', "");
Expect(1, 8303, '\P{^isgeneralpunctuation}', "");
Expect(0, 8304, '\p{isgeneralpunctuation}', "");
Expect(1, 8304, '\p{^isgeneralpunctuation}', "");
Expect(1, 8304, '\P{isgeneralpunctuation}', "");
Expect(0, 8304, '\P{^isgeneralpunctuation}', "");
Expect(1, 8303, '\p{-IS_General_punctuation}', "");
Expect(0, 8303, '\p{^-IS_General_punctuation}', "");
Expect(0, 8303, '\P{-IS_General_punctuation}', "");
Expect(1, 8303, '\P{^-IS_General_punctuation}', "");
Expect(0, 8304, '\p{-IS_General_punctuation}', "");
Expect(1, 8304, '\p{^-IS_General_punctuation}', "");
Expect(1, 8304, '\P{-IS_General_punctuation}', "");
Expect(0, 8304, '\P{^-IS_General_punctuation}', "");
Error('\p{:= In_General_Punctuation}');
Error('\P{:= In_General_Punctuation}');
Expect(1, 8303, '\p{ingeneralpunctuation}', "");
Expect(0, 8303, '\p{^ingeneralpunctuation}', "");
Expect(0, 8303, '\P{ingeneralpunctuation}', "");
Expect(1, 8303, '\P{^ingeneralpunctuation}', "");
Expect(0, 8304, '\p{ingeneralpunctuation}', "");
Expect(1, 8304, '\p{^ingeneralpunctuation}', "");
Expect(1, 8304, '\P{ingeneralpunctuation}', "");
Expect(0, 8304, '\P{^ingeneralpunctuation}', "");
Expect(1, 8303, '\p{-IN_General_Punctuation}', "");
Expect(0, 8303, '\p{^-IN_General_Punctuation}', "");
Expect(0, 8303, '\P{-IN_General_Punctuation}', "");
Expect(1, 8303, '\P{^-IN_General_Punctuation}', "");
Expect(0, 8304, '\p{-IN_General_Punctuation}', "");
Expect(1, 8304, '\p{^-IN_General_Punctuation}', "");
Expect(1, 8304, '\P{-IN_General_Punctuation}', "");
Expect(0, 8304, '\P{^-IN_General_Punctuation}', "");
Error('\p{-_In_Punctuation:=}');
Error('\P{-_In_Punctuation:=}');
Expect(1, 8303, '\p{inpunctuation}', "");
Expect(0, 8303, '\p{^inpunctuation}', "");
Expect(0, 8303, '\P{inpunctuation}', "");
Expect(1, 8303, '\P{^inpunctuation}', "");
Expect(0, 8304, '\p{inpunctuation}', "");
Expect(1, 8304, '\p{^inpunctuation}', "");
Expect(1, 8304, '\P{inpunctuation}', "");
Expect(0, 8304, '\P{^inpunctuation}', "");
Expect(1, 8303, '\p{_In_Punctuation}', "");
Expect(0, 8303, '\p{^_In_Punctuation}', "");
Expect(0, 8303, '\P{_In_Punctuation}', "");
Expect(1, 8303, '\P{^_In_Punctuation}', "");
Expect(0, 8304, '\p{_In_Punctuation}', "");
Expect(1, 8304, '\p{^_In_Punctuation}', "");
Expect(1, 8304, '\P{_In_Punctuation}', "");
Expect(0, 8304, '\P{^_In_Punctuation}', "");
Error('\p{ /a/Geometric_Shapes}');
Error('\P{ /a/Geometric_Shapes}');
Expect(1, 9727, '\p{geometricshapes}', "");
Expect(0, 9727, '\p{^geometricshapes}', "");
Expect(0, 9727, '\P{geometricshapes}', "");
Expect(1, 9727, '\P{^geometricshapes}', "");
Expect(0, 9728, '\p{geometricshapes}', "");
Expect(1, 9728, '\p{^geometricshapes}', "");
Expect(1, 9728, '\P{geometricshapes}', "");
Expect(0, 9728, '\P{^geometricshapes}', "");
Expect(1, 9727, '\p{Geometric_SHAPES}', "");
Expect(0, 9727, '\p{^Geometric_SHAPES}', "");
Expect(0, 9727, '\P{Geometric_SHAPES}', "");
Expect(1, 9727, '\P{^Geometric_SHAPES}', "");
Expect(0, 9728, '\p{Geometric_SHAPES}', "");
Expect(1, 9728, '\p{^Geometric_SHAPES}', "");
Expect(1, 9728, '\P{Geometric_SHAPES}', "");
Expect(0, 9728, '\P{^Geometric_SHAPES}', "");
Error('\p{/a/_ is_geometric_Shapes}');
Error('\P{/a/_ is_geometric_Shapes}');
Expect(1, 9727, '\p{isgeometricshapes}', "");
Expect(0, 9727, '\p{^isgeometricshapes}', "");
Expect(0, 9727, '\P{isgeometricshapes}', "");
Expect(1, 9727, '\P{^isgeometricshapes}', "");
Expect(0, 9728, '\p{isgeometricshapes}', "");
Expect(1, 9728, '\p{^isgeometricshapes}', "");
Expect(1, 9728, '\P{isgeometricshapes}', "");
Expect(0, 9728, '\P{^isgeometricshapes}', "");
Expect(1, 9727, '\p{-	Is_Geometric_Shapes}', "");
Expect(0, 9727, '\p{^-	Is_Geometric_Shapes}', "");
Expect(0, 9727, '\P{-	Is_Geometric_Shapes}', "");
Expect(1, 9727, '\P{^-	Is_Geometric_Shapes}', "");
Expect(0, 9728, '\p{-	Is_Geometric_Shapes}', "");
Expect(1, 9728, '\p{^-	Is_Geometric_Shapes}', "");
Expect(1, 9728, '\P{-	Is_Geometric_Shapes}', "");
Expect(0, 9728, '\P{^-	Is_Geometric_Shapes}', "");
Error('\p{:=-IN_Geometric_shapes}');
Error('\P{:=-IN_Geometric_shapes}');
Expect(1, 9727, '\p{ingeometricshapes}', "");
Expect(0, 9727, '\p{^ingeometricshapes}', "");
Expect(0, 9727, '\P{ingeometricshapes}', "");
Expect(1, 9727, '\P{^ingeometricshapes}', "");
Expect(0, 9728, '\p{ingeometricshapes}', "");
Expect(1, 9728, '\p{^ingeometricshapes}', "");
Expect(1, 9728, '\P{ingeometricshapes}', "");
Expect(0, 9728, '\P{^ingeometricshapes}', "");
Expect(1, 9727, '\p{_In_GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\p{^_In_GEOMETRIC_Shapes}', "");
Expect(0, 9727, '\P{_In_GEOMETRIC_Shapes}', "");
Expect(1, 9727, '\P{^_In_GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\p{_In_GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\p{^_In_GEOMETRIC_Shapes}', "");
Expect(1, 9728, '\P{_In_GEOMETRIC_Shapes}', "");
Expect(0, 9728, '\P{^_In_GEOMETRIC_Shapes}', "");
Error('\p{/a/georgian}');
Error('\P{/a/georgian}');
Expect(1, 11565, '\p{georgian}', "");
Expect(0, 11565, '\p{^georgian}', "");
Expect(0, 11565, '\P{georgian}', "");
Expect(1, 11565, '\P{^georgian}', "");
Expect(0, 11566, '\p{georgian}', "");
Expect(1, 11566, '\p{^georgian}', "");
Expect(1, 11566, '\P{georgian}', "");
Expect(0, 11566, '\P{^georgian}', "");
Expect(1, 11565, '\p{- Georgian}', "");
Expect(0, 11565, '\p{^- Georgian}', "");
Expect(0, 11565, '\P{- Georgian}', "");
Expect(1, 11565, '\P{^- Georgian}', "");
Expect(0, 11566, '\p{- Georgian}', "");
Expect(1, 11566, '\p{^- Georgian}', "");
Expect(1, 11566, '\P{- Georgian}', "");
Expect(0, 11566, '\P{^- Georgian}', "");
Error('\p{ -Is_GEORGIAN:=}');
Error('\P{ -Is_GEORGIAN:=}');
Expect(1, 11565, '\p{isgeorgian}', "");
Expect(0, 11565, '\p{^isgeorgian}', "");
Expect(0, 11565, '\P{isgeorgian}', "");
Expect(1, 11565, '\P{^isgeorgian}', "");
Expect(0, 11566, '\p{isgeorgian}', "");
Expect(1, 11566, '\p{^isgeorgian}', "");
Expect(1, 11566, '\P{isgeorgian}', "");
Expect(0, 11566, '\P{^isgeorgian}', "");
Expect(1, 11565, '\p{  is_Georgian}', "");
Expect(0, 11565, '\p{^  is_Georgian}', "");
Expect(0, 11565, '\P{  is_Georgian}', "");
Expect(1, 11565, '\P{^  is_Georgian}', "");
Expect(0, 11566, '\p{  is_Georgian}', "");
Expect(1, 11566, '\p{^  is_Georgian}', "");
Expect(1, 11566, '\P{  is_Georgian}', "");
Expect(0, 11566, '\P{^  is_Georgian}', "");
Error('\p{/a/-_geor}');
Error('\P{/a/-_geor}');
Expect(1, 11565, '\p{geor}', "");
Expect(0, 11565, '\p{^geor}', "");
Expect(0, 11565, '\P{geor}', "");
Expect(1, 11565, '\P{^geor}', "");
Expect(0, 11566, '\p{geor}', "");
Expect(1, 11566, '\p{^geor}', "");
Expect(1, 11566, '\P{geor}', "");
Expect(0, 11566, '\P{^geor}', "");
Expect(1, 11565, '\p{Geor}', "");
Expect(0, 11565, '\p{^Geor}', "");
Expect(0, 11565, '\P{Geor}', "");
Expect(1, 11565, '\P{^Geor}', "");
Expect(0, 11566, '\p{Geor}', "");
Expect(1, 11566, '\p{^Geor}', "");
Expect(1, 11566, '\P{Geor}', "");
Expect(0, 11566, '\P{^Geor}', "");
Error('\p{/a/_ Is_Geor}');
Error('\P{/a/_ Is_Geor}');
Expect(1, 11565, '\p{isgeor}', "");
Expect(0, 11565, '\p{^isgeor}', "");
Expect(0, 11565, '\P{isgeor}', "");
Expect(1, 11565, '\P{^isgeor}', "");
Expect(0, 11566, '\p{isgeor}', "");
Expect(1, 11566, '\p{^isgeor}', "");
Expect(1, 11566, '\P{isgeor}', "");
Expect(0, 11566, '\P{^isgeor}', "");
Expect(1, 11565, '\p{--is_GEOR}', "");
Expect(0, 11565, '\p{^--is_GEOR}', "");
Expect(0, 11565, '\P{--is_GEOR}', "");
Expect(1, 11565, '\P{^--is_GEOR}', "");
Expect(0, 11566, '\p{--is_GEOR}', "");
Expect(1, 11566, '\p{^--is_GEOR}', "");
Expect(1, 11566, '\P{--is_GEOR}', "");
Expect(0, 11566, '\P{^--is_GEOR}', "");
Error('\p{ Georgian_SUPPLEMENT:=}');
Error('\P{ Georgian_SUPPLEMENT:=}');
Expect(1, 11567, '\p{georgiansupplement}', "");
Expect(0, 11567, '\p{^georgiansupplement}', "");
Expect(0, 11567, '\P{georgiansupplement}', "");
Expect(1, 11567, '\P{^georgiansupplement}', "");
Expect(0, 11568, '\p{georgiansupplement}', "");
Expect(1, 11568, '\p{^georgiansupplement}', "");
Expect(1, 11568, '\P{georgiansupplement}', "");
Expect(0, 11568, '\P{^georgiansupplement}', "");
Expect(1, 11567, '\p{georgian_supplement}', "");
Expect(0, 11567, '\p{^georgian_supplement}', "");
Expect(0, 11567, '\P{georgian_supplement}', "");
Expect(1, 11567, '\P{^georgian_supplement}', "");
Expect(0, 11568, '\p{georgian_supplement}', "");
Expect(1, 11568, '\p{^georgian_supplement}', "");
Expect(1, 11568, '\P{georgian_supplement}', "");
Expect(0, 11568, '\P{^georgian_supplement}', "");
Error('\p{ :=IS_Georgian_SUPPLEMENT}');
Error('\P{ :=IS_Georgian_SUPPLEMENT}');
Expect(1, 11567, '\p{isgeorgiansupplement}', "");
Expect(0, 11567, '\p{^isgeorgiansupplement}', "");
Expect(0, 11567, '\P{isgeorgiansupplement}', "");
Expect(1, 11567, '\P{^isgeorgiansupplement}', "");
Expect(0, 11568, '\p{isgeorgiansupplement}', "");
Expect(1, 11568, '\p{^isgeorgiansupplement}', "");
Expect(1, 11568, '\P{isgeorgiansupplement}', "");
Expect(0, 11568, '\P{^isgeorgiansupplement}', "");
Expect(1, 11567, '\p{--IS_GEORGIAN_Supplement}', "");
Expect(0, 11567, '\p{^--IS_GEORGIAN_Supplement}', "");
Expect(0, 11567, '\P{--IS_GEORGIAN_Supplement}', "");
Expect(1, 11567, '\P{^--IS_GEORGIAN_Supplement}', "");
Expect(0, 11568, '\p{--IS_GEORGIAN_Supplement}', "");
Expect(1, 11568, '\p{^--IS_GEORGIAN_Supplement}', "");
Expect(1, 11568, '\P{--IS_GEORGIAN_Supplement}', "");
Expect(0, 11568, '\P{^--IS_GEORGIAN_Supplement}', "");
Error('\p{-_in_GEORGIAN_Supplement/a/}');
Error('\P{-_in_GEORGIAN_Supplement/a/}');
Expect(1, 11567, '\p{ingeorgiansupplement}', "");
Expect(0, 11567, '\p{^ingeorgiansupplement}', "");
Expect(0, 11567, '\P{ingeorgiansupplement}', "");
Expect(1, 11567, '\P{^ingeorgiansupplement}', "");
Expect(0, 11568, '\p{ingeorgiansupplement}', "");
Expect(1, 11568, '\p{^ingeorgiansupplement}', "");
Expect(1, 11568, '\P{ingeorgiansupplement}', "");
Expect(0, 11568, '\P{^ingeorgiansupplement}', "");
Expect(1, 11567, '\p{-In_Georgian_SUPPLEMENT}', "");
Expect(0, 11567, '\p{^-In_Georgian_SUPPLEMENT}', "");
Expect(0, 11567, '\P{-In_Georgian_SUPPLEMENT}', "");
Expect(1, 11567, '\P{^-In_Georgian_SUPPLEMENT}', "");
Expect(0, 11568, '\p{-In_Georgian_SUPPLEMENT}', "");
Expect(1, 11568, '\p{^-In_Georgian_SUPPLEMENT}', "");
Expect(1, 11568, '\P{-In_Georgian_SUPPLEMENT}', "");
Expect(0, 11568, '\P{^-In_Georgian_SUPPLEMENT}', "");
Error('\p{	_Georgian_Sup/a/}');
Error('\P{	_Georgian_Sup/a/}');
Expect(1, 11567, '\p{georgiansup}', "");
Expect(0, 11567, '\p{^georgiansup}', "");
Expect(0, 11567, '\P{georgiansup}', "");
Expect(1, 11567, '\P{^georgiansup}', "");
Expect(0, 11568, '\p{georgiansup}', "");
Expect(1, 11568, '\p{^georgiansup}', "");
Expect(1, 11568, '\P{georgiansup}', "");
Expect(0, 11568, '\P{^georgiansup}', "");
Expect(1, 11567, '\p{	GEORGIAN_SUP}', "");
Expect(0, 11567, '\p{^	GEORGIAN_SUP}', "");
Expect(0, 11567, '\P{	GEORGIAN_SUP}', "");
Expect(1, 11567, '\P{^	GEORGIAN_SUP}', "");
Expect(0, 11568, '\p{	GEORGIAN_SUP}', "");
Expect(1, 11568, '\p{^	GEORGIAN_SUP}', "");
Expect(1, 11568, '\P{	GEORGIAN_SUP}', "");
Expect(0, 11568, '\P{^	GEORGIAN_SUP}', "");
Error('\p{/a/_Is_georgian_SUP}');
Error('\P{/a/_Is_georgian_SUP}');
Expect(1, 11567, '\p{isgeorgiansup}', "");
Expect(0, 11567, '\p{^isgeorgiansup}', "");
Expect(0, 11567, '\P{isgeorgiansup}', "");
Expect(1, 11567, '\P{^isgeorgiansup}', "");
Expect(0, 11568, '\p{isgeorgiansup}', "");
Expect(1, 11568, '\p{^isgeorgiansup}', "");
Expect(1, 11568, '\P{isgeorgiansup}', "");
Expect(0, 11568, '\P{^isgeorgiansup}', "");
Expect(1, 11567, '\p{		Is_Georgian_Sup}', "");
Expect(0, 11567, '\p{^		Is_Georgian_Sup}', "");
Expect(0, 11567, '\P{		Is_Georgian_Sup}', "");
Expect(1, 11567, '\P{^		Is_Georgian_Sup}', "");
Expect(0, 11568, '\p{		Is_Georgian_Sup}', "");
Expect(1, 11568, '\p{^		Is_Georgian_Sup}', "");
Expect(1, 11568, '\P{		Is_Georgian_Sup}', "");
Expect(0, 11568, '\P{^		Is_Georgian_Sup}', "");
Error('\p{:=-in_Georgian_Sup}');
Error('\P{:=-in_Georgian_Sup}');
Expect(1, 11567, '\p{ingeorgiansup}', "");
Expect(0, 11567, '\p{^ingeorgiansup}', "");
Expect(0, 11567, '\P{ingeorgiansup}', "");
Expect(1, 11567, '\P{^ingeorgiansup}', "");
Expect(0, 11568, '\p{ingeorgiansup}', "");
Expect(1, 11568, '\p{^ingeorgiansup}', "");
Expect(1, 11568, '\P{ingeorgiansup}', "");
Expect(0, 11568, '\P{^ingeorgiansup}', "");
Expect(1, 11567, '\p{	In_Georgian_Sup}', "");
Expect(0, 11567, '\p{^	In_Georgian_Sup}', "");
Expect(0, 11567, '\P{	In_Georgian_Sup}', "");
Expect(1, 11567, '\P{^	In_Georgian_Sup}', "");
Expect(0, 11568, '\p{	In_Georgian_Sup}', "");
Expect(1, 11568, '\p{^	In_Georgian_Sup}', "");
Expect(1, 11568, '\P{	In_Georgian_Sup}', "");
Expect(0, 11568, '\P{^	In_Georgian_Sup}', "");
Error('\p{-:=Glagolitic}');
Error('\P{-:=Glagolitic}');
Expect(1, 11358, '\p{glagolitic}', "");
Expect(0, 11358, '\p{^glagolitic}', "");
Expect(0, 11358, '\P{glagolitic}', "");
Expect(1, 11358, '\P{^glagolitic}', "");
Expect(0, 11359, '\p{glagolitic}', "");
Expect(1, 11359, '\p{^glagolitic}', "");
Expect(1, 11359, '\P{glagolitic}', "");
Expect(0, 11359, '\P{^glagolitic}', "");
Expect(1, 11358, '\p{	Glagolitic}', "");
Expect(0, 11358, '\p{^	Glagolitic}', "");
Expect(0, 11358, '\P{	Glagolitic}', "");
Expect(1, 11358, '\P{^	Glagolitic}', "");
Expect(0, 11359, '\p{	Glagolitic}', "");
Expect(1, 11359, '\p{^	Glagolitic}', "");
Expect(1, 11359, '\P{	Glagolitic}', "");
Expect(0, 11359, '\P{^	Glagolitic}', "");
Error('\p{	_Is_Glagolitic/a/}');
Error('\P{	_Is_Glagolitic/a/}');
Expect(1, 11358, '\p{isglagolitic}', "");
Expect(0, 11358, '\p{^isglagolitic}', "");
Expect(0, 11358, '\P{isglagolitic}', "");
Expect(1, 11358, '\P{^isglagolitic}', "");
Expect(0, 11359, '\p{isglagolitic}', "");
Expect(1, 11359, '\p{^isglagolitic}', "");
Expect(1, 11359, '\P{isglagolitic}', "");
Expect(0, 11359, '\P{^isglagolitic}', "");
Expect(1, 11358, '\p{_Is_Glagolitic}', "");
Expect(0, 11358, '\p{^_Is_Glagolitic}', "");
Expect(0, 11358, '\P{_Is_Glagolitic}', "");
Expect(1, 11358, '\P{^_Is_Glagolitic}', "");
Expect(0, 11359, '\p{_Is_Glagolitic}', "");
Expect(1, 11359, '\p{^_Is_Glagolitic}', "");
Expect(1, 11359, '\P{_Is_Glagolitic}', "");
Expect(0, 11359, '\P{^_Is_Glagolitic}', "");
Error('\p{	_GLAG:=}');
Error('\P{	_GLAG:=}');
Expect(1, 11358, '\p{glag}', "");
Expect(0, 11358, '\p{^glag}', "");
Expect(0, 11358, '\P{glag}', "");
Expect(1, 11358, '\P{^glag}', "");
Expect(0, 11359, '\p{glag}', "");
Expect(1, 11359, '\p{^glag}', "");
Expect(1, 11359, '\P{glag}', "");
Expect(0, 11359, '\P{^glag}', "");
Expect(1, 11358, '\p{-glag}', "");
Expect(0, 11358, '\p{^-glag}', "");
Expect(0, 11358, '\P{-glag}', "");
Expect(1, 11358, '\P{^-glag}', "");
Expect(0, 11359, '\p{-glag}', "");
Expect(1, 11359, '\p{^-glag}', "");
Expect(1, 11359, '\P{-glag}', "");
Expect(0, 11359, '\P{^-glag}', "");
Error('\p{	/a/Is_glag}');
Error('\P{	/a/Is_glag}');
Expect(1, 11358, '\p{isglag}', "");
Expect(0, 11358, '\p{^isglag}', "");
Expect(0, 11358, '\P{isglag}', "");
Expect(1, 11358, '\P{^isglag}', "");
Expect(0, 11359, '\p{isglag}', "");
Expect(1, 11359, '\p{^isglag}', "");
Expect(1, 11359, '\P{isglag}', "");
Expect(0, 11359, '\P{^isglag}', "");
Expect(1, 11358, '\p{-_Is_Glag}', "");
Expect(0, 11358, '\p{^-_Is_Glag}', "");
Expect(0, 11358, '\P{-_Is_Glag}', "");
Expect(1, 11358, '\P{^-_Is_Glag}', "");
Expect(0, 11359, '\p{-_Is_Glag}', "");
Expect(1, 11359, '\p{^-_Is_Glag}', "");
Expect(1, 11359, '\P{-_Is_Glag}', "");
Expect(0, 11359, '\P{^-_Is_Glag}', "");
Error('\p{/a/	-Gothic}');
Error('\P{/a/	-Gothic}');
Expect(1, 66378, '\p{gothic}', "");
Expect(0, 66378, '\p{^gothic}', "");
Expect(0, 66378, '\P{gothic}', "");
Expect(1, 66378, '\P{^gothic}', "");
Expect(0, 66379, '\p{gothic}', "");
Expect(1, 66379, '\p{^gothic}', "");
Expect(1, 66379, '\P{gothic}', "");
Expect(0, 66379, '\P{^gothic}', "");
Expect(1, 66378, '\p{__Gothic}', "");
Expect(0, 66378, '\p{^__Gothic}', "");
Expect(0, 66378, '\P{__Gothic}', "");
Expect(1, 66378, '\P{^__Gothic}', "");
Expect(0, 66379, '\p{__Gothic}', "");
Expect(1, 66379, '\p{^__Gothic}', "");
Expect(1, 66379, '\P{__Gothic}', "");
Expect(0, 66379, '\P{^__Gothic}', "");
Error('\p{- Is_Gothic:=}');
Error('\P{- Is_Gothic:=}');
Expect(1, 66378, '\p{isgothic}', "");
Expect(0, 66378, '\p{^isgothic}', "");
Expect(0, 66378, '\P{isgothic}', "");
Expect(1, 66378, '\P{^isgothic}', "");
Expect(0, 66379, '\p{isgothic}', "");
Expect(1, 66379, '\p{^isgothic}', "");
Expect(1, 66379, '\P{isgothic}', "");
Expect(0, 66379, '\P{^isgothic}', "");
Expect(1, 66378, '\p{	 is_Gothic}', "");
Expect(0, 66378, '\p{^	 is_Gothic}', "");
Expect(0, 66378, '\P{	 is_Gothic}', "");
Expect(1, 66378, '\P{^	 is_Gothic}', "");
Expect(0, 66379, '\p{	 is_Gothic}', "");
Expect(1, 66379, '\p{^	 is_Gothic}', "");
Expect(1, 66379, '\P{	 is_Gothic}', "");
Expect(0, 66379, '\P{^	 is_Gothic}', "");
Error('\p{_GOTH/a/}');
Error('\P{_GOTH/a/}');
Expect(1, 66378, '\p{goth}', "");
Expect(0, 66378, '\p{^goth}', "");
Expect(0, 66378, '\P{goth}', "");
Expect(1, 66378, '\P{^goth}', "");
Expect(0, 66379, '\p{goth}', "");
Expect(1, 66379, '\p{^goth}', "");
Expect(1, 66379, '\P{goth}', "");
Expect(0, 66379, '\P{^goth}', "");
Expect(1, 66378, '\p{_Goth}', "");
Expect(0, 66378, '\p{^_Goth}', "");
Expect(0, 66378, '\P{_Goth}', "");
Expect(1, 66378, '\P{^_Goth}', "");
Expect(0, 66379, '\p{_Goth}', "");
Expect(1, 66379, '\p{^_Goth}', "");
Expect(1, 66379, '\P{_Goth}', "");
Expect(0, 66379, '\P{^_Goth}', "");
Error('\p{-/a/Is_GOTH}');
Error('\P{-/a/Is_GOTH}');
Expect(1, 66378, '\p{isgoth}', "");
Expect(0, 66378, '\p{^isgoth}', "");
Expect(0, 66378, '\P{isgoth}', "");
Expect(1, 66378, '\P{^isgoth}', "");
Expect(0, 66379, '\p{isgoth}', "");
Expect(1, 66379, '\p{^isgoth}', "");
Expect(1, 66379, '\P{isgoth}', "");
Expect(0, 66379, '\P{^isgoth}', "");
Expect(1, 66378, '\p{--Is_Goth}', "");
Expect(0, 66378, '\p{^--Is_Goth}', "");
Expect(0, 66378, '\P{--Is_Goth}', "");
Expect(1, 66378, '\P{^--Is_Goth}', "");
Expect(0, 66379, '\p{--Is_Goth}', "");
Expect(1, 66379, '\p{^--Is_Goth}', "");
Expect(1, 66379, '\P{--Is_Goth}', "");
Expect(0, 66379, '\P{^--Is_Goth}', "");
Error('\p{:=Graph}');
Error('\P{:=Graph}');
Expect(1, 1114109, '\p{graph}', "");
Expect(0, 1114109, '\p{^graph}', "");
Expect(0, 1114109, '\P{graph}', "");
Expect(1, 1114109, '\P{^graph}', "");
Expect(0, 918000, '\p{graph}', "");
Expect(1, 918000, '\p{^graph}', "");
Expect(1, 918000, '\P{graph}', "");
Expect(0, 918000, '\P{^graph}', "");
Expect(1, 1114109, '\p{- Graph}', "");
Expect(0, 1114109, '\p{^- Graph}', "");
Expect(0, 1114109, '\P{- Graph}', "");
Expect(1, 1114109, '\P{^- Graph}', "");
Expect(0, 918000, '\p{- Graph}', "");
Expect(1, 918000, '\p{^- Graph}', "");
Expect(1, 918000, '\P{- Graph}', "");
Expect(0, 918000, '\P{^- Graph}', "");
Error('\p{/a/	xposixgraph}');
Error('\P{/a/	xposixgraph}');
Expect(1, 1114109, '\p{xposixgraph}', "");
Expect(0, 1114109, '\p{^xposixgraph}', "");
Expect(0, 1114109, '\P{xposixgraph}', "");
Expect(1, 1114109, '\P{^xposixgraph}', "");
Expect(0, 918000, '\p{xposixgraph}', "");
Expect(1, 918000, '\p{^xposixgraph}', "");
Expect(1, 918000, '\P{xposixgraph}', "");
Expect(0, 918000, '\P{^xposixgraph}', "");
Expect(1, 1114109, '\p{-_XPosixGraph}', "");
Expect(0, 1114109, '\p{^-_XPosixGraph}', "");
Expect(0, 1114109, '\P{-_XPosixGraph}', "");
Expect(1, 1114109, '\P{^-_XPosixGraph}', "");
Expect(0, 918000, '\p{-_XPosixGraph}', "");
Expect(1, 918000, '\p{^-_XPosixGraph}', "");
Expect(1, 918000, '\P{-_XPosixGraph}', "");
Expect(0, 918000, '\P{^-_XPosixGraph}', "");
Error('\p{:=-Is_Graph}');
Error('\P{:=-Is_Graph}');
Expect(1, 1114109, '\p{isgraph}', "");
Expect(0, 1114109, '\p{^isgraph}', "");
Expect(0, 1114109, '\P{isgraph}', "");
Expect(1, 1114109, '\P{^isgraph}', "");
Expect(0, 918000, '\p{isgraph}', "");
Expect(1, 918000, '\p{^isgraph}', "");
Expect(1, 918000, '\P{isgraph}', "");
Expect(0, 918000, '\P{^isgraph}', "");
Expect(1, 1114109, '\p{-Is_Graph}', "");
Expect(0, 1114109, '\p{^-Is_Graph}', "");
Expect(0, 1114109, '\P{-Is_Graph}', "");
Expect(1, 1114109, '\P{^-Is_Graph}', "");
Expect(0, 918000, '\p{-Is_Graph}', "");
Expect(1, 918000, '\p{^-Is_Graph}', "");
Expect(1, 918000, '\P{-Is_Graph}', "");
Expect(0, 918000, '\P{^-Is_Graph}', "");
Error('\p{-/a/IS_XPOSIXGRAPH}');
Error('\P{-/a/IS_XPOSIXGRAPH}');
Expect(1, 1114109, '\p{isxposixgraph}', "");
Expect(0, 1114109, '\p{^isxposixgraph}', "");
Expect(0, 1114109, '\P{isxposixgraph}', "");
Expect(1, 1114109, '\P{^isxposixgraph}', "");
Expect(0, 918000, '\p{isxposixgraph}', "");
Expect(1, 918000, '\p{^isxposixgraph}', "");
Expect(1, 918000, '\P{isxposixgraph}', "");
Expect(0, 918000, '\P{^isxposixgraph}', "");
Expect(1, 1114109, '\p{  IS_XPosixGraph}', "");
Expect(0, 1114109, '\p{^  IS_XPosixGraph}', "");
Expect(0, 1114109, '\P{  IS_XPosixGraph}', "");
Expect(1, 1114109, '\P{^  IS_XPosixGraph}', "");
Expect(0, 918000, '\p{  IS_XPosixGraph}', "");
Expect(1, 918000, '\p{^  IS_XPosixGraph}', "");
Expect(1, 918000, '\P{  IS_XPosixGraph}', "");
Expect(0, 918000, '\P{^  IS_XPosixGraph}', "");
Error('\p{/a/ _grapheme_Base}');
Error('\P{/a/ _grapheme_Base}');
Expect(1, 195101, '\p{graphemebase}', "");
Expect(0, 195101, '\p{^graphemebase}', "");
Expect(0, 195101, '\P{graphemebase}', "");
Expect(1, 195101, '\P{^graphemebase}', "");
Expect(0, 195102, '\p{graphemebase}', "");
Expect(1, 195102, '\p{^graphemebase}', "");
Expect(1, 195102, '\P{graphemebase}', "");
Expect(0, 195102, '\P{^graphemebase}', "");
Expect(1, 195101, '\p{ 	GRAPHEME_BASE}', "");
Expect(0, 195101, '\p{^ 	GRAPHEME_BASE}', "");
Expect(0, 195101, '\P{ 	GRAPHEME_BASE}', "");
Expect(1, 195101, '\P{^ 	GRAPHEME_BASE}', "");
Expect(0, 195102, '\p{ 	GRAPHEME_BASE}', "");
Expect(1, 195102, '\p{^ 	GRAPHEME_BASE}', "");
Expect(1, 195102, '\P{ 	GRAPHEME_BASE}', "");
Expect(0, 195102, '\P{^ 	GRAPHEME_BASE}', "");
Error('\p{_/a/IS_grapheme_BASE}');
Error('\P{_/a/IS_grapheme_BASE}');
Expect(1, 195101, '\p{isgraphemebase}', "");
Expect(0, 195101, '\p{^isgraphemebase}', "");
Expect(0, 195101, '\P{isgraphemebase}', "");
Expect(1, 195101, '\P{^isgraphemebase}', "");
Expect(0, 195102, '\p{isgraphemebase}', "");
Expect(1, 195102, '\p{^isgraphemebase}', "");
Expect(1, 195102, '\P{isgraphemebase}', "");
Expect(0, 195102, '\P{^isgraphemebase}', "");
Expect(1, 195101, '\p{ -is_Grapheme_BASE}', "");
Expect(0, 195101, '\p{^ -is_Grapheme_BASE}', "");
Expect(0, 195101, '\P{ -is_Grapheme_BASE}', "");
Expect(1, 195101, '\P{^ -is_Grapheme_BASE}', "");
Expect(0, 195102, '\p{ -is_Grapheme_BASE}', "");
Expect(1, 195102, '\p{^ -is_Grapheme_BASE}', "");
Expect(1, 195102, '\P{ -is_Grapheme_BASE}', "");
Expect(0, 195102, '\P{^ -is_Grapheme_BASE}', "");
Error('\p{/a/ -Gr_base}');
Error('\P{/a/ -Gr_base}');
Expect(1, 195101, '\p{grbase}', "");
Expect(0, 195101, '\p{^grbase}', "");
Expect(0, 195101, '\P{grbase}', "");
Expect(1, 195101, '\P{^grbase}', "");
Expect(0, 195102, '\p{grbase}', "");
Expect(1, 195102, '\p{^grbase}', "");
Expect(1, 195102, '\P{grbase}', "");
Expect(0, 195102, '\P{^grbase}', "");
Expect(1, 195101, '\p{-Gr_Base}', "");
Expect(0, 195101, '\p{^-Gr_Base}', "");
Expect(0, 195101, '\P{-Gr_Base}', "");
Expect(1, 195101, '\P{^-Gr_Base}', "");
Expect(0, 195102, '\p{-Gr_Base}', "");
Expect(1, 195102, '\p{^-Gr_Base}', "");
Expect(1, 195102, '\P{-Gr_Base}', "");
Expect(0, 195102, '\P{^-Gr_Base}', "");
Error('\p{:=- Is_Gr_base}');
Error('\P{:=- Is_Gr_base}');
Expect(1, 195101, '\p{isgrbase}', "");
Expect(0, 195101, '\p{^isgrbase}', "");
Expect(0, 195101, '\P{isgrbase}', "");
Expect(1, 195101, '\P{^isgrbase}', "");
Expect(0, 195102, '\p{isgrbase}', "");
Expect(1, 195102, '\p{^isgrbase}', "");
Expect(1, 195102, '\P{isgrbase}', "");
Expect(0, 195102, '\P{^isgrbase}', "");
Expect(1, 195101, '\p{ _Is_GR_Base}', "");
Expect(0, 195101, '\p{^ _Is_GR_Base}', "");
Expect(0, 195101, '\P{ _Is_GR_Base}', "");
Expect(1, 195101, '\P{^ _Is_GR_Base}', "");
Expect(0, 195102, '\p{ _Is_GR_Base}', "");
Expect(1, 195102, '\p{^ _Is_GR_Base}', "");
Expect(1, 195102, '\P{ _Is_GR_Base}', "");
Expect(0, 195102, '\P{^ _Is_GR_Base}', "");
Error('\p{ /a/grapheme_Extend}');
Error('\P{ /a/grapheme_Extend}');
Expect(1, 917999, '\p{graphemeextend}', "");
Expect(0, 917999, '\p{^graphemeextend}', "");
Expect(0, 917999, '\P{graphemeextend}', "");
Expect(1, 917999, '\P{^graphemeextend}', "");
Expect(0, 918000, '\p{graphemeextend}', "");
Expect(1, 918000, '\p{^graphemeextend}', "");
Expect(1, 918000, '\P{graphemeextend}', "");
Expect(0, 918000, '\P{^graphemeextend}', "");
Expect(1, 917999, '\p{-	Grapheme_Extend}', "");
Expect(0, 917999, '\p{^-	Grapheme_Extend}', "");
Expect(0, 917999, '\P{-	Grapheme_Extend}', "");
Expect(1, 917999, '\P{^-	Grapheme_Extend}', "");
Expect(0, 918000, '\p{-	Grapheme_Extend}', "");
Expect(1, 918000, '\p{^-	Grapheme_Extend}', "");
Expect(1, 918000, '\P{-	Grapheme_Extend}', "");
Expect(0, 918000, '\P{^-	Grapheme_Extend}', "");
Error('\p{/a/_-Is_grapheme_Extend}');
Error('\P{/a/_-Is_grapheme_Extend}');
Expect(1, 917999, '\p{isgraphemeextend}', "");
Expect(0, 917999, '\p{^isgraphemeextend}', "");
Expect(0, 917999, '\P{isgraphemeextend}', "");
Expect(1, 917999, '\P{^isgraphemeextend}', "");
Expect(0, 918000, '\p{isgraphemeextend}', "");
Expect(1, 918000, '\p{^isgraphemeextend}', "");
Expect(1, 918000, '\P{isgraphemeextend}', "");
Expect(0, 918000, '\P{^isgraphemeextend}', "");
Expect(1, 917999, '\p{-Is_GRAPHEME_Extend}', "");
Expect(0, 917999, '\p{^-Is_GRAPHEME_Extend}', "");
Expect(0, 917999, '\P{-Is_GRAPHEME_Extend}', "");
Expect(1, 917999, '\P{^-Is_GRAPHEME_Extend}', "");
Expect(0, 918000, '\p{-Is_GRAPHEME_Extend}', "");
Expect(1, 918000, '\p{^-Is_GRAPHEME_Extend}', "");
Expect(1, 918000, '\P{-Is_GRAPHEME_Extend}', "");
Expect(0, 918000, '\P{^-Is_GRAPHEME_Extend}', "");
Error('\p{	/a/GR_Ext}');
Error('\P{	/a/GR_Ext}');
Expect(1, 917999, '\p{grext}', "");
Expect(0, 917999, '\p{^grext}', "");
Expect(0, 917999, '\P{grext}', "");
Expect(1, 917999, '\P{^grext}', "");
Expect(0, 918000, '\p{grext}', "");
Expect(1, 918000, '\p{^grext}', "");
Expect(1, 918000, '\P{grext}', "");
Expect(0, 918000, '\P{^grext}', "");
Expect(1, 917999, '\p{__Gr_EXT}', "");
Expect(0, 917999, '\p{^__Gr_EXT}', "");
Expect(0, 917999, '\P{__Gr_EXT}', "");
Expect(1, 917999, '\P{^__Gr_EXT}', "");
Expect(0, 918000, '\p{__Gr_EXT}', "");
Expect(1, 918000, '\p{^__Gr_EXT}', "");
Expect(1, 918000, '\P{__Gr_EXT}', "");
Expect(0, 918000, '\P{^__Gr_EXT}', "");
Error('\p{ is_gr_Ext:=}');
Error('\P{ is_gr_Ext:=}');
Expect(1, 917999, '\p{isgrext}', "");
Expect(0, 917999, '\p{^isgrext}', "");
Expect(0, 917999, '\P{isgrext}', "");
Expect(1, 917999, '\P{^isgrext}', "");
Expect(0, 918000, '\p{isgrext}', "");
Expect(1, 918000, '\p{^isgrext}', "");
Expect(1, 918000, '\P{isgrext}', "");
Expect(0, 918000, '\P{^isgrext}', "");
Expect(1, 917999, '\p{	Is_gr_Ext}', "");
Expect(0, 917999, '\p{^	Is_gr_Ext}', "");
Expect(0, 917999, '\P{	Is_gr_Ext}', "");
Expect(1, 917999, '\P{^	Is_gr_Ext}', "");
Expect(0, 918000, '\p{	Is_gr_Ext}', "");
Expect(1, 918000, '\p{^	Is_gr_Ext}', "");
Expect(1, 918000, '\P{	Is_gr_Ext}', "");
Expect(0, 918000, '\P{^	Is_gr_Ext}', "");
Error('\p{Grapheme_Link}');
Error('\P{Grapheme_Link}');
Error('\p{Is_Grapheme_Link}');
Error('\P{Is_Grapheme_Link}');
Error('\p{Gr_Link}');
Error('\P{Gr_Link}');
Error('\p{Is_Gr_Link}');
Error('\P{Is_Gr_Link}');
Error('\p{:=	-greek}');
Error('\P{:=	-greek}');
Expect(1, 119365, '\p{greek}', "");
Expect(0, 119365, '\p{^greek}', "");
Expect(0, 119365, '\P{greek}', "");
Expect(1, 119365, '\P{^greek}', "");
Expect(0, 119366, '\p{greek}', "");
Expect(1, 119366, '\p{^greek}', "");
Expect(1, 119366, '\P{greek}', "");
Expect(0, 119366, '\P{^greek}', "");
Expect(1, 119365, '\p{ -GREEK}', "");
Expect(0, 119365, '\p{^ -GREEK}', "");
Expect(0, 119365, '\P{ -GREEK}', "");
Expect(1, 119365, '\P{^ -GREEK}', "");
Expect(0, 119366, '\p{ -GREEK}', "");
Expect(1, 119366, '\p{^ -GREEK}', "");
Expect(1, 119366, '\P{ -GREEK}', "");
Expect(0, 119366, '\P{^ -GREEK}', "");
Error('\p{_ is_Greek:=}');
Error('\P{_ is_Greek:=}');
Expect(1, 119365, '\p{isgreek}', "");
Expect(0, 119365, '\p{^isgreek}', "");
Expect(0, 119365, '\P{isgreek}', "");
Expect(1, 119365, '\P{^isgreek}', "");
Expect(0, 119366, '\p{isgreek}', "");
Expect(1, 119366, '\p{^isgreek}', "");
Expect(1, 119366, '\P{isgreek}', "");
Expect(0, 119366, '\P{^isgreek}', "");
Expect(1, 119365, '\p{-is_Greek}', "");
Expect(0, 119365, '\p{^-is_Greek}', "");
Expect(0, 119365, '\P{-is_Greek}', "");
Expect(1, 119365, '\P{^-is_Greek}', "");
Expect(0, 119366, '\p{-is_Greek}', "");
Expect(1, 119366, '\p{^-is_Greek}', "");
Expect(1, 119366, '\P{-is_Greek}', "");
Expect(0, 119366, '\P{^-is_Greek}', "");
Error('\p{_:=Grek}');
Error('\P{_:=Grek}');
Expect(1, 119365, '\p{grek}', "");
Expect(0, 119365, '\p{^grek}', "");
Expect(0, 119365, '\P{grek}', "");
Expect(1, 119365, '\P{^grek}', "");
Expect(0, 119366, '\p{grek}', "");
Expect(1, 119366, '\p{^grek}', "");
Expect(1, 119366, '\P{grek}', "");
Expect(0, 119366, '\P{^grek}', "");
Expect(1, 119365, '\p{	GREK}', "");
Expect(0, 119365, '\p{^	GREK}', "");
Expect(0, 119365, '\P{	GREK}', "");
Expect(1, 119365, '\P{^	GREK}', "");
Expect(0, 119366, '\p{	GREK}', "");
Expect(1, 119366, '\p{^	GREK}', "");
Expect(1, 119366, '\P{	GREK}', "");
Expect(0, 119366, '\P{^	GREK}', "");
Error('\p{_ IS_Grek:=}');
Error('\P{_ IS_Grek:=}');
Expect(1, 119365, '\p{isgrek}', "");
Expect(0, 119365, '\p{^isgrek}', "");
Expect(0, 119365, '\P{isgrek}', "");
Expect(1, 119365, '\P{^isgrek}', "");
Expect(0, 119366, '\p{isgrek}', "");
Expect(1, 119366, '\p{^isgrek}', "");
Expect(1, 119366, '\P{isgrek}', "");
Expect(0, 119366, '\P{^isgrek}', "");
Expect(1, 119365, '\p{_ Is_Grek}', "");
Expect(0, 119365, '\p{^_ Is_Grek}', "");
Expect(0, 119365, '\P{_ Is_Grek}', "");
Expect(1, 119365, '\P{^_ Is_Grek}', "");
Expect(0, 119366, '\p{_ Is_Grek}', "");
Expect(1, 119366, '\p{^_ Is_Grek}', "");
Expect(1, 119366, '\P{_ Is_Grek}', "");
Expect(0, 119366, '\P{^_ Is_Grek}', "");
Error('\p{:=- greek_And_coptic}');
Error('\P{:=- greek_And_coptic}');
Expect(1, 1023, '\p{greekandcoptic}', "");
Expect(0, 1023, '\p{^greekandcoptic}', "");
Expect(0, 1023, '\P{greekandcoptic}', "");
Expect(1, 1023, '\P{^greekandcoptic}', "");
Expect(0, 1024, '\p{greekandcoptic}', "");
Expect(1, 1024, '\p{^greekandcoptic}', "");
Expect(1, 1024, '\P{greekandcoptic}', "");
Expect(0, 1024, '\P{^greekandcoptic}', "");
Expect(1, 1023, '\p{ Greek_And_coptic}', "");
Expect(0, 1023, '\p{^ Greek_And_coptic}', "");
Expect(0, 1023, '\P{ Greek_And_coptic}', "");
Expect(1, 1023, '\P{^ Greek_And_coptic}', "");
Expect(0, 1024, '\p{ Greek_And_coptic}', "");
Expect(1, 1024, '\p{^ Greek_And_coptic}', "");
Expect(1, 1024, '\P{ Greek_And_coptic}', "");
Expect(0, 1024, '\P{^ Greek_And_coptic}', "");
Error('\p{/a/ -Is_Greek_and_Coptic}');
Error('\P{/a/ -Is_Greek_and_Coptic}');
Expect(1, 1023, '\p{isgreekandcoptic}', "");
Expect(0, 1023, '\p{^isgreekandcoptic}', "");
Expect(0, 1023, '\P{isgreekandcoptic}', "");
Expect(1, 1023, '\P{^isgreekandcoptic}', "");
Expect(0, 1024, '\p{isgreekandcoptic}', "");
Expect(1, 1024, '\p{^isgreekandcoptic}', "");
Expect(1, 1024, '\P{isgreekandcoptic}', "");
Expect(0, 1024, '\P{^isgreekandcoptic}', "");
Expect(1, 1023, '\p{_-IS_Greek_And_coptic}', "");
Expect(0, 1023, '\p{^_-IS_Greek_And_coptic}', "");
Expect(0, 1023, '\P{_-IS_Greek_And_coptic}', "");
Expect(1, 1023, '\P{^_-IS_Greek_And_coptic}', "");
Expect(0, 1024, '\p{_-IS_Greek_And_coptic}', "");
Expect(1, 1024, '\p{^_-IS_Greek_And_coptic}', "");
Expect(1, 1024, '\P{_-IS_Greek_And_coptic}', "");
Expect(0, 1024, '\P{^_-IS_Greek_And_coptic}', "");
Error('\p{/a/ 	in_Greek_and_Coptic}');
Error('\P{/a/ 	in_Greek_and_Coptic}');
Expect(1, 1023, '\p{ingreekandcoptic}', "");
Expect(0, 1023, '\p{^ingreekandcoptic}', "");
Expect(0, 1023, '\P{ingreekandcoptic}', "");
Expect(1, 1023, '\P{^ingreekandcoptic}', "");
Expect(0, 1024, '\p{ingreekandcoptic}', "");
Expect(1, 1024, '\p{^ingreekandcoptic}', "");
Expect(1, 1024, '\P{ingreekandcoptic}', "");
Expect(0, 1024, '\P{^ingreekandcoptic}', "");
Expect(1, 1023, '\p{- IN_Greek_And_Coptic}', "");
Expect(0, 1023, '\p{^- IN_Greek_And_Coptic}', "");
Expect(0, 1023, '\P{- IN_Greek_And_Coptic}', "");
Expect(1, 1023, '\P{^- IN_Greek_And_Coptic}', "");
Expect(0, 1024, '\p{- IN_Greek_And_Coptic}', "");
Expect(1, 1024, '\p{^- IN_Greek_And_Coptic}', "");
Expect(1, 1024, '\P{- IN_Greek_And_Coptic}', "");
Expect(0, 1024, '\P{^- IN_Greek_And_Coptic}', "");
Error('\p{/a/in_greek}');
Error('\P{/a/in_greek}');
Expect(1, 1023, '\p{ingreek}', "");
Expect(0, 1023, '\p{^ingreek}', "");
Expect(0, 1023, '\P{ingreek}', "");
Expect(1, 1023, '\P{^ingreek}', "");
Expect(0, 1024, '\p{ingreek}', "");
Expect(1, 1024, '\p{^ingreek}', "");
Expect(1, 1024, '\P{ingreek}', "");
Expect(0, 1024, '\P{^ingreek}', "");
Expect(1, 1023, '\p{	-In_Greek}', "");
Expect(0, 1023, '\p{^	-In_Greek}', "");
Expect(0, 1023, '\P{	-In_Greek}', "");
Expect(1, 1023, '\P{^	-In_Greek}', "");
Expect(0, 1024, '\p{	-In_Greek}', "");
Expect(1, 1024, '\p{^	-In_Greek}', "");
Expect(1, 1024, '\P{	-In_Greek}', "");
Expect(0, 1024, '\P{^	-In_Greek}', "");
Error('\p{	/a/Greek_Extended}');
Error('\P{	/a/Greek_Extended}');
Expect(1, 8191, '\p{greekextended}', "");
Expect(0, 8191, '\p{^greekextended}', "");
Expect(0, 8191, '\P{greekextended}', "");
Expect(1, 8191, '\P{^greekextended}', "");
Expect(0, 8192, '\p{greekextended}', "");
Expect(1, 8192, '\p{^greekextended}', "");
Expect(1, 8192, '\P{greekextended}', "");
Expect(0, 8192, '\P{^greekextended}', "");
Expect(1, 8191, '\p{	 GREEK_Extended}', "");
Expect(0, 8191, '\p{^	 GREEK_Extended}', "");
Expect(0, 8191, '\P{	 GREEK_Extended}', "");
Expect(1, 8191, '\P{^	 GREEK_Extended}', "");
Expect(0, 8192, '\p{	 GREEK_Extended}', "");
Expect(1, 8192, '\p{^	 GREEK_Extended}', "");
Expect(1, 8192, '\P{	 GREEK_Extended}', "");
Expect(0, 8192, '\P{^	 GREEK_Extended}', "");
Error('\p{/a/is_Greek_Extended}');
Error('\P{/a/is_Greek_Extended}');
Expect(1, 8191, '\p{isgreekextended}', "");
Expect(0, 8191, '\p{^isgreekextended}', "");
Expect(0, 8191, '\P{isgreekextended}', "");
Expect(1, 8191, '\P{^isgreekextended}', "");
Expect(0, 8192, '\p{isgreekextended}', "");
Expect(1, 8192, '\p{^isgreekextended}', "");
Expect(1, 8192, '\P{isgreekextended}', "");
Expect(0, 8192, '\P{^isgreekextended}', "");
Expect(1, 8191, '\p{  IS_Greek_Extended}', "");
Expect(0, 8191, '\p{^  IS_Greek_Extended}', "");
Expect(0, 8191, '\P{  IS_Greek_Extended}', "");
Expect(1, 8191, '\P{^  IS_Greek_Extended}', "");
Expect(0, 8192, '\p{  IS_Greek_Extended}', "");
Expect(1, 8192, '\p{^  IS_Greek_Extended}', "");
Expect(1, 8192, '\P{  IS_Greek_Extended}', "");
Expect(0, 8192, '\P{^  IS_Greek_Extended}', "");
Error('\p{:=	 In_Greek_EXTENDED}');
Error('\P{:=	 In_Greek_EXTENDED}');
Expect(1, 8191, '\p{ingreekextended}', "");
Expect(0, 8191, '\p{^ingreekextended}', "");
Expect(0, 8191, '\P{ingreekextended}', "");
Expect(1, 8191, '\P{^ingreekextended}', "");
Expect(0, 8192, '\p{ingreekextended}', "");
Expect(1, 8192, '\p{^ingreekextended}', "");
Expect(1, 8192, '\P{ingreekextended}', "");
Expect(0, 8192, '\P{^ingreekextended}', "");
Expect(1, 8191, '\p{	In_Greek_Extended}', "");
Expect(0, 8191, '\p{^	In_Greek_Extended}', "");
Expect(0, 8191, '\P{	In_Greek_Extended}', "");
Expect(1, 8191, '\P{^	In_Greek_Extended}', "");
Expect(0, 8192, '\p{	In_Greek_Extended}', "");
Expect(1, 8192, '\p{^	In_Greek_Extended}', "");
Expect(1, 8192, '\P{	In_Greek_Extended}', "");
Expect(0, 8192, '\P{^	In_Greek_Extended}', "");
Error('\p{ _GREEK_ext/a/}');
Error('\P{ _GREEK_ext/a/}');
Expect(1, 8191, '\p{greekext}', "");
Expect(0, 8191, '\p{^greekext}', "");
Expect(0, 8191, '\P{greekext}', "");
Expect(1, 8191, '\P{^greekext}', "");
Expect(0, 8192, '\p{greekext}', "");
Expect(1, 8192, '\p{^greekext}', "");
Expect(1, 8192, '\P{greekext}', "");
Expect(0, 8192, '\P{^greekext}', "");
Expect(1, 8191, '\p{  Greek_EXT}', "");
Expect(0, 8191, '\p{^  Greek_EXT}', "");
Expect(0, 8191, '\P{  Greek_EXT}', "");
Expect(1, 8191, '\P{^  Greek_EXT}', "");
Expect(0, 8192, '\p{  Greek_EXT}', "");
Expect(1, 8192, '\p{^  Greek_EXT}', "");
Expect(1, 8192, '\P{  Greek_EXT}', "");
Expect(0, 8192, '\P{^  Greek_EXT}', "");
Error('\p{:=-IS_Greek_ext}');
Error('\P{:=-IS_Greek_ext}');
Expect(1, 8191, '\p{isgreekext}', "");
Expect(0, 8191, '\p{^isgreekext}', "");
Expect(0, 8191, '\P{isgreekext}', "");
Expect(1, 8191, '\P{^isgreekext}', "");
Expect(0, 8192, '\p{isgreekext}', "");
Expect(1, 8192, '\p{^isgreekext}', "");
Expect(1, 8192, '\P{isgreekext}', "");
Expect(0, 8192, '\P{^isgreekext}', "");
Expect(1, 8191, '\p{_ IS_Greek_ext}', "");
Expect(0, 8191, '\p{^_ IS_Greek_ext}', "");
Expect(0, 8191, '\P{_ IS_Greek_ext}', "");
Expect(1, 8191, '\P{^_ IS_Greek_ext}', "");
Expect(0, 8192, '\p{_ IS_Greek_ext}', "");
Expect(1, 8192, '\p{^_ IS_Greek_ext}', "");
Expect(1, 8192, '\P{_ IS_Greek_ext}', "");
Expect(0, 8192, '\P{^_ IS_Greek_ext}', "");
Error('\p{:=	 in_Greek_ext}');
Error('\P{:=	 in_Greek_ext}');
Expect(1, 8191, '\p{ingreekext}', "");
Expect(0, 8191, '\p{^ingreekext}', "");
Expect(0, 8191, '\P{ingreekext}', "");
Expect(1, 8191, '\P{^ingreekext}', "");
Expect(0, 8192, '\p{ingreekext}', "");
Expect(1, 8192, '\p{^ingreekext}', "");
Expect(1, 8192, '\P{ingreekext}', "");
Expect(0, 8192, '\P{^ingreekext}', "");
Expect(1, 8191, '\p{-	In_GREEK_EXT}', "");
Expect(0, 8191, '\p{^-	In_GREEK_EXT}', "");
Expect(0, 8191, '\P{-	In_GREEK_EXT}', "");
Expect(1, 8191, '\P{^-	In_GREEK_EXT}', "");
Expect(0, 8192, '\p{-	In_GREEK_EXT}', "");
Expect(1, 8192, '\p{^-	In_GREEK_EXT}', "");
Expect(1, 8192, '\P{-	In_GREEK_EXT}', "");
Expect(0, 8192, '\P{^-	In_GREEK_EXT}', "");
Error('\p{:=  GUJARATI}');
Error('\P{:=  GUJARATI}');
Expect(1, 2801, '\p{gujarati}', "");
Expect(0, 2801, '\p{^gujarati}', "");
Expect(0, 2801, '\P{gujarati}', "");
Expect(1, 2801, '\P{^gujarati}', "");
Expect(0, 2802, '\p{gujarati}', "");
Expect(1, 2802, '\p{^gujarati}', "");
Expect(1, 2802, '\P{gujarati}', "");
Expect(0, 2802, '\P{^gujarati}', "");
Expect(1, 2801, '\p{_Gujarati}', "");
Expect(0, 2801, '\p{^_Gujarati}', "");
Expect(0, 2801, '\P{_Gujarati}', "");
Expect(1, 2801, '\P{^_Gujarati}', "");
Expect(0, 2802, '\p{_Gujarati}', "");
Expect(1, 2802, '\p{^_Gujarati}', "");
Expect(1, 2802, '\P{_Gujarati}', "");
Expect(0, 2802, '\P{^_Gujarati}', "");
Error('\p{/a/IS_Gujarati}');
Error('\P{/a/IS_Gujarati}');
Expect(1, 2801, '\p{isgujarati}', "");
Expect(0, 2801, '\p{^isgujarati}', "");
Expect(0, 2801, '\P{isgujarati}', "");
Expect(1, 2801, '\P{^isgujarati}', "");
Expect(0, 2802, '\p{isgujarati}', "");
Expect(1, 2802, '\p{^isgujarati}', "");
Expect(1, 2802, '\P{isgujarati}', "");
Expect(0, 2802, '\P{^isgujarati}', "");
Expect(1, 2801, '\p{_ IS_Gujarati}', "");
Expect(0, 2801, '\p{^_ IS_Gujarati}', "");
Expect(0, 2801, '\P{_ IS_Gujarati}', "");
Expect(1, 2801, '\P{^_ IS_Gujarati}', "");
Expect(0, 2802, '\p{_ IS_Gujarati}', "");
Expect(1, 2802, '\p{^_ IS_Gujarati}', "");
Expect(1, 2802, '\P{_ IS_Gujarati}', "");
Expect(0, 2802, '\P{^_ IS_Gujarati}', "");
Error('\p{	:=Gujr}');
Error('\P{	:=Gujr}');
Expect(1, 2801, '\p{gujr}', "");
Expect(0, 2801, '\p{^gujr}', "");
Expect(0, 2801, '\P{gujr}', "");
Expect(1, 2801, '\P{^gujr}', "");
Expect(0, 2802, '\p{gujr}', "");
Expect(1, 2802, '\p{^gujr}', "");
Expect(1, 2802, '\P{gujr}', "");
Expect(0, 2802, '\P{^gujr}', "");
Expect(1, 2801, '\p{--GUJR}', "");
Expect(0, 2801, '\p{^--GUJR}', "");
Expect(0, 2801, '\P{--GUJR}', "");
Expect(1, 2801, '\P{^--GUJR}', "");
Expect(0, 2802, '\p{--GUJR}', "");
Expect(1, 2802, '\p{^--GUJR}', "");
Expect(1, 2802, '\P{--GUJR}', "");
Expect(0, 2802, '\P{^--GUJR}', "");
Error('\p{- Is_Gujr/a/}');
Error('\P{- Is_Gujr/a/}');
Expect(1, 2801, '\p{isgujr}', "");
Expect(0, 2801, '\p{^isgujr}', "");
Expect(0, 2801, '\P{isgujr}', "");
Expect(1, 2801, '\P{^isgujr}', "");
Expect(0, 2802, '\p{isgujr}', "");
Expect(1, 2802, '\p{^isgujr}', "");
Expect(1, 2802, '\P{isgujr}', "");
Expect(0, 2802, '\P{^isgujr}', "");
Expect(1, 2801, '\p{	Is_Gujr}', "");
Expect(0, 2801, '\p{^	Is_Gujr}', "");
Expect(0, 2801, '\P{	Is_Gujr}', "");
Expect(1, 2801, '\P{^	Is_Gujr}', "");
Expect(0, 2802, '\p{	Is_Gujr}', "");
Expect(1, 2802, '\p{^	Is_Gujr}', "");
Expect(1, 2802, '\P{	Is_Gujr}', "");
Expect(0, 2802, '\P{^	Is_Gujr}', "");
Error('\p{ /a/Gurmukhi}');
Error('\P{ /a/Gurmukhi}');
Expect(1, 2677, '\p{gurmukhi}', "");
Expect(0, 2677, '\p{^gurmukhi}', "");
Expect(0, 2677, '\P{gurmukhi}', "");
Expect(1, 2677, '\P{^gurmukhi}', "");
Expect(0, 2678, '\p{gurmukhi}', "");
Expect(1, 2678, '\p{^gurmukhi}', "");
Expect(1, 2678, '\P{gurmukhi}', "");
Expect(0, 2678, '\P{^gurmukhi}', "");
Expect(1, 2677, '\p{- GURMUKHI}', "");
Expect(0, 2677, '\p{^- GURMUKHI}', "");
Expect(0, 2677, '\P{- GURMUKHI}', "");
Expect(1, 2677, '\P{^- GURMUKHI}', "");
Expect(0, 2678, '\p{- GURMUKHI}', "");
Expect(1, 2678, '\p{^- GURMUKHI}', "");
Expect(1, 2678, '\P{- GURMUKHI}', "");
Expect(0, 2678, '\P{^- GURMUKHI}', "");
Error('\p{/a/	_IS_Gurmukhi}');
Error('\P{/a/	_IS_Gurmukhi}');
Expect(1, 2677, '\p{isgurmukhi}', "");
Expect(0, 2677, '\p{^isgurmukhi}', "");
Expect(0, 2677, '\P{isgurmukhi}', "");
Expect(1, 2677, '\P{^isgurmukhi}', "");
Expect(0, 2678, '\p{isgurmukhi}', "");
Expect(1, 2678, '\p{^isgurmukhi}', "");
Expect(1, 2678, '\P{isgurmukhi}', "");
Expect(0, 2678, '\P{^isgurmukhi}', "");
Expect(1, 2677, '\p{_IS_GURMUKHI}', "");
Expect(0, 2677, '\p{^_IS_GURMUKHI}', "");
Expect(0, 2677, '\P{_IS_GURMUKHI}', "");
Expect(1, 2677, '\P{^_IS_GURMUKHI}', "");
Expect(0, 2678, '\p{_IS_GURMUKHI}', "");
Expect(1, 2678, '\p{^_IS_GURMUKHI}', "");
Expect(1, 2678, '\P{_IS_GURMUKHI}', "");
Expect(0, 2678, '\P{^_IS_GURMUKHI}', "");
Error('\p{/a/	-Guru}');
Error('\P{/a/	-Guru}');
Expect(1, 2677, '\p{guru}', "");
Expect(0, 2677, '\p{^guru}', "");
Expect(0, 2677, '\P{guru}', "");
Expect(1, 2677, '\P{^guru}', "");
Expect(0, 2678, '\p{guru}', "");
Expect(1, 2678, '\p{^guru}', "");
Expect(1, 2678, '\P{guru}', "");
Expect(0, 2678, '\P{^guru}', "");
Expect(1, 2677, '\p{ Guru}', "");
Expect(0, 2677, '\p{^ Guru}', "");
Expect(0, 2677, '\P{ Guru}', "");
Expect(1, 2677, '\P{^ Guru}', "");
Expect(0, 2678, '\p{ Guru}', "");
Expect(1, 2678, '\p{^ Guru}', "");
Expect(1, 2678, '\P{ Guru}', "");
Expect(0, 2678, '\P{^ Guru}', "");
Error('\p{/a/	IS_guru}');
Error('\P{/a/	IS_guru}');
Expect(1, 2677, '\p{isguru}', "");
Expect(0, 2677, '\p{^isguru}', "");
Expect(0, 2677, '\P{isguru}', "");
Expect(1, 2677, '\P{^isguru}', "");
Expect(0, 2678, '\p{isguru}', "");
Expect(1, 2678, '\p{^isguru}', "");
Expect(1, 2678, '\P{isguru}', "");
Expect(0, 2678, '\P{^isguru}', "");
Expect(1, 2677, '\p{	Is_guru}', "");
Expect(0, 2677, '\p{^	Is_guru}', "");
Expect(0, 2677, '\P{	Is_guru}', "");
Expect(1, 2677, '\P{^	Is_guru}', "");
Expect(0, 2678, '\p{	Is_guru}', "");
Expect(1, 2678, '\p{^	Is_guru}', "");
Expect(1, 2678, '\P{	Is_guru}', "");
Expect(0, 2678, '\P{^	Is_guru}', "");
Error('\p{-_HALFWIDTH_And_Fullwidth_FORMS/a/}');
Error('\P{-_HALFWIDTH_And_Fullwidth_FORMS/a/}');
Expect(1, 65519, '\p{halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^halfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^halfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{halfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^halfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(0, 65519, '\p{^_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(0, 65519, '\P{_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(1, 65519, '\P{^_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(0, 65520, '\p{_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(1, 65520, '\p{^_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(1, 65520, '\P{_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Expect(0, 65520, '\P{^_HALFWIDTH_And_FULLWIDTH_FORMS}', "");
Error('\p{:=-	IS_halfwidth_And_FULLWIDTH_Forms}');
Error('\P{:=-	IS_halfwidth_And_FULLWIDTH_Forms}');
Expect(1, 65519, '\p{ishalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^ishalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{ishalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^ishalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{ishalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^ishalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{ishalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^ishalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(0, 65519, '\p{^_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(0, 65519, '\P{_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(1, 65519, '\P{^_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(0, 65520, '\p{_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(1, 65520, '\p{^_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(1, 65520, '\P{_-Is_halfwidth_And_fullwidth_Forms}', "");
Expect(0, 65520, '\P{^_-Is_halfwidth_And_fullwidth_Forms}', "");
Error('\p{ in_HALFWIDTH_and_Fullwidth_Forms/a/}');
Error('\P{ in_HALFWIDTH_and_Fullwidth_Forms/a/}');
Expect(1, 65519, '\p{inhalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\p{^inhalfwidthandfullwidthforms}', "");
Expect(0, 65519, '\P{inhalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\P{^inhalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\p{inhalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\p{^inhalfwidthandfullwidthforms}', "");
Expect(1, 65520, '\P{inhalfwidthandfullwidthforms}', "");
Expect(0, 65520, '\P{^inhalfwidthandfullwidthforms}', "");
Expect(1, 65519, '\p{- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(0, 65519, '\p{^- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(0, 65519, '\P{- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(1, 65519, '\P{^- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(0, 65520, '\p{- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(1, 65520, '\p{^- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(1, 65520, '\P{- IN_halfwidth_And_Fullwidth_Forms}', "");
Expect(0, 65520, '\P{^- IN_halfwidth_And_Fullwidth_Forms}', "");
Error('\p{:=-Half_And_Full_Forms}');
Error('\P{:=-Half_And_Full_Forms}');
Expect(1, 65519, '\p{halfandfullforms}', "");
Expect(0, 65519, '\p{^halfandfullforms}', "");
Expect(0, 65519, '\P{halfandfullforms}', "");
Expect(1, 65519, '\P{^halfandfullforms}', "");
Expect(0, 65520, '\p{halfandfullforms}', "");
Expect(1, 65520, '\p{^halfandfullforms}', "");
Expect(1, 65520, '\P{halfandfullforms}', "");
Expect(0, 65520, '\P{^halfandfullforms}', "");
Expect(1, 65519, '\p{	Half_AND_Full_forms}', "");
Expect(0, 65519, '\p{^	Half_AND_Full_forms}', "");
Expect(0, 65519, '\P{	Half_AND_Full_forms}', "");
Expect(1, 65519, '\P{^	Half_AND_Full_forms}', "");
Expect(0, 65520, '\p{	Half_AND_Full_forms}', "");
Expect(1, 65520, '\p{^	Half_AND_Full_forms}', "");
Expect(1, 65520, '\P{	Half_AND_Full_forms}', "");
Expect(0, 65520, '\P{^	Half_AND_Full_forms}', "");
Error('\p{:=	 Is_Half_And_full_FORMS}');
Error('\P{:=	 Is_Half_And_full_FORMS}');
Expect(1, 65519, '\p{ishalfandfullforms}', "");
Expect(0, 65519, '\p{^ishalfandfullforms}', "");
Expect(0, 65519, '\P{ishalfandfullforms}', "");
Expect(1, 65519, '\P{^ishalfandfullforms}', "");
Expect(0, 65520, '\p{ishalfandfullforms}', "");
Expect(1, 65520, '\p{^ishalfandfullforms}', "");
Expect(1, 65520, '\P{ishalfandfullforms}', "");
Expect(0, 65520, '\P{^ishalfandfullforms}', "");
Expect(1, 65519, '\p{ _is_half_and_Full_Forms}', "");
Expect(0, 65519, '\p{^ _is_half_and_Full_Forms}', "");
Expect(0, 65519, '\P{ _is_half_and_Full_Forms}', "");
Expect(1, 65519, '\P{^ _is_half_and_Full_Forms}', "");
Expect(0, 65520, '\p{ _is_half_and_Full_Forms}', "");
Expect(1, 65520, '\p{^ _is_half_and_Full_Forms}', "");
Expect(1, 65520, '\P{ _is_half_and_Full_Forms}', "");
Expect(0, 65520, '\P{^ _is_half_and_Full_Forms}', "");
Error('\p{-In_HALF_And_Full_Forms:=}');
Error('\P{-In_HALF_And_Full_Forms:=}');
Expect(1, 65519, '\p{inhalfandfullforms}', "");
Expect(0, 65519, '\p{^inhalfandfullforms}', "");
Expect(0, 65519, '\P{inhalfandfullforms}', "");
Expect(1, 65519, '\P{^inhalfandfullforms}', "");
Expect(0, 65520, '\p{inhalfandfullforms}', "");
Expect(1, 65520, '\p{^inhalfandfullforms}', "");
Expect(1, 65520, '\P{inhalfandfullforms}', "");
Expect(0, 65520, '\P{^inhalfandfullforms}', "");
Expect(1, 65519, '\p{-IN_HALF_And_FULL_Forms}', "");
Expect(0, 65519, '\p{^-IN_HALF_And_FULL_Forms}', "");
Expect(0, 65519, '\P{-IN_HALF_And_FULL_Forms}', "");
Expect(1, 65519, '\P{^-IN_HALF_And_FULL_Forms}', "");
Expect(0, 65520, '\p{-IN_HALF_And_FULL_Forms}', "");
Expect(1, 65520, '\p{^-IN_HALF_And_FULL_Forms}', "");
Expect(1, 65520, '\P{-IN_HALF_And_FULL_Forms}', "");
Expect(0, 65520, '\P{^-IN_HALF_And_FULL_Forms}', "");
Error('\p{:=		han}');
Error('\P{:=		han}');
Expect(1, 195101, '\p{han}', "");
Expect(0, 195101, '\p{^han}', "");
Expect(0, 195101, '\P{han}', "");
Expect(1, 195101, '\P{^han}', "");
Expect(0, 195102, '\p{han}', "");
Expect(1, 195102, '\p{^han}', "");
Expect(1, 195102, '\P{han}', "");
Expect(0, 195102, '\P{^han}', "");
Expect(1, 195101, '\p{__Han}', "");
Expect(0, 195101, '\p{^__Han}', "");
Expect(0, 195101, '\P{__Han}', "");
Expect(1, 195101, '\P{^__Han}', "");
Expect(0, 195102, '\p{__Han}', "");
Expect(1, 195102, '\p{^__Han}', "");
Expect(1, 195102, '\P{__Han}', "");
Expect(0, 195102, '\P{^__Han}', "");
Error('\p{ Is_han/a/}');
Error('\P{ Is_han/a/}');
Expect(1, 195101, '\p{ishan}', "");
Expect(0, 195101, '\p{^ishan}', "");
Expect(0, 195101, '\P{ishan}', "");
Expect(1, 195101, '\P{^ishan}', "");
Expect(0, 195102, '\p{ishan}', "");
Expect(1, 195102, '\p{^ishan}', "");
Expect(1, 195102, '\P{ishan}', "");
Expect(0, 195102, '\P{^ishan}', "");
Expect(1, 195101, '\p{_Is_HAN}', "");
Expect(0, 195101, '\p{^_Is_HAN}', "");
Expect(0, 195101, '\P{_Is_HAN}', "");
Expect(1, 195101, '\P{^_Is_HAN}', "");
Expect(0, 195102, '\p{_Is_HAN}', "");
Expect(1, 195102, '\p{^_Is_HAN}', "");
Expect(1, 195102, '\P{_Is_HAN}', "");
Expect(0, 195102, '\P{^_Is_HAN}', "");
Error('\p{/a/_HANI}');
Error('\P{/a/_HANI}');
Expect(1, 195101, '\p{hani}', "");
Expect(0, 195101, '\p{^hani}', "");
Expect(0, 195101, '\P{hani}', "");
Expect(1, 195101, '\P{^hani}', "");
Expect(0, 195102, '\p{hani}', "");
Expect(1, 195102, '\p{^hani}', "");
Expect(1, 195102, '\P{hani}', "");
Expect(0, 195102, '\P{^hani}', "");
Expect(1, 195101, '\p{ Hani}', "");
Expect(0, 195101, '\p{^ Hani}', "");
Expect(0, 195101, '\P{ Hani}', "");
Expect(1, 195101, '\P{^ Hani}', "");
Expect(0, 195102, '\p{ Hani}', "");
Expect(1, 195102, '\p{^ Hani}', "");
Expect(1, 195102, '\P{ Hani}', "");
Expect(0, 195102, '\P{^ Hani}', "");
Error('\p{/a/  is_HANI}');
Error('\P{/a/  is_HANI}');
Expect(1, 195101, '\p{ishani}', "");
Expect(0, 195101, '\p{^ishani}', "");
Expect(0, 195101, '\P{ishani}', "");
Expect(1, 195101, '\P{^ishani}', "");
Expect(0, 195102, '\p{ishani}', "");
Expect(1, 195102, '\p{^ishani}', "");
Expect(1, 195102, '\P{ishani}', "");
Expect(0, 195102, '\P{^ishani}', "");
Expect(1, 195101, '\p{is_HANI}', "");
Expect(0, 195101, '\p{^is_HANI}', "");
Expect(0, 195101, '\P{is_HANI}', "");
Expect(1, 195101, '\P{^is_HANI}', "");
Expect(0, 195102, '\p{is_HANI}', "");
Expect(1, 195102, '\p{^is_HANI}', "");
Expect(1, 195102, '\P{is_HANI}', "");
Expect(0, 195102, '\P{^is_HANI}', "");
Error('\p{_/a/HANGUL}');
Error('\P{_/a/HANGUL}');
Expect(1, 65500, '\p{hangul}', "");
Expect(0, 65500, '\p{^hangul}', "");
Expect(0, 65500, '\P{hangul}', "");
Expect(1, 65500, '\P{^hangul}', "");
Expect(0, 65501, '\p{hangul}', "");
Expect(1, 65501, '\p{^hangul}', "");
Expect(1, 65501, '\P{hangul}', "");
Expect(0, 65501, '\P{^hangul}', "");
Expect(1, 65500, '\p{-_Hangul}', "");
Expect(0, 65500, '\p{^-_Hangul}', "");
Expect(0, 65500, '\P{-_Hangul}', "");
Expect(1, 65500, '\P{^-_Hangul}', "");
Expect(0, 65501, '\p{-_Hangul}', "");
Expect(1, 65501, '\p{^-_Hangul}', "");
Expect(1, 65501, '\P{-_Hangul}', "");
Expect(0, 65501, '\P{^-_Hangul}', "");
Error('\p{_:=Is_HANGUL}');
Error('\P{_:=Is_HANGUL}');
Expect(1, 65500, '\p{ishangul}', "");
Expect(0, 65500, '\p{^ishangul}', "");
Expect(0, 65500, '\P{ishangul}', "");
Expect(1, 65500, '\P{^ishangul}', "");
Expect(0, 65501, '\p{ishangul}', "");
Expect(1, 65501, '\p{^ishangul}', "");
Expect(1, 65501, '\P{ishangul}', "");
Expect(0, 65501, '\P{^ishangul}', "");
Expect(1, 65500, '\p{- Is_Hangul}', "");
Expect(0, 65500, '\p{^- Is_Hangul}', "");
Expect(0, 65500, '\P{- Is_Hangul}', "");
Expect(1, 65500, '\P{^- Is_Hangul}', "");
Expect(0, 65501, '\p{- Is_Hangul}', "");
Expect(1, 65501, '\p{^- Is_Hangul}', "");
Expect(1, 65501, '\P{- Is_Hangul}', "");
Expect(0, 65501, '\P{^- Is_Hangul}', "");
Error('\p{:=	 Hang}');
Error('\P{:=	 Hang}');
Expect(1, 65500, '\p{hang}', "");
Expect(0, 65500, '\p{^hang}', "");
Expect(0, 65500, '\P{hang}', "");
Expect(1, 65500, '\P{^hang}', "");
Expect(0, 65501, '\p{hang}', "");
Expect(1, 65501, '\p{^hang}', "");
Expect(1, 65501, '\P{hang}', "");
Expect(0, 65501, '\P{^hang}', "");
Expect(1, 65500, '\p{		HANG}', "");
Expect(0, 65500, '\p{^		HANG}', "");
Expect(0, 65500, '\P{		HANG}', "");
Expect(1, 65500, '\P{^		HANG}', "");
Expect(0, 65501, '\p{		HANG}', "");
Expect(1, 65501, '\p{^		HANG}', "");
Expect(1, 65501, '\P{		HANG}', "");
Expect(0, 65501, '\P{^		HANG}', "");
Error('\p{:=	Is_Hang}');
Error('\P{:=	Is_Hang}');
Expect(1, 65500, '\p{ishang}', "");
Expect(0, 65500, '\p{^ishang}', "");
Expect(0, 65500, '\P{ishang}', "");
Expect(1, 65500, '\P{^ishang}', "");
Expect(0, 65501, '\p{ishang}', "");
Expect(1, 65501, '\p{^ishang}', "");
Expect(1, 65501, '\P{ishang}', "");
Expect(0, 65501, '\P{^ishang}', "");
Expect(1, 65500, '\p{-_is_Hang}', "");
Expect(0, 65500, '\p{^-_is_Hang}', "");
Expect(0, 65500, '\P{-_is_Hang}', "");
Expect(1, 65500, '\P{^-_is_Hang}', "");
Expect(0, 65501, '\p{-_is_Hang}', "");
Expect(1, 65501, '\p{^-_is_Hang}', "");
Expect(1, 65501, '\P{-_is_Hang}', "");
Expect(0, 65501, '\P{^-_is_Hang}', "");
Error('\p{/a/_-Hangul_Compatibility_Jamo}');
Error('\P{/a/_-Hangul_Compatibility_Jamo}');
Expect(1, 12687, '\p{hangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^hangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{hangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^hangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{hangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^hangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{hangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^hangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{	 Hangul_Compatibility_JAMO}', "");
Expect(0, 12687, '\p{^	 Hangul_Compatibility_JAMO}', "");
Expect(0, 12687, '\P{	 Hangul_Compatibility_JAMO}', "");
Expect(1, 12687, '\P{^	 Hangul_Compatibility_JAMO}', "");
Expect(0, 12688, '\p{	 Hangul_Compatibility_JAMO}', "");
Expect(1, 12688, '\p{^	 Hangul_Compatibility_JAMO}', "");
Expect(1, 12688, '\P{	 Hangul_Compatibility_JAMO}', "");
Expect(0, 12688, '\P{^	 Hangul_Compatibility_JAMO}', "");
Error('\p{:= -IS_hangul_Compatibility_Jamo}');
Error('\P{:= -IS_hangul_Compatibility_Jamo}');
Expect(1, 12687, '\p{ishangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^ishangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{ishangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^ishangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{ishangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^ishangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{ishangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^ishangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{_IS_Hangul_Compatibility_Jamo}', "");
Expect(0, 12687, '\p{^_IS_Hangul_Compatibility_Jamo}', "");
Expect(0, 12687, '\P{_IS_Hangul_Compatibility_Jamo}', "");
Expect(1, 12687, '\P{^_IS_Hangul_Compatibility_Jamo}', "");
Expect(0, 12688, '\p{_IS_Hangul_Compatibility_Jamo}', "");
Expect(1, 12688, '\p{^_IS_Hangul_Compatibility_Jamo}', "");
Expect(1, 12688, '\P{_IS_Hangul_Compatibility_Jamo}', "");
Expect(0, 12688, '\P{^_IS_Hangul_Compatibility_Jamo}', "");
Error('\p{	In_HANGUL_Compatibility_Jamo:=}');
Error('\P{	In_HANGUL_Compatibility_Jamo:=}');
Expect(1, 12687, '\p{inhangulcompatibilityjamo}', "");
Expect(0, 12687, '\p{^inhangulcompatibilityjamo}', "");
Expect(0, 12687, '\P{inhangulcompatibilityjamo}', "");
Expect(1, 12687, '\P{^inhangulcompatibilityjamo}', "");
Expect(0, 12688, '\p{inhangulcompatibilityjamo}', "");
Expect(1, 12688, '\p{^inhangulcompatibilityjamo}', "");
Expect(1, 12688, '\P{inhangulcompatibilityjamo}', "");
Expect(0, 12688, '\P{^inhangulcompatibilityjamo}', "");
Expect(1, 12687, '\p{-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(0, 12687, '\p{^-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(0, 12687, '\P{-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(1, 12687, '\P{^-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(0, 12688, '\p{-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(1, 12688, '\p{^-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(1, 12688, '\P{-in_Hangul_COMPATIBILITY_JAMO}', "");
Expect(0, 12688, '\P{^-in_Hangul_COMPATIBILITY_JAMO}', "");
Error('\p{-/a/compat_Jamo}');
Error('\P{-/a/compat_Jamo}');
Expect(1, 12687, '\p{compatjamo}', "");
Expect(0, 12687, '\p{^compatjamo}', "");
Expect(0, 12687, '\P{compatjamo}', "");
Expect(1, 12687, '\P{^compatjamo}', "");
Expect(0, 12688, '\p{compatjamo}', "");
Expect(1, 12688, '\p{^compatjamo}', "");
Expect(1, 12688, '\P{compatjamo}', "");
Expect(0, 12688, '\P{^compatjamo}', "");
Expect(1, 12687, '\p{-Compat_Jamo}', "");
Expect(0, 12687, '\p{^-Compat_Jamo}', "");
Expect(0, 12687, '\P{-Compat_Jamo}', "");
Expect(1, 12687, '\P{^-Compat_Jamo}', "");
Expect(0, 12688, '\p{-Compat_Jamo}', "");
Expect(1, 12688, '\p{^-Compat_Jamo}', "");
Expect(1, 12688, '\P{-Compat_Jamo}', "");
Expect(0, 12688, '\P{^-Compat_Jamo}', "");
Error('\p{/a/-	is_COMPAT_JAMO}');
Error('\P{/a/-	is_COMPAT_JAMO}');
Expect(1, 12687, '\p{iscompatjamo}', "");
Expect(0, 12687, '\p{^iscompatjamo}', "");
Expect(0, 12687, '\P{iscompatjamo}', "");
Expect(1, 12687, '\P{^iscompatjamo}', "");
Expect(0, 12688, '\p{iscompatjamo}', "");
Expect(1, 12688, '\p{^iscompatjamo}', "");
Expect(1, 12688, '\P{iscompatjamo}', "");
Expect(0, 12688, '\P{^iscompatjamo}', "");
Expect(1, 12687, '\p{ -is_compat_JAMO}', "");
Expect(0, 12687, '\p{^ -is_compat_JAMO}', "");
Expect(0, 12687, '\P{ -is_compat_JAMO}', "");
Expect(1, 12687, '\P{^ -is_compat_JAMO}', "");
Expect(0, 12688, '\p{ -is_compat_JAMO}', "");
Expect(1, 12688, '\p{^ -is_compat_JAMO}', "");
Expect(1, 12688, '\P{ -is_compat_JAMO}', "");
Expect(0, 12688, '\P{^ -is_compat_JAMO}', "");
Error('\p{-/a/IN_Compat_Jamo}');
Error('\P{-/a/IN_Compat_Jamo}');
Expect(1, 12687, '\p{incompatjamo}', "");
Expect(0, 12687, '\p{^incompatjamo}', "");
Expect(0, 12687, '\P{incompatjamo}', "");
Expect(1, 12687, '\P{^incompatjamo}', "");
Expect(0, 12688, '\p{incompatjamo}', "");
Expect(1, 12688, '\p{^incompatjamo}', "");
Expect(1, 12688, '\P{incompatjamo}', "");
Expect(0, 12688, '\P{^incompatjamo}', "");
Expect(1, 12687, '\p{	in_Compat_Jamo}', "");
Expect(0, 12687, '\p{^	in_Compat_Jamo}', "");
Expect(0, 12687, '\P{	in_Compat_Jamo}', "");
Expect(1, 12687, '\P{^	in_Compat_Jamo}', "");
Expect(0, 12688, '\p{	in_Compat_Jamo}', "");
Expect(1, 12688, '\p{^	in_Compat_Jamo}', "");
Expect(1, 12688, '\P{	in_Compat_Jamo}', "");
Expect(0, 12688, '\P{^	in_Compat_Jamo}', "");
Error('\p{	-Hangul_jamo:=}');
Error('\P{	-Hangul_jamo:=}');
Expect(1, 4607, '\p{hanguljamo}', "");
Expect(0, 4607, '\p{^hanguljamo}', "");
Expect(0, 4607, '\P{hanguljamo}', "");
Expect(1, 4607, '\P{^hanguljamo}', "");
Expect(0, 4608, '\p{hanguljamo}', "");
Expect(1, 4608, '\p{^hanguljamo}', "");
Expect(1, 4608, '\P{hanguljamo}', "");
Expect(0, 4608, '\P{^hanguljamo}', "");
Expect(1, 4607, '\p{	HANGUL_Jamo}', "");
Expect(0, 4607, '\p{^	HANGUL_Jamo}', "");
Expect(0, 4607, '\P{	HANGUL_Jamo}', "");
Expect(1, 4607, '\P{^	HANGUL_Jamo}', "");
Expect(0, 4608, '\p{	HANGUL_Jamo}', "");
Expect(1, 4608, '\p{^	HANGUL_Jamo}', "");
Expect(1, 4608, '\P{	HANGUL_Jamo}', "");
Expect(0, 4608, '\P{^	HANGUL_Jamo}', "");
Error('\p{_	Is_hangul_JAMO:=}');
Error('\P{_	Is_hangul_JAMO:=}');
Expect(1, 4607, '\p{ishanguljamo}', "");
Expect(0, 4607, '\p{^ishanguljamo}', "");
Expect(0, 4607, '\P{ishanguljamo}', "");
Expect(1, 4607, '\P{^ishanguljamo}', "");
Expect(0, 4608, '\p{ishanguljamo}', "");
Expect(1, 4608, '\p{^ishanguljamo}', "");
Expect(1, 4608, '\P{ishanguljamo}', "");
Expect(0, 4608, '\P{^ishanguljamo}', "");
Expect(1, 4607, '\p{- IS_Hangul_jamo}', "");
Expect(0, 4607, '\p{^- IS_Hangul_jamo}', "");
Expect(0, 4607, '\P{- IS_Hangul_jamo}', "");
Expect(1, 4607, '\P{^- IS_Hangul_jamo}', "");
Expect(0, 4608, '\p{- IS_Hangul_jamo}', "");
Expect(1, 4608, '\p{^- IS_Hangul_jamo}', "");
Expect(1, 4608, '\P{- IS_Hangul_jamo}', "");
Expect(0, 4608, '\P{^- IS_Hangul_jamo}', "");
Error('\p{:= In_Hangul_JAMO}');
Error('\P{:= In_Hangul_JAMO}');
Expect(1, 4607, '\p{inhanguljamo}', "");
Expect(0, 4607, '\p{^inhanguljamo}', "");
Expect(0, 4607, '\P{inhanguljamo}', "");
Expect(1, 4607, '\P{^inhanguljamo}', "");
Expect(0, 4608, '\p{inhanguljamo}', "");
Expect(1, 4608, '\p{^inhanguljamo}', "");
Expect(1, 4608, '\P{inhanguljamo}', "");
Expect(0, 4608, '\P{^inhanguljamo}', "");
Expect(1, 4607, '\p{	IN_Hangul_Jamo}', "");
Expect(0, 4607, '\p{^	IN_Hangul_Jamo}', "");
Expect(0, 4607, '\P{	IN_Hangul_Jamo}', "");
Expect(1, 4607, '\P{^	IN_Hangul_Jamo}', "");
Expect(0, 4608, '\p{	IN_Hangul_Jamo}', "");
Expect(1, 4608, '\p{^	IN_Hangul_Jamo}', "");
Expect(1, 4608, '\P{	IN_Hangul_Jamo}', "");
Expect(0, 4608, '\P{^	IN_Hangul_Jamo}', "");
Error('\p{ /a/Jamo}');
Error('\P{ /a/Jamo}');
Expect(1, 4607, '\p{jamo}', "");
Expect(0, 4607, '\p{^jamo}', "");
Expect(0, 4607, '\P{jamo}', "");
Expect(1, 4607, '\P{^jamo}', "");
Expect(0, 4608, '\p{jamo}', "");
Expect(1, 4608, '\p{^jamo}', "");
Expect(1, 4608, '\P{jamo}', "");
Expect(0, 4608, '\P{^jamo}', "");
Expect(1, 4607, '\p{	jamo}', "");
Expect(0, 4607, '\p{^	jamo}', "");
Expect(0, 4607, '\P{	jamo}', "");
Expect(1, 4607, '\P{^	jamo}', "");
Expect(0, 4608, '\p{	jamo}', "");
Expect(1, 4608, '\p{^	jamo}', "");
Expect(1, 4608, '\P{	jamo}', "");
Expect(0, 4608, '\P{^	jamo}', "");
Error('\p{ Is_Jamo/a/}');
Error('\P{ Is_Jamo/a/}');
Expect(1, 4607, '\p{isjamo}', "");
Expect(0, 4607, '\p{^isjamo}', "");
Expect(0, 4607, '\P{isjamo}', "");
Expect(1, 4607, '\P{^isjamo}', "");
Expect(0, 4608, '\p{isjamo}', "");
Expect(1, 4608, '\p{^isjamo}', "");
Expect(1, 4608, '\P{isjamo}', "");
Expect(0, 4608, '\P{^isjamo}', "");
Expect(1, 4607, '\p{-	IS_Jamo}', "");
Expect(0, 4607, '\p{^-	IS_Jamo}', "");
Expect(0, 4607, '\P{-	IS_Jamo}', "");
Expect(1, 4607, '\P{^-	IS_Jamo}', "");
Expect(0, 4608, '\p{-	IS_Jamo}', "");
Expect(1, 4608, '\p{^-	IS_Jamo}', "");
Expect(1, 4608, '\P{-	IS_Jamo}', "");
Expect(0, 4608, '\P{^-	IS_Jamo}', "");
Error('\p{/a/_	In_Jamo}');
Error('\P{/a/_	In_Jamo}');
Expect(1, 4607, '\p{injamo}', "");
Expect(0, 4607, '\p{^injamo}', "");
Expect(0, 4607, '\P{injamo}', "");
Expect(1, 4607, '\P{^injamo}', "");
Expect(0, 4608, '\p{injamo}', "");
Expect(1, 4608, '\p{^injamo}', "");
Expect(1, 4608, '\P{injamo}', "");
Expect(0, 4608, '\P{^injamo}', "");
Expect(1, 4607, '\p{_in_Jamo}', "");
Expect(0, 4607, '\p{^_in_Jamo}', "");
Expect(0, 4607, '\P{_in_Jamo}', "");
Expect(1, 4607, '\P{^_in_Jamo}', "");
Expect(0, 4608, '\p{_in_Jamo}', "");
Expect(1, 4608, '\p{^_in_Jamo}', "");
Expect(1, 4608, '\P{_in_Jamo}', "");
Expect(0, 4608, '\P{^_in_Jamo}', "");
Error('\p{- hangul_Jamo_EXTENDED_A:=}');
Error('\P{- hangul_Jamo_EXTENDED_A:=}');
Expect(1, 43391, '\p{hanguljamoextendeda}', "");
Expect(0, 43391, '\p{^hanguljamoextendeda}', "");
Expect(0, 43391, '\P{hanguljamoextendeda}', "");
Expect(1, 43391, '\P{^hanguljamoextendeda}', "");
Expect(0, 43392, '\p{hanguljamoextendeda}', "");
Expect(1, 43392, '\p{^hanguljamoextendeda}', "");
Expect(1, 43392, '\P{hanguljamoextendeda}', "");
Expect(0, 43392, '\P{^hanguljamoextendeda}', "");
Expect(1, 43391, '\p{_	Hangul_Jamo_extended_a}', "");
Expect(0, 43391, '\p{^_	Hangul_Jamo_extended_a}', "");
Expect(0, 43391, '\P{_	Hangul_Jamo_extended_a}', "");
Expect(1, 43391, '\P{^_	Hangul_Jamo_extended_a}', "");
Expect(0, 43392, '\p{_	Hangul_Jamo_extended_a}', "");
Expect(1, 43392, '\p{^_	Hangul_Jamo_extended_a}', "");
Expect(1, 43392, '\P{_	Hangul_Jamo_extended_a}', "");
Expect(0, 43392, '\P{^_	Hangul_Jamo_extended_a}', "");
Error('\p{	-Is_hangul_JAMO_Extended_A/a/}');
Error('\P{	-Is_hangul_JAMO_Extended_A/a/}');
Expect(1, 43391, '\p{ishanguljamoextendeda}', "");
Expect(0, 43391, '\p{^ishanguljamoextendeda}', "");
Expect(0, 43391, '\P{ishanguljamoextendeda}', "");
Expect(1, 43391, '\P{^ishanguljamoextendeda}', "");
Expect(0, 43392, '\p{ishanguljamoextendeda}', "");
Expect(1, 43392, '\p{^ishanguljamoextendeda}', "");
Expect(1, 43392, '\P{ishanguljamoextendeda}', "");
Expect(0, 43392, '\P{^ishanguljamoextendeda}', "");
Expect(1, 43391, '\p{__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(0, 43391, '\p{^__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(0, 43391, '\P{__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(1, 43391, '\P{^__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(0, 43392, '\p{__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(1, 43392, '\p{^__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(1, 43392, '\P{__is_Hangul_Jamo_EXTENDED_a}', "");
Expect(0, 43392, '\P{^__is_Hangul_Jamo_EXTENDED_a}', "");
Error('\p{	:=IN_Hangul_jamo_Extended_a}');
Error('\P{	:=IN_Hangul_jamo_Extended_a}');
Expect(1, 43391, '\p{inhanguljamoextendeda}', "");
Expect(0, 43391, '\p{^inhanguljamoextendeda}', "");
Expect(0, 43391, '\P{inhanguljamoextendeda}', "");
Expect(1, 43391, '\P{^inhanguljamoextendeda}', "");
Expect(0, 43392, '\p{inhanguljamoextendeda}', "");
Expect(1, 43392, '\p{^inhanguljamoextendeda}', "");
Expect(1, 43392, '\P{inhanguljamoextendeda}', "");
Expect(0, 43392, '\P{^inhanguljamoextendeda}', "");
Expect(1, 43391, '\p{	_In_Hangul_Jamo_extended_a}', "");
Expect(0, 43391, '\p{^	_In_Hangul_Jamo_extended_a}', "");
Expect(0, 43391, '\P{	_In_Hangul_Jamo_extended_a}', "");
Expect(1, 43391, '\P{^	_In_Hangul_Jamo_extended_a}', "");
Expect(0, 43392, '\p{	_In_Hangul_Jamo_extended_a}', "");
Expect(1, 43392, '\p{^	_In_Hangul_Jamo_extended_a}', "");
Expect(1, 43392, '\P{	_In_Hangul_Jamo_extended_a}', "");
Expect(0, 43392, '\P{^	_In_Hangul_Jamo_extended_a}', "");
Error('\p{_ Jamo_Ext_A:=}');
Error('\P{_ Jamo_Ext_A:=}');
Expect(1, 43391, '\p{jamoexta}', "");
Expect(0, 43391, '\p{^jamoexta}', "");
Expect(0, 43391, '\P{jamoexta}', "");
Expect(1, 43391, '\P{^jamoexta}', "");
Expect(0, 43392, '\p{jamoexta}', "");
Expect(1, 43392, '\p{^jamoexta}', "");
Expect(1, 43392, '\P{jamoexta}', "");
Expect(0, 43392, '\P{^jamoexta}', "");
Expect(1, 43391, '\p{ _Jamo_Ext_A}', "");
Expect(0, 43391, '\p{^ _Jamo_Ext_A}', "");
Expect(0, 43391, '\P{ _Jamo_Ext_A}', "");
Expect(1, 43391, '\P{^ _Jamo_Ext_A}', "");
Expect(0, 43392, '\p{ _Jamo_Ext_A}', "");
Expect(1, 43392, '\p{^ _Jamo_Ext_A}', "");
Expect(1, 43392, '\P{ _Jamo_Ext_A}', "");
Expect(0, 43392, '\P{^ _Jamo_Ext_A}', "");
Error('\p{:=is_JAMO_ext_A}');
Error('\P{:=is_JAMO_ext_A}');
Expect(1, 43391, '\p{isjamoexta}', "");
Expect(0, 43391, '\p{^isjamoexta}', "");
Expect(0, 43391, '\P{isjamoexta}', "");
Expect(1, 43391, '\P{^isjamoexta}', "");
Expect(0, 43392, '\p{isjamoexta}', "");
Expect(1, 43392, '\p{^isjamoexta}', "");
Expect(1, 43392, '\P{isjamoexta}', "");
Expect(0, 43392, '\P{^isjamoexta}', "");
Expect(1, 43391, '\p{	-is_Jamo_ext_A}', "");
Expect(0, 43391, '\p{^	-is_Jamo_ext_A}', "");
Expect(0, 43391, '\P{	-is_Jamo_ext_A}', "");
Expect(1, 43391, '\P{^	-is_Jamo_ext_A}', "");
Expect(0, 43392, '\p{	-is_Jamo_ext_A}', "");
Expect(1, 43392, '\p{^	-is_Jamo_ext_A}', "");
Expect(1, 43392, '\P{	-is_Jamo_ext_A}', "");
Expect(0, 43392, '\P{^	-is_Jamo_ext_A}', "");
Error('\p{:=_	In_Jamo_Ext_a}');
Error('\P{:=_	In_Jamo_Ext_a}');
Expect(1, 43391, '\p{injamoexta}', "");
Expect(0, 43391, '\p{^injamoexta}', "");
Expect(0, 43391, '\P{injamoexta}', "");
Expect(1, 43391, '\P{^injamoexta}', "");
Expect(0, 43392, '\p{injamoexta}', "");
Expect(1, 43392, '\p{^injamoexta}', "");
Expect(1, 43392, '\P{injamoexta}', "");
Expect(0, 43392, '\P{^injamoexta}', "");
Expect(1, 43391, '\p{_	In_jamo_Ext_A}', "");
Expect(0, 43391, '\p{^_	In_jamo_Ext_A}', "");
Expect(0, 43391, '\P{_	In_jamo_Ext_A}', "");
Expect(1, 43391, '\P{^_	In_jamo_Ext_A}', "");
Expect(0, 43392, '\p{_	In_jamo_Ext_A}', "");
Expect(1, 43392, '\p{^_	In_jamo_Ext_A}', "");
Expect(1, 43392, '\P{_	In_jamo_Ext_A}', "");
Expect(0, 43392, '\P{^_	In_jamo_Ext_A}', "");
Error('\p{:=	hangul_Jamo_Extended_B}');
Error('\P{:=	hangul_Jamo_Extended_B}');
Expect(1, 55295, '\p{hanguljamoextendedb}', "");
Expect(0, 55295, '\p{^hanguljamoextendedb}', "");
Expect(0, 55295, '\P{hanguljamoextendedb}', "");
Expect(1, 55295, '\P{^hanguljamoextendedb}', "");
Expect(0, 57344, '\p{hanguljamoextendedb}', "");
Expect(1, 57344, '\p{^hanguljamoextendedb}', "");
Expect(1, 57344, '\P{hanguljamoextendedb}', "");
Expect(0, 57344, '\P{^hanguljamoextendedb}', "");
Expect(1, 55295, '\p{	Hangul_Jamo_Extended_B}', "");
Expect(0, 55295, '\p{^	Hangul_Jamo_Extended_B}', "");
Expect(0, 55295, '\P{	Hangul_Jamo_Extended_B}', "");
Expect(1, 55295, '\P{^	Hangul_Jamo_Extended_B}', "");
Expect(0, 57344, '\p{	Hangul_Jamo_Extended_B}', "");
Expect(1, 57344, '\p{^	Hangul_Jamo_Extended_B}', "");
Expect(1, 57344, '\P{	Hangul_Jamo_Extended_B}', "");
Expect(0, 57344, '\P{^	Hangul_Jamo_Extended_B}', "");
Error('\p{ is_hangul_jamo_Extended_B/a/}');
Error('\P{ is_hangul_jamo_Extended_B/a/}');
Expect(1, 55295, '\p{ishanguljamoextendedb}', "");
Expect(0, 55295, '\p{^ishanguljamoextendedb}', "");
Expect(0, 55295, '\P{ishanguljamoextendedb}', "");
Expect(1, 55295, '\P{^ishanguljamoextendedb}', "");
Expect(0, 57344, '\p{ishanguljamoextendedb}', "");
Expect(1, 57344, '\p{^ishanguljamoextendedb}', "");
Expect(1, 57344, '\P{ishanguljamoextendedb}', "");
Expect(0, 57344, '\P{^ishanguljamoextendedb}', "");
Expect(1, 55295, '\p{	IS_Hangul_Jamo_Extended_B}', "");
Expect(0, 55295, '\p{^	IS_Hangul_Jamo_Extended_B}', "");
Expect(0, 55295, '\P{	IS_Hangul_Jamo_Extended_B}', "");
Expect(1, 55295, '\P{^	IS_Hangul_Jamo_Extended_B}', "");
Expect(0, 57344, '\p{	IS_Hangul_Jamo_Extended_B}', "");
Expect(1, 57344, '\p{^	IS_Hangul_Jamo_Extended_B}', "");
Expect(1, 57344, '\P{	IS_Hangul_Jamo_Extended_B}', "");
Expect(0, 57344, '\P{^	IS_Hangul_Jamo_Extended_B}', "");
Error('\p{/a/-In_HANGUL_JAMO_Extended_B}');
Error('\P{/a/-In_HANGUL_JAMO_Extended_B}');
Expect(1, 55295, '\p{inhanguljamoextendedb}', "");
Expect(0, 55295, '\p{^inhanguljamoextendedb}', "");
Expect(0, 55295, '\P{inhanguljamoextendedb}', "");
Expect(1, 55295, '\P{^inhanguljamoextendedb}', "");
Expect(0, 57344, '\p{inhanguljamoextendedb}', "");
Expect(1, 57344, '\p{^inhanguljamoextendedb}', "");
Expect(1, 57344, '\P{inhanguljamoextendedb}', "");
Expect(0, 57344, '\P{^inhanguljamoextendedb}', "");
Expect(1, 55295, '\p{-	In_hangul_JAMO_extended_b}', "");
Expect(0, 55295, '\p{^-	In_hangul_JAMO_extended_b}', "");
Expect(0, 55295, '\P{-	In_hangul_JAMO_extended_b}', "");
Expect(1, 55295, '\P{^-	In_hangul_JAMO_extended_b}', "");
Expect(0, 57344, '\p{-	In_hangul_JAMO_extended_b}', "");
Expect(1, 57344, '\p{^-	In_hangul_JAMO_extended_b}', "");
Expect(1, 57344, '\P{-	In_hangul_JAMO_extended_b}', "");
Expect(0, 57344, '\P{^-	In_hangul_JAMO_extended_b}', "");
Error('\p{	/a/jamo_EXT_b}');
Error('\P{	/a/jamo_EXT_b}');
Expect(1, 55295, '\p{jamoextb}', "");
Expect(0, 55295, '\p{^jamoextb}', "");
Expect(0, 55295, '\P{jamoextb}', "");
Expect(1, 55295, '\P{^jamoextb}', "");
Expect(0, 57344, '\p{jamoextb}', "");
Expect(1, 57344, '\p{^jamoextb}', "");
Expect(1, 57344, '\P{jamoextb}', "");
Expect(0, 57344, '\P{^jamoextb}', "");
Expect(1, 55295, '\p{Jamo_Ext_B}', "");
Expect(0, 55295, '\p{^Jamo_Ext_B}', "");
Expect(0, 55295, '\P{Jamo_Ext_B}', "");
Expect(1, 55295, '\P{^Jamo_Ext_B}', "");
Expect(0, 57344, '\p{Jamo_Ext_B}', "");
Expect(1, 57344, '\p{^Jamo_Ext_B}', "");
Expect(1, 57344, '\P{Jamo_Ext_B}', "");
Expect(0, 57344, '\P{^Jamo_Ext_B}', "");
Error('\p{	-Is_Jamo_EXT_B/a/}');
Error('\P{	-Is_Jamo_EXT_B/a/}');
Expect(1, 55295, '\p{isjamoextb}', "");
Expect(0, 55295, '\p{^isjamoextb}', "");
Expect(0, 55295, '\P{isjamoextb}', "");
Expect(1, 55295, '\P{^isjamoextb}', "");
Expect(0, 57344, '\p{isjamoextb}', "");
Expect(1, 57344, '\p{^isjamoextb}', "");
Expect(1, 57344, '\P{isjamoextb}', "");
Expect(0, 57344, '\P{^isjamoextb}', "");
Expect(1, 55295, '\p{_ Is_JAMO_Ext_B}', "");
Expect(0, 55295, '\p{^_ Is_JAMO_Ext_B}', "");
Expect(0, 55295, '\P{_ Is_JAMO_Ext_B}', "");
Expect(1, 55295, '\P{^_ Is_JAMO_Ext_B}', "");
Expect(0, 57344, '\p{_ Is_JAMO_Ext_B}', "");
Expect(1, 57344, '\p{^_ Is_JAMO_Ext_B}', "");
Expect(1, 57344, '\P{_ Is_JAMO_Ext_B}', "");
Expect(0, 57344, '\P{^_ Is_JAMO_Ext_B}', "");
Error('\p{  In_jamo_EXT_B/a/}');
Error('\P{  In_jamo_EXT_B/a/}');
Expect(1, 55295, '\p{injamoextb}', "");
Expect(0, 55295, '\p{^injamoextb}', "");
Expect(0, 55295, '\P{injamoextb}', "");
Expect(1, 55295, '\P{^injamoextb}', "");
Expect(0, 57344, '\p{injamoextb}', "");
Expect(1, 57344, '\p{^injamoextb}', "");
Expect(1, 57344, '\P{injamoextb}', "");
Expect(0, 57344, '\P{^injamoextb}', "");
Expect(1, 55295, '\p{-IN_jamo_EXT_b}', "");
Expect(0, 55295, '\p{^-IN_jamo_EXT_b}', "");
Expect(0, 55295, '\P{-IN_jamo_EXT_b}', "");
Expect(1, 55295, '\P{^-IN_jamo_EXT_b}', "");
Expect(0, 57344, '\p{-IN_jamo_EXT_b}', "");
Expect(1, 57344, '\p{^-IN_jamo_EXT_b}', "");
Expect(1, 57344, '\P{-IN_jamo_EXT_b}', "");
Expect(0, 57344, '\P{^-IN_jamo_EXT_b}', "");
Error('\p{:=	hangul_Syllables}');
Error('\P{:=	hangul_Syllables}');
Expect(1, 55215, '\p{hangulsyllables}', "");
Expect(0, 55215, '\p{^hangulsyllables}', "");
Expect(0, 55215, '\P{hangulsyllables}', "");
Expect(1, 55215, '\P{^hangulsyllables}', "");
Expect(0, 55216, '\p{hangulsyllables}', "");
Expect(1, 55216, '\p{^hangulsyllables}', "");
Expect(1, 55216, '\P{hangulsyllables}', "");
Expect(0, 55216, '\P{^hangulsyllables}', "");
Expect(1, 55215, '\p{ -Hangul_Syllables}', "");
Expect(0, 55215, '\p{^ -Hangul_Syllables}', "");
Expect(0, 55215, '\P{ -Hangul_Syllables}', "");
Expect(1, 55215, '\P{^ -Hangul_Syllables}', "");
Expect(0, 55216, '\p{ -Hangul_Syllables}', "");
Expect(1, 55216, '\p{^ -Hangul_Syllables}', "");
Expect(1, 55216, '\P{ -Hangul_Syllables}', "");
Expect(0, 55216, '\P{^ -Hangul_Syllables}', "");
Error('\p{_-Is_Hangul_SYLLABLES/a/}');
Error('\P{_-Is_Hangul_SYLLABLES/a/}');
Expect(1, 55215, '\p{ishangulsyllables}', "");
Expect(0, 55215, '\p{^ishangulsyllables}', "");
Expect(0, 55215, '\P{ishangulsyllables}', "");
Expect(1, 55215, '\P{^ishangulsyllables}', "");
Expect(0, 55216, '\p{ishangulsyllables}', "");
Expect(1, 55216, '\p{^ishangulsyllables}', "");
Expect(1, 55216, '\P{ishangulsyllables}', "");
Expect(0, 55216, '\P{^ishangulsyllables}', "");
Expect(1, 55215, '\p{ _is_Hangul_Syllables}', "");
Expect(0, 55215, '\p{^ _is_Hangul_Syllables}', "");
Expect(0, 55215, '\P{ _is_Hangul_Syllables}', "");
Expect(1, 55215, '\P{^ _is_Hangul_Syllables}', "");
Expect(0, 55216, '\p{ _is_Hangul_Syllables}', "");
Expect(1, 55216, '\p{^ _is_Hangul_Syllables}', "");
Expect(1, 55216, '\P{ _is_Hangul_Syllables}', "");
Expect(0, 55216, '\P{^ _is_Hangul_Syllables}', "");
Error('\p{_-IN_Hangul_syllables:=}');
Error('\P{_-IN_Hangul_syllables:=}');
Expect(1, 55215, '\p{inhangulsyllables}', "");
Expect(0, 55215, '\p{^inhangulsyllables}', "");
Expect(0, 55215, '\P{inhangulsyllables}', "");
Expect(1, 55215, '\P{^inhangulsyllables}', "");
Expect(0, 55216, '\p{inhangulsyllables}', "");
Expect(1, 55216, '\p{^inhangulsyllables}', "");
Expect(1, 55216, '\P{inhangulsyllables}', "");
Expect(0, 55216, '\P{^inhangulsyllables}', "");
Expect(1, 55215, '\p{ 	In_HANGUL_Syllables}', "");
Expect(0, 55215, '\p{^ 	In_HANGUL_Syllables}', "");
Expect(0, 55215, '\P{ 	In_HANGUL_Syllables}', "");
Expect(1, 55215, '\P{^ 	In_HANGUL_Syllables}', "");
Expect(0, 55216, '\p{ 	In_HANGUL_Syllables}', "");
Expect(1, 55216, '\p{^ 	In_HANGUL_Syllables}', "");
Expect(1, 55216, '\P{ 	In_HANGUL_Syllables}', "");
Expect(0, 55216, '\P{^ 	In_HANGUL_Syllables}', "");
Error('\p{ In_HANGUL:=}');
Error('\P{ In_HANGUL:=}');
Expect(1, 55215, '\p{inhangul}', "");
Expect(0, 55215, '\p{^inhangul}', "");
Expect(0, 55215, '\P{inhangul}', "");
Expect(1, 55215, '\P{^inhangul}', "");
Expect(0, 55216, '\p{inhangul}', "");
Expect(1, 55216, '\p{^inhangul}', "");
Expect(1, 55216, '\P{inhangul}', "");
Expect(0, 55216, '\P{^inhangul}', "");
Expect(1, 55215, '\p{	_In_hangul}', "");
Expect(0, 55215, '\p{^	_In_hangul}', "");
Expect(0, 55215, '\P{	_In_hangul}', "");
Expect(1, 55215, '\P{^	_In_hangul}', "");
Expect(0, 55216, '\p{	_In_hangul}', "");
Expect(1, 55216, '\p{^	_In_hangul}', "");
Expect(1, 55216, '\P{	_In_hangul}', "");
Expect(0, 55216, '\P{^	_In_hangul}', "");
Error('\p{_:=HANUNOO}');
Error('\P{_:=HANUNOO}');
Expect(1, 5940, '\p{hanunoo}', "");
Expect(0, 5940, '\p{^hanunoo}', "");
Expect(0, 5940, '\P{hanunoo}', "");
Expect(1, 5940, '\P{^hanunoo}', "");
Expect(0, 5941, '\p{hanunoo}', "");
Expect(1, 5941, '\p{^hanunoo}', "");
Expect(1, 5941, '\P{hanunoo}', "");
Expect(0, 5941, '\P{^hanunoo}', "");
Expect(1, 5940, '\p{_HANUNOO}', "");
Expect(0, 5940, '\p{^_HANUNOO}', "");
Expect(0, 5940, '\P{_HANUNOO}', "");
Expect(1, 5940, '\P{^_HANUNOO}', "");
Expect(0, 5941, '\p{_HANUNOO}', "");
Expect(1, 5941, '\p{^_HANUNOO}', "");
Expect(1, 5941, '\P{_HANUNOO}', "");
Expect(0, 5941, '\P{^_HANUNOO}', "");
Error('\p{/a/Is_hanunoo}');
Error('\P{/a/Is_hanunoo}');
Expect(1, 5940, '\p{ishanunoo}', "");
Expect(0, 5940, '\p{^ishanunoo}', "");
Expect(0, 5940, '\P{ishanunoo}', "");
Expect(1, 5940, '\P{^ishanunoo}', "");
Expect(0, 5941, '\p{ishanunoo}', "");
Expect(1, 5941, '\p{^ishanunoo}', "");
Expect(1, 5941, '\P{ishanunoo}', "");
Expect(0, 5941, '\P{^ishanunoo}', "");
Expect(1, 5940, '\p{	IS_HANUNOO}', "");
Expect(0, 5940, '\p{^	IS_HANUNOO}', "");
Expect(0, 5940, '\P{	IS_HANUNOO}', "");
Expect(1, 5940, '\P{^	IS_HANUNOO}', "");
Expect(0, 5941, '\p{	IS_HANUNOO}', "");
Expect(1, 5941, '\p{^	IS_HANUNOO}', "");
Expect(1, 5941, '\P{	IS_HANUNOO}', "");
Expect(0, 5941, '\P{^	IS_HANUNOO}', "");
Error('\p{	Hano:=}');
Error('\P{	Hano:=}');
Expect(1, 5940, '\p{hano}', "");
Expect(0, 5940, '\p{^hano}', "");
Expect(0, 5940, '\P{hano}', "");
Expect(1, 5940, '\P{^hano}', "");
Expect(0, 5941, '\p{hano}', "");
Expect(1, 5941, '\p{^hano}', "");
Expect(1, 5941, '\P{hano}', "");
Expect(0, 5941, '\P{^hano}', "");
Expect(1, 5940, '\p{	_Hano}', "");
Expect(0, 5940, '\p{^	_Hano}', "");
Expect(0, 5940, '\P{	_Hano}', "");
Expect(1, 5940, '\P{^	_Hano}', "");
Expect(0, 5941, '\p{	_Hano}', "");
Expect(1, 5941, '\p{^	_Hano}', "");
Expect(1, 5941, '\P{	_Hano}', "");
Expect(0, 5941, '\P{^	_Hano}', "");
Error('\p{_is_hano/a/}');
Error('\P{_is_hano/a/}');
Expect(1, 5940, '\p{ishano}', "");
Expect(0, 5940, '\p{^ishano}', "");
Expect(0, 5940, '\P{ishano}', "");
Expect(1, 5940, '\P{^ishano}', "");
Expect(0, 5941, '\p{ishano}', "");
Expect(1, 5941, '\p{^ishano}', "");
Expect(1, 5941, '\P{ishano}', "");
Expect(0, 5941, '\P{^ishano}', "");
Expect(1, 5940, '\p{  is_HANO}', "");
Expect(0, 5940, '\p{^  is_HANO}', "");
Expect(0, 5940, '\P{  is_HANO}', "");
Expect(1, 5940, '\P{^  is_HANO}', "");
Expect(0, 5941, '\p{  is_HANO}', "");
Expect(1, 5941, '\p{^  is_HANO}', "");
Expect(1, 5941, '\P{  is_HANO}', "");
Expect(0, 5941, '\P{^  is_HANO}', "");
Error('\p{- Hebrew/a/}');
Error('\P{- Hebrew/a/}');
Expect(1, 64335, '\p{hebrew}', "");
Expect(0, 64335, '\p{^hebrew}', "");
Expect(0, 64335, '\P{hebrew}', "");
Expect(1, 64335, '\P{^hebrew}', "");
Expect(0, 64336, '\p{hebrew}', "");
Expect(1, 64336, '\p{^hebrew}', "");
Expect(1, 64336, '\P{hebrew}', "");
Expect(0, 64336, '\P{^hebrew}', "");
Expect(1, 64335, '\p{-	Hebrew}', "");
Expect(0, 64335, '\p{^-	Hebrew}', "");
Expect(0, 64335, '\P{-	Hebrew}', "");
Expect(1, 64335, '\P{^-	Hebrew}', "");
Expect(0, 64336, '\p{-	Hebrew}', "");
Expect(1, 64336, '\p{^-	Hebrew}', "");
Expect(1, 64336, '\P{-	Hebrew}', "");
Expect(0, 64336, '\P{^-	Hebrew}', "");
Error('\p{-Is_Hebrew:=}');
Error('\P{-Is_Hebrew:=}');
Expect(1, 64335, '\p{ishebrew}', "");
Expect(0, 64335, '\p{^ishebrew}', "");
Expect(0, 64335, '\P{ishebrew}', "");
Expect(1, 64335, '\P{^ishebrew}', "");
Expect(0, 64336, '\p{ishebrew}', "");
Expect(1, 64336, '\p{^ishebrew}', "");
Expect(1, 64336, '\P{ishebrew}', "");
Expect(0, 64336, '\P{^ishebrew}', "");
Expect(1, 64335, '\p{is_Hebrew}', "");
Expect(0, 64335, '\p{^is_Hebrew}', "");
Expect(0, 64335, '\P{is_Hebrew}', "");
Expect(1, 64335, '\P{^is_Hebrew}', "");
Expect(0, 64336, '\p{is_Hebrew}', "");
Expect(1, 64336, '\p{^is_Hebrew}', "");
Expect(1, 64336, '\P{is_Hebrew}', "");
Expect(0, 64336, '\P{^is_Hebrew}', "");
Error('\p{/a/  HEBR}');
Error('\P{/a/  HEBR}');
Expect(1, 64335, '\p{hebr}', "");
Expect(0, 64335, '\p{^hebr}', "");
Expect(0, 64335, '\P{hebr}', "");
Expect(1, 64335, '\P{^hebr}', "");
Expect(0, 64336, '\p{hebr}', "");
Expect(1, 64336, '\p{^hebr}', "");
Expect(1, 64336, '\P{hebr}', "");
Expect(0, 64336, '\P{^hebr}', "");
Expect(1, 64335, '\p{	Hebr}', "");
Expect(0, 64335, '\p{^	Hebr}', "");
Expect(0, 64335, '\P{	Hebr}', "");
Expect(1, 64335, '\P{^	Hebr}', "");
Expect(0, 64336, '\p{	Hebr}', "");
Expect(1, 64336, '\p{^	Hebr}', "");
Expect(1, 64336, '\P{	Hebr}', "");
Expect(0, 64336, '\P{^	Hebr}', "");
Error('\p{/a/IS_HEBR}');
Error('\P{/a/IS_HEBR}');
Expect(1, 64335, '\p{ishebr}', "");
Expect(0, 64335, '\p{^ishebr}', "");
Expect(0, 64335, '\P{ishebr}', "");
Expect(1, 64335, '\P{^ishebr}', "");
Expect(0, 64336, '\p{ishebr}', "");
Expect(1, 64336, '\p{^ishebr}', "");
Expect(1, 64336, '\P{ishebr}', "");
Expect(0, 64336, '\P{^ishebr}', "");
Expect(1, 64335, '\p{ IS_hebr}', "");
Expect(0, 64335, '\p{^ IS_hebr}', "");
Expect(0, 64335, '\P{ IS_hebr}', "");
Expect(1, 64335, '\P{^ IS_hebr}', "");
Expect(0, 64336, '\p{ IS_hebr}', "");
Expect(1, 64336, '\p{^ IS_hebr}', "");
Expect(1, 64336, '\P{ IS_hebr}', "");
Expect(0, 64336, '\P{^ IS_hebr}', "");
Error('\p{	high_Private_use_surrogates/a/}');
Error('\P{	high_Private_use_surrogates/a/}');
Expect(1, 56319, '\p{highprivateusesurrogates}', "");
Expect(0, 56319, '\p{^highprivateusesurrogates}', "");
Expect(0, 56319, '\P{highprivateusesurrogates}', "");
Expect(1, 56319, '\P{^highprivateusesurrogates}', "");
Expect(0, 57344, '\p{highprivateusesurrogates}', "");
Expect(1, 57344, '\p{^highprivateusesurrogates}', "");
Expect(1, 57344, '\P{highprivateusesurrogates}', "");
Expect(0, 57344, '\P{^highprivateusesurrogates}', "");
Expect(1, 56319, '\p{_	High_Private_Use_Surrogates}', "");
Expect(0, 56319, '\p{^_	High_Private_Use_Surrogates}', "");
Expect(0, 56319, '\P{_	High_Private_Use_Surrogates}', "");
Expect(1, 56319, '\P{^_	High_Private_Use_Surrogates}', "");
Expect(0, 57344, '\p{_	High_Private_Use_Surrogates}', "");
Expect(1, 57344, '\p{^_	High_Private_Use_Surrogates}', "");
Expect(1, 57344, '\P{_	High_Private_Use_Surrogates}', "");
Expect(0, 57344, '\P{^_	High_Private_Use_Surrogates}', "");
Error('\p{-_Is_HIGH_Private_USE_surrogates:=}');
Error('\P{-_Is_HIGH_Private_USE_surrogates:=}');
Expect(1, 56319, '\p{ishighprivateusesurrogates}', "");
Expect(0, 56319, '\p{^ishighprivateusesurrogates}', "");
Expect(0, 56319, '\P{ishighprivateusesurrogates}', "");
Expect(1, 56319, '\P{^ishighprivateusesurrogates}', "");
Expect(0, 57344, '\p{ishighprivateusesurrogates}', "");
Expect(1, 57344, '\p{^ishighprivateusesurrogates}', "");
Expect(1, 57344, '\P{ishighprivateusesurrogates}', "");
Expect(0, 57344, '\P{^ishighprivateusesurrogates}', "");
Expect(1, 56319, '\p{ 	Is_High_Private_Use_surrogates}', "");
Expect(0, 56319, '\p{^ 	Is_High_Private_Use_surrogates}', "");
Expect(0, 56319, '\P{ 	Is_High_Private_Use_surrogates}', "");
Expect(1, 56319, '\P{^ 	Is_High_Private_Use_surrogates}', "");
Expect(0, 57344, '\p{ 	Is_High_Private_Use_surrogates}', "");
Expect(1, 57344, '\p{^ 	Is_High_Private_Use_surrogates}', "");
Expect(1, 57344, '\P{ 	Is_High_Private_Use_surrogates}', "");
Expect(0, 57344, '\P{^ 	Is_High_Private_Use_surrogates}', "");
Error('\p{	:=In_HIGH_Private_USE_surrogates}');
Error('\P{	:=In_HIGH_Private_USE_surrogates}');
Expect(1, 56319, '\p{inhighprivateusesurrogates}', "");
Expect(0, 56319, '\p{^inhighprivateusesurrogates}', "");
Expect(0, 56319, '\P{inhighprivateusesurrogates}', "");
Expect(1, 56319, '\P{^inhighprivateusesurrogates}', "");
Expect(0, 57344, '\p{inhighprivateusesurrogates}', "");
Expect(1, 57344, '\p{^inhighprivateusesurrogates}', "");
Expect(1, 57344, '\P{inhighprivateusesurrogates}', "");
Expect(0, 57344, '\P{^inhighprivateusesurrogates}', "");
Expect(1, 56319, '\p{ In_high_Private_use_SURROGATES}', "");
Expect(0, 56319, '\p{^ In_high_Private_use_SURROGATES}', "");
Expect(0, 56319, '\P{ In_high_Private_use_SURROGATES}', "");
Expect(1, 56319, '\P{^ In_high_Private_use_SURROGATES}', "");
Expect(0, 57344, '\p{ In_high_Private_use_SURROGATES}', "");
Expect(1, 57344, '\p{^ In_high_Private_use_SURROGATES}', "");
Expect(1, 57344, '\P{ In_high_Private_use_SURROGATES}', "");
Expect(0, 57344, '\P{^ In_high_Private_use_SURROGATES}', "");
Error('\p{  High_PU_Surrogates/a/}');
Error('\P{  High_PU_Surrogates/a/}');
Expect(1, 56319, '\p{highpusurrogates}', "");
Expect(0, 56319, '\p{^highpusurrogates}', "");
Expect(0, 56319, '\P{highpusurrogates}', "");
Expect(1, 56319, '\P{^highpusurrogates}', "");
Expect(0, 57344, '\p{highpusurrogates}', "");
Expect(1, 57344, '\p{^highpusurrogates}', "");
Expect(1, 57344, '\P{highpusurrogates}', "");
Expect(0, 57344, '\P{^highpusurrogates}', "");
Expect(1, 56319, '\p{ _high_PU_SURROGATES}', "");
Expect(0, 56319, '\p{^ _high_PU_SURROGATES}', "");
Expect(0, 56319, '\P{ _high_PU_SURROGATES}', "");
Expect(1, 56319, '\P{^ _high_PU_SURROGATES}', "");
Expect(0, 57344, '\p{ _high_PU_SURROGATES}', "");
Expect(1, 57344, '\p{^ _high_PU_SURROGATES}', "");
Expect(1, 57344, '\P{ _high_PU_SURROGATES}', "");
Expect(0, 57344, '\P{^ _high_PU_SURROGATES}', "");
Error('\p{__Is_high_pu_Surrogates:=}');
Error('\P{__Is_high_pu_Surrogates:=}');
Expect(1, 56319, '\p{ishighpusurrogates}', "");
Expect(0, 56319, '\p{^ishighpusurrogates}', "");
Expect(0, 56319, '\P{ishighpusurrogates}', "");
Expect(1, 56319, '\P{^ishighpusurrogates}', "");
Expect(0, 57344, '\p{ishighpusurrogates}', "");
Expect(1, 57344, '\p{^ishighpusurrogates}', "");
Expect(1, 57344, '\P{ishighpusurrogates}', "");
Expect(0, 57344, '\P{^ishighpusurrogates}', "");
Expect(1, 56319, '\p{- Is_High_PU_surrogates}', "");
Expect(0, 56319, '\p{^- Is_High_PU_surrogates}', "");
Expect(0, 56319, '\P{- Is_High_PU_surrogates}', "");
Expect(1, 56319, '\P{^- Is_High_PU_surrogates}', "");
Expect(0, 57344, '\p{- Is_High_PU_surrogates}', "");
Expect(1, 57344, '\p{^- Is_High_PU_surrogates}', "");
Expect(1, 57344, '\P{- Is_High_PU_surrogates}', "");
Expect(0, 57344, '\P{^- Is_High_PU_surrogates}', "");
Error('\p{/a/	_IN_HIGH_pu_Surrogates}');
Error('\P{/a/	_IN_HIGH_pu_Surrogates}');
Expect(1, 56319, '\p{inhighpusurrogates}', "");
Expect(0, 56319, '\p{^inhighpusurrogates}', "");
Expect(0, 56319, '\P{inhighpusurrogates}', "");
Expect(1, 56319, '\P{^inhighpusurrogates}', "");
Expect(0, 57344, '\p{inhighpusurrogates}', "");
Expect(1, 57344, '\p{^inhighpusurrogates}', "");
Expect(1, 57344, '\P{inhighpusurrogates}', "");
Expect(0, 57344, '\P{^inhighpusurrogates}', "");
Expect(1, 56319, '\p{_In_High_pu_Surrogates}', "");
Expect(0, 56319, '\p{^_In_High_pu_Surrogates}', "");
Expect(0, 56319, '\P{_In_High_pu_Surrogates}', "");
Expect(1, 56319, '\P{^_In_High_pu_Surrogates}', "");
Expect(0, 57344, '\p{_In_High_pu_Surrogates}', "");
Expect(1, 57344, '\p{^_In_High_pu_Surrogates}', "");
Expect(1, 57344, '\P{_In_High_pu_Surrogates}', "");
Expect(0, 57344, '\P{^_In_High_pu_Surrogates}', "");
Error('\p{/a/	_High_Surrogates}');
Error('\P{/a/	_High_Surrogates}');
Expect(1, 56191, '\p{highsurrogates}', "");
Expect(0, 56191, '\p{^highsurrogates}', "");
Expect(0, 56191, '\P{highsurrogates}', "");
Expect(1, 56191, '\P{^highsurrogates}', "");
Expect(0, 57344, '\p{highsurrogates}', "");
Expect(1, 57344, '\p{^highsurrogates}', "");
Expect(1, 57344, '\P{highsurrogates}', "");
Expect(0, 57344, '\P{^highsurrogates}', "");
Expect(1, 56191, '\p{_high_Surrogates}', "");
Expect(0, 56191, '\p{^_high_Surrogates}', "");
Expect(0, 56191, '\P{_high_Surrogates}', "");
Expect(1, 56191, '\P{^_high_Surrogates}', "");
Expect(0, 57344, '\p{_high_Surrogates}', "");
Expect(1, 57344, '\p{^_high_Surrogates}', "");
Expect(1, 57344, '\P{_high_Surrogates}', "");
Expect(0, 57344, '\P{^_high_Surrogates}', "");
Error('\p{/a/__is_high_surrogates}');
Error('\P{/a/__is_high_surrogates}');
Expect(1, 56191, '\p{ishighsurrogates}', "");
Expect(0, 56191, '\p{^ishighsurrogates}', "");
Expect(0, 56191, '\P{ishighsurrogates}', "");
Expect(1, 56191, '\P{^ishighsurrogates}', "");
Expect(0, 57344, '\p{ishighsurrogates}', "");
Expect(1, 57344, '\p{^ishighsurrogates}', "");
Expect(1, 57344, '\P{ishighsurrogates}', "");
Expect(0, 57344, '\P{^ishighsurrogates}', "");
Expect(1, 56191, '\p{	is_high_Surrogates}', "");
Expect(0, 56191, '\p{^	is_high_Surrogates}', "");
Expect(0, 56191, '\P{	is_high_Surrogates}', "");
Expect(1, 56191, '\P{^	is_high_Surrogates}', "");
Expect(0, 57344, '\p{	is_high_Surrogates}', "");
Expect(1, 57344, '\p{^	is_high_Surrogates}', "");
Expect(1, 57344, '\P{	is_high_Surrogates}', "");
Expect(0, 57344, '\P{^	is_high_Surrogates}', "");
Error('\p{:=IN_High_Surrogates}');
Error('\P{:=IN_High_Surrogates}');
Expect(1, 56191, '\p{inhighsurrogates}', "");
Expect(0, 56191, '\p{^inhighsurrogates}', "");
Expect(0, 56191, '\P{inhighsurrogates}', "");
Expect(1, 56191, '\P{^inhighsurrogates}', "");
Expect(0, 57344, '\p{inhighsurrogates}', "");
Expect(1, 57344, '\p{^inhighsurrogates}', "");
Expect(1, 57344, '\P{inhighsurrogates}', "");
Expect(0, 57344, '\P{^inhighsurrogates}', "");
Expect(1, 56191, '\p{_ in_High_Surrogates}', "");
Expect(0, 56191, '\p{^_ in_High_Surrogates}', "");
Expect(0, 56191, '\P{_ in_High_Surrogates}', "");
Expect(1, 56191, '\P{^_ in_High_Surrogates}', "");
Expect(0, 57344, '\p{_ in_High_Surrogates}', "");
Expect(1, 57344, '\p{^_ in_High_Surrogates}', "");
Expect(1, 57344, '\P{_ in_High_Surrogates}', "");
Expect(0, 57344, '\P{^_ in_High_Surrogates}', "");
Error('\p{Hiragana:=}');
Error('\P{Hiragana:=}');
Expect(1, 127488, '\p{hiragana}', "");
Expect(0, 127488, '\p{^hiragana}', "");
Expect(0, 127488, '\P{hiragana}', "");
Expect(1, 127488, '\P{^hiragana}', "");
Expect(0, 127489, '\p{hiragana}', "");
Expect(1, 127489, '\p{^hiragana}', "");
Expect(1, 127489, '\P{hiragana}', "");
Expect(0, 127489, '\P{^hiragana}', "");
Expect(1, 127488, '\p{_	Hiragana}', "");
Expect(0, 127488, '\p{^_	Hiragana}', "");
Expect(0, 127488, '\P{_	Hiragana}', "");
Expect(1, 127488, '\P{^_	Hiragana}', "");
Expect(0, 127489, '\p{_	Hiragana}', "");
Expect(1, 127489, '\p{^_	Hiragana}', "");
Expect(1, 127489, '\P{_	Hiragana}', "");
Expect(0, 127489, '\P{^_	Hiragana}', "");
Error('\p{/a/ _Is_Hiragana}');
Error('\P{/a/ _Is_Hiragana}');
Expect(1, 127488, '\p{ishiragana}', "");
Expect(0, 127488, '\p{^ishiragana}', "");
Expect(0, 127488, '\P{ishiragana}', "");
Expect(1, 127488, '\P{^ishiragana}', "");
Expect(0, 127489, '\p{ishiragana}', "");
Expect(1, 127489, '\p{^ishiragana}', "");
Expect(1, 127489, '\P{ishiragana}', "");
Expect(0, 127489, '\P{^ishiragana}', "");
Expect(1, 127488, '\p{ 	IS_Hiragana}', "");
Expect(0, 127488, '\p{^ 	IS_Hiragana}', "");
Expect(0, 127488, '\P{ 	IS_Hiragana}', "");
Expect(1, 127488, '\P{^ 	IS_Hiragana}', "");
Expect(0, 127489, '\p{ 	IS_Hiragana}', "");
Expect(1, 127489, '\p{^ 	IS_Hiragana}', "");
Expect(1, 127489, '\P{ 	IS_Hiragana}', "");
Expect(0, 127489, '\P{^ 	IS_Hiragana}', "");
Error('\p{:=- hira}');
Error('\P{:=- hira}');
Expect(1, 127488, '\p{hira}', "");
Expect(0, 127488, '\p{^hira}', "");
Expect(0, 127488, '\P{hira}', "");
Expect(1, 127488, '\P{^hira}', "");
Expect(0, 127489, '\p{hira}', "");
Expect(1, 127489, '\p{^hira}', "");
Expect(1, 127489, '\P{hira}', "");
Expect(0, 127489, '\P{^hira}', "");
Expect(1, 127488, '\p{	_hira}', "");
Expect(0, 127488, '\p{^	_hira}', "");
Expect(0, 127488, '\P{	_hira}', "");
Expect(1, 127488, '\P{^	_hira}', "");
Expect(0, 127489, '\p{	_hira}', "");
Expect(1, 127489, '\p{^	_hira}', "");
Expect(1, 127489, '\P{	_hira}', "");
Expect(0, 127489, '\P{^	_hira}', "");
Error('\p{  Is_Hira:=}');
Error('\P{  Is_Hira:=}');
Expect(1, 127488, '\p{ishira}', "");
Expect(0, 127488, '\p{^ishira}', "");
Expect(0, 127488, '\P{ishira}', "");
Expect(1, 127488, '\P{^ishira}', "");
Expect(0, 127489, '\p{ishira}', "");
Expect(1, 127489, '\p{^ishira}', "");
Expect(1, 127489, '\P{ishira}', "");
Expect(0, 127489, '\P{^ishira}', "");
Expect(1, 127488, '\p{_-IS_Hira}', "");
Expect(0, 127488, '\p{^_-IS_Hira}', "");
Expect(0, 127488, '\P{_-IS_Hira}', "");
Expect(1, 127488, '\P{^_-IS_Hira}', "");
Expect(0, 127489, '\p{_-IS_Hira}', "");
Expect(1, 127489, '\p{^_-IS_Hira}', "");
Expect(1, 127489, '\P{_-IS_Hira}', "");
Expect(0, 127489, '\P{^_-IS_Hira}', "");
Error('\p{__Hyphen:=}');
Error('\P{__Hyphen:=}');
Expect(1, 65381, '\p{hyphen}', 'deprecated');
Expect(0, 65381, '\p{^hyphen}', 'deprecated');
Expect(0, 65381, '\P{hyphen}', 'deprecated');
Expect(1, 65381, '\P{^hyphen}', 'deprecated');
Expect(0, 65382, '\p{hyphen}', 'deprecated');
Expect(1, 65382, '\p{^hyphen}', 'deprecated');
Expect(1, 65382, '\P{hyphen}', 'deprecated');
Expect(0, 65382, '\P{^hyphen}', 'deprecated');
Expect(1, 65381, '\p{_hyphen}', 'deprecated');
Expect(0, 65381, '\p{^_hyphen}', 'deprecated');
Expect(0, 65381, '\P{_hyphen}', 'deprecated');
Expect(1, 65381, '\P{^_hyphen}', 'deprecated');
Expect(0, 65382, '\p{_hyphen}', 'deprecated');
Expect(1, 65382, '\p{^_hyphen}', 'deprecated');
Expect(1, 65382, '\P{_hyphen}', 'deprecated');
Expect(0, 65382, '\P{^_hyphen}', 'deprecated');
Error('\p{_ IS_HYPHEN/a/}');
Error('\P{_ IS_HYPHEN/a/}');
Expect(1, 65381, '\p{ishyphen}', 'deprecated');
Expect(0, 65381, '\p{^ishyphen}', 'deprecated');
Expect(0, 65381, '\P{ishyphen}', 'deprecated');
Expect(1, 65381, '\P{^ishyphen}', 'deprecated');
Expect(0, 65382, '\p{ishyphen}', 'deprecated');
Expect(1, 65382, '\p{^ishyphen}', 'deprecated');
Expect(1, 65382, '\P{ishyphen}', 'deprecated');
Expect(0, 65382, '\P{^ishyphen}', 'deprecated');
Expect(1, 65381, '\p{_ Is_Hyphen}', 'deprecated');
Expect(0, 65381, '\p{^_ Is_Hyphen}', 'deprecated');
Expect(0, 65381, '\P{_ Is_Hyphen}', 'deprecated');
Expect(1, 65381, '\P{^_ Is_Hyphen}', 'deprecated');
Expect(0, 65382, '\p{_ Is_Hyphen}', 'deprecated');
Expect(1, 65382, '\p{^_ Is_Hyphen}', 'deprecated');
Expect(1, 65382, '\P{_ Is_Hyphen}', 'deprecated');
Expect(0, 65382, '\P{^_ Is_Hyphen}', 'deprecated');
Error('\p{	/a/IDS_binary_Operator}');
Error('\P{	/a/IDS_binary_Operator}');
Expect(1, 12283, '\p{idsbinaryoperator}', "");
Expect(0, 12283, '\p{^idsbinaryoperator}', "");
Expect(0, 12283, '\P{idsbinaryoperator}', "");
Expect(1, 12283, '\P{^idsbinaryoperator}', "");
Expect(0, 12284, '\p{idsbinaryoperator}', "");
Expect(1, 12284, '\p{^idsbinaryoperator}', "");
Expect(1, 12284, '\P{idsbinaryoperator}', "");
Expect(0, 12284, '\P{^idsbinaryoperator}', "");
Expect(1, 12283, '\p{__ids_binary_OPERATOR}', "");
Expect(0, 12283, '\p{^__ids_binary_OPERATOR}', "");
Expect(0, 12283, '\P{__ids_binary_OPERATOR}', "");
Expect(1, 12283, '\P{^__ids_binary_OPERATOR}', "");
Expect(0, 12284, '\p{__ids_binary_OPERATOR}', "");
Expect(1, 12284, '\p{^__ids_binary_OPERATOR}', "");
Expect(1, 12284, '\P{__ids_binary_OPERATOR}', "");
Expect(0, 12284, '\P{^__ids_binary_OPERATOR}', "");
Error('\p{_is_IDS_binary_operator/a/}');
Error('\P{_is_IDS_binary_operator/a/}');
Expect(1, 12283, '\p{isidsbinaryoperator}', "");
Expect(0, 12283, '\p{^isidsbinaryoperator}', "");
Expect(0, 12283, '\P{isidsbinaryoperator}', "");
Expect(1, 12283, '\P{^isidsbinaryoperator}', "");
Expect(0, 12284, '\p{isidsbinaryoperator}', "");
Expect(1, 12284, '\p{^isidsbinaryoperator}', "");
Expect(1, 12284, '\P{isidsbinaryoperator}', "");
Expect(0, 12284, '\P{^isidsbinaryoperator}', "");
Expect(1, 12283, '\p{	is_ids_binary_Operator}', "");
Expect(0, 12283, '\p{^	is_ids_binary_Operator}', "");
Expect(0, 12283, '\P{	is_ids_binary_Operator}', "");
Expect(1, 12283, '\P{^	is_ids_binary_Operator}', "");
Expect(0, 12284, '\p{	is_ids_binary_Operator}', "");
Expect(1, 12284, '\p{^	is_ids_binary_Operator}', "");
Expect(1, 12284, '\P{	is_ids_binary_Operator}', "");
Expect(0, 12284, '\P{^	is_ids_binary_Operator}', "");
Error('\p{:=	_IDSB}');
Error('\P{:=	_IDSB}');
Expect(1, 12283, '\p{idsb}', "");
Expect(0, 12283, '\p{^idsb}', "");
Expect(0, 12283, '\P{idsb}', "");
Expect(1, 12283, '\P{^idsb}', "");
Expect(0, 12284, '\p{idsb}', "");
Expect(1, 12284, '\p{^idsb}', "");
Expect(1, 12284, '\P{idsb}', "");
Expect(0, 12284, '\P{^idsb}', "");
Expect(1, 12283, '\p{_	IDSB}', "");
Expect(0, 12283, '\p{^_	IDSB}', "");
Expect(0, 12283, '\P{_	IDSB}', "");
Expect(1, 12283, '\P{^_	IDSB}', "");
Expect(0, 12284, '\p{_	IDSB}', "");
Expect(1, 12284, '\p{^_	IDSB}', "");
Expect(1, 12284, '\P{_	IDSB}', "");
Expect(0, 12284, '\P{^_	IDSB}', "");
Error('\p{ :=Is_IDSB}');
Error('\P{ :=Is_IDSB}');
Expect(1, 12283, '\p{isidsb}', "");
Expect(0, 12283, '\p{^isidsb}', "");
Expect(0, 12283, '\P{isidsb}', "");
Expect(1, 12283, '\P{^isidsb}', "");
Expect(0, 12284, '\p{isidsb}', "");
Expect(1, 12284, '\p{^isidsb}', "");
Expect(1, 12284, '\P{isidsb}', "");
Expect(0, 12284, '\P{^isidsb}', "");
Expect(1, 12283, '\p{- is_idsb}', "");
Expect(0, 12283, '\p{^- is_idsb}', "");
Expect(0, 12283, '\P{- is_idsb}', "");
Expect(1, 12283, '\P{^- is_idsb}', "");
Expect(0, 12284, '\p{- is_idsb}', "");
Expect(1, 12284, '\p{^- is_idsb}', "");
Expect(1, 12284, '\P{- is_idsb}', "");
Expect(0, 12284, '\P{^- is_idsb}', "");
Error('\p{-IDS_trinary_operator:=}');
Error('\P{-IDS_trinary_operator:=}');
Expect(1, 12275, '\p{idstrinaryoperator}', "");
Expect(0, 12275, '\p{^idstrinaryoperator}', "");
Expect(0, 12275, '\P{idstrinaryoperator}', "");
Expect(1, 12275, '\P{^idstrinaryoperator}', "");
Expect(0, 12276, '\p{idstrinaryoperator}', "");
Expect(1, 12276, '\p{^idstrinaryoperator}', "");
Expect(1, 12276, '\P{idstrinaryoperator}', "");
Expect(0, 12276, '\P{^idstrinaryoperator}', "");
Expect(1, 12275, '\p{-_IDS_Trinary_OPERATOR}', "");
Expect(0, 12275, '\p{^-_IDS_Trinary_OPERATOR}', "");
Expect(0, 12275, '\P{-_IDS_Trinary_OPERATOR}', "");
Expect(1, 12275, '\P{^-_IDS_Trinary_OPERATOR}', "");
Expect(0, 12276, '\p{-_IDS_Trinary_OPERATOR}', "");
Expect(1, 12276, '\p{^-_IDS_Trinary_OPERATOR}', "");
Expect(1, 12276, '\P{-_IDS_Trinary_OPERATOR}', "");
Expect(0, 12276, '\P{^-_IDS_Trinary_OPERATOR}', "");
Error('\p{:=-Is_IDS_trinary_Operator}');
Error('\P{:=-Is_IDS_trinary_Operator}');
Expect(1, 12275, '\p{isidstrinaryoperator}', "");
Expect(0, 12275, '\p{^isidstrinaryoperator}', "");
Expect(0, 12275, '\P{isidstrinaryoperator}', "");
Expect(1, 12275, '\P{^isidstrinaryoperator}', "");
Expect(0, 12276, '\p{isidstrinaryoperator}', "");
Expect(1, 12276, '\p{^isidstrinaryoperator}', "");
Expect(1, 12276, '\P{isidstrinaryoperator}', "");
Expect(0, 12276, '\P{^isidstrinaryoperator}', "");
Expect(1, 12275, '\p{	Is_IDS_Trinary_OPERATOR}', "");
Expect(0, 12275, '\p{^	Is_IDS_Trinary_OPERATOR}', "");
Expect(0, 12275, '\P{	Is_IDS_Trinary_OPERATOR}', "");
Expect(1, 12275, '\P{^	Is_IDS_Trinary_OPERATOR}', "");
Expect(0, 12276, '\p{	Is_IDS_Trinary_OPERATOR}', "");
Expect(1, 12276, '\p{^	Is_IDS_Trinary_OPERATOR}', "");
Expect(1, 12276, '\P{	Is_IDS_Trinary_OPERATOR}', "");
Expect(0, 12276, '\P{^	Is_IDS_Trinary_OPERATOR}', "");
Error('\p{	/a/IDST}');
Error('\P{	/a/IDST}');
Expect(1, 12275, '\p{idst}', "");
Expect(0, 12275, '\p{^idst}', "");
Expect(0, 12275, '\P{idst}', "");
Expect(1, 12275, '\P{^idst}', "");
Expect(0, 12276, '\p{idst}', "");
Expect(1, 12276, '\p{^idst}', "");
Expect(1, 12276, '\P{idst}', "");
Expect(0, 12276, '\P{^idst}', "");
Expect(1, 12275, '\p{	IDST}', "");
Expect(0, 12275, '\p{^	IDST}', "");
Expect(0, 12275, '\P{	IDST}', "");
Expect(1, 12275, '\P{^	IDST}', "");
Expect(0, 12276, '\p{	IDST}', "");
Expect(1, 12276, '\p{^	IDST}', "");
Expect(1, 12276, '\P{	IDST}', "");
Expect(0, 12276, '\P{^	IDST}', "");
Error('\p{		IS_IDST/a/}');
Error('\P{		IS_IDST/a/}');
Expect(1, 12275, '\p{isidst}', "");
Expect(0, 12275, '\p{^isidst}', "");
Expect(0, 12275, '\P{isidst}', "");
Expect(1, 12275, '\P{^isidst}', "");
Expect(0, 12276, '\p{isidst}', "");
Expect(1, 12276, '\p{^isidst}', "");
Expect(1, 12276, '\P{isidst}', "");
Expect(0, 12276, '\P{^isidst}', "");
Expect(1, 12275, '\p{Is_IDST}', "");
Expect(0, 12275, '\p{^Is_IDST}', "");
Expect(0, 12275, '\P{Is_IDST}', "");
Expect(1, 12275, '\P{^Is_IDST}', "");
Expect(0, 12276, '\p{Is_IDST}', "");
Expect(1, 12276, '\p{^Is_IDST}', "");
Expect(1, 12276, '\P{Is_IDST}', "");
Expect(0, 12276, '\P{^Is_IDST}', "");
Error('\p{:=	_ID_Continue}');
Error('\P{:=	_ID_Continue}');
Expect(1, 917999, '\p{idcontinue}', "");
Expect(0, 917999, '\p{^idcontinue}', "");
Expect(0, 917999, '\P{idcontinue}', "");
Expect(1, 917999, '\P{^idcontinue}', "");
Expect(0, 918000, '\p{idcontinue}', "");
Expect(1, 918000, '\p{^idcontinue}', "");
Expect(1, 918000, '\P{idcontinue}', "");
Expect(0, 918000, '\P{^idcontinue}', "");
Expect(1, 917999, '\p{ -ID_CONTINUE}', "");
Expect(0, 917999, '\p{^ -ID_CONTINUE}', "");
Expect(0, 917999, '\P{ -ID_CONTINUE}', "");
Expect(1, 917999, '\P{^ -ID_CONTINUE}', "");
Expect(0, 918000, '\p{ -ID_CONTINUE}', "");
Expect(1, 918000, '\p{^ -ID_CONTINUE}', "");
Expect(1, 918000, '\P{ -ID_CONTINUE}', "");
Expect(0, 918000, '\P{^ -ID_CONTINUE}', "");
Error('\p{:=_ Is_id_continue}');
Error('\P{:=_ Is_id_continue}');
Expect(1, 917999, '\p{isidcontinue}', "");
Expect(0, 917999, '\p{^isidcontinue}', "");
Expect(0, 917999, '\P{isidcontinue}', "");
Expect(1, 917999, '\P{^isidcontinue}', "");
Expect(0, 918000, '\p{isidcontinue}', "");
Expect(1, 918000, '\p{^isidcontinue}', "");
Expect(1, 918000, '\P{isidcontinue}', "");
Expect(0, 918000, '\P{^isidcontinue}', "");
Expect(1, 917999, '\p{_	IS_ID_CONTINUE}', "");
Expect(0, 917999, '\p{^_	IS_ID_CONTINUE}', "");
Expect(0, 917999, '\P{_	IS_ID_CONTINUE}', "");
Expect(1, 917999, '\P{^_	IS_ID_CONTINUE}', "");
Expect(0, 918000, '\p{_	IS_ID_CONTINUE}', "");
Expect(1, 918000, '\p{^_	IS_ID_CONTINUE}', "");
Expect(1, 918000, '\P{_	IS_ID_CONTINUE}', "");
Expect(0, 918000, '\P{^_	IS_ID_CONTINUE}', "");
Error('\p{/a/idc}');
Error('\P{/a/idc}');
Expect(1, 917999, '\p{idc}', "");
Expect(0, 917999, '\p{^idc}', "");
Expect(0, 917999, '\P{idc}', "");
Expect(1, 917999, '\P{^idc}', "");
Expect(0, 918000, '\p{idc}', "");
Expect(1, 918000, '\p{^idc}', "");
Expect(1, 918000, '\P{idc}', "");
Expect(0, 918000, '\P{^idc}', "");
Expect(1, 917999, '\p{_ IDC}', "");
Expect(0, 917999, '\p{^_ IDC}', "");
Expect(0, 917999, '\P{_ IDC}', "");
Expect(1, 917999, '\P{^_ IDC}', "");
Expect(0, 918000, '\p{_ IDC}', "");
Expect(1, 918000, '\p{^_ IDC}', "");
Expect(1, 918000, '\P{_ IDC}', "");
Expect(0, 918000, '\P{^_ IDC}', "");
Error('\p{ /a/Is_IDC}');
Error('\P{ /a/Is_IDC}');
Expect(1, 917999, '\p{isidc}', "");
Expect(0, 917999, '\p{^isidc}', "");
Expect(0, 917999, '\P{isidc}', "");
Expect(1, 917999, '\P{^isidc}', "");
Expect(0, 918000, '\p{isidc}', "");
Expect(1, 918000, '\p{^isidc}', "");
Expect(1, 918000, '\P{isidc}', "");
Expect(0, 918000, '\P{^isidc}', "");
Expect(1, 917999, '\p{	Is_idc}', "");
Expect(0, 917999, '\p{^	Is_idc}', "");
Expect(0, 917999, '\P{	Is_idc}', "");
Expect(1, 917999, '\P{^	Is_idc}', "");
Expect(0, 918000, '\p{	Is_idc}', "");
Expect(1, 918000, '\p{^	Is_idc}', "");
Expect(1, 918000, '\P{	Is_idc}', "");
Expect(0, 918000, '\P{^	Is_idc}', "");
Error('\p{ :=ID_START}');
Error('\P{ :=ID_START}');
Expect(1, 195101, '\p{idstart}', "");
Expect(0, 195101, '\p{^idstart}', "");
Expect(0, 195101, '\P{idstart}', "");
Expect(1, 195101, '\P{^idstart}', "");
Expect(0, 195102, '\p{idstart}', "");
Expect(1, 195102, '\p{^idstart}', "");
Expect(1, 195102, '\P{idstart}', "");
Expect(0, 195102, '\P{^idstart}', "");
Expect(1, 195101, '\p{__ID_Start}', "");
Expect(0, 195101, '\p{^__ID_Start}', "");
Expect(0, 195101, '\P{__ID_Start}', "");
Expect(1, 195101, '\P{^__ID_Start}', "");
Expect(0, 195102, '\p{__ID_Start}', "");
Expect(1, 195102, '\p{^__ID_Start}', "");
Expect(1, 195102, '\P{__ID_Start}', "");
Expect(0, 195102, '\P{^__ID_Start}', "");
Error('\p{	/a/is_ID_start}');
Error('\P{	/a/is_ID_start}');
Expect(1, 195101, '\p{isidstart}', "");
Expect(0, 195101, '\p{^isidstart}', "");
Expect(0, 195101, '\P{isidstart}', "");
Expect(1, 195101, '\P{^isidstart}', "");
Expect(0, 195102, '\p{isidstart}', "");
Expect(1, 195102, '\p{^isidstart}', "");
Expect(1, 195102, '\P{isidstart}', "");
Expect(0, 195102, '\P{^isidstart}', "");
Expect(1, 195101, '\p{-	IS_ID_Start}', "");
Expect(0, 195101, '\p{^-	IS_ID_Start}', "");
Expect(0, 195101, '\P{-	IS_ID_Start}', "");
Expect(1, 195101, '\P{^-	IS_ID_Start}', "");
Expect(0, 195102, '\p{-	IS_ID_Start}', "");
Expect(1, 195102, '\p{^-	IS_ID_Start}', "");
Expect(1, 195102, '\P{-	IS_ID_Start}', "");
Expect(0, 195102, '\P{^-	IS_ID_Start}', "");
Error('\p{/a/_ IDS}');
Error('\P{/a/_ IDS}');
Expect(1, 195101, '\p{ids}', "");
Expect(0, 195101, '\p{^ids}', "");
Expect(0, 195101, '\P{ids}', "");
Expect(1, 195101, '\P{^ids}', "");
Expect(0, 195102, '\p{ids}', "");
Expect(1, 195102, '\p{^ids}', "");
Expect(1, 195102, '\P{ids}', "");
Expect(0, 195102, '\P{^ids}', "");
Expect(1, 195101, '\p{	_ids}', "");
Expect(0, 195101, '\p{^	_ids}', "");
Expect(0, 195101, '\P{	_ids}', "");
Expect(1, 195101, '\P{^	_ids}', "");
Expect(0, 195102, '\p{	_ids}', "");
Expect(1, 195102, '\p{^	_ids}', "");
Expect(1, 195102, '\P{	_ids}', "");
Expect(0, 195102, '\P{^	_ids}', "");
Error('\p{/a/ Is_IDS}');
Error('\P{/a/ Is_IDS}');
Expect(1, 195101, '\p{isids}', "");
Expect(0, 195101, '\p{^isids}', "");
Expect(0, 195101, '\P{isids}', "");
Expect(1, 195101, '\P{^isids}', "");
Expect(0, 195102, '\p{isids}', "");
Expect(1, 195102, '\p{^isids}', "");
Expect(1, 195102, '\P{isids}', "");
Expect(0, 195102, '\P{^isids}', "");
Expect(1, 195101, '\p{__IS_IDS}', "");
Expect(0, 195101, '\p{^__IS_IDS}', "");
Expect(0, 195101, '\P{__IS_IDS}', "");
Expect(1, 195101, '\P{^__IS_IDS}', "");
Expect(0, 195102, '\p{__IS_IDS}', "");
Expect(1, 195102, '\p{^__IS_IDS}', "");
Expect(1, 195102, '\P{__IS_IDS}', "");
Expect(0, 195102, '\P{^__IS_IDS}', "");
Error('\p{ -IPA_EXTENSIONS/a/}');
Error('\P{ -IPA_EXTENSIONS/a/}');
Expect(1, 687, '\p{ipaextensions}', "");
Expect(0, 687, '\p{^ipaextensions}', "");
Expect(0, 687, '\P{ipaextensions}', "");
Expect(1, 687, '\P{^ipaextensions}', "");
Expect(0, 688, '\p{ipaextensions}', "");
Expect(1, 688, '\p{^ipaextensions}', "");
Expect(1, 688, '\P{ipaextensions}', "");
Expect(0, 688, '\P{^ipaextensions}', "");
Expect(1, 687, '\p{		IPA_Extensions}', "");
Expect(0, 687, '\p{^		IPA_Extensions}', "");
Expect(0, 687, '\P{		IPA_Extensions}', "");
Expect(1, 687, '\P{^		IPA_Extensions}', "");
Expect(0, 688, '\p{		IPA_Extensions}', "");
Expect(1, 688, '\p{^		IPA_Extensions}', "");
Expect(1, 688, '\P{		IPA_Extensions}', "");
Expect(0, 688, '\P{^		IPA_Extensions}', "");
Error('\p{/a/_-is_IPA_extensions}');
Error('\P{/a/_-is_IPA_extensions}');
Expect(1, 687, '\p{isipaextensions}', "");
Expect(0, 687, '\p{^isipaextensions}', "");
Expect(0, 687, '\P{isipaextensions}', "");
Expect(1, 687, '\P{^isipaextensions}', "");
Expect(0, 688, '\p{isipaextensions}', "");
Expect(1, 688, '\p{^isipaextensions}', "");
Expect(1, 688, '\P{isipaextensions}', "");
Expect(0, 688, '\P{^isipaextensions}', "");
Expect(1, 687, '\p{	Is_IPA_Extensions}', "");
Expect(0, 687, '\p{^	Is_IPA_Extensions}', "");
Expect(0, 687, '\P{	Is_IPA_Extensions}', "");
Expect(1, 687, '\P{^	Is_IPA_Extensions}', "");
Expect(0, 688, '\p{	Is_IPA_Extensions}', "");
Expect(1, 688, '\p{^	Is_IPA_Extensions}', "");
Expect(1, 688, '\P{	Is_IPA_Extensions}', "");
Expect(0, 688, '\P{^	Is_IPA_Extensions}', "");
Error('\p{/a/in_IPA_Extensions}');
Error('\P{/a/in_IPA_Extensions}');
Expect(1, 687, '\p{inipaextensions}', "");
Expect(0, 687, '\p{^inipaextensions}', "");
Expect(0, 687, '\P{inipaextensions}', "");
Expect(1, 687, '\P{^inipaextensions}', "");
Expect(0, 688, '\p{inipaextensions}', "");
Expect(1, 688, '\p{^inipaextensions}', "");
Expect(1, 688, '\P{inipaextensions}', "");
Expect(0, 688, '\P{^inipaextensions}', "");
Expect(1, 687, '\p{_-IN_IPA_EXTENSIONS}', "");
Expect(0, 687, '\p{^_-IN_IPA_EXTENSIONS}', "");
Expect(0, 687, '\P{_-IN_IPA_EXTENSIONS}', "");
Expect(1, 687, '\P{^_-IN_IPA_EXTENSIONS}', "");
Expect(0, 688, '\p{_-IN_IPA_EXTENSIONS}', "");
Expect(1, 688, '\p{^_-IN_IPA_EXTENSIONS}', "");
Expect(1, 688, '\P{_-IN_IPA_EXTENSIONS}', "");
Expect(0, 688, '\P{^_-IN_IPA_EXTENSIONS}', "");
Error('\p{/a/-_IPA_ext}');
Error('\P{/a/-_IPA_ext}');
Expect(1, 687, '\p{ipaext}', "");
Expect(0, 687, '\p{^ipaext}', "");
Expect(0, 687, '\P{ipaext}', "");
Expect(1, 687, '\P{^ipaext}', "");
Expect(0, 688, '\p{ipaext}', "");
Expect(1, 688, '\p{^ipaext}', "");
Expect(1, 688, '\P{ipaext}', "");
Expect(0, 688, '\P{^ipaext}', "");
Expect(1, 687, '\p{	-IPA_ext}', "");
Expect(0, 687, '\p{^	-IPA_ext}', "");
Expect(0, 687, '\P{	-IPA_ext}', "");
Expect(1, 687, '\P{^	-IPA_ext}', "");
Expect(0, 688, '\p{	-IPA_ext}', "");
Expect(1, 688, '\p{^	-IPA_ext}', "");
Expect(1, 688, '\P{	-IPA_ext}', "");
Expect(0, 688, '\P{^	-IPA_ext}', "");
Error('\p{ :=is_IPA_EXT}');
Error('\P{ :=is_IPA_EXT}');
Expect(1, 687, '\p{isipaext}', "");
Expect(0, 687, '\p{^isipaext}', "");
Expect(0, 687, '\P{isipaext}', "");
Expect(1, 687, '\P{^isipaext}', "");
Expect(0, 688, '\p{isipaext}', "");
Expect(1, 688, '\p{^isipaext}', "");
Expect(1, 688, '\P{isipaext}', "");
Expect(0, 688, '\P{^isipaext}', "");
Expect(1, 687, '\p{ is_IPA_ext}', "");
Expect(0, 687, '\p{^ is_IPA_ext}', "");
Expect(0, 687, '\P{ is_IPA_ext}', "");
Expect(1, 687, '\P{^ is_IPA_ext}', "");
Expect(0, 688, '\p{ is_IPA_ext}', "");
Expect(1, 688, '\p{^ is_IPA_ext}', "");
Expect(1, 688, '\P{ is_IPA_ext}', "");
Expect(0, 688, '\P{^ is_IPA_ext}', "");
Error('\p{:=-In_IPA_EXT}');
Error('\P{:=-In_IPA_EXT}');
Expect(1, 687, '\p{inipaext}', "");
Expect(0, 687, '\p{^inipaext}', "");
Expect(0, 687, '\P{inipaext}', "");
Expect(1, 687, '\P{^inipaext}', "");
Expect(0, 688, '\p{inipaext}', "");
Expect(1, 688, '\p{^inipaext}', "");
Expect(1, 688, '\P{inipaext}', "");
Expect(0, 688, '\P{^inipaext}', "");
Expect(1, 687, '\p{__In_IPA_ext}', "");
Expect(0, 687, '\p{^__In_IPA_ext}', "");
Expect(0, 687, '\P{__In_IPA_ext}', "");
Expect(1, 687, '\P{^__In_IPA_ext}', "");
Expect(0, 688, '\p{__In_IPA_ext}', "");
Expect(1, 688, '\p{^__In_IPA_ext}', "");
Expect(1, 688, '\P{__In_IPA_ext}', "");
Expect(0, 688, '\P{^__In_IPA_ext}', "");
Error('\p{_IDEOGRAPHIC/a/}');
Error('\P{_IDEOGRAPHIC/a/}');
Expect(1, 195101, '\p{ideographic}', "");
Expect(0, 195101, '\p{^ideographic}', "");
Expect(0, 195101, '\P{ideographic}', "");
Expect(1, 195101, '\P{^ideographic}', "");
Expect(0, 195102, '\p{ideographic}', "");
Expect(1, 195102, '\p{^ideographic}', "");
Expect(1, 195102, '\P{ideographic}', "");
Expect(0, 195102, '\P{^ideographic}', "");
Expect(1, 195101, '\p{	IDEOGRAPHIC}', "");
Expect(0, 195101, '\p{^	IDEOGRAPHIC}', "");
Expect(0, 195101, '\P{	IDEOGRAPHIC}', "");
Expect(1, 195101, '\P{^	IDEOGRAPHIC}', "");
Expect(0, 195102, '\p{	IDEOGRAPHIC}', "");
Expect(1, 195102, '\p{^	IDEOGRAPHIC}', "");
Expect(1, 195102, '\P{	IDEOGRAPHIC}', "");
Expect(0, 195102, '\P{^	IDEOGRAPHIC}', "");
Error('\p{:=-_is_IDEOGRAPHIC}');
Error('\P{:=-_is_IDEOGRAPHIC}');
Expect(1, 195101, '\p{isideographic}', "");
Expect(0, 195101, '\p{^isideographic}', "");
Expect(0, 195101, '\P{isideographic}', "");
Expect(1, 195101, '\P{^isideographic}', "");
Expect(0, 195102, '\p{isideographic}', "");
Expect(1, 195102, '\p{^isideographic}', "");
Expect(1, 195102, '\P{isideographic}', "");
Expect(0, 195102, '\P{^isideographic}', "");
Expect(1, 195101, '\p{-_Is_ideographic}', "");
Expect(0, 195101, '\p{^-_Is_ideographic}', "");
Expect(0, 195101, '\P{-_Is_ideographic}', "");
Expect(1, 195101, '\P{^-_Is_ideographic}', "");
Expect(0, 195102, '\p{-_Is_ideographic}', "");
Expect(1, 195102, '\p{^-_Is_ideographic}', "");
Expect(1, 195102, '\P{-_Is_ideographic}', "");
Expect(0, 195102, '\P{^-_Is_ideographic}', "");
Error('\p{_:=Ideo}');
Error('\P{_:=Ideo}');
Expect(1, 195101, '\p{ideo}', "");
Expect(0, 195101, '\p{^ideo}', "");
Expect(0, 195101, '\P{ideo}', "");
Expect(1, 195101, '\P{^ideo}', "");
Expect(0, 195102, '\p{ideo}', "");
Expect(1, 195102, '\p{^ideo}', "");
Expect(1, 195102, '\P{ideo}', "");
Expect(0, 195102, '\P{^ideo}', "");
Expect(1, 195101, '\p{	_IDEO}', "");
Expect(0, 195101, '\p{^	_IDEO}', "");
Expect(0, 195101, '\P{	_IDEO}', "");
Expect(1, 195101, '\P{^	_IDEO}', "");
Expect(0, 195102, '\p{	_IDEO}', "");
Expect(1, 195102, '\p{^	_IDEO}', "");
Expect(1, 195102, '\P{	_IDEO}', "");
Expect(0, 195102, '\P{^	_IDEO}', "");
Error('\p{:=_ IS_Ideo}');
Error('\P{:=_ IS_Ideo}');
Expect(1, 195101, '\p{isideo}', "");
Expect(0, 195101, '\p{^isideo}', "");
Expect(0, 195101, '\P{isideo}', "");
Expect(1, 195101, '\P{^isideo}', "");
Expect(0, 195102, '\p{isideo}', "");
Expect(1, 195102, '\p{^isideo}', "");
Expect(1, 195102, '\P{isideo}', "");
Expect(0, 195102, '\P{^isideo}', "");
Expect(1, 195101, '\p{	_IS_IDEO}', "");
Expect(0, 195101, '\p{^	_IS_IDEO}', "");
Expect(0, 195101, '\P{	_IS_IDEO}', "");
Expect(1, 195101, '\P{^	_IS_IDEO}', "");
Expect(0, 195102, '\p{	_IS_IDEO}', "");
Expect(1, 195102, '\p{^	_IS_IDEO}', "");
Expect(1, 195102, '\P{	_IS_IDEO}', "");
Expect(0, 195102, '\P{^	_IS_IDEO}', "");
Error('\p{_/a/IDEOGRAPHIC_description_Characters}');
Error('\P{_/a/IDEOGRAPHIC_description_Characters}');
Expect(1, 12287, '\p{ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^ideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^ideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{ideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^ideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{		Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12287, '\p{^		Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12287, '\P{		Ideographic_DESCRIPTION_Characters}', "");
Expect(1, 12287, '\P{^		Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12288, '\p{		Ideographic_DESCRIPTION_Characters}', "");
Expect(1, 12288, '\p{^		Ideographic_DESCRIPTION_Characters}', "");
Expect(1, 12288, '\P{		Ideographic_DESCRIPTION_Characters}', "");
Expect(0, 12288, '\P{^		Ideographic_DESCRIPTION_Characters}', "");
Error('\p{:=is_ideographic_Description_characters}');
Error('\P{:=is_ideographic_Description_characters}');
Expect(1, 12287, '\p{isideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^isideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{isideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^isideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{isideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^isideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{isideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^isideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{-IS_Ideographic_description_CHARACTERS}', "");
Expect(0, 12287, '\p{^-IS_Ideographic_description_CHARACTERS}', "");
Expect(0, 12287, '\P{-IS_Ideographic_description_CHARACTERS}', "");
Expect(1, 12287, '\P{^-IS_Ideographic_description_CHARACTERS}', "");
Expect(0, 12288, '\p{-IS_Ideographic_description_CHARACTERS}', "");
Expect(1, 12288, '\p{^-IS_Ideographic_description_CHARACTERS}', "");
Expect(1, 12288, '\P{-IS_Ideographic_description_CHARACTERS}', "");
Expect(0, 12288, '\P{^-IS_Ideographic_description_CHARACTERS}', "");
Error('\p{:=_IN_Ideographic_Description_Characters}');
Error('\P{:=_IN_Ideographic_Description_Characters}');
Expect(1, 12287, '\p{inideographicdescriptioncharacters}', "");
Expect(0, 12287, '\p{^inideographicdescriptioncharacters}', "");
Expect(0, 12287, '\P{inideographicdescriptioncharacters}', "");
Expect(1, 12287, '\P{^inideographicdescriptioncharacters}', "");
Expect(0, 12288, '\p{inideographicdescriptioncharacters}', "");
Expect(1, 12288, '\p{^inideographicdescriptioncharacters}', "");
Expect(1, 12288, '\P{inideographicdescriptioncharacters}', "");
Expect(0, 12288, '\P{^inideographicdescriptioncharacters}', "");
Expect(1, 12287, '\p{ In_Ideographic_Description_characters}', "");
Expect(0, 12287, '\p{^ In_Ideographic_Description_characters}', "");
Expect(0, 12287, '\P{ In_Ideographic_Description_characters}', "");
Expect(1, 12287, '\P{^ In_Ideographic_Description_characters}', "");
Expect(0, 12288, '\p{ In_Ideographic_Description_characters}', "");
Expect(1, 12288, '\p{^ In_Ideographic_Description_characters}', "");
Expect(1, 12288, '\P{ In_Ideographic_Description_characters}', "");
Expect(0, 12288, '\P{^ In_Ideographic_Description_characters}', "");
Error('\p{:=	in_idc}');
Error('\P{:=	in_idc}');
Expect(1, 12287, '\p{inidc}', "");
Expect(0, 12287, '\p{^inidc}', "");
Expect(0, 12287, '\P{inidc}', "");
Expect(1, 12287, '\P{^inidc}', "");
Expect(0, 12288, '\p{inidc}', "");
Expect(1, 12288, '\p{^inidc}', "");
Expect(1, 12288, '\P{inidc}', "");
Expect(0, 12288, '\P{^inidc}', "");
Expect(1, 12287, '\p{	IN_IDC}', "");
Expect(0, 12287, '\p{^	IN_IDC}', "");
Expect(0, 12287, '\P{	IN_IDC}', "");
Expect(1, 12287, '\P{^	IN_IDC}', "");
Expect(0, 12288, '\p{	IN_IDC}', "");
Expect(1, 12288, '\p{^	IN_IDC}', "");
Expect(1, 12288, '\P{	IN_IDC}', "");
Expect(0, 12288, '\P{^	IN_IDC}', "");
Error('\p{_/a/Imperial_ARAMAIC}');
Error('\P{_/a/Imperial_ARAMAIC}');
Expect(1, 67679, '\p{imperialaramaic}', "");
Expect(0, 67679, '\p{^imperialaramaic}', "");
Expect(0, 67679, '\P{imperialaramaic}', "");
Expect(1, 67679, '\P{^imperialaramaic}', "");
Expect(0, 67680, '\p{imperialaramaic}', "");
Expect(1, 67680, '\p{^imperialaramaic}', "");
Expect(1, 67680, '\P{imperialaramaic}', "");
Expect(0, 67680, '\P{^imperialaramaic}', "");
Expect(1, 67679, '\p{		IMPERIAL_ARAMAIC}', "");
Expect(0, 67679, '\p{^		IMPERIAL_ARAMAIC}', "");
Expect(0, 67679, '\P{		IMPERIAL_ARAMAIC}', "");
Expect(1, 67679, '\P{^		IMPERIAL_ARAMAIC}', "");
Expect(0, 67680, '\p{		IMPERIAL_ARAMAIC}', "");
Expect(1, 67680, '\p{^		IMPERIAL_ARAMAIC}', "");
Expect(1, 67680, '\P{		IMPERIAL_ARAMAIC}', "");
Expect(0, 67680, '\P{^		IMPERIAL_ARAMAIC}', "");
Error('\p{-/a/Is_IMPERIAL_Aramaic}');
Error('\P{-/a/Is_IMPERIAL_Aramaic}');
Expect(1, 67679, '\p{isimperialaramaic}', "");
Expect(0, 67679, '\p{^isimperialaramaic}', "");
Expect(0, 67679, '\P{isimperialaramaic}', "");
Expect(1, 67679, '\P{^isimperialaramaic}', "");
Expect(0, 67680, '\p{isimperialaramaic}', "");
Expect(1, 67680, '\p{^isimperialaramaic}', "");
Expect(1, 67680, '\P{isimperialaramaic}', "");
Expect(0, 67680, '\P{^isimperialaramaic}', "");
Expect(1, 67679, '\p{	Is_imperial_ARAMAIC}', "");
Expect(0, 67679, '\p{^	Is_imperial_ARAMAIC}', "");
Expect(0, 67679, '\P{	Is_imperial_ARAMAIC}', "");
Expect(1, 67679, '\P{^	Is_imperial_ARAMAIC}', "");
Expect(0, 67680, '\p{	Is_imperial_ARAMAIC}', "");
Expect(1, 67680, '\p{^	Is_imperial_ARAMAIC}', "");
Expect(1, 67680, '\P{	Is_imperial_ARAMAIC}', "");
Expect(0, 67680, '\P{^	Is_imperial_ARAMAIC}', "");
Error('\p{/a/-	ARMI}');
Error('\P{/a/-	ARMI}');
Expect(1, 67679, '\p{armi}', "");
Expect(0, 67679, '\p{^armi}', "");
Expect(0, 67679, '\P{armi}', "");
Expect(1, 67679, '\P{^armi}', "");
Expect(0, 67680, '\p{armi}', "");
Expect(1, 67680, '\p{^armi}', "");
Expect(1, 67680, '\P{armi}', "");
Expect(0, 67680, '\P{^armi}', "");
Expect(1, 67679, '\p{	Armi}', "");
Expect(0, 67679, '\p{^	Armi}', "");
Expect(0, 67679, '\P{	Armi}', "");
Expect(1, 67679, '\P{^	Armi}', "");
Expect(0, 67680, '\p{	Armi}', "");
Expect(1, 67680, '\p{^	Armi}', "");
Expect(1, 67680, '\P{	Armi}', "");
Expect(0, 67680, '\P{^	Armi}', "");
Error('\p{_:=Is_Armi}');
Error('\P{_:=Is_Armi}');
Expect(1, 67679, '\p{isarmi}', "");
Expect(0, 67679, '\p{^isarmi}', "");
Expect(0, 67679, '\P{isarmi}', "");
Expect(1, 67679, '\P{^isarmi}', "");
Expect(0, 67680, '\p{isarmi}', "");
Expect(1, 67680, '\p{^isarmi}', "");
Expect(1, 67680, '\P{isarmi}', "");
Expect(0, 67680, '\P{^isarmi}', "");
Expect(1, 67679, '\p{_Is_Armi}', "");
Expect(0, 67679, '\p{^_Is_Armi}', "");
Expect(0, 67679, '\P{_Is_Armi}', "");
Expect(1, 67679, '\P{^_Is_Armi}', "");
Expect(0, 67680, '\p{_Is_Armi}', "");
Expect(1, 67680, '\p{^_Is_Armi}', "");
Expect(1, 67680, '\P{_Is_Armi}', "");
Expect(0, 67680, '\P{^_Is_Armi}', "");
Error('\p{/a/__IN_arabic}');
Error('\P{/a/__IN_arabic}');
Expect(1, 1791, '\p{inarabic}', "");
Expect(0, 1791, '\p{^inarabic}', "");
Expect(0, 1791, '\P{inarabic}', "");
Expect(1, 1791, '\P{^inarabic}', "");
Expect(0, 1792, '\p{inarabic}', "");
Expect(1, 1792, '\p{^inarabic}', "");
Expect(1, 1792, '\P{inarabic}', "");
Expect(0, 1792, '\P{^inarabic}', "");
Expect(1, 1791, '\p{_-In_ARABIC}', "");
Expect(0, 1791, '\p{^_-In_ARABIC}', "");
Expect(0, 1791, '\P{_-In_ARABIC}', "");
Expect(1, 1791, '\P{^_-In_ARABIC}', "");
Expect(0, 1792, '\p{_-In_ARABIC}', "");
Expect(1, 1792, '\p{^_-In_ARABIC}', "");
Expect(1, 1792, '\P{_-In_ARABIC}', "");
Expect(0, 1792, '\P{^_-In_ARABIC}', "");
Error('\p{ IN_ARABIC:=}');
Error('\P{ IN_ARABIC:=}');
Expect(1, 1791, '\p{ In_Arabic}', "");
Expect(0, 1791, '\p{^ In_Arabic}', "");
Expect(0, 1791, '\P{ In_Arabic}', "");
Expect(1, 1791, '\P{^ In_Arabic}', "");
Expect(0, 1792, '\p{ In_Arabic}', "");
Expect(1, 1792, '\p{^ In_Arabic}', "");
Expect(1, 1792, '\P{ In_Arabic}', "");
Expect(0, 1792, '\P{^ In_Arabic}', "");
Error('\p{:= in_Armenian}');
Error('\P{:= in_Armenian}');
Expect(1, 1423, '\p{inarmenian}', "");
Expect(0, 1423, '\p{^inarmenian}', "");
Expect(0, 1423, '\P{inarmenian}', "");
Expect(1, 1423, '\P{^inarmenian}', "");
Expect(0, 1424, '\p{inarmenian}', "");
Expect(1, 1424, '\p{^inarmenian}', "");
Expect(1, 1424, '\P{inarmenian}', "");
Expect(0, 1424, '\P{^inarmenian}', "");
Expect(1, 1423, '\p{_in_armenian}', "");
Expect(0, 1423, '\p{^_in_armenian}', "");
Expect(0, 1423, '\P{_in_armenian}', "");
Expect(1, 1423, '\P{^_in_armenian}', "");
Expect(0, 1424, '\p{_in_armenian}', "");
Expect(1, 1424, '\p{^_in_armenian}', "");
Expect(1, 1424, '\P{_in_armenian}', "");
Expect(0, 1424, '\P{^_in_armenian}', "");
Error('\p{ -In_Armenian:=}');
Error('\P{ -In_Armenian:=}');
Expect(1, 1423, '\p{ 	In_armenian}', "");
Expect(0, 1423, '\p{^ 	In_armenian}', "");
Expect(0, 1423, '\P{ 	In_armenian}', "");
Expect(1, 1423, '\P{^ 	In_armenian}', "");
Expect(0, 1424, '\p{ 	In_armenian}', "");
Expect(1, 1424, '\p{^ 	In_armenian}', "");
Expect(1, 1424, '\P{ 	In_armenian}', "");
Expect(0, 1424, '\P{^ 	In_armenian}', "");
Error('\p{__IN_Avestan:=}');
Error('\P{__IN_Avestan:=}');
Expect(1, 68415, '\p{inavestan}', "");
Expect(0, 68415, '\p{^inavestan}', "");
Expect(0, 68415, '\P{inavestan}', "");
Expect(1, 68415, '\P{^inavestan}', "");
Expect(0, 68416, '\p{inavestan}', "");
Expect(1, 68416, '\p{^inavestan}', "");
Expect(1, 68416, '\P{inavestan}', "");
Expect(0, 68416, '\P{^inavestan}', "");
Expect(1, 68415, '\p{	In_Avestan}', "");
Expect(0, 68415, '\p{^	In_Avestan}', "");
Expect(0, 68415, '\P{	In_Avestan}', "");
Expect(1, 68415, '\P{^	In_Avestan}', "");
Expect(0, 68416, '\p{	In_Avestan}', "");
Expect(1, 68416, '\p{^	In_Avestan}', "");
Expect(1, 68416, '\P{	In_Avestan}', "");
Expect(0, 68416, '\P{^	In_Avestan}', "");
Error('\p{_-In_Avestan/a/}');
Error('\P{_-In_Avestan/a/}');
Expect(1, 68415, '\p{ 	In_AVESTAN}', "");
Expect(0, 68415, '\p{^ 	In_AVESTAN}', "");
Expect(0, 68415, '\P{ 	In_AVESTAN}', "");
Expect(1, 68415, '\P{^ 	In_AVESTAN}', "");
Expect(0, 68416, '\p{ 	In_AVESTAN}', "");
Expect(1, 68416, '\p{^ 	In_AVESTAN}', "");
Expect(1, 68416, '\P{ 	In_AVESTAN}', "");
Expect(0, 68416, '\P{^ 	In_AVESTAN}', "");
Error('\p{/a/-_In_Balinese}');
Error('\P{/a/-_In_Balinese}');
Expect(1, 7039, '\p{inbalinese}', "");
Expect(0, 7039, '\p{^inbalinese}', "");
Expect(0, 7039, '\P{inbalinese}', "");
Expect(1, 7039, '\P{^inbalinese}', "");
Expect(0, 7040, '\p{inbalinese}', "");
Expect(1, 7040, '\p{^inbalinese}', "");
Expect(1, 7040, '\P{inbalinese}', "");
Expect(0, 7040, '\P{^inbalinese}', "");
Expect(1, 7039, '\p{  in_BALINESE}', "");
Expect(0, 7039, '\p{^  in_BALINESE}', "");
Expect(0, 7039, '\P{  in_BALINESE}', "");
Expect(1, 7039, '\P{^  in_BALINESE}', "");
Expect(0, 7040, '\p{  in_BALINESE}', "");
Expect(1, 7040, '\p{^  in_BALINESE}', "");
Expect(1, 7040, '\P{  in_BALINESE}', "");
Expect(0, 7040, '\P{^  in_BALINESE}', "");
Error('\p{/a/	_In_BALINESE}');
Error('\P{/a/	_In_BALINESE}');
Expect(1, 7039, '\p{	In_BALINESE}', "");
Expect(0, 7039, '\p{^	In_BALINESE}', "");
Expect(0, 7039, '\P{	In_BALINESE}', "");
Expect(1, 7039, '\P{^	In_BALINESE}', "");
Expect(0, 7040, '\p{	In_BALINESE}', "");
Expect(1, 7040, '\p{^	In_BALINESE}', "");
Expect(1, 7040, '\P{	In_BALINESE}', "");
Expect(0, 7040, '\P{^	In_BALINESE}', "");
Error('\p{:=--IN_BAMUM}');
Error('\P{:=--IN_BAMUM}');
Expect(1, 42751, '\p{inbamum}', "");
Expect(0, 42751, '\p{^inbamum}', "");
Expect(0, 42751, '\P{inbamum}', "");
Expect(1, 42751, '\P{^inbamum}', "");
Expect(0, 42752, '\p{inbamum}', "");
Expect(1, 42752, '\p{^inbamum}', "");
Expect(1, 42752, '\P{inbamum}', "");
Expect(0, 42752, '\P{^inbamum}', "");
Expect(1, 42751, '\p{ _In_Bamum}', "");
Expect(0, 42751, '\p{^ _In_Bamum}', "");
Expect(0, 42751, '\P{ _In_Bamum}', "");
Expect(1, 42751, '\P{^ _In_Bamum}', "");
Expect(0, 42752, '\p{ _In_Bamum}', "");
Expect(1, 42752, '\p{^ _In_Bamum}', "");
Expect(1, 42752, '\P{ _In_Bamum}', "");
Expect(0, 42752, '\P{^ _In_Bamum}', "");
Error('\p{	-in_bamum:=}');
Error('\P{	-in_bamum:=}');
Expect(1, 42751, '\p{		In_Bamum}', "");
Expect(0, 42751, '\p{^		In_Bamum}', "");
Expect(0, 42751, '\P{		In_Bamum}', "");
Expect(1, 42751, '\P{^		In_Bamum}', "");
Expect(0, 42752, '\p{		In_Bamum}', "");
Expect(1, 42752, '\p{^		In_Bamum}', "");
Expect(1, 42752, '\P{		In_Bamum}', "");
Expect(0, 42752, '\P{^		In_Bamum}', "");
Error('\p{_/a/In_BATAK}');
Error('\P{_/a/In_BATAK}');
Expect(1, 7167, '\p{inbatak}', "");
Expect(0, 7167, '\p{^inbatak}', "");
Expect(0, 7167, '\P{inbatak}', "");
Expect(1, 7167, '\P{^inbatak}', "");
Expect(0, 7168, '\p{inbatak}', "");
Expect(1, 7168, '\p{^inbatak}', "");
Expect(1, 7168, '\P{inbatak}', "");
Expect(0, 7168, '\P{^inbatak}', "");
Expect(1, 7167, '\p{__IN_Batak}', "");
Expect(0, 7167, '\p{^__IN_Batak}', "");
Expect(0, 7167, '\P{__IN_Batak}', "");
Expect(1, 7167, '\P{^__IN_Batak}', "");
Expect(0, 7168, '\p{__IN_Batak}', "");
Expect(1, 7168, '\p{^__IN_Batak}', "");
Expect(1, 7168, '\P{__IN_Batak}', "");
Expect(0, 7168, '\P{^__IN_Batak}', "");
Error('\p{-:=In_batak}');
Error('\P{-:=In_batak}');
Expect(1, 7167, '\p{__In_BATAK}', "");
Expect(0, 7167, '\p{^__In_BATAK}', "");
Expect(0, 7167, '\P{__In_BATAK}', "");
Expect(1, 7167, '\P{^__In_BATAK}', "");
Expect(0, 7168, '\p{__In_BATAK}', "");
Expect(1, 7168, '\p{^__In_BATAK}', "");
Expect(1, 7168, '\P{__In_BATAK}', "");
Expect(0, 7168, '\P{^__In_BATAK}', "");
Error('\p{	:=in_BENGALI}');
Error('\P{	:=in_BENGALI}');
Expect(1, 2559, '\p{inbengali}', "");
Expect(0, 2559, '\p{^inbengali}', "");
Expect(0, 2559, '\P{inbengali}', "");
Expect(1, 2559, '\P{^inbengali}', "");
Expect(0, 2560, '\p{inbengali}', "");
Expect(1, 2560, '\p{^inbengali}', "");
Expect(1, 2560, '\P{inbengali}', "");
Expect(0, 2560, '\P{^inbengali}', "");
Expect(1, 2559, '\p{_-in_Bengali}', "");
Expect(0, 2559, '\p{^_-in_Bengali}', "");
Expect(0, 2559, '\P{_-in_Bengali}', "");
Expect(1, 2559, '\P{^_-in_Bengali}', "");
Expect(0, 2560, '\p{_-in_Bengali}', "");
Expect(1, 2560, '\p{^_-in_Bengali}', "");
Expect(1, 2560, '\P{_-in_Bengali}', "");
Expect(0, 2560, '\P{^_-in_Bengali}', "");
Error('\p{:=_ In_bengali}');
Error('\P{:=_ In_bengali}');
Expect(1, 2559, '\p{	 In_bengali}', "");
Expect(0, 2559, '\p{^	 In_bengali}', "");
Expect(0, 2559, '\P{	 In_bengali}', "");
Expect(1, 2559, '\P{^	 In_bengali}', "");
Expect(0, 2560, '\p{	 In_bengali}', "");
Expect(1, 2560, '\p{^	 In_bengali}', "");
Expect(1, 2560, '\P{	 In_bengali}', "");
Expect(0, 2560, '\P{^	 In_bengali}', "");
Error('\p{_/a/in_BOPOMOFO}');
Error('\P{_/a/in_BOPOMOFO}');
Expect(1, 12591, '\p{inbopomofo}', "");
Expect(0, 12591, '\p{^inbopomofo}', "");
Expect(0, 12591, '\P{inbopomofo}', "");
Expect(1, 12591, '\P{^inbopomofo}', "");
Expect(0, 12592, '\p{inbopomofo}', "");
Expect(1, 12592, '\p{^inbopomofo}', "");
Expect(1, 12592, '\P{inbopomofo}', "");
Expect(0, 12592, '\P{^inbopomofo}', "");
Expect(1, 12591, '\p{	 In_Bopomofo}', "");
Expect(0, 12591, '\p{^	 In_Bopomofo}', "");
Expect(0, 12591, '\P{	 In_Bopomofo}', "");
Expect(1, 12591, '\P{^	 In_Bopomofo}', "");
Expect(0, 12592, '\p{	 In_Bopomofo}', "");
Expect(1, 12592, '\p{^	 In_Bopomofo}', "");
Expect(1, 12592, '\P{	 In_Bopomofo}', "");
Expect(0, 12592, '\P{^	 In_Bopomofo}', "");
Error('\p{:=_ In_Bopomofo}');
Error('\P{:=_ In_Bopomofo}');
Expect(1, 12591, '\p{-In_bopomofo}', "");
Expect(0, 12591, '\p{^-In_bopomofo}', "");
Expect(0, 12591, '\P{-In_bopomofo}', "");
Expect(1, 12591, '\P{^-In_bopomofo}', "");
Expect(0, 12592, '\p{-In_bopomofo}', "");
Expect(1, 12592, '\p{^-In_bopomofo}', "");
Expect(1, 12592, '\P{-In_bopomofo}', "");
Expect(0, 12592, '\P{^-In_bopomofo}', "");
Error('\p{/a/__in_Brahmi}');
Error('\P{/a/__in_Brahmi}');
Expect(1, 69759, '\p{inbrahmi}', "");
Expect(0, 69759, '\p{^inbrahmi}', "");
Expect(0, 69759, '\P{inbrahmi}', "");
Expect(1, 69759, '\P{^inbrahmi}', "");
Expect(0, 69760, '\p{inbrahmi}', "");
Expect(1, 69760, '\p{^inbrahmi}', "");
Expect(1, 69760, '\P{inbrahmi}', "");
Expect(0, 69760, '\P{^inbrahmi}', "");
Expect(1, 69759, '\p{-in_Brahmi}', "");
Expect(0, 69759, '\p{^-in_Brahmi}', "");
Expect(0, 69759, '\P{-in_Brahmi}', "");
Expect(1, 69759, '\P{^-in_Brahmi}', "");
Expect(0, 69760, '\p{-in_Brahmi}', "");
Expect(1, 69760, '\p{^-in_Brahmi}', "");
Expect(1, 69760, '\P{-in_Brahmi}', "");
Expect(0, 69760, '\P{^-in_Brahmi}', "");
Error('\p{-/a/in_Brahmi}');
Error('\P{-/a/in_Brahmi}');
Expect(1, 69759, '\p{	IN_brahmi}', "");
Expect(0, 69759, '\p{^	IN_brahmi}', "");
Expect(0, 69759, '\P{	IN_brahmi}', "");
Expect(1, 69759, '\P{^	IN_brahmi}', "");
Expect(0, 69760, '\p{	IN_brahmi}', "");
Expect(1, 69760, '\p{^	IN_brahmi}', "");
Expect(1, 69760, '\P{	IN_brahmi}', "");
Expect(0, 69760, '\P{^	IN_brahmi}', "");
Error('\p{/a/- In_BUGINESE}');
Error('\P{/a/- In_BUGINESE}');
Expect(1, 6687, '\p{inbuginese}', "");
Expect(0, 6687, '\p{^inbuginese}', "");
Expect(0, 6687, '\P{inbuginese}', "");
Expect(1, 6687, '\P{^inbuginese}', "");
Expect(0, 6688, '\p{inbuginese}', "");
Expect(1, 6688, '\p{^inbuginese}', "");
Expect(1, 6688, '\P{inbuginese}', "");
Expect(0, 6688, '\P{^inbuginese}', "");
Expect(1, 6687, '\p{- IN_BUGINESE}', "");
Expect(0, 6687, '\p{^- IN_BUGINESE}', "");
Expect(0, 6687, '\P{- IN_BUGINESE}', "");
Expect(1, 6687, '\P{^- IN_BUGINESE}', "");
Expect(0, 6688, '\p{- IN_BUGINESE}', "");
Expect(1, 6688, '\p{^- IN_BUGINESE}', "");
Expect(1, 6688, '\P{- IN_BUGINESE}', "");
Expect(0, 6688, '\P{^- IN_BUGINESE}', "");
Error('\p{/a/IN_BUGINESE}');
Error('\P{/a/IN_BUGINESE}');
Expect(1, 6687, '\p{  in_Buginese}', "");
Expect(0, 6687, '\p{^  in_Buginese}', "");
Expect(0, 6687, '\P{  in_Buginese}', "");
Expect(1, 6687, '\P{^  in_Buginese}', "");
Expect(0, 6688, '\p{  in_Buginese}', "");
Expect(1, 6688, '\p{^  in_Buginese}', "");
Expect(1, 6688, '\P{  in_Buginese}', "");
Expect(0, 6688, '\P{^  in_Buginese}', "");
Error('\p{ _in_BUHID/a/}');
Error('\P{ _in_BUHID/a/}');
Expect(1, 5983, '\p{inbuhid}', "");
Expect(0, 5983, '\p{^inbuhid}', "");
Expect(0, 5983, '\P{inbuhid}', "");
Expect(1, 5983, '\P{^inbuhid}', "");
Expect(0, 5984, '\p{inbuhid}', "");
Expect(1, 5984, '\p{^inbuhid}', "");
Expect(1, 5984, '\P{inbuhid}', "");
Expect(0, 5984, '\P{^inbuhid}', "");
Expect(1, 5983, '\p{	 in_Buhid}', "");
Expect(0, 5983, '\p{^	 in_Buhid}', "");
Expect(0, 5983, '\P{	 in_Buhid}', "");
Expect(1, 5983, '\P{^	 in_Buhid}', "");
Expect(0, 5984, '\p{	 in_Buhid}', "");
Expect(1, 5984, '\p{^	 in_Buhid}', "");
Expect(1, 5984, '\P{	 in_Buhid}', "");
Expect(0, 5984, '\P{^	 in_Buhid}', "");
Error('\p{ :=In_buhid}');
Error('\P{ :=In_buhid}');
Expect(1, 5983, '\p{- IN_BUHID}', "");
Expect(0, 5983, '\p{^- IN_BUHID}', "");
Expect(0, 5983, '\P{- IN_BUHID}', "");
Expect(1, 5983, '\P{^- IN_BUHID}', "");
Expect(0, 5984, '\p{- IN_BUHID}', "");
Expect(1, 5984, '\p{^- IN_BUHID}', "");
Expect(1, 5984, '\P{- IN_BUHID}', "");
Expect(0, 5984, '\P{^- IN_BUHID}', "");
Error('\p{_IN_carian:=}');
Error('\P{_IN_carian:=}');
Expect(1, 66271, '\p{incarian}', "");
Expect(0, 66271, '\p{^incarian}', "");
Expect(0, 66271, '\P{incarian}', "");
Expect(1, 66271, '\P{^incarian}', "");
Expect(0, 66272, '\p{incarian}', "");
Expect(1, 66272, '\p{^incarian}', "");
Expect(1, 66272, '\P{incarian}', "");
Expect(0, 66272, '\P{^incarian}', "");
Expect(1, 66271, '\p{_-IN_CARIAN}', "");
Expect(0, 66271, '\p{^_-IN_CARIAN}', "");
Expect(0, 66271, '\P{_-IN_CARIAN}', "");
Expect(1, 66271, '\P{^_-IN_CARIAN}', "");
Expect(0, 66272, '\p{_-IN_CARIAN}', "");
Expect(1, 66272, '\p{^_-IN_CARIAN}', "");
Expect(1, 66272, '\P{_-IN_CARIAN}', "");
Expect(0, 66272, '\P{^_-IN_CARIAN}', "");
Error('\p{_:=In_CARIAN}');
Error('\P{_:=In_CARIAN}');
Expect(1, 66271, '\p{_IN_Carian}', "");
Expect(0, 66271, '\p{^_IN_Carian}', "");
Expect(0, 66271, '\P{_IN_Carian}', "");
Expect(1, 66271, '\P{^_IN_Carian}', "");
Expect(0, 66272, '\p{_IN_Carian}', "");
Expect(1, 66272, '\p{^_IN_Carian}', "");
Expect(1, 66272, '\P{_IN_Carian}', "");
Expect(0, 66272, '\P{^_IN_Carian}', "");
Error('\p{ /a/IN_chakma}');
Error('\P{ /a/IN_chakma}');
Expect(1, 69967, '\p{inchakma}', "");
Expect(0, 69967, '\p{^inchakma}', "");
Expect(0, 69967, '\P{inchakma}', "");
Expect(1, 69967, '\P{^inchakma}', "");
Expect(0, 69968, '\p{inchakma}', "");
Expect(1, 69968, '\p{^inchakma}', "");
Expect(1, 69968, '\P{inchakma}', "");
Expect(0, 69968, '\P{^inchakma}', "");
Expect(1, 69967, '\p{In_Chakma}', "");
Expect(0, 69967, '\p{^In_Chakma}', "");
Expect(0, 69967, '\P{In_Chakma}', "");
Expect(1, 69967, '\P{^In_Chakma}', "");
Expect(0, 69968, '\p{In_Chakma}', "");
Expect(1, 69968, '\p{^In_Chakma}', "");
Expect(1, 69968, '\P{In_Chakma}', "");
Expect(0, 69968, '\P{^In_Chakma}', "");
Error('\p{_:=in_Chakma}');
Error('\P{_:=in_Chakma}');
Expect(1, 69967, '\p{ -In_Chakma}', "");
Expect(0, 69967, '\p{^ -In_Chakma}', "");
Expect(0, 69967, '\P{ -In_Chakma}', "");
Expect(1, 69967, '\P{^ -In_Chakma}', "");
Expect(0, 69968, '\p{ -In_Chakma}', "");
Expect(1, 69968, '\p{^ -In_Chakma}', "");
Expect(1, 69968, '\P{ -In_Chakma}', "");
Expect(0, 69968, '\P{^ -In_Chakma}', "");
Error('\p{	:=In_Cham}');
Error('\P{	:=In_Cham}');
Expect(1, 43615, '\p{incham}', "");
Expect(0, 43615, '\p{^incham}', "");
Expect(0, 43615, '\P{incham}', "");
Expect(1, 43615, '\P{^incham}', "");
Expect(0, 43616, '\p{incham}', "");
Expect(1, 43616, '\p{^incham}', "");
Expect(1, 43616, '\P{incham}', "");
Expect(0, 43616, '\P{^incham}', "");
Expect(1, 43615, '\p{_-In_Cham}', "");
Expect(0, 43615, '\p{^_-In_Cham}', "");
Expect(0, 43615, '\P{_-In_Cham}', "");
Expect(1, 43615, '\P{^_-In_Cham}', "");
Expect(0, 43616, '\p{_-In_Cham}', "");
Expect(1, 43616, '\p{^_-In_Cham}', "");
Expect(1, 43616, '\P{_-In_Cham}', "");
Expect(0, 43616, '\P{^_-In_Cham}', "");
Error('\p{	-IN_cham/a/}');
Error('\P{	-IN_cham/a/}');
Expect(1, 43615, '\p{		IN_Cham}', "");
Expect(0, 43615, '\p{^		IN_Cham}', "");
Expect(0, 43615, '\P{		IN_Cham}', "");
Expect(1, 43615, '\P{^		IN_Cham}', "");
Expect(0, 43616, '\p{		IN_Cham}', "");
Expect(1, 43616, '\p{^		IN_Cham}', "");
Expect(1, 43616, '\P{		IN_Cham}', "");
Expect(0, 43616, '\P{^		IN_Cham}', "");
Error('\p{_/a/in_Cherokee}');
Error('\P{_/a/in_Cherokee}');
Expect(1, 5119, '\p{incherokee}', "");
Expect(0, 5119, '\p{^incherokee}', "");
Expect(0, 5119, '\P{incherokee}', "");
Expect(1, 5119, '\P{^incherokee}', "");
Expect(0, 5120, '\p{incherokee}', "");
Expect(1, 5120, '\p{^incherokee}', "");
Expect(1, 5120, '\P{incherokee}', "");
Expect(0, 5120, '\P{^incherokee}', "");
Expect(1, 5119, '\p{ In_Cherokee}', "");
Expect(0, 5119, '\p{^ In_Cherokee}', "");
Expect(0, 5119, '\P{ In_Cherokee}', "");
Expect(1, 5119, '\P{^ In_Cherokee}', "");
Expect(0, 5120, '\p{ In_Cherokee}', "");
Expect(1, 5120, '\p{^ In_Cherokee}', "");
Expect(1, 5120, '\P{ In_Cherokee}', "");
Expect(0, 5120, '\P{^ In_Cherokee}', "");
Error('\p{--In_Cherokee/a/}');
Error('\P{--In_Cherokee/a/}');
Expect(1, 5119, '\p{ 	IN_Cherokee}', "");
Expect(0, 5119, '\p{^ 	IN_Cherokee}', "");
Expect(0, 5119, '\P{ 	IN_Cherokee}', "");
Expect(1, 5119, '\P{^ 	IN_Cherokee}', "");
Expect(0, 5120, '\p{ 	IN_Cherokee}', "");
Expect(1, 5120, '\p{^ 	IN_Cherokee}', "");
Expect(1, 5120, '\P{ 	IN_Cherokee}', "");
Expect(0, 5120, '\P{^ 	IN_Cherokee}', "");
Error('\p{	IN_Coptic:=}');
Error('\P{	IN_Coptic:=}');
Expect(1, 11519, '\p{incoptic}', "");
Expect(0, 11519, '\p{^incoptic}', "");
Expect(0, 11519, '\P{incoptic}', "");
Expect(1, 11519, '\P{^incoptic}', "");
Expect(0, 11520, '\p{incoptic}', "");
Expect(1, 11520, '\p{^incoptic}', "");
Expect(1, 11520, '\P{incoptic}', "");
Expect(0, 11520, '\P{^incoptic}', "");
Expect(1, 11519, '\p{	-In_COPTIC}', "");
Expect(0, 11519, '\p{^	-In_COPTIC}', "");
Expect(0, 11519, '\P{	-In_COPTIC}', "");
Expect(1, 11519, '\P{^	-In_COPTIC}', "");
Expect(0, 11520, '\p{	-In_COPTIC}', "");
Expect(1, 11520, '\p{^	-In_COPTIC}', "");
Expect(1, 11520, '\P{	-In_COPTIC}', "");
Expect(0, 11520, '\P{^	-In_COPTIC}', "");
Error('\p{_In_COPTIC:=}');
Error('\P{_In_COPTIC:=}');
Expect(1, 11519, '\p{		in_Coptic}', "");
Expect(0, 11519, '\p{^		in_Coptic}', "");
Expect(0, 11519, '\P{		in_Coptic}', "");
Expect(1, 11519, '\P{^		in_Coptic}', "");
Expect(0, 11520, '\p{		in_Coptic}', "");
Expect(1, 11520, '\p{^		in_Coptic}', "");
Expect(1, 11520, '\P{		in_Coptic}', "");
Expect(0, 11520, '\P{^		in_Coptic}', "");
Error('\p{/a/--In_cuneiform}');
Error('\P{/a/--In_cuneiform}');
Expect(1, 74751, '\p{incuneiform}', "");
Expect(0, 74751, '\p{^incuneiform}', "");
Expect(0, 74751, '\P{incuneiform}', "");
Expect(1, 74751, '\P{^incuneiform}', "");
Expect(0, 74752, '\p{incuneiform}', "");
Expect(1, 74752, '\p{^incuneiform}', "");
Expect(1, 74752, '\P{incuneiform}', "");
Expect(0, 74752, '\P{^incuneiform}', "");
Expect(1, 74751, '\p{ 	IN_Cuneiform}', "");
Expect(0, 74751, '\p{^ 	IN_Cuneiform}', "");
Expect(0, 74751, '\P{ 	IN_Cuneiform}', "");
Expect(1, 74751, '\P{^ 	IN_Cuneiform}', "");
Expect(0, 74752, '\p{ 	IN_Cuneiform}', "");
Expect(1, 74752, '\p{^ 	IN_Cuneiform}', "");
Expect(1, 74752, '\P{ 	IN_Cuneiform}', "");
Expect(0, 74752, '\P{^ 	IN_Cuneiform}', "");
Error('\p{ IN_cuneiform:=}');
Error('\P{ IN_cuneiform:=}');
Expect(1, 74751, '\p{ IN_CUNEIFORM}', "");
Expect(0, 74751, '\p{^ IN_CUNEIFORM}', "");
Expect(0, 74751, '\P{ IN_CUNEIFORM}', "");
Expect(1, 74751, '\P{^ IN_CUNEIFORM}', "");
Expect(0, 74752, '\p{ IN_CUNEIFORM}', "");
Expect(1, 74752, '\p{^ IN_CUNEIFORM}', "");
Expect(1, 74752, '\P{ IN_CUNEIFORM}', "");
Expect(0, 74752, '\P{^ IN_CUNEIFORM}', "");
Error('\p{-/a/IN_cyrillic}');
Error('\P{-/a/IN_cyrillic}');
Expect(1, 1279, '\p{incyrillic}', "");
Expect(0, 1279, '\p{^incyrillic}', "");
Expect(0, 1279, '\P{incyrillic}', "");
Expect(1, 1279, '\P{^incyrillic}', "");
Expect(0, 1280, '\p{incyrillic}', "");
Expect(1, 1280, '\p{^incyrillic}', "");
Expect(1, 1280, '\P{incyrillic}', "");
Expect(0, 1280, '\P{^incyrillic}', "");
Expect(1, 1279, '\p{-_In_CYRILLIC}', "");
Expect(0, 1279, '\p{^-_In_CYRILLIC}', "");
Expect(0, 1279, '\P{-_In_CYRILLIC}', "");
Expect(1, 1279, '\P{^-_In_CYRILLIC}', "");
Expect(0, 1280, '\p{-_In_CYRILLIC}', "");
Expect(1, 1280, '\p{^-_In_CYRILLIC}', "");
Expect(1, 1280, '\P{-_In_CYRILLIC}', "");
Expect(0, 1280, '\P{^-_In_CYRILLIC}', "");
Error('\p{/a/-in_cyrillic}');
Error('\P{/a/-in_cyrillic}');
Expect(1, 1279, '\p{-IN_cyrillic}', "");
Expect(0, 1279, '\p{^-IN_cyrillic}', "");
Expect(0, 1279, '\P{-IN_cyrillic}', "");
Expect(1, 1279, '\P{^-IN_cyrillic}', "");
Expect(0, 1280, '\p{-IN_cyrillic}', "");
Expect(1, 1280, '\p{^-IN_cyrillic}', "");
Expect(1, 1280, '\P{-IN_cyrillic}', "");
Expect(0, 1280, '\P{^-IN_cyrillic}', "");
Error('\p{	In_DESERET/a/}');
Error('\P{	In_DESERET/a/}');
Expect(1, 66639, '\p{indeseret}', "");
Expect(0, 66639, '\p{^indeseret}', "");
Expect(0, 66639, '\P{indeseret}', "");
Expect(1, 66639, '\P{^indeseret}', "");
Expect(0, 66640, '\p{indeseret}', "");
Expect(1, 66640, '\p{^indeseret}', "");
Expect(1, 66640, '\P{indeseret}', "");
Expect(0, 66640, '\P{^indeseret}', "");
Expect(1, 66639, '\p{_	IN_DESERET}', "");
Expect(0, 66639, '\p{^_	IN_DESERET}', "");
Expect(0, 66639, '\P{_	IN_DESERET}', "");
Expect(1, 66639, '\P{^_	IN_DESERET}', "");
Expect(0, 66640, '\p{_	IN_DESERET}', "");
Expect(1, 66640, '\p{^_	IN_DESERET}', "");
Expect(1, 66640, '\P{_	IN_DESERET}', "");
Expect(0, 66640, '\P{^_	IN_DESERET}', "");
Error('\p{/a/		In_deseret}');
Error('\P{/a/		In_deseret}');
Expect(1, 66639, '\p{_In_deseret}', "");
Expect(0, 66639, '\p{^_In_deseret}', "");
Expect(0, 66639, '\P{_In_deseret}', "");
Expect(1, 66639, '\P{^_In_deseret}', "");
Expect(0, 66640, '\p{_In_deseret}', "");
Expect(1, 66640, '\p{^_In_deseret}', "");
Expect(1, 66640, '\P{_In_deseret}', "");
Expect(0, 66640, '\P{^_In_deseret}', "");
Error('\p{/a/ IN_Devanagari}');
Error('\P{/a/ IN_Devanagari}');
Expect(1, 2431, '\p{indevanagari}', "");
Expect(0, 2431, '\p{^indevanagari}', "");
Expect(0, 2431, '\P{indevanagari}', "");
Expect(1, 2431, '\P{^indevanagari}', "");
Expect(0, 2432, '\p{indevanagari}', "");
Expect(1, 2432, '\p{^indevanagari}', "");
Expect(1, 2432, '\P{indevanagari}', "");
Expect(0, 2432, '\P{^indevanagari}', "");
Expect(1, 2431, '\p{	-In_Devanagari}', "");
Expect(0, 2431, '\p{^	-In_Devanagari}', "");
Expect(0, 2431, '\P{	-In_Devanagari}', "");
Expect(1, 2431, '\P{^	-In_Devanagari}', "");
Expect(0, 2432, '\p{	-In_Devanagari}', "");
Expect(1, 2432, '\p{^	-In_Devanagari}', "");
Expect(1, 2432, '\P{	-In_Devanagari}', "");
Expect(0, 2432, '\P{^	-In_Devanagari}', "");
Error('\p{--IN_devanagari:=}');
Error('\P{--IN_devanagari:=}');
Error('\p{_/a/in_Egyptian_hieroglyphs}');
Error('\P{_/a/in_Egyptian_hieroglyphs}');
Expect(1, 78895, '\p{inegyptianhieroglyphs}', "");
Expect(0, 78895, '\p{^inegyptianhieroglyphs}', "");
Expect(0, 78895, '\P{inegyptianhieroglyphs}', "");
Expect(1, 78895, '\P{^inegyptianhieroglyphs}', "");
Expect(0, 78896, '\p{inegyptianhieroglyphs}', "");
Expect(1, 78896, '\p{^inegyptianhieroglyphs}', "");
Expect(1, 78896, '\P{inegyptianhieroglyphs}', "");
Expect(0, 78896, '\P{^inegyptianhieroglyphs}', "");
Expect(1, 78895, '\p{ In_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\p{^ In_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\P{ In_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\P{^ In_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78896, '\p{ In_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78896, '\p{^ In_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78896, '\P{ In_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78896, '\P{^ In_EGYPTIAN_Hieroglyphs}', "");
Error('\p{_	IN_Egyptian_Hieroglyphs:=}');
Error('\P{_	IN_Egyptian_Hieroglyphs:=}');
Expect(1, 78895, '\p{_In_egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\p{^_In_egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\P{_In_egyptian_HIEROGLYPHS}', "");
Expect(1, 78895, '\P{^_In_egyptian_HIEROGLYPHS}', "");
Expect(0, 78896, '\p{_In_egyptian_HIEROGLYPHS}', "");
Expect(1, 78896, '\p{^_In_egyptian_HIEROGLYPHS}', "");
Expect(1, 78896, '\P{_In_egyptian_HIEROGLYPHS}', "");
Expect(0, 78896, '\P{^_In_egyptian_HIEROGLYPHS}', "");
Error('\p{_In_ETHIOPIC/a/}');
Error('\P{_In_ETHIOPIC/a/}');
Expect(1, 4991, '\p{inethiopic}', "");
Expect(0, 4991, '\p{^inethiopic}', "");
Expect(0, 4991, '\P{inethiopic}', "");
Expect(1, 4991, '\P{^inethiopic}', "");
Expect(0, 4992, '\p{inethiopic}', "");
Expect(1, 4992, '\p{^inethiopic}', "");
Expect(1, 4992, '\P{inethiopic}', "");
Expect(0, 4992, '\P{^inethiopic}', "");
Expect(1, 4991, '\p{-_In_ethiopic}', "");
Expect(0, 4991, '\p{^-_In_ethiopic}', "");
Expect(0, 4991, '\P{-_In_ethiopic}', "");
Expect(1, 4991, '\P{^-_In_ethiopic}', "");
Expect(0, 4992, '\p{-_In_ethiopic}', "");
Expect(1, 4992, '\p{^-_In_ethiopic}', "");
Expect(1, 4992, '\P{-_In_ethiopic}', "");
Expect(0, 4992, '\P{^-_In_ethiopic}', "");
Error('\p{:= _in_ETHIOPIC}');
Error('\P{:= _in_ETHIOPIC}');
Expect(1, 4991, '\p{_ in_Ethiopic}', "");
Expect(0, 4991, '\p{^_ in_Ethiopic}', "");
Expect(0, 4991, '\P{_ in_Ethiopic}', "");
Expect(1, 4991, '\P{^_ in_Ethiopic}', "");
Expect(0, 4992, '\p{_ in_Ethiopic}', "");
Expect(1, 4992, '\p{^_ in_Ethiopic}', "");
Expect(1, 4992, '\P{_ in_Ethiopic}', "");
Expect(0, 4992, '\P{^_ in_Ethiopic}', "");
Error('\p{	in_Georgian/a/}');
Error('\P{	in_Georgian/a/}');
Expect(1, 4351, '\p{ingeorgian}', "");
Expect(0, 4351, '\p{^ingeorgian}', "");
Expect(0, 4351, '\P{ingeorgian}', "");
Expect(1, 4351, '\P{^ingeorgian}', "");
Expect(0, 4352, '\p{ingeorgian}', "");
Expect(1, 4352, '\p{^ingeorgian}', "");
Expect(1, 4352, '\P{ingeorgian}', "");
Expect(0, 4352, '\P{^ingeorgian}', "");
Expect(1, 4351, '\p{_-in_Georgian}', "");
Expect(0, 4351, '\p{^_-in_Georgian}', "");
Expect(0, 4351, '\P{_-in_Georgian}', "");
Expect(1, 4351, '\P{^_-in_Georgian}', "");
Expect(0, 4352, '\p{_-in_Georgian}', "");
Expect(1, 4352, '\p{^_-in_Georgian}', "");
Expect(1, 4352, '\P{_-in_Georgian}', "");
Expect(0, 4352, '\P{^_-in_Georgian}', "");
Error('\p{-_IN_Georgian:=}');
Error('\P{-_IN_Georgian:=}');
Expect(1, 4351, '\p{	-In_Georgian}', "");
Expect(0, 4351, '\p{^	-In_Georgian}', "");
Expect(0, 4351, '\P{	-In_Georgian}', "");
Expect(1, 4351, '\P{^	-In_Georgian}', "");
Expect(0, 4352, '\p{	-In_Georgian}', "");
Expect(1, 4352, '\p{^	-In_Georgian}', "");
Expect(1, 4352, '\P{	-In_Georgian}', "");
Expect(0, 4352, '\P{^	-In_Georgian}', "");
Error('\p{ 	In_Glagolitic:=}');
Error('\P{ 	In_Glagolitic:=}');
Expect(1, 11359, '\p{inglagolitic}', "");
Expect(0, 11359, '\p{^inglagolitic}', "");
Expect(0, 11359, '\P{inglagolitic}', "");
Expect(1, 11359, '\P{^inglagolitic}', "");
Expect(0, 11360, '\p{inglagolitic}', "");
Expect(1, 11360, '\p{^inglagolitic}', "");
Expect(1, 11360, '\P{inglagolitic}', "");
Expect(0, 11360, '\P{^inglagolitic}', "");
Expect(1, 11359, '\p{_IN_GLAGOLITIC}', "");
Expect(0, 11359, '\p{^_IN_GLAGOLITIC}', "");
Expect(0, 11359, '\P{_IN_GLAGOLITIC}', "");
Expect(1, 11359, '\P{^_IN_GLAGOLITIC}', "");
Expect(0, 11360, '\p{_IN_GLAGOLITIC}', "");
Expect(1, 11360, '\p{^_IN_GLAGOLITIC}', "");
Expect(1, 11360, '\P{_IN_GLAGOLITIC}', "");
Expect(0, 11360, '\P{^_IN_GLAGOLITIC}', "");
Error('\p{:=_IN_Glagolitic}');
Error('\P{:=_IN_Glagolitic}');
Expect(1, 11359, '\p{-_in_Glagolitic}', "");
Expect(0, 11359, '\p{^-_in_Glagolitic}', "");
Expect(0, 11359, '\P{-_in_Glagolitic}', "");
Expect(1, 11359, '\P{^-_in_Glagolitic}', "");
Expect(0, 11360, '\p{-_in_Glagolitic}', "");
Expect(1, 11360, '\p{^-_in_Glagolitic}', "");
Expect(1, 11360, '\P{-_in_Glagolitic}', "");
Expect(0, 11360, '\P{^-_in_Glagolitic}', "");
Error('\p{/a/	_In_Gothic}');
Error('\P{/a/	_In_Gothic}');
Expect(1, 66383, '\p{ingothic}', "");
Expect(0, 66383, '\p{^ingothic}', "");
Expect(0, 66383, '\P{ingothic}', "");
Expect(1, 66383, '\P{^ingothic}', "");
Expect(0, 66384, '\p{ingothic}', "");
Expect(1, 66384, '\p{^ingothic}', "");
Expect(1, 66384, '\P{ingothic}', "");
Expect(0, 66384, '\P{^ingothic}', "");
Expect(1, 66383, '\p{	in_gothic}', "");
Expect(0, 66383, '\p{^	in_gothic}', "");
Expect(0, 66383, '\P{	in_gothic}', "");
Expect(1, 66383, '\P{^	in_gothic}', "");
Expect(0, 66384, '\p{	in_gothic}', "");
Expect(1, 66384, '\p{^	in_gothic}', "");
Expect(1, 66384, '\P{	in_gothic}', "");
Expect(0, 66384, '\P{^	in_gothic}', "");
Error('\p{/a/IN_GOTHIC}');
Error('\P{/a/IN_GOTHIC}');
Expect(1, 66383, '\p{  IN_gothic}', "");
Expect(0, 66383, '\p{^  IN_gothic}', "");
Expect(0, 66383, '\P{  IN_gothic}', "");
Expect(1, 66383, '\P{^  IN_gothic}', "");
Expect(0, 66384, '\p{  IN_gothic}', "");
Expect(1, 66384, '\p{^  IN_gothic}', "");
Expect(1, 66384, '\P{  IN_gothic}', "");
Expect(0, 66384, '\P{^  IN_gothic}', "");
Error('\p{_-In_Gujarati/a/}');
Error('\P{_-In_Gujarati/a/}');
Expect(1, 2815, '\p{ingujarati}', "");
Expect(0, 2815, '\p{^ingujarati}', "");
Expect(0, 2815, '\P{ingujarati}', "");
Expect(1, 2815, '\P{^ingujarati}', "");
Expect(0, 2816, '\p{ingujarati}', "");
Expect(1, 2816, '\p{^ingujarati}', "");
Expect(1, 2816, '\P{ingujarati}', "");
Expect(0, 2816, '\P{^ingujarati}', "");
Expect(1, 2815, '\p{	In_Gujarati}', "");
Expect(0, 2815, '\p{^	In_Gujarati}', "");
Expect(0, 2815, '\P{	In_Gujarati}', "");
Expect(1, 2815, '\P{^	In_Gujarati}', "");
Expect(0, 2816, '\p{	In_Gujarati}', "");
Expect(1, 2816, '\p{^	In_Gujarati}', "");
Expect(1, 2816, '\P{	In_Gujarati}', "");
Expect(0, 2816, '\P{^	In_Gujarati}', "");
Error('\p{in_gujarati/a/}');
Error('\P{in_gujarati/a/}');
Expect(1, 2815, '\p{		IN_Gujarati}', "");
Expect(0, 2815, '\p{^		IN_Gujarati}', "");
Expect(0, 2815, '\P{		IN_Gujarati}', "");
Expect(1, 2815, '\P{^		IN_Gujarati}', "");
Expect(0, 2816, '\p{		IN_Gujarati}', "");
Expect(1, 2816, '\p{^		IN_Gujarati}', "");
Expect(1, 2816, '\P{		IN_Gujarati}', "");
Expect(0, 2816, '\P{^		IN_Gujarati}', "");
Error('\p{ 	In_Gurmukhi:=}');
Error('\P{ 	In_Gurmukhi:=}');
Expect(1, 2687, '\p{ingurmukhi}', "");
Expect(0, 2687, '\p{^ingurmukhi}', "");
Expect(0, 2687, '\P{ingurmukhi}', "");
Expect(1, 2687, '\P{^ingurmukhi}', "");
Expect(0, 2688, '\p{ingurmukhi}', "");
Expect(1, 2688, '\p{^ingurmukhi}', "");
Expect(1, 2688, '\P{ingurmukhi}', "");
Expect(0, 2688, '\P{^ingurmukhi}', "");
Expect(1, 2687, '\p{	 In_Gurmukhi}', "");
Expect(0, 2687, '\p{^	 In_Gurmukhi}', "");
Expect(0, 2687, '\P{	 In_Gurmukhi}', "");
Expect(1, 2687, '\P{^	 In_Gurmukhi}', "");
Expect(0, 2688, '\p{	 In_Gurmukhi}', "");
Expect(1, 2688, '\p{^	 In_Gurmukhi}', "");
Expect(1, 2688, '\P{	 In_Gurmukhi}', "");
Expect(0, 2688, '\P{^	 In_Gurmukhi}', "");
Error('\p{		IN_gurmukhi/a/}');
Error('\P{		IN_gurmukhi/a/}');
Expect(1, 2687, '\p{- In_gurmukhi}', "");
Expect(0, 2687, '\p{^- In_gurmukhi}', "");
Expect(0, 2687, '\P{- In_gurmukhi}', "");
Expect(1, 2687, '\P{^- In_gurmukhi}', "");
Expect(0, 2688, '\p{- In_gurmukhi}', "");
Expect(1, 2688, '\p{^- In_gurmukhi}', "");
Expect(1, 2688, '\P{- In_gurmukhi}', "");
Expect(0, 2688, '\P{^- In_gurmukhi}', "");
Error('\p{	In_Hanunoo/a/}');
Error('\P{	In_Hanunoo/a/}');
Expect(1, 5951, '\p{inhanunoo}', "");
Expect(0, 5951, '\p{^inhanunoo}', "");
Expect(0, 5951, '\P{inhanunoo}', "");
Expect(1, 5951, '\P{^inhanunoo}', "");
Expect(0, 5952, '\p{inhanunoo}', "");
Expect(1, 5952, '\p{^inhanunoo}', "");
Expect(1, 5952, '\P{inhanunoo}', "");
Expect(0, 5952, '\P{^inhanunoo}', "");
Expect(1, 5951, '\p{__In_Hanunoo}', "");
Expect(0, 5951, '\p{^__In_Hanunoo}', "");
Expect(0, 5951, '\P{__In_Hanunoo}', "");
Expect(1, 5951, '\P{^__In_Hanunoo}', "");
Expect(0, 5952, '\p{__In_Hanunoo}', "");
Expect(1, 5952, '\p{^__In_Hanunoo}', "");
Expect(1, 5952, '\P{__In_Hanunoo}', "");
Expect(0, 5952, '\P{^__In_Hanunoo}', "");
Error('\p{_:=In_hanunoo}');
Error('\P{_:=In_hanunoo}');
Expect(1, 5951, '\p{_	In_HANUNOO}', "");
Expect(0, 5951, '\p{^_	In_HANUNOO}', "");
Expect(0, 5951, '\P{_	In_HANUNOO}', "");
Expect(1, 5951, '\P{^_	In_HANUNOO}', "");
Expect(0, 5952, '\p{_	In_HANUNOO}', "");
Expect(1, 5952, '\p{^_	In_HANUNOO}', "");
Expect(1, 5952, '\P{_	In_HANUNOO}', "");
Expect(0, 5952, '\P{^_	In_HANUNOO}', "");
Error('\p{/a/	 In_hebrew}');
Error('\P{/a/	 In_hebrew}');
Expect(1, 1535, '\p{inhebrew}', "");
Expect(0, 1535, '\p{^inhebrew}', "");
Expect(0, 1535, '\P{inhebrew}', "");
Expect(1, 1535, '\P{^inhebrew}', "");
Expect(0, 1536, '\p{inhebrew}', "");
Expect(1, 1536, '\p{^inhebrew}', "");
Expect(1, 1536, '\P{inhebrew}', "");
Expect(0, 1536, '\P{^inhebrew}', "");
Expect(1, 1535, '\p{  IN_HEBREW}', "");
Expect(0, 1535, '\p{^  IN_HEBREW}', "");
Expect(0, 1535, '\P{  IN_HEBREW}', "");
Expect(1, 1535, '\P{^  IN_HEBREW}', "");
Expect(0, 1536, '\p{  IN_HEBREW}', "");
Expect(1, 1536, '\p{^  IN_HEBREW}', "");
Expect(1, 1536, '\P{  IN_HEBREW}', "");
Expect(0, 1536, '\P{^  IN_HEBREW}', "");
Error('\p{	:=in_HEBREW}');
Error('\P{	:=in_HEBREW}');
Expect(1, 1535, '\p{ -in_HEBREW}', "");
Expect(0, 1535, '\p{^ -in_HEBREW}', "");
Expect(0, 1535, '\P{ -in_HEBREW}', "");
Expect(1, 1535, '\P{^ -in_HEBREW}', "");
Expect(0, 1536, '\p{ -in_HEBREW}', "");
Expect(1, 1536, '\p{^ -in_HEBREW}', "");
Expect(1, 1536, '\P{ -in_HEBREW}', "");
Expect(0, 1536, '\P{^ -in_HEBREW}', "");
Error('\p{/a/_	IN_Hiragana}');
Error('\P{/a/_	IN_Hiragana}');
Expect(1, 12447, '\p{inhiragana}', "");
Expect(0, 12447, '\p{^inhiragana}', "");
Expect(0, 12447, '\P{inhiragana}', "");
Expect(1, 12447, '\P{^inhiragana}', "");
Expect(0, 12448, '\p{inhiragana}', "");
Expect(1, 12448, '\p{^inhiragana}', "");
Expect(1, 12448, '\P{inhiragana}', "");
Expect(0, 12448, '\P{^inhiragana}', "");
Expect(1, 12447, '\p{__IN_Hiragana}', "");
Expect(0, 12447, '\p{^__IN_Hiragana}', "");
Expect(0, 12447, '\P{__IN_Hiragana}', "");
Expect(1, 12447, '\P{^__IN_Hiragana}', "");
Expect(0, 12448, '\p{__IN_Hiragana}', "");
Expect(1, 12448, '\p{^__IN_Hiragana}', "");
Expect(1, 12448, '\P{__IN_Hiragana}', "");
Expect(0, 12448, '\P{^__IN_Hiragana}', "");
Error('\p{- In_hiragana:=}');
Error('\P{- In_hiragana:=}');
Expect(1, 12447, '\p{	-in_HIRAGANA}', "");
Expect(0, 12447, '\p{^	-in_HIRAGANA}', "");
Expect(0, 12447, '\P{	-in_HIRAGANA}', "");
Expect(1, 12447, '\P{^	-in_HIRAGANA}', "");
Expect(0, 12448, '\p{	-in_HIRAGANA}', "");
Expect(1, 12448, '\p{^	-in_HIRAGANA}', "");
Expect(1, 12448, '\P{	-in_HIRAGANA}', "");
Expect(0, 12448, '\P{^	-in_HIRAGANA}', "");
Error('\p{	_In_Imperial_ARAMAIC:=}');
Error('\P{	_In_Imperial_ARAMAIC:=}');
Expect(1, 67679, '\p{inimperialaramaic}', "");
Expect(0, 67679, '\p{^inimperialaramaic}', "");
Expect(0, 67679, '\P{inimperialaramaic}', "");
Expect(1, 67679, '\P{^inimperialaramaic}', "");
Expect(0, 67680, '\p{inimperialaramaic}', "");
Expect(1, 67680, '\p{^inimperialaramaic}', "");
Expect(1, 67680, '\P{inimperialaramaic}', "");
Expect(0, 67680, '\P{^inimperialaramaic}', "");
Expect(1, 67679, '\p{In_Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^In_Imperial_Aramaic}', "");
Expect(0, 67679, '\P{In_Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^In_Imperial_Aramaic}', "");
Expect(0, 67680, '\p{In_Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^In_Imperial_Aramaic}', "");
Expect(1, 67680, '\P{In_Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^In_Imperial_Aramaic}', "");
Error('\p{	/a/in_imperial_Aramaic}');
Error('\P{	/a/in_imperial_Aramaic}');
Expect(1, 67679, '\p{_ in_imperial_ARAMAIC}', "");
Expect(0, 67679, '\p{^_ in_imperial_ARAMAIC}', "");
Expect(0, 67679, '\P{_ in_imperial_ARAMAIC}', "");
Expect(1, 67679, '\P{^_ in_imperial_ARAMAIC}', "");
Expect(0, 67680, '\p{_ in_imperial_ARAMAIC}', "");
Expect(1, 67680, '\p{^_ in_imperial_ARAMAIC}', "");
Expect(1, 67680, '\P{_ in_imperial_ARAMAIC}', "");
Expect(0, 67680, '\P{^_ in_imperial_ARAMAIC}', "");
Error('\p{:=-in_INSCRIPTIONAL_PAHLAVI}');
Error('\P{:=-in_INSCRIPTIONAL_PAHLAVI}');
Expect(1, 68479, '\p{ininscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^ininscriptionalpahlavi}', "");
Expect(0, 68479, '\P{ininscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^ininscriptionalpahlavi}', "");
Expect(0, 68480, '\p{ininscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^ininscriptionalpahlavi}', "");
Expect(1, 68480, '\P{ininscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^ininscriptionalpahlavi}', "");
Expect(1, 68479, '\p{ IN_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^ IN_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{ IN_Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^ IN_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{ IN_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^ IN_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{ IN_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^ IN_Inscriptional_Pahlavi}', "");
Error('\p{:=--In_inscriptional_Pahlavi}');
Error('\P{:=--In_inscriptional_Pahlavi}');
Expect(1, 68479, '\p{_-In_Inscriptional_pahlavi}', "");
Expect(0, 68479, '\p{^_-In_Inscriptional_pahlavi}', "");
Expect(0, 68479, '\P{_-In_Inscriptional_pahlavi}', "");
Expect(1, 68479, '\P{^_-In_Inscriptional_pahlavi}', "");
Expect(0, 68480, '\p{_-In_Inscriptional_pahlavi}', "");
Expect(1, 68480, '\p{^_-In_Inscriptional_pahlavi}', "");
Expect(1, 68480, '\P{_-In_Inscriptional_pahlavi}', "");
Expect(0, 68480, '\P{^_-In_Inscriptional_pahlavi}', "");
Error('\p{:=	in_inscriptional_PARTHIAN}');
Error('\P{:=	in_inscriptional_PARTHIAN}');
Expect(1, 68447, '\p{ininscriptionalparthian}', "");
Expect(0, 68447, '\p{^ininscriptionalparthian}', "");
Expect(0, 68447, '\P{ininscriptionalparthian}', "");
Expect(1, 68447, '\P{^ininscriptionalparthian}', "");
Expect(0, 68448, '\p{ininscriptionalparthian}', "");
Expect(1, 68448, '\p{^ininscriptionalparthian}', "");
Expect(1, 68448, '\P{ininscriptionalparthian}', "");
Expect(0, 68448, '\P{^ininscriptionalparthian}', "");
Expect(1, 68447, '\p{ _In_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^ _In_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{ _In_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^ _In_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{ _In_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^ _In_INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{ _In_INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^ _In_INSCRIPTIONAL_Parthian}', "");
Error('\p{	/a/in_inscriptional_Parthian}');
Error('\P{	/a/in_inscriptional_Parthian}');
Expect(1, 68447, '\p{In_Inscriptional_parthian}', "");
Expect(0, 68447, '\p{^In_Inscriptional_parthian}', "");
Expect(0, 68447, '\P{In_Inscriptional_parthian}', "");
Expect(1, 68447, '\P{^In_Inscriptional_parthian}', "");
Expect(0, 68448, '\p{In_Inscriptional_parthian}', "");
Expect(1, 68448, '\p{^In_Inscriptional_parthian}', "");
Expect(1, 68448, '\P{In_Inscriptional_parthian}', "");
Expect(0, 68448, '\P{^In_Inscriptional_parthian}', "");
Error('\p{ _in_JAVANESE:=}');
Error('\P{ _in_JAVANESE:=}');
Expect(1, 43487, '\p{injavanese}', "");
Expect(0, 43487, '\p{^injavanese}', "");
Expect(0, 43487, '\P{injavanese}', "");
Expect(1, 43487, '\P{^injavanese}', "");
Expect(0, 43488, '\p{injavanese}', "");
Expect(1, 43488, '\p{^injavanese}', "");
Expect(1, 43488, '\P{injavanese}', "");
Expect(0, 43488, '\P{^injavanese}', "");
Expect(1, 43487, '\p{  IN_JAVANESE}', "");
Expect(0, 43487, '\p{^  IN_JAVANESE}', "");
Expect(0, 43487, '\P{  IN_JAVANESE}', "");
Expect(1, 43487, '\P{^  IN_JAVANESE}', "");
Expect(0, 43488, '\p{  IN_JAVANESE}', "");
Expect(1, 43488, '\p{^  IN_JAVANESE}', "");
Expect(1, 43488, '\P{  IN_JAVANESE}', "");
Expect(0, 43488, '\P{^  IN_JAVANESE}', "");
Error('\p{	/a/In_Javanese}');
Error('\P{	/a/In_Javanese}');
Error('\p{_IN_KAITHI/a/}');
Error('\P{_IN_KAITHI/a/}');
Expect(1, 69839, '\p{inkaithi}', "");
Expect(0, 69839, '\p{^inkaithi}', "");
Expect(0, 69839, '\P{inkaithi}', "");
Expect(1, 69839, '\P{^inkaithi}', "");
Expect(0, 69840, '\p{inkaithi}', "");
Expect(1, 69840, '\p{^inkaithi}', "");
Expect(1, 69840, '\P{inkaithi}', "");
Expect(0, 69840, '\P{^inkaithi}', "");
Expect(1, 69839, '\p{__IN_Kaithi}', "");
Expect(0, 69839, '\p{^__IN_Kaithi}', "");
Expect(0, 69839, '\P{__IN_Kaithi}', "");
Expect(1, 69839, '\P{^__IN_Kaithi}', "");
Expect(0, 69840, '\p{__IN_Kaithi}', "");
Expect(1, 69840, '\p{^__IN_Kaithi}', "");
Expect(1, 69840, '\P{__IN_Kaithi}', "");
Expect(0, 69840, '\P{^__IN_Kaithi}', "");
Error('\p{-/a/IN_KAITHI}');
Error('\P{-/a/IN_KAITHI}');
Expect(1, 69839, '\p{ In_Kaithi}', "");
Expect(0, 69839, '\p{^ In_Kaithi}', "");
Expect(0, 69839, '\P{ In_Kaithi}', "");
Expect(1, 69839, '\P{^ In_Kaithi}', "");
Expect(0, 69840, '\p{ In_Kaithi}', "");
Expect(1, 69840, '\p{^ In_Kaithi}', "");
Expect(1, 69840, '\P{ In_Kaithi}', "");
Expect(0, 69840, '\P{^ In_Kaithi}', "");
Error('\p{-	In_kannada:=}');
Error('\P{-	In_kannada:=}');
Expect(1, 3327, '\p{inkannada}', "");
Expect(0, 3327, '\p{^inkannada}', "");
Expect(0, 3327, '\P{inkannada}', "");
Expect(1, 3327, '\P{^inkannada}', "");
Expect(0, 3328, '\p{inkannada}', "");
Expect(1, 3328, '\p{^inkannada}', "");
Expect(1, 3328, '\P{inkannada}', "");
Expect(0, 3328, '\P{^inkannada}', "");
Expect(1, 3327, '\p{In_Kannada}', "");
Expect(0, 3327, '\p{^In_Kannada}', "");
Expect(0, 3327, '\P{In_Kannada}', "");
Expect(1, 3327, '\P{^In_Kannada}', "");
Expect(0, 3328, '\p{In_Kannada}', "");
Expect(1, 3328, '\p{^In_Kannada}', "");
Expect(1, 3328, '\P{In_Kannada}', "");
Expect(0, 3328, '\P{^In_Kannada}', "");
Error('\p{/a/-In_KANNADA}');
Error('\P{/a/-In_KANNADA}');
Expect(1, 3327, '\p{-	in_Kannada}', "");
Expect(0, 3327, '\p{^-	in_Kannada}', "");
Expect(0, 3327, '\P{-	in_Kannada}', "");
Expect(1, 3327, '\P{^-	in_Kannada}', "");
Expect(0, 3328, '\p{-	in_Kannada}', "");
Expect(1, 3328, '\p{^-	in_Kannada}', "");
Expect(1, 3328, '\P{-	in_Kannada}', "");
Expect(0, 3328, '\P{^-	in_Kannada}', "");
Error('\p{/a/-	in_KATAKANA}');
Error('\P{/a/-	in_KATAKANA}');
Expect(1, 12543, '\p{inkatakana}', "");
Expect(0, 12543, '\p{^inkatakana}', "");
Expect(0, 12543, '\P{inkatakana}', "");
Expect(1, 12543, '\P{^inkatakana}', "");
Expect(0, 12544, '\p{inkatakana}', "");
Expect(1, 12544, '\p{^inkatakana}', "");
Expect(1, 12544, '\P{inkatakana}', "");
Expect(0, 12544, '\P{^inkatakana}', "");
Expect(1, 12543, '\p{_In_KATAKANA}', "");
Expect(0, 12543, '\p{^_In_KATAKANA}', "");
Expect(0, 12543, '\P{_In_KATAKANA}', "");
Expect(1, 12543, '\P{^_In_KATAKANA}', "");
Expect(0, 12544, '\p{_In_KATAKANA}', "");
Expect(1, 12544, '\p{^_In_KATAKANA}', "");
Expect(1, 12544, '\P{_In_KATAKANA}', "");
Expect(0, 12544, '\P{^_In_KATAKANA}', "");
Error('\p{	In_Katakana/a/}');
Error('\P{	In_Katakana/a/}');
Expect(1, 12543, '\p{_	In_KATAKANA}', "");
Expect(0, 12543, '\p{^_	In_KATAKANA}', "");
Expect(0, 12543, '\P{_	In_KATAKANA}', "");
Expect(1, 12543, '\P{^_	In_KATAKANA}', "");
Expect(0, 12544, '\p{_	In_KATAKANA}', "");
Expect(1, 12544, '\p{^_	In_KATAKANA}', "");
Expect(1, 12544, '\P{_	In_KATAKANA}', "");
Expect(0, 12544, '\P{^_	In_KATAKANA}', "");
Error('\p{/a/	-IN_kayah_Li}');
Error('\P{/a/	-IN_kayah_Li}');
Expect(1, 43311, '\p{inkayahli}', "");
Expect(0, 43311, '\p{^inkayahli}', "");
Expect(0, 43311, '\P{inkayahli}', "");
Expect(1, 43311, '\P{^inkayahli}', "");
Expect(0, 43312, '\p{inkayahli}', "");
Expect(1, 43312, '\p{^inkayahli}', "");
Expect(1, 43312, '\P{inkayahli}', "");
Expect(0, 43312, '\P{^inkayahli}', "");
Expect(1, 43311, '\p{_ In_Kayah_Li}', "");
Expect(0, 43311, '\p{^_ In_Kayah_Li}', "");
Expect(0, 43311, '\P{_ In_Kayah_Li}', "");
Expect(1, 43311, '\P{^_ In_Kayah_Li}', "");
Expect(0, 43312, '\p{_ In_Kayah_Li}', "");
Expect(1, 43312, '\p{^_ In_Kayah_Li}', "");
Expect(1, 43312, '\P{_ In_Kayah_Li}', "");
Expect(0, 43312, '\P{^_ In_Kayah_Li}', "");
Error('\p{	_in_KAYAH_Li:=}');
Error('\P{	_in_KAYAH_Li:=}');
Expect(1, 43311, '\p{- IN_KAYAH_Li}', "");
Expect(0, 43311, '\p{^- IN_KAYAH_Li}', "");
Expect(0, 43311, '\P{- IN_KAYAH_Li}', "");
Expect(1, 43311, '\P{^- IN_KAYAH_Li}', "");
Expect(0, 43312, '\p{- IN_KAYAH_Li}', "");
Expect(1, 43312, '\p{^- IN_KAYAH_Li}', "");
Expect(1, 43312, '\P{- IN_KAYAH_Li}', "");
Expect(0, 43312, '\P{^- IN_KAYAH_Li}', "");
Error('\p{  in_kharoshthi:=}');
Error('\P{  in_kharoshthi:=}');
Expect(1, 68191, '\p{inkharoshthi}', "");
Expect(0, 68191, '\p{^inkharoshthi}', "");
Expect(0, 68191, '\P{inkharoshthi}', "");
Expect(1, 68191, '\P{^inkharoshthi}', "");
Expect(0, 68192, '\p{inkharoshthi}', "");
Expect(1, 68192, '\p{^inkharoshthi}', "");
Expect(1, 68192, '\P{inkharoshthi}', "");
Expect(0, 68192, '\P{^inkharoshthi}', "");
Expect(1, 68191, '\p{		IN_KHAROSHTHI}', "");
Expect(0, 68191, '\p{^		IN_KHAROSHTHI}', "");
Expect(0, 68191, '\P{		IN_KHAROSHTHI}', "");
Expect(1, 68191, '\P{^		IN_KHAROSHTHI}', "");
Expect(0, 68192, '\p{		IN_KHAROSHTHI}', "");
Expect(1, 68192, '\p{^		IN_KHAROSHTHI}', "");
Expect(1, 68192, '\P{		IN_KHAROSHTHI}', "");
Expect(0, 68192, '\P{^		IN_KHAROSHTHI}', "");
Error('\p{	:=IN_Kharoshthi}');
Error('\P{	:=IN_Kharoshthi}');
Expect(1, 68191, '\p{	 in_KHAROSHTHI}', "");
Expect(0, 68191, '\p{^	 in_KHAROSHTHI}', "");
Expect(0, 68191, '\P{	 in_KHAROSHTHI}', "");
Expect(1, 68191, '\P{^	 in_KHAROSHTHI}', "");
Expect(0, 68192, '\p{	 in_KHAROSHTHI}', "");
Expect(1, 68192, '\p{^	 in_KHAROSHTHI}', "");
Expect(1, 68192, '\P{	 in_KHAROSHTHI}', "");
Expect(0, 68192, '\P{^	 in_KHAROSHTHI}', "");
Error('\p{ /a/In_Khmer}');
Error('\P{ /a/In_Khmer}');
Expect(1, 6143, '\p{inkhmer}', "");
Expect(0, 6143, '\p{^inkhmer}', "");
Expect(0, 6143, '\P{inkhmer}', "");
Expect(1, 6143, '\P{^inkhmer}', "");
Expect(0, 6144, '\p{inkhmer}', "");
Expect(1, 6144, '\p{^inkhmer}', "");
Expect(1, 6144, '\P{inkhmer}', "");
Expect(0, 6144, '\P{^inkhmer}', "");
Expect(1, 6143, '\p{	In_KHMER}', "");
Expect(0, 6143, '\p{^	In_KHMER}', "");
Expect(0, 6143, '\P{	In_KHMER}', "");
Expect(1, 6143, '\P{^	In_KHMER}', "");
Expect(0, 6144, '\p{	In_KHMER}', "");
Expect(1, 6144, '\p{^	In_KHMER}', "");
Expect(1, 6144, '\P{	In_KHMER}', "");
Expect(0, 6144, '\P{^	In_KHMER}', "");
Error('\p{--In_Khmer/a/}');
Error('\P{--In_Khmer/a/}');
Expect(1, 6143, '\p{-	IN_khmer}', "");
Expect(0, 6143, '\p{^-	IN_khmer}', "");
Expect(0, 6143, '\P{-	IN_khmer}', "");
Expect(1, 6143, '\P{^-	IN_khmer}', "");
Expect(0, 6144, '\p{-	IN_khmer}', "");
Expect(1, 6144, '\p{^-	IN_khmer}', "");
Expect(1, 6144, '\P{-	IN_khmer}', "");
Expect(0, 6144, '\P{^-	IN_khmer}', "");
Error('\p{_:=In_LAO}');
Error('\P{_:=In_LAO}');
Expect(1, 3839, '\p{inlao}', "");
Expect(0, 3839, '\p{^inlao}', "");
Expect(0, 3839, '\P{inlao}', "");
Expect(1, 3839, '\P{^inlao}', "");
Expect(0, 3840, '\p{inlao}', "");
Expect(1, 3840, '\p{^inlao}', "");
Expect(1, 3840, '\P{inlao}', "");
Expect(0, 3840, '\P{^inlao}', "");
Expect(1, 3839, '\p{_In_LAO}', "");
Expect(0, 3839, '\p{^_In_LAO}', "");
Expect(0, 3839, '\P{_In_LAO}', "");
Expect(1, 3839, '\P{^_In_LAO}', "");
Expect(0, 3840, '\p{_In_LAO}', "");
Expect(1, 3840, '\p{^_In_LAO}', "");
Expect(1, 3840, '\P{_In_LAO}', "");
Expect(0, 3840, '\P{^_In_LAO}', "");
Error('\p{	_In_Lao:=}');
Error('\P{	_In_Lao:=}');
Expect(1, 3839, '\p{		in_Lao}', "");
Expect(0, 3839, '\p{^		in_Lao}', "");
Expect(0, 3839, '\P{		in_Lao}', "");
Expect(1, 3839, '\P{^		in_Lao}', "");
Expect(0, 3840, '\p{		in_Lao}', "");
Expect(1, 3840, '\p{^		in_Lao}', "");
Expect(1, 3840, '\P{		in_Lao}', "");
Expect(0, 3840, '\P{^		in_Lao}', "");
Error('\p{__in_Lepcha/a/}');
Error('\P{__in_Lepcha/a/}');
Expect(1, 7247, '\p{inlepcha}', "");
Expect(0, 7247, '\p{^inlepcha}', "");
Expect(0, 7247, '\P{inlepcha}', "");
Expect(1, 7247, '\P{^inlepcha}', "");
Expect(0, 7248, '\p{inlepcha}', "");
Expect(1, 7248, '\p{^inlepcha}', "");
Expect(1, 7248, '\P{inlepcha}', "");
Expect(0, 7248, '\P{^inlepcha}', "");
Expect(1, 7247, '\p{	-In_lepcha}', "");
Expect(0, 7247, '\p{^	-In_lepcha}', "");
Expect(0, 7247, '\P{	-In_lepcha}', "");
Expect(1, 7247, '\P{^	-In_lepcha}', "");
Expect(0, 7248, '\p{	-In_lepcha}', "");
Expect(1, 7248, '\p{^	-In_lepcha}', "");
Expect(1, 7248, '\P{	-In_lepcha}', "");
Expect(0, 7248, '\P{^	-In_lepcha}', "");
Error('\p{_-IN_LEPCHA:=}');
Error('\P{_-IN_LEPCHA:=}');
Expect(1, 7247, '\p{-	IN_LEPCHA}', "");
Expect(0, 7247, '\p{^-	IN_LEPCHA}', "");
Expect(0, 7247, '\P{-	IN_LEPCHA}', "");
Expect(1, 7247, '\P{^-	IN_LEPCHA}', "");
Expect(0, 7248, '\p{-	IN_LEPCHA}', "");
Expect(1, 7248, '\p{^-	IN_LEPCHA}', "");
Expect(1, 7248, '\P{-	IN_LEPCHA}', "");
Expect(0, 7248, '\P{^-	IN_LEPCHA}', "");
Error('\p{:=	_In_Limbu}');
Error('\P{:=	_In_Limbu}');
Expect(1, 6479, '\p{inlimbu}', "");
Expect(0, 6479, '\p{^inlimbu}', "");
Expect(0, 6479, '\P{inlimbu}', "");
Expect(1, 6479, '\P{^inlimbu}', "");
Expect(0, 6480, '\p{inlimbu}', "");
Expect(1, 6480, '\p{^inlimbu}', "");
Expect(1, 6480, '\P{inlimbu}', "");
Expect(0, 6480, '\P{^inlimbu}', "");
Expect(1, 6479, '\p{_ In_Limbu}', "");
Expect(0, 6479, '\p{^_ In_Limbu}', "");
Expect(0, 6479, '\P{_ In_Limbu}', "");
Expect(1, 6479, '\P{^_ In_Limbu}', "");
Expect(0, 6480, '\p{_ In_Limbu}', "");
Expect(1, 6480, '\p{^_ In_Limbu}', "");
Expect(1, 6480, '\P{_ In_Limbu}', "");
Expect(0, 6480, '\P{^_ In_Limbu}', "");
Error('\p{-in_Limbu/a/}');
Error('\P{-in_Limbu/a/}');
Expect(1, 6479, '\p{-	in_LIMBU}', "");
Expect(0, 6479, '\p{^-	in_LIMBU}', "");
Expect(0, 6479, '\P{-	in_LIMBU}', "");
Expect(1, 6479, '\P{^-	in_LIMBU}', "");
Expect(0, 6480, '\p{-	in_LIMBU}', "");
Expect(1, 6480, '\p{^-	in_LIMBU}', "");
Expect(1, 6480, '\P{-	in_LIMBU}', "");
Expect(0, 6480, '\P{^-	in_LIMBU}', "");
Error('\p{_In_Lisu/a/}');
Error('\P{_In_Lisu/a/}');
Expect(1, 42239, '\p{inlisu}', "");
Expect(0, 42239, '\p{^inlisu}', "");
Expect(0, 42239, '\P{inlisu}', "");
Expect(1, 42239, '\P{^inlisu}', "");
Expect(0, 42240, '\p{inlisu}', "");
Expect(1, 42240, '\p{^inlisu}', "");
Expect(1, 42240, '\P{inlisu}', "");
Expect(0, 42240, '\P{^inlisu}', "");
Expect(1, 42239, '\p{-in_lisu}', "");
Expect(0, 42239, '\p{^-in_lisu}', "");
Expect(0, 42239, '\P{-in_lisu}', "");
Expect(1, 42239, '\P{^-in_lisu}', "");
Expect(0, 42240, '\p{-in_lisu}', "");
Expect(1, 42240, '\p{^-in_lisu}', "");
Expect(1, 42240, '\P{-in_lisu}', "");
Expect(0, 42240, '\P{^-in_lisu}', "");
Error('\p{ IN_Lisu/a/}');
Error('\P{ IN_Lisu/a/}');
Expect(1, 42239, '\p{_	In_LISU}', "");
Expect(0, 42239, '\p{^_	In_LISU}', "");
Expect(0, 42239, '\P{_	In_LISU}', "");
Expect(1, 42239, '\P{^_	In_LISU}', "");
Expect(0, 42240, '\p{_	In_LISU}', "");
Expect(1, 42240, '\p{^_	In_LISU}', "");
Expect(1, 42240, '\P{_	In_LISU}', "");
Expect(0, 42240, '\P{^_	In_LISU}', "");
Error('\p{_/a/in_lycian}');
Error('\P{_/a/in_lycian}');
Expect(1, 66207, '\p{inlycian}', "");
Expect(0, 66207, '\p{^inlycian}', "");
Expect(0, 66207, '\P{inlycian}', "");
Expect(1, 66207, '\P{^inlycian}', "");
Expect(0, 66208, '\p{inlycian}', "");
Expect(1, 66208, '\p{^inlycian}', "");
Expect(1, 66208, '\P{inlycian}', "");
Expect(0, 66208, '\P{^inlycian}', "");
Expect(1, 66207, '\p{ -In_Lycian}', "");
Expect(0, 66207, '\p{^ -In_Lycian}', "");
Expect(0, 66207, '\P{ -In_Lycian}', "");
Expect(1, 66207, '\P{^ -In_Lycian}', "");
Expect(0, 66208, '\p{ -In_Lycian}', "");
Expect(1, 66208, '\p{^ -In_Lycian}', "");
Expect(1, 66208, '\P{ -In_Lycian}', "");
Expect(0, 66208, '\P{^ -In_Lycian}', "");
Error('\p{/a/__in_Lycian}');
Error('\P{/a/__in_Lycian}');
Expect(1, 66207, '\p{ _In_LYCIAN}', "");
Expect(0, 66207, '\p{^ _In_LYCIAN}', "");
Expect(0, 66207, '\P{ _In_LYCIAN}', "");
Expect(1, 66207, '\P{^ _In_LYCIAN}', "");
Expect(0, 66208, '\p{ _In_LYCIAN}', "");
Expect(1, 66208, '\p{^ _In_LYCIAN}', "");
Expect(1, 66208, '\P{ _In_LYCIAN}', "");
Expect(0, 66208, '\P{^ _In_LYCIAN}', "");
Error('\p{	:=In_Lydian}');
Error('\P{	:=In_Lydian}');
Expect(1, 67903, '\p{inlydian}', "");
Expect(0, 67903, '\p{^inlydian}', "");
Expect(0, 67903, '\P{inlydian}', "");
Expect(1, 67903, '\P{^inlydian}', "");
Expect(0, 67904, '\p{inlydian}', "");
Expect(1, 67904, '\p{^inlydian}', "");
Expect(1, 67904, '\P{inlydian}', "");
Expect(0, 67904, '\P{^inlydian}', "");
Expect(1, 67903, '\p{-In_LYDIAN}', "");
Expect(0, 67903, '\p{^-In_LYDIAN}', "");
Expect(0, 67903, '\P{-In_LYDIAN}', "");
Expect(1, 67903, '\P{^-In_LYDIAN}', "");
Expect(0, 67904, '\p{-In_LYDIAN}', "");
Expect(1, 67904, '\p{^-In_LYDIAN}', "");
Expect(1, 67904, '\P{-In_LYDIAN}', "");
Expect(0, 67904, '\P{^-In_LYDIAN}', "");
Error('\p{ _In_Lydian:=}');
Error('\P{ _In_Lydian:=}');
Expect(1, 67903, '\p{_	In_Lydian}', "");
Expect(0, 67903, '\p{^_	In_Lydian}', "");
Expect(0, 67903, '\P{_	In_Lydian}', "");
Expect(1, 67903, '\P{^_	In_Lydian}', "");
Expect(0, 67904, '\p{_	In_Lydian}', "");
Expect(1, 67904, '\p{^_	In_Lydian}', "");
Expect(1, 67904, '\P{_	In_Lydian}', "");
Expect(0, 67904, '\P{^_	In_Lydian}', "");
Error('\p{/a/ 	In_MALAYALAM}');
Error('\P{/a/ 	In_MALAYALAM}');
Expect(1, 3455, '\p{inmalayalam}', "");
Expect(0, 3455, '\p{^inmalayalam}', "");
Expect(0, 3455, '\P{inmalayalam}', "");
Expect(1, 3455, '\P{^inmalayalam}', "");
Expect(0, 3456, '\p{inmalayalam}', "");
Expect(1, 3456, '\p{^inmalayalam}', "");
Expect(1, 3456, '\P{inmalayalam}', "");
Expect(0, 3456, '\P{^inmalayalam}', "");
Expect(1, 3455, '\p{-_In_Malayalam}', "");
Expect(0, 3455, '\p{^-_In_Malayalam}', "");
Expect(0, 3455, '\P{-_In_Malayalam}', "");
Expect(1, 3455, '\P{^-_In_Malayalam}', "");
Expect(0, 3456, '\p{-_In_Malayalam}', "");
Expect(1, 3456, '\p{^-_In_Malayalam}', "");
Expect(1, 3456, '\P{-_In_Malayalam}', "");
Expect(0, 3456, '\P{^-_In_Malayalam}', "");
Error('\p{	:=In_MALAYALAM}');
Error('\P{	:=In_MALAYALAM}');
Expect(1, 3455, '\p{	in_Malayalam}', "");
Expect(0, 3455, '\p{^	in_Malayalam}', "");
Expect(0, 3455, '\P{	in_Malayalam}', "");
Expect(1, 3455, '\P{^	in_Malayalam}', "");
Expect(0, 3456, '\p{	in_Malayalam}', "");
Expect(1, 3456, '\p{^	in_Malayalam}', "");
Expect(1, 3456, '\P{	in_Malayalam}', "");
Expect(0, 3456, '\P{^	in_Malayalam}', "");
Error('\p{- in_MANDAIC:=}');
Error('\P{- in_MANDAIC:=}');
Expect(1, 2143, '\p{inmandaic}', "");
Expect(0, 2143, '\p{^inmandaic}', "");
Expect(0, 2143, '\P{inmandaic}', "");
Expect(1, 2143, '\P{^inmandaic}', "");
Expect(0, 2144, '\p{inmandaic}', "");
Expect(1, 2144, '\p{^inmandaic}', "");
Expect(1, 2144, '\P{inmandaic}', "");
Expect(0, 2144, '\P{^inmandaic}', "");
Expect(1, 2143, '\p{	In_Mandaic}', "");
Expect(0, 2143, '\p{^	In_Mandaic}', "");
Expect(0, 2143, '\P{	In_Mandaic}', "");
Expect(1, 2143, '\P{^	In_Mandaic}', "");
Expect(0, 2144, '\p{	In_Mandaic}', "");
Expect(1, 2144, '\p{^	In_Mandaic}', "");
Expect(1, 2144, '\P{	In_Mandaic}', "");
Expect(0, 2144, '\P{^	In_Mandaic}', "");
Error('\p{	:=In_Mandaic}');
Error('\P{	:=In_Mandaic}');
Expect(1, 2143, '\p{_In_Mandaic}', "");
Expect(0, 2143, '\p{^_In_Mandaic}', "");
Expect(0, 2143, '\P{_In_Mandaic}', "");
Expect(1, 2143, '\P{^_In_Mandaic}', "");
Expect(0, 2144, '\p{_In_Mandaic}', "");
Expect(1, 2144, '\p{^_In_Mandaic}', "");
Expect(1, 2144, '\P{_In_Mandaic}', "");
Expect(0, 2144, '\P{^_In_Mandaic}', "");
Error('\p{/a/In_Meetei_MAYEK}');
Error('\P{/a/In_Meetei_MAYEK}');
Expect(1, 44031, '\p{inmeeteimayek}', "");
Expect(0, 44031, '\p{^inmeeteimayek}', "");
Expect(0, 44031, '\P{inmeeteimayek}', "");
Expect(1, 44031, '\P{^inmeeteimayek}', "");
Expect(0, 44032, '\p{inmeeteimayek}', "");
Expect(1, 44032, '\p{^inmeeteimayek}', "");
Expect(1, 44032, '\P{inmeeteimayek}', "");
Expect(0, 44032, '\P{^inmeeteimayek}', "");
Expect(1, 44031, '\p{	_In_meetei_MAYEK}', "");
Expect(0, 44031, '\p{^	_In_meetei_MAYEK}', "");
Expect(0, 44031, '\P{	_In_meetei_MAYEK}', "");
Expect(1, 44031, '\P{^	_In_meetei_MAYEK}', "");
Expect(0, 44032, '\p{	_In_meetei_MAYEK}', "");
Expect(1, 44032, '\p{^	_In_meetei_MAYEK}', "");
Expect(1, 44032, '\P{	_In_meetei_MAYEK}', "");
Expect(0, 44032, '\P{^	_In_meetei_MAYEK}', "");
Error('\p{/a/In_meetei_mayek}');
Error('\P{/a/In_meetei_mayek}');
Expect(1, 44031, '\p{_in_Meetei_mayek}', "");
Expect(0, 44031, '\p{^_in_Meetei_mayek}', "");
Expect(0, 44031, '\P{_in_Meetei_mayek}', "");
Expect(1, 44031, '\P{^_in_Meetei_mayek}', "");
Expect(0, 44032, '\p{_in_Meetei_mayek}', "");
Expect(1, 44032, '\p{^_in_Meetei_mayek}', "");
Expect(1, 44032, '\P{_in_Meetei_mayek}', "");
Expect(0, 44032, '\P{^_in_Meetei_mayek}', "");
Error('\p{:=		IN_meroitic_Cursive}');
Error('\P{:=		IN_meroitic_Cursive}');
Expect(1, 68095, '\p{inmeroiticcursive}', "");
Expect(0, 68095, '\p{^inmeroiticcursive}', "");
Expect(0, 68095, '\P{inmeroiticcursive}', "");
Expect(1, 68095, '\P{^inmeroiticcursive}', "");
Expect(0, 68096, '\p{inmeroiticcursive}', "");
Expect(1, 68096, '\p{^inmeroiticcursive}', "");
Expect(1, 68096, '\P{inmeroiticcursive}', "");
Expect(0, 68096, '\P{^inmeroiticcursive}', "");
Expect(1, 68095, '\p{- IN_MEROITIC_Cursive}', "");
Expect(0, 68095, '\p{^- IN_MEROITIC_Cursive}', "");
Expect(0, 68095, '\P{- IN_MEROITIC_Cursive}', "");
Expect(1, 68095, '\P{^- IN_MEROITIC_Cursive}', "");
Expect(0, 68096, '\p{- IN_MEROITIC_Cursive}', "");
Expect(1, 68096, '\p{^- IN_MEROITIC_Cursive}', "");
Expect(1, 68096, '\P{- IN_MEROITIC_Cursive}', "");
Expect(0, 68096, '\P{^- IN_MEROITIC_Cursive}', "");
Error('\p{	/a/In_meroitic_CURSIVE}');
Error('\P{	/a/In_meroitic_CURSIVE}');
Expect(1, 68095, '\p{-In_Meroitic_CURSIVE}', "");
Expect(0, 68095, '\p{^-In_Meroitic_CURSIVE}', "");
Expect(0, 68095, '\P{-In_Meroitic_CURSIVE}', "");
Expect(1, 68095, '\P{^-In_Meroitic_CURSIVE}', "");
Expect(0, 68096, '\p{-In_Meroitic_CURSIVE}', "");
Expect(1, 68096, '\p{^-In_Meroitic_CURSIVE}', "");
Expect(1, 68096, '\P{-In_Meroitic_CURSIVE}', "");
Expect(0, 68096, '\P{^-In_Meroitic_CURSIVE}', "");
Error('\p{:=-_In_Meroitic_Hieroglyphs}');
Error('\P{:=-_In_Meroitic_Hieroglyphs}');
Expect(1, 67999, '\p{inmeroitichieroglyphs}', "");
Expect(0, 67999, '\p{^inmeroitichieroglyphs}', "");
Expect(0, 67999, '\P{inmeroitichieroglyphs}', "");
Expect(1, 67999, '\P{^inmeroitichieroglyphs}', "");
Expect(0, 68000, '\p{inmeroitichieroglyphs}', "");
Expect(1, 68000, '\p{^inmeroitichieroglyphs}', "");
Expect(1, 68000, '\P{inmeroitichieroglyphs}', "");
Expect(0, 68000, '\P{^inmeroitichieroglyphs}', "");
Expect(1, 67999, '\p{ In_MEROITIC_Hieroglyphs}', "");
Expect(0, 67999, '\p{^ In_MEROITIC_Hieroglyphs}', "");
Expect(0, 67999, '\P{ In_MEROITIC_Hieroglyphs}', "");
Expect(1, 67999, '\P{^ In_MEROITIC_Hieroglyphs}', "");
Expect(0, 68000, '\p{ In_MEROITIC_Hieroglyphs}', "");
Expect(1, 68000, '\p{^ In_MEROITIC_Hieroglyphs}', "");
Expect(1, 68000, '\P{ In_MEROITIC_Hieroglyphs}', "");
Expect(0, 68000, '\P{^ In_MEROITIC_Hieroglyphs}', "");
Error('\p{	 in_Meroitic_Hieroglyphs/a/}');
Error('\P{	 in_Meroitic_Hieroglyphs/a/}');
Expect(1, 67999, '\p{	_In_Meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^	_In_Meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{	_In_Meroitic_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^	_In_Meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{	_In_Meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^	_In_Meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{	_In_Meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^	_In_Meroitic_HIEROGLYPHS}', "");
Error('\p{:=	 IN_Miao}');
Error('\P{:=	 IN_Miao}');
Expect(1, 94111, '\p{inmiao}', "");
Expect(0, 94111, '\p{^inmiao}', "");
Expect(0, 94111, '\P{inmiao}', "");
Expect(1, 94111, '\P{^inmiao}', "");
Expect(0, 94112, '\p{inmiao}', "");
Expect(1, 94112, '\p{^inmiao}', "");
Expect(1, 94112, '\P{inmiao}', "");
Expect(0, 94112, '\P{^inmiao}', "");
Expect(1, 94111, '\p{- In_Miao}', "");
Expect(0, 94111, '\p{^- In_Miao}', "");
Expect(0, 94111, '\P{- In_Miao}', "");
Expect(1, 94111, '\P{^- In_Miao}', "");
Expect(0, 94112, '\p{- In_Miao}', "");
Expect(1, 94112, '\p{^- In_Miao}', "");
Expect(1, 94112, '\P{- In_Miao}', "");
Expect(0, 94112, '\P{^- In_Miao}', "");
Error('\p{:=_-IN_Miao}');
Error('\P{:=_-IN_Miao}');
Expect(1, 94111, '\p{ IN_miao}', "");
Expect(0, 94111, '\p{^ IN_miao}', "");
Expect(0, 94111, '\P{ IN_miao}', "");
Expect(1, 94111, '\P{^ IN_miao}', "");
Expect(0, 94112, '\p{ IN_miao}', "");
Expect(1, 94112, '\p{^ IN_miao}', "");
Expect(1, 94112, '\P{ IN_miao}', "");
Expect(0, 94112, '\P{^ IN_miao}', "");
Error('\p{	-IN_Mongolian:=}');
Error('\P{	-IN_Mongolian:=}');
Expect(1, 6319, '\p{inmongolian}', "");
Expect(0, 6319, '\p{^inmongolian}', "");
Expect(0, 6319, '\P{inmongolian}', "");
Expect(1, 6319, '\P{^inmongolian}', "");
Expect(0, 6320, '\p{inmongolian}', "");
Expect(1, 6320, '\p{^inmongolian}', "");
Expect(1, 6320, '\P{inmongolian}', "");
Expect(0, 6320, '\P{^inmongolian}', "");
Expect(1, 6319, '\p{ 	IN_Mongolian}', "");
Expect(0, 6319, '\p{^ 	IN_Mongolian}', "");
Expect(0, 6319, '\P{ 	IN_Mongolian}', "");
Expect(1, 6319, '\P{^ 	IN_Mongolian}', "");
Expect(0, 6320, '\p{ 	IN_Mongolian}', "");
Expect(1, 6320, '\p{^ 	IN_Mongolian}', "");
Expect(1, 6320, '\P{ 	IN_Mongolian}', "");
Expect(0, 6320, '\P{^ 	IN_Mongolian}', "");
Error('\p{/a/ In_Mongolian}');
Error('\P{/a/ In_Mongolian}');
Expect(1, 6319, '\p{  In_Mongolian}', "");
Expect(0, 6319, '\p{^  In_Mongolian}', "");
Expect(0, 6319, '\P{  In_Mongolian}', "");
Expect(1, 6319, '\P{^  In_Mongolian}', "");
Expect(0, 6320, '\p{  In_Mongolian}', "");
Expect(1, 6320, '\p{^  In_Mongolian}', "");
Expect(1, 6320, '\P{  In_Mongolian}', "");
Expect(0, 6320, '\P{^  In_Mongolian}', "");
Error('\p{:=_in_myanmar}');
Error('\P{:=_in_myanmar}');
Expect(1, 4255, '\p{inmyanmar}', "");
Expect(0, 4255, '\p{^inmyanmar}', "");
Expect(0, 4255, '\P{inmyanmar}', "");
Expect(1, 4255, '\P{^inmyanmar}', "");
Expect(0, 4256, '\p{inmyanmar}', "");
Expect(1, 4256, '\p{^inmyanmar}', "");
Expect(1, 4256, '\P{inmyanmar}', "");
Expect(0, 4256, '\P{^inmyanmar}', "");
Expect(1, 4255, '\p{	_IN_MYANMAR}', "");
Expect(0, 4255, '\p{^	_IN_MYANMAR}', "");
Expect(0, 4255, '\P{	_IN_MYANMAR}', "");
Expect(1, 4255, '\P{^	_IN_MYANMAR}', "");
Expect(0, 4256, '\p{	_IN_MYANMAR}', "");
Expect(1, 4256, '\p{^	_IN_MYANMAR}', "");
Expect(1, 4256, '\P{	_IN_MYANMAR}', "");
Expect(0, 4256, '\P{^	_IN_MYANMAR}', "");
Error('\p{  In_Myanmar/a/}');
Error('\P{  In_Myanmar/a/}');
Expect(1, 4255, '\p{	 IN_myanmar}', "");
Expect(0, 4255, '\p{^	 IN_myanmar}', "");
Expect(0, 4255, '\P{	 IN_myanmar}', "");
Expect(1, 4255, '\P{^	 IN_myanmar}', "");
Expect(0, 4256, '\p{	 IN_myanmar}', "");
Expect(1, 4256, '\p{^	 IN_myanmar}', "");
Expect(1, 4256, '\P{	 IN_myanmar}', "");
Expect(0, 4256, '\P{^	 IN_myanmar}', "");
Error('\p{-/a/IN_NKo}');
Error('\P{-/a/IN_NKo}');
Expect(1, 2047, '\p{innko}', "");
Expect(0, 2047, '\p{^innko}', "");
Expect(0, 2047, '\P{innko}', "");
Expect(1, 2047, '\P{^innko}', "");
Expect(0, 2048, '\p{innko}', "");
Expect(1, 2048, '\p{^innko}', "");
Expect(1, 2048, '\P{innko}', "");
Expect(0, 2048, '\P{^innko}', "");
Expect(1, 2047, '\p{  In_NKo}', "");
Expect(0, 2047, '\p{^  In_NKo}', "");
Expect(0, 2047, '\P{  In_NKo}', "");
Expect(1, 2047, '\P{^  In_NKo}', "");
Expect(0, 2048, '\p{  In_NKo}', "");
Expect(1, 2048, '\p{^  In_NKo}', "");
Expect(1, 2048, '\P{  In_NKo}', "");
Expect(0, 2048, '\P{^  In_NKo}', "");
Error('\p{/a/_In_nko}');
Error('\P{/a/_In_nko}');
Expect(1, 2047, '\p{- In_NKo}', "");
Expect(0, 2047, '\p{^- In_NKo}', "");
Expect(0, 2047, '\P{- In_NKo}', "");
Expect(1, 2047, '\P{^- In_NKo}', "");
Expect(0, 2048, '\p{- In_NKo}', "");
Expect(1, 2048, '\p{^- In_NKo}', "");
Expect(1, 2048, '\P{- In_NKo}', "");
Expect(0, 2048, '\P{^- In_NKo}', "");
Error('\p{		in_new_TAI_Lue:=}');
Error('\P{		in_new_TAI_Lue:=}');
Expect(1, 6623, '\p{innewtailue}', "");
Expect(0, 6623, '\p{^innewtailue}', "");
Expect(0, 6623, '\P{innewtailue}', "");
Expect(1, 6623, '\P{^innewtailue}', "");
Expect(0, 6624, '\p{innewtailue}', "");
Expect(1, 6624, '\p{^innewtailue}', "");
Expect(1, 6624, '\P{innewtailue}', "");
Expect(0, 6624, '\P{^innewtailue}', "");
Expect(1, 6623, '\p{- in_new_tai_lue}', "");
Expect(0, 6623, '\p{^- in_new_tai_lue}', "");
Expect(0, 6623, '\P{- in_new_tai_lue}', "");
Expect(1, 6623, '\P{^- in_new_tai_lue}', "");
Expect(0, 6624, '\p{- in_new_tai_lue}', "");
Expect(1, 6624, '\p{^- in_new_tai_lue}', "");
Expect(1, 6624, '\P{- in_new_tai_lue}', "");
Expect(0, 6624, '\P{^- in_new_tai_lue}', "");
Error('\p{:=	 In_New_Tai_LUE}');
Error('\P{:=	 In_New_Tai_LUE}');
Expect(1, 6623, '\p{_In_New_tai_Lue}', "");
Expect(0, 6623, '\p{^_In_New_tai_Lue}', "");
Expect(0, 6623, '\P{_In_New_tai_Lue}', "");
Expect(1, 6623, '\P{^_In_New_tai_Lue}', "");
Expect(0, 6624, '\p{_In_New_tai_Lue}', "");
Expect(1, 6624, '\p{^_In_New_tai_Lue}', "");
Expect(1, 6624, '\P{_In_New_tai_Lue}', "");
Expect(0, 6624, '\P{^_In_New_tai_Lue}', "");
Error('\p{	in_Ogham/a/}');
Error('\P{	in_Ogham/a/}');
Expect(1, 5791, '\p{inogham}', "");
Expect(0, 5791, '\p{^inogham}', "");
Expect(0, 5791, '\P{inogham}', "");
Expect(1, 5791, '\P{^inogham}', "");
Expect(0, 5792, '\p{inogham}', "");
Expect(1, 5792, '\p{^inogham}', "");
Expect(1, 5792, '\P{inogham}', "");
Expect(0, 5792, '\P{^inogham}', "");
Expect(1, 5791, '\p{	_IN_Ogham}', "");
Expect(0, 5791, '\p{^	_IN_Ogham}', "");
Expect(0, 5791, '\P{	_IN_Ogham}', "");
Expect(1, 5791, '\P{^	_IN_Ogham}', "");
Expect(0, 5792, '\p{	_IN_Ogham}', "");
Expect(1, 5792, '\p{^	_IN_Ogham}', "");
Expect(1, 5792, '\P{	_IN_Ogham}', "");
Expect(0, 5792, '\P{^	_IN_Ogham}', "");
Error('\p{		In_OGHAM:=}');
Error('\P{		In_OGHAM:=}');
Error('\p{_:=In_OL_CHIKI}');
Error('\P{_:=In_OL_CHIKI}');
Expect(1, 7295, '\p{inolchiki}', "");
Expect(0, 7295, '\p{^inolchiki}', "");
Expect(0, 7295, '\P{inolchiki}', "");
Expect(1, 7295, '\P{^inolchiki}', "");
Expect(0, 7296, '\p{inolchiki}', "");
Expect(1, 7296, '\p{^inolchiki}', "");
Expect(1, 7296, '\P{inolchiki}', "");
Expect(0, 7296, '\P{^inolchiki}', "");
Expect(1, 7295, '\p{	_In_Ol_Chiki}', "");
Expect(0, 7295, '\p{^	_In_Ol_Chiki}', "");
Expect(0, 7295, '\P{	_In_Ol_Chiki}', "");
Expect(1, 7295, '\P{^	_In_Ol_Chiki}', "");
Expect(0, 7296, '\p{	_In_Ol_Chiki}', "");
Expect(1, 7296, '\p{^	_In_Ol_Chiki}', "");
Expect(1, 7296, '\P{	_In_Ol_Chiki}', "");
Expect(0, 7296, '\P{^	_In_Ol_Chiki}', "");
Error('\p{	/a/IN_ol_Chiki}');
Error('\P{	/a/IN_ol_Chiki}');
Expect(1, 7295, '\p{	 IN_Ol_Chiki}', "");
Expect(0, 7295, '\p{^	 IN_Ol_Chiki}', "");
Expect(0, 7295, '\P{	 IN_Ol_Chiki}', "");
Expect(1, 7295, '\P{^	 IN_Ol_Chiki}', "");
Expect(0, 7296, '\p{	 IN_Ol_Chiki}', "");
Expect(1, 7296, '\p{^	 IN_Ol_Chiki}', "");
Expect(1, 7296, '\P{	 IN_Ol_Chiki}', "");
Expect(0, 7296, '\P{^	 IN_Ol_Chiki}', "");
Error('\p{ 	in_Old_ITALIC:=}');
Error('\P{ 	in_Old_ITALIC:=}');
Expect(1, 66351, '\p{inolditalic}', "");
Expect(0, 66351, '\p{^inolditalic}', "");
Expect(0, 66351, '\P{inolditalic}', "");
Expect(1, 66351, '\P{^inolditalic}', "");
Expect(0, 66352, '\p{inolditalic}', "");
Expect(1, 66352, '\p{^inolditalic}', "");
Expect(1, 66352, '\P{inolditalic}', "");
Expect(0, 66352, '\P{^inolditalic}', "");
Expect(1, 66351, '\p{-_In_Old_Italic}', "");
Expect(0, 66351, '\p{^-_In_Old_Italic}', "");
Expect(0, 66351, '\P{-_In_Old_Italic}', "");
Expect(1, 66351, '\P{^-_In_Old_Italic}', "");
Expect(0, 66352, '\p{-_In_Old_Italic}', "");
Expect(1, 66352, '\p{^-_In_Old_Italic}', "");
Expect(1, 66352, '\P{-_In_Old_Italic}', "");
Expect(0, 66352, '\P{^-_In_Old_Italic}', "");
Error('\p{-/a/In_OLD_italic}');
Error('\P{-/a/In_OLD_italic}');
Expect(1, 66351, '\p{	In_old_Italic}', "");
Expect(0, 66351, '\p{^	In_old_Italic}', "");
Expect(0, 66351, '\P{	In_old_Italic}', "");
Expect(1, 66351, '\P{^	In_old_Italic}', "");
Expect(0, 66352, '\p{	In_old_Italic}', "");
Expect(1, 66352, '\p{^	In_old_Italic}', "");
Expect(1, 66352, '\P{	In_old_Italic}', "");
Expect(0, 66352, '\P{^	In_old_Italic}', "");
Error('\p{_In_OLD_Persian/a/}');
Error('\P{_In_OLD_Persian/a/}');
Expect(1, 66527, '\p{inoldpersian}', "");
Expect(0, 66527, '\p{^inoldpersian}', "");
Expect(0, 66527, '\P{inoldpersian}', "");
Expect(1, 66527, '\P{^inoldpersian}', "");
Expect(0, 66528, '\p{inoldpersian}', "");
Expect(1, 66528, '\p{^inoldpersian}', "");
Expect(1, 66528, '\P{inoldpersian}', "");
Expect(0, 66528, '\P{^inoldpersian}', "");
Expect(1, 66527, '\p{--IN_Old_persian}', "");
Expect(0, 66527, '\p{^--IN_Old_persian}', "");
Expect(0, 66527, '\P{--IN_Old_persian}', "");
Expect(1, 66527, '\P{^--IN_Old_persian}', "");
Expect(0, 66528, '\p{--IN_Old_persian}', "");
Expect(1, 66528, '\p{^--IN_Old_persian}', "");
Expect(1, 66528, '\P{--IN_Old_persian}', "");
Expect(0, 66528, '\P{^--IN_Old_persian}', "");
Error('\p{/a/_-In_Old_PERSIAN}');
Error('\P{/a/_-In_Old_PERSIAN}');
Expect(1, 66527, '\p{-In_Old_Persian}', "");
Expect(0, 66527, '\p{^-In_Old_Persian}', "");
Expect(0, 66527, '\P{-In_Old_Persian}', "");
Expect(1, 66527, '\P{^-In_Old_Persian}', "");
Expect(0, 66528, '\p{-In_Old_Persian}', "");
Expect(1, 66528, '\p{^-In_Old_Persian}', "");
Expect(1, 66528, '\P{-In_Old_Persian}', "");
Expect(0, 66528, '\P{^-In_Old_Persian}', "");
Error('\p{/a/  IN_Old_South_Arabian}');
Error('\P{/a/  IN_Old_South_Arabian}');
Expect(1, 68223, '\p{inoldsoutharabian}', "");
Expect(0, 68223, '\p{^inoldsoutharabian}', "");
Expect(0, 68223, '\P{inoldsoutharabian}', "");
Expect(1, 68223, '\P{^inoldsoutharabian}', "");
Expect(0, 68224, '\p{inoldsoutharabian}', "");
Expect(1, 68224, '\p{^inoldsoutharabian}', "");
Expect(1, 68224, '\P{inoldsoutharabian}', "");
Expect(0, 68224, '\P{^inoldsoutharabian}', "");
Expect(1, 68223, '\p{	In_Old_South_arabian}', "");
Expect(0, 68223, '\p{^	In_Old_South_arabian}', "");
Expect(0, 68223, '\P{	In_Old_South_arabian}', "");
Expect(1, 68223, '\P{^	In_Old_South_arabian}', "");
Expect(0, 68224, '\p{	In_Old_South_arabian}', "");
Expect(1, 68224, '\p{^	In_Old_South_arabian}', "");
Expect(1, 68224, '\P{	In_Old_South_arabian}', "");
Expect(0, 68224, '\P{^	In_Old_South_arabian}', "");
Error('\p{-:=IN_OLD_South_Arabian}');
Error('\P{-:=IN_OLD_South_Arabian}');
Expect(1, 68223, '\p{ -IN_Old_south_Arabian}', "");
Expect(0, 68223, '\p{^ -IN_Old_south_Arabian}', "");
Expect(0, 68223, '\P{ -IN_Old_south_Arabian}', "");
Expect(1, 68223, '\P{^ -IN_Old_south_Arabian}', "");
Expect(0, 68224, '\p{ -IN_Old_south_Arabian}', "");
Expect(1, 68224, '\p{^ -IN_Old_south_Arabian}', "");
Expect(1, 68224, '\P{ -IN_Old_south_Arabian}', "");
Expect(0, 68224, '\P{^ -IN_Old_south_Arabian}', "");
Error('\p{	:=IN_old_turkic}');
Error('\P{	:=IN_old_turkic}');
Expect(1, 68687, '\p{inoldturkic}', "");
Expect(0, 68687, '\p{^inoldturkic}', "");
Expect(0, 68687, '\P{inoldturkic}', "");
Expect(1, 68687, '\P{^inoldturkic}', "");
Expect(0, 68688, '\p{inoldturkic}', "");
Expect(1, 68688, '\p{^inoldturkic}', "");
Expect(1, 68688, '\P{inoldturkic}', "");
Expect(0, 68688, '\P{^inoldturkic}', "");
Expect(1, 68687, '\p{in_OLD_Turkic}', "");
Expect(0, 68687, '\p{^in_OLD_Turkic}', "");
Expect(0, 68687, '\P{in_OLD_Turkic}', "");
Expect(1, 68687, '\P{^in_OLD_Turkic}', "");
Expect(0, 68688, '\p{in_OLD_Turkic}', "");
Expect(1, 68688, '\p{^in_OLD_Turkic}', "");
Expect(1, 68688, '\P{in_OLD_Turkic}', "");
Expect(0, 68688, '\P{^in_OLD_Turkic}', "");
Error('\p{--IN_old_TURKIC/a/}');
Error('\P{--IN_old_TURKIC/a/}');
Expect(1, 68687, '\p{  in_OLD_turkic}', "");
Expect(0, 68687, '\p{^  in_OLD_turkic}', "");
Expect(0, 68687, '\P{  in_OLD_turkic}', "");
Expect(1, 68687, '\P{^  in_OLD_turkic}', "");
Expect(0, 68688, '\p{  in_OLD_turkic}', "");
Expect(1, 68688, '\p{^  in_OLD_turkic}', "");
Expect(1, 68688, '\P{  in_OLD_turkic}', "");
Expect(0, 68688, '\P{^  in_OLD_turkic}', "");
Error('\p{:= IN_oriya}');
Error('\P{:= IN_oriya}');
Expect(1, 2943, '\p{inoriya}', "");
Expect(0, 2943, '\p{^inoriya}', "");
Expect(0, 2943, '\P{inoriya}', "");
Expect(1, 2943, '\P{^inoriya}', "");
Expect(0, 2944, '\p{inoriya}', "");
Expect(1, 2944, '\p{^inoriya}', "");
Expect(1, 2944, '\P{inoriya}', "");
Expect(0, 2944, '\P{^inoriya}', "");
Expect(1, 2943, '\p{ -In_oriya}', "");
Expect(0, 2943, '\p{^ -In_oriya}', "");
Expect(0, 2943, '\P{ -In_oriya}', "");
Expect(1, 2943, '\P{^ -In_oriya}', "");
Expect(0, 2944, '\p{ -In_oriya}', "");
Expect(1, 2944, '\p{^ -In_oriya}', "");
Expect(1, 2944, '\P{ -In_oriya}', "");
Expect(0, 2944, '\P{^ -In_oriya}', "");
Error('\p{/a/ IN_Oriya}');
Error('\P{/a/ IN_Oriya}');
Expect(1, 2943, '\p{-In_ORIYA}', "");
Expect(0, 2943, '\p{^-In_ORIYA}', "");
Expect(0, 2943, '\P{-In_ORIYA}', "");
Expect(1, 2943, '\P{^-In_ORIYA}', "");
Expect(0, 2944, '\p{-In_ORIYA}', "");
Expect(1, 2944, '\p{^-In_ORIYA}', "");
Expect(1, 2944, '\P{-In_ORIYA}', "");
Expect(0, 2944, '\P{^-In_ORIYA}', "");
Error('\p{:=		in_OSMANYA}');
Error('\P{:=		in_OSMANYA}');
Expect(1, 66735, '\p{inosmanya}', "");
Expect(0, 66735, '\p{^inosmanya}', "");
Expect(0, 66735, '\P{inosmanya}', "");
Expect(1, 66735, '\P{^inosmanya}', "");
Expect(0, 66736, '\p{inosmanya}', "");
Expect(1, 66736, '\p{^inosmanya}', "");
Expect(1, 66736, '\P{inosmanya}', "");
Expect(0, 66736, '\P{^inosmanya}', "");
Expect(1, 66735, '\p{	_In_Osmanya}', "");
Expect(0, 66735, '\p{^	_In_Osmanya}', "");
Expect(0, 66735, '\P{	_In_Osmanya}', "");
Expect(1, 66735, '\P{^	_In_Osmanya}', "");
Expect(0, 66736, '\p{	_In_Osmanya}', "");
Expect(1, 66736, '\p{^	_In_Osmanya}', "");
Expect(1, 66736, '\P{	_In_Osmanya}', "");
Expect(0, 66736, '\P{^	_In_Osmanya}', "");
Error('\p{In_osmanya:=}');
Error('\P{In_osmanya:=}');
Expect(1, 66735, '\p{-In_Osmanya}', "");
Expect(0, 66735, '\p{^-In_Osmanya}', "");
Expect(0, 66735, '\P{-In_Osmanya}', "");
Expect(1, 66735, '\P{^-In_Osmanya}', "");
Expect(0, 66736, '\p{-In_Osmanya}', "");
Expect(1, 66736, '\p{^-In_Osmanya}', "");
Expect(1, 66736, '\P{-In_Osmanya}', "");
Expect(0, 66736, '\P{^-In_Osmanya}', "");
Error('\p{/a/-in_PHAGS_Pa}');
Error('\P{/a/-in_PHAGS_Pa}');
Expect(1, 43135, '\p{inphagspa}', "");
Expect(0, 43135, '\p{^inphagspa}', "");
Expect(0, 43135, '\P{inphagspa}', "");
Expect(1, 43135, '\P{^inphagspa}', "");
Expect(0, 43136, '\p{inphagspa}', "");
Expect(1, 43136, '\p{^inphagspa}', "");
Expect(1, 43136, '\P{inphagspa}', "");
Expect(0, 43136, '\P{^inphagspa}', "");
Expect(1, 43135, '\p{_in_Phags_Pa}', "");
Expect(0, 43135, '\p{^_in_Phags_Pa}', "");
Expect(0, 43135, '\P{_in_Phags_Pa}', "");
Expect(1, 43135, '\P{^_in_Phags_Pa}', "");
Expect(0, 43136, '\p{_in_Phags_Pa}', "");
Expect(1, 43136, '\p{^_in_Phags_Pa}', "");
Expect(1, 43136, '\P{_in_Phags_Pa}', "");
Expect(0, 43136, '\P{^_in_Phags_Pa}', "");
Error('\p{:=- in_Phags_Pa}');
Error('\P{:=- in_Phags_Pa}');
Expect(1, 43135, '\p{_	In_Phags_PA}', "");
Expect(0, 43135, '\p{^_	In_Phags_PA}', "");
Expect(0, 43135, '\P{_	In_Phags_PA}', "");
Expect(1, 43135, '\P{^_	In_Phags_PA}', "");
Expect(0, 43136, '\p{_	In_Phags_PA}', "");
Expect(1, 43136, '\p{^_	In_Phags_PA}', "");
Expect(1, 43136, '\P{_	In_Phags_PA}', "");
Expect(0, 43136, '\P{^_	In_Phags_PA}', "");
Error('\p{/a/ In_phoenician}');
Error('\P{/a/ In_phoenician}');
Expect(1, 67871, '\p{inphoenician}', "");
Expect(0, 67871, '\p{^inphoenician}', "");
Expect(0, 67871, '\P{inphoenician}', "");
Expect(1, 67871, '\P{^inphoenician}', "");
Expect(0, 67872, '\p{inphoenician}', "");
Expect(1, 67872, '\p{^inphoenician}', "");
Expect(1, 67872, '\P{inphoenician}', "");
Expect(0, 67872, '\P{^inphoenician}', "");
Expect(1, 67871, '\p{		In_Phoenician}', "");
Expect(0, 67871, '\p{^		In_Phoenician}', "");
Expect(0, 67871, '\P{		In_Phoenician}', "");
Expect(1, 67871, '\P{^		In_Phoenician}', "");
Expect(0, 67872, '\p{		In_Phoenician}', "");
Expect(1, 67872, '\p{^		In_Phoenician}', "");
Expect(1, 67872, '\P{		In_Phoenician}', "");
Expect(0, 67872, '\P{^		In_Phoenician}', "");
Error('\p{ :=In_PHOENICIAN}');
Error('\P{ :=In_PHOENICIAN}');
Expect(1, 67871, '\p{__In_PHOENICIAN}', "");
Expect(0, 67871, '\p{^__In_PHOENICIAN}', "");
Expect(0, 67871, '\P{__In_PHOENICIAN}', "");
Expect(1, 67871, '\P{^__In_PHOENICIAN}', "");
Expect(0, 67872, '\p{__In_PHOENICIAN}', "");
Expect(1, 67872, '\p{^__In_PHOENICIAN}', "");
Expect(1, 67872, '\P{__In_PHOENICIAN}', "");
Expect(0, 67872, '\P{^__In_PHOENICIAN}', "");
Error('\p{	/a/In_rejang}');
Error('\P{	/a/In_rejang}');
Expect(1, 43359, '\p{inrejang}', "");
Expect(0, 43359, '\p{^inrejang}', "");
Expect(0, 43359, '\P{inrejang}', "");
Expect(1, 43359, '\P{^inrejang}', "");
Expect(0, 43360, '\p{inrejang}', "");
Expect(1, 43360, '\p{^inrejang}', "");
Expect(1, 43360, '\P{inrejang}', "");
Expect(0, 43360, '\P{^inrejang}', "");
Expect(1, 43359, '\p{  In_rejang}', "");
Expect(0, 43359, '\p{^  In_rejang}', "");
Expect(0, 43359, '\P{  In_rejang}', "");
Expect(1, 43359, '\P{^  In_rejang}', "");
Expect(0, 43360, '\p{  In_rejang}', "");
Expect(1, 43360, '\p{^  In_rejang}', "");
Expect(1, 43360, '\P{  In_rejang}', "");
Expect(0, 43360, '\P{^  In_rejang}', "");
Error('\p{/a/IN_rejang}');
Error('\P{/a/IN_rejang}');
Expect(1, 43359, '\p{ In_rejang}', "");
Expect(0, 43359, '\p{^ In_rejang}', "");
Expect(0, 43359, '\P{ In_rejang}', "");
Expect(1, 43359, '\P{^ In_rejang}', "");
Expect(0, 43360, '\p{ In_rejang}', "");
Expect(1, 43360, '\p{^ In_rejang}', "");
Expect(1, 43360, '\P{ In_rejang}', "");
Expect(0, 43360, '\P{^ In_rejang}', "");
Error('\p{/a/ _In_Runic}');
Error('\P{/a/ _In_Runic}');
Expect(1, 5887, '\p{inrunic}', "");
Expect(0, 5887, '\p{^inrunic}', "");
Expect(0, 5887, '\P{inrunic}', "");
Expect(1, 5887, '\P{^inrunic}', "");
Expect(0, 5888, '\p{inrunic}', "");
Expect(1, 5888, '\p{^inrunic}', "");
Expect(1, 5888, '\P{inrunic}', "");
Expect(0, 5888, '\P{^inrunic}', "");
Expect(1, 5887, '\p{-	In_Runic}', "");
Expect(0, 5887, '\p{^-	In_Runic}', "");
Expect(0, 5887, '\P{-	In_Runic}', "");
Expect(1, 5887, '\P{^-	In_Runic}', "");
Expect(0, 5888, '\p{-	In_Runic}', "");
Expect(1, 5888, '\p{^-	In_Runic}', "");
Expect(1, 5888, '\P{-	In_Runic}', "");
Expect(0, 5888, '\P{^-	In_Runic}', "");
Error('\p{-:=in_runic}');
Error('\P{-:=in_runic}');
Expect(1, 5887, '\p{ _IN_Runic}', "");
Expect(0, 5887, '\p{^ _IN_Runic}', "");
Expect(0, 5887, '\P{ _IN_Runic}', "");
Expect(1, 5887, '\P{^ _IN_Runic}', "");
Expect(0, 5888, '\p{ _IN_Runic}', "");
Expect(1, 5888, '\p{^ _IN_Runic}', "");
Expect(1, 5888, '\P{ _IN_Runic}', "");
Expect(0, 5888, '\P{^ _IN_Runic}', "");
Error('\p{/a/_In_SAMARITAN}');
Error('\P{/a/_In_SAMARITAN}');
Expect(1, 2111, '\p{insamaritan}', "");
Expect(0, 2111, '\p{^insamaritan}', "");
Expect(0, 2111, '\P{insamaritan}', "");
Expect(1, 2111, '\P{^insamaritan}', "");
Expect(0, 2112, '\p{insamaritan}', "");
Expect(1, 2112, '\p{^insamaritan}', "");
Expect(1, 2112, '\P{insamaritan}', "");
Expect(0, 2112, '\P{^insamaritan}', "");
Expect(1, 2111, '\p{__In_SAMARITAN}', "");
Expect(0, 2111, '\p{^__In_SAMARITAN}', "");
Expect(0, 2111, '\P{__In_SAMARITAN}', "");
Expect(1, 2111, '\P{^__In_SAMARITAN}', "");
Expect(0, 2112, '\p{__In_SAMARITAN}', "");
Expect(1, 2112, '\p{^__In_SAMARITAN}', "");
Expect(1, 2112, '\P{__In_SAMARITAN}', "");
Expect(0, 2112, '\P{^__In_SAMARITAN}', "");
Error('\p{/a/In_samaritan}');
Error('\P{/a/In_samaritan}');
Expect(1, 2111, '\p{__In_samaritan}', "");
Expect(0, 2111, '\p{^__In_samaritan}', "");
Expect(0, 2111, '\P{__In_samaritan}', "");
Expect(1, 2111, '\P{^__In_samaritan}', "");
Expect(0, 2112, '\p{__In_samaritan}', "");
Expect(1, 2112, '\p{^__In_samaritan}', "");
Expect(1, 2112, '\P{__In_samaritan}', "");
Expect(0, 2112, '\P{^__In_samaritan}', "");
Error('\p{	In_Saurashtra:=}');
Error('\P{	In_Saurashtra:=}');
Expect(1, 43231, '\p{insaurashtra}', "");
Expect(0, 43231, '\p{^insaurashtra}', "");
Expect(0, 43231, '\P{insaurashtra}', "");
Expect(1, 43231, '\P{^insaurashtra}', "");
Expect(0, 43232, '\p{insaurashtra}', "");
Expect(1, 43232, '\p{^insaurashtra}', "");
Expect(1, 43232, '\P{insaurashtra}', "");
Expect(0, 43232, '\P{^insaurashtra}', "");
Expect(1, 43231, '\p{__In_SAURASHTRA}', "");
Expect(0, 43231, '\p{^__In_SAURASHTRA}', "");
Expect(0, 43231, '\P{__In_SAURASHTRA}', "");
Expect(1, 43231, '\P{^__In_SAURASHTRA}', "");
Expect(0, 43232, '\p{__In_SAURASHTRA}', "");
Expect(1, 43232, '\p{^__In_SAURASHTRA}', "");
Expect(1, 43232, '\P{__In_SAURASHTRA}', "");
Expect(0, 43232, '\P{^__In_SAURASHTRA}', "");
Error('\p{_-In_SAURASHTRA:=}');
Error('\P{_-In_SAURASHTRA:=}');
Expect(1, 43231, '\p{- in_Saurashtra}', "");
Expect(0, 43231, '\p{^- in_Saurashtra}', "");
Expect(0, 43231, '\P{- in_Saurashtra}', "");
Expect(1, 43231, '\P{^- in_Saurashtra}', "");
Expect(0, 43232, '\p{- in_Saurashtra}', "");
Expect(1, 43232, '\p{^- in_Saurashtra}', "");
Expect(1, 43232, '\P{- in_Saurashtra}', "");
Expect(0, 43232, '\P{^- in_Saurashtra}', "");
Error('\p{:= IN_Sharada}');
Error('\P{:= IN_Sharada}');
Expect(1, 70111, '\p{insharada}', "");
Expect(0, 70111, '\p{^insharada}', "");
Expect(0, 70111, '\P{insharada}', "");
Expect(1, 70111, '\P{^insharada}', "");
Expect(0, 70112, '\p{insharada}', "");
Expect(1, 70112, '\p{^insharada}', "");
Expect(1, 70112, '\P{insharada}', "");
Expect(0, 70112, '\P{^insharada}', "");
Expect(1, 70111, '\p{ In_sharada}', "");
Expect(0, 70111, '\p{^ In_sharada}', "");
Expect(0, 70111, '\P{ In_sharada}', "");
Expect(1, 70111, '\P{^ In_sharada}', "");
Expect(0, 70112, '\p{ In_sharada}', "");
Expect(1, 70112, '\p{^ In_sharada}', "");
Expect(1, 70112, '\P{ In_sharada}', "");
Expect(0, 70112, '\P{^ In_sharada}', "");
Error('\p{	in_Sharada/a/}');
Error('\P{	in_Sharada/a/}');
Expect(1, 70111, '\p{-In_Sharada}', "");
Expect(0, 70111, '\p{^-In_Sharada}', "");
Expect(0, 70111, '\P{-In_Sharada}', "");
Expect(1, 70111, '\P{^-In_Sharada}', "");
Expect(0, 70112, '\p{-In_Sharada}', "");
Expect(1, 70112, '\p{^-In_Sharada}', "");
Expect(1, 70112, '\P{-In_Sharada}', "");
Expect(0, 70112, '\P{^-In_Sharada}', "");
Error('\p{_/a/In_Shavian}');
Error('\P{_/a/In_Shavian}');
Expect(1, 66687, '\p{inshavian}', "");
Expect(0, 66687, '\p{^inshavian}', "");
Expect(0, 66687, '\P{inshavian}', "");
Expect(1, 66687, '\P{^inshavian}', "");
Expect(0, 66688, '\p{inshavian}', "");
Expect(1, 66688, '\p{^inshavian}', "");
Expect(1, 66688, '\P{inshavian}', "");
Expect(0, 66688, '\P{^inshavian}', "");
Expect(1, 66687, '\p{ In_Shavian}', "");
Expect(0, 66687, '\p{^ In_Shavian}', "");
Expect(0, 66687, '\P{ In_Shavian}', "");
Expect(1, 66687, '\P{^ In_Shavian}', "");
Expect(0, 66688, '\p{ In_Shavian}', "");
Expect(1, 66688, '\p{^ In_Shavian}', "");
Expect(1, 66688, '\P{ In_Shavian}', "");
Expect(0, 66688, '\P{^ In_Shavian}', "");
Error('\p{ /a/In_SHAVIAN}');
Error('\P{ /a/In_SHAVIAN}');
Expect(1, 66687, '\p{ IN_Shavian}', "");
Expect(0, 66687, '\p{^ IN_Shavian}', "");
Expect(0, 66687, '\P{ IN_Shavian}', "");
Expect(1, 66687, '\P{^ IN_Shavian}', "");
Expect(0, 66688, '\p{ IN_Shavian}', "");
Expect(1, 66688, '\p{^ IN_Shavian}', "");
Expect(1, 66688, '\P{ IN_Shavian}', "");
Expect(0, 66688, '\P{^ IN_Shavian}', "");
Error('\p{/a/__in_Sinhala}');
Error('\P{/a/__in_Sinhala}');
Expect(1, 3583, '\p{insinhala}', "");
Expect(0, 3583, '\p{^insinhala}', "");
Expect(0, 3583, '\P{insinhala}', "");
Expect(1, 3583, '\P{^insinhala}', "");
Expect(0, 3584, '\p{insinhala}', "");
Expect(1, 3584, '\p{^insinhala}', "");
Expect(1, 3584, '\P{insinhala}', "");
Expect(0, 3584, '\P{^insinhala}', "");
Expect(1, 3583, '\p{__in_Sinhala}', "");
Expect(0, 3583, '\p{^__in_Sinhala}', "");
Expect(0, 3583, '\P{__in_Sinhala}', "");
Expect(1, 3583, '\P{^__in_Sinhala}', "");
Expect(0, 3584, '\p{__in_Sinhala}', "");
Expect(1, 3584, '\p{^__in_Sinhala}', "");
Expect(1, 3584, '\P{__in_Sinhala}', "");
Expect(0, 3584, '\P{^__in_Sinhala}', "");
Error('\p{/a/In_sinhala}');
Error('\P{/a/In_sinhala}');
Expect(1, 3583, '\p{-	In_Sinhala}', "");
Expect(0, 3583, '\p{^-	In_Sinhala}', "");
Expect(0, 3583, '\P{-	In_Sinhala}', "");
Expect(1, 3583, '\P{^-	In_Sinhala}', "");
Expect(0, 3584, '\p{-	In_Sinhala}', "");
Expect(1, 3584, '\p{^-	In_Sinhala}', "");
Expect(1, 3584, '\P{-	In_Sinhala}', "");
Expect(0, 3584, '\P{^-	In_Sinhala}', "");
Error('\p{ -IN_Sora_SOMPENG/a/}');
Error('\P{ -IN_Sora_SOMPENG/a/}');
Expect(1, 69887, '\p{insorasompeng}', "");
Expect(0, 69887, '\p{^insorasompeng}', "");
Expect(0, 69887, '\P{insorasompeng}', "");
Expect(1, 69887, '\P{^insorasompeng}', "");
Expect(0, 69888, '\p{insorasompeng}', "");
Expect(1, 69888, '\p{^insorasompeng}', "");
Expect(1, 69888, '\P{insorasompeng}', "");
Expect(0, 69888, '\P{^insorasompeng}', "");
Expect(1, 69887, '\p{ in_sora_sompeng}', "");
Expect(0, 69887, '\p{^ in_sora_sompeng}', "");
Expect(0, 69887, '\P{ in_sora_sompeng}', "");
Expect(1, 69887, '\P{^ in_sora_sompeng}', "");
Expect(0, 69888, '\p{ in_sora_sompeng}', "");
Expect(1, 69888, '\p{^ in_sora_sompeng}', "");
Expect(1, 69888, '\P{ in_sora_sompeng}', "");
Expect(0, 69888, '\P{^ in_sora_sompeng}', "");
Error('\p{:=  IN_sora_SOMPENG}');
Error('\P{:=  IN_sora_SOMPENG}');
Expect(1, 69887, '\p{ In_Sora_Sompeng}', "");
Expect(0, 69887, '\p{^ In_Sora_Sompeng}', "");
Expect(0, 69887, '\P{ In_Sora_Sompeng}', "");
Expect(1, 69887, '\P{^ In_Sora_Sompeng}', "");
Expect(0, 69888, '\p{ In_Sora_Sompeng}', "");
Expect(1, 69888, '\p{^ In_Sora_Sompeng}', "");
Expect(1, 69888, '\P{ In_Sora_Sompeng}', "");
Expect(0, 69888, '\P{^ In_Sora_Sompeng}', "");
Error('\p{_:=In_sundanese}');
Error('\P{_:=In_sundanese}');
Expect(1, 7103, '\p{insundanese}', "");
Expect(0, 7103, '\p{^insundanese}', "");
Expect(0, 7103, '\P{insundanese}', "");
Expect(1, 7103, '\P{^insundanese}', "");
Expect(0, 7104, '\p{insundanese}', "");
Expect(1, 7104, '\p{^insundanese}', "");
Expect(1, 7104, '\P{insundanese}', "");
Expect(0, 7104, '\P{^insundanese}', "");
Expect(1, 7103, '\p{IN_Sundanese}', "");
Expect(0, 7103, '\p{^IN_Sundanese}', "");
Expect(0, 7103, '\P{IN_Sundanese}', "");
Expect(1, 7103, '\P{^IN_Sundanese}', "");
Expect(0, 7104, '\p{IN_Sundanese}', "");
Expect(1, 7104, '\p{^IN_Sundanese}', "");
Expect(1, 7104, '\P{IN_Sundanese}', "");
Expect(0, 7104, '\P{^IN_Sundanese}', "");
Error('\p{-:=in_SUNDANESE}');
Error('\P{-:=in_SUNDANESE}');
Expect(1, 7103, '\p{-_in_Sundanese}', "");
Expect(0, 7103, '\p{^-_in_Sundanese}', "");
Expect(0, 7103, '\P{-_in_Sundanese}', "");
Expect(1, 7103, '\P{^-_in_Sundanese}', "");
Expect(0, 7104, '\p{-_in_Sundanese}', "");
Expect(1, 7104, '\p{^-_in_Sundanese}', "");
Expect(1, 7104, '\P{-_in_Sundanese}', "");
Expect(0, 7104, '\P{^-_in_Sundanese}', "");
Error('\p{:=		IN_SYLOTI_nagri}');
Error('\P{:=		IN_SYLOTI_nagri}');
Expect(1, 43055, '\p{insylotinagri}', "");
Expect(0, 43055, '\p{^insylotinagri}', "");
Expect(0, 43055, '\P{insylotinagri}', "");
Expect(1, 43055, '\P{^insylotinagri}', "");
Expect(0, 43056, '\p{insylotinagri}', "");
Expect(1, 43056, '\p{^insylotinagri}', "");
Expect(1, 43056, '\P{insylotinagri}', "");
Expect(0, 43056, '\P{^insylotinagri}', "");
Expect(1, 43055, '\p{	-IN_Syloti_nagri}', "");
Expect(0, 43055, '\p{^	-IN_Syloti_nagri}', "");
Expect(0, 43055, '\P{	-IN_Syloti_nagri}', "");
Expect(1, 43055, '\P{^	-IN_Syloti_nagri}', "");
Expect(0, 43056, '\p{	-IN_Syloti_nagri}', "");
Expect(1, 43056, '\p{^	-IN_Syloti_nagri}', "");
Expect(1, 43056, '\P{	-IN_Syloti_nagri}', "");
Expect(0, 43056, '\P{^	-IN_Syloti_nagri}', "");
Error('\p{	 In_SYLOTI_Nagri:=}');
Error('\P{	 In_SYLOTI_Nagri:=}');
Expect(1, 43055, '\p{	 IN_syloti_NAGRI}', "");
Expect(0, 43055, '\p{^	 IN_syloti_NAGRI}', "");
Expect(0, 43055, '\P{	 IN_syloti_NAGRI}', "");
Expect(1, 43055, '\P{^	 IN_syloti_NAGRI}', "");
Expect(0, 43056, '\p{	 IN_syloti_NAGRI}', "");
Expect(1, 43056, '\p{^	 IN_syloti_NAGRI}', "");
Expect(1, 43056, '\P{	 IN_syloti_NAGRI}', "");
Expect(0, 43056, '\P{^	 IN_syloti_NAGRI}', "");
Error('\p{:=In_Syriac}');
Error('\P{:=In_Syriac}');
Expect(1, 1871, '\p{insyriac}', "");
Expect(0, 1871, '\p{^insyriac}', "");
Expect(0, 1871, '\P{insyriac}', "");
Expect(1, 1871, '\P{^insyriac}', "");
Expect(0, 1872, '\p{insyriac}', "");
Expect(1, 1872, '\p{^insyriac}', "");
Expect(1, 1872, '\P{insyriac}', "");
Expect(0, 1872, '\P{^insyriac}', "");
Expect(1, 1871, '\p{-	In_SYRIAC}', "");
Expect(0, 1871, '\p{^-	In_SYRIAC}', "");
Expect(0, 1871, '\P{-	In_SYRIAC}', "");
Expect(1, 1871, '\P{^-	In_SYRIAC}', "");
Expect(0, 1872, '\p{-	In_SYRIAC}', "");
Expect(1, 1872, '\p{^-	In_SYRIAC}', "");
Expect(1, 1872, '\P{-	In_SYRIAC}', "");
Expect(0, 1872, '\P{^-	In_SYRIAC}', "");
Error('\p{/a/_-In_syriac}');
Error('\P{/a/_-In_syriac}');
Expect(1, 1871, '\p{-	IN_syriac}', "");
Expect(0, 1871, '\p{^-	IN_syriac}', "");
Expect(0, 1871, '\P{-	IN_syriac}', "");
Expect(1, 1871, '\P{^-	IN_syriac}', "");
Expect(0, 1872, '\p{-	IN_syriac}', "");
Expect(1, 1872, '\p{^-	IN_syriac}', "");
Expect(1, 1872, '\P{-	IN_syriac}', "");
Expect(0, 1872, '\P{^-	IN_syriac}', "");
Error('\p{ /a/In_tagalog}');
Error('\P{ /a/In_tagalog}');
Expect(1, 5919, '\p{intagalog}', "");
Expect(0, 5919, '\p{^intagalog}', "");
Expect(0, 5919, '\P{intagalog}', "");
Expect(1, 5919, '\P{^intagalog}', "");
Expect(0, 5920, '\p{intagalog}', "");
Expect(1, 5920, '\p{^intagalog}', "");
Expect(1, 5920, '\P{intagalog}', "");
Expect(0, 5920, '\P{^intagalog}', "");
Expect(1, 5919, '\p{ In_TAGALOG}', "");
Expect(0, 5919, '\p{^ In_TAGALOG}', "");
Expect(0, 5919, '\P{ In_TAGALOG}', "");
Expect(1, 5919, '\P{^ In_TAGALOG}', "");
Expect(0, 5920, '\p{ In_TAGALOG}', "");
Expect(1, 5920, '\p{^ In_TAGALOG}', "");
Expect(1, 5920, '\P{ In_TAGALOG}', "");
Expect(0, 5920, '\P{^ In_TAGALOG}', "");
Error('\p{/a/_In_Tagalog}');
Error('\P{/a/_In_Tagalog}');
Expect(1, 5919, '\p{-_In_tagalog}', "");
Expect(0, 5919, '\p{^-_In_tagalog}', "");
Expect(0, 5919, '\P{-_In_tagalog}', "");
Expect(1, 5919, '\P{^-_In_tagalog}', "");
Expect(0, 5920, '\p{-_In_tagalog}', "");
Expect(1, 5920, '\p{^-_In_tagalog}', "");
Expect(1, 5920, '\P{-_In_tagalog}', "");
Expect(0, 5920, '\P{^-_In_tagalog}', "");
Error('\p{:=  In_TAGBANWA}');
Error('\P{:=  In_TAGBANWA}');
Expect(1, 6015, '\p{intagbanwa}', "");
Expect(0, 6015, '\p{^intagbanwa}', "");
Expect(0, 6015, '\P{intagbanwa}', "");
Expect(1, 6015, '\P{^intagbanwa}', "");
Expect(0, 6016, '\p{intagbanwa}', "");
Expect(1, 6016, '\p{^intagbanwa}', "");
Expect(1, 6016, '\P{intagbanwa}', "");
Expect(0, 6016, '\P{^intagbanwa}', "");
Expect(1, 6015, '\p{_-In_tagbanwa}', "");
Expect(0, 6015, '\p{^_-In_tagbanwa}', "");
Expect(0, 6015, '\P{_-In_tagbanwa}', "");
Expect(1, 6015, '\P{^_-In_tagbanwa}', "");
Expect(0, 6016, '\p{_-In_tagbanwa}', "");
Expect(1, 6016, '\p{^_-In_tagbanwa}', "");
Expect(1, 6016, '\P{_-In_tagbanwa}', "");
Expect(0, 6016, '\P{^_-In_tagbanwa}', "");
Error('\p{-:=IN_tagbanwa}');
Error('\P{-:=IN_tagbanwa}');
Expect(1, 6015, '\p{- IN_tagbanwa}', "");
Expect(0, 6015, '\p{^- IN_tagbanwa}', "");
Expect(0, 6015, '\P{- IN_tagbanwa}', "");
Expect(1, 6015, '\P{^- IN_tagbanwa}', "");
Expect(0, 6016, '\p{- IN_tagbanwa}', "");
Expect(1, 6016, '\p{^- IN_tagbanwa}', "");
Expect(1, 6016, '\P{- IN_tagbanwa}', "");
Expect(0, 6016, '\P{^- IN_tagbanwa}', "");
Error('\p{ :=in_tai_le}');
Error('\P{ :=in_tai_le}');
Expect(1, 6527, '\p{intaile}', "");
Expect(0, 6527, '\p{^intaile}', "");
Expect(0, 6527, '\P{intaile}', "");
Expect(1, 6527, '\P{^intaile}', "");
Expect(0, 6528, '\p{intaile}', "");
Expect(1, 6528, '\p{^intaile}', "");
Expect(1, 6528, '\P{intaile}', "");
Expect(0, 6528, '\P{^intaile}', "");
Expect(1, 6527, '\p{	-IN_TAI_le}', "");
Expect(0, 6527, '\p{^	-IN_TAI_le}', "");
Expect(0, 6527, '\P{	-IN_TAI_le}', "");
Expect(1, 6527, '\P{^	-IN_TAI_le}', "");
Expect(0, 6528, '\p{	-IN_TAI_le}', "");
Expect(1, 6528, '\p{^	-IN_TAI_le}', "");
Expect(1, 6528, '\P{	-IN_TAI_le}', "");
Expect(0, 6528, '\P{^	-IN_TAI_le}', "");
Error('\p{:=- In_Tai_le}');
Error('\P{:=- In_Tai_le}');
Expect(1, 6527, '\p{ In_Tai_Le}', "");
Expect(0, 6527, '\p{^ In_Tai_Le}', "");
Expect(0, 6527, '\P{ In_Tai_Le}', "");
Expect(1, 6527, '\P{^ In_Tai_Le}', "");
Expect(0, 6528, '\p{ In_Tai_Le}', "");
Expect(1, 6528, '\p{^ In_Tai_Le}', "");
Expect(1, 6528, '\P{ In_Tai_Le}', "");
Expect(0, 6528, '\P{^ In_Tai_Le}', "");
Error('\p{_/a/in_Tai_Tham}');
Error('\P{_/a/in_Tai_Tham}');
Expect(1, 6831, '\p{intaitham}', "");
Expect(0, 6831, '\p{^intaitham}', "");
Expect(0, 6831, '\P{intaitham}', "");
Expect(1, 6831, '\P{^intaitham}', "");
Expect(0, 6832, '\p{intaitham}', "");
Expect(1, 6832, '\p{^intaitham}', "");
Expect(1, 6832, '\P{intaitham}', "");
Expect(0, 6832, '\P{^intaitham}', "");
Expect(1, 6831, '\p{ -In_Tai_tham}', "");
Expect(0, 6831, '\p{^ -In_Tai_tham}', "");
Expect(0, 6831, '\P{ -In_Tai_tham}', "");
Expect(1, 6831, '\P{^ -In_Tai_tham}', "");
Expect(0, 6832, '\p{ -In_Tai_tham}', "");
Expect(1, 6832, '\p{^ -In_Tai_tham}', "");
Expect(1, 6832, '\P{ -In_Tai_tham}', "");
Expect(0, 6832, '\P{^ -In_Tai_tham}', "");
Error('\p{-	In_Tai_tham:=}');
Error('\P{-	In_Tai_tham:=}');
Expect(1, 6831, '\p{- In_tai_Tham}', "");
Expect(0, 6831, '\p{^- In_tai_Tham}', "");
Expect(0, 6831, '\P{- In_tai_Tham}', "");
Expect(1, 6831, '\P{^- In_tai_Tham}', "");
Expect(0, 6832, '\p{- In_tai_Tham}', "");
Expect(1, 6832, '\p{^- In_tai_Tham}', "");
Expect(1, 6832, '\P{- In_tai_Tham}', "");
Expect(0, 6832, '\P{^- In_tai_Tham}', "");
Error('\p{	_IN_tai_Viet:=}');
Error('\P{	_IN_tai_Viet:=}');
Expect(1, 43743, '\p{intaiviet}', "");
Expect(0, 43743, '\p{^intaiviet}', "");
Expect(0, 43743, '\P{intaiviet}', "");
Expect(1, 43743, '\P{^intaiviet}', "");
Expect(0, 43744, '\p{intaiviet}', "");
Expect(1, 43744, '\p{^intaiviet}', "");
Expect(1, 43744, '\P{intaiviet}', "");
Expect(0, 43744, '\P{^intaiviet}', "");
Expect(1, 43743, '\p{ _in_Tai_Viet}', "");
Expect(0, 43743, '\p{^ _in_Tai_Viet}', "");
Expect(0, 43743, '\P{ _in_Tai_Viet}', "");
Expect(1, 43743, '\P{^ _in_Tai_Viet}', "");
Expect(0, 43744, '\p{ _in_Tai_Viet}', "");
Expect(1, 43744, '\p{^ _in_Tai_Viet}', "");
Expect(1, 43744, '\P{ _in_Tai_Viet}', "");
Expect(0, 43744, '\P{^ _in_Tai_Viet}', "");
Error('\p{:=__In_tai_viet}');
Error('\P{:=__In_tai_viet}');
Expect(1, 43743, '\p{  In_tai_Viet}', "");
Expect(0, 43743, '\p{^  In_tai_Viet}', "");
Expect(0, 43743, '\P{  In_tai_Viet}', "");
Expect(1, 43743, '\P{^  In_tai_Viet}', "");
Expect(0, 43744, '\p{  In_tai_Viet}', "");
Expect(1, 43744, '\p{^  In_tai_Viet}', "");
Expect(1, 43744, '\P{  In_tai_Viet}', "");
Expect(0, 43744, '\P{^  In_tai_Viet}', "");
Error('\p{:=-	In_TAKRI}');
Error('\P{:=-	In_TAKRI}');
Expect(1, 71375, '\p{intakri}', "");
Expect(0, 71375, '\p{^intakri}', "");
Expect(0, 71375, '\P{intakri}', "");
Expect(1, 71375, '\P{^intakri}', "");
Expect(0, 71376, '\p{intakri}', "");
Expect(1, 71376, '\p{^intakri}', "");
Expect(1, 71376, '\P{intakri}', "");
Expect(0, 71376, '\P{^intakri}', "");
Expect(1, 71375, '\p{-In_takri}', "");
Expect(0, 71375, '\p{^-In_takri}', "");
Expect(0, 71375, '\P{-In_takri}', "");
Expect(1, 71375, '\P{^-In_takri}', "");
Expect(0, 71376, '\p{-In_takri}', "");
Expect(1, 71376, '\p{^-In_takri}', "");
Expect(1, 71376, '\P{-In_takri}', "");
Expect(0, 71376, '\P{^-In_takri}', "");
Error('\p{ 	In_takri:=}');
Error('\P{ 	In_takri:=}');
Expect(1, 71375, '\p{ IN_takri}', "");
Expect(0, 71375, '\p{^ IN_takri}', "");
Expect(0, 71375, '\P{ IN_takri}', "");
Expect(1, 71375, '\P{^ IN_takri}', "");
Expect(0, 71376, '\p{ IN_takri}', "");
Expect(1, 71376, '\p{^ IN_takri}', "");
Expect(1, 71376, '\P{ IN_takri}', "");
Expect(0, 71376, '\P{^ IN_takri}', "");
Error('\p{:=In_Tamil}');
Error('\P{:=In_Tamil}');
Expect(1, 3071, '\p{intamil}', "");
Expect(0, 3071, '\p{^intamil}', "");
Expect(0, 3071, '\P{intamil}', "");
Expect(1, 3071, '\P{^intamil}', "");
Expect(0, 3072, '\p{intamil}', "");
Expect(1, 3072, '\p{^intamil}', "");
Expect(1, 3072, '\P{intamil}', "");
Expect(0, 3072, '\P{^intamil}', "");
Expect(1, 3071, '\p{In_Tamil}', "");
Expect(0, 3071, '\p{^In_Tamil}', "");
Expect(0, 3071, '\P{In_Tamil}', "");
Expect(1, 3071, '\P{^In_Tamil}', "");
Expect(0, 3072, '\p{In_Tamil}', "");
Expect(1, 3072, '\p{^In_Tamil}', "");
Expect(1, 3072, '\P{In_Tamil}', "");
Expect(0, 3072, '\P{^In_Tamil}', "");
Error('\p{-IN_Tamil:=}');
Error('\P{-IN_Tamil:=}');
Expect(1, 3071, '\p{-in_Tamil}', "");
Expect(0, 3071, '\p{^-in_Tamil}', "");
Expect(0, 3071, '\P{-in_Tamil}', "");
Expect(1, 3071, '\P{^-in_Tamil}', "");
Expect(0, 3072, '\p{-in_Tamil}', "");
Expect(1, 3072, '\p{^-in_Tamil}', "");
Expect(1, 3072, '\P{-in_Tamil}', "");
Expect(0, 3072, '\P{^-in_Tamil}', "");
Error('\p{-_In_Telugu/a/}');
Error('\P{-_In_Telugu/a/}');
Expect(1, 3199, '\p{intelugu}', "");
Expect(0, 3199, '\p{^intelugu}', "");
Expect(0, 3199, '\P{intelugu}', "");
Expect(1, 3199, '\P{^intelugu}', "");
Expect(0, 3200, '\p{intelugu}', "");
Expect(1, 3200, '\p{^intelugu}', "");
Expect(1, 3200, '\P{intelugu}', "");
Expect(0, 3200, '\P{^intelugu}', "");
Expect(1, 3199, '\p{-IN_Telugu}', "");
Expect(0, 3199, '\p{^-IN_Telugu}', "");
Expect(0, 3199, '\P{-IN_Telugu}', "");
Expect(1, 3199, '\P{^-IN_Telugu}', "");
Expect(0, 3200, '\p{-IN_Telugu}', "");
Expect(1, 3200, '\p{^-IN_Telugu}', "");
Expect(1, 3200, '\P{-IN_Telugu}', "");
Expect(0, 3200, '\P{^-IN_Telugu}', "");
Error('\p{:=-	in_Telugu}');
Error('\P{:=-	in_Telugu}');
Expect(1, 3199, '\p{	in_TELUGU}', "");
Expect(0, 3199, '\p{^	in_TELUGU}', "");
Expect(0, 3199, '\P{	in_TELUGU}', "");
Expect(1, 3199, '\P{^	in_TELUGU}', "");
Expect(0, 3200, '\p{	in_TELUGU}', "");
Expect(1, 3200, '\p{^	in_TELUGU}', "");
Expect(1, 3200, '\P{	in_TELUGU}', "");
Expect(0, 3200, '\P{^	in_TELUGU}', "");
Error('\p{/a/	 IN_Thaana}');
Error('\P{/a/	 IN_Thaana}');
Expect(1, 1983, '\p{inthaana}', "");
Expect(0, 1983, '\p{^inthaana}', "");
Expect(0, 1983, '\P{inthaana}', "");
Expect(1, 1983, '\P{^inthaana}', "");
Expect(0, 1984, '\p{inthaana}', "");
Expect(1, 1984, '\p{^inthaana}', "");
Expect(1, 1984, '\P{inthaana}', "");
Expect(0, 1984, '\P{^inthaana}', "");
Expect(1, 1983, '\p{ 	IN_Thaana}', "");
Expect(0, 1983, '\p{^ 	IN_Thaana}', "");
Expect(0, 1983, '\P{ 	IN_Thaana}', "");
Expect(1, 1983, '\P{^ 	IN_Thaana}', "");
Expect(0, 1984, '\p{ 	IN_Thaana}', "");
Expect(1, 1984, '\p{^ 	IN_Thaana}', "");
Expect(1, 1984, '\P{ 	IN_Thaana}', "");
Expect(0, 1984, '\P{^ 	IN_Thaana}', "");
Error('\p{ in_Thaana/a/}');
Error('\P{ in_Thaana/a/}');
Expect(1, 1983, '\p{ In_THAANA}', "");
Expect(0, 1983, '\p{^ In_THAANA}', "");
Expect(0, 1983, '\P{ In_THAANA}', "");
Expect(1, 1983, '\P{^ In_THAANA}', "");
Expect(0, 1984, '\p{ In_THAANA}', "");
Expect(1, 1984, '\p{^ In_THAANA}', "");
Expect(1, 1984, '\P{ In_THAANA}', "");
Expect(0, 1984, '\P{^ In_THAANA}', "");
Error('\p{/a/ 	In_thai}');
Error('\P{/a/ 	In_thai}');
Expect(1, 3711, '\p{inthai}', "");
Expect(0, 3711, '\p{^inthai}', "");
Expect(0, 3711, '\P{inthai}', "");
Expect(1, 3711, '\P{^inthai}', "");
Expect(0, 3712, '\p{inthai}', "");
Expect(1, 3712, '\p{^inthai}', "");
Expect(1, 3712, '\P{inthai}', "");
Expect(0, 3712, '\P{^inthai}', "");
Expect(1, 3711, '\p{--In_thai}', "");
Expect(0, 3711, '\p{^--In_thai}', "");
Expect(0, 3711, '\P{--In_thai}', "");
Expect(1, 3711, '\P{^--In_thai}', "");
Expect(0, 3712, '\p{--In_thai}', "");
Expect(1, 3712, '\p{^--In_thai}', "");
Expect(1, 3712, '\P{--In_thai}', "");
Expect(0, 3712, '\P{^--In_thai}', "");
Error('\p{:=In_Thai}');
Error('\P{:=In_Thai}');
Expect(1, 3711, '\p{	-in_Thai}', "");
Expect(0, 3711, '\p{^	-in_Thai}', "");
Expect(0, 3711, '\P{	-in_Thai}', "");
Expect(1, 3711, '\P{^	-in_Thai}', "");
Expect(0, 3712, '\p{	-in_Thai}', "");
Expect(1, 3712, '\p{^	-in_Thai}', "");
Expect(1, 3712, '\P{	-in_Thai}', "");
Expect(0, 3712, '\P{^	-in_Thai}', "");
Error('\p{:=	In_TIBETAN}');
Error('\P{:=	In_TIBETAN}');
Expect(1, 4095, '\p{intibetan}', "");
Expect(0, 4095, '\p{^intibetan}', "");
Expect(0, 4095, '\P{intibetan}', "");
Expect(1, 4095, '\P{^intibetan}', "");
Expect(0, 4096, '\p{intibetan}', "");
Expect(1, 4096, '\p{^intibetan}', "");
Expect(1, 4096, '\P{intibetan}', "");
Expect(0, 4096, '\P{^intibetan}', "");
Expect(1, 4095, '\p{	IN_TIBETAN}', "");
Expect(0, 4095, '\p{^	IN_TIBETAN}', "");
Expect(0, 4095, '\P{	IN_TIBETAN}', "");
Expect(1, 4095, '\P{^	IN_TIBETAN}', "");
Expect(0, 4096, '\p{	IN_TIBETAN}', "");
Expect(1, 4096, '\p{^	IN_TIBETAN}', "");
Expect(1, 4096, '\P{	IN_TIBETAN}', "");
Expect(0, 4096, '\P{^	IN_TIBETAN}', "");
Error('\p{/a/_	In_tibetan}');
Error('\P{/a/_	In_tibetan}');
Expect(1, 4095, '\p{ In_Tibetan}', "");
Expect(0, 4095, '\p{^ In_Tibetan}', "");
Expect(0, 4095, '\P{ In_Tibetan}', "");
Expect(1, 4095, '\P{^ In_Tibetan}', "");
Expect(0, 4096, '\p{ In_Tibetan}', "");
Expect(1, 4096, '\p{^ In_Tibetan}', "");
Expect(1, 4096, '\P{ In_Tibetan}', "");
Expect(0, 4096, '\P{^ In_Tibetan}', "");
Error('\p{	In_Tifinagh:=}');
Error('\P{	In_Tifinagh:=}');
Expect(1, 11647, '\p{intifinagh}', "");
Expect(0, 11647, '\p{^intifinagh}', "");
Expect(0, 11647, '\P{intifinagh}', "");
Expect(1, 11647, '\P{^intifinagh}', "");
Expect(0, 11648, '\p{intifinagh}', "");
Expect(1, 11648, '\p{^intifinagh}', "");
Expect(1, 11648, '\P{intifinagh}', "");
Expect(0, 11648, '\P{^intifinagh}', "");
Expect(1, 11647, '\p{-_in_Tifinagh}', "");
Expect(0, 11647, '\p{^-_in_Tifinagh}', "");
Expect(0, 11647, '\P{-_in_Tifinagh}', "");
Expect(1, 11647, '\P{^-_in_Tifinagh}', "");
Expect(0, 11648, '\p{-_in_Tifinagh}', "");
Expect(1, 11648, '\p{^-_in_Tifinagh}', "");
Expect(1, 11648, '\P{-_in_Tifinagh}', "");
Expect(0, 11648, '\P{^-_in_Tifinagh}', "");
Error('\p{ In_Tifinagh/a/}');
Error('\P{ In_Tifinagh/a/}');
Expect(1, 11647, '\p{	_IN_Tifinagh}', "");
Expect(0, 11647, '\p{^	_IN_Tifinagh}', "");
Expect(0, 11647, '\P{	_IN_Tifinagh}', "");
Expect(1, 11647, '\P{^	_IN_Tifinagh}', "");
Expect(0, 11648, '\p{	_IN_Tifinagh}', "");
Expect(1, 11648, '\p{^	_IN_Tifinagh}', "");
Expect(1, 11648, '\P{	_IN_Tifinagh}', "");
Expect(0, 11648, '\P{^	_IN_Tifinagh}', "");
Error('\p{	IN_Ugaritic:=}');
Error('\P{	IN_Ugaritic:=}');
Expect(1, 66463, '\p{inugaritic}', "");
Expect(0, 66463, '\p{^inugaritic}', "");
Expect(0, 66463, '\P{inugaritic}', "");
Expect(1, 66463, '\P{^inugaritic}', "");
Expect(0, 66464, '\p{inugaritic}', "");
Expect(1, 66464, '\p{^inugaritic}', "");
Expect(1, 66464, '\P{inugaritic}', "");
Expect(0, 66464, '\P{^inugaritic}', "");
Expect(1, 66463, '\p{ -in_Ugaritic}', "");
Expect(0, 66463, '\p{^ -in_Ugaritic}', "");
Expect(0, 66463, '\P{ -in_Ugaritic}', "");
Expect(1, 66463, '\P{^ -in_Ugaritic}', "");
Expect(0, 66464, '\p{ -in_Ugaritic}', "");
Expect(1, 66464, '\p{^ -in_Ugaritic}', "");
Expect(1, 66464, '\P{ -in_Ugaritic}', "");
Expect(0, 66464, '\P{^ -in_Ugaritic}', "");
Error('\p{ :=in_ugaritic}');
Error('\P{ :=in_ugaritic}');
Expect(1, 66463, '\p{_-IN_ugaritic}', "");
Expect(0, 66463, '\p{^_-IN_ugaritic}', "");
Expect(0, 66463, '\P{_-IN_ugaritic}', "");
Expect(1, 66463, '\P{^_-IN_ugaritic}', "");
Expect(0, 66464, '\p{_-IN_ugaritic}', "");
Expect(1, 66464, '\p{^_-IN_ugaritic}', "");
Expect(1, 66464, '\P{_-IN_ugaritic}', "");
Expect(0, 66464, '\P{^_-IN_ugaritic}', "");
Error('\p{ :=In_VAI}');
Error('\P{ :=In_VAI}');
Expect(1, 42559, '\p{invai}', "");
Expect(0, 42559, '\p{^invai}', "");
Expect(0, 42559, '\P{invai}', "");
Expect(1, 42559, '\P{^invai}', "");
Expect(0, 42560, '\p{invai}', "");
Expect(1, 42560, '\p{^invai}', "");
Expect(1, 42560, '\P{invai}', "");
Expect(0, 42560, '\P{^invai}', "");
Expect(1, 42559, '\p{__IN_VAI}', "");
Expect(0, 42559, '\p{^__IN_VAI}', "");
Expect(0, 42559, '\P{__IN_VAI}', "");
Expect(1, 42559, '\P{^__IN_VAI}', "");
Expect(0, 42560, '\p{__IN_VAI}', "");
Expect(1, 42560, '\p{^__IN_VAI}', "");
Expect(1, 42560, '\P{__IN_VAI}', "");
Expect(0, 42560, '\P{^__IN_VAI}', "");
Error('\p{:= -In_Vai}');
Error('\P{:= -In_Vai}');
Expect(1, 42559, '\p{	 IN_vai}', "");
Expect(0, 42559, '\p{^	 IN_vai}', "");
Expect(0, 42559, '\P{	 IN_vai}', "");
Expect(1, 42559, '\P{^	 IN_vai}', "");
Expect(0, 42560, '\p{	 IN_vai}', "");
Expect(1, 42560, '\p{^	 IN_vai}', "");
Expect(1, 42560, '\P{	 IN_vai}', "");
Expect(0, 42560, '\P{^	 IN_vai}', "");
Error('\p{-/a/INHERITED}');
Error('\P{-/a/INHERITED}');
Expect(1, 917999, '\p{inherited}', "");
Expect(0, 917999, '\p{^inherited}', "");
Expect(0, 917999, '\P{inherited}', "");
Expect(1, 917999, '\P{^inherited}', "");
Expect(0, 918000, '\p{inherited}', "");
Expect(1, 918000, '\p{^inherited}', "");
Expect(1, 918000, '\P{inherited}', "");
Expect(0, 918000, '\P{^inherited}', "");
Expect(1, 917999, '\p{	_inherited}', "");
Expect(0, 917999, '\p{^	_inherited}', "");
Expect(0, 917999, '\P{	_inherited}', "");
Expect(1, 917999, '\P{^	_inherited}', "");
Expect(0, 918000, '\p{	_inherited}', "");
Expect(1, 918000, '\p{^	_inherited}', "");
Expect(1, 918000, '\P{	_inherited}', "");
Expect(0, 918000, '\P{^	_inherited}', "");
Error('\p{/a/-Is_inherited}');
Error('\P{/a/-Is_inherited}');
Expect(1, 917999, '\p{isinherited}', "");
Expect(0, 917999, '\p{^isinherited}', "");
Expect(0, 917999, '\P{isinherited}', "");
Expect(1, 917999, '\P{^isinherited}', "");
Expect(0, 918000, '\p{isinherited}', "");
Expect(1, 918000, '\p{^isinherited}', "");
Expect(1, 918000, '\P{isinherited}', "");
Expect(0, 918000, '\P{^isinherited}', "");
Expect(1, 917999, '\p{-IS_inherited}', "");
Expect(0, 917999, '\p{^-IS_inherited}', "");
Expect(0, 917999, '\P{-IS_inherited}', "");
Expect(1, 917999, '\P{^-IS_inherited}', "");
Expect(0, 918000, '\p{-IS_inherited}', "");
Expect(1, 918000, '\p{^-IS_inherited}', "");
Expect(1, 918000, '\P{-IS_inherited}', "");
Expect(0, 918000, '\P{^-IS_inherited}', "");
Error('\p{ :=ZINH}');
Error('\P{ :=ZINH}');
Expect(1, 917999, '\p{zinh}', "");
Expect(0, 917999, '\p{^zinh}', "");
Expect(0, 917999, '\P{zinh}', "");
Expect(1, 917999, '\P{^zinh}', "");
Expect(0, 918000, '\p{zinh}', "");
Expect(1, 918000, '\p{^zinh}', "");
Expect(1, 918000, '\P{zinh}', "");
Expect(0, 918000, '\P{^zinh}', "");
Expect(1, 917999, '\p{	zinh}', "");
Expect(0, 917999, '\p{^	zinh}', "");
Expect(0, 917999, '\P{	zinh}', "");
Expect(1, 917999, '\P{^	zinh}', "");
Expect(0, 918000, '\p{	zinh}', "");
Expect(1, 918000, '\p{^	zinh}', "");
Expect(1, 918000, '\P{	zinh}', "");
Expect(0, 918000, '\P{^	zinh}', "");
Error('\p{ -is_Zinh/a/}');
Error('\P{ -is_Zinh/a/}');
Expect(1, 917999, '\p{iszinh}', "");
Expect(0, 917999, '\p{^iszinh}', "");
Expect(0, 917999, '\P{iszinh}', "");
Expect(1, 917999, '\P{^iszinh}', "");
Expect(0, 918000, '\p{iszinh}', "");
Expect(1, 918000, '\p{^iszinh}', "");
Expect(1, 918000, '\P{iszinh}', "");
Expect(0, 918000, '\P{^iszinh}', "");
Expect(1, 917999, '\p{	is_ZINH}', "");
Expect(0, 917999, '\p{^	is_ZINH}', "");
Expect(0, 917999, '\P{	is_ZINH}', "");
Expect(1, 917999, '\P{^	is_ZINH}', "");
Expect(0, 918000, '\p{	is_ZINH}', "");
Expect(1, 918000, '\p{^	is_ZINH}', "");
Expect(1, 918000, '\P{	is_ZINH}', "");
Expect(0, 918000, '\P{^	is_ZINH}', "");
Error('\p{/a/-	qaai}');
Error('\P{/a/-	qaai}');
Expect(1, 917999, '\p{qaai}', "");
Expect(0, 917999, '\p{^qaai}', "");
Expect(0, 917999, '\P{qaai}', "");
Expect(1, 917999, '\P{^qaai}', "");
Expect(0, 918000, '\p{qaai}', "");
Expect(1, 918000, '\p{^qaai}', "");
Expect(1, 918000, '\P{qaai}', "");
Expect(0, 918000, '\P{^qaai}', "");
Expect(1, 917999, '\p{-	Qaai}', "");
Expect(0, 917999, '\p{^-	Qaai}', "");
Expect(0, 917999, '\P{-	Qaai}', "");
Expect(1, 917999, '\P{^-	Qaai}', "");
Expect(0, 918000, '\p{-	Qaai}', "");
Expect(1, 918000, '\p{^-	Qaai}', "");
Expect(1, 918000, '\P{-	Qaai}', "");
Expect(0, 918000, '\P{^-	Qaai}', "");
Error('\p{-/a/is_Qaai}');
Error('\P{-/a/is_Qaai}');
Expect(1, 917999, '\p{isqaai}', "");
Expect(0, 917999, '\p{^isqaai}', "");
Expect(0, 917999, '\P{isqaai}', "");
Expect(1, 917999, '\P{^isqaai}', "");
Expect(0, 918000, '\p{isqaai}', "");
Expect(1, 918000, '\p{^isqaai}', "");
Expect(1, 918000, '\P{isqaai}', "");
Expect(0, 918000, '\P{^isqaai}', "");
Expect(1, 917999, '\p{	_Is_Qaai}', "");
Expect(0, 917999, '\p{^	_Is_Qaai}', "");
Expect(0, 917999, '\P{	_Is_Qaai}', "");
Expect(1, 917999, '\P{^	_Is_Qaai}', "");
Expect(0, 918000, '\p{	_Is_Qaai}', "");
Expect(1, 918000, '\p{^	_Is_Qaai}', "");
Expect(1, 918000, '\P{	_Is_Qaai}', "");
Expect(0, 918000, '\P{^	_Is_Qaai}', "");
Error('\p{:=_Initial_Punctuation}');
Error('\P{:=_Initial_Punctuation}');
Expect(1, 11808, '\p{initialpunctuation}', "");
Expect(0, 11808, '\p{^initialpunctuation}', "");
Expect(0, 11808, '\P{initialpunctuation}', "");
Expect(1, 11808, '\P{^initialpunctuation}', "");
Expect(0, 11809, '\p{initialpunctuation}', "");
Expect(1, 11809, '\p{^initialpunctuation}', "");
Expect(1, 11809, '\P{initialpunctuation}', "");
Expect(0, 11809, '\P{^initialpunctuation}', "");
Expect(1, 11808, '\p{ _Initial_PUNCTUATION}', "");
Expect(0, 11808, '\p{^ _Initial_PUNCTUATION}', "");
Expect(0, 11808, '\P{ _Initial_PUNCTUATION}', "");
Expect(1, 11808, '\P{^ _Initial_PUNCTUATION}', "");
Expect(0, 11809, '\p{ _Initial_PUNCTUATION}', "");
Expect(1, 11809, '\p{^ _Initial_PUNCTUATION}', "");
Expect(1, 11809, '\P{ _Initial_PUNCTUATION}', "");
Expect(0, 11809, '\P{^ _Initial_PUNCTUATION}', "");
Error('\p{:= -Is_Initial_punctuation}');
Error('\P{:= -Is_Initial_punctuation}');
Expect(1, 11808, '\p{isinitialpunctuation}', "");
Expect(0, 11808, '\p{^isinitialpunctuation}', "");
Expect(0, 11808, '\P{isinitialpunctuation}', "");
Expect(1, 11808, '\P{^isinitialpunctuation}', "");
Expect(0, 11809, '\p{isinitialpunctuation}', "");
Expect(1, 11809, '\p{^isinitialpunctuation}', "");
Expect(1, 11809, '\P{isinitialpunctuation}', "");
Expect(0, 11809, '\P{^isinitialpunctuation}', "");
Expect(1, 11808, '\p{-	IS_Initial_punctuation}', "");
Expect(0, 11808, '\p{^-	IS_Initial_punctuation}', "");
Expect(0, 11808, '\P{-	IS_Initial_punctuation}', "");
Expect(1, 11808, '\P{^-	IS_Initial_punctuation}', "");
Expect(0, 11809, '\p{-	IS_Initial_punctuation}', "");
Expect(1, 11809, '\p{^-	IS_Initial_punctuation}', "");
Expect(1, 11809, '\P{-	IS_Initial_punctuation}', "");
Expect(0, 11809, '\P{^-	IS_Initial_punctuation}', "");
Error('\p{	/a/Pi}');
Error('\P{	/a/Pi}');
Expect(1, 11808, '\p{pi}', "");
Expect(0, 11808, '\p{^pi}', "");
Expect(0, 11808, '\P{pi}', "");
Expect(1, 11808, '\P{^pi}', "");
Expect(0, 11809, '\p{pi}', "");
Expect(1, 11809, '\p{^pi}', "");
Expect(1, 11809, '\P{pi}', "");
Expect(0, 11809, '\P{^pi}', "");
Expect(1, 11808, '\p{	-Pi}', "");
Expect(0, 11808, '\p{^	-Pi}', "");
Expect(0, 11808, '\P{	-Pi}', "");
Expect(1, 11808, '\P{^	-Pi}', "");
Expect(0, 11809, '\p{	-Pi}', "");
Expect(1, 11809, '\p{^	-Pi}', "");
Expect(1, 11809, '\P{	-Pi}', "");
Expect(0, 11809, '\P{^	-Pi}', "");
Error('\p{ 	Is_PI:=}');
Error('\P{ 	Is_PI:=}');
Expect(1, 11808, '\p{ispi}', "");
Expect(0, 11808, '\p{^ispi}', "");
Expect(0, 11808, '\P{ispi}', "");
Expect(1, 11808, '\P{^ispi}', "");
Expect(0, 11809, '\p{ispi}', "");
Expect(1, 11809, '\p{^ispi}', "");
Expect(1, 11809, '\P{ispi}', "");
Expect(0, 11809, '\P{^ispi}', "");
Expect(1, 11808, '\p{__is_Pi}', "");
Expect(0, 11808, '\p{^__is_Pi}', "");
Expect(0, 11808, '\P{__is_Pi}', "");
Expect(1, 11808, '\P{^__is_Pi}', "");
Expect(0, 11809, '\p{__is_Pi}', "");
Expect(1, 11809, '\p{^__is_Pi}', "");
Expect(1, 11809, '\P{__is_Pi}', "");
Expect(0, 11809, '\P{^__is_Pi}', "");
Error('\p{/a/-	Inscriptional_Pahlavi}');
Error('\P{/a/-	Inscriptional_Pahlavi}');
Expect(1, 68479, '\p{inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{- Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^- Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{- Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^- Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{- Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^- Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{- Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^- Inscriptional_Pahlavi}', "");
Error('\p{/a/_ IS_INSCRIPTIONAL_Pahlavi}');
Error('\P{/a/_ IS_INSCRIPTIONAL_Pahlavi}');
Expect(1, 68479, '\p{isinscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^isinscriptionalpahlavi}', "");
Expect(0, 68479, '\P{isinscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^isinscriptionalpahlavi}', "");
Expect(0, 68480, '\p{isinscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^isinscriptionalpahlavi}', "");
Expect(1, 68480, '\P{isinscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^isinscriptionalpahlavi}', "");
Expect(1, 68479, '\p{  Is_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\p{^  Is_Inscriptional_Pahlavi}', "");
Expect(0, 68479, '\P{  Is_Inscriptional_Pahlavi}', "");
Expect(1, 68479, '\P{^  Is_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\p{  Is_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\p{^  Is_Inscriptional_Pahlavi}', "");
Expect(1, 68480, '\P{  Is_Inscriptional_Pahlavi}', "");
Expect(0, 68480, '\P{^  Is_Inscriptional_Pahlavi}', "");
Error('\p{ /a/phli}');
Error('\P{ /a/phli}');
Expect(1, 68479, '\p{phli}', "");
Expect(0, 68479, '\p{^phli}', "");
Expect(0, 68479, '\P{phli}', "");
Expect(1, 68479, '\P{^phli}', "");
Expect(0, 68480, '\p{phli}', "");
Expect(1, 68480, '\p{^phli}', "");
Expect(1, 68480, '\P{phli}', "");
Expect(0, 68480, '\P{^phli}', "");
Expect(1, 68479, '\p{-_phli}', "");
Expect(0, 68479, '\p{^-_phli}', "");
Expect(0, 68479, '\P{-_phli}', "");
Expect(1, 68479, '\P{^-_phli}', "");
Expect(0, 68480, '\p{-_phli}', "");
Expect(1, 68480, '\p{^-_phli}', "");
Expect(1, 68480, '\P{-_phli}', "");
Expect(0, 68480, '\P{^-_phli}', "");
Error('\p{_:=Is_phli}');
Error('\P{_:=Is_phli}');
Expect(1, 68479, '\p{isphli}', "");
Expect(0, 68479, '\p{^isphli}', "");
Expect(0, 68479, '\P{isphli}', "");
Expect(1, 68479, '\P{^isphli}', "");
Expect(0, 68480, '\p{isphli}', "");
Expect(1, 68480, '\p{^isphli}', "");
Expect(1, 68480, '\P{isphli}', "");
Expect(0, 68480, '\P{^isphli}', "");
Expect(1, 68479, '\p{_ Is_Phli}', "");
Expect(0, 68479, '\p{^_ Is_Phli}', "");
Expect(0, 68479, '\P{_ Is_Phli}', "");
Expect(1, 68479, '\P{^_ Is_Phli}', "");
Expect(0, 68480, '\p{_ Is_Phli}', "");
Expect(1, 68480, '\p{^_ Is_Phli}', "");
Expect(1, 68480, '\P{_ Is_Phli}', "");
Expect(0, 68480, '\P{^_ Is_Phli}', "");
Error('\p{ :=inscriptional_parthian}');
Error('\P{ :=inscriptional_parthian}');
Expect(1, 68447, '\p{inscriptionalparthian}', "");
Expect(0, 68447, '\p{^inscriptionalparthian}', "");
Expect(0, 68447, '\P{inscriptionalparthian}', "");
Expect(1, 68447, '\P{^inscriptionalparthian}', "");
Expect(0, 68448, '\p{inscriptionalparthian}', "");
Expect(1, 68448, '\p{^inscriptionalparthian}', "");
Expect(1, 68448, '\P{inscriptionalparthian}', "");
Expect(0, 68448, '\P{^inscriptionalparthian}', "");
Expect(1, 68447, '\p{ Inscriptional_parthian}', "");
Expect(0, 68447, '\p{^ Inscriptional_parthian}', "");
Expect(0, 68447, '\P{ Inscriptional_parthian}', "");
Expect(1, 68447, '\P{^ Inscriptional_parthian}', "");
Expect(0, 68448, '\p{ Inscriptional_parthian}', "");
Expect(1, 68448, '\p{^ Inscriptional_parthian}', "");
Expect(1, 68448, '\P{ Inscriptional_parthian}', "");
Expect(0, 68448, '\P{^ Inscriptional_parthian}', "");
Error('\p{:=_Is_Inscriptional_Parthian}');
Error('\P{:=_Is_Inscriptional_Parthian}');
Expect(1, 68447, '\p{isinscriptionalparthian}', "");
Expect(0, 68447, '\p{^isinscriptionalparthian}', "");
Expect(0, 68447, '\P{isinscriptionalparthian}', "");
Expect(1, 68447, '\P{^isinscriptionalparthian}', "");
Expect(0, 68448, '\p{isinscriptionalparthian}', "");
Expect(1, 68448, '\p{^isinscriptionalparthian}', "");
Expect(1, 68448, '\P{isinscriptionalparthian}', "");
Expect(0, 68448, '\P{^isinscriptionalparthian}', "");
Expect(1, 68447, '\p{- Is_Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\p{^- Is_Inscriptional_PARTHIAN}', "");
Expect(0, 68447, '\P{- Is_Inscriptional_PARTHIAN}', "");
Expect(1, 68447, '\P{^- Is_Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\p{- Is_Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\p{^- Is_Inscriptional_PARTHIAN}', "");
Expect(1, 68448, '\P{- Is_Inscriptional_PARTHIAN}', "");
Expect(0, 68448, '\P{^- Is_Inscriptional_PARTHIAN}', "");
Error('\p{	-prti:=}');
Error('\P{	-prti:=}');
Expect(1, 68447, '\p{prti}', "");
Expect(0, 68447, '\p{^prti}', "");
Expect(0, 68447, '\P{prti}', "");
Expect(1, 68447, '\P{^prti}', "");
Expect(0, 68448, '\p{prti}', "");
Expect(1, 68448, '\p{^prti}', "");
Expect(1, 68448, '\P{prti}', "");
Expect(0, 68448, '\P{^prti}', "");
Expect(1, 68447, '\p{-Prti}', "");
Expect(0, 68447, '\p{^-Prti}', "");
Expect(0, 68447, '\P{-Prti}', "");
Expect(1, 68447, '\P{^-Prti}', "");
Expect(0, 68448, '\p{-Prti}', "");
Expect(1, 68448, '\p{^-Prti}', "");
Expect(1, 68448, '\P{-Prti}', "");
Expect(0, 68448, '\P{^-Prti}', "");
Error('\p{/a/ _Is_prti}');
Error('\P{/a/ _Is_prti}');
Expect(1, 68447, '\p{isprti}', "");
Expect(0, 68447, '\p{^isprti}', "");
Expect(0, 68447, '\P{isprti}', "");
Expect(1, 68447, '\P{^isprti}', "");
Expect(0, 68448, '\p{isprti}', "");
Expect(1, 68448, '\p{^isprti}', "");
Expect(1, 68448, '\P{isprti}', "");
Expect(0, 68448, '\P{^isprti}', "");
Expect(1, 68447, '\p{  Is_Prti}', "");
Expect(0, 68447, '\p{^  Is_Prti}', "");
Expect(0, 68447, '\P{  Is_Prti}', "");
Expect(1, 68447, '\P{^  Is_Prti}', "");
Expect(0, 68448, '\p{  Is_Prti}', "");
Expect(1, 68448, '\p{^  Is_Prti}', "");
Expect(1, 68448, '\P{  Is_Prti}', "");
Expect(0, 68448, '\P{^  Is_Prti}', "");
Error('\p{-/a/Javanese}');
Error('\P{-/a/Javanese}');
Expect(1, 43487, '\p{javanese}', "");
Expect(0, 43487, '\p{^javanese}', "");
Expect(0, 43487, '\P{javanese}', "");
Expect(1, 43487, '\P{^javanese}', "");
Expect(0, 43488, '\p{javanese}', "");
Expect(1, 43488, '\p{^javanese}', "");
Expect(1, 43488, '\P{javanese}', "");
Expect(0, 43488, '\P{^javanese}', "");
Expect(1, 43487, '\p{_-JAVANESE}', "");
Expect(0, 43487, '\p{^_-JAVANESE}', "");
Expect(0, 43487, '\P{_-JAVANESE}', "");
Expect(1, 43487, '\P{^_-JAVANESE}', "");
Expect(0, 43488, '\p{_-JAVANESE}', "");
Expect(1, 43488, '\p{^_-JAVANESE}', "");
Expect(1, 43488, '\P{_-JAVANESE}', "");
Expect(0, 43488, '\P{^_-JAVANESE}', "");
Error('\p{/a/	_IS_Javanese}');
Error('\P{/a/	_IS_Javanese}');
Expect(1, 43487, '\p{isjavanese}', "");
Expect(0, 43487, '\p{^isjavanese}', "");
Expect(0, 43487, '\P{isjavanese}', "");
Expect(1, 43487, '\P{^isjavanese}', "");
Expect(0, 43488, '\p{isjavanese}', "");
Expect(1, 43488, '\p{^isjavanese}', "");
Expect(1, 43488, '\P{isjavanese}', "");
Expect(0, 43488, '\P{^isjavanese}', "");
Expect(1, 43487, '\p{-_IS_JAVANESE}', "");
Expect(0, 43487, '\p{^-_IS_JAVANESE}', "");
Expect(0, 43487, '\P{-_IS_JAVANESE}', "");
Expect(1, 43487, '\P{^-_IS_JAVANESE}', "");
Expect(0, 43488, '\p{-_IS_JAVANESE}', "");
Expect(1, 43488, '\p{^-_IS_JAVANESE}', "");
Expect(1, 43488, '\P{-_IS_JAVANESE}', "");
Expect(0, 43488, '\P{^-_IS_JAVANESE}', "");
Error('\p{/a/	Java}');
Error('\P{/a/	Java}');
Expect(1, 43487, '\p{java}', "");
Expect(0, 43487, '\p{^java}', "");
Expect(0, 43487, '\P{java}', "");
Expect(1, 43487, '\P{^java}', "");
Expect(0, 43488, '\p{java}', "");
Expect(1, 43488, '\p{^java}', "");
Expect(1, 43488, '\P{java}', "");
Expect(0, 43488, '\P{^java}', "");
Expect(1, 43487, '\p{ -Java}', "");
Expect(0, 43487, '\p{^ -Java}', "");
Expect(0, 43487, '\P{ -Java}', "");
Expect(1, 43487, '\P{^ -Java}', "");
Expect(0, 43488, '\p{ -Java}', "");
Expect(1, 43488, '\p{^ -Java}', "");
Expect(1, 43488, '\P{ -Java}', "");
Expect(0, 43488, '\P{^ -Java}', "");
Error('\p{:=	Is_Java}');
Error('\P{:=	Is_Java}');
Expect(1, 43487, '\p{isjava}', "");
Expect(0, 43487, '\p{^isjava}', "");
Expect(0, 43487, '\P{isjava}', "");
Expect(1, 43487, '\P{^isjava}', "");
Expect(0, 43488, '\p{isjava}', "");
Expect(1, 43488, '\p{^isjava}', "");
Expect(1, 43488, '\P{isjava}', "");
Expect(0, 43488, '\P{^isjava}', "");
Expect(1, 43487, '\p{ IS_Java}', "");
Expect(0, 43487, '\p{^ IS_Java}', "");
Expect(0, 43487, '\P{ IS_Java}', "");
Expect(1, 43487, '\P{^ IS_Java}', "");
Expect(0, 43488, '\p{ IS_Java}', "");
Expect(1, 43488, '\p{^ IS_Java}', "");
Expect(1, 43488, '\P{ IS_Java}', "");
Expect(0, 43488, '\P{^ IS_Java}', "");
Error('\p{_/a/Join_CONTROL}');
Error('\P{_/a/Join_CONTROL}');
Expect(1, 8205, '\p{joincontrol}', "");
Expect(0, 8205, '\p{^joincontrol}', "");
Expect(0, 8205, '\P{joincontrol}', "");
Expect(1, 8205, '\P{^joincontrol}', "");
Expect(0, 8206, '\p{joincontrol}', "");
Expect(1, 8206, '\p{^joincontrol}', "");
Expect(1, 8206, '\P{joincontrol}', "");
Expect(0, 8206, '\P{^joincontrol}', "");
Expect(1, 8205, '\p{ _JOIN_CONTROL}', "");
Expect(0, 8205, '\p{^ _JOIN_CONTROL}', "");
Expect(0, 8205, '\P{ _JOIN_CONTROL}', "");
Expect(1, 8205, '\P{^ _JOIN_CONTROL}', "");
Expect(0, 8206, '\p{ _JOIN_CONTROL}', "");
Expect(1, 8206, '\p{^ _JOIN_CONTROL}', "");
Expect(1, 8206, '\P{ _JOIN_CONTROL}', "");
Expect(0, 8206, '\P{^ _JOIN_CONTROL}', "");
Error('\p{-	Is_JOIN_control/a/}');
Error('\P{-	Is_JOIN_control/a/}');
Expect(1, 8205, '\p{isjoincontrol}', "");
Expect(0, 8205, '\p{^isjoincontrol}', "");
Expect(0, 8205, '\P{isjoincontrol}', "");
Expect(1, 8205, '\P{^isjoincontrol}', "");
Expect(0, 8206, '\p{isjoincontrol}', "");
Expect(1, 8206, '\p{^isjoincontrol}', "");
Expect(1, 8206, '\P{isjoincontrol}', "");
Expect(0, 8206, '\P{^isjoincontrol}', "");
Expect(1, 8205, '\p{	_IS_Join_CONTROL}', "");
Expect(0, 8205, '\p{^	_IS_Join_CONTROL}', "");
Expect(0, 8205, '\P{	_IS_Join_CONTROL}', "");
Expect(1, 8205, '\P{^	_IS_Join_CONTROL}', "");
Expect(0, 8206, '\p{	_IS_Join_CONTROL}', "");
Expect(1, 8206, '\p{^	_IS_Join_CONTROL}', "");
Expect(1, 8206, '\P{	_IS_Join_CONTROL}', "");
Expect(0, 8206, '\P{^	_IS_Join_CONTROL}', "");
Error('\p{-Join_C/a/}');
Error('\P{-Join_C/a/}');
Expect(1, 8205, '\p{joinc}', "");
Expect(0, 8205, '\p{^joinc}', "");
Expect(0, 8205, '\P{joinc}', "");
Expect(1, 8205, '\P{^joinc}', "");
Expect(0, 8206, '\p{joinc}', "");
Expect(1, 8206, '\p{^joinc}', "");
Expect(1, 8206, '\P{joinc}', "");
Expect(0, 8206, '\P{^joinc}', "");
Expect(1, 8205, '\p{_join_C}', "");
Expect(0, 8205, '\p{^_join_C}', "");
Expect(0, 8205, '\P{_join_C}', "");
Expect(1, 8205, '\P{^_join_C}', "");
Expect(0, 8206, '\p{_join_C}', "");
Expect(1, 8206, '\p{^_join_C}', "");
Expect(1, 8206, '\P{_join_C}', "");
Expect(0, 8206, '\P{^_join_C}', "");
Error('\p{ :=is_join_C}');
Error('\P{ :=is_join_C}');
Expect(1, 8205, '\p{isjoinc}', "");
Expect(0, 8205, '\p{^isjoinc}', "");
Expect(0, 8205, '\P{isjoinc}', "");
Expect(1, 8205, '\P{^isjoinc}', "");
Expect(0, 8206, '\p{isjoinc}', "");
Expect(1, 8206, '\p{^isjoinc}', "");
Expect(1, 8206, '\P{isjoinc}', "");
Expect(0, 8206, '\P{^isjoinc}', "");
Expect(1, 8205, '\p{_-IS_JOIN_C}', "");
Expect(0, 8205, '\p{^_-IS_JOIN_C}', "");
Expect(0, 8205, '\P{_-IS_JOIN_C}', "");
Expect(1, 8205, '\P{^_-IS_JOIN_C}', "");
Expect(0, 8206, '\p{_-IS_JOIN_C}', "");
Expect(1, 8206, '\p{^_-IS_JOIN_C}', "");
Expect(1, 8206, '\P{_-IS_JOIN_C}', "");
Expect(0, 8206, '\P{^_-IS_JOIN_C}', "");
Error('\p{:=kaithi}');
Error('\P{:=kaithi}');
Expect(1, 69825, '\p{kaithi}', "");
Expect(0, 69825, '\p{^kaithi}', "");
Expect(0, 69825, '\P{kaithi}', "");
Expect(1, 69825, '\P{^kaithi}', "");
Expect(0, 69826, '\p{kaithi}', "");
Expect(1, 69826, '\p{^kaithi}', "");
Expect(1, 69826, '\P{kaithi}', "");
Expect(0, 69826, '\P{^kaithi}', "");
Expect(1, 69825, '\p{_kaithi}', "");
Expect(0, 69825, '\p{^_kaithi}', "");
Expect(0, 69825, '\P{_kaithi}', "");
Expect(1, 69825, '\P{^_kaithi}', "");
Expect(0, 69826, '\p{_kaithi}', "");
Expect(1, 69826, '\p{^_kaithi}', "");
Expect(1, 69826, '\P{_kaithi}', "");
Expect(0, 69826, '\P{^_kaithi}', "");
Error('\p{/a/ IS_Kaithi}');
Error('\P{/a/ IS_Kaithi}');
Expect(1, 69825, '\p{iskaithi}', "");
Expect(0, 69825, '\p{^iskaithi}', "");
Expect(0, 69825, '\P{iskaithi}', "");
Expect(1, 69825, '\P{^iskaithi}', "");
Expect(0, 69826, '\p{iskaithi}', "");
Expect(1, 69826, '\p{^iskaithi}', "");
Expect(1, 69826, '\P{iskaithi}', "");
Expect(0, 69826, '\P{^iskaithi}', "");
Expect(1, 69825, '\p{		Is_KAITHI}', "");
Expect(0, 69825, '\p{^		Is_KAITHI}', "");
Expect(0, 69825, '\P{		Is_KAITHI}', "");
Expect(1, 69825, '\P{^		Is_KAITHI}', "");
Expect(0, 69826, '\p{		Is_KAITHI}', "");
Expect(1, 69826, '\p{^		Is_KAITHI}', "");
Expect(1, 69826, '\P{		Is_KAITHI}', "");
Expect(0, 69826, '\P{^		Is_KAITHI}', "");
Error('\p{-:=kthi}');
Error('\P{-:=kthi}');
Expect(1, 69825, '\p{kthi}', "");
Expect(0, 69825, '\p{^kthi}', "");
Expect(0, 69825, '\P{kthi}', "");
Expect(1, 69825, '\P{^kthi}', "");
Expect(0, 69826, '\p{kthi}', "");
Expect(1, 69826, '\p{^kthi}', "");
Expect(1, 69826, '\P{kthi}', "");
Expect(0, 69826, '\P{^kthi}', "");
Expect(1, 69825, '\p{_ KTHI}', "");
Expect(0, 69825, '\p{^_ KTHI}', "");
Expect(0, 69825, '\P{_ KTHI}', "");
Expect(1, 69825, '\P{^_ KTHI}', "");
Expect(0, 69826, '\p{_ KTHI}', "");
Expect(1, 69826, '\p{^_ KTHI}', "");
Expect(1, 69826, '\P{_ KTHI}', "");
Expect(0, 69826, '\P{^_ KTHI}', "");
Error('\p{-/a/Is_kthi}');
Error('\P{-/a/Is_kthi}');
Expect(1, 69825, '\p{iskthi}', "");
Expect(0, 69825, '\p{^iskthi}', "");
Expect(0, 69825, '\P{iskthi}', "");
Expect(1, 69825, '\P{^iskthi}', "");
Expect(0, 69826, '\p{iskthi}', "");
Expect(1, 69826, '\p{^iskthi}', "");
Expect(1, 69826, '\P{iskthi}', "");
Expect(0, 69826, '\P{^iskthi}', "");
Expect(1, 69825, '\p{Is_Kthi}', "");
Expect(0, 69825, '\p{^Is_Kthi}', "");
Expect(0, 69825, '\P{Is_Kthi}', "");
Expect(1, 69825, '\P{^Is_Kthi}', "");
Expect(0, 69826, '\p{Is_Kthi}', "");
Expect(1, 69826, '\p{^Is_Kthi}', "");
Expect(1, 69826, '\P{Is_Kthi}', "");
Expect(0, 69826, '\P{^Is_Kthi}', "");
Error('\p{	_Kana_SUPPLEMENT/a/}');
Error('\P{	_Kana_SUPPLEMENT/a/}');
Expect(1, 110847, '\p{kanasupplement}', "");
Expect(0, 110847, '\p{^kanasupplement}', "");
Expect(0, 110847, '\P{kanasupplement}', "");
Expect(1, 110847, '\P{^kanasupplement}', "");
Expect(0, 110848, '\p{kanasupplement}', "");
Expect(1, 110848, '\p{^kanasupplement}', "");
Expect(1, 110848, '\P{kanasupplement}', "");
Expect(0, 110848, '\P{^kanasupplement}', "");
Expect(1, 110847, '\p{		Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\p{^		Kana_SUPPLEMENT}', "");
Expect(0, 110847, '\P{		Kana_SUPPLEMENT}', "");
Expect(1, 110847, '\P{^		Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\p{		Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\p{^		Kana_SUPPLEMENT}', "");
Expect(1, 110848, '\P{		Kana_SUPPLEMENT}', "");
Expect(0, 110848, '\P{^		Kana_SUPPLEMENT}', "");
Error('\p{:=_is_Kana_Supplement}');
Error('\P{:=_is_Kana_Supplement}');
Expect(1, 110847, '\p{iskanasupplement}', "");
Expect(0, 110847, '\p{^iskanasupplement}', "");
Expect(0, 110847, '\P{iskanasupplement}', "");
Expect(1, 110847, '\P{^iskanasupplement}', "");
Expect(0, 110848, '\p{iskanasupplement}', "");
Expect(1, 110848, '\p{^iskanasupplement}', "");
Expect(1, 110848, '\P{iskanasupplement}', "");
Expect(0, 110848, '\P{^iskanasupplement}', "");
Expect(1, 110847, '\p{- IS_kana_supplement}', "");
Expect(0, 110847, '\p{^- IS_kana_supplement}', "");
Expect(0, 110847, '\P{- IS_kana_supplement}', "");
Expect(1, 110847, '\P{^- IS_kana_supplement}', "");
Expect(0, 110848, '\p{- IS_kana_supplement}', "");
Expect(1, 110848, '\p{^- IS_kana_supplement}', "");
Expect(1, 110848, '\P{- IS_kana_supplement}', "");
Expect(0, 110848, '\P{^- IS_kana_supplement}', "");
Error('\p{-IN_Kana_Supplement:=}');
Error('\P{-IN_Kana_Supplement:=}');
Expect(1, 110847, '\p{inkanasupplement}', "");
Expect(0, 110847, '\p{^inkanasupplement}', "");
Expect(0, 110847, '\P{inkanasupplement}', "");
Expect(1, 110847, '\P{^inkanasupplement}', "");
Expect(0, 110848, '\p{inkanasupplement}', "");
Expect(1, 110848, '\p{^inkanasupplement}', "");
Expect(1, 110848, '\P{inkanasupplement}', "");
Expect(0, 110848, '\P{^inkanasupplement}', "");
Expect(1, 110847, '\p{- in_Kana_supplement}', "");
Expect(0, 110847, '\p{^- in_Kana_supplement}', "");
Expect(0, 110847, '\P{- in_Kana_supplement}', "");
Expect(1, 110847, '\P{^- in_Kana_supplement}', "");
Expect(0, 110848, '\p{- in_Kana_supplement}', "");
Expect(1, 110848, '\p{^- in_Kana_supplement}', "");
Expect(1, 110848, '\P{- in_Kana_supplement}', "");
Expect(0, 110848, '\P{^- in_Kana_supplement}', "");
Error('\p{ _kana_sup:=}');
Error('\P{ _kana_sup:=}');
Expect(1, 110847, '\p{kanasup}', "");
Expect(0, 110847, '\p{^kanasup}', "");
Expect(0, 110847, '\P{kanasup}', "");
Expect(1, 110847, '\P{^kanasup}', "");
Expect(0, 110848, '\p{kanasup}', "");
Expect(1, 110848, '\p{^kanasup}', "");
Expect(1, 110848, '\P{kanasup}', "");
Expect(0, 110848, '\P{^kanasup}', "");
Expect(1, 110847, '\p{- Kana_Sup}', "");
Expect(0, 110847, '\p{^- Kana_Sup}', "");
Expect(0, 110847, '\P{- Kana_Sup}', "");
Expect(1, 110847, '\P{^- Kana_Sup}', "");
Expect(0, 110848, '\p{- Kana_Sup}', "");
Expect(1, 110848, '\p{^- Kana_Sup}', "");
Expect(1, 110848, '\P{- Kana_Sup}', "");
Expect(0, 110848, '\P{^- Kana_Sup}', "");
Error('\p{IS_Kana_SUP:=}');
Error('\P{IS_Kana_SUP:=}');
Expect(1, 110847, '\p{iskanasup}', "");
Expect(0, 110847, '\p{^iskanasup}', "");
Expect(0, 110847, '\P{iskanasup}', "");
Expect(1, 110847, '\P{^iskanasup}', "");
Expect(0, 110848, '\p{iskanasup}', "");
Expect(1, 110848, '\p{^iskanasup}', "");
Expect(1, 110848, '\P{iskanasup}', "");
Expect(0, 110848, '\P{^iskanasup}', "");
Expect(1, 110847, '\p{	-Is_KANA_SUP}', "");
Expect(0, 110847, '\p{^	-Is_KANA_SUP}', "");
Expect(0, 110847, '\P{	-Is_KANA_SUP}', "");
Expect(1, 110847, '\P{^	-Is_KANA_SUP}', "");
Expect(0, 110848, '\p{	-Is_KANA_SUP}', "");
Expect(1, 110848, '\p{^	-Is_KANA_SUP}', "");
Expect(1, 110848, '\P{	-Is_KANA_SUP}', "");
Expect(0, 110848, '\P{^	-Is_KANA_SUP}', "");
Error('\p{/a/-_In_Kana_Sup}');
Error('\P{/a/-_In_Kana_Sup}');
Expect(1, 110847, '\p{inkanasup}', "");
Expect(0, 110847, '\p{^inkanasup}', "");
Expect(0, 110847, '\P{inkanasup}', "");
Expect(1, 110847, '\P{^inkanasup}', "");
Expect(0, 110848, '\p{inkanasup}', "");
Expect(1, 110848, '\p{^inkanasup}', "");
Expect(1, 110848, '\P{inkanasup}', "");
Expect(0, 110848, '\P{^inkanasup}', "");
Expect(1, 110847, '\p{	IN_kana_SUP}', "");
Expect(0, 110847, '\p{^	IN_kana_SUP}', "");
Expect(0, 110847, '\P{	IN_kana_SUP}', "");
Expect(1, 110847, '\P{^	IN_kana_SUP}', "");
Expect(0, 110848, '\p{	IN_kana_SUP}', "");
Expect(1, 110848, '\p{^	IN_kana_SUP}', "");
Expect(1, 110848, '\P{	IN_kana_SUP}', "");
Expect(0, 110848, '\P{^	IN_kana_SUP}', "");
Error('\p{/a/-	Kanbun}');
Error('\P{/a/-	Kanbun}');
Expect(1, 12703, '\p{kanbun}', "");
Expect(0, 12703, '\p{^kanbun}', "");
Expect(0, 12703, '\P{kanbun}', "");
Expect(1, 12703, '\P{^kanbun}', "");
Expect(0, 12704, '\p{kanbun}', "");
Expect(1, 12704, '\p{^kanbun}', "");
Expect(1, 12704, '\P{kanbun}', "");
Expect(0, 12704, '\P{^kanbun}', "");
Expect(1, 12703, '\p{_Kanbun}', "");
Expect(0, 12703, '\p{^_Kanbun}', "");
Expect(0, 12703, '\P{_Kanbun}', "");
Expect(1, 12703, '\P{^_Kanbun}', "");
Expect(0, 12704, '\p{_Kanbun}', "");
Expect(1, 12704, '\p{^_Kanbun}', "");
Expect(1, 12704, '\P{_Kanbun}', "");
Expect(0, 12704, '\P{^_Kanbun}', "");
Error('\p{	:=IS_kanbun}');
Error('\P{	:=IS_kanbun}');
Expect(1, 12703, '\p{iskanbun}', "");
Expect(0, 12703, '\p{^iskanbun}', "");
Expect(0, 12703, '\P{iskanbun}', "");
Expect(1, 12703, '\P{^iskanbun}', "");
Expect(0, 12704, '\p{iskanbun}', "");
Expect(1, 12704, '\p{^iskanbun}', "");
Expect(1, 12704, '\P{iskanbun}', "");
Expect(0, 12704, '\P{^iskanbun}', "");
Expect(1, 12703, '\p{	is_Kanbun}', "");
Expect(0, 12703, '\p{^	is_Kanbun}', "");
Expect(0, 12703, '\P{	is_Kanbun}', "");
Expect(1, 12703, '\P{^	is_Kanbun}', "");
Expect(0, 12704, '\p{	is_Kanbun}', "");
Expect(1, 12704, '\p{^	is_Kanbun}', "");
Expect(1, 12704, '\P{	is_Kanbun}', "");
Expect(0, 12704, '\P{^	is_Kanbun}', "");
Error('\p{:=_in_kanbun}');
Error('\P{:=_in_kanbun}');
Expect(1, 12703, '\p{inkanbun}', "");
Expect(0, 12703, '\p{^inkanbun}', "");
Expect(0, 12703, '\P{inkanbun}', "");
Expect(1, 12703, '\P{^inkanbun}', "");
Expect(0, 12704, '\p{inkanbun}', "");
Expect(1, 12704, '\p{^inkanbun}', "");
Expect(1, 12704, '\P{inkanbun}', "");
Expect(0, 12704, '\P{^inkanbun}', "");
Expect(1, 12703, '\p{-_in_KANBUN}', "");
Expect(0, 12703, '\p{^-_in_KANBUN}', "");
Expect(0, 12703, '\P{-_in_KANBUN}', "");
Expect(1, 12703, '\P{^-_in_KANBUN}', "");
Expect(0, 12704, '\p{-_in_KANBUN}', "");
Expect(1, 12704, '\p{^-_in_KANBUN}', "");
Expect(1, 12704, '\P{-_in_KANBUN}', "");
Expect(0, 12704, '\P{^-_in_KANBUN}', "");
Error('\p{	/a/Kangxi_RADICALS}');
Error('\P{	/a/Kangxi_RADICALS}');
Expect(1, 12255, '\p{kangxiradicals}', "");
Expect(0, 12255, '\p{^kangxiradicals}', "");
Expect(0, 12255, '\P{kangxiradicals}', "");
Expect(1, 12255, '\P{^kangxiradicals}', "");
Expect(0, 12256, '\p{kangxiradicals}', "");
Expect(1, 12256, '\p{^kangxiradicals}', "");
Expect(1, 12256, '\P{kangxiradicals}', "");
Expect(0, 12256, '\P{^kangxiradicals}', "");
Expect(1, 12255, '\p{-_Kangxi_Radicals}', "");
Expect(0, 12255, '\p{^-_Kangxi_Radicals}', "");
Expect(0, 12255, '\P{-_Kangxi_Radicals}', "");
Expect(1, 12255, '\P{^-_Kangxi_Radicals}', "");
Expect(0, 12256, '\p{-_Kangxi_Radicals}', "");
Expect(1, 12256, '\p{^-_Kangxi_Radicals}', "");
Expect(1, 12256, '\P{-_Kangxi_Radicals}', "");
Expect(0, 12256, '\P{^-_Kangxi_Radicals}', "");
Error('\p{/a/__Is_KANGXI_Radicals}');
Error('\P{/a/__Is_KANGXI_Radicals}');
Expect(1, 12255, '\p{iskangxiradicals}', "");
Expect(0, 12255, '\p{^iskangxiradicals}', "");
Expect(0, 12255, '\P{iskangxiradicals}', "");
Expect(1, 12255, '\P{^iskangxiradicals}', "");
Expect(0, 12256, '\p{iskangxiradicals}', "");
Expect(1, 12256, '\p{^iskangxiradicals}', "");
Expect(1, 12256, '\P{iskangxiradicals}', "");
Expect(0, 12256, '\P{^iskangxiradicals}', "");
Expect(1, 12255, '\p{_-is_KANGXI_Radicals}', "");
Expect(0, 12255, '\p{^_-is_KANGXI_Radicals}', "");
Expect(0, 12255, '\P{_-is_KANGXI_Radicals}', "");
Expect(1, 12255, '\P{^_-is_KANGXI_Radicals}', "");
Expect(0, 12256, '\p{_-is_KANGXI_Radicals}', "");
Expect(1, 12256, '\p{^_-is_KANGXI_Radicals}', "");
Expect(1, 12256, '\P{_-is_KANGXI_Radicals}', "");
Expect(0, 12256, '\P{^_-is_KANGXI_Radicals}', "");
Error('\p{	In_KANGXI_Radicals/a/}');
Error('\P{	In_KANGXI_Radicals/a/}');
Expect(1, 12255, '\p{inkangxiradicals}', "");
Expect(0, 12255, '\p{^inkangxiradicals}', "");
Expect(0, 12255, '\P{inkangxiradicals}', "");
Expect(1, 12255, '\P{^inkangxiradicals}', "");
Expect(0, 12256, '\p{inkangxiradicals}', "");
Expect(1, 12256, '\p{^inkangxiradicals}', "");
Expect(1, 12256, '\P{inkangxiradicals}', "");
Expect(0, 12256, '\P{^inkangxiradicals}', "");
Expect(1, 12255, '\p{_-In_KANGXI_Radicals}', "");
Expect(0, 12255, '\p{^_-In_KANGXI_Radicals}', "");
Expect(0, 12255, '\P{_-In_KANGXI_Radicals}', "");
Expect(1, 12255, '\P{^_-In_KANGXI_Radicals}', "");
Expect(0, 12256, '\p{_-In_KANGXI_Radicals}', "");
Expect(1, 12256, '\p{^_-In_KANGXI_Radicals}', "");
Expect(1, 12256, '\P{_-In_KANGXI_Radicals}', "");
Expect(0, 12256, '\P{^_-In_KANGXI_Radicals}', "");
Error('\p{:= -kangxi}');
Error('\P{:= -kangxi}');
Expect(1, 12255, '\p{kangxi}', "");
Expect(0, 12255, '\p{^kangxi}', "");
Expect(0, 12255, '\P{kangxi}', "");
Expect(1, 12255, '\P{^kangxi}', "");
Expect(0, 12256, '\p{kangxi}', "");
Expect(1, 12256, '\p{^kangxi}', "");
Expect(1, 12256, '\P{kangxi}', "");
Expect(0, 12256, '\P{^kangxi}', "");
Expect(1, 12255, '\p{_kangxi}', "");
Expect(0, 12255, '\p{^_kangxi}', "");
Expect(0, 12255, '\P{_kangxi}', "");
Expect(1, 12255, '\P{^_kangxi}', "");
Expect(0, 12256, '\p{_kangxi}', "");
Expect(1, 12256, '\p{^_kangxi}', "");
Expect(1, 12256, '\P{_kangxi}', "");
Expect(0, 12256, '\P{^_kangxi}', "");
Error('\p{		IS_Kangxi:=}');
Error('\P{		IS_Kangxi:=}');
Expect(1, 12255, '\p{iskangxi}', "");
Expect(0, 12255, '\p{^iskangxi}', "");
Expect(0, 12255, '\P{iskangxi}', "");
Expect(1, 12255, '\P{^iskangxi}', "");
Expect(0, 12256, '\p{iskangxi}', "");
Expect(1, 12256, '\p{^iskangxi}', "");
Expect(1, 12256, '\P{iskangxi}', "");
Expect(0, 12256, '\P{^iskangxi}', "");
Expect(1, 12255, '\p{_is_kangxi}', "");
Expect(0, 12255, '\p{^_is_kangxi}', "");
Expect(0, 12255, '\P{_is_kangxi}', "");
Expect(1, 12255, '\P{^_is_kangxi}', "");
Expect(0, 12256, '\p{_is_kangxi}', "");
Expect(1, 12256, '\p{^_is_kangxi}', "");
Expect(1, 12256, '\P{_is_kangxi}', "");
Expect(0, 12256, '\P{^_is_kangxi}', "");
Error('\p{/a/--IN_Kangxi}');
Error('\P{/a/--IN_Kangxi}');
Expect(1, 12255, '\p{inkangxi}', "");
Expect(0, 12255, '\p{^inkangxi}', "");
Expect(0, 12255, '\P{inkangxi}', "");
Expect(1, 12255, '\P{^inkangxi}', "");
Expect(0, 12256, '\p{inkangxi}', "");
Expect(1, 12256, '\p{^inkangxi}', "");
Expect(1, 12256, '\P{inkangxi}', "");
Expect(0, 12256, '\P{^inkangxi}', "");
Expect(1, 12255, '\p{_ In_kangxi}', "");
Expect(0, 12255, '\p{^_ In_kangxi}', "");
Expect(0, 12255, '\P{_ In_kangxi}', "");
Expect(1, 12255, '\P{^_ In_kangxi}', "");
Expect(0, 12256, '\p{_ In_kangxi}', "");
Expect(1, 12256, '\p{^_ In_kangxi}', "");
Expect(1, 12256, '\P{_ In_kangxi}', "");
Expect(0, 12256, '\P{^_ In_kangxi}', "");
Error('\p{:=_kannada}');
Error('\P{:=_kannada}');
Expect(1, 3314, '\p{kannada}', "");
Expect(0, 3314, '\p{^kannada}', "");
Expect(0, 3314, '\P{kannada}', "");
Expect(1, 3314, '\P{^kannada}', "");
Expect(0, 3315, '\p{kannada}', "");
Expect(1, 3315, '\p{^kannada}', "");
Expect(1, 3315, '\P{kannada}', "");
Expect(0, 3315, '\P{^kannada}', "");
Expect(1, 3314, '\p{ 	Kannada}', "");
Expect(0, 3314, '\p{^ 	Kannada}', "");
Expect(0, 3314, '\P{ 	Kannada}', "");
Expect(1, 3314, '\P{^ 	Kannada}', "");
Expect(0, 3315, '\p{ 	Kannada}', "");
Expect(1, 3315, '\p{^ 	Kannada}', "");
Expect(1, 3315, '\P{ 	Kannada}', "");
Expect(0, 3315, '\P{^ 	Kannada}', "");
Error('\p{	 Is_Kannada:=}');
Error('\P{	 Is_Kannada:=}');
Expect(1, 3314, '\p{iskannada}', "");
Expect(0, 3314, '\p{^iskannada}', "");
Expect(0, 3314, '\P{iskannada}', "");
Expect(1, 3314, '\P{^iskannada}', "");
Expect(0, 3315, '\p{iskannada}', "");
Expect(1, 3315, '\p{^iskannada}', "");
Expect(1, 3315, '\P{iskannada}', "");
Expect(0, 3315, '\P{^iskannada}', "");
Expect(1, 3314, '\p{- is_KANNADA}', "");
Expect(0, 3314, '\p{^- is_KANNADA}', "");
Expect(0, 3314, '\P{- is_KANNADA}', "");
Expect(1, 3314, '\P{^- is_KANNADA}', "");
Expect(0, 3315, '\p{- is_KANNADA}', "");
Expect(1, 3315, '\p{^- is_KANNADA}', "");
Expect(1, 3315, '\P{- is_KANNADA}', "");
Expect(0, 3315, '\P{^- is_KANNADA}', "");
Error('\p{/a/ _KNDA}');
Error('\P{/a/ _KNDA}');
Expect(1, 3314, '\p{knda}', "");
Expect(0, 3314, '\p{^knda}', "");
Expect(0, 3314, '\P{knda}', "");
Expect(1, 3314, '\P{^knda}', "");
Expect(0, 3315, '\p{knda}', "");
Expect(1, 3315, '\p{^knda}', "");
Expect(1, 3315, '\P{knda}', "");
Expect(0, 3315, '\P{^knda}', "");
Expect(1, 3314, '\p{	Knda}', "");
Expect(0, 3314, '\p{^	Knda}', "");
Expect(0, 3314, '\P{	Knda}', "");
Expect(1, 3314, '\P{^	Knda}', "");
Expect(0, 3315, '\p{	Knda}', "");
Expect(1, 3315, '\p{^	Knda}', "");
Expect(1, 3315, '\P{	Knda}', "");
Expect(0, 3315, '\P{^	Knda}', "");
Error('\p{/a/-IS_knda}');
Error('\P{/a/-IS_knda}');
Expect(1, 3314, '\p{isknda}', "");
Expect(0, 3314, '\p{^isknda}', "");
Expect(0, 3314, '\P{isknda}', "");
Expect(1, 3314, '\P{^isknda}', "");
Expect(0, 3315, '\p{isknda}', "");
Expect(1, 3315, '\p{^isknda}', "");
Expect(1, 3315, '\P{isknda}', "");
Expect(0, 3315, '\P{^isknda}', "");
Expect(1, 3314, '\p{	IS_Knda}', "");
Expect(0, 3314, '\p{^	IS_Knda}', "");
Expect(0, 3314, '\P{	IS_Knda}', "");
Expect(1, 3314, '\P{^	IS_Knda}', "");
Expect(0, 3315, '\p{	IS_Knda}', "");
Expect(1, 3315, '\p{^	IS_Knda}', "");
Expect(1, 3315, '\P{	IS_Knda}', "");
Expect(0, 3315, '\P{^	IS_Knda}', "");
Error('\p{:=- KATAKANA}');
Error('\P{:=- KATAKANA}');
Expect(1, 110592, '\p{katakana}', "");
Expect(0, 110592, '\p{^katakana}', "");
Expect(0, 110592, '\P{katakana}', "");
Expect(1, 110592, '\P{^katakana}', "");
Expect(0, 110593, '\p{katakana}', "");
Expect(1, 110593, '\p{^katakana}', "");
Expect(1, 110593, '\P{katakana}', "");
Expect(0, 110593, '\P{^katakana}', "");
Expect(1, 110592, '\p{- Katakana}', "");
Expect(0, 110592, '\p{^- Katakana}', "");
Expect(0, 110592, '\P{- Katakana}', "");
Expect(1, 110592, '\P{^- Katakana}', "");
Expect(0, 110593, '\p{- Katakana}', "");
Expect(1, 110593, '\p{^- Katakana}', "");
Expect(1, 110593, '\P{- Katakana}', "");
Expect(0, 110593, '\P{^- Katakana}', "");
Error('\p{ :=IS_Katakana}');
Error('\P{ :=IS_Katakana}');
Expect(1, 110592, '\p{iskatakana}', "");
Expect(0, 110592, '\p{^iskatakana}', "");
Expect(0, 110592, '\P{iskatakana}', "");
Expect(1, 110592, '\P{^iskatakana}', "");
Expect(0, 110593, '\p{iskatakana}', "");
Expect(1, 110593, '\p{^iskatakana}', "");
Expect(1, 110593, '\P{iskatakana}', "");
Expect(0, 110593, '\P{^iskatakana}', "");
Expect(1, 110592, '\p{	 Is_Katakana}', "");
Expect(0, 110592, '\p{^	 Is_Katakana}', "");
Expect(0, 110592, '\P{	 Is_Katakana}', "");
Expect(1, 110592, '\P{^	 Is_Katakana}', "");
Expect(0, 110593, '\p{	 Is_Katakana}', "");
Expect(1, 110593, '\p{^	 Is_Katakana}', "");
Expect(1, 110593, '\P{	 Is_Katakana}', "");
Expect(0, 110593, '\P{^	 Is_Katakana}', "");
Error('\p{- kana/a/}');
Error('\P{- kana/a/}');
Expect(1, 110592, '\p{kana}', "");
Expect(0, 110592, '\p{^kana}', "");
Expect(0, 110592, '\P{kana}', "");
Expect(1, 110592, '\P{^kana}', "");
Expect(0, 110593, '\p{kana}', "");
Expect(1, 110593, '\p{^kana}', "");
Expect(1, 110593, '\P{kana}', "");
Expect(0, 110593, '\P{^kana}', "");
Expect(1, 110592, '\p{-Kana}', "");
Expect(0, 110592, '\p{^-Kana}', "");
Expect(0, 110592, '\P{-Kana}', "");
Expect(1, 110592, '\P{^-Kana}', "");
Expect(0, 110593, '\p{-Kana}', "");
Expect(1, 110593, '\p{^-Kana}', "");
Expect(1, 110593, '\P{-Kana}', "");
Expect(0, 110593, '\P{^-Kana}', "");
Error('\p{/a/ _Is_Kana}');
Error('\P{/a/ _Is_Kana}');
Expect(1, 110592, '\p{iskana}', "");
Expect(0, 110592, '\p{^iskana}', "");
Expect(0, 110592, '\P{iskana}', "");
Expect(1, 110592, '\P{^iskana}', "");
Expect(0, 110593, '\p{iskana}', "");
Expect(1, 110593, '\p{^iskana}', "");
Expect(1, 110593, '\P{iskana}', "");
Expect(0, 110593, '\P{^iskana}', "");
Expect(1, 110592, '\p{	 is_Kana}', "");
Expect(0, 110592, '\p{^	 is_Kana}', "");
Expect(0, 110592, '\P{	 is_Kana}', "");
Expect(1, 110592, '\P{^	 is_Kana}', "");
Expect(0, 110593, '\p{	 is_Kana}', "");
Expect(1, 110593, '\p{^	 is_Kana}', "");
Expect(1, 110593, '\P{	 is_Kana}', "");
Expect(0, 110593, '\P{^	 is_Kana}', "");
Error('\p{Katakana_Or_Hiragana}');
Error('\P{Katakana_Or_Hiragana}');
Error('\p{Is_Katakana_Or_Hiragana}');
Error('\P{Is_Katakana_Or_Hiragana}');
Error('\p{Hrkt}');
Error('\P{Hrkt}');
Error('\p{Is_Hrkt}');
Error('\P{Is_Hrkt}');
Error('\p{-	Katakana_phonetic_extensions/a/}');
Error('\P{-	Katakana_phonetic_extensions/a/}');
Expect(1, 12799, '\p{katakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^katakanaphoneticextensions}', "");
Expect(0, 12799, '\P{katakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^katakanaphoneticextensions}', "");
Expect(0, 12800, '\p{katakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^katakanaphoneticextensions}', "");
Expect(1, 12800, '\P{katakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^katakanaphoneticextensions}', "");
Expect(1, 12799, '\p{_ katakana_PHONETIC_Extensions}', "");
Expect(0, 12799, '\p{^_ katakana_PHONETIC_Extensions}', "");
Expect(0, 12799, '\P{_ katakana_PHONETIC_Extensions}', "");
Expect(1, 12799, '\P{^_ katakana_PHONETIC_Extensions}', "");
Expect(0, 12800, '\p{_ katakana_PHONETIC_Extensions}', "");
Expect(1, 12800, '\p{^_ katakana_PHONETIC_Extensions}', "");
Expect(1, 12800, '\P{_ katakana_PHONETIC_Extensions}', "");
Expect(0, 12800, '\P{^_ katakana_PHONETIC_Extensions}', "");
Error('\p{_/a/Is_KATAKANA_Phonetic_EXTENSIONS}');
Error('\P{_/a/Is_KATAKANA_Phonetic_EXTENSIONS}');
Expect(1, 12799, '\p{iskatakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^iskatakanaphoneticextensions}', "");
Expect(0, 12799, '\P{iskatakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^iskatakanaphoneticextensions}', "");
Expect(0, 12800, '\p{iskatakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^iskatakanaphoneticextensions}', "");
Expect(1, 12800, '\P{iskatakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^iskatakanaphoneticextensions}', "");
Expect(1, 12799, '\p{  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(0, 12799, '\p{^  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(0, 12799, '\P{  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(1, 12799, '\P{^  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(0, 12800, '\p{  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(1, 12800, '\p{^  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(1, 12800, '\P{  IS_Katakana_phonetic_EXTENSIONS}', "");
Expect(0, 12800, '\P{^  IS_Katakana_phonetic_EXTENSIONS}', "");
Error('\p{/a/_In_KATAKANA_phonetic_EXTENSIONS}');
Error('\P{/a/_In_KATAKANA_phonetic_EXTENSIONS}');
Expect(1, 12799, '\p{inkatakanaphoneticextensions}', "");
Expect(0, 12799, '\p{^inkatakanaphoneticextensions}', "");
Expect(0, 12799, '\P{inkatakanaphoneticextensions}', "");
Expect(1, 12799, '\P{^inkatakanaphoneticextensions}', "");
Expect(0, 12800, '\p{inkatakanaphoneticextensions}', "");
Expect(1, 12800, '\p{^inkatakanaphoneticextensions}', "");
Expect(1, 12800, '\P{inkatakanaphoneticextensions}', "");
Expect(0, 12800, '\P{^inkatakanaphoneticextensions}', "");
Expect(1, 12799, '\p{ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(0, 12799, '\p{^ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(0, 12799, '\P{ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(1, 12799, '\P{^ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(0, 12800, '\p{ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(1, 12800, '\p{^ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(1, 12800, '\P{ 	in_KATAKANA_phonetic_Extensions}', "");
Expect(0, 12800, '\P{^ 	in_KATAKANA_phonetic_Extensions}', "");
Error('\p{  katakana_EXT:=}');
Error('\P{  katakana_EXT:=}');
Expect(1, 12799, '\p{katakanaext}', "");
Expect(0, 12799, '\p{^katakanaext}', "");
Expect(0, 12799, '\P{katakanaext}', "");
Expect(1, 12799, '\P{^katakanaext}', "");
Expect(0, 12800, '\p{katakanaext}', "");
Expect(1, 12800, '\p{^katakanaext}', "");
Expect(1, 12800, '\P{katakanaext}', "");
Expect(0, 12800, '\P{^katakanaext}', "");
Expect(1, 12799, '\p{-_Katakana_EXT}', "");
Expect(0, 12799, '\p{^-_Katakana_EXT}', "");
Expect(0, 12799, '\P{-_Katakana_EXT}', "");
Expect(1, 12799, '\P{^-_Katakana_EXT}', "");
Expect(0, 12800, '\p{-_Katakana_EXT}', "");
Expect(1, 12800, '\p{^-_Katakana_EXT}', "");
Expect(1, 12800, '\P{-_Katakana_EXT}', "");
Expect(0, 12800, '\P{^-_Katakana_EXT}', "");
Error('\p{- is_Katakana_EXT/a/}');
Error('\P{- is_Katakana_EXT/a/}');
Expect(1, 12799, '\p{iskatakanaext}', "");
Expect(0, 12799, '\p{^iskatakanaext}', "");
Expect(0, 12799, '\P{iskatakanaext}', "");
Expect(1, 12799, '\P{^iskatakanaext}', "");
Expect(0, 12800, '\p{iskatakanaext}', "");
Expect(1, 12800, '\p{^iskatakanaext}', "");
Expect(1, 12800, '\P{iskatakanaext}', "");
Expect(0, 12800, '\P{^iskatakanaext}', "");
Expect(1, 12799, '\p{__IS_KATAKANA_Ext}', "");
Expect(0, 12799, '\p{^__IS_KATAKANA_Ext}', "");
Expect(0, 12799, '\P{__IS_KATAKANA_Ext}', "");
Expect(1, 12799, '\P{^__IS_KATAKANA_Ext}', "");
Expect(0, 12800, '\p{__IS_KATAKANA_Ext}', "");
Expect(1, 12800, '\p{^__IS_KATAKANA_Ext}', "");
Expect(1, 12800, '\P{__IS_KATAKANA_Ext}', "");
Expect(0, 12800, '\P{^__IS_KATAKANA_Ext}', "");
Error('\p{_In_Katakana_EXT:=}');
Error('\P{_In_Katakana_EXT:=}');
Expect(1, 12799, '\p{inkatakanaext}', "");
Expect(0, 12799, '\p{^inkatakanaext}', "");
Expect(0, 12799, '\P{inkatakanaext}', "");
Expect(1, 12799, '\P{^inkatakanaext}', "");
Expect(0, 12800, '\p{inkatakanaext}', "");
Expect(1, 12800, '\p{^inkatakanaext}', "");
Expect(1, 12800, '\P{inkatakanaext}', "");
Expect(0, 12800, '\P{^inkatakanaext}', "");
Expect(1, 12799, '\p{ -In_Katakana_ext}', "");
Expect(0, 12799, '\p{^ -In_Katakana_ext}', "");
Expect(0, 12799, '\P{ -In_Katakana_ext}', "");
Expect(1, 12799, '\P{^ -In_Katakana_ext}', "");
Expect(0, 12800, '\p{ -In_Katakana_ext}', "");
Expect(1, 12800, '\p{^ -In_Katakana_ext}', "");
Expect(1, 12800, '\P{ -In_Katakana_ext}', "");
Expect(0, 12800, '\P{^ -In_Katakana_ext}', "");
Error('\p{ -kayah_LI/a/}');
Error('\P{ -kayah_LI/a/}');
Expect(1, 43311, '\p{kayahli}', "");
Expect(0, 43311, '\p{^kayahli}', "");
Expect(0, 43311, '\P{kayahli}', "");
Expect(1, 43311, '\P{^kayahli}', "");
Expect(0, 43312, '\p{kayahli}', "");
Expect(1, 43312, '\p{^kayahli}', "");
Expect(1, 43312, '\P{kayahli}', "");
Expect(0, 43312, '\P{^kayahli}', "");
Expect(1, 43311, '\p{  kayah_li}', "");
Expect(0, 43311, '\p{^  kayah_li}', "");
Expect(0, 43311, '\P{  kayah_li}', "");
Expect(1, 43311, '\P{^  kayah_li}', "");
Expect(0, 43312, '\p{  kayah_li}', "");
Expect(1, 43312, '\p{^  kayah_li}', "");
Expect(1, 43312, '\P{  kayah_li}', "");
Expect(0, 43312, '\P{^  kayah_li}', "");
Error('\p{:=-_Is_KAYAH_LI}');
Error('\P{:=-_Is_KAYAH_LI}');
Expect(1, 43311, '\p{iskayahli}', "");
Expect(0, 43311, '\p{^iskayahli}', "");
Expect(0, 43311, '\P{iskayahli}', "");
Expect(1, 43311, '\P{^iskayahli}', "");
Expect(0, 43312, '\p{iskayahli}', "");
Expect(1, 43312, '\p{^iskayahli}', "");
Expect(1, 43312, '\P{iskayahli}', "");
Expect(0, 43312, '\P{^iskayahli}', "");
Expect(1, 43311, '\p{-_Is_Kayah_Li}', "");
Expect(0, 43311, '\p{^-_Is_Kayah_Li}', "");
Expect(0, 43311, '\P{-_Is_Kayah_Li}', "");
Expect(1, 43311, '\P{^-_Is_Kayah_Li}', "");
Expect(0, 43312, '\p{-_Is_Kayah_Li}', "");
Expect(1, 43312, '\p{^-_Is_Kayah_Li}', "");
Expect(1, 43312, '\P{-_Is_Kayah_Li}', "");
Expect(0, 43312, '\P{^-_Is_Kayah_Li}', "");
Error('\p{/a/	 KALI}');
Error('\P{/a/	 KALI}');
Expect(1, 43311, '\p{kali}', "");
Expect(0, 43311, '\p{^kali}', "");
Expect(0, 43311, '\P{kali}', "");
Expect(1, 43311, '\P{^kali}', "");
Expect(0, 43312, '\p{kali}', "");
Expect(1, 43312, '\p{^kali}', "");
Expect(1, 43312, '\P{kali}', "");
Expect(0, 43312, '\P{^kali}', "");
Expect(1, 43311, '\p{-kali}', "");
Expect(0, 43311, '\p{^-kali}', "");
Expect(0, 43311, '\P{-kali}', "");
Expect(1, 43311, '\P{^-kali}', "");
Expect(0, 43312, '\p{-kali}', "");
Expect(1, 43312, '\p{^-kali}', "");
Expect(1, 43312, '\P{-kali}', "");
Expect(0, 43312, '\P{^-kali}', "");
Error('\p{  Is_kali:=}');
Error('\P{  Is_kali:=}');
Expect(1, 43311, '\p{iskali}', "");
Expect(0, 43311, '\p{^iskali}', "");
Expect(0, 43311, '\P{iskali}', "");
Expect(1, 43311, '\P{^iskali}', "");
Expect(0, 43312, '\p{iskali}', "");
Expect(1, 43312, '\p{^iskali}', "");
Expect(1, 43312, '\P{iskali}', "");
Expect(0, 43312, '\P{^iskali}', "");
Expect(1, 43311, '\p{_-is_KALI}', "");
Expect(0, 43311, '\p{^_-is_KALI}', "");
Expect(0, 43311, '\P{_-is_KALI}', "");
Expect(1, 43311, '\P{^_-is_KALI}', "");
Expect(0, 43312, '\p{_-is_KALI}', "");
Expect(1, 43312, '\p{^_-is_KALI}', "");
Expect(1, 43312, '\P{_-is_KALI}', "");
Expect(0, 43312, '\P{^_-is_KALI}', "");
Error('\p{ /a/kharoshthi}');
Error('\P{ /a/kharoshthi}');
Expect(1, 68184, '\p{kharoshthi}', "");
Expect(0, 68184, '\p{^kharoshthi}', "");
Expect(0, 68184, '\P{kharoshthi}', "");
Expect(1, 68184, '\P{^kharoshthi}', "");
Expect(0, 68185, '\p{kharoshthi}', "");
Expect(1, 68185, '\p{^kharoshthi}', "");
Expect(1, 68185, '\P{kharoshthi}', "");
Expect(0, 68185, '\P{^kharoshthi}', "");
Expect(1, 68184, '\p{	Kharoshthi}', "");
Expect(0, 68184, '\p{^	Kharoshthi}', "");
Expect(0, 68184, '\P{	Kharoshthi}', "");
Expect(1, 68184, '\P{^	Kharoshthi}', "");
Expect(0, 68185, '\p{	Kharoshthi}', "");
Expect(1, 68185, '\p{^	Kharoshthi}', "");
Expect(1, 68185, '\P{	Kharoshthi}', "");
Expect(0, 68185, '\P{^	Kharoshthi}', "");
Error('\p{_:=Is_KHAROSHTHI}');
Error('\P{_:=Is_KHAROSHTHI}');
Expect(1, 68184, '\p{iskharoshthi}', "");
Expect(0, 68184, '\p{^iskharoshthi}', "");
Expect(0, 68184, '\P{iskharoshthi}', "");
Expect(1, 68184, '\P{^iskharoshthi}', "");
Expect(0, 68185, '\p{iskharoshthi}', "");
Expect(1, 68185, '\p{^iskharoshthi}', "");
Expect(1, 68185, '\P{iskharoshthi}', "");
Expect(0, 68185, '\P{^iskharoshthi}', "");
Expect(1, 68184, '\p{	-Is_Kharoshthi}', "");
Expect(0, 68184, '\p{^	-Is_Kharoshthi}', "");
Expect(0, 68184, '\P{	-Is_Kharoshthi}', "");
Expect(1, 68184, '\P{^	-Is_Kharoshthi}', "");
Expect(0, 68185, '\p{	-Is_Kharoshthi}', "");
Expect(1, 68185, '\p{^	-Is_Kharoshthi}', "");
Expect(1, 68185, '\P{	-Is_Kharoshthi}', "");
Expect(0, 68185, '\P{^	-Is_Kharoshthi}', "");
Error('\p{/a/__Khar}');
Error('\P{/a/__Khar}');
Expect(1, 68184, '\p{khar}', "");
Expect(0, 68184, '\p{^khar}', "");
Expect(0, 68184, '\P{khar}', "");
Expect(1, 68184, '\P{^khar}', "");
Expect(0, 68185, '\p{khar}', "");
Expect(1, 68185, '\p{^khar}', "");
Expect(1, 68185, '\P{khar}', "");
Expect(0, 68185, '\P{^khar}', "");
Expect(1, 68184, '\p{		Khar}', "");
Expect(0, 68184, '\p{^		Khar}', "");
Expect(0, 68184, '\P{		Khar}', "");
Expect(1, 68184, '\P{^		Khar}', "");
Expect(0, 68185, '\p{		Khar}', "");
Expect(1, 68185, '\p{^		Khar}', "");
Expect(1, 68185, '\P{		Khar}', "");
Expect(0, 68185, '\P{^		Khar}', "");
Error('\p{/a/--is_khar}');
Error('\P{/a/--is_khar}');
Expect(1, 68184, '\p{iskhar}', "");
Expect(0, 68184, '\p{^iskhar}', "");
Expect(0, 68184, '\P{iskhar}', "");
Expect(1, 68184, '\P{^iskhar}', "");
Expect(0, 68185, '\p{iskhar}', "");
Expect(1, 68185, '\p{^iskhar}', "");
Expect(1, 68185, '\P{iskhar}', "");
Expect(0, 68185, '\P{^iskhar}', "");
Expect(1, 68184, '\p{--Is_Khar}', "");
Expect(0, 68184, '\p{^--Is_Khar}', "");
Expect(0, 68184, '\P{--Is_Khar}', "");
Expect(1, 68184, '\P{^--Is_Khar}', "");
Expect(0, 68185, '\p{--Is_Khar}', "");
Expect(1, 68185, '\p{^--Is_Khar}', "");
Expect(1, 68185, '\P{--Is_Khar}', "");
Expect(0, 68185, '\P{^--Is_Khar}', "");
Error('\p{/a/__Khmer}');
Error('\P{/a/__Khmer}');
Expect(1, 6655, '\p{khmer}', "");
Expect(0, 6655, '\p{^khmer}', "");
Expect(0, 6655, '\P{khmer}', "");
Expect(1, 6655, '\P{^khmer}', "");
Expect(0, 6656, '\p{khmer}', "");
Expect(1, 6656, '\p{^khmer}', "");
Expect(1, 6656, '\P{khmer}', "");
Expect(0, 6656, '\P{^khmer}', "");
Expect(1, 6655, '\p{-	KHMER}', "");
Expect(0, 6655, '\p{^-	KHMER}', "");
Expect(0, 6655, '\P{-	KHMER}', "");
Expect(1, 6655, '\P{^-	KHMER}', "");
Expect(0, 6656, '\p{-	KHMER}', "");
Expect(1, 6656, '\p{^-	KHMER}', "");
Expect(1, 6656, '\P{-	KHMER}', "");
Expect(0, 6656, '\P{^-	KHMER}', "");
Error('\p{-_Is_KHMER/a/}');
Error('\P{-_Is_KHMER/a/}');
Expect(1, 6655, '\p{iskhmer}', "");
Expect(0, 6655, '\p{^iskhmer}', "");
Expect(0, 6655, '\P{iskhmer}', "");
Expect(1, 6655, '\P{^iskhmer}', "");
Expect(0, 6656, '\p{iskhmer}', "");
Expect(1, 6656, '\p{^iskhmer}', "");
Expect(1, 6656, '\P{iskhmer}', "");
Expect(0, 6656, '\P{^iskhmer}', "");
Expect(1, 6655, '\p{ is_khmer}', "");
Expect(0, 6655, '\p{^ is_khmer}', "");
Expect(0, 6655, '\P{ is_khmer}', "");
Expect(1, 6655, '\P{^ is_khmer}', "");
Expect(0, 6656, '\p{ is_khmer}', "");
Expect(1, 6656, '\p{^ is_khmer}', "");
Expect(1, 6656, '\P{ is_khmer}', "");
Expect(0, 6656, '\P{^ is_khmer}', "");
Error('\p{:=khmr}');
Error('\P{:=khmr}');
Expect(1, 6655, '\p{khmr}', "");
Expect(0, 6655, '\p{^khmr}', "");
Expect(0, 6655, '\P{khmr}', "");
Expect(1, 6655, '\P{^khmr}', "");
Expect(0, 6656, '\p{khmr}', "");
Expect(1, 6656, '\p{^khmr}', "");
Expect(1, 6656, '\P{khmr}', "");
Expect(0, 6656, '\P{^khmr}', "");
Expect(1, 6655, '\p{_khmr}', "");
Expect(0, 6655, '\p{^_khmr}', "");
Expect(0, 6655, '\P{_khmr}', "");
Expect(1, 6655, '\P{^_khmr}', "");
Expect(0, 6656, '\p{_khmr}', "");
Expect(1, 6656, '\p{^_khmr}', "");
Expect(1, 6656, '\P{_khmr}', "");
Expect(0, 6656, '\P{^_khmr}', "");
Error('\p{:=--IS_khmr}');
Error('\P{:=--IS_khmr}');
Expect(1, 6655, '\p{iskhmr}', "");
Expect(0, 6655, '\p{^iskhmr}', "");
Expect(0, 6655, '\P{iskhmr}', "");
Expect(1, 6655, '\P{^iskhmr}', "");
Expect(0, 6656, '\p{iskhmr}', "");
Expect(1, 6656, '\p{^iskhmr}', "");
Expect(1, 6656, '\P{iskhmr}', "");
Expect(0, 6656, '\P{^iskhmr}', "");
Expect(1, 6655, '\p{--Is_KHMR}', "");
Expect(0, 6655, '\p{^--Is_KHMR}', "");
Expect(0, 6655, '\P{--Is_KHMR}', "");
Expect(1, 6655, '\P{^--Is_KHMR}', "");
Expect(0, 6656, '\p{--Is_KHMR}', "");
Expect(1, 6656, '\p{^--Is_KHMR}', "");
Expect(1, 6656, '\P{--Is_KHMR}', "");
Expect(0, 6656, '\P{^--Is_KHMR}', "");
Error('\p{-_Khmer_Symbols/a/}');
Error('\P{-_Khmer_Symbols/a/}');
Expect(1, 6655, '\p{khmersymbols}', "");
Expect(0, 6655, '\p{^khmersymbols}', "");
Expect(0, 6655, '\P{khmersymbols}', "");
Expect(1, 6655, '\P{^khmersymbols}', "");
Expect(0, 6656, '\p{khmersymbols}', "");
Expect(1, 6656, '\p{^khmersymbols}', "");
Expect(1, 6656, '\P{khmersymbols}', "");
Expect(0, 6656, '\P{^khmersymbols}', "");
Expect(1, 6655, '\p{	khmer_Symbols}', "");
Expect(0, 6655, '\p{^	khmer_Symbols}', "");
Expect(0, 6655, '\P{	khmer_Symbols}', "");
Expect(1, 6655, '\P{^	khmer_Symbols}', "");
Expect(0, 6656, '\p{	khmer_Symbols}', "");
Expect(1, 6656, '\p{^	khmer_Symbols}', "");
Expect(1, 6656, '\P{	khmer_Symbols}', "");
Expect(0, 6656, '\P{^	khmer_Symbols}', "");
Error('\p{ Is_Khmer_Symbols:=}');
Error('\P{ Is_Khmer_Symbols:=}');
Expect(1, 6655, '\p{iskhmersymbols}', "");
Expect(0, 6655, '\p{^iskhmersymbols}', "");
Expect(0, 6655, '\P{iskhmersymbols}', "");
Expect(1, 6655, '\P{^iskhmersymbols}', "");
Expect(0, 6656, '\p{iskhmersymbols}', "");
Expect(1, 6656, '\p{^iskhmersymbols}', "");
Expect(1, 6656, '\P{iskhmersymbols}', "");
Expect(0, 6656, '\P{^iskhmersymbols}', "");
Expect(1, 6655, '\p{	Is_Khmer_SYMBOLS}', "");
Expect(0, 6655, '\p{^	Is_Khmer_SYMBOLS}', "");
Expect(0, 6655, '\P{	Is_Khmer_SYMBOLS}', "");
Expect(1, 6655, '\P{^	Is_Khmer_SYMBOLS}', "");
Expect(0, 6656, '\p{	Is_Khmer_SYMBOLS}', "");
Expect(1, 6656, '\p{^	Is_Khmer_SYMBOLS}', "");
Expect(1, 6656, '\P{	Is_Khmer_SYMBOLS}', "");
Expect(0, 6656, '\P{^	Is_Khmer_SYMBOLS}', "");
Error('\p{:= IN_Khmer_Symbols}');
Error('\P{:= IN_Khmer_Symbols}');
Expect(1, 6655, '\p{inkhmersymbols}', "");
Expect(0, 6655, '\p{^inkhmersymbols}', "");
Expect(0, 6655, '\P{inkhmersymbols}', "");
Expect(1, 6655, '\P{^inkhmersymbols}', "");
Expect(0, 6656, '\p{inkhmersymbols}', "");
Expect(1, 6656, '\p{^inkhmersymbols}', "");
Expect(1, 6656, '\P{inkhmersymbols}', "");
Expect(0, 6656, '\P{^inkhmersymbols}', "");
Expect(1, 6655, '\p{ in_KHMER_symbols}', "");
Expect(0, 6655, '\p{^ in_KHMER_symbols}', "");
Expect(0, 6655, '\P{ in_KHMER_symbols}', "");
Expect(1, 6655, '\P{^ in_KHMER_symbols}', "");
Expect(0, 6656, '\p{ in_KHMER_symbols}', "");
Expect(1, 6656, '\p{^ in_KHMER_symbols}', "");
Expect(1, 6656, '\P{ in_KHMER_symbols}', "");
Expect(0, 6656, '\P{^ in_KHMER_symbols}', "");
Error('\p{__Lao/a/}');
Error('\P{__Lao/a/}');
Expect(1, 3807, '\p{lao}', "");
Expect(0, 3807, '\p{^lao}', "");
Expect(0, 3807, '\P{lao}', "");
Expect(1, 3807, '\P{^lao}', "");
Expect(0, 3808, '\p{lao}', "");
Expect(1, 3808, '\p{^lao}', "");
Expect(1, 3808, '\P{lao}', "");
Expect(0, 3808, '\P{^lao}', "");
Expect(1, 3807, '\p{-_Lao}', "");
Expect(0, 3807, '\p{^-_Lao}', "");
Expect(0, 3807, '\P{-_Lao}', "");
Expect(1, 3807, '\P{^-_Lao}', "");
Expect(0, 3808, '\p{-_Lao}', "");
Expect(1, 3808, '\p{^-_Lao}', "");
Expect(1, 3808, '\P{-_Lao}', "");
Expect(0, 3808, '\P{^-_Lao}', "");
Error('\p{:=	_is_Lao}');
Error('\P{:=	_is_Lao}');
Expect(1, 3807, '\p{islao}', "");
Expect(0, 3807, '\p{^islao}', "");
Expect(0, 3807, '\P{islao}', "");
Expect(1, 3807, '\P{^islao}', "");
Expect(0, 3808, '\p{islao}', "");
Expect(1, 3808, '\p{^islao}', "");
Expect(1, 3808, '\P{islao}', "");
Expect(0, 3808, '\P{^islao}', "");
Expect(1, 3807, '\p{	 Is_lao}', "");
Expect(0, 3807, '\p{^	 Is_lao}', "");
Expect(0, 3807, '\P{	 Is_lao}', "");
Expect(1, 3807, '\P{^	 Is_lao}', "");
Expect(0, 3808, '\p{	 Is_lao}', "");
Expect(1, 3808, '\p{^	 Is_lao}', "");
Expect(1, 3808, '\P{	 Is_lao}', "");
Expect(0, 3808, '\P{^	 Is_lao}', "");
Error('\p{_Laoo/a/}');
Error('\P{_Laoo/a/}');
Expect(1, 3807, '\p{laoo}', "");
Expect(0, 3807, '\p{^laoo}', "");
Expect(0, 3807, '\P{laoo}', "");
Expect(1, 3807, '\P{^laoo}', "");
Expect(0, 3808, '\p{laoo}', "");
Expect(1, 3808, '\p{^laoo}', "");
Expect(1, 3808, '\P{laoo}', "");
Expect(0, 3808, '\P{^laoo}', "");
Expect(1, 3807, '\p{-laoo}', "");
Expect(0, 3807, '\p{^-laoo}', "");
Expect(0, 3807, '\P{-laoo}', "");
Expect(1, 3807, '\P{^-laoo}', "");
Expect(0, 3808, '\p{-laoo}', "");
Expect(1, 3808, '\p{^-laoo}', "");
Expect(1, 3808, '\P{-laoo}', "");
Expect(0, 3808, '\P{^-laoo}', "");
Error('\p{-/a/is_Laoo}');
Error('\P{-/a/is_Laoo}');
Expect(1, 3807, '\p{islaoo}', "");
Expect(0, 3807, '\p{^islaoo}', "");
Expect(0, 3807, '\P{islaoo}', "");
Expect(1, 3807, '\P{^islaoo}', "");
Expect(0, 3808, '\p{islaoo}', "");
Expect(1, 3808, '\p{^islaoo}', "");
Expect(1, 3808, '\P{islaoo}', "");
Expect(0, 3808, '\P{^islaoo}', "");
Expect(1, 3807, '\p{ 	is_Laoo}', "");
Expect(0, 3807, '\p{^ 	is_Laoo}', "");
Expect(0, 3807, '\P{ 	is_Laoo}', "");
Expect(1, 3807, '\P{^ 	is_Laoo}', "");
Expect(0, 3808, '\p{ 	is_Laoo}', "");
Expect(1, 3808, '\p{^ 	is_Laoo}', "");
Expect(1, 3808, '\P{ 	is_Laoo}', "");
Expect(0, 3808, '\P{^ 	is_Laoo}', "");
Error('\p{__Latin:=}');
Error('\P{__Latin:=}');
Expect(1, 65370, '\p{latin}', "");
Expect(0, 65370, '\p{^latin}', "");
Expect(0, 65370, '\P{latin}', "");
Expect(1, 65370, '\P{^latin}', "");
Expect(0, 65371, '\p{latin}', "");
Expect(1, 65371, '\p{^latin}', "");
Expect(1, 65371, '\P{latin}', "");
Expect(0, 65371, '\P{^latin}', "");
Expect(1, 65370, '\p{_-Latin}', "");
Expect(0, 65370, '\p{^_-Latin}', "");
Expect(0, 65370, '\P{_-Latin}', "");
Expect(1, 65370, '\P{^_-Latin}', "");
Expect(0, 65371, '\p{_-Latin}', "");
Expect(1, 65371, '\p{^_-Latin}', "");
Expect(1, 65371, '\P{_-Latin}', "");
Expect(0, 65371, '\P{^_-Latin}', "");
Error('\p{ 	is_Latin/a/}');
Error('\P{ 	is_Latin/a/}');
Expect(1, 65370, '\p{islatin}', "");
Expect(0, 65370, '\p{^islatin}', "");
Expect(0, 65370, '\P{islatin}', "");
Expect(1, 65370, '\P{^islatin}', "");
Expect(0, 65371, '\p{islatin}', "");
Expect(1, 65371, '\p{^islatin}', "");
Expect(1, 65371, '\P{islatin}', "");
Expect(0, 65371, '\P{^islatin}', "");
Expect(1, 65370, '\p{ -IS_Latin}', "");
Expect(0, 65370, '\p{^ -IS_Latin}', "");
Expect(0, 65370, '\P{ -IS_Latin}', "");
Expect(1, 65370, '\P{^ -IS_Latin}', "");
Expect(0, 65371, '\p{ -IS_Latin}', "");
Expect(1, 65371, '\p{^ -IS_Latin}', "");
Expect(1, 65371, '\P{ -IS_Latin}', "");
Expect(0, 65371, '\P{^ -IS_Latin}', "");
Error('\p{_/a/Latn}');
Error('\P{_/a/Latn}');
Expect(1, 65370, '\p{latn}', "");
Expect(0, 65370, '\p{^latn}', "");
Expect(0, 65370, '\P{latn}', "");
Expect(1, 65370, '\P{^latn}', "");
Expect(0, 65371, '\p{latn}', "");
Expect(1, 65371, '\p{^latn}', "");
Expect(1, 65371, '\P{latn}', "");
Expect(0, 65371, '\P{^latn}', "");
Expect(1, 65370, '\p{		LATN}', "");
Expect(0, 65370, '\p{^		LATN}', "");
Expect(0, 65370, '\P{		LATN}', "");
Expect(1, 65370, '\P{^		LATN}', "");
Expect(0, 65371, '\p{		LATN}', "");
Expect(1, 65371, '\p{^		LATN}', "");
Expect(1, 65371, '\P{		LATN}', "");
Expect(0, 65371, '\P{^		LATN}', "");
Error('\p{ is_LATN:=}');
Error('\P{ is_LATN:=}');
Expect(1, 65370, '\p{islatn}', "");
Expect(0, 65370, '\p{^islatn}', "");
Expect(0, 65370, '\P{islatn}', "");
Expect(1, 65370, '\P{^islatn}', "");
Expect(0, 65371, '\p{islatn}', "");
Expect(1, 65371, '\p{^islatn}', "");
Expect(1, 65371, '\P{islatn}', "");
Expect(0, 65371, '\P{^islatn}', "");
Expect(1, 65370, '\p{_ is_LATN}', "");
Expect(0, 65370, '\p{^_ is_LATN}', "");
Expect(0, 65370, '\P{_ is_LATN}', "");
Expect(1, 65370, '\P{^_ is_LATN}', "");
Expect(0, 65371, '\p{_ is_LATN}', "");
Expect(1, 65371, '\p{^_ is_LATN}', "");
Expect(1, 65371, '\P{_ is_LATN}', "");
Expect(0, 65371, '\P{^_ is_LATN}', "");
Error('\p{		Latin_1_Supplement/a/}');
Error('\P{		Latin_1_Supplement/a/}');
Expect(1, 255, '\p{latin1supplement}', "");
Expect(0, 255, '\p{^latin1supplement}', "");
Expect(0, 255, '\P{latin1supplement}', "");
Expect(1, 255, '\P{^latin1supplement}', "");
Expect(0, 256, '\p{latin1supplement}', "");
Expect(1, 256, '\p{^latin1supplement}', "");
Expect(1, 256, '\P{latin1supplement}', "");
Expect(0, 256, '\P{^latin1supplement}', "");
Expect(1, 255, '\p{-Latin_1_SUPPLEMENT}', "");
Expect(0, 255, '\p{^-Latin_1_SUPPLEMENT}', "");
Expect(0, 255, '\P{-Latin_1_SUPPLEMENT}', "");
Expect(1, 255, '\P{^-Latin_1_SUPPLEMENT}', "");
Expect(0, 256, '\p{-Latin_1_SUPPLEMENT}', "");
Expect(1, 256, '\p{^-Latin_1_SUPPLEMENT}', "");
Expect(1, 256, '\P{-Latin_1_SUPPLEMENT}', "");
Expect(0, 256, '\P{^-Latin_1_SUPPLEMENT}', "");
Error('\p{/a/	is_latin_1_Supplement}');
Error('\P{/a/	is_latin_1_Supplement}');
Expect(1, 255, '\p{islatin1supplement}', "");
Expect(0, 255, '\p{^islatin1supplement}', "");
Expect(0, 255, '\P{islatin1supplement}', "");
Expect(1, 255, '\P{^islatin1supplement}', "");
Expect(0, 256, '\p{islatin1supplement}', "");
Expect(1, 256, '\p{^islatin1supplement}', "");
Expect(1, 256, '\P{islatin1supplement}', "");
Expect(0, 256, '\P{^islatin1supplement}', "");
Expect(1, 255, '\p{--is_LATIN_1_Supplement}', "");
Expect(0, 255, '\p{^--is_LATIN_1_Supplement}', "");
Expect(0, 255, '\P{--is_LATIN_1_Supplement}', "");
Expect(1, 255, '\P{^--is_LATIN_1_Supplement}', "");
Expect(0, 256, '\p{--is_LATIN_1_Supplement}', "");
Expect(1, 256, '\p{^--is_LATIN_1_Supplement}', "");
Expect(1, 256, '\P{--is_LATIN_1_Supplement}', "");
Expect(0, 256, '\P{^--is_LATIN_1_Supplement}', "");
Error('\p{:=In_Latin_1_Supplement}');
Error('\P{:=In_Latin_1_Supplement}');
Expect(1, 255, '\p{inlatin1supplement}', "");
Expect(0, 255, '\p{^inlatin1supplement}', "");
Expect(0, 255, '\P{inlatin1supplement}', "");
Expect(1, 255, '\P{^inlatin1supplement}', "");
Expect(0, 256, '\p{inlatin1supplement}', "");
Expect(1, 256, '\p{^inlatin1supplement}', "");
Expect(1, 256, '\P{inlatin1supplement}', "");
Expect(0, 256, '\P{^inlatin1supplement}', "");
Expect(1, 255, '\p{	IN_LATIN_1_supplement}', "");
Expect(0, 255, '\p{^	IN_LATIN_1_supplement}', "");
Expect(0, 255, '\P{	IN_LATIN_1_supplement}', "");
Expect(1, 255, '\P{^	IN_LATIN_1_supplement}', "");
Expect(0, 256, '\p{	IN_LATIN_1_supplement}', "");
Expect(1, 256, '\p{^	IN_LATIN_1_supplement}', "");
Expect(1, 256, '\P{	IN_LATIN_1_supplement}', "");
Expect(0, 256, '\P{^	IN_LATIN_1_supplement}', "");
Error('\p{_:=Latin_1_Sup}');
Error('\P{_:=Latin_1_Sup}');
Expect(1, 255, '\p{latin1sup}', "");
Expect(0, 255, '\p{^latin1sup}', "");
Expect(0, 255, '\P{latin1sup}', "");
Expect(1, 255, '\P{^latin1sup}', "");
Expect(0, 256, '\p{latin1sup}', "");
Expect(1, 256, '\p{^latin1sup}', "");
Expect(1, 256, '\P{latin1sup}', "");
Expect(0, 256, '\P{^latin1sup}', "");
Expect(1, 255, '\p{-LATIN_1_SUP}', "");
Expect(0, 255, '\p{^-LATIN_1_SUP}', "");
Expect(0, 255, '\P{-LATIN_1_SUP}', "");
Expect(1, 255, '\P{^-LATIN_1_SUP}', "");
Expect(0, 256, '\p{-LATIN_1_SUP}', "");
Expect(1, 256, '\p{^-LATIN_1_SUP}', "");
Expect(1, 256, '\P{-LATIN_1_SUP}', "");
Expect(0, 256, '\P{^-LATIN_1_SUP}', "");
Error('\p{:=-Is_Latin_1_sup}');
Error('\P{:=-Is_Latin_1_sup}');
Expect(1, 255, '\p{islatin1sup}', "");
Expect(0, 255, '\p{^islatin1sup}', "");
Expect(0, 255, '\P{islatin1sup}', "");
Expect(1, 255, '\P{^islatin1sup}', "");
Expect(0, 256, '\p{islatin1sup}', "");
Expect(1, 256, '\p{^islatin1sup}', "");
Expect(1, 256, '\P{islatin1sup}', "");
Expect(0, 256, '\P{^islatin1sup}', "");
Expect(1, 255, '\p{is_latin_1_SUP}', "");
Expect(0, 255, '\p{^is_latin_1_SUP}', "");
Expect(0, 255, '\P{is_latin_1_SUP}', "");
Expect(1, 255, '\P{^is_latin_1_SUP}', "");
Expect(0, 256, '\p{is_latin_1_SUP}', "");
Expect(1, 256, '\p{^is_latin_1_SUP}', "");
Expect(1, 256, '\P{is_latin_1_SUP}', "");
Expect(0, 256, '\P{^is_latin_1_SUP}', "");
Error('\p{_/a/IN_LATIN_1_Sup}');
Error('\P{_/a/IN_LATIN_1_Sup}');
Expect(1, 255, '\p{inlatin1sup}', "");
Expect(0, 255, '\p{^inlatin1sup}', "");
Expect(0, 255, '\P{inlatin1sup}', "");
Expect(1, 255, '\P{^inlatin1sup}', "");
Expect(0, 256, '\p{inlatin1sup}', "");
Expect(1, 256, '\p{^inlatin1sup}', "");
Expect(1, 256, '\P{inlatin1sup}', "");
Expect(0, 256, '\P{^inlatin1sup}', "");
Expect(1, 255, '\p{_In_Latin_1_SUP}', "");
Expect(0, 255, '\p{^_In_Latin_1_SUP}', "");
Expect(0, 255, '\P{_In_Latin_1_SUP}', "");
Expect(1, 255, '\P{^_In_Latin_1_SUP}', "");
Expect(0, 256, '\p{_In_Latin_1_SUP}', "");
Expect(1, 256, '\p{^_In_Latin_1_SUP}', "");
Expect(1, 256, '\P{_In_Latin_1_SUP}', "");
Expect(0, 256, '\P{^_In_Latin_1_SUP}', "");
Error('\p{_ latin_1:=}');
Error('\P{_ latin_1:=}');
Expect(1, 255, '\p{latin1}', "");
Expect(0, 255, '\p{^latin1}', "");
Expect(0, 255, '\P{latin1}', "");
Expect(1, 255, '\P{^latin1}', "");
Expect(0, 256, '\p{latin1}', "");
Expect(1, 256, '\p{^latin1}', "");
Expect(1, 256, '\P{latin1}', "");
Expect(0, 256, '\P{^latin1}', "");
Expect(1, 255, '\p{-	Latin_1}', "");
Expect(0, 255, '\p{^-	Latin_1}', "");
Expect(0, 255, '\P{-	Latin_1}', "");
Expect(1, 255, '\P{^-	Latin_1}', "");
Expect(0, 256, '\p{-	Latin_1}', "");
Expect(1, 256, '\p{^-	Latin_1}', "");
Expect(1, 256, '\P{-	Latin_1}', "");
Expect(0, 256, '\P{^-	Latin_1}', "");
Error('\p{_/a/IS_Latin_1}');
Error('\P{_/a/IS_Latin_1}');
Expect(1, 255, '\p{islatin1}', "");
Expect(0, 255, '\p{^islatin1}', "");
Expect(0, 255, '\P{islatin1}', "");
Expect(1, 255, '\P{^islatin1}', "");
Expect(0, 256, '\p{islatin1}', "");
Expect(1, 256, '\p{^islatin1}', "");
Expect(1, 256, '\P{islatin1}', "");
Expect(0, 256, '\P{^islatin1}', "");
Expect(1, 255, '\p{_is_LATIN_1}', "");
Expect(0, 255, '\p{^_is_LATIN_1}', "");
Expect(0, 255, '\P{_is_LATIN_1}', "");
Expect(1, 255, '\P{^_is_LATIN_1}', "");
Expect(0, 256, '\p{_is_LATIN_1}', "");
Expect(1, 256, '\p{^_is_LATIN_1}', "");
Expect(1, 256, '\P{_is_LATIN_1}', "");
Expect(0, 256, '\P{^_is_LATIN_1}', "");
Error('\p{-	In_Latin_1/a/}');
Error('\P{-	In_Latin_1/a/}');
Expect(1, 255, '\p{inlatin1}', "");
Expect(0, 255, '\p{^inlatin1}', "");
Expect(0, 255, '\P{inlatin1}', "");
Expect(1, 255, '\P{^inlatin1}', "");
Expect(0, 256, '\p{inlatin1}', "");
Expect(1, 256, '\p{^inlatin1}', "");
Expect(1, 256, '\P{inlatin1}', "");
Expect(0, 256, '\P{^inlatin1}', "");
Expect(1, 255, '\p{ -in_LATIN_1}', "");
Expect(0, 255, '\p{^ -in_LATIN_1}', "");
Expect(0, 255, '\P{ -in_LATIN_1}', "");
Expect(1, 255, '\P{^ -in_LATIN_1}', "");
Expect(0, 256, '\p{ -in_LATIN_1}', "");
Expect(1, 256, '\p{^ -in_LATIN_1}', "");
Expect(1, 256, '\P{ -in_LATIN_1}', "");
Expect(0, 256, '\P{^ -in_LATIN_1}', "");
Error('\p{/a/  latin_Extended_A}');
Error('\P{/a/  latin_Extended_A}');
Expect(1, 383, '\p{latinextendeda}', "");
Expect(0, 383, '\p{^latinextendeda}', "");
Expect(0, 383, '\P{latinextendeda}', "");
Expect(1, 383, '\P{^latinextendeda}', "");
Expect(0, 384, '\p{latinextendeda}', "");
Expect(1, 384, '\p{^latinextendeda}', "");
Expect(1, 384, '\P{latinextendeda}', "");
Expect(0, 384, '\P{^latinextendeda}', "");
Expect(1, 383, '\p{	 Latin_Extended_a}', "");
Expect(0, 383, '\p{^	 Latin_Extended_a}', "");
Expect(0, 383, '\P{	 Latin_Extended_a}', "");
Expect(1, 383, '\P{^	 Latin_Extended_a}', "");
Expect(0, 384, '\p{	 Latin_Extended_a}', "");
Expect(1, 384, '\p{^	 Latin_Extended_a}', "");
Expect(1, 384, '\P{	 Latin_Extended_a}', "");
Expect(0, 384, '\P{^	 Latin_Extended_a}', "");
Error('\p{-:=is_Latin_Extended_A}');
Error('\P{-:=is_Latin_Extended_A}');
Expect(1, 383, '\p{islatinextendeda}', "");
Expect(0, 383, '\p{^islatinextendeda}', "");
Expect(0, 383, '\P{islatinextendeda}', "");
Expect(1, 383, '\P{^islatinextendeda}', "");
Expect(0, 384, '\p{islatinextendeda}', "");
Expect(1, 384, '\p{^islatinextendeda}', "");
Expect(1, 384, '\P{islatinextendeda}', "");
Expect(0, 384, '\P{^islatinextendeda}', "");
Expect(1, 383, '\p{	 Is_Latin_Extended_A}', "");
Expect(0, 383, '\p{^	 Is_Latin_Extended_A}', "");
Expect(0, 383, '\P{	 Is_Latin_Extended_A}', "");
Expect(1, 383, '\P{^	 Is_Latin_Extended_A}', "");
Expect(0, 384, '\p{	 Is_Latin_Extended_A}', "");
Expect(1, 384, '\p{^	 Is_Latin_Extended_A}', "");
Expect(1, 384, '\P{	 Is_Latin_Extended_A}', "");
Expect(0, 384, '\P{^	 Is_Latin_Extended_A}', "");
Error('\p{:= 	in_Latin_Extended_a}');
Error('\P{:= 	in_Latin_Extended_a}');
Expect(1, 383, '\p{inlatinextendeda}', "");
Expect(0, 383, '\p{^inlatinextendeda}', "");
Expect(0, 383, '\P{inlatinextendeda}', "");
Expect(1, 383, '\P{^inlatinextendeda}', "");
Expect(0, 384, '\p{inlatinextendeda}', "");
Expect(1, 384, '\p{^inlatinextendeda}', "");
Expect(1, 384, '\P{inlatinextendeda}', "");
Expect(0, 384, '\P{^inlatinextendeda}', "");
Expect(1, 383, '\p{-In_Latin_EXTENDED_a}', "");
Expect(0, 383, '\p{^-In_Latin_EXTENDED_a}', "");
Expect(0, 383, '\P{-In_Latin_EXTENDED_a}', "");
Expect(1, 383, '\P{^-In_Latin_EXTENDED_a}', "");
Expect(0, 384, '\p{-In_Latin_EXTENDED_a}', "");
Expect(1, 384, '\p{^-In_Latin_EXTENDED_a}', "");
Expect(1, 384, '\P{-In_Latin_EXTENDED_a}', "");
Expect(0, 384, '\P{^-In_Latin_EXTENDED_a}', "");
Error('\p{	:=latin_EXT_A}');
Error('\P{	:=latin_EXT_A}');
Expect(1, 383, '\p{latinexta}', "");
Expect(0, 383, '\p{^latinexta}', "");
Expect(0, 383, '\P{latinexta}', "");
Expect(1, 383, '\P{^latinexta}', "");
Expect(0, 384, '\p{latinexta}', "");
Expect(1, 384, '\p{^latinexta}', "");
Expect(1, 384, '\P{latinexta}', "");
Expect(0, 384, '\P{^latinexta}', "");
Expect(1, 383, '\p{	_LATIN_EXT_A}', "");
Expect(0, 383, '\p{^	_LATIN_EXT_A}', "");
Expect(0, 383, '\P{	_LATIN_EXT_A}', "");
Expect(1, 383, '\P{^	_LATIN_EXT_A}', "");
Expect(0, 384, '\p{	_LATIN_EXT_A}', "");
Expect(1, 384, '\p{^	_LATIN_EXT_A}', "");
Expect(1, 384, '\P{	_LATIN_EXT_A}', "");
Expect(0, 384, '\P{^	_LATIN_EXT_A}', "");
Error('\p{:=-	Is_Latin_Ext_A}');
Error('\P{:=-	Is_Latin_Ext_A}');
Expect(1, 383, '\p{islatinexta}', "");
Expect(0, 383, '\p{^islatinexta}', "");
Expect(0, 383, '\P{islatinexta}', "");
Expect(1, 383, '\P{^islatinexta}', "");
Expect(0, 384, '\p{islatinexta}', "");
Expect(1, 384, '\p{^islatinexta}', "");
Expect(1, 384, '\P{islatinexta}', "");
Expect(0, 384, '\P{^islatinexta}', "");
Expect(1, 383, '\p{ 	Is_latin_EXT_A}', "");
Expect(0, 383, '\p{^ 	Is_latin_EXT_A}', "");
Expect(0, 383, '\P{ 	Is_latin_EXT_A}', "");
Expect(1, 383, '\P{^ 	Is_latin_EXT_A}', "");
Expect(0, 384, '\p{ 	Is_latin_EXT_A}', "");
Expect(1, 384, '\p{^ 	Is_latin_EXT_A}', "");
Expect(1, 384, '\P{ 	Is_latin_EXT_A}', "");
Expect(0, 384, '\P{^ 	Is_latin_EXT_A}', "");
Error('\p{	_IN_Latin_ext_A/a/}');
Error('\P{	_IN_Latin_ext_A/a/}');
Expect(1, 383, '\p{inlatinexta}', "");
Expect(0, 383, '\p{^inlatinexta}', "");
Expect(0, 383, '\P{inlatinexta}', "");
Expect(1, 383, '\P{^inlatinexta}', "");
Expect(0, 384, '\p{inlatinexta}', "");
Expect(1, 384, '\p{^inlatinexta}', "");
Expect(1, 384, '\P{inlatinexta}', "");
Expect(0, 384, '\P{^inlatinexta}', "");
Expect(1, 383, '\p{-	In_LATIN_EXT_a}', "");
Expect(0, 383, '\p{^-	In_LATIN_EXT_a}', "");
Expect(0, 383, '\P{-	In_LATIN_EXT_a}', "");
Expect(1, 383, '\P{^-	In_LATIN_EXT_a}', "");
Expect(0, 384, '\p{-	In_LATIN_EXT_a}', "");
Expect(1, 384, '\p{^-	In_LATIN_EXT_a}', "");
Expect(1, 384, '\P{-	In_LATIN_EXT_a}', "");
Expect(0, 384, '\P{^-	In_LATIN_EXT_a}', "");
Error('\p{_:=LATIN_Extended_Additional}');
Error('\P{_:=LATIN_Extended_Additional}');
Expect(1, 7935, '\p{latinextendedadditional}', "");
Expect(0, 7935, '\p{^latinextendedadditional}', "");
Expect(0, 7935, '\P{latinextendedadditional}', "");
Expect(1, 7935, '\P{^latinextendedadditional}', "");
Expect(0, 7936, '\p{latinextendedadditional}', "");
Expect(1, 7936, '\p{^latinextendedadditional}', "");
Expect(1, 7936, '\P{latinextendedadditional}', "");
Expect(0, 7936, '\P{^latinextendedadditional}', "");
Expect(1, 7935, '\p{-_Latin_Extended_ADDITIONAL}', "");
Expect(0, 7935, '\p{^-_Latin_Extended_ADDITIONAL}', "");
Expect(0, 7935, '\P{-_Latin_Extended_ADDITIONAL}', "");
Expect(1, 7935, '\P{^-_Latin_Extended_ADDITIONAL}', "");
Expect(0, 7936, '\p{-_Latin_Extended_ADDITIONAL}', "");
Expect(1, 7936, '\p{^-_Latin_Extended_ADDITIONAL}', "");
Expect(1, 7936, '\P{-_Latin_Extended_ADDITIONAL}', "");
Expect(0, 7936, '\P{^-_Latin_Extended_ADDITIONAL}', "");
Error('\p{/a/_Is_Latin_Extended_additional}');
Error('\P{/a/_Is_Latin_Extended_additional}');
Expect(1, 7935, '\p{islatinextendedadditional}', "");
Expect(0, 7935, '\p{^islatinextendedadditional}', "");
Expect(0, 7935, '\P{islatinextendedadditional}', "");
Expect(1, 7935, '\P{^islatinextendedadditional}', "");
Expect(0, 7936, '\p{islatinextendedadditional}', "");
Expect(1, 7936, '\p{^islatinextendedadditional}', "");
Expect(1, 7936, '\P{islatinextendedadditional}', "");
Expect(0, 7936, '\P{^islatinextendedadditional}', "");
Expect(1, 7935, '\p{--Is_Latin_EXTENDED_Additional}', "");
Expect(0, 7935, '\p{^--Is_Latin_EXTENDED_Additional}', "");
Expect(0, 7935, '\P{--Is_Latin_EXTENDED_Additional}', "");
Expect(1, 7935, '\P{^--Is_Latin_EXTENDED_Additional}', "");
Expect(0, 7936, '\p{--Is_Latin_EXTENDED_Additional}', "");
Expect(1, 7936, '\p{^--Is_Latin_EXTENDED_Additional}', "");
Expect(1, 7936, '\P{--Is_Latin_EXTENDED_Additional}', "");
Expect(0, 7936, '\P{^--Is_Latin_EXTENDED_Additional}', "");
Error('\p{-/a/IN_Latin_Extended_Additional}');
Error('\P{-/a/IN_Latin_Extended_Additional}');
Expect(1, 7935, '\p{inlatinextendedadditional}', "");
Expect(0, 7935, '\p{^inlatinextendedadditional}', "");
Expect(0, 7935, '\P{inlatinextendedadditional}', "");
Expect(1, 7935, '\P{^inlatinextendedadditional}', "");
Expect(0, 7936, '\p{inlatinextendedadditional}', "");
Expect(1, 7936, '\p{^inlatinextendedadditional}', "");
Expect(1, 7936, '\P{inlatinextendedadditional}', "");
Expect(0, 7936, '\P{^inlatinextendedadditional}', "");
Expect(1, 7935, '\p{ IN_Latin_EXTENDED_Additional}', "");
Expect(0, 7935, '\p{^ IN_Latin_EXTENDED_Additional}', "");
Expect(0, 7935, '\P{ IN_Latin_EXTENDED_Additional}', "");
Expect(1, 7935, '\P{^ IN_Latin_EXTENDED_Additional}', "");
Expect(0, 7936, '\p{ IN_Latin_EXTENDED_Additional}', "");
Expect(1, 7936, '\p{^ IN_Latin_EXTENDED_Additional}', "");
Expect(1, 7936, '\P{ IN_Latin_EXTENDED_Additional}', "");
Expect(0, 7936, '\P{^ IN_Latin_EXTENDED_Additional}', "");
Error('\p{:= Latin_EXT_Additional}');
Error('\P{:= Latin_EXT_Additional}');
Expect(1, 7935, '\p{latinextadditional}', "");
Expect(0, 7935, '\p{^latinextadditional}', "");
Expect(0, 7935, '\P{latinextadditional}', "");
Expect(1, 7935, '\P{^latinextadditional}', "");
Expect(0, 7936, '\p{latinextadditional}', "");
Expect(1, 7936, '\p{^latinextadditional}', "");
Expect(1, 7936, '\P{latinextadditional}', "");
Expect(0, 7936, '\P{^latinextadditional}', "");
Expect(1, 7935, '\p{-Latin_Ext_Additional}', "");
Expect(0, 7935, '\p{^-Latin_Ext_Additional}', "");
Expect(0, 7935, '\P{-Latin_Ext_Additional}', "");
Expect(1, 7935, '\P{^-Latin_Ext_Additional}', "");
Expect(0, 7936, '\p{-Latin_Ext_Additional}', "");
Expect(1, 7936, '\p{^-Latin_Ext_Additional}', "");
Expect(1, 7936, '\P{-Latin_Ext_Additional}', "");
Expect(0, 7936, '\P{^-Latin_Ext_Additional}', "");
Error('\p{/a/IS_LATIN_Ext_Additional}');
Error('\P{/a/IS_LATIN_Ext_Additional}');
Expect(1, 7935, '\p{islatinextadditional}', "");
Expect(0, 7935, '\p{^islatinextadditional}', "");
Expect(0, 7935, '\P{islatinextadditional}', "");
Expect(1, 7935, '\P{^islatinextadditional}', "");
Expect(0, 7936, '\p{islatinextadditional}', "");
Expect(1, 7936, '\p{^islatinextadditional}', "");
Expect(1, 7936, '\P{islatinextadditional}', "");
Expect(0, 7936, '\P{^islatinextadditional}', "");
Expect(1, 7935, '\p{	is_Latin_EXT_additional}', "");
Expect(0, 7935, '\p{^	is_Latin_EXT_additional}', "");
Expect(0, 7935, '\P{	is_Latin_EXT_additional}', "");
Expect(1, 7935, '\P{^	is_Latin_EXT_additional}', "");
Expect(0, 7936, '\p{	is_Latin_EXT_additional}', "");
Expect(1, 7936, '\p{^	is_Latin_EXT_additional}', "");
Expect(1, 7936, '\P{	is_Latin_EXT_additional}', "");
Expect(0, 7936, '\P{^	is_Latin_EXT_additional}', "");
Error('\p{/a/	_In_LATIN_EXT_Additional}');
Error('\P{/a/	_In_LATIN_EXT_Additional}');
Expect(1, 7935, '\p{inlatinextadditional}', "");
Expect(0, 7935, '\p{^inlatinextadditional}', "");
Expect(0, 7935, '\P{inlatinextadditional}', "");
Expect(1, 7935, '\P{^inlatinextadditional}', "");
Expect(0, 7936, '\p{inlatinextadditional}', "");
Expect(1, 7936, '\p{^inlatinextadditional}', "");
Expect(1, 7936, '\P{inlatinextadditional}', "");
Expect(0, 7936, '\P{^inlatinextadditional}', "");
Expect(1, 7935, '\p{		In_latin_Ext_additional}', "");
Expect(0, 7935, '\p{^		In_latin_Ext_additional}', "");
Expect(0, 7935, '\P{		In_latin_Ext_additional}', "");
Expect(1, 7935, '\P{^		In_latin_Ext_additional}', "");
Expect(0, 7936, '\p{		In_latin_Ext_additional}', "");
Expect(1, 7936, '\p{^		In_latin_Ext_additional}', "");
Expect(1, 7936, '\P{		In_latin_Ext_additional}', "");
Expect(0, 7936, '\P{^		In_latin_Ext_additional}', "");
Error('\p{:=latin_Extended_B}');
Error('\P{:=latin_Extended_B}');
Expect(1, 591, '\p{latinextendedb}', "");
Expect(0, 591, '\p{^latinextendedb}', "");
Expect(0, 591, '\P{latinextendedb}', "");
Expect(1, 591, '\P{^latinextendedb}', "");
Expect(0, 592, '\p{latinextendedb}', "");
Expect(1, 592, '\p{^latinextendedb}', "");
Expect(1, 592, '\P{latinextendedb}', "");
Expect(0, 592, '\P{^latinextendedb}', "");
Expect(1, 591, '\p{	LATIN_EXTENDED_b}', "");
Expect(0, 591, '\p{^	LATIN_EXTENDED_b}', "");
Expect(0, 591, '\P{	LATIN_EXTENDED_b}', "");
Expect(1, 591, '\P{^	LATIN_EXTENDED_b}', "");
Expect(0, 592, '\p{	LATIN_EXTENDED_b}', "");
Expect(1, 592, '\p{^	LATIN_EXTENDED_b}', "");
Expect(1, 592, '\P{	LATIN_EXTENDED_b}', "");
Expect(0, 592, '\P{^	LATIN_EXTENDED_b}', "");
Error('\p{_	is_Latin_Extended_B/a/}');
Error('\P{_	is_Latin_Extended_B/a/}');
Expect(1, 591, '\p{islatinextendedb}', "");
Expect(0, 591, '\p{^islatinextendedb}', "");
Expect(0, 591, '\P{islatinextendedb}', "");
Expect(1, 591, '\P{^islatinextendedb}', "");
Expect(0, 592, '\p{islatinextendedb}', "");
Expect(1, 592, '\p{^islatinextendedb}', "");
Expect(1, 592, '\P{islatinextendedb}', "");
Expect(0, 592, '\P{^islatinextendedb}', "");
Expect(1, 591, '\p{ -Is_LATIN_Extended_B}', "");
Expect(0, 591, '\p{^ -Is_LATIN_Extended_B}', "");
Expect(0, 591, '\P{ -Is_LATIN_Extended_B}', "");
Expect(1, 591, '\P{^ -Is_LATIN_Extended_B}', "");
Expect(0, 592, '\p{ -Is_LATIN_Extended_B}', "");
Expect(1, 592, '\p{^ -Is_LATIN_Extended_B}', "");
Expect(1, 592, '\P{ -Is_LATIN_Extended_B}', "");
Expect(0, 592, '\P{^ -Is_LATIN_Extended_B}', "");
Error('\p{ :=In_LATIN_Extended_b}');
Error('\P{ :=In_LATIN_Extended_b}');
Expect(1, 591, '\p{inlatinextendedb}', "");
Expect(0, 591, '\p{^inlatinextendedb}', "");
Expect(0, 591, '\P{inlatinextendedb}', "");
Expect(1, 591, '\P{^inlatinextendedb}', "");
Expect(0, 592, '\p{inlatinextendedb}', "");
Expect(1, 592, '\p{^inlatinextendedb}', "");
Expect(1, 592, '\P{inlatinextendedb}', "");
Expect(0, 592, '\P{^inlatinextendedb}', "");
Expect(1, 591, '\p{	_IN_Latin_Extended_B}', "");
Expect(0, 591, '\p{^	_IN_Latin_Extended_B}', "");
Expect(0, 591, '\P{	_IN_Latin_Extended_B}', "");
Expect(1, 591, '\P{^	_IN_Latin_Extended_B}', "");
Expect(0, 592, '\p{	_IN_Latin_Extended_B}', "");
Expect(1, 592, '\p{^	_IN_Latin_Extended_B}', "");
Expect(1, 592, '\P{	_IN_Latin_Extended_B}', "");
Expect(0, 592, '\P{^	_IN_Latin_Extended_B}', "");
Error('\p{/a/ _Latin_ext_B}');
Error('\P{/a/ _Latin_ext_B}');
Expect(1, 591, '\p{latinextb}', "");
Expect(0, 591, '\p{^latinextb}', "");
Expect(0, 591, '\P{latinextb}', "");
Expect(1, 591, '\P{^latinextb}', "");
Expect(0, 592, '\p{latinextb}', "");
Expect(1, 592, '\p{^latinextb}', "");
Expect(1, 592, '\P{latinextb}', "");
Expect(0, 592, '\P{^latinextb}', "");
Expect(1, 591, '\p{_	latin_ext_B}', "");
Expect(0, 591, '\p{^_	latin_ext_B}', "");
Expect(0, 591, '\P{_	latin_ext_B}', "");
Expect(1, 591, '\P{^_	latin_ext_B}', "");
Expect(0, 592, '\p{_	latin_ext_B}', "");
Expect(1, 592, '\p{^_	latin_ext_B}', "");
Expect(1, 592, '\P{_	latin_ext_B}', "");
Expect(0, 592, '\P{^_	latin_ext_B}', "");
Error('\p{:=_-IS_LATIN_Ext_b}');
Error('\P{:=_-IS_LATIN_Ext_b}');
Expect(1, 591, '\p{islatinextb}', "");
Expect(0, 591, '\p{^islatinextb}', "");
Expect(0, 591, '\P{islatinextb}', "");
Expect(1, 591, '\P{^islatinextb}', "");
Expect(0, 592, '\p{islatinextb}', "");
Expect(1, 592, '\p{^islatinextb}', "");
Expect(1, 592, '\P{islatinextb}', "");
Expect(0, 592, '\P{^islatinextb}', "");
Expect(1, 591, '\p{  is_Latin_Ext_B}', "");
Expect(0, 591, '\p{^  is_Latin_Ext_B}', "");
Expect(0, 591, '\P{  is_Latin_Ext_B}', "");
Expect(1, 591, '\P{^  is_Latin_Ext_B}', "");
Expect(0, 592, '\p{  is_Latin_Ext_B}', "");
Expect(1, 592, '\p{^  is_Latin_Ext_B}', "");
Expect(1, 592, '\P{  is_Latin_Ext_B}', "");
Expect(0, 592, '\P{^  is_Latin_Ext_B}', "");
Error('\p{_in_LATIN_ext_B:=}');
Error('\P{_in_LATIN_ext_B:=}');
Expect(1, 591, '\p{inlatinextb}', "");
Expect(0, 591, '\p{^inlatinextb}', "");
Expect(0, 591, '\P{inlatinextb}', "");
Expect(1, 591, '\P{^inlatinextb}', "");
Expect(0, 592, '\p{inlatinextb}', "");
Expect(1, 592, '\p{^inlatinextb}', "");
Expect(1, 592, '\P{inlatinextb}', "");
Expect(0, 592, '\P{^inlatinextb}', "");
Expect(1, 591, '\p{__In_Latin_Ext_b}', "");
Expect(0, 591, '\p{^__In_Latin_Ext_b}', "");
Expect(0, 591, '\P{__In_Latin_Ext_b}', "");
Expect(1, 591, '\P{^__In_Latin_Ext_b}', "");
Expect(0, 592, '\p{__In_Latin_Ext_b}', "");
Expect(1, 592, '\p{^__In_Latin_Ext_b}', "");
Expect(1, 592, '\P{__In_Latin_Ext_b}', "");
Expect(0, 592, '\P{^__In_Latin_Ext_b}', "");
Error('\p{/a/	LATIN_Extended_C}');
Error('\P{/a/	LATIN_Extended_C}');
Expect(1, 11391, '\p{latinextendedc}', "");
Expect(0, 11391, '\p{^latinextendedc}', "");
Expect(0, 11391, '\P{latinextendedc}', "");
Expect(1, 11391, '\P{^latinextendedc}', "");
Expect(0, 11392, '\p{latinextendedc}', "");
Expect(1, 11392, '\p{^latinextendedc}', "");
Expect(1, 11392, '\P{latinextendedc}', "");
Expect(0, 11392, '\P{^latinextendedc}', "");
Expect(1, 11391, '\p{ Latin_EXTENDED_C}', "");
Expect(0, 11391, '\p{^ Latin_EXTENDED_C}', "");
Expect(0, 11391, '\P{ Latin_EXTENDED_C}', "");
Expect(1, 11391, '\P{^ Latin_EXTENDED_C}', "");
Expect(0, 11392, '\p{ Latin_EXTENDED_C}', "");
Expect(1, 11392, '\p{^ Latin_EXTENDED_C}', "");
Expect(1, 11392, '\P{ Latin_EXTENDED_C}', "");
Expect(0, 11392, '\P{^ Latin_EXTENDED_C}', "");
Error('\p{/a/_-IS_Latin_Extended_c}');
Error('\P{/a/_-IS_Latin_Extended_c}');
Expect(1, 11391, '\p{islatinextendedc}', "");
Expect(0, 11391, '\p{^islatinextendedc}', "");
Expect(0, 11391, '\P{islatinextendedc}', "");
Expect(1, 11391, '\P{^islatinextendedc}', "");
Expect(0, 11392, '\p{islatinextendedc}', "");
Expect(1, 11392, '\p{^islatinextendedc}', "");
Expect(1, 11392, '\P{islatinextendedc}', "");
Expect(0, 11392, '\P{^islatinextendedc}', "");
Expect(1, 11391, '\p{  Is_Latin_Extended_C}', "");
Expect(0, 11391, '\p{^  Is_Latin_Extended_C}', "");
Expect(0, 11391, '\P{  Is_Latin_Extended_C}', "");
Expect(1, 11391, '\P{^  Is_Latin_Extended_C}', "");
Expect(0, 11392, '\p{  Is_Latin_Extended_C}', "");
Expect(1, 11392, '\p{^  Is_Latin_Extended_C}', "");
Expect(1, 11392, '\P{  Is_Latin_Extended_C}', "");
Expect(0, 11392, '\P{^  Is_Latin_Extended_C}', "");
Error('\p{:= -In_LATIN_Extended_C}');
Error('\P{:= -In_LATIN_Extended_C}');
Expect(1, 11391, '\p{inlatinextendedc}', "");
Expect(0, 11391, '\p{^inlatinextendedc}', "");
Expect(0, 11391, '\P{inlatinextendedc}', "");
Expect(1, 11391, '\P{^inlatinextendedc}', "");
Expect(0, 11392, '\p{inlatinextendedc}', "");
Expect(1, 11392, '\p{^inlatinextendedc}', "");
Expect(1, 11392, '\P{inlatinextendedc}', "");
Expect(0, 11392, '\P{^inlatinextendedc}', "");
Expect(1, 11391, '\p{ 	In_LATIN_EXTENDED_C}', "");
Expect(0, 11391, '\p{^ 	In_LATIN_EXTENDED_C}', "");
Expect(0, 11391, '\P{ 	In_LATIN_EXTENDED_C}', "");
Expect(1, 11391, '\P{^ 	In_LATIN_EXTENDED_C}', "");
Expect(0, 11392, '\p{ 	In_LATIN_EXTENDED_C}', "");
Expect(1, 11392, '\p{^ 	In_LATIN_EXTENDED_C}', "");
Expect(1, 11392, '\P{ 	In_LATIN_EXTENDED_C}', "");
Expect(0, 11392, '\P{^ 	In_LATIN_EXTENDED_C}', "");
Error('\p{/a/_	Latin_EXT_c}');
Error('\P{/a/_	Latin_EXT_c}');
Expect(1, 11391, '\p{latinextc}', "");
Expect(0, 11391, '\p{^latinextc}', "");
Expect(0, 11391, '\P{latinextc}', "");
Expect(1, 11391, '\P{^latinextc}', "");
Expect(0, 11392, '\p{latinextc}', "");
Expect(1, 11392, '\p{^latinextc}', "");
Expect(1, 11392, '\P{latinextc}', "");
Expect(0, 11392, '\P{^latinextc}', "");
Expect(1, 11391, '\p{-latin_Ext_C}', "");
Expect(0, 11391, '\p{^-latin_Ext_C}', "");
Expect(0, 11391, '\P{-latin_Ext_C}', "");
Expect(1, 11391, '\P{^-latin_Ext_C}', "");
Expect(0, 11392, '\p{-latin_Ext_C}', "");
Expect(1, 11392, '\p{^-latin_Ext_C}', "");
Expect(1, 11392, '\P{-latin_Ext_C}', "");
Expect(0, 11392, '\P{^-latin_Ext_C}', "");
Error('\p{__IS_Latin_Ext_C/a/}');
Error('\P{__IS_Latin_Ext_C/a/}');
Expect(1, 11391, '\p{islatinextc}', "");
Expect(0, 11391, '\p{^islatinextc}', "");
Expect(0, 11391, '\P{islatinextc}', "");
Expect(1, 11391, '\P{^islatinextc}', "");
Expect(0, 11392, '\p{islatinextc}', "");
Expect(1, 11392, '\p{^islatinextc}', "");
Expect(1, 11392, '\P{islatinextc}', "");
Expect(0, 11392, '\P{^islatinextc}', "");
Expect(1, 11391, '\p{-IS_Latin_EXT_C}', "");
Expect(0, 11391, '\p{^-IS_Latin_EXT_C}', "");
Expect(0, 11391, '\P{-IS_Latin_EXT_C}', "");
Expect(1, 11391, '\P{^-IS_Latin_EXT_C}', "");
Expect(0, 11392, '\p{-IS_Latin_EXT_C}', "");
Expect(1, 11392, '\p{^-IS_Latin_EXT_C}', "");
Expect(1, 11392, '\P{-IS_Latin_EXT_C}', "");
Expect(0, 11392, '\P{^-IS_Latin_EXT_C}', "");
Error('\p{:=In_Latin_ext_c}');
Error('\P{:=In_Latin_ext_c}');
Expect(1, 11391, '\p{inlatinextc}', "");
Expect(0, 11391, '\p{^inlatinextc}', "");
Expect(0, 11391, '\P{inlatinextc}', "");
Expect(1, 11391, '\P{^inlatinextc}', "");
Expect(0, 11392, '\p{inlatinextc}', "");
Expect(1, 11392, '\p{^inlatinextc}', "");
Expect(1, 11392, '\P{inlatinextc}', "");
Expect(0, 11392, '\P{^inlatinextc}', "");
Expect(1, 11391, '\p{__in_Latin_EXT_c}', "");
Expect(0, 11391, '\p{^__in_Latin_EXT_c}', "");
Expect(0, 11391, '\P{__in_Latin_EXT_c}', "");
Expect(1, 11391, '\P{^__in_Latin_EXT_c}', "");
Expect(0, 11392, '\p{__in_Latin_EXT_c}', "");
Expect(1, 11392, '\p{^__in_Latin_EXT_c}', "");
Expect(1, 11392, '\P{__in_Latin_EXT_c}', "");
Expect(0, 11392, '\P{^__in_Latin_EXT_c}', "");
Error('\p{:=_ LATIN_extended_d}');
Error('\P{:=_ LATIN_extended_d}');
Expect(1, 43007, '\p{latinextendedd}', "");
Expect(0, 43007, '\p{^latinextendedd}', "");
Expect(0, 43007, '\P{latinextendedd}', "");
Expect(1, 43007, '\P{^latinextendedd}', "");
Expect(0, 43008, '\p{latinextendedd}', "");
Expect(1, 43008, '\p{^latinextendedd}', "");
Expect(1, 43008, '\P{latinextendedd}', "");
Expect(0, 43008, '\P{^latinextendedd}', "");
Expect(1, 43007, '\p{ -Latin_extended_D}', "");
Expect(0, 43007, '\p{^ -Latin_extended_D}', "");
Expect(0, 43007, '\P{ -Latin_extended_D}', "");
Expect(1, 43007, '\P{^ -Latin_extended_D}', "");
Expect(0, 43008, '\p{ -Latin_extended_D}', "");
Expect(1, 43008, '\p{^ -Latin_extended_D}', "");
Expect(1, 43008, '\P{ -Latin_extended_D}', "");
Expect(0, 43008, '\P{^ -Latin_extended_D}', "");
Error('\p{:=is_LATIN_extended_D}');
Error('\P{:=is_LATIN_extended_D}');
Expect(1, 43007, '\p{islatinextendedd}', "");
Expect(0, 43007, '\p{^islatinextendedd}', "");
Expect(0, 43007, '\P{islatinextendedd}', "");
Expect(1, 43007, '\P{^islatinextendedd}', "");
Expect(0, 43008, '\p{islatinextendedd}', "");
Expect(1, 43008, '\p{^islatinextendedd}', "");
Expect(1, 43008, '\P{islatinextendedd}', "");
Expect(0, 43008, '\P{^islatinextendedd}', "");
Expect(1, 43007, '\p{__Is_Latin_EXTENDED_D}', "");
Expect(0, 43007, '\p{^__Is_Latin_EXTENDED_D}', "");
Expect(0, 43007, '\P{__Is_Latin_EXTENDED_D}', "");
Expect(1, 43007, '\P{^__Is_Latin_EXTENDED_D}', "");
Expect(0, 43008, '\p{__Is_Latin_EXTENDED_D}', "");
Expect(1, 43008, '\p{^__Is_Latin_EXTENDED_D}', "");
Expect(1, 43008, '\P{__Is_Latin_EXTENDED_D}', "");
Expect(0, 43008, '\P{^__Is_Latin_EXTENDED_D}', "");
Error('\p{	:=in_LATIN_extended_D}');
Error('\P{	:=in_LATIN_extended_D}');
Expect(1, 43007, '\p{inlatinextendedd}', "");
Expect(0, 43007, '\p{^inlatinextendedd}', "");
Expect(0, 43007, '\P{inlatinextendedd}', "");
Expect(1, 43007, '\P{^inlatinextendedd}', "");
Expect(0, 43008, '\p{inlatinextendedd}', "");
Expect(1, 43008, '\p{^inlatinextendedd}', "");
Expect(1, 43008, '\P{inlatinextendedd}', "");
Expect(0, 43008, '\P{^inlatinextendedd}', "");
Expect(1, 43007, '\p{ -In_LATIN_extended_D}', "");
Expect(0, 43007, '\p{^ -In_LATIN_extended_D}', "");
Expect(0, 43007, '\P{ -In_LATIN_extended_D}', "");
Expect(1, 43007, '\P{^ -In_LATIN_extended_D}', "");
Expect(0, 43008, '\p{ -In_LATIN_extended_D}', "");
Expect(1, 43008, '\p{^ -In_LATIN_extended_D}', "");
Expect(1, 43008, '\P{ -In_LATIN_extended_D}', "");
Expect(0, 43008, '\P{^ -In_LATIN_extended_D}', "");
Error('\p{/a/ Latin_ext_D}');
Error('\P{/a/ Latin_ext_D}');
Expect(1, 43007, '\p{latinextd}', "");
Expect(0, 43007, '\p{^latinextd}', "");
Expect(0, 43007, '\P{latinextd}', "");
Expect(1, 43007, '\P{^latinextd}', "");
Expect(0, 43008, '\p{latinextd}', "");
Expect(1, 43008, '\p{^latinextd}', "");
Expect(1, 43008, '\P{latinextd}', "");
Expect(0, 43008, '\P{^latinextd}', "");
Expect(1, 43007, '\p{ _Latin_Ext_d}', "");
Expect(0, 43007, '\p{^ _Latin_Ext_d}', "");
Expect(0, 43007, '\P{ _Latin_Ext_d}', "");
Expect(1, 43007, '\P{^ _Latin_Ext_d}', "");
Expect(0, 43008, '\p{ _Latin_Ext_d}', "");
Expect(1, 43008, '\p{^ _Latin_Ext_d}', "");
Expect(1, 43008, '\P{ _Latin_Ext_d}', "");
Expect(0, 43008, '\P{^ _Latin_Ext_d}', "");
Error('\p{-_is_Latin_EXT_D/a/}');
Error('\P{-_is_Latin_EXT_D/a/}');
Expect(1, 43007, '\p{islatinextd}', "");
Expect(0, 43007, '\p{^islatinextd}', "");
Expect(0, 43007, '\P{islatinextd}', "");
Expect(1, 43007, '\P{^islatinextd}', "");
Expect(0, 43008, '\p{islatinextd}', "");
Expect(1, 43008, '\p{^islatinextd}', "");
Expect(1, 43008, '\P{islatinextd}', "");
Expect(0, 43008, '\P{^islatinextd}', "");
Expect(1, 43007, '\p{ 	IS_LATIN_Ext_D}', "");
Expect(0, 43007, '\p{^ 	IS_LATIN_Ext_D}', "");
Expect(0, 43007, '\P{ 	IS_LATIN_Ext_D}', "");
Expect(1, 43007, '\P{^ 	IS_LATIN_Ext_D}', "");
Expect(0, 43008, '\p{ 	IS_LATIN_Ext_D}', "");
Expect(1, 43008, '\p{^ 	IS_LATIN_Ext_D}', "");
Expect(1, 43008, '\P{ 	IS_LATIN_Ext_D}', "");
Expect(0, 43008, '\P{^ 	IS_LATIN_Ext_D}', "");
Error('\p{_	IN_LATIN_Ext_D:=}');
Error('\P{_	IN_LATIN_Ext_D:=}');
Expect(1, 43007, '\p{inlatinextd}', "");
Expect(0, 43007, '\p{^inlatinextd}', "");
Expect(0, 43007, '\P{inlatinextd}', "");
Expect(1, 43007, '\P{^inlatinextd}', "");
Expect(0, 43008, '\p{inlatinextd}', "");
Expect(1, 43008, '\p{^inlatinextd}', "");
Expect(1, 43008, '\P{inlatinextd}', "");
Expect(0, 43008, '\P{^inlatinextd}', "");
Expect(1, 43007, '\p{IN_Latin_EXT_D}', "");
Expect(0, 43007, '\p{^IN_Latin_EXT_D}', "");
Expect(0, 43007, '\P{IN_Latin_EXT_D}', "");
Expect(1, 43007, '\P{^IN_Latin_EXT_D}', "");
Expect(0, 43008, '\p{IN_Latin_EXT_D}', "");
Expect(1, 43008, '\p{^IN_Latin_EXT_D}', "");
Expect(1, 43008, '\P{IN_Latin_EXT_D}', "");
Expect(0, 43008, '\P{^IN_Latin_EXT_D}', "");
Error('\p{__Lepcha/a/}');
Error('\P{__Lepcha/a/}');
Expect(1, 7247, '\p{lepcha}', "");
Expect(0, 7247, '\p{^lepcha}', "");
Expect(0, 7247, '\P{lepcha}', "");
Expect(1, 7247, '\P{^lepcha}', "");
Expect(0, 7248, '\p{lepcha}', "");
Expect(1, 7248, '\p{^lepcha}', "");
Expect(1, 7248, '\P{lepcha}', "");
Expect(0, 7248, '\P{^lepcha}', "");
Expect(1, 7247, '\p{ 	Lepcha}', "");
Expect(0, 7247, '\p{^ 	Lepcha}', "");
Expect(0, 7247, '\P{ 	Lepcha}', "");
Expect(1, 7247, '\P{^ 	Lepcha}', "");
Expect(0, 7248, '\p{ 	Lepcha}', "");
Expect(1, 7248, '\p{^ 	Lepcha}', "");
Expect(1, 7248, '\P{ 	Lepcha}', "");
Expect(0, 7248, '\P{^ 	Lepcha}', "");
Error('\p{	:=Is_lepcha}');
Error('\P{	:=Is_lepcha}');
Expect(1, 7247, '\p{islepcha}', "");
Expect(0, 7247, '\p{^islepcha}', "");
Expect(0, 7247, '\P{islepcha}', "");
Expect(1, 7247, '\P{^islepcha}', "");
Expect(0, 7248, '\p{islepcha}', "");
Expect(1, 7248, '\p{^islepcha}', "");
Expect(1, 7248, '\P{islepcha}', "");
Expect(0, 7248, '\P{^islepcha}', "");
Expect(1, 7247, '\p{ Is_Lepcha}', "");
Expect(0, 7247, '\p{^ Is_Lepcha}', "");
Expect(0, 7247, '\P{ Is_Lepcha}', "");
Expect(1, 7247, '\P{^ Is_Lepcha}', "");
Expect(0, 7248, '\p{ Is_Lepcha}', "");
Expect(1, 7248, '\p{^ Is_Lepcha}', "");
Expect(1, 7248, '\P{ Is_Lepcha}', "");
Expect(0, 7248, '\P{^ Is_Lepcha}', "");
Error('\p{ /a/Lepc}');
Error('\P{ /a/Lepc}');
Expect(1, 7247, '\p{lepc}', "");
Expect(0, 7247, '\p{^lepc}', "");
Expect(0, 7247, '\P{lepc}', "");
Expect(1, 7247, '\P{^lepc}', "");
Expect(0, 7248, '\p{lepc}', "");
Expect(1, 7248, '\p{^lepc}', "");
Expect(1, 7248, '\P{lepc}', "");
Expect(0, 7248, '\P{^lepc}', "");
Expect(1, 7247, '\p{_ Lepc}', "");
Expect(0, 7247, '\p{^_ Lepc}', "");
Expect(0, 7247, '\P{_ Lepc}', "");
Expect(1, 7247, '\P{^_ Lepc}', "");
Expect(0, 7248, '\p{_ Lepc}', "");
Expect(1, 7248, '\p{^_ Lepc}', "");
Expect(1, 7248, '\P{_ Lepc}', "");
Expect(0, 7248, '\P{^_ Lepc}', "");
Error('\p{:=--Is_LEPC}');
Error('\P{:=--Is_LEPC}');
Expect(1, 7247, '\p{islepc}', "");
Expect(0, 7247, '\p{^islepc}', "");
Expect(0, 7247, '\P{islepc}', "");
Expect(1, 7247, '\P{^islepc}', "");
Expect(0, 7248, '\p{islepc}', "");
Expect(1, 7248, '\p{^islepc}', "");
Expect(1, 7248, '\P{islepc}', "");
Expect(0, 7248, '\P{^islepc}', "");
Expect(1, 7247, '\p{_	Is_lepc}', "");
Expect(0, 7247, '\p{^_	Is_lepc}', "");
Expect(0, 7247, '\P{_	Is_lepc}', "");
Expect(1, 7247, '\P{^_	Is_lepc}', "");
Expect(0, 7248, '\p{_	Is_lepc}', "");
Expect(1, 7248, '\p{^_	Is_lepc}', "");
Expect(1, 7248, '\P{_	Is_lepc}', "");
Expect(0, 7248, '\P{^_	Is_lepc}', "");
Error('\p{ LETTER:=}');
Error('\P{ LETTER:=}');
Expect(1, 195101, '\p{letter}', "");
Expect(0, 195101, '\p{^letter}', "");
Expect(0, 195101, '\P{letter}', "");
Expect(1, 195101, '\P{^letter}', "");
Expect(0, 195102, '\p{letter}', "");
Expect(1, 195102, '\p{^letter}', "");
Expect(1, 195102, '\P{letter}', "");
Expect(0, 195102, '\P{^letter}', "");
Expect(1, 195101, '\p{__LETTER}', "");
Expect(0, 195101, '\p{^__LETTER}', "");
Expect(0, 195101, '\P{__LETTER}', "");
Expect(1, 195101, '\P{^__LETTER}', "");
Expect(0, 195102, '\p{__LETTER}', "");
Expect(1, 195102, '\p{^__LETTER}', "");
Expect(1, 195102, '\P{__LETTER}', "");
Expect(0, 195102, '\P{^__LETTER}', "");
Error('\p{	:=IS_Letter}');
Error('\P{	:=IS_Letter}');
Expect(1, 195101, '\p{isletter}', "");
Expect(0, 195101, '\p{^isletter}', "");
Expect(0, 195101, '\P{isletter}', "");
Expect(1, 195101, '\P{^isletter}', "");
Expect(0, 195102, '\p{isletter}', "");
Expect(1, 195102, '\p{^isletter}', "");
Expect(1, 195102, '\P{isletter}', "");
Expect(0, 195102, '\P{^isletter}', "");
Expect(1, 195101, '\p{--Is_Letter}', "");
Expect(0, 195101, '\p{^--Is_Letter}', "");
Expect(0, 195101, '\P{--Is_Letter}', "");
Expect(1, 195101, '\P{^--Is_Letter}', "");
Expect(0, 195102, '\p{--Is_Letter}', "");
Expect(1, 195102, '\p{^--Is_Letter}', "");
Expect(1, 195102, '\P{--Is_Letter}', "");
Expect(0, 195102, '\P{^--Is_Letter}', "");
Error('\p{/a/L}');
Error('\P{/a/L}');
Expect(1, 195101, '\p{l}', "");
Expect(0, 195101, '\p{^l}', "");
Expect(0, 195101, '\P{l}', "");
Expect(1, 195101, '\P{^l}', "");
Expect(0, 195102, '\p{l}', "");
Expect(1, 195102, '\p{^l}', "");
Expect(1, 195102, '\P{l}', "");
Expect(0, 195102, '\P{^l}', "");
Expect(1, 195101, '\p{-L}', "");
Expect(0, 195101, '\p{^-L}', "");
Expect(0, 195101, '\P{-L}', "");
Expect(1, 195101, '\P{^-L}', "");
Expect(0, 195102, '\p{-L}', "");
Expect(1, 195102, '\p{^-L}', "");
Expect(1, 195102, '\P{-L}', "");
Expect(0, 195102, '\P{^-L}', "");
Error('\p{/a/-	Is_L}');
Error('\P{/a/-	Is_L}');
Expect(1, 195101, '\p{isl}', "");
Expect(0, 195101, '\p{^isl}', "");
Expect(0, 195101, '\P{isl}', "");
Expect(1, 195101, '\P{^isl}', "");
Expect(0, 195102, '\p{isl}', "");
Expect(1, 195102, '\p{^isl}', "");
Expect(1, 195102, '\P{isl}', "");
Expect(0, 195102, '\P{^isl}', "");
Expect(1, 195101, '\p{ _Is_l}', "");
Expect(0, 195101, '\p{^ _Is_l}', "");
Expect(0, 195101, '\P{ _Is_l}', "");
Expect(1, 195101, '\P{^ _Is_l}', "");
Expect(0, 195102, '\p{ _Is_l}', "");
Expect(1, 195102, '\p{^ _Is_l}', "");
Expect(1, 195102, '\P{ _Is_l}', "");
Expect(0, 195102, '\P{^ _Is_l}', "");
Error('\p{/a/_	Letter_number}');
Error('\P{/a/_	Letter_number}');
Expect(1, 74850, '\p{letternumber}', "");
Expect(0, 74850, '\p{^letternumber}', "");
Expect(0, 74850, '\P{letternumber}', "");
Expect(1, 74850, '\P{^letternumber}', "");
Expect(0, 74851, '\p{letternumber}', "");
Expect(1, 74851, '\p{^letternumber}', "");
Expect(1, 74851, '\P{letternumber}', "");
Expect(0, 74851, '\P{^letternumber}', "");
Expect(1, 74850, '\p{	Letter_Number}', "");
Expect(0, 74850, '\p{^	Letter_Number}', "");
Expect(0, 74850, '\P{	Letter_Number}', "");
Expect(1, 74850, '\P{^	Letter_Number}', "");
Expect(0, 74851, '\p{	Letter_Number}', "");
Expect(1, 74851, '\p{^	Letter_Number}', "");
Expect(1, 74851, '\P{	Letter_Number}', "");
Expect(0, 74851, '\P{^	Letter_Number}', "");
Error('\p{:=Is_letter_Number}');
Error('\P{:=Is_letter_Number}');
Expect(1, 74850, '\p{isletternumber}', "");
Expect(0, 74850, '\p{^isletternumber}', "");
Expect(0, 74850, '\P{isletternumber}', "");
Expect(1, 74850, '\P{^isletternumber}', "");
Expect(0, 74851, '\p{isletternumber}', "");
Expect(1, 74851, '\p{^isletternumber}', "");
Expect(1, 74851, '\P{isletternumber}', "");
Expect(0, 74851, '\P{^isletternumber}', "");
Expect(1, 74850, '\p{_is_Letter_number}', "");
Expect(0, 74850, '\p{^_is_Letter_number}', "");
Expect(0, 74850, '\P{_is_Letter_number}', "");
Expect(1, 74850, '\P{^_is_Letter_number}', "");
Expect(0, 74851, '\p{_is_Letter_number}', "");
Expect(1, 74851, '\p{^_is_Letter_number}', "");
Expect(1, 74851, '\P{_is_Letter_number}', "");
Expect(0, 74851, '\P{^_is_Letter_number}', "");
Error('\p{/a/nl}');
Error('\P{/a/nl}');
Expect(1, 74850, '\p{nl}', "");
Expect(0, 74850, '\p{^nl}', "");
Expect(0, 74850, '\P{nl}', "");
Expect(1, 74850, '\P{^nl}', "");
Expect(0, 74851, '\p{nl}', "");
Expect(1, 74851, '\p{^nl}', "");
Expect(1, 74851, '\P{nl}', "");
Expect(0, 74851, '\P{^nl}', "");
Expect(1, 74850, '\p{-nl}', "");
Expect(0, 74850, '\p{^-nl}', "");
Expect(0, 74850, '\P{-nl}', "");
Expect(1, 74850, '\P{^-nl}', "");
Expect(0, 74851, '\p{-nl}', "");
Expect(1, 74851, '\p{^-nl}', "");
Expect(1, 74851, '\P{-nl}', "");
Expect(0, 74851, '\P{^-nl}', "");
Error('\p{ _Is_Nl/a/}');
Error('\P{ _Is_Nl/a/}');
Expect(1, 74850, '\p{isnl}', "");
Expect(0, 74850, '\p{^isnl}', "");
Expect(0, 74850, '\P{isnl}', "");
Expect(1, 74850, '\P{^isnl}', "");
Expect(0, 74851, '\p{isnl}', "");
Expect(1, 74851, '\p{^isnl}', "");
Expect(1, 74851, '\P{isnl}', "");
Expect(0, 74851, '\P{^isnl}', "");
Expect(1, 74850, '\p{	-IS_Nl}', "");
Expect(0, 74850, '\p{^	-IS_Nl}', "");
Expect(0, 74850, '\P{	-IS_Nl}', "");
Expect(1, 74850, '\P{^	-IS_Nl}', "");
Expect(0, 74851, '\p{	-IS_Nl}', "");
Expect(1, 74851, '\p{^	-IS_Nl}', "");
Expect(1, 74851, '\P{	-IS_Nl}', "");
Expect(0, 74851, '\P{^	-IS_Nl}', "");
Error('\p{- LETTERLIKE_symbols:=}');
Error('\P{- LETTERLIKE_symbols:=}');
Expect(1, 8527, '\p{letterlikesymbols}', "");
Expect(0, 8527, '\p{^letterlikesymbols}', "");
Expect(0, 8527, '\P{letterlikesymbols}', "");
Expect(1, 8527, '\P{^letterlikesymbols}', "");
Expect(0, 8528, '\p{letterlikesymbols}', "");
Expect(1, 8528, '\p{^letterlikesymbols}', "");
Expect(1, 8528, '\P{letterlikesymbols}', "");
Expect(0, 8528, '\P{^letterlikesymbols}', "");
Expect(1, 8527, '\p{_Letterlike_Symbols}', "");
Expect(0, 8527, '\p{^_Letterlike_Symbols}', "");
Expect(0, 8527, '\P{_Letterlike_Symbols}', "");
Expect(1, 8527, '\P{^_Letterlike_Symbols}', "");
Expect(0, 8528, '\p{_Letterlike_Symbols}', "");
Expect(1, 8528, '\p{^_Letterlike_Symbols}', "");
Expect(1, 8528, '\P{_Letterlike_Symbols}', "");
Expect(0, 8528, '\P{^_Letterlike_Symbols}', "");
Error('\p{	:=Is_Letterlike_SYMBOLS}');
Error('\P{	:=Is_Letterlike_SYMBOLS}');
Expect(1, 8527, '\p{isletterlikesymbols}', "");
Expect(0, 8527, '\p{^isletterlikesymbols}', "");
Expect(0, 8527, '\P{isletterlikesymbols}', "");
Expect(1, 8527, '\P{^isletterlikesymbols}', "");
Expect(0, 8528, '\p{isletterlikesymbols}', "");
Expect(1, 8528, '\p{^isletterlikesymbols}', "");
Expect(1, 8528, '\P{isletterlikesymbols}', "");
Expect(0, 8528, '\P{^isletterlikesymbols}', "");
Expect(1, 8527, '\p{-IS_Letterlike_Symbols}', "");
Expect(0, 8527, '\p{^-IS_Letterlike_Symbols}', "");
Expect(0, 8527, '\P{-IS_Letterlike_Symbols}', "");
Expect(1, 8527, '\P{^-IS_Letterlike_Symbols}', "");
Expect(0, 8528, '\p{-IS_Letterlike_Symbols}', "");
Expect(1, 8528, '\p{^-IS_Letterlike_Symbols}', "");
Expect(1, 8528, '\P{-IS_Letterlike_Symbols}', "");
Expect(0, 8528, '\P{^-IS_Letterlike_Symbols}', "");
Error('\p{/a/In_LETTERLIKE_symbols}');
Error('\P{/a/In_LETTERLIKE_symbols}');
Expect(1, 8527, '\p{inletterlikesymbols}', "");
Expect(0, 8527, '\p{^inletterlikesymbols}', "");
Expect(0, 8527, '\P{inletterlikesymbols}', "");
Expect(1, 8527, '\P{^inletterlikesymbols}', "");
Expect(0, 8528, '\p{inletterlikesymbols}', "");
Expect(1, 8528, '\p{^inletterlikesymbols}', "");
Expect(1, 8528, '\P{inletterlikesymbols}', "");
Expect(0, 8528, '\P{^inletterlikesymbols}', "");
Expect(1, 8527, '\p{-IN_letterlike_Symbols}', "");
Expect(0, 8527, '\p{^-IN_letterlike_Symbols}', "");
Expect(0, 8527, '\P{-IN_letterlike_Symbols}', "");
Expect(1, 8527, '\P{^-IN_letterlike_Symbols}', "");
Expect(0, 8528, '\p{-IN_letterlike_Symbols}', "");
Expect(1, 8528, '\p{^-IN_letterlike_Symbols}', "");
Expect(1, 8528, '\P{-IN_letterlike_Symbols}', "");
Expect(0, 8528, '\P{^-IN_letterlike_Symbols}', "");
Error('\p{_-limbu/a/}');
Error('\P{_-limbu/a/}');
Expect(1, 6479, '\p{limbu}', "");
Expect(0, 6479, '\p{^limbu}', "");
Expect(0, 6479, '\P{limbu}', "");
Expect(1, 6479, '\P{^limbu}', "");
Expect(0, 6480, '\p{limbu}', "");
Expect(1, 6480, '\p{^limbu}', "");
Expect(1, 6480, '\P{limbu}', "");
Expect(0, 6480, '\P{^limbu}', "");
Expect(1, 6479, '\p{_Limbu}', "");
Expect(0, 6479, '\p{^_Limbu}', "");
Expect(0, 6479, '\P{_Limbu}', "");
Expect(1, 6479, '\P{^_Limbu}', "");
Expect(0, 6480, '\p{_Limbu}', "");
Expect(1, 6480, '\p{^_Limbu}', "");
Expect(1, 6480, '\P{_Limbu}', "");
Expect(0, 6480, '\P{^_Limbu}', "");
Error('\p{-/a/Is_Limbu}');
Error('\P{-/a/Is_Limbu}');
Expect(1, 6479, '\p{islimbu}', "");
Expect(0, 6479, '\p{^islimbu}', "");
Expect(0, 6479, '\P{islimbu}', "");
Expect(1, 6479, '\P{^islimbu}', "");
Expect(0, 6480, '\p{islimbu}', "");
Expect(1, 6480, '\p{^islimbu}', "");
Expect(1, 6480, '\P{islimbu}', "");
Expect(0, 6480, '\P{^islimbu}', "");
Expect(1, 6479, '\p{ 	is_limbu}', "");
Expect(0, 6479, '\p{^ 	is_limbu}', "");
Expect(0, 6479, '\P{ 	is_limbu}', "");
Expect(1, 6479, '\P{^ 	is_limbu}', "");
Expect(0, 6480, '\p{ 	is_limbu}', "");
Expect(1, 6480, '\p{^ 	is_limbu}', "");
Expect(1, 6480, '\P{ 	is_limbu}', "");
Expect(0, 6480, '\P{^ 	is_limbu}', "");
Error('\p{	_limb/a/}');
Error('\P{	_limb/a/}');
Expect(1, 6479, '\p{limb}', "");
Expect(0, 6479, '\p{^limb}', "");
Expect(0, 6479, '\P{limb}', "");
Expect(1, 6479, '\P{^limb}', "");
Expect(0, 6480, '\p{limb}', "");
Expect(1, 6480, '\p{^limb}', "");
Expect(1, 6480, '\P{limb}', "");
Expect(0, 6480, '\P{^limb}', "");
Expect(1, 6479, '\p{-limb}', "");
Expect(0, 6479, '\p{^-limb}', "");
Expect(0, 6479, '\P{-limb}', "");
Expect(1, 6479, '\P{^-limb}', "");
Expect(0, 6480, '\p{-limb}', "");
Expect(1, 6480, '\p{^-limb}', "");
Expect(1, 6480, '\P{-limb}', "");
Expect(0, 6480, '\P{^-limb}', "");
Error('\p{	:=Is_limb}');
Error('\P{	:=Is_limb}');
Expect(1, 6479, '\p{islimb}', "");
Expect(0, 6479, '\p{^islimb}', "");
Expect(0, 6479, '\P{islimb}', "");
Expect(1, 6479, '\P{^islimb}', "");
Expect(0, 6480, '\p{islimb}', "");
Expect(1, 6480, '\p{^islimb}', "");
Expect(1, 6480, '\P{islimb}', "");
Expect(0, 6480, '\P{^islimb}', "");
Expect(1, 6479, '\p{	Is_Limb}', "");
Expect(0, 6479, '\p{^	Is_Limb}', "");
Expect(0, 6479, '\P{	Is_Limb}', "");
Expect(1, 6479, '\P{^	Is_Limb}', "");
Expect(0, 6480, '\p{	Is_Limb}', "");
Expect(1, 6480, '\p{^	Is_Limb}', "");
Expect(1, 6480, '\P{	Is_Limb}', "");
Expect(0, 6480, '\P{^	Is_Limb}', "");
Error('\p{:=Line_separator}');
Error('\P{:=Line_separator}');
Expect(1, 8232, '\p{lineseparator}', "");
Expect(0, 8232, '\p{^lineseparator}', "");
Expect(0, 8232, '\P{lineseparator}', "");
Expect(1, 8232, '\P{^lineseparator}', "");
Expect(0, 8233, '\p{lineseparator}', "");
Expect(1, 8233, '\p{^lineseparator}', "");
Expect(1, 8233, '\P{lineseparator}', "");
Expect(0, 8233, '\P{^lineseparator}', "");
Expect(1, 8232, '\p{	line_Separator}', "");
Expect(0, 8232, '\p{^	line_Separator}', "");
Expect(0, 8232, '\P{	line_Separator}', "");
Expect(1, 8232, '\P{^	line_Separator}', "");
Expect(0, 8233, '\p{	line_Separator}', "");
Expect(1, 8233, '\p{^	line_Separator}', "");
Expect(1, 8233, '\P{	line_Separator}', "");
Expect(0, 8233, '\P{^	line_Separator}', "");
Error('\p{ 	IS_Line_Separator:=}');
Error('\P{ 	IS_Line_Separator:=}');
Expect(1, 8232, '\p{islineseparator}', "");
Expect(0, 8232, '\p{^islineseparator}', "");
Expect(0, 8232, '\P{islineseparator}', "");
Expect(1, 8232, '\P{^islineseparator}', "");
Expect(0, 8233, '\p{islineseparator}', "");
Expect(1, 8233, '\p{^islineseparator}', "");
Expect(1, 8233, '\P{islineseparator}', "");
Expect(0, 8233, '\P{^islineseparator}', "");
Expect(1, 8232, '\p{	 is_LINE_Separator}', "");
Expect(0, 8232, '\p{^	 is_LINE_Separator}', "");
Expect(0, 8232, '\P{	 is_LINE_Separator}', "");
Expect(1, 8232, '\P{^	 is_LINE_Separator}', "");
Expect(0, 8233, '\p{	 is_LINE_Separator}', "");
Expect(1, 8233, '\p{^	 is_LINE_Separator}', "");
Expect(1, 8233, '\P{	 is_LINE_Separator}', "");
Expect(0, 8233, '\P{^	 is_LINE_Separator}', "");
Error('\p{:= 	Zl}');
Error('\P{:= 	Zl}');
Expect(1, 8232, '\p{zl}', "");
Expect(0, 8232, '\p{^zl}', "");
Expect(0, 8232, '\P{zl}', "");
Expect(1, 8232, '\P{^zl}', "");
Expect(0, 8233, '\p{zl}', "");
Expect(1, 8233, '\p{^zl}', "");
Expect(1, 8233, '\P{zl}', "");
Expect(0, 8233, '\P{^zl}', "");
Expect(1, 8232, '\p{ _zl}', "");
Expect(0, 8232, '\p{^ _zl}', "");
Expect(0, 8232, '\P{ _zl}', "");
Expect(1, 8232, '\P{^ _zl}', "");
Expect(0, 8233, '\p{ _zl}', "");
Expect(1, 8233, '\p{^ _zl}', "");
Expect(1, 8233, '\P{ _zl}', "");
Expect(0, 8233, '\P{^ _zl}', "");
Error('\p{_Is_Zl/a/}');
Error('\P{_Is_Zl/a/}');
Expect(1, 8232, '\p{iszl}', "");
Expect(0, 8232, '\p{^iszl}', "");
Expect(0, 8232, '\P{iszl}', "");
Expect(1, 8232, '\P{^iszl}', "");
Expect(0, 8233, '\p{iszl}', "");
Expect(1, 8233, '\p{^iszl}', "");
Expect(1, 8233, '\P{iszl}', "");
Expect(0, 8233, '\P{^iszl}', "");
Expect(1, 8232, '\p{-IS_zl}', "");
Expect(0, 8232, '\p{^-IS_zl}', "");
Expect(0, 8232, '\P{-IS_zl}', "");
Expect(1, 8232, '\P{^-IS_zl}', "");
Expect(0, 8233, '\p{-IS_zl}', "");
Expect(1, 8233, '\p{^-IS_zl}', "");
Expect(1, 8233, '\P{-IS_zl}', "");
Expect(0, 8233, '\P{^-IS_zl}', "");
Error('\p{	:=linear_b}');
Error('\P{	:=linear_b}');
Expect(1, 65786, '\p{linearb}', "");
Expect(0, 65786, '\p{^linearb}', "");
Expect(0, 65786, '\P{linearb}', "");
Expect(1, 65786, '\P{^linearb}', "");
Expect(0, 65787, '\p{linearb}', "");
Expect(1, 65787, '\p{^linearb}', "");
Expect(1, 65787, '\P{linearb}', "");
Expect(0, 65787, '\P{^linearb}', "");
Expect(1, 65786, '\p{	 linear_B}', "");
Expect(0, 65786, '\p{^	 linear_B}', "");
Expect(0, 65786, '\P{	 linear_B}', "");
Expect(1, 65786, '\P{^	 linear_B}', "");
Expect(0, 65787, '\p{	 linear_B}', "");
Expect(1, 65787, '\p{^	 linear_B}', "");
Expect(1, 65787, '\P{	 linear_B}', "");
Expect(0, 65787, '\P{^	 linear_B}', "");
Error('\p{:=__Is_linear_b}');
Error('\P{:=__Is_linear_b}');
Expect(1, 65786, '\p{islinearb}', "");
Expect(0, 65786, '\p{^islinearb}', "");
Expect(0, 65786, '\P{islinearb}', "");
Expect(1, 65786, '\P{^islinearb}', "");
Expect(0, 65787, '\p{islinearb}', "");
Expect(1, 65787, '\p{^islinearb}', "");
Expect(1, 65787, '\P{islinearb}', "");
Expect(0, 65787, '\P{^islinearb}', "");
Expect(1, 65786, '\p{	 Is_Linear_B}', "");
Expect(0, 65786, '\p{^	 Is_Linear_B}', "");
Expect(0, 65786, '\P{	 Is_Linear_B}', "");
Expect(1, 65786, '\P{^	 Is_Linear_B}', "");
Expect(0, 65787, '\p{	 Is_Linear_B}', "");
Expect(1, 65787, '\p{^	 Is_Linear_B}', "");
Expect(1, 65787, '\P{	 Is_Linear_B}', "");
Expect(0, 65787, '\P{^	 Is_Linear_B}', "");
Error('\p{-:=LINB}');
Error('\P{-:=LINB}');
Expect(1, 65786, '\p{linb}', "");
Expect(0, 65786, '\p{^linb}', "");
Expect(0, 65786, '\P{linb}', "");
Expect(1, 65786, '\P{^linb}', "");
Expect(0, 65787, '\p{linb}', "");
Expect(1, 65787, '\p{^linb}', "");
Expect(1, 65787, '\P{linb}', "");
Expect(0, 65787, '\P{^linb}', "");
Expect(1, 65786, '\p{  Linb}', "");
Expect(0, 65786, '\p{^  Linb}', "");
Expect(0, 65786, '\P{  Linb}', "");
Expect(1, 65786, '\P{^  Linb}', "");
Expect(0, 65787, '\p{  Linb}', "");
Expect(1, 65787, '\p{^  Linb}', "");
Expect(1, 65787, '\P{  Linb}', "");
Expect(0, 65787, '\P{^  Linb}', "");
Error('\p{/a/__IS_linb}');
Error('\P{/a/__IS_linb}');
Expect(1, 65786, '\p{islinb}', "");
Expect(0, 65786, '\p{^islinb}', "");
Expect(0, 65786, '\P{islinb}', "");
Expect(1, 65786, '\P{^islinb}', "");
Expect(0, 65787, '\p{islinb}', "");
Expect(1, 65787, '\p{^islinb}', "");
Expect(1, 65787, '\P{islinb}', "");
Expect(0, 65787, '\P{^islinb}', "");
Expect(1, 65786, '\p{-	Is_linb}', "");
Expect(0, 65786, '\p{^-	Is_linb}', "");
Expect(0, 65786, '\P{-	Is_linb}', "");
Expect(1, 65786, '\P{^-	Is_linb}', "");
Expect(0, 65787, '\p{-	Is_linb}', "");
Expect(1, 65787, '\p{^-	Is_linb}', "");
Expect(1, 65787, '\P{-	Is_linb}', "");
Expect(0, 65787, '\P{^-	Is_linb}', "");
Error('\p{_linear_B_Ideograms:=}');
Error('\P{_linear_B_Ideograms:=}');
Expect(1, 65791, '\p{linearbideograms}', "");
Expect(0, 65791, '\p{^linearbideograms}', "");
Expect(0, 65791, '\P{linearbideograms}', "");
Expect(1, 65791, '\P{^linearbideograms}', "");
Expect(0, 65792, '\p{linearbideograms}', "");
Expect(1, 65792, '\p{^linearbideograms}', "");
Expect(1, 65792, '\P{linearbideograms}', "");
Expect(0, 65792, '\P{^linearbideograms}', "");
Expect(1, 65791, '\p{_ LINEAR_b_IDEOGRAMS}', "");
Expect(0, 65791, '\p{^_ LINEAR_b_IDEOGRAMS}', "");
Expect(0, 65791, '\P{_ LINEAR_b_IDEOGRAMS}', "");
Expect(1, 65791, '\P{^_ LINEAR_b_IDEOGRAMS}', "");
Expect(0, 65792, '\p{_ LINEAR_b_IDEOGRAMS}', "");
Expect(1, 65792, '\p{^_ LINEAR_b_IDEOGRAMS}', "");
Expect(1, 65792, '\P{_ LINEAR_b_IDEOGRAMS}', "");
Expect(0, 65792, '\P{^_ LINEAR_b_IDEOGRAMS}', "");
Error('\p{__Is_Linear_B_IDEOGRAMS/a/}');
Error('\P{__Is_Linear_B_IDEOGRAMS/a/}');
Expect(1, 65791, '\p{islinearbideograms}', "");
Expect(0, 65791, '\p{^islinearbideograms}', "");
Expect(0, 65791, '\P{islinearbideograms}', "");
Expect(1, 65791, '\P{^islinearbideograms}', "");
Expect(0, 65792, '\p{islinearbideograms}', "");
Expect(1, 65792, '\p{^islinearbideograms}', "");
Expect(1, 65792, '\P{islinearbideograms}', "");
Expect(0, 65792, '\P{^islinearbideograms}', "");
Expect(1, 65791, '\p{ is_LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\p{^ is_LINEAR_B_Ideograms}', "");
Expect(0, 65791, '\P{ is_LINEAR_B_Ideograms}', "");
Expect(1, 65791, '\P{^ is_LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\p{ is_LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\p{^ is_LINEAR_B_Ideograms}', "");
Expect(1, 65792, '\P{ is_LINEAR_B_Ideograms}', "");
Expect(0, 65792, '\P{^ is_LINEAR_B_Ideograms}', "");
Error('\p{/a/_	in_Linear_B_IDEOGRAMS}');
Error('\P{/a/_	in_Linear_B_IDEOGRAMS}');
Expect(1, 65791, '\p{inlinearbideograms}', "");
Expect(0, 65791, '\p{^inlinearbideograms}', "");
Expect(0, 65791, '\P{inlinearbideograms}', "");
Expect(1, 65791, '\P{^inlinearbideograms}', "");
Expect(0, 65792, '\p{inlinearbideograms}', "");
Expect(1, 65792, '\p{^inlinearbideograms}', "");
Expect(1, 65792, '\P{inlinearbideograms}', "");
Expect(0, 65792, '\P{^inlinearbideograms}', "");
Expect(1, 65791, '\p{-In_Linear_b_Ideograms}', "");
Expect(0, 65791, '\p{^-In_Linear_b_Ideograms}', "");
Expect(0, 65791, '\P{-In_Linear_b_Ideograms}', "");
Expect(1, 65791, '\P{^-In_Linear_b_Ideograms}', "");
Expect(0, 65792, '\p{-In_Linear_b_Ideograms}', "");
Expect(1, 65792, '\p{^-In_Linear_b_Ideograms}', "");
Expect(1, 65792, '\P{-In_Linear_b_Ideograms}', "");
Expect(0, 65792, '\P{^-In_Linear_b_Ideograms}', "");
Error('\p{-/a/LINEAR_B_syllabary}');
Error('\P{-/a/LINEAR_B_syllabary}');
Expect(1, 65663, '\p{linearbsyllabary}', "");
Expect(0, 65663, '\p{^linearbsyllabary}', "");
Expect(0, 65663, '\P{linearbsyllabary}', "");
Expect(1, 65663, '\P{^linearbsyllabary}', "");
Expect(0, 65664, '\p{linearbsyllabary}', "");
Expect(1, 65664, '\p{^linearbsyllabary}', "");
Expect(1, 65664, '\P{linearbsyllabary}', "");
Expect(0, 65664, '\P{^linearbsyllabary}', "");
Expect(1, 65663, '\p{		linear_B_syllabary}', "");
Expect(0, 65663, '\p{^		linear_B_syllabary}', "");
Expect(0, 65663, '\P{		linear_B_syllabary}', "");
Expect(1, 65663, '\P{^		linear_B_syllabary}', "");
Expect(0, 65664, '\p{		linear_B_syllabary}', "");
Expect(1, 65664, '\p{^		linear_B_syllabary}', "");
Expect(1, 65664, '\P{		linear_B_syllabary}', "");
Expect(0, 65664, '\P{^		linear_B_syllabary}', "");
Error('\p{/a/ IS_LINEAR_B_SYLLABARY}');
Error('\P{/a/ IS_LINEAR_B_SYLLABARY}');
Expect(1, 65663, '\p{islinearbsyllabary}', "");
Expect(0, 65663, '\p{^islinearbsyllabary}', "");
Expect(0, 65663, '\P{islinearbsyllabary}', "");
Expect(1, 65663, '\P{^islinearbsyllabary}', "");
Expect(0, 65664, '\p{islinearbsyllabary}', "");
Expect(1, 65664, '\p{^islinearbsyllabary}', "");
Expect(1, 65664, '\P{islinearbsyllabary}', "");
Expect(0, 65664, '\P{^islinearbsyllabary}', "");
Expect(1, 65663, '\p{-Is_Linear_B_Syllabary}', "");
Expect(0, 65663, '\p{^-Is_Linear_B_Syllabary}', "");
Expect(0, 65663, '\P{-Is_Linear_B_Syllabary}', "");
Expect(1, 65663, '\P{^-Is_Linear_B_Syllabary}', "");
Expect(0, 65664, '\p{-Is_Linear_B_Syllabary}', "");
Expect(1, 65664, '\p{^-Is_Linear_B_Syllabary}', "");
Expect(1, 65664, '\P{-Is_Linear_B_Syllabary}', "");
Expect(0, 65664, '\P{^-Is_Linear_B_Syllabary}', "");
Error('\p{IN_linear_B_Syllabary:=}');
Error('\P{IN_linear_B_Syllabary:=}');
Expect(1, 65663, '\p{inlinearbsyllabary}', "");
Expect(0, 65663, '\p{^inlinearbsyllabary}', "");
Expect(0, 65663, '\P{inlinearbsyllabary}', "");
Expect(1, 65663, '\P{^inlinearbsyllabary}', "");
Expect(0, 65664, '\p{inlinearbsyllabary}', "");
Expect(1, 65664, '\p{^inlinearbsyllabary}', "");
Expect(1, 65664, '\P{inlinearbsyllabary}', "");
Expect(0, 65664, '\P{^inlinearbsyllabary}', "");
Expect(1, 65663, '\p{_-IN_Linear_b_syllabary}', "");
Expect(0, 65663, '\p{^_-IN_Linear_b_syllabary}', "");
Expect(0, 65663, '\P{_-IN_Linear_b_syllabary}', "");
Expect(1, 65663, '\P{^_-IN_Linear_b_syllabary}', "");
Expect(0, 65664, '\p{_-IN_Linear_b_syllabary}', "");
Expect(1, 65664, '\p{^_-IN_Linear_b_syllabary}', "");
Expect(1, 65664, '\P{_-IN_Linear_b_syllabary}', "");
Expect(0, 65664, '\P{^_-IN_Linear_b_syllabary}', "");
Error('\p{_:=LISU}');
Error('\P{_:=LISU}');
Expect(1, 42239, '\p{lisu}', "");
Expect(0, 42239, '\p{^lisu}', "");
Expect(0, 42239, '\P{lisu}', "");
Expect(1, 42239, '\P{^lisu}', "");
Expect(0, 42240, '\p{lisu}', "");
Expect(1, 42240, '\p{^lisu}', "");
Expect(1, 42240, '\P{lisu}', "");
Expect(0, 42240, '\P{^lisu}', "");
Expect(1, 42239, '\p{ Lisu}', "");
Expect(0, 42239, '\p{^ Lisu}', "");
Expect(0, 42239, '\P{ Lisu}', "");
Expect(1, 42239, '\P{^ Lisu}', "");
Expect(0, 42240, '\p{ Lisu}', "");
Expect(1, 42240, '\p{^ Lisu}', "");
Expect(1, 42240, '\P{ Lisu}', "");
Expect(0, 42240, '\P{^ Lisu}', "");
Error('\p{_:=Is_Lisu}');
Error('\P{_:=Is_Lisu}');
Expect(1, 42239, '\p{islisu}', "");
Expect(0, 42239, '\p{^islisu}', "");
Expect(0, 42239, '\P{islisu}', "");
Expect(1, 42239, '\P{^islisu}', "");
Expect(0, 42240, '\p{islisu}', "");
Expect(1, 42240, '\p{^islisu}', "");
Expect(1, 42240, '\P{islisu}', "");
Expect(0, 42240, '\P{^islisu}', "");
Expect(1, 42239, '\p{Is_Lisu}', "");
Expect(0, 42239, '\p{^Is_Lisu}', "");
Expect(0, 42239, '\P{Is_Lisu}', "");
Expect(1, 42239, '\P{^Is_Lisu}', "");
Expect(0, 42240, '\p{Is_Lisu}', "");
Expect(1, 42240, '\p{^Is_Lisu}', "");
Expect(1, 42240, '\P{Is_Lisu}', "");
Expect(0, 42240, '\P{^Is_Lisu}', "");
Error('\p{/a/ logical_order_Exception}');
Error('\P{/a/ logical_order_Exception}');
Expect(1, 43708, '\p{logicalorderexception}', "");
Expect(0, 43708, '\p{^logicalorderexception}', "");
Expect(0, 43708, '\P{logicalorderexception}', "");
Expect(1, 43708, '\P{^logicalorderexception}', "");
Expect(0, 43709, '\p{logicalorderexception}', "");
Expect(1, 43709, '\p{^logicalorderexception}', "");
Expect(1, 43709, '\P{logicalorderexception}', "");
Expect(0, 43709, '\P{^logicalorderexception}', "");
Expect(1, 43708, '\p{-Logical_order_EXCEPTION}', "");
Expect(0, 43708, '\p{^-Logical_order_EXCEPTION}', "");
Expect(0, 43708, '\P{-Logical_order_EXCEPTION}', "");
Expect(1, 43708, '\P{^-Logical_order_EXCEPTION}', "");
Expect(0, 43709, '\p{-Logical_order_EXCEPTION}', "");
Expect(1, 43709, '\p{^-Logical_order_EXCEPTION}', "");
Expect(1, 43709, '\P{-Logical_order_EXCEPTION}', "");
Expect(0, 43709, '\P{^-Logical_order_EXCEPTION}', "");
Error('\p{:=_Is_Logical_ORDER_Exception}');
Error('\P{:=_Is_Logical_ORDER_Exception}');
Expect(1, 43708, '\p{islogicalorderexception}', "");
Expect(0, 43708, '\p{^islogicalorderexception}', "");
Expect(0, 43708, '\P{islogicalorderexception}', "");
Expect(1, 43708, '\P{^islogicalorderexception}', "");
Expect(0, 43709, '\p{islogicalorderexception}', "");
Expect(1, 43709, '\p{^islogicalorderexception}', "");
Expect(1, 43709, '\P{islogicalorderexception}', "");
Expect(0, 43709, '\P{^islogicalorderexception}', "");
Expect(1, 43708, '\p{	-IS_Logical_Order_Exception}', "");
Expect(0, 43708, '\p{^	-IS_Logical_Order_Exception}', "");
Expect(0, 43708, '\P{	-IS_Logical_Order_Exception}', "");
Expect(1, 43708, '\P{^	-IS_Logical_Order_Exception}', "");
Expect(0, 43709, '\p{	-IS_Logical_Order_Exception}', "");
Expect(1, 43709, '\p{^	-IS_Logical_Order_Exception}', "");
Expect(1, 43709, '\P{	-IS_Logical_Order_Exception}', "");
Expect(0, 43709, '\P{^	-IS_Logical_Order_Exception}', "");
Error('\p{:=_LOE}');
Error('\P{:=_LOE}');
Expect(1, 43708, '\p{loe}', "");
Expect(0, 43708, '\p{^loe}', "");
Expect(0, 43708, '\P{loe}', "");
Expect(1, 43708, '\P{^loe}', "");
Expect(0, 43709, '\p{loe}', "");
Expect(1, 43709, '\p{^loe}', "");
Expect(1, 43709, '\P{loe}', "");
Expect(0, 43709, '\P{^loe}', "");
Expect(1, 43708, '\p{ 	LOE}', "");
Expect(0, 43708, '\p{^ 	LOE}', "");
Expect(0, 43708, '\P{ 	LOE}', "");
Expect(1, 43708, '\P{^ 	LOE}', "");
Expect(0, 43709, '\p{ 	LOE}', "");
Expect(1, 43709, '\p{^ 	LOE}', "");
Expect(1, 43709, '\P{ 	LOE}', "");
Expect(0, 43709, '\P{^ 	LOE}', "");
Error('\p{		is_LOE/a/}');
Error('\P{		is_LOE/a/}');
Expect(1, 43708, '\p{isloe}', "");
Expect(0, 43708, '\p{^isloe}', "");
Expect(0, 43708, '\P{isloe}', "");
Expect(1, 43708, '\P{^isloe}', "");
Expect(0, 43709, '\p{isloe}', "");
Expect(1, 43709, '\p{^isloe}', "");
Expect(1, 43709, '\P{isloe}', "");
Expect(0, 43709, '\P{^isloe}', "");
Expect(1, 43708, '\p{-	IS_LOE}', "");
Expect(0, 43708, '\p{^-	IS_LOE}', "");
Expect(0, 43708, '\P{-	IS_LOE}', "");
Expect(1, 43708, '\P{^-	IS_LOE}', "");
Expect(0, 43709, '\p{-	IS_LOE}', "");
Expect(1, 43709, '\p{^-	IS_LOE}', "");
Expect(1, 43709, '\P{-	IS_LOE}', "");
Expect(0, 43709, '\P{^-	IS_LOE}', "");
Error('\p{-Low_Surrogates:=}');
Error('\P{-Low_Surrogates:=}');
Expect(1, 57343, '\p{lowsurrogates}', "");
Expect(0, 57343, '\p{^lowsurrogates}', "");
Expect(0, 57343, '\P{lowsurrogates}', "");
Expect(1, 57343, '\P{^lowsurrogates}', "");
Expect(0, 57344, '\p{lowsurrogates}', "");
Expect(1, 57344, '\p{^lowsurrogates}', "");
Expect(1, 57344, '\P{lowsurrogates}', "");
Expect(0, 57344, '\P{^lowsurrogates}', "");
Expect(1, 57343, '\p{ 	low_surrogates}', "");
Expect(0, 57343, '\p{^ 	low_surrogates}', "");
Expect(0, 57343, '\P{ 	low_surrogates}', "");
Expect(1, 57343, '\P{^ 	low_surrogates}', "");
Expect(0, 57344, '\p{ 	low_surrogates}', "");
Expect(1, 57344, '\p{^ 	low_surrogates}', "");
Expect(1, 57344, '\P{ 	low_surrogates}', "");
Expect(0, 57344, '\P{^ 	low_surrogates}', "");
Error('\p{		Is_low_Surrogates:=}');
Error('\P{		Is_low_Surrogates:=}');
Expect(1, 57343, '\p{islowsurrogates}', "");
Expect(0, 57343, '\p{^islowsurrogates}', "");
Expect(0, 57343, '\P{islowsurrogates}', "");
Expect(1, 57343, '\P{^islowsurrogates}', "");
Expect(0, 57344, '\p{islowsurrogates}', "");
Expect(1, 57344, '\p{^islowsurrogates}', "");
Expect(1, 57344, '\P{islowsurrogates}', "");
Expect(0, 57344, '\P{^islowsurrogates}', "");
Expect(1, 57343, '\p{_	Is_Low_Surrogates}', "");
Expect(0, 57343, '\p{^_	Is_Low_Surrogates}', "");
Expect(0, 57343, '\P{_	Is_Low_Surrogates}', "");
Expect(1, 57343, '\P{^_	Is_Low_Surrogates}', "");
Expect(0, 57344, '\p{_	Is_Low_Surrogates}', "");
Expect(1, 57344, '\p{^_	Is_Low_Surrogates}', "");
Expect(1, 57344, '\P{_	Is_Low_Surrogates}', "");
Expect(0, 57344, '\P{^_	Is_Low_Surrogates}', "");
Error('\p{/a/In_low_SURROGATES}');
Error('\P{/a/In_low_SURROGATES}');
Expect(1, 57343, '\p{inlowsurrogates}', "");
Expect(0, 57343, '\p{^inlowsurrogates}', "");
Expect(0, 57343, '\P{inlowsurrogates}', "");
Expect(1, 57343, '\P{^inlowsurrogates}', "");
Expect(0, 57344, '\p{inlowsurrogates}', "");
Expect(1, 57344, '\p{^inlowsurrogates}', "");
Expect(1, 57344, '\P{inlowsurrogates}', "");
Expect(0, 57344, '\P{^inlowsurrogates}', "");
Expect(1, 57343, '\p{-_IN_LOW_SURROGATES}', "");
Expect(0, 57343, '\p{^-_IN_LOW_SURROGATES}', "");
Expect(0, 57343, '\P{-_IN_LOW_SURROGATES}', "");
Expect(1, 57343, '\P{^-_IN_LOW_SURROGATES}', "");
Expect(0, 57344, '\p{-_IN_LOW_SURROGATES}', "");
Expect(1, 57344, '\p{^-_IN_LOW_SURROGATES}', "");
Expect(1, 57344, '\P{-_IN_LOW_SURROGATES}', "");
Expect(0, 57344, '\P{^-_IN_LOW_SURROGATES}', "");
Error('\p{:=Lower}');
Error('\P{:=Lower}');
Expect(1, 120779, '\p{lower}', "");
Expect(0, 120779, '\p{^lower}', "");
Expect(0, 120779, '\P{lower}', "");
Expect(1, 120779, '\P{^lower}', "");
Expect(0, 120780, '\p{lower}', "");
Expect(1, 120780, '\p{^lower}', "");
Expect(1, 120780, '\P{lower}', "");
Expect(0, 120780, '\P{^lower}', "");
Expect(1, 120779, '\p{- lower}', "");
Expect(0, 120779, '\p{^- lower}', "");
Expect(0, 120779, '\P{- lower}', "");
Expect(1, 120779, '\P{^- lower}', "");
Expect(0, 120780, '\p{- lower}', "");
Expect(1, 120780, '\p{^- lower}', "");
Expect(1, 120780, '\P{- lower}', "");
Expect(0, 120780, '\P{^- lower}', "");
Error('\p{-	xposixlower/a/}');
Error('\P{-	xposixlower/a/}');
Expect(1, 120779, '\p{xposixlower}', "");
Expect(0, 120779, '\p{^xposixlower}', "");
Expect(0, 120779, '\P{xposixlower}', "");
Expect(1, 120779, '\P{^xposixlower}', "");
Expect(0, 120780, '\p{xposixlower}', "");
Expect(1, 120780, '\p{^xposixlower}', "");
Expect(1, 120780, '\P{xposixlower}', "");
Expect(0, 120780, '\P{^xposixlower}', "");
Expect(1, 120779, '\p{-XPOSIXLOWER}', "");
Expect(0, 120779, '\p{^-XPOSIXLOWER}', "");
Expect(0, 120779, '\P{-XPOSIXLOWER}', "");
Expect(1, 120779, '\P{^-XPOSIXLOWER}', "");
Expect(0, 120780, '\p{-XPOSIXLOWER}', "");
Expect(1, 120780, '\p{^-XPOSIXLOWER}', "");
Expect(1, 120780, '\P{-XPOSIXLOWER}', "");
Expect(0, 120780, '\P{^-XPOSIXLOWER}', "");
Error('\p{	:=Is_Lower}');
Error('\P{	:=Is_Lower}');
Expect(1, 120779, '\p{islower}', "");
Expect(0, 120779, '\p{^islower}', "");
Expect(0, 120779, '\P{islower}', "");
Expect(1, 120779, '\P{^islower}', "");
Expect(0, 120780, '\p{islower}', "");
Expect(1, 120780, '\p{^islower}', "");
Expect(1, 120780, '\P{islower}', "");
Expect(0, 120780, '\P{^islower}', "");
Expect(1, 120779, '\p{	_Is_Lower}', "");
Expect(0, 120779, '\p{^	_Is_Lower}', "");
Expect(0, 120779, '\P{	_Is_Lower}', "");
Expect(1, 120779, '\P{^	_Is_Lower}', "");
Expect(0, 120780, '\p{	_Is_Lower}', "");
Expect(1, 120780, '\p{^	_Is_Lower}', "");
Expect(1, 120780, '\P{	_Is_Lower}', "");
Expect(0, 120780, '\P{^	_Is_Lower}', "");
Error('\p{/a/	 is_XPosixLower}');
Error('\P{/a/	 is_XPosixLower}');
Expect(1, 120779, '\p{isxposixlower}', "");
Expect(0, 120779, '\p{^isxposixlower}', "");
Expect(0, 120779, '\P{isxposixlower}', "");
Expect(1, 120779, '\P{^isxposixlower}', "");
Expect(0, 120780, '\p{isxposixlower}', "");
Expect(1, 120780, '\p{^isxposixlower}', "");
Expect(1, 120780, '\P{isxposixlower}', "");
Expect(0, 120780, '\P{^isxposixlower}', "");
Expect(1, 120779, '\p{_	is_XPOSIXLOWER}', "");
Expect(0, 120779, '\p{^_	is_XPOSIXLOWER}', "");
Expect(0, 120779, '\P{_	is_XPOSIXLOWER}', "");
Expect(1, 120779, '\P{^_	is_XPOSIXLOWER}', "");
Expect(0, 120780, '\p{_	is_XPOSIXLOWER}', "");
Expect(1, 120780, '\p{^_	is_XPOSIXLOWER}', "");
Expect(1, 120780, '\P{_	is_XPOSIXLOWER}', "");
Expect(0, 120780, '\P{^_	is_XPOSIXLOWER}', "");
Error('\p{/a/lowercase}');
Error('\P{/a/lowercase}');
Expect(1, 120779, '\p{lowercase}', "");
Expect(0, 120779, '\p{^lowercase}', "");
Expect(0, 120779, '\P{lowercase}', "");
Expect(1, 120779, '\P{^lowercase}', "");
Expect(0, 120780, '\p{lowercase}', "");
Expect(1, 120780, '\p{^lowercase}', "");
Expect(1, 120780, '\P{lowercase}', "");
Expect(0, 120780, '\P{^lowercase}', "");
Expect(1, 120779, '\p{		Lowercase}', "");
Expect(0, 120779, '\p{^		Lowercase}', "");
Expect(0, 120779, '\P{		Lowercase}', "");
Expect(1, 120779, '\P{^		Lowercase}', "");
Expect(0, 120780, '\p{		Lowercase}', "");
Expect(1, 120780, '\p{^		Lowercase}', "");
Expect(1, 120780, '\P{		Lowercase}', "");
Expect(0, 120780, '\P{^		Lowercase}', "");
Error('\p{_Is_Lowercase:=}');
Error('\P{_Is_Lowercase:=}');
Expect(1, 120779, '\p{islowercase}', "");
Expect(0, 120779, '\p{^islowercase}', "");
Expect(0, 120779, '\P{islowercase}', "");
Expect(1, 120779, '\P{^islowercase}', "");
Expect(0, 120780, '\p{islowercase}', "");
Expect(1, 120780, '\p{^islowercase}', "");
Expect(1, 120780, '\P{islowercase}', "");
Expect(0, 120780, '\P{^islowercase}', "");
Expect(1, 120779, '\p{--is_lowercase}', "");
Expect(0, 120779, '\p{^--is_lowercase}', "");
Expect(0, 120779, '\P{--is_lowercase}', "");
Expect(1, 120779, '\P{^--is_lowercase}', "");
Expect(0, 120780, '\p{--is_lowercase}', "");
Expect(1, 120780, '\p{^--is_lowercase}', "");
Expect(1, 120780, '\P{--is_lowercase}', "");
Expect(0, 120780, '\P{^--is_lowercase}', "");
Error('\p{/a/	 Lowercase_Letter}');
Error('\P{/a/	 Lowercase_Letter}');
Expect(1, 120779, '\p{lowercaseletter}', "");
Expect(0, 120779, '\p{^lowercaseletter}', "");
Expect(0, 120779, '\P{lowercaseletter}', "");
Expect(1, 120779, '\P{^lowercaseletter}', "");
Expect(0, 120780, '\p{lowercaseletter}', "");
Expect(1, 120780, '\p{^lowercaseletter}', "");
Expect(1, 120780, '\P{lowercaseletter}', "");
Expect(0, 120780, '\P{^lowercaseletter}', "");
Expect(1, 120779, '\p{	Lowercase_Letter}', "");
Expect(0, 120779, '\p{^	Lowercase_Letter}', "");
Expect(0, 120779, '\P{	Lowercase_Letter}', "");
Expect(1, 120779, '\P{^	Lowercase_Letter}', "");
Expect(0, 120780, '\p{	Lowercase_Letter}', "");
Expect(1, 120780, '\p{^	Lowercase_Letter}', "");
Expect(1, 120780, '\P{	Lowercase_Letter}', "");
Expect(0, 120780, '\P{^	Lowercase_Letter}', "");
Error('\p{_	is_Lowercase_Letter:=}');
Error('\P{_	is_Lowercase_Letter:=}');
Expect(1, 120779, '\p{islowercaseletter}', "");
Expect(0, 120779, '\p{^islowercaseletter}', "");
Expect(0, 120779, '\P{islowercaseletter}', "");
Expect(1, 120779, '\P{^islowercaseletter}', "");
Expect(0, 120780, '\p{islowercaseletter}', "");
Expect(1, 120780, '\p{^islowercaseletter}', "");
Expect(1, 120780, '\P{islowercaseletter}', "");
Expect(0, 120780, '\P{^islowercaseletter}', "");
Expect(1, 120779, '\p{ -Is_lowercase_Letter}', "");
Expect(0, 120779, '\p{^ -Is_lowercase_Letter}', "");
Expect(0, 120779, '\P{ -Is_lowercase_Letter}', "");
Expect(1, 120779, '\P{^ -Is_lowercase_Letter}', "");
Expect(0, 120780, '\p{ -Is_lowercase_Letter}', "");
Expect(1, 120780, '\p{^ -Is_lowercase_Letter}', "");
Expect(1, 120780, '\P{ -Is_lowercase_Letter}', "");
Expect(0, 120780, '\P{^ -Is_lowercase_Letter}', "");
Error('\p{/a/_	ll}');
Error('\P{/a/_	ll}');
Expect(1, 120779, '\p{ll}', "");
Expect(0, 120779, '\p{^ll}', "");
Expect(0, 120779, '\P{ll}', "");
Expect(1, 120779, '\P{^ll}', "");
Expect(0, 120780, '\p{ll}', "");
Expect(1, 120780, '\p{^ll}', "");
Expect(1, 120780, '\P{ll}', "");
Expect(0, 120780, '\P{^ll}', "");
Expect(1, 120779, '\p{	_ll}', "");
Expect(0, 120779, '\p{^	_ll}', "");
Expect(0, 120779, '\P{	_ll}', "");
Expect(1, 120779, '\P{^	_ll}', "");
Expect(0, 120780, '\p{	_ll}', "");
Expect(1, 120780, '\p{^	_ll}', "");
Expect(1, 120780, '\P{	_ll}', "");
Expect(0, 120780, '\P{^	_ll}', "");
Error('\p{ 	IS_LL:=}');
Error('\P{ 	IS_LL:=}');
Expect(1, 120779, '\p{isll}', "");
Expect(0, 120779, '\p{^isll}', "");
Expect(0, 120779, '\P{isll}', "");
Expect(1, 120779, '\P{^isll}', "");
Expect(0, 120780, '\p{isll}', "");
Expect(1, 120780, '\p{^isll}', "");
Expect(1, 120780, '\P{isll}', "");
Expect(0, 120780, '\P{^isll}', "");
Expect(1, 120779, '\p{-_Is_Ll}', "");
Expect(0, 120779, '\p{^-_Is_Ll}', "");
Expect(0, 120779, '\P{-_Is_Ll}', "");
Expect(1, 120779, '\P{^-_Is_Ll}', "");
Expect(0, 120780, '\p{-_Is_Ll}', "");
Expect(1, 120780, '\p{^-_Is_Ll}', "");
Expect(1, 120780, '\P{-_Is_Ll}', "");
Expect(0, 120780, '\P{^-_Is_Ll}', "");
Error('\p{/a/		Lycian}');
Error('\P{/a/		Lycian}');
Expect(1, 66204, '\p{lycian}', "");
Expect(0, 66204, '\p{^lycian}', "");
Expect(0, 66204, '\P{lycian}', "");
Expect(1, 66204, '\P{^lycian}', "");
Expect(0, 66205, '\p{lycian}', "");
Expect(1, 66205, '\p{^lycian}', "");
Expect(1, 66205, '\P{lycian}', "");
Expect(0, 66205, '\P{^lycian}', "");
Expect(1, 66204, '\p{-Lycian}', "");
Expect(0, 66204, '\p{^-Lycian}', "");
Expect(0, 66204, '\P{-Lycian}', "");
Expect(1, 66204, '\P{^-Lycian}', "");
Expect(0, 66205, '\p{-Lycian}', "");
Expect(1, 66205, '\p{^-Lycian}', "");
Expect(1, 66205, '\P{-Lycian}', "");
Expect(0, 66205, '\P{^-Lycian}', "");
Error('\p{/a/Is_lycian}');
Error('\P{/a/Is_lycian}');
Expect(1, 66204, '\p{islycian}', "");
Expect(0, 66204, '\p{^islycian}', "");
Expect(0, 66204, '\P{islycian}', "");
Expect(1, 66204, '\P{^islycian}', "");
Expect(0, 66205, '\p{islycian}', "");
Expect(1, 66205, '\p{^islycian}', "");
Expect(1, 66205, '\P{islycian}', "");
Expect(0, 66205, '\P{^islycian}', "");
Expect(1, 66204, '\p{	Is_Lycian}', "");
Expect(0, 66204, '\p{^	Is_Lycian}', "");
Expect(0, 66204, '\P{	Is_Lycian}', "");
Expect(1, 66204, '\P{^	Is_Lycian}', "");
Expect(0, 66205, '\p{	Is_Lycian}', "");
Expect(1, 66205, '\p{^	Is_Lycian}', "");
Expect(1, 66205, '\P{	Is_Lycian}', "");
Expect(0, 66205, '\P{^	Is_Lycian}', "");
Error('\p{-/a/LYCI}');
Error('\P{-/a/LYCI}');
Expect(1, 66204, '\p{lyci}', "");
Expect(0, 66204, '\p{^lyci}', "");
Expect(0, 66204, '\P{lyci}', "");
Expect(1, 66204, '\P{^lyci}', "");
Expect(0, 66205, '\p{lyci}', "");
Expect(1, 66205, '\p{^lyci}', "");
Expect(1, 66205, '\P{lyci}', "");
Expect(0, 66205, '\P{^lyci}', "");
Expect(1, 66204, '\p{	 Lyci}', "");
Expect(0, 66204, '\p{^	 Lyci}', "");
Expect(0, 66204, '\P{	 Lyci}', "");
Expect(1, 66204, '\P{^	 Lyci}', "");
Expect(0, 66205, '\p{	 Lyci}', "");
Expect(1, 66205, '\p{^	 Lyci}', "");
Expect(1, 66205, '\P{	 Lyci}', "");
Expect(0, 66205, '\P{^	 Lyci}', "");
Error('\p{:=IS_lyci}');
Error('\P{:=IS_lyci}');
Expect(1, 66204, '\p{islyci}', "");
Expect(0, 66204, '\p{^islyci}', "");
Expect(0, 66204, '\P{islyci}', "");
Expect(1, 66204, '\P{^islyci}', "");
Expect(0, 66205, '\p{islyci}', "");
Expect(1, 66205, '\p{^islyci}', "");
Expect(1, 66205, '\P{islyci}', "");
Expect(0, 66205, '\P{^islyci}', "");
Expect(1, 66204, '\p{ _Is_Lyci}', "");
Expect(0, 66204, '\p{^ _Is_Lyci}', "");
Expect(0, 66204, '\P{ _Is_Lyci}', "");
Expect(1, 66204, '\P{^ _Is_Lyci}', "");
Expect(0, 66205, '\p{ _Is_Lyci}', "");
Expect(1, 66205, '\p{^ _Is_Lyci}', "");
Expect(1, 66205, '\P{ _Is_Lyci}', "");
Expect(0, 66205, '\P{^ _Is_Lyci}', "");
Error('\p{:=Lydian}');
Error('\P{:=Lydian}');
Expect(1, 67903, '\p{lydian}', "");
Expect(0, 67903, '\p{^lydian}', "");
Expect(0, 67903, '\P{lydian}', "");
Expect(1, 67903, '\P{^lydian}', "");
Expect(0, 67904, '\p{lydian}', "");
Expect(1, 67904, '\p{^lydian}', "");
Expect(1, 67904, '\P{lydian}', "");
Expect(0, 67904, '\P{^lydian}', "");
Expect(1, 67903, '\p{	-Lydian}', "");
Expect(0, 67903, '\p{^	-Lydian}', "");
Expect(0, 67903, '\P{	-Lydian}', "");
Expect(1, 67903, '\P{^	-Lydian}', "");
Expect(0, 67904, '\p{	-Lydian}', "");
Expect(1, 67904, '\p{^	-Lydian}', "");
Expect(1, 67904, '\P{	-Lydian}', "");
Expect(0, 67904, '\P{^	-Lydian}', "");
Error('\p{/a/_ Is_LYDIAN}');
Error('\P{/a/_ Is_LYDIAN}');
Expect(1, 67903, '\p{islydian}', "");
Expect(0, 67903, '\p{^islydian}', "");
Expect(0, 67903, '\P{islydian}', "");
Expect(1, 67903, '\P{^islydian}', "");
Expect(0, 67904, '\p{islydian}', "");
Expect(1, 67904, '\p{^islydian}', "");
Expect(1, 67904, '\P{islydian}', "");
Expect(0, 67904, '\P{^islydian}', "");
Expect(1, 67903, '\p{ IS_Lydian}', "");
Expect(0, 67903, '\p{^ IS_Lydian}', "");
Expect(0, 67903, '\P{ IS_Lydian}', "");
Expect(1, 67903, '\P{^ IS_Lydian}', "");
Expect(0, 67904, '\p{ IS_Lydian}', "");
Expect(1, 67904, '\p{^ IS_Lydian}', "");
Expect(1, 67904, '\P{ IS_Lydian}', "");
Expect(0, 67904, '\P{^ IS_Lydian}', "");
Error('\p{:=		LYDI}');
Error('\P{:=		LYDI}');
Expect(1, 67903, '\p{lydi}', "");
Expect(0, 67903, '\p{^lydi}', "");
Expect(0, 67903, '\P{lydi}', "");
Expect(1, 67903, '\P{^lydi}', "");
Expect(0, 67904, '\p{lydi}', "");
Expect(1, 67904, '\p{^lydi}', "");
Expect(1, 67904, '\P{lydi}', "");
Expect(0, 67904, '\P{^lydi}', "");
Expect(1, 67903, '\p{ 	Lydi}', "");
Expect(0, 67903, '\p{^ 	Lydi}', "");
Expect(0, 67903, '\P{ 	Lydi}', "");
Expect(1, 67903, '\P{^ 	Lydi}', "");
Expect(0, 67904, '\p{ 	Lydi}', "");
Expect(1, 67904, '\p{^ 	Lydi}', "");
Expect(1, 67904, '\P{ 	Lydi}', "");
Expect(0, 67904, '\P{^ 	Lydi}', "");
Error('\p{:=_Is_Lydi}');
Error('\P{:=_Is_Lydi}');
Expect(1, 67903, '\p{islydi}', "");
Expect(0, 67903, '\p{^islydi}', "");
Expect(0, 67903, '\P{islydi}', "");
Expect(1, 67903, '\P{^islydi}', "");
Expect(0, 67904, '\p{islydi}', "");
Expect(1, 67904, '\p{^islydi}', "");
Expect(1, 67904, '\P{islydi}', "");
Expect(0, 67904, '\P{^islydi}', "");
Expect(1, 67903, '\p{ -Is_Lydi}', "");
Expect(0, 67903, '\p{^ -Is_Lydi}', "");
Expect(0, 67903, '\P{ -Is_Lydi}', "");
Expect(1, 67903, '\P{^ -Is_Lydi}', "");
Expect(0, 67904, '\p{ -Is_Lydi}', "");
Expect(1, 67904, '\p{^ -Is_Lydi}', "");
Expect(1, 67904, '\P{ -Is_Lydi}', "");
Expect(0, 67904, '\P{^ -Is_Lydi}', "");
Error('\p{:=Mahjong_tiles}');
Error('\P{:=Mahjong_tiles}');
Expect(1, 127023, '\p{mahjongtiles}', "");
Expect(0, 127023, '\p{^mahjongtiles}', "");
Expect(0, 127023, '\P{mahjongtiles}', "");
Expect(1, 127023, '\P{^mahjongtiles}', "");
Expect(0, 127024, '\p{mahjongtiles}', "");
Expect(1, 127024, '\p{^mahjongtiles}', "");
Expect(1, 127024, '\P{mahjongtiles}', "");
Expect(0, 127024, '\P{^mahjongtiles}', "");
Expect(1, 127023, '\p{ -mahjong_Tiles}', "");
Expect(0, 127023, '\p{^ -mahjong_Tiles}', "");
Expect(0, 127023, '\P{ -mahjong_Tiles}', "");
Expect(1, 127023, '\P{^ -mahjong_Tiles}', "");
Expect(0, 127024, '\p{ -mahjong_Tiles}', "");
Expect(1, 127024, '\p{^ -mahjong_Tiles}', "");
Expect(1, 127024, '\P{ -mahjong_Tiles}', "");
Expect(0, 127024, '\P{^ -mahjong_Tiles}', "");
Error('\p{/a/is_MAHJONG_Tiles}');
Error('\P{/a/is_MAHJONG_Tiles}');
Expect(1, 127023, '\p{ismahjongtiles}', "");
Expect(0, 127023, '\p{^ismahjongtiles}', "");
Expect(0, 127023, '\P{ismahjongtiles}', "");
Expect(1, 127023, '\P{^ismahjongtiles}', "");
Expect(0, 127024, '\p{ismahjongtiles}', "");
Expect(1, 127024, '\p{^ismahjongtiles}', "");
Expect(1, 127024, '\P{ismahjongtiles}', "");
Expect(0, 127024, '\P{^ismahjongtiles}', "");
Expect(1, 127023, '\p{_-Is_MAHJONG_TILES}', "");
Expect(0, 127023, '\p{^_-Is_MAHJONG_TILES}', "");
Expect(0, 127023, '\P{_-Is_MAHJONG_TILES}', "");
Expect(1, 127023, '\P{^_-Is_MAHJONG_TILES}', "");
Expect(0, 127024, '\p{_-Is_MAHJONG_TILES}', "");
Expect(1, 127024, '\p{^_-Is_MAHJONG_TILES}', "");
Expect(1, 127024, '\P{_-Is_MAHJONG_TILES}', "");
Expect(0, 127024, '\P{^_-Is_MAHJONG_TILES}', "");
Error('\p{_	In_Mahjong_Tiles/a/}');
Error('\P{_	In_Mahjong_Tiles/a/}');
Expect(1, 127023, '\p{inmahjongtiles}', "");
Expect(0, 127023, '\p{^inmahjongtiles}', "");
Expect(0, 127023, '\P{inmahjongtiles}', "");
Expect(1, 127023, '\P{^inmahjongtiles}', "");
Expect(0, 127024, '\p{inmahjongtiles}', "");
Expect(1, 127024, '\p{^inmahjongtiles}', "");
Expect(1, 127024, '\P{inmahjongtiles}', "");
Expect(0, 127024, '\P{^inmahjongtiles}', "");
Expect(1, 127023, '\p{ 	In_Mahjong_Tiles}', "");
Expect(0, 127023, '\p{^ 	In_Mahjong_Tiles}', "");
Expect(0, 127023, '\P{ 	In_Mahjong_Tiles}', "");
Expect(1, 127023, '\P{^ 	In_Mahjong_Tiles}', "");
Expect(0, 127024, '\p{ 	In_Mahjong_Tiles}', "");
Expect(1, 127024, '\p{^ 	In_Mahjong_Tiles}', "");
Expect(1, 127024, '\P{ 	In_Mahjong_Tiles}', "");
Expect(0, 127024, '\P{^ 	In_Mahjong_Tiles}', "");
Error('\p{-/a/mahjong}');
Error('\P{-/a/mahjong}');
Expect(1, 127023, '\p{mahjong}', "");
Expect(0, 127023, '\p{^mahjong}', "");
Expect(0, 127023, '\P{mahjong}', "");
Expect(1, 127023, '\P{^mahjong}', "");
Expect(0, 127024, '\p{mahjong}', "");
Expect(1, 127024, '\p{^mahjong}', "");
Expect(1, 127024, '\P{mahjong}', "");
Expect(0, 127024, '\P{^mahjong}', "");
Expect(1, 127023, '\p{_ Mahjong}', "");
Expect(0, 127023, '\p{^_ Mahjong}', "");
Expect(0, 127023, '\P{_ Mahjong}', "");
Expect(1, 127023, '\P{^_ Mahjong}', "");
Expect(0, 127024, '\p{_ Mahjong}', "");
Expect(1, 127024, '\p{^_ Mahjong}', "");
Expect(1, 127024, '\P{_ Mahjong}', "");
Expect(0, 127024, '\P{^_ Mahjong}', "");
Error('\p{/a/ IS_Mahjong}');
Error('\P{/a/ IS_Mahjong}');
Expect(1, 127023, '\p{ismahjong}', "");
Expect(0, 127023, '\p{^ismahjong}', "");
Expect(0, 127023, '\P{ismahjong}', "");
Expect(1, 127023, '\P{^ismahjong}', "");
Expect(0, 127024, '\p{ismahjong}', "");
Expect(1, 127024, '\p{^ismahjong}', "");
Expect(1, 127024, '\P{ismahjong}', "");
Expect(0, 127024, '\P{^ismahjong}', "");
Expect(1, 127023, '\p{_is_mahjong}', "");
Expect(0, 127023, '\p{^_is_mahjong}', "");
Expect(0, 127023, '\P{_is_mahjong}', "");
Expect(1, 127023, '\P{^_is_mahjong}', "");
Expect(0, 127024, '\p{_is_mahjong}', "");
Expect(1, 127024, '\p{^_is_mahjong}', "");
Expect(1, 127024, '\P{_is_mahjong}', "");
Expect(0, 127024, '\P{^_is_mahjong}', "");
Error('\p{-_in_Mahjong:=}');
Error('\P{-_in_Mahjong:=}');
Expect(1, 127023, '\p{inmahjong}', "");
Expect(0, 127023, '\p{^inmahjong}', "");
Expect(0, 127023, '\P{inmahjong}', "");
Expect(1, 127023, '\P{^inmahjong}', "");
Expect(0, 127024, '\p{inmahjong}', "");
Expect(1, 127024, '\p{^inmahjong}', "");
Expect(1, 127024, '\P{inmahjong}', "");
Expect(0, 127024, '\P{^inmahjong}', "");
Expect(1, 127023, '\p{	-In_MAHJONG}', "");
Expect(0, 127023, '\p{^	-In_MAHJONG}', "");
Expect(0, 127023, '\P{	-In_MAHJONG}', "");
Expect(1, 127023, '\P{^	-In_MAHJONG}', "");
Expect(0, 127024, '\p{	-In_MAHJONG}', "");
Expect(1, 127024, '\p{^	-In_MAHJONG}', "");
Expect(1, 127024, '\P{	-In_MAHJONG}', "");
Expect(0, 127024, '\P{^	-In_MAHJONG}', "");
Error('\p{:= _malayalam}');
Error('\P{:= _malayalam}');
Expect(1, 3455, '\p{malayalam}', "");
Expect(0, 3455, '\p{^malayalam}', "");
Expect(0, 3455, '\P{malayalam}', "");
Expect(1, 3455, '\P{^malayalam}', "");
Expect(0, 3456, '\p{malayalam}', "");
Expect(1, 3456, '\p{^malayalam}', "");
Expect(1, 3456, '\P{malayalam}', "");
Expect(0, 3456, '\P{^malayalam}', "");
Expect(1, 3455, '\p{_Malayalam}', "");
Expect(0, 3455, '\p{^_Malayalam}', "");
Expect(0, 3455, '\P{_Malayalam}', "");
Expect(1, 3455, '\P{^_Malayalam}', "");
Expect(0, 3456, '\p{_Malayalam}', "");
Expect(1, 3456, '\p{^_Malayalam}', "");
Expect(1, 3456, '\P{_Malayalam}', "");
Expect(0, 3456, '\P{^_Malayalam}', "");
Error('\p{-_Is_Malayalam/a/}');
Error('\P{-_Is_Malayalam/a/}');
Expect(1, 3455, '\p{ismalayalam}', "");
Expect(0, 3455, '\p{^ismalayalam}', "");
Expect(0, 3455, '\P{ismalayalam}', "");
Expect(1, 3455, '\P{^ismalayalam}', "");
Expect(0, 3456, '\p{ismalayalam}', "");
Expect(1, 3456, '\p{^ismalayalam}', "");
Expect(1, 3456, '\P{ismalayalam}', "");
Expect(0, 3456, '\P{^ismalayalam}', "");
Expect(1, 3455, '\p{ 	IS_MALAYALAM}', "");
Expect(0, 3455, '\p{^ 	IS_MALAYALAM}', "");
Expect(0, 3455, '\P{ 	IS_MALAYALAM}', "");
Expect(1, 3455, '\P{^ 	IS_MALAYALAM}', "");
Expect(0, 3456, '\p{ 	IS_MALAYALAM}', "");
Expect(1, 3456, '\p{^ 	IS_MALAYALAM}', "");
Expect(1, 3456, '\P{ 	IS_MALAYALAM}', "");
Expect(0, 3456, '\P{^ 	IS_MALAYALAM}', "");
Error('\p{_:=Mlym}');
Error('\P{_:=Mlym}');
Expect(1, 3455, '\p{mlym}', "");
Expect(0, 3455, '\p{^mlym}', "");
Expect(0, 3455, '\P{mlym}', "");
Expect(1, 3455, '\P{^mlym}', "");
Expect(0, 3456, '\p{mlym}', "");
Expect(1, 3456, '\p{^mlym}', "");
Expect(1, 3456, '\P{mlym}', "");
Expect(0, 3456, '\P{^mlym}', "");
Expect(1, 3455, '\p{_ mlym}', "");
Expect(0, 3455, '\p{^_ mlym}', "");
Expect(0, 3455, '\P{_ mlym}', "");
Expect(1, 3455, '\P{^_ mlym}', "");
Expect(0, 3456, '\p{_ mlym}', "");
Expect(1, 3456, '\p{^_ mlym}', "");
Expect(1, 3456, '\P{_ mlym}', "");
Expect(0, 3456, '\P{^_ mlym}', "");
Error('\p{-:=IS_Mlym}');
Error('\P{-:=IS_Mlym}');
Expect(1, 3455, '\p{ismlym}', "");
Expect(0, 3455, '\p{^ismlym}', "");
Expect(0, 3455, '\P{ismlym}', "");
Expect(1, 3455, '\P{^ismlym}', "");
Expect(0, 3456, '\p{ismlym}', "");
Expect(1, 3456, '\p{^ismlym}', "");
Expect(1, 3456, '\P{ismlym}', "");
Expect(0, 3456, '\P{^ismlym}', "");
Expect(1, 3455, '\p{ -Is_mlym}', "");
Expect(0, 3455, '\p{^ -Is_mlym}', "");
Expect(0, 3455, '\P{ -Is_mlym}', "");
Expect(1, 3455, '\P{^ -Is_mlym}', "");
Expect(0, 3456, '\p{ -Is_mlym}', "");
Expect(1, 3456, '\p{^ -Is_mlym}', "");
Expect(1, 3456, '\P{ -Is_mlym}', "");
Expect(0, 3456, '\P{^ -Is_mlym}', "");
Error('\p{/a/-Mandaic}');
Error('\P{/a/-Mandaic}');
Expect(1, 2142, '\p{mandaic}', "");
Expect(0, 2142, '\p{^mandaic}', "");
Expect(0, 2142, '\P{mandaic}', "");
Expect(1, 2142, '\P{^mandaic}', "");
Expect(0, 2143, '\p{mandaic}', "");
Expect(1, 2143, '\p{^mandaic}', "");
Expect(1, 2143, '\P{mandaic}', "");
Expect(0, 2143, '\P{^mandaic}', "");
Expect(1, 2142, '\p{_-Mandaic}', "");
Expect(0, 2142, '\p{^_-Mandaic}', "");
Expect(0, 2142, '\P{_-Mandaic}', "");
Expect(1, 2142, '\P{^_-Mandaic}', "");
Expect(0, 2143, '\p{_-Mandaic}', "");
Expect(1, 2143, '\p{^_-Mandaic}', "");
Expect(1, 2143, '\P{_-Mandaic}', "");
Expect(0, 2143, '\P{^_-Mandaic}', "");
Error('\p{	/a/Is_Mandaic}');
Error('\P{	/a/Is_Mandaic}');
Expect(1, 2142, '\p{ismandaic}', "");
Expect(0, 2142, '\p{^ismandaic}', "");
Expect(0, 2142, '\P{ismandaic}', "");
Expect(1, 2142, '\P{^ismandaic}', "");
Expect(0, 2143, '\p{ismandaic}', "");
Expect(1, 2143, '\p{^ismandaic}', "");
Expect(1, 2143, '\P{ismandaic}', "");
Expect(0, 2143, '\P{^ismandaic}', "");
Expect(1, 2142, '\p{		Is_Mandaic}', "");
Expect(0, 2142, '\p{^		Is_Mandaic}', "");
Expect(0, 2142, '\P{		Is_Mandaic}', "");
Expect(1, 2142, '\P{^		Is_Mandaic}', "");
Expect(0, 2143, '\p{		Is_Mandaic}', "");
Expect(1, 2143, '\p{^		Is_Mandaic}', "");
Expect(1, 2143, '\P{		Is_Mandaic}', "");
Expect(0, 2143, '\P{^		Is_Mandaic}', "");
Error('\p{/a/  Mand}');
Error('\P{/a/  Mand}');
Expect(1, 2142, '\p{mand}', "");
Expect(0, 2142, '\p{^mand}', "");
Expect(0, 2142, '\P{mand}', "");
Expect(1, 2142, '\P{^mand}', "");
Expect(0, 2143, '\p{mand}', "");
Expect(1, 2143, '\p{^mand}', "");
Expect(1, 2143, '\P{mand}', "");
Expect(0, 2143, '\P{^mand}', "");
Expect(1, 2142, '\p{ -mand}', "");
Expect(0, 2142, '\p{^ -mand}', "");
Expect(0, 2142, '\P{ -mand}', "");
Expect(1, 2142, '\P{^ -mand}', "");
Expect(0, 2143, '\p{ -mand}', "");
Expect(1, 2143, '\p{^ -mand}', "");
Expect(1, 2143, '\P{ -mand}', "");
Expect(0, 2143, '\P{^ -mand}', "");
Error('\p{	/a/IS_mand}');
Error('\P{	/a/IS_mand}');
Expect(1, 2142, '\p{ismand}', "");
Expect(0, 2142, '\p{^ismand}', "");
Expect(0, 2142, '\P{ismand}', "");
Expect(1, 2142, '\P{^ismand}', "");
Expect(0, 2143, '\p{ismand}', "");
Expect(1, 2143, '\p{^ismand}', "");
Expect(1, 2143, '\P{ismand}', "");
Expect(0, 2143, '\P{^ismand}', "");
Expect(1, 2142, '\p{_	is_MAND}', "");
Expect(0, 2142, '\p{^_	is_MAND}', "");
Expect(0, 2142, '\P{_	is_MAND}', "");
Expect(1, 2142, '\P{^_	is_MAND}', "");
Expect(0, 2143, '\p{_	is_MAND}', "");
Expect(1, 2143, '\p{^_	is_MAND}', "");
Expect(1, 2143, '\P{_	is_MAND}', "");
Expect(0, 2143, '\P{^_	is_MAND}', "");
Error('\p{ _MARK/a/}');
Error('\P{ _MARK/a/}');
Expect(1, 917999, '\p{mark}', "");
Expect(0, 917999, '\p{^mark}', "");
Expect(0, 917999, '\P{mark}', "");
Expect(1, 917999, '\P{^mark}', "");
Expect(0, 918000, '\p{mark}', "");
Expect(1, 918000, '\p{^mark}', "");
Expect(1, 918000, '\P{mark}', "");
Expect(0, 918000, '\P{^mark}', "");
Expect(1, 917999, '\p{ _Mark}', "");
Expect(0, 917999, '\p{^ _Mark}', "");
Expect(0, 917999, '\P{ _Mark}', "");
Expect(1, 917999, '\P{^ _Mark}', "");
Expect(0, 918000, '\p{ _Mark}', "");
Expect(1, 918000, '\p{^ _Mark}', "");
Expect(1, 918000, '\P{ _Mark}', "");
Expect(0, 918000, '\P{^ _Mark}', "");
Error('\p{/a/_	Is_mark}');
Error('\P{/a/_	Is_mark}');
Expect(1, 917999, '\p{ismark}', "");
Expect(0, 917999, '\p{^ismark}', "");
Expect(0, 917999, '\P{ismark}', "");
Expect(1, 917999, '\P{^ismark}', "");
Expect(0, 918000, '\p{ismark}', "");
Expect(1, 918000, '\p{^ismark}', "");
Expect(1, 918000, '\P{ismark}', "");
Expect(0, 918000, '\P{^ismark}', "");
Expect(1, 917999, '\p{ IS_MARK}', "");
Expect(0, 917999, '\p{^ IS_MARK}', "");
Expect(0, 917999, '\P{ IS_MARK}', "");
Expect(1, 917999, '\P{^ IS_MARK}', "");
Expect(0, 918000, '\p{ IS_MARK}', "");
Expect(1, 918000, '\p{^ IS_MARK}', "");
Expect(1, 918000, '\P{ IS_MARK}', "");
Expect(0, 918000, '\P{^ IS_MARK}', "");
Error('\p{/a/-M}');
Error('\P{/a/-M}');
Expect(1, 917999, '\p{m}', "");
Expect(0, 917999, '\p{^m}', "");
Expect(0, 917999, '\P{m}', "");
Expect(1, 917999, '\P{^m}', "");
Expect(0, 918000, '\p{m}', "");
Expect(1, 918000, '\p{^m}', "");
Expect(1, 918000, '\P{m}', "");
Expect(0, 918000, '\P{^m}', "");
Expect(1, 917999, '\p{ M}', "");
Expect(0, 917999, '\p{^ M}', "");
Expect(0, 917999, '\P{ M}', "");
Expect(1, 917999, '\P{^ M}', "");
Expect(0, 918000, '\p{ M}', "");
Expect(1, 918000, '\p{^ M}', "");
Expect(1, 918000, '\P{ M}', "");
Expect(0, 918000, '\P{^ M}', "");
Error('\p{--Is_M:=}');
Error('\P{--Is_M:=}');
Expect(1, 917999, '\p{ism}', "");
Expect(0, 917999, '\p{^ism}', "");
Expect(0, 917999, '\P{ism}', "");
Expect(1, 917999, '\P{^ism}', "");
Expect(0, 918000, '\p{ism}', "");
Expect(1, 918000, '\p{^ism}', "");
Expect(1, 918000, '\P{ism}', "");
Expect(0, 918000, '\P{^ism}', "");
Expect(1, 917999, '\p{ _Is_m}', "");
Expect(0, 917999, '\p{^ _Is_m}', "");
Expect(0, 917999, '\P{ _Is_m}', "");
Expect(1, 917999, '\P{^ _Is_m}', "");
Expect(0, 918000, '\p{ _Is_m}', "");
Expect(1, 918000, '\p{^ _Is_m}', "");
Expect(1, 918000, '\P{ _Is_m}', "");
Expect(0, 918000, '\P{^ _Is_m}', "");
Error('\p{/a/-_Combining_Mark}');
Error('\P{/a/-_Combining_Mark}');
Expect(1, 917999, '\p{combiningmark}', "");
Expect(0, 917999, '\p{^combiningmark}', "");
Expect(0, 917999, '\P{combiningmark}', "");
Expect(1, 917999, '\P{^combiningmark}', "");
Expect(0, 918000, '\p{combiningmark}', "");
Expect(1, 918000, '\p{^combiningmark}', "");
Expect(1, 918000, '\P{combiningmark}', "");
Expect(0, 918000, '\P{^combiningmark}', "");
Expect(1, 917999, '\p{ -Combining_Mark}', "");
Expect(0, 917999, '\p{^ -Combining_Mark}', "");
Expect(0, 917999, '\P{ -Combining_Mark}', "");
Expect(1, 917999, '\P{^ -Combining_Mark}', "");
Expect(0, 918000, '\p{ -Combining_Mark}', "");
Expect(1, 918000, '\p{^ -Combining_Mark}', "");
Expect(1, 918000, '\P{ -Combining_Mark}', "");
Expect(0, 918000, '\P{^ -Combining_Mark}', "");
Error('\p{:=	 Is_combining_Mark}');
Error('\P{:=	 Is_combining_Mark}');
Expect(1, 917999, '\p{iscombiningmark}', "");
Expect(0, 917999, '\p{^iscombiningmark}', "");
Expect(0, 917999, '\P{iscombiningmark}', "");
Expect(1, 917999, '\P{^iscombiningmark}', "");
Expect(0, 918000, '\p{iscombiningmark}', "");
Expect(1, 918000, '\p{^iscombiningmark}', "");
Expect(1, 918000, '\P{iscombiningmark}', "");
Expect(0, 918000, '\P{^iscombiningmark}', "");
Expect(1, 917999, '\p{__Is_combining_Mark}', "");
Expect(0, 917999, '\p{^__Is_combining_Mark}', "");
Expect(0, 917999, '\P{__Is_combining_Mark}', "");
Expect(1, 917999, '\P{^__Is_combining_Mark}', "");
Expect(0, 918000, '\p{__Is_combining_Mark}', "");
Expect(1, 918000, '\p{^__Is_combining_Mark}', "");
Expect(1, 918000, '\P{__Is_combining_Mark}', "");
Expect(0, 918000, '\P{^__Is_combining_Mark}', "");
Error('\p{ :=Math}');
Error('\P{ :=Math}');
Expect(1, 126705, '\p{math}', "");
Expect(0, 126705, '\p{^math}', "");
Expect(0, 126705, '\P{math}', "");
Expect(1, 126705, '\P{^math}', "");
Expect(0, 126706, '\p{math}', "");
Expect(1, 126706, '\p{^math}', "");
Expect(1, 126706, '\P{math}', "");
Expect(0, 126706, '\P{^math}', "");
Expect(1, 126705, '\p{Math}', "");
Expect(0, 126705, '\p{^Math}', "");
Expect(0, 126705, '\P{Math}', "");
Expect(1, 126705, '\P{^Math}', "");
Expect(0, 126706, '\p{Math}', "");
Expect(1, 126706, '\p{^Math}', "");
Expect(1, 126706, '\P{Math}', "");
Expect(0, 126706, '\P{^Math}', "");
Error('\p{:=  Is_Math}');
Error('\P{:=  Is_Math}');
Expect(1, 126705, '\p{ismath}', "");
Expect(0, 126705, '\p{^ismath}', "");
Expect(0, 126705, '\P{ismath}', "");
Expect(1, 126705, '\P{^ismath}', "");
Expect(0, 126706, '\p{ismath}', "");
Expect(1, 126706, '\p{^ismath}', "");
Expect(1, 126706, '\P{ismath}', "");
Expect(0, 126706, '\P{^ismath}', "");
Expect(1, 126705, '\p{-is_Math}', "");
Expect(0, 126705, '\p{^-is_Math}', "");
Expect(0, 126705, '\P{-is_Math}', "");
Expect(1, 126705, '\P{^-is_Math}', "");
Expect(0, 126706, '\p{-is_Math}', "");
Expect(1, 126706, '\p{^-is_Math}', "");
Expect(1, 126706, '\P{-is_Math}', "");
Expect(0, 126706, '\P{^-is_Math}', "");
Error('\p{  MATH_SYMBOL/a/}');
Error('\P{  MATH_SYMBOL/a/}');
Expect(1, 126705, '\p{mathsymbol}', "");
Expect(0, 126705, '\p{^mathsymbol}', "");
Expect(0, 126705, '\P{mathsymbol}', "");
Expect(1, 126705, '\P{^mathsymbol}', "");
Expect(0, 126706, '\p{mathsymbol}', "");
Expect(1, 126706, '\p{^mathsymbol}', "");
Expect(1, 126706, '\P{mathsymbol}', "");
Expect(0, 126706, '\P{^mathsymbol}', "");
Expect(1, 126705, '\p{-Math_Symbol}', "");
Expect(0, 126705, '\p{^-Math_Symbol}', "");
Expect(0, 126705, '\P{-Math_Symbol}', "");
Expect(1, 126705, '\P{^-Math_Symbol}', "");
Expect(0, 126706, '\p{-Math_Symbol}', "");
Expect(1, 126706, '\p{^-Math_Symbol}', "");
Expect(1, 126706, '\P{-Math_Symbol}', "");
Expect(0, 126706, '\P{^-Math_Symbol}', "");
Error('\p{/a/_IS_MATH_symbol}');
Error('\P{/a/_IS_MATH_symbol}');
Expect(1, 126705, '\p{ismathsymbol}', "");
Expect(0, 126705, '\p{^ismathsymbol}', "");
Expect(0, 126705, '\P{ismathsymbol}', "");
Expect(1, 126705, '\P{^ismathsymbol}', "");
Expect(0, 126706, '\p{ismathsymbol}', "");
Expect(1, 126706, '\p{^ismathsymbol}', "");
Expect(1, 126706, '\P{ismathsymbol}', "");
Expect(0, 126706, '\P{^ismathsymbol}', "");
Expect(1, 126705, '\p{_ Is_MATH_SYMBOL}', "");
Expect(0, 126705, '\p{^_ Is_MATH_SYMBOL}', "");
Expect(0, 126705, '\P{_ Is_MATH_SYMBOL}', "");
Expect(1, 126705, '\P{^_ Is_MATH_SYMBOL}', "");
Expect(0, 126706, '\p{_ Is_MATH_SYMBOL}', "");
Expect(1, 126706, '\p{^_ Is_MATH_SYMBOL}', "");
Expect(1, 126706, '\P{_ Is_MATH_SYMBOL}', "");
Expect(0, 126706, '\P{^_ Is_MATH_SYMBOL}', "");
Error('\p{/a/sm}');
Error('\P{/a/sm}');
Expect(1, 126705, '\p{sm}', "");
Expect(0, 126705, '\p{^sm}', "");
Expect(0, 126705, '\P{sm}', "");
Expect(1, 126705, '\P{^sm}', "");
Expect(0, 126706, '\p{sm}', "");
Expect(1, 126706, '\p{^sm}', "");
Expect(1, 126706, '\P{sm}', "");
Expect(0, 126706, '\P{^sm}', "");
Expect(1, 126705, '\p{	 sm}', "");
Expect(0, 126705, '\p{^	 sm}', "");
Expect(0, 126705, '\P{	 sm}', "");
Expect(1, 126705, '\P{^	 sm}', "");
Expect(0, 126706, '\p{	 sm}', "");
Expect(1, 126706, '\p{^	 sm}', "");
Expect(1, 126706, '\P{	 sm}', "");
Expect(0, 126706, '\P{^	 sm}', "");
Error('\p{  Is_Sm:=}');
Error('\P{  Is_Sm:=}');
Expect(1, 126705, '\p{issm}', "");
Expect(0, 126705, '\p{^issm}', "");
Expect(0, 126705, '\P{issm}', "");
Expect(1, 126705, '\P{^issm}', "");
Expect(0, 126706, '\p{issm}', "");
Expect(1, 126706, '\p{^issm}', "");
Expect(1, 126706, '\P{issm}', "");
Expect(0, 126706, '\P{^issm}', "");
Expect(1, 126705, '\p{	_is_Sm}', "");
Expect(0, 126705, '\p{^	_is_Sm}', "");
Expect(0, 126705, '\P{	_is_Sm}', "");
Expect(1, 126705, '\P{^	_is_Sm}', "");
Expect(0, 126706, '\p{	_is_Sm}', "");
Expect(1, 126706, '\p{^	_is_Sm}', "");
Expect(1, 126706, '\P{	_is_Sm}', "");
Expect(0, 126706, '\P{^	_is_Sm}', "");
Error('\p{:=- Mathematical_Alphanumeric_Symbols}');
Error('\P{:=- Mathematical_Alphanumeric_Symbols}');
Expect(1, 120831, '\p{mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^mathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^mathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{mathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^mathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{_mathematical_alphanumeric_Symbols}', "");
Expect(0, 120831, '\p{^_mathematical_alphanumeric_Symbols}', "");
Expect(0, 120831, '\P{_mathematical_alphanumeric_Symbols}', "");
Expect(1, 120831, '\P{^_mathematical_alphanumeric_Symbols}', "");
Expect(0, 120832, '\p{_mathematical_alphanumeric_Symbols}', "");
Expect(1, 120832, '\p{^_mathematical_alphanumeric_Symbols}', "");
Expect(1, 120832, '\P{_mathematical_alphanumeric_Symbols}', "");
Expect(0, 120832, '\P{^_mathematical_alphanumeric_Symbols}', "");
Error('\p{_	Is_Mathematical_Alphanumeric_Symbols:=}');
Error('\P{_	Is_Mathematical_Alphanumeric_Symbols:=}');
Expect(1, 120831, '\p{ismathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^ismathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{ismathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^ismathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{ismathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^ismathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{ismathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^ismathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120831, '\p{^_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120831, '\P{_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(1, 120831, '\P{^_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120832, '\p{_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(1, 120832, '\p{^_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(1, 120832, '\P{_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120832, '\P{^_ Is_MATHEMATICAL_alphanumeric_Symbols}', "");
Error('\p{	_In_Mathematical_ALPHANUMERIC_SYMBOLS:=}');
Error('\P{	_In_Mathematical_ALPHANUMERIC_SYMBOLS:=}');
Expect(1, 120831, '\p{inmathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\p{^inmathematicalalphanumericsymbols}', "");
Expect(0, 120831, '\P{inmathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\P{^inmathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\p{inmathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\p{^inmathematicalalphanumericsymbols}', "");
Expect(1, 120832, '\P{inmathematicalalphanumericsymbols}', "");
Expect(0, 120832, '\P{^inmathematicalalphanumericsymbols}', "");
Expect(1, 120831, '\p{ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120831, '\p{^ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120831, '\P{ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(1, 120831, '\P{^ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120832, '\p{ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(1, 120832, '\p{^ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(1, 120832, '\P{ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Expect(0, 120832, '\P{^ -In_MATHEMATICAL_alphanumeric_Symbols}', "");
Error('\p{--MATH_Alphanum:=}');
Error('\P{--MATH_Alphanum:=}');
Expect(1, 120831, '\p{mathalphanum}', "");
Expect(0, 120831, '\p{^mathalphanum}', "");
Expect(0, 120831, '\P{mathalphanum}', "");
Expect(1, 120831, '\P{^mathalphanum}', "");
Expect(0, 120832, '\p{mathalphanum}', "");
Expect(1, 120832, '\p{^mathalphanum}', "");
Expect(1, 120832, '\P{mathalphanum}', "");
Expect(0, 120832, '\P{^mathalphanum}', "");
Expect(1, 120831, '\p{ 	math_Alphanum}', "");
Expect(0, 120831, '\p{^ 	math_Alphanum}', "");
Expect(0, 120831, '\P{ 	math_Alphanum}', "");
Expect(1, 120831, '\P{^ 	math_Alphanum}', "");
Expect(0, 120832, '\p{ 	math_Alphanum}', "");
Expect(1, 120832, '\p{^ 	math_Alphanum}', "");
Expect(1, 120832, '\P{ 	math_Alphanum}', "");
Expect(0, 120832, '\P{^ 	math_Alphanum}', "");
Error('\p{ :=IS_math_Alphanum}');
Error('\P{ :=IS_math_Alphanum}');
Expect(1, 120831, '\p{ismathalphanum}', "");
Expect(0, 120831, '\p{^ismathalphanum}', "");
Expect(0, 120831, '\P{ismathalphanum}', "");
Expect(1, 120831, '\P{^ismathalphanum}', "");
Expect(0, 120832, '\p{ismathalphanum}', "");
Expect(1, 120832, '\p{^ismathalphanum}', "");
Expect(1, 120832, '\P{ismathalphanum}', "");
Expect(0, 120832, '\P{^ismathalphanum}', "");
Expect(1, 120831, '\p{--IS_Math_alphanum}', "");
Expect(0, 120831, '\p{^--IS_Math_alphanum}', "");
Expect(0, 120831, '\P{--IS_Math_alphanum}', "");
Expect(1, 120831, '\P{^--IS_Math_alphanum}', "");
Expect(0, 120832, '\p{--IS_Math_alphanum}', "");
Expect(1, 120832, '\p{^--IS_Math_alphanum}', "");
Expect(1, 120832, '\P{--IS_Math_alphanum}', "");
Expect(0, 120832, '\P{^--IS_Math_alphanum}', "");
Error('\p{	:=in_MATH_alphanum}');
Error('\P{	:=in_MATH_alphanum}');
Expect(1, 120831, '\p{inmathalphanum}', "");
Expect(0, 120831, '\p{^inmathalphanum}', "");
Expect(0, 120831, '\P{inmathalphanum}', "");
Expect(1, 120831, '\P{^inmathalphanum}', "");
Expect(0, 120832, '\p{inmathalphanum}', "");
Expect(1, 120832, '\p{^inmathalphanum}', "");
Expect(1, 120832, '\P{inmathalphanum}', "");
Expect(0, 120832, '\P{^inmathalphanum}', "");
Expect(1, 120831, '\p{ 	in_math_ALPHANUM}', "");
Expect(0, 120831, '\p{^ 	in_math_ALPHANUM}', "");
Expect(0, 120831, '\P{ 	in_math_ALPHANUM}', "");
Expect(1, 120831, '\P{^ 	in_math_ALPHANUM}', "");
Expect(0, 120832, '\p{ 	in_math_ALPHANUM}', "");
Expect(1, 120832, '\p{^ 	in_math_ALPHANUM}', "");
Expect(1, 120832, '\P{ 	in_math_ALPHANUM}', "");
Expect(0, 120832, '\P{^ 	in_math_ALPHANUM}', "");
Error('\p{/a/Mathematical_Operators}');
Error('\P{/a/Mathematical_Operators}');
Expect(1, 8959, '\p{mathematicaloperators}', "");
Expect(0, 8959, '\p{^mathematicaloperators}', "");
Expect(0, 8959, '\P{mathematicaloperators}', "");
Expect(1, 8959, '\P{^mathematicaloperators}', "");
Expect(0, 8960, '\p{mathematicaloperators}', "");
Expect(1, 8960, '\p{^mathematicaloperators}', "");
Expect(1, 8960, '\P{mathematicaloperators}', "");
Expect(0, 8960, '\P{^mathematicaloperators}', "");
Expect(1, 8959, '\p{  mathematical_operators}', "");
Expect(0, 8959, '\p{^  mathematical_operators}', "");
Expect(0, 8959, '\P{  mathematical_operators}', "");
Expect(1, 8959, '\P{^  mathematical_operators}', "");
Expect(0, 8960, '\p{  mathematical_operators}', "");
Expect(1, 8960, '\p{^  mathematical_operators}', "");
Expect(1, 8960, '\P{  mathematical_operators}', "");
Expect(0, 8960, '\P{^  mathematical_operators}', "");
Error('\p{ IS_Mathematical_OPERATORS:=}');
Error('\P{ IS_Mathematical_OPERATORS:=}');
Expect(1, 8959, '\p{ismathematicaloperators}', "");
Expect(0, 8959, '\p{^ismathematicaloperators}', "");
Expect(0, 8959, '\P{ismathematicaloperators}', "");
Expect(1, 8959, '\P{^ismathematicaloperators}', "");
Expect(0, 8960, '\p{ismathematicaloperators}', "");
Expect(1, 8960, '\p{^ismathematicaloperators}', "");
Expect(1, 8960, '\P{ismathematicaloperators}', "");
Expect(0, 8960, '\P{^ismathematicaloperators}', "");
Expect(1, 8959, '\p{  Is_Mathematical_Operators}', "");
Expect(0, 8959, '\p{^  Is_Mathematical_Operators}', "");
Expect(0, 8959, '\P{  Is_Mathematical_Operators}', "");
Expect(1, 8959, '\P{^  Is_Mathematical_Operators}', "");
Expect(0, 8960, '\p{  Is_Mathematical_Operators}', "");
Expect(1, 8960, '\p{^  Is_Mathematical_Operators}', "");
Expect(1, 8960, '\P{  Is_Mathematical_Operators}', "");
Expect(0, 8960, '\P{^  Is_Mathematical_Operators}', "");
Error('\p{-_In_mathematical_Operators/a/}');
Error('\P{-_In_mathematical_Operators/a/}');
Expect(1, 8959, '\p{inmathematicaloperators}', "");
Expect(0, 8959, '\p{^inmathematicaloperators}', "");
Expect(0, 8959, '\P{inmathematicaloperators}', "");
Expect(1, 8959, '\P{^inmathematicaloperators}', "");
Expect(0, 8960, '\p{inmathematicaloperators}', "");
Expect(1, 8960, '\p{^inmathematicaloperators}', "");
Expect(1, 8960, '\P{inmathematicaloperators}', "");
Expect(0, 8960, '\P{^inmathematicaloperators}', "");
Expect(1, 8959, '\p{- In_MATHEMATICAL_Operators}', "");
Expect(0, 8959, '\p{^- In_MATHEMATICAL_Operators}', "");
Expect(0, 8959, '\P{- In_MATHEMATICAL_Operators}', "");
Expect(1, 8959, '\P{^- In_MATHEMATICAL_Operators}', "");
Expect(0, 8960, '\p{- In_MATHEMATICAL_Operators}', "");
Expect(1, 8960, '\p{^- In_MATHEMATICAL_Operators}', "");
Expect(1, 8960, '\P{- In_MATHEMATICAL_Operators}', "");
Expect(0, 8960, '\P{^- In_MATHEMATICAL_Operators}', "");
Error('\p{/a/-Math_Operators}');
Error('\P{/a/-Math_Operators}');
Expect(1, 8959, '\p{mathoperators}', "");
Expect(0, 8959, '\p{^mathoperators}', "");
Expect(0, 8959, '\P{mathoperators}', "");
Expect(1, 8959, '\P{^mathoperators}', "");
Expect(0, 8960, '\p{mathoperators}', "");
Expect(1, 8960, '\p{^mathoperators}', "");
Expect(1, 8960, '\P{mathoperators}', "");
Expect(0, 8960, '\P{^mathoperators}', "");
Expect(1, 8959, '\p{_-Math_OPERATORS}', "");
Expect(0, 8959, '\p{^_-Math_OPERATORS}', "");
Expect(0, 8959, '\P{_-Math_OPERATORS}', "");
Expect(1, 8959, '\P{^_-Math_OPERATORS}', "");
Expect(0, 8960, '\p{_-Math_OPERATORS}', "");
Expect(1, 8960, '\p{^_-Math_OPERATORS}', "");
Expect(1, 8960, '\P{_-Math_OPERATORS}', "");
Expect(0, 8960, '\P{^_-Math_OPERATORS}', "");
Error('\p{:=	_Is_MATH_Operators}');
Error('\P{:=	_Is_MATH_Operators}');
Expect(1, 8959, '\p{ismathoperators}', "");
Expect(0, 8959, '\p{^ismathoperators}', "");
Expect(0, 8959, '\P{ismathoperators}', "");
Expect(1, 8959, '\P{^ismathoperators}', "");
Expect(0, 8960, '\p{ismathoperators}', "");
Expect(1, 8960, '\p{^ismathoperators}', "");
Expect(1, 8960, '\P{ismathoperators}', "");
Expect(0, 8960, '\P{^ismathoperators}', "");
Expect(1, 8959, '\p{_IS_Math_Operators}', "");
Expect(0, 8959, '\p{^_IS_Math_Operators}', "");
Expect(0, 8959, '\P{_IS_Math_Operators}', "");
Expect(1, 8959, '\P{^_IS_Math_Operators}', "");
Expect(0, 8960, '\p{_IS_Math_Operators}', "");
Expect(1, 8960, '\p{^_IS_Math_Operators}', "");
Expect(1, 8960, '\P{_IS_Math_Operators}', "");
Expect(0, 8960, '\P{^_IS_Math_Operators}', "");
Error('\p{ /a/in_MATH_operators}');
Error('\P{ /a/in_MATH_operators}');
Expect(1, 8959, '\p{inmathoperators}', "");
Expect(0, 8959, '\p{^inmathoperators}', "");
Expect(0, 8959, '\P{inmathoperators}', "");
Expect(1, 8959, '\P{^inmathoperators}', "");
Expect(0, 8960, '\p{inmathoperators}', "");
Expect(1, 8960, '\p{^inmathoperators}', "");
Expect(1, 8960, '\P{inmathoperators}', "");
Expect(0, 8960, '\P{^inmathoperators}', "");
Expect(1, 8959, '\p{	_In_Math_Operators}', "");
Expect(0, 8959, '\p{^	_In_Math_Operators}', "");
Expect(0, 8959, '\P{	_In_Math_Operators}', "");
Expect(1, 8959, '\P{^	_In_Math_Operators}', "");
Expect(0, 8960, '\p{	_In_Math_Operators}', "");
Expect(1, 8960, '\p{^	_In_Math_Operators}', "");
Expect(1, 8960, '\P{	_In_Math_Operators}', "");
Expect(0, 8960, '\P{^	_In_Math_Operators}', "");
Error('\p{_:=Meetei_Mayek}');
Error('\P{_:=Meetei_Mayek}');
Expect(1, 44025, '\p{meeteimayek}', "");
Expect(0, 44025, '\p{^meeteimayek}', "");
Expect(0, 44025, '\P{meeteimayek}', "");
Expect(1, 44025, '\P{^meeteimayek}', "");
Expect(0, 44026, '\p{meeteimayek}', "");
Expect(1, 44026, '\p{^meeteimayek}', "");
Expect(1, 44026, '\P{meeteimayek}', "");
Expect(0, 44026, '\P{^meeteimayek}', "");
Expect(1, 44025, '\p{_Meetei_mayek}', "");
Expect(0, 44025, '\p{^_Meetei_mayek}', "");
Expect(0, 44025, '\P{_Meetei_mayek}', "");
Expect(1, 44025, '\P{^_Meetei_mayek}', "");
Expect(0, 44026, '\p{_Meetei_mayek}', "");
Expect(1, 44026, '\p{^_Meetei_mayek}', "");
Expect(1, 44026, '\P{_Meetei_mayek}', "");
Expect(0, 44026, '\P{^_Meetei_mayek}', "");
Error('\p{-/a/Is_MEETEI_Mayek}');
Error('\P{-/a/Is_MEETEI_Mayek}');
Expect(1, 44025, '\p{ismeeteimayek}', "");
Expect(0, 44025, '\p{^ismeeteimayek}', "");
Expect(0, 44025, '\P{ismeeteimayek}', "");
Expect(1, 44025, '\P{^ismeeteimayek}', "");
Expect(0, 44026, '\p{ismeeteimayek}', "");
Expect(1, 44026, '\p{^ismeeteimayek}', "");
Expect(1, 44026, '\P{ismeeteimayek}', "");
Expect(0, 44026, '\P{^ismeeteimayek}', "");
Expect(1, 44025, '\p{	is_MEETEI_Mayek}', "");
Expect(0, 44025, '\p{^	is_MEETEI_Mayek}', "");
Expect(0, 44025, '\P{	is_MEETEI_Mayek}', "");
Expect(1, 44025, '\P{^	is_MEETEI_Mayek}', "");
Expect(0, 44026, '\p{	is_MEETEI_Mayek}', "");
Expect(1, 44026, '\p{^	is_MEETEI_Mayek}', "");
Expect(1, 44026, '\P{	is_MEETEI_Mayek}', "");
Expect(0, 44026, '\P{^	is_MEETEI_Mayek}', "");
Error('\p{	:=mtei}');
Error('\P{	:=mtei}');
Expect(1, 44025, '\p{mtei}', "");
Expect(0, 44025, '\p{^mtei}', "");
Expect(0, 44025, '\P{mtei}', "");
Expect(1, 44025, '\P{^mtei}', "");
Expect(0, 44026, '\p{mtei}', "");
Expect(1, 44026, '\p{^mtei}', "");
Expect(1, 44026, '\P{mtei}', "");
Expect(0, 44026, '\P{^mtei}', "");
Expect(1, 44025, '\p{_-mtei}', "");
Expect(0, 44025, '\p{^_-mtei}', "");
Expect(0, 44025, '\P{_-mtei}', "");
Expect(1, 44025, '\P{^_-mtei}', "");
Expect(0, 44026, '\p{_-mtei}', "");
Expect(1, 44026, '\p{^_-mtei}', "");
Expect(1, 44026, '\P{_-mtei}', "");
Expect(0, 44026, '\P{^_-mtei}', "");
Error('\p{:=--Is_mtei}');
Error('\P{:=--Is_mtei}');
Expect(1, 44025, '\p{ismtei}', "");
Expect(0, 44025, '\p{^ismtei}', "");
Expect(0, 44025, '\P{ismtei}', "");
Expect(1, 44025, '\P{^ismtei}', "");
Expect(0, 44026, '\p{ismtei}', "");
Expect(1, 44026, '\p{^ismtei}', "");
Expect(1, 44026, '\P{ismtei}', "");
Expect(0, 44026, '\P{^ismtei}', "");
Expect(1, 44025, '\p{_IS_Mtei}', "");
Expect(0, 44025, '\p{^_IS_Mtei}', "");
Expect(0, 44025, '\P{_IS_Mtei}', "");
Expect(1, 44025, '\P{^_IS_Mtei}', "");
Expect(0, 44026, '\p{_IS_Mtei}', "");
Expect(1, 44026, '\p{^_IS_Mtei}', "");
Expect(1, 44026, '\P{_IS_Mtei}', "");
Expect(0, 44026, '\P{^_IS_Mtei}', "");
Error('\p{-/a/MEETEI_Mayek_extensions}');
Error('\P{-/a/MEETEI_Mayek_extensions}');
Expect(1, 43775, '\p{meeteimayekextensions}', "");
Expect(0, 43775, '\p{^meeteimayekextensions}', "");
Expect(0, 43775, '\P{meeteimayekextensions}', "");
Expect(1, 43775, '\P{^meeteimayekextensions}', "");
Expect(0, 43776, '\p{meeteimayekextensions}', "");
Expect(1, 43776, '\p{^meeteimayekextensions}', "");
Expect(1, 43776, '\P{meeteimayekextensions}', "");
Expect(0, 43776, '\P{^meeteimayekextensions}', "");
Expect(1, 43775, '\p{  meetei_Mayek_extensions}', "");
Expect(0, 43775, '\p{^  meetei_Mayek_extensions}', "");
Expect(0, 43775, '\P{  meetei_Mayek_extensions}', "");
Expect(1, 43775, '\P{^  meetei_Mayek_extensions}', "");
Expect(0, 43776, '\p{  meetei_Mayek_extensions}', "");
Expect(1, 43776, '\p{^  meetei_Mayek_extensions}', "");
Expect(1, 43776, '\P{  meetei_Mayek_extensions}', "");
Expect(0, 43776, '\P{^  meetei_Mayek_extensions}', "");
Error('\p{ /a/Is_Meetei_Mayek_Extensions}');
Error('\P{ /a/Is_Meetei_Mayek_Extensions}');
Expect(1, 43775, '\p{ismeeteimayekextensions}', "");
Expect(0, 43775, '\p{^ismeeteimayekextensions}', "");
Expect(0, 43775, '\P{ismeeteimayekextensions}', "");
Expect(1, 43775, '\P{^ismeeteimayekextensions}', "");
Expect(0, 43776, '\p{ismeeteimayekextensions}', "");
Expect(1, 43776, '\p{^ismeeteimayekextensions}', "");
Expect(1, 43776, '\P{ismeeteimayekextensions}', "");
Expect(0, 43776, '\P{^ismeeteimayekextensions}', "");
Expect(1, 43775, '\p{-Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\p{^-Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43775, '\P{-Is_Meetei_Mayek_Extensions}', "");
Expect(1, 43775, '\P{^-Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\p{-Is_Meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\p{^-Is_Meetei_Mayek_Extensions}', "");
Expect(1, 43776, '\P{-Is_Meetei_Mayek_Extensions}', "");
Expect(0, 43776, '\P{^-Is_Meetei_Mayek_Extensions}', "");
Error('\p{_	IN_MEETEI_MAYEK_extensions/a/}');
Error('\P{_	IN_MEETEI_MAYEK_extensions/a/}');
Expect(1, 43775, '\p{inmeeteimayekextensions}', "");
Expect(0, 43775, '\p{^inmeeteimayekextensions}', "");
Expect(0, 43775, '\P{inmeeteimayekextensions}', "");
Expect(1, 43775, '\P{^inmeeteimayekextensions}', "");
Expect(0, 43776, '\p{inmeeteimayekextensions}', "");
Expect(1, 43776, '\p{^inmeeteimayekextensions}', "");
Expect(1, 43776, '\P{inmeeteimayekextensions}', "");
Expect(0, 43776, '\P{^inmeeteimayekextensions}', "");
Expect(1, 43775, '\p{__In_MEETEI_Mayek_Extensions}', "");
Expect(0, 43775, '\p{^__In_MEETEI_Mayek_Extensions}', "");
Expect(0, 43775, '\P{__In_MEETEI_Mayek_Extensions}', "");
Expect(1, 43775, '\P{^__In_MEETEI_Mayek_Extensions}', "");
Expect(0, 43776, '\p{__In_MEETEI_Mayek_Extensions}', "");
Expect(1, 43776, '\p{^__In_MEETEI_Mayek_Extensions}', "");
Expect(1, 43776, '\P{__In_MEETEI_Mayek_Extensions}', "");
Expect(0, 43776, '\P{^__In_MEETEI_Mayek_Extensions}', "");
Error('\p{/a/meetei_mayek_Ext}');
Error('\P{/a/meetei_mayek_Ext}');
Expect(1, 43775, '\p{meeteimayekext}', "");
Expect(0, 43775, '\p{^meeteimayekext}', "");
Expect(0, 43775, '\P{meeteimayekext}', "");
Expect(1, 43775, '\P{^meeteimayekext}', "");
Expect(0, 43776, '\p{meeteimayekext}', "");
Expect(1, 43776, '\p{^meeteimayekext}', "");
Expect(1, 43776, '\P{meeteimayekext}', "");
Expect(0, 43776, '\P{^meeteimayekext}', "");
Expect(1, 43775, '\p{_ Meetei_mayek_Ext}', "");
Expect(0, 43775, '\p{^_ Meetei_mayek_Ext}', "");
Expect(0, 43775, '\P{_ Meetei_mayek_Ext}', "");
Expect(1, 43775, '\P{^_ Meetei_mayek_Ext}', "");
Expect(0, 43776, '\p{_ Meetei_mayek_Ext}', "");
Expect(1, 43776, '\p{^_ Meetei_mayek_Ext}', "");
Expect(1, 43776, '\P{_ Meetei_mayek_Ext}', "");
Expect(0, 43776, '\P{^_ Meetei_mayek_Ext}', "");
Error('\p{:= 	Is_meetei_MAYEK_ext}');
Error('\P{:= 	Is_meetei_MAYEK_ext}');
Expect(1, 43775, '\p{ismeeteimayekext}', "");
Expect(0, 43775, '\p{^ismeeteimayekext}', "");
Expect(0, 43775, '\P{ismeeteimayekext}', "");
Expect(1, 43775, '\P{^ismeeteimayekext}', "");
Expect(0, 43776, '\p{ismeeteimayekext}', "");
Expect(1, 43776, '\p{^ismeeteimayekext}', "");
Expect(1, 43776, '\P{ismeeteimayekext}', "");
Expect(0, 43776, '\P{^ismeeteimayekext}', "");
Expect(1, 43775, '\p{-Is_Meetei_mayek_EXT}', "");
Expect(0, 43775, '\p{^-Is_Meetei_mayek_EXT}', "");
Expect(0, 43775, '\P{-Is_Meetei_mayek_EXT}', "");
Expect(1, 43775, '\P{^-Is_Meetei_mayek_EXT}', "");
Expect(0, 43776, '\p{-Is_Meetei_mayek_EXT}', "");
Expect(1, 43776, '\p{^-Is_Meetei_mayek_EXT}', "");
Expect(1, 43776, '\P{-Is_Meetei_mayek_EXT}', "");
Expect(0, 43776, '\P{^-Is_Meetei_mayek_EXT}', "");
Error('\p{- In_MEETEI_Mayek_EXT:=}');
Error('\P{- In_MEETEI_Mayek_EXT:=}');
Expect(1, 43775, '\p{inmeeteimayekext}', "");
Expect(0, 43775, '\p{^inmeeteimayekext}', "");
Expect(0, 43775, '\P{inmeeteimayekext}', "");
Expect(1, 43775, '\P{^inmeeteimayekext}', "");
Expect(0, 43776, '\p{inmeeteimayekext}', "");
Expect(1, 43776, '\p{^inmeeteimayekext}', "");
Expect(1, 43776, '\P{inmeeteimayekext}', "");
Expect(0, 43776, '\P{^inmeeteimayekext}', "");
Expect(1, 43775, '\p{  In_meetei_Mayek_Ext}', "");
Expect(0, 43775, '\p{^  In_meetei_Mayek_Ext}', "");
Expect(0, 43775, '\P{  In_meetei_Mayek_Ext}', "");
Expect(1, 43775, '\P{^  In_meetei_Mayek_Ext}', "");
Expect(0, 43776, '\p{  In_meetei_Mayek_Ext}', "");
Expect(1, 43776, '\p{^  In_meetei_Mayek_Ext}', "");
Expect(1, 43776, '\P{  In_meetei_Mayek_Ext}', "");
Expect(0, 43776, '\P{^  In_meetei_Mayek_Ext}', "");
Error('\p{/a/-	Meroitic_CURSIVE}');
Error('\P{/a/-	Meroitic_CURSIVE}');
Expect(1, 68031, '\p{meroiticcursive}', "");
Expect(0, 68031, '\p{^meroiticcursive}', "");
Expect(0, 68031, '\P{meroiticcursive}', "");
Expect(1, 68031, '\P{^meroiticcursive}', "");
Expect(0, 68032, '\p{meroiticcursive}', "");
Expect(1, 68032, '\p{^meroiticcursive}', "");
Expect(1, 68032, '\P{meroiticcursive}', "");
Expect(0, 68032, '\P{^meroiticcursive}', "");
Expect(1, 68031, '\p{-MEROITIC_CURSIVE}', "");
Expect(0, 68031, '\p{^-MEROITIC_CURSIVE}', "");
Expect(0, 68031, '\P{-MEROITIC_CURSIVE}', "");
Expect(1, 68031, '\P{^-MEROITIC_CURSIVE}', "");
Expect(0, 68032, '\p{-MEROITIC_CURSIVE}', "");
Expect(1, 68032, '\p{^-MEROITIC_CURSIVE}', "");
Expect(1, 68032, '\P{-MEROITIC_CURSIVE}', "");
Expect(0, 68032, '\P{^-MEROITIC_CURSIVE}', "");
Error('\p{_:=Is_meroitic_CURSIVE}');
Error('\P{_:=Is_meroitic_CURSIVE}');
Expect(1, 68031, '\p{ismeroiticcursive}', "");
Expect(0, 68031, '\p{^ismeroiticcursive}', "");
Expect(0, 68031, '\P{ismeroiticcursive}', "");
Expect(1, 68031, '\P{^ismeroiticcursive}', "");
Expect(0, 68032, '\p{ismeroiticcursive}', "");
Expect(1, 68032, '\p{^ismeroiticcursive}', "");
Expect(1, 68032, '\P{ismeroiticcursive}', "");
Expect(0, 68032, '\P{^ismeroiticcursive}', "");
Expect(1, 68031, '\p{_-Is_Meroitic_Cursive}', "");
Expect(0, 68031, '\p{^_-Is_Meroitic_Cursive}', "");
Expect(0, 68031, '\P{_-Is_Meroitic_Cursive}', "");
Expect(1, 68031, '\P{^_-Is_Meroitic_Cursive}', "");
Expect(0, 68032, '\p{_-Is_Meroitic_Cursive}', "");
Expect(1, 68032, '\p{^_-Is_Meroitic_Cursive}', "");
Expect(1, 68032, '\P{_-Is_Meroitic_Cursive}', "");
Expect(0, 68032, '\P{^_-Is_Meroitic_Cursive}', "");
Error('\p{--merc:=}');
Error('\P{--merc:=}');
Expect(1, 68031, '\p{merc}', "");
Expect(0, 68031, '\p{^merc}', "");
Expect(0, 68031, '\P{merc}', "");
Expect(1, 68031, '\P{^merc}', "");
Expect(0, 68032, '\p{merc}', "");
Expect(1, 68032, '\p{^merc}', "");
Expect(1, 68032, '\P{merc}', "");
Expect(0, 68032, '\P{^merc}', "");
Expect(1, 68031, '\p{	 Merc}', "");
Expect(0, 68031, '\p{^	 Merc}', "");
Expect(0, 68031, '\P{	 Merc}', "");
Expect(1, 68031, '\P{^	 Merc}', "");
Expect(0, 68032, '\p{	 Merc}', "");
Expect(1, 68032, '\p{^	 Merc}', "");
Expect(1, 68032, '\P{	 Merc}', "");
Expect(0, 68032, '\P{^	 Merc}', "");
Error('\p{ Is_Merc:=}');
Error('\P{ Is_Merc:=}');
Expect(1, 68031, '\p{ismerc}', "");
Expect(0, 68031, '\p{^ismerc}', "");
Expect(0, 68031, '\P{ismerc}', "");
Expect(1, 68031, '\P{^ismerc}', "");
Expect(0, 68032, '\p{ismerc}', "");
Expect(1, 68032, '\p{^ismerc}', "");
Expect(1, 68032, '\P{ismerc}', "");
Expect(0, 68032, '\P{^ismerc}', "");
Expect(1, 68031, '\p{_ is_MERC}', "");
Expect(0, 68031, '\p{^_ is_MERC}', "");
Expect(0, 68031, '\P{_ is_MERC}', "");
Expect(1, 68031, '\P{^_ is_MERC}', "");
Expect(0, 68032, '\p{_ is_MERC}', "");
Expect(1, 68032, '\p{^_ is_MERC}', "");
Expect(1, 68032, '\P{_ is_MERC}', "");
Expect(0, 68032, '\P{^_ is_MERC}', "");
Error('\p{-:=Meroitic_hieroglyphs}');
Error('\P{-:=Meroitic_hieroglyphs}');
Expect(1, 67999, '\p{meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^meroitichieroglyphs}', "");
Expect(0, 67999, '\P{meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^meroitichieroglyphs}', "");
Expect(0, 68000, '\p{meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^meroitichieroglyphs}', "");
Expect(1, 68000, '\P{meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^meroitichieroglyphs}', "");
Expect(1, 67999, '\p{_	meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^_	meroitic_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{_	meroitic_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^_	meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{_	meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^_	meroitic_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{_	meroitic_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^_	meroitic_HIEROGLYPHS}', "");
Error('\p{	Is_meroitic_HIEROGLYPHS:=}');
Error('\P{	Is_meroitic_HIEROGLYPHS:=}');
Expect(1, 67999, '\p{ismeroitichieroglyphs}', "");
Expect(0, 67999, '\p{^ismeroitichieroglyphs}', "");
Expect(0, 67999, '\P{ismeroitichieroglyphs}', "");
Expect(1, 67999, '\P{^ismeroitichieroglyphs}', "");
Expect(0, 68000, '\p{ismeroitichieroglyphs}', "");
Expect(1, 68000, '\p{^ismeroitichieroglyphs}', "");
Expect(1, 68000, '\P{ismeroitichieroglyphs}', "");
Expect(0, 68000, '\P{^ismeroitichieroglyphs}', "");
Expect(1, 67999, '\p{-is_Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^-is_Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{-is_Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^-is_Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{-is_Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^-is_Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{-is_Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^-is_Meroitic_Hieroglyphs}', "");
Error('\p{:=	 mero}');
Error('\P{:=	 mero}');
Expect(1, 67999, '\p{mero}', "");
Expect(0, 67999, '\p{^mero}', "");
Expect(0, 67999, '\P{mero}', "");
Expect(1, 67999, '\P{^mero}', "");
Expect(0, 68000, '\p{mero}', "");
Expect(1, 68000, '\p{^mero}', "");
Expect(1, 68000, '\P{mero}', "");
Expect(0, 68000, '\P{^mero}', "");
Expect(1, 67999, '\p{-	MERO}', "");
Expect(0, 67999, '\p{^-	MERO}', "");
Expect(0, 67999, '\P{-	MERO}', "");
Expect(1, 67999, '\P{^-	MERO}', "");
Expect(0, 68000, '\p{-	MERO}', "");
Expect(1, 68000, '\p{^-	MERO}', "");
Expect(1, 68000, '\P{-	MERO}', "");
Expect(0, 68000, '\P{^-	MERO}', "");
Error('\p{ /a/IS_mero}');
Error('\P{ /a/IS_mero}');
Expect(1, 67999, '\p{ismero}', "");
Expect(0, 67999, '\p{^ismero}', "");
Expect(0, 67999, '\P{ismero}', "");
Expect(1, 67999, '\P{^ismero}', "");
Expect(0, 68000, '\p{ismero}', "");
Expect(1, 68000, '\p{^ismero}', "");
Expect(1, 68000, '\P{ismero}', "");
Expect(0, 68000, '\P{^ismero}', "");
Expect(1, 67999, '\p{	 Is_Mero}', "");
Expect(0, 67999, '\p{^	 Is_Mero}', "");
Expect(0, 67999, '\P{	 Is_Mero}', "");
Expect(1, 67999, '\P{^	 Is_Mero}', "");
Expect(0, 68000, '\p{	 Is_Mero}', "");
Expect(1, 68000, '\p{^	 Is_Mero}', "");
Expect(1, 68000, '\P{	 Is_Mero}', "");
Expect(0, 68000, '\P{^	 Is_Mero}', "");
Error('\p{:=	miao}');
Error('\P{:=	miao}');
Expect(1, 94111, '\p{miao}', "");
Expect(0, 94111, '\p{^miao}', "");
Expect(0, 94111, '\P{miao}', "");
Expect(1, 94111, '\P{^miao}', "");
Expect(0, 94112, '\p{miao}', "");
Expect(1, 94112, '\p{^miao}', "");
Expect(1, 94112, '\P{miao}', "");
Expect(0, 94112, '\P{^miao}', "");
Expect(1, 94111, '\p{	-Miao}', "");
Expect(0, 94111, '\p{^	-Miao}', "");
Expect(0, 94111, '\P{	-Miao}', "");
Expect(1, 94111, '\P{^	-Miao}', "");
Expect(0, 94112, '\p{	-Miao}', "");
Expect(1, 94112, '\p{^	-Miao}', "");
Expect(1, 94112, '\P{	-Miao}', "");
Expect(0, 94112, '\P{^	-Miao}', "");
Error('\p{-:=Is_miao}');
Error('\P{-:=Is_miao}');
Expect(1, 94111, '\p{ismiao}', "");
Expect(0, 94111, '\p{^ismiao}', "");
Expect(0, 94111, '\P{ismiao}', "");
Expect(1, 94111, '\P{^ismiao}', "");
Expect(0, 94112, '\p{ismiao}', "");
Expect(1, 94112, '\p{^ismiao}', "");
Expect(1, 94112, '\P{ismiao}', "");
Expect(0, 94112, '\P{^ismiao}', "");
Expect(1, 94111, '\p{ 	is_miao}', "");
Expect(0, 94111, '\p{^ 	is_miao}', "");
Expect(0, 94111, '\P{ 	is_miao}', "");
Expect(1, 94111, '\P{^ 	is_miao}', "");
Expect(0, 94112, '\p{ 	is_miao}', "");
Expect(1, 94112, '\p{^ 	is_miao}', "");
Expect(1, 94112, '\P{ 	is_miao}', "");
Expect(0, 94112, '\P{^ 	is_miao}', "");
Error('\p{		Plrd/a/}');
Error('\P{		Plrd/a/}');
Expect(1, 94111, '\p{plrd}', "");
Expect(0, 94111, '\p{^plrd}', "");
Expect(0, 94111, '\P{plrd}', "");
Expect(1, 94111, '\P{^plrd}', "");
Expect(0, 94112, '\p{plrd}', "");
Expect(1, 94112, '\p{^plrd}', "");
Expect(1, 94112, '\P{plrd}', "");
Expect(0, 94112, '\P{^plrd}', "");
Expect(1, 94111, '\p{ PLRD}', "");
Expect(0, 94111, '\p{^ PLRD}', "");
Expect(0, 94111, '\P{ PLRD}', "");
Expect(1, 94111, '\P{^ PLRD}', "");
Expect(0, 94112, '\p{ PLRD}', "");
Expect(1, 94112, '\p{^ PLRD}', "");
Expect(1, 94112, '\P{ PLRD}', "");
Expect(0, 94112, '\P{^ PLRD}', "");
Error('\p{ -Is_plrd:=}');
Error('\P{ -Is_plrd:=}');
Expect(1, 94111, '\p{isplrd}', "");
Expect(0, 94111, '\p{^isplrd}', "");
Expect(0, 94111, '\P{isplrd}', "");
Expect(1, 94111, '\P{^isplrd}', "");
Expect(0, 94112, '\p{isplrd}', "");
Expect(1, 94112, '\p{^isplrd}', "");
Expect(1, 94112, '\P{isplrd}', "");
Expect(0, 94112, '\P{^isplrd}', "");
Expect(1, 94111, '\p{		is_plrd}', "");
Expect(0, 94111, '\p{^		is_plrd}', "");
Expect(0, 94111, '\P{		is_plrd}', "");
Expect(1, 94111, '\P{^		is_plrd}', "");
Expect(0, 94112, '\p{		is_plrd}', "");
Expect(1, 94112, '\p{^		is_plrd}', "");
Expect(1, 94112, '\P{		is_plrd}', "");
Expect(0, 94112, '\P{^		is_plrd}', "");
Error('\p{_	Miscellaneous_mathematical_Symbols_A:=}');
Error('\P{_	Miscellaneous_mathematical_Symbols_A:=}');
Expect(1, 10223, '\p{miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{miscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^miscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10223, '\p{^Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10223, '\P{Miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10223, '\P{^Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10224, '\p{Miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10224, '\p{^Miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10224, '\P{Miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10224, '\P{^Miscellaneous_Mathematical_Symbols_A}', "");
Error('\p{- is_Miscellaneous_MATHEMATICAL_Symbols_A:=}');
Error('\P{- is_Miscellaneous_MATHEMATICAL_Symbols_A:=}');
Expect(1, 10223, '\p{ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{ismiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^ismiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(0, 10223, '\p{^	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(0, 10223, '\P{	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(1, 10223, '\P{^	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(0, 10224, '\p{	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(1, 10224, '\p{^	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(1, 10224, '\P{	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Expect(0, 10224, '\P{^	 Is_Miscellaneous_MATHEMATICAL_SYMBOLS_A}', "");
Error('\p{:=		in_Miscellaneous_Mathematical_Symbols_A}');
Error('\P{:=		in_Miscellaneous_Mathematical_Symbols_A}');
Expect(1, 10223, '\p{inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\p{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10223, '\P{inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\P{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\p{inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\p{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10224, '\P{inmiscellaneousmathematicalsymbolsa}', "");
Expect(0, 10224, '\P{^inmiscellaneousmathematicalsymbolsa}', "");
Expect(1, 10223, '\p{__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10223, '\p{^__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10223, '\P{__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10223, '\P{^__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10224, '\p{__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10224, '\p{^__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(1, 10224, '\P{__In_miscellaneous_Mathematical_Symbols_A}', "");
Expect(0, 10224, '\P{^__In_miscellaneous_Mathematical_Symbols_A}', "");
Error('\p{:=--Misc_Math_Symbols_A}');
Error('\P{:=--Misc_Math_Symbols_A}');
Expect(1, 10223, '\p{miscmathsymbolsa}', "");
Expect(0, 10223, '\p{^miscmathsymbolsa}', "");
Expect(0, 10223, '\P{miscmathsymbolsa}', "");
Expect(1, 10223, '\P{^miscmathsymbolsa}', "");
Expect(0, 10224, '\p{miscmathsymbolsa}', "");
Expect(1, 10224, '\p{^miscmathsymbolsa}', "");
Expect(1, 10224, '\P{miscmathsymbolsa}', "");
Expect(0, 10224, '\P{^miscmathsymbolsa}', "");
Expect(1, 10223, '\p{	 misc_Math_SYMBOLS_A}', "");
Expect(0, 10223, '\p{^	 misc_Math_SYMBOLS_A}', "");
Expect(0, 10223, '\P{	 misc_Math_SYMBOLS_A}', "");
Expect(1, 10223, '\P{^	 misc_Math_SYMBOLS_A}', "");
Expect(0, 10224, '\p{	 misc_Math_SYMBOLS_A}', "");
Expect(1, 10224, '\p{^	 misc_Math_SYMBOLS_A}', "");
Expect(1, 10224, '\P{	 misc_Math_SYMBOLS_A}', "");
Expect(0, 10224, '\P{^	 misc_Math_SYMBOLS_A}', "");
Error('\p{:=	 is_misc_Math_symbols_a}');
Error('\P{:=	 is_misc_Math_symbols_a}');
Expect(1, 10223, '\p{ismiscmathsymbolsa}', "");
Expect(0, 10223, '\p{^ismiscmathsymbolsa}', "");
Expect(0, 10223, '\P{ismiscmathsymbolsa}', "");
Expect(1, 10223, '\P{^ismiscmathsymbolsa}', "");
Expect(0, 10224, '\p{ismiscmathsymbolsa}', "");
Expect(1, 10224, '\p{^ismiscmathsymbolsa}', "");
Expect(1, 10224, '\P{ismiscmathsymbolsa}', "");
Expect(0, 10224, '\P{^ismiscmathsymbolsa}', "");
Expect(1, 10223, '\p{-	Is_misc_math_symbols_a}', "");
Expect(0, 10223, '\p{^-	Is_misc_math_symbols_a}', "");
Expect(0, 10223, '\P{-	Is_misc_math_symbols_a}', "");
Expect(1, 10223, '\P{^-	Is_misc_math_symbols_a}', "");
Expect(0, 10224, '\p{-	Is_misc_math_symbols_a}', "");
Expect(1, 10224, '\p{^-	Is_misc_math_symbols_a}', "");
Expect(1, 10224, '\P{-	Is_misc_math_symbols_a}', "");
Expect(0, 10224, '\P{^-	Is_misc_math_symbols_a}', "");
Error('\p{ /a/in_Misc_Math_Symbols_a}');
Error('\P{ /a/in_Misc_Math_Symbols_a}');
Expect(1, 10223, '\p{inmiscmathsymbolsa}', "");
Expect(0, 10223, '\p{^inmiscmathsymbolsa}', "");
Expect(0, 10223, '\P{inmiscmathsymbolsa}', "");
Expect(1, 10223, '\P{^inmiscmathsymbolsa}', "");
Expect(0, 10224, '\p{inmiscmathsymbolsa}', "");
Expect(1, 10224, '\p{^inmiscmathsymbolsa}', "");
Expect(1, 10224, '\P{inmiscmathsymbolsa}', "");
Expect(0, 10224, '\P{^inmiscmathsymbolsa}', "");
Expect(1, 10223, '\p{	-in_Misc_MATH_Symbols_A}', "");
Expect(0, 10223, '\p{^	-in_Misc_MATH_Symbols_A}', "");
Expect(0, 10223, '\P{	-in_Misc_MATH_Symbols_A}', "");
Expect(1, 10223, '\P{^	-in_Misc_MATH_Symbols_A}', "");
Expect(0, 10224, '\p{	-in_Misc_MATH_Symbols_A}', "");
Expect(1, 10224, '\p{^	-in_Misc_MATH_Symbols_A}', "");
Expect(1, 10224, '\P{	-in_Misc_MATH_Symbols_A}', "");
Expect(0, 10224, '\P{^	-in_Misc_MATH_Symbols_A}', "");
Error('\p{/a/-MISCELLANEOUS_mathematical_Symbols_B}');
Error('\P{/a/-MISCELLANEOUS_mathematical_Symbols_B}');
Expect(1, 10751, '\p{miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{miscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^miscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{-Miscellaneous_mathematical_Symbols_b}', "");
Expect(0, 10751, '\p{^-Miscellaneous_mathematical_Symbols_b}', "");
Expect(0, 10751, '\P{-Miscellaneous_mathematical_Symbols_b}', "");
Expect(1, 10751, '\P{^-Miscellaneous_mathematical_Symbols_b}', "");
Expect(0, 10752, '\p{-Miscellaneous_mathematical_Symbols_b}', "");
Expect(1, 10752, '\p{^-Miscellaneous_mathematical_Symbols_b}', "");
Expect(1, 10752, '\P{-Miscellaneous_mathematical_Symbols_b}', "");
Expect(0, 10752, '\P{^-Miscellaneous_mathematical_Symbols_b}', "");
Error('\p{ IS_Miscellaneous_MATHEMATICAL_symbols_B/a/}');
Error('\P{ IS_Miscellaneous_MATHEMATICAL_symbols_B/a/}');
Expect(1, 10751, '\p{ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{ismiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^ismiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(0, 10751, '\p{^-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(0, 10751, '\P{-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(1, 10751, '\P{^-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(0, 10752, '\p{-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(1, 10752, '\p{^-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(1, 10752, '\P{-IS_Miscellaneous_Mathematical_symbols_B}', "");
Expect(0, 10752, '\P{^-IS_Miscellaneous_Mathematical_symbols_B}', "");
Error('\p{	:=in_miscellaneous_MATHEMATICAL_symbols_B}');
Error('\P{	:=in_miscellaneous_MATHEMATICAL_symbols_B}');
Expect(1, 10751, '\p{inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\p{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10751, '\P{inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\P{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\p{inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\p{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10752, '\P{inmiscellaneousmathematicalsymbolsb}', "");
Expect(0, 10752, '\P{^inmiscellaneousmathematicalsymbolsb}', "");
Expect(1, 10751, '\p{_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(0, 10751, '\p{^_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(0, 10751, '\P{_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(1, 10751, '\P{^_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(0, 10752, '\p{_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(1, 10752, '\p{^_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(1, 10752, '\P{_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Expect(0, 10752, '\P{^_	In_Miscellaneous_mathematical_SYMBOLS_B}', "");
Error('\p{:=	_MISC_MATH_Symbols_B}');
Error('\P{:=	_MISC_MATH_Symbols_B}');
Expect(1, 10751, '\p{miscmathsymbolsb}', "");
Expect(0, 10751, '\p{^miscmathsymbolsb}', "");
Expect(0, 10751, '\P{miscmathsymbolsb}', "");
Expect(1, 10751, '\P{^miscmathsymbolsb}', "");
Expect(0, 10752, '\p{miscmathsymbolsb}', "");
Expect(1, 10752, '\p{^miscmathsymbolsb}', "");
Expect(1, 10752, '\P{miscmathsymbolsb}', "");
Expect(0, 10752, '\P{^miscmathsymbolsb}', "");
Expect(1, 10751, '\p{ -Misc_Math_symbols_B}', "");
Expect(0, 10751, '\p{^ -Misc_Math_symbols_B}', "");
Expect(0, 10751, '\P{ -Misc_Math_symbols_B}', "");
Expect(1, 10751, '\P{^ -Misc_Math_symbols_B}', "");
Expect(0, 10752, '\p{ -Misc_Math_symbols_B}', "");
Expect(1, 10752, '\p{^ -Misc_Math_symbols_B}', "");
Expect(1, 10752, '\P{ -Misc_Math_symbols_B}', "");
Expect(0, 10752, '\P{^ -Misc_Math_symbols_B}', "");
Error('\p{ is_misc_MATH_Symbols_B/a/}');
Error('\P{ is_misc_MATH_Symbols_B/a/}');
Expect(1, 10751, '\p{ismiscmathsymbolsb}', "");
Expect(0, 10751, '\p{^ismiscmathsymbolsb}', "");
Expect(0, 10751, '\P{ismiscmathsymbolsb}', "");
Expect(1, 10751, '\P{^ismiscmathsymbolsb}', "");
Expect(0, 10752, '\p{ismiscmathsymbolsb}', "");
Expect(1, 10752, '\p{^ismiscmathsymbolsb}', "");
Expect(1, 10752, '\P{ismiscmathsymbolsb}', "");
Expect(0, 10752, '\P{^ismiscmathsymbolsb}', "");
Expect(1, 10751, '\p{- IS_Misc_Math_symbols_b}', "");
Expect(0, 10751, '\p{^- IS_Misc_Math_symbols_b}', "");
Expect(0, 10751, '\P{- IS_Misc_Math_symbols_b}', "");
Expect(1, 10751, '\P{^- IS_Misc_Math_symbols_b}', "");
Expect(0, 10752, '\p{- IS_Misc_Math_symbols_b}', "");
Expect(1, 10752, '\p{^- IS_Misc_Math_symbols_b}', "");
Expect(1, 10752, '\P{- IS_Misc_Math_symbols_b}', "");
Expect(0, 10752, '\P{^- IS_Misc_Math_symbols_b}', "");
Error('\p{/a/_IN_Misc_math_Symbols_B}');
Error('\P{/a/_IN_Misc_math_Symbols_B}');
Expect(1, 10751, '\p{inmiscmathsymbolsb}', "");
Expect(0, 10751, '\p{^inmiscmathsymbolsb}', "");
Expect(0, 10751, '\P{inmiscmathsymbolsb}', "");
Expect(1, 10751, '\P{^inmiscmathsymbolsb}', "");
Expect(0, 10752, '\p{inmiscmathsymbolsb}', "");
Expect(1, 10752, '\p{^inmiscmathsymbolsb}', "");
Expect(1, 10752, '\P{inmiscmathsymbolsb}', "");
Expect(0, 10752, '\P{^inmiscmathsymbolsb}', "");
Expect(1, 10751, '\p{- in_Misc_Math_symbols_B}', "");
Expect(0, 10751, '\p{^- in_Misc_Math_symbols_B}', "");
Expect(0, 10751, '\P{- in_Misc_Math_symbols_B}', "");
Expect(1, 10751, '\P{^- in_Misc_Math_symbols_B}', "");
Expect(0, 10752, '\p{- in_Misc_Math_symbols_B}', "");
Expect(1, 10752, '\p{^- in_Misc_Math_symbols_B}', "");
Expect(1, 10752, '\P{- in_Misc_Math_symbols_B}', "");
Expect(0, 10752, '\P{^- in_Misc_Math_symbols_B}', "");
Error('\p{_/a/miscellaneous_Symbols}');
Error('\P{_/a/miscellaneous_Symbols}');
Expect(1, 9983, '\p{miscellaneoussymbols}', "");
Expect(0, 9983, '\p{^miscellaneoussymbols}', "");
Expect(0, 9983, '\P{miscellaneoussymbols}', "");
Expect(1, 9983, '\P{^miscellaneoussymbols}', "");
Expect(0, 9984, '\p{miscellaneoussymbols}', "");
Expect(1, 9984, '\p{^miscellaneoussymbols}', "");
Expect(1, 9984, '\P{miscellaneoussymbols}', "");
Expect(0, 9984, '\P{^miscellaneoussymbols}', "");
Expect(1, 9983, '\p{_Miscellaneous_symbols}', "");
Expect(0, 9983, '\p{^_Miscellaneous_symbols}', "");
Expect(0, 9983, '\P{_Miscellaneous_symbols}', "");
Expect(1, 9983, '\P{^_Miscellaneous_symbols}', "");
Expect(0, 9984, '\p{_Miscellaneous_symbols}', "");
Expect(1, 9984, '\p{^_Miscellaneous_symbols}', "");
Expect(1, 9984, '\P{_Miscellaneous_symbols}', "");
Expect(0, 9984, '\P{^_Miscellaneous_symbols}', "");
Error('\p{/a/- Is_Miscellaneous_symbols}');
Error('\P{/a/- Is_Miscellaneous_symbols}');
Expect(1, 9983, '\p{ismiscellaneoussymbols}', "");
Expect(0, 9983, '\p{^ismiscellaneoussymbols}', "");
Expect(0, 9983, '\P{ismiscellaneoussymbols}', "");
Expect(1, 9983, '\P{^ismiscellaneoussymbols}', "");
Expect(0, 9984, '\p{ismiscellaneoussymbols}', "");
Expect(1, 9984, '\p{^ismiscellaneoussymbols}', "");
Expect(1, 9984, '\P{ismiscellaneoussymbols}', "");
Expect(0, 9984, '\P{^ismiscellaneoussymbols}', "");
Expect(1, 9983, '\p{-Is_Miscellaneous_symbols}', "");
Expect(0, 9983, '\p{^-Is_Miscellaneous_symbols}', "");
Expect(0, 9983, '\P{-Is_Miscellaneous_symbols}', "");
Expect(1, 9983, '\P{^-Is_Miscellaneous_symbols}', "");
Expect(0, 9984, '\p{-Is_Miscellaneous_symbols}', "");
Expect(1, 9984, '\p{^-Is_Miscellaneous_symbols}', "");
Expect(1, 9984, '\P{-Is_Miscellaneous_symbols}', "");
Expect(0, 9984, '\P{^-Is_Miscellaneous_symbols}', "");
Error('\p{_/a/IN_Miscellaneous_Symbols}');
Error('\P{_/a/IN_Miscellaneous_Symbols}');
Expect(1, 9983, '\p{inmiscellaneoussymbols}', "");
Expect(0, 9983, '\p{^inmiscellaneoussymbols}', "");
Expect(0, 9983, '\P{inmiscellaneoussymbols}', "");
Expect(1, 9983, '\P{^inmiscellaneoussymbols}', "");
Expect(0, 9984, '\p{inmiscellaneoussymbols}', "");
Expect(1, 9984, '\p{^inmiscellaneoussymbols}', "");
Expect(1, 9984, '\P{inmiscellaneoussymbols}', "");
Expect(0, 9984, '\P{^inmiscellaneoussymbols}', "");
Expect(1, 9983, '\p{In_Miscellaneous_Symbols}', "");
Expect(0, 9983, '\p{^In_Miscellaneous_Symbols}', "");
Expect(0, 9983, '\P{In_Miscellaneous_Symbols}', "");
Expect(1, 9983, '\P{^In_Miscellaneous_Symbols}', "");
Expect(0, 9984, '\p{In_Miscellaneous_Symbols}', "");
Expect(1, 9984, '\p{^In_Miscellaneous_Symbols}', "");
Expect(1, 9984, '\P{In_Miscellaneous_Symbols}', "");
Expect(0, 9984, '\P{^In_Miscellaneous_Symbols}', "");
Error('\p{- Misc_Symbols/a/}');
Error('\P{- Misc_Symbols/a/}');
Expect(1, 9983, '\p{miscsymbols}', "");
Expect(0, 9983, '\p{^miscsymbols}', "");
Expect(0, 9983, '\P{miscsymbols}', "");
Expect(1, 9983, '\P{^miscsymbols}', "");
Expect(0, 9984, '\p{miscsymbols}', "");
Expect(1, 9984, '\p{^miscsymbols}', "");
Expect(1, 9984, '\P{miscsymbols}', "");
Expect(0, 9984, '\P{^miscsymbols}', "");
Expect(1, 9983, '\p{ Misc_Symbols}', "");
Expect(0, 9983, '\p{^ Misc_Symbols}', "");
Expect(0, 9983, '\P{ Misc_Symbols}', "");
Expect(1, 9983, '\P{^ Misc_Symbols}', "");
Expect(0, 9984, '\p{ Misc_Symbols}', "");
Expect(1, 9984, '\p{^ Misc_Symbols}', "");
Expect(1, 9984, '\P{ Misc_Symbols}', "");
Expect(0, 9984, '\P{^ Misc_Symbols}', "");
Error('\p{-:=Is_Misc_symbols}');
Error('\P{-:=Is_Misc_symbols}');
Expect(1, 9983, '\p{ismiscsymbols}', "");
Expect(0, 9983, '\p{^ismiscsymbols}', "");
Expect(0, 9983, '\P{ismiscsymbols}', "");
Expect(1, 9983, '\P{^ismiscsymbols}', "");
Expect(0, 9984, '\p{ismiscsymbols}', "");
Expect(1, 9984, '\p{^ismiscsymbols}', "");
Expect(1, 9984, '\P{ismiscsymbols}', "");
Expect(0, 9984, '\P{^ismiscsymbols}', "");
Expect(1, 9983, '\p{ -Is_Misc_SYMBOLS}', "");
Expect(0, 9983, '\p{^ -Is_Misc_SYMBOLS}', "");
Expect(0, 9983, '\P{ -Is_Misc_SYMBOLS}', "");
Expect(1, 9983, '\P{^ -Is_Misc_SYMBOLS}', "");
Expect(0, 9984, '\p{ -Is_Misc_SYMBOLS}', "");
Expect(1, 9984, '\p{^ -Is_Misc_SYMBOLS}', "");
Expect(1, 9984, '\P{ -Is_Misc_SYMBOLS}', "");
Expect(0, 9984, '\P{^ -Is_Misc_SYMBOLS}', "");
Error('\p{	/a/IN_Misc_SYMBOLS}');
Error('\P{	/a/IN_Misc_SYMBOLS}');
Expect(1, 9983, '\p{inmiscsymbols}', "");
Expect(0, 9983, '\p{^inmiscsymbols}', "");
Expect(0, 9983, '\P{inmiscsymbols}', "");
Expect(1, 9983, '\P{^inmiscsymbols}', "");
Expect(0, 9984, '\p{inmiscsymbols}', "");
Expect(1, 9984, '\p{^inmiscsymbols}', "");
Expect(1, 9984, '\P{inmiscsymbols}', "");
Expect(0, 9984, '\P{^inmiscsymbols}', "");
Expect(1, 9983, '\p{-IN_misc_Symbols}', "");
Expect(0, 9983, '\p{^-IN_misc_Symbols}', "");
Expect(0, 9983, '\P{-IN_misc_Symbols}', "");
Expect(1, 9983, '\P{^-IN_misc_Symbols}', "");
Expect(0, 9984, '\p{-IN_misc_Symbols}', "");
Expect(1, 9984, '\p{^-IN_misc_Symbols}', "");
Expect(1, 9984, '\P{-IN_misc_Symbols}', "");
Expect(0, 9984, '\P{^-IN_misc_Symbols}', "");
Error('\p{--miscellaneous_Symbols_And_arrows/a/}');
Error('\P{--miscellaneous_Symbols_And_arrows/a/}');
Expect(1, 11263, '\p{miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^miscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^miscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{miscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^miscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{-_Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11263, '\p{^-_Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11263, '\P{-_Miscellaneous_symbols_And_Arrows}', "");
Expect(1, 11263, '\P{^-_Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11264, '\p{-_Miscellaneous_symbols_And_Arrows}', "");
Expect(1, 11264, '\p{^-_Miscellaneous_symbols_And_Arrows}', "");
Expect(1, 11264, '\P{-_Miscellaneous_symbols_And_Arrows}', "");
Expect(0, 11264, '\P{^-_Miscellaneous_symbols_And_Arrows}', "");
Error('\p{_/a/Is_Miscellaneous_SYMBOLS_AND_Arrows}');
Error('\P{_/a/Is_Miscellaneous_SYMBOLS_AND_Arrows}');
Expect(1, 11263, '\p{ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{ismiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^ismiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(0, 11263, '\p{^-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(0, 11263, '\P{-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(1, 11263, '\P{^-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(0, 11264, '\p{-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(1, 11264, '\p{^-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(1, 11264, '\P{-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Expect(0, 11264, '\P{^-IS_MISCELLANEOUS_symbols_And_arrows}', "");
Error('\p{:=in_MISCELLANEOUS_Symbols_AND_Arrows}');
Error('\P{:=in_MISCELLANEOUS_Symbols_AND_Arrows}');
Expect(1, 11263, '\p{inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\p{^inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11263, '\P{inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\P{^inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\p{inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\p{^inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11264, '\P{inmiscellaneoussymbolsandarrows}', "");
Expect(0, 11264, '\P{^inmiscellaneoussymbolsandarrows}', "");
Expect(1, 11263, '\p{ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(0, 11263, '\p{^ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(0, 11263, '\P{ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(1, 11263, '\P{^ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(0, 11264, '\p{ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(1, 11264, '\p{^ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(1, 11264, '\P{ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Expect(0, 11264, '\P{^ -In_miscellaneous_SYMBOLS_And_Arrows}', "");
Error('\p{:=	 Misc_Arrows}');
Error('\P{:=	 Misc_Arrows}');
Expect(1, 11263, '\p{miscarrows}', "");
Expect(0, 11263, '\p{^miscarrows}', "");
Expect(0, 11263, '\P{miscarrows}', "");
Expect(1, 11263, '\P{^miscarrows}', "");
Expect(0, 11264, '\p{miscarrows}', "");
Expect(1, 11264, '\p{^miscarrows}', "");
Expect(1, 11264, '\P{miscarrows}', "");
Expect(0, 11264, '\P{^miscarrows}', "");
Expect(1, 11263, '\p{-	MISC_ARROWS}', "");
Expect(0, 11263, '\p{^-	MISC_ARROWS}', "");
Expect(0, 11263, '\P{-	MISC_ARROWS}', "");
Expect(1, 11263, '\P{^-	MISC_ARROWS}', "");
Expect(0, 11264, '\p{-	MISC_ARROWS}', "");
Expect(1, 11264, '\p{^-	MISC_ARROWS}', "");
Expect(1, 11264, '\P{-	MISC_ARROWS}', "");
Expect(0, 11264, '\P{^-	MISC_ARROWS}', "");
Error('\p{:= -IS_misc_arrows}');
Error('\P{:= -IS_misc_arrows}');
Expect(1, 11263, '\p{ismiscarrows}', "");
Expect(0, 11263, '\p{^ismiscarrows}', "");
Expect(0, 11263, '\P{ismiscarrows}', "");
Expect(1, 11263, '\P{^ismiscarrows}', "");
Expect(0, 11264, '\p{ismiscarrows}', "");
Expect(1, 11264, '\p{^ismiscarrows}', "");
Expect(1, 11264, '\P{ismiscarrows}', "");
Expect(0, 11264, '\P{^ismiscarrows}', "");
Expect(1, 11263, '\p{ 	Is_Misc_ARROWS}', "");
Expect(0, 11263, '\p{^ 	Is_Misc_ARROWS}', "");
Expect(0, 11263, '\P{ 	Is_Misc_ARROWS}', "");
Expect(1, 11263, '\P{^ 	Is_Misc_ARROWS}', "");
Expect(0, 11264, '\p{ 	Is_Misc_ARROWS}', "");
Expect(1, 11264, '\p{^ 	Is_Misc_ARROWS}', "");
Expect(1, 11264, '\P{ 	Is_Misc_ARROWS}', "");
Expect(0, 11264, '\P{^ 	Is_Misc_ARROWS}', "");
Error('\p{	_in_Misc_ARROWS/a/}');
Error('\P{	_in_Misc_ARROWS/a/}');
Expect(1, 11263, '\p{inmiscarrows}', "");
Expect(0, 11263, '\p{^inmiscarrows}', "");
Expect(0, 11263, '\P{inmiscarrows}', "");
Expect(1, 11263, '\P{^inmiscarrows}', "");
Expect(0, 11264, '\p{inmiscarrows}', "");
Expect(1, 11264, '\p{^inmiscarrows}', "");
Expect(1, 11264, '\P{inmiscarrows}', "");
Expect(0, 11264, '\P{^inmiscarrows}', "");
Expect(1, 11263, '\p{ In_misc_ARROWS}', "");
Expect(0, 11263, '\p{^ In_misc_ARROWS}', "");
Expect(0, 11263, '\P{ In_misc_ARROWS}', "");
Expect(1, 11263, '\P{^ In_misc_ARROWS}', "");
Expect(0, 11264, '\p{ In_misc_ARROWS}', "");
Expect(1, 11264, '\p{^ In_misc_ARROWS}', "");
Expect(1, 11264, '\P{ In_misc_ARROWS}', "");
Expect(0, 11264, '\P{^ In_misc_ARROWS}', "");
Error('\p{/a/ _Miscellaneous_SYMBOLS_and_Pictographs}');
Error('\P{/a/ _Miscellaneous_SYMBOLS_and_Pictographs}');
Expect(1, 128511, '\p{miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^miscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^miscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{miscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^miscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128511, '\p{^_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128511, '\P{_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128511, '\P{^_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128512, '\p{_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128512, '\p{^_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128512, '\P{_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128512, '\P{^_Miscellaneous_symbols_And_Pictographs}', "");
Error('\p{ _is_Miscellaneous_SYMBOLS_And_Pictographs:=}');
Error('\P{ _is_Miscellaneous_SYMBOLS_And_Pictographs:=}');
Expect(1, 128511, '\p{ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{ismiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^ismiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128511, '\p{^--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128511, '\P{--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128511, '\P{^--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128512, '\p{--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128512, '\p{^--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(1, 128512, '\P{--Is_Miscellaneous_symbols_And_Pictographs}', "");
Expect(0, 128512, '\P{^--Is_Miscellaneous_symbols_And_Pictographs}', "");
Error('\p{_ IN_Miscellaneous_symbols_AND_Pictographs:=}');
Error('\P{_ IN_Miscellaneous_symbols_AND_Pictographs:=}');
Expect(1, 128511, '\p{inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\p{^inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128511, '\P{inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\P{^inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\p{inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\p{^inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128512, '\P{inmiscellaneoussymbolsandpictographs}', "");
Expect(0, 128512, '\P{^inmiscellaneoussymbolsandpictographs}', "");
Expect(1, 128511, '\p{		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(0, 128511, '\p{^		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(0, 128511, '\P{		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(1, 128511, '\P{^		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(0, 128512, '\p{		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(1, 128512, '\p{^		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(1, 128512, '\P{		in_Miscellaneous_Symbols_And_Pictographs}', "");
Expect(0, 128512, '\P{^		in_Miscellaneous_Symbols_And_Pictographs}', "");
Error('\p{/a/_-MISC_pictographs}');
Error('\P{/a/_-MISC_pictographs}');
Expect(1, 128511, '\p{miscpictographs}', "");
Expect(0, 128511, '\p{^miscpictographs}', "");
Expect(0, 128511, '\P{miscpictographs}', "");
Expect(1, 128511, '\P{^miscpictographs}', "");
Expect(0, 128512, '\p{miscpictographs}', "");
Expect(1, 128512, '\p{^miscpictographs}', "");
Expect(1, 128512, '\P{miscpictographs}', "");
Expect(0, 128512, '\P{^miscpictographs}', "");
Expect(1, 128511, '\p{_ Misc_Pictographs}', "");
Expect(0, 128511, '\p{^_ Misc_Pictographs}', "");
Expect(0, 128511, '\P{_ Misc_Pictographs}', "");
Expect(1, 128511, '\P{^_ Misc_Pictographs}', "");
Expect(0, 128512, '\p{_ Misc_Pictographs}', "");
Expect(1, 128512, '\p{^_ Misc_Pictographs}', "");
Expect(1, 128512, '\P{_ Misc_Pictographs}', "");
Expect(0, 128512, '\P{^_ Misc_Pictographs}', "");
Error('\p{:=-Is_MISC_pictographs}');
Error('\P{:=-Is_MISC_pictographs}');
Expect(1, 128511, '\p{ismiscpictographs}', "");
Expect(0, 128511, '\p{^ismiscpictographs}', "");
Expect(0, 128511, '\P{ismiscpictographs}', "");
Expect(1, 128511, '\P{^ismiscpictographs}', "");
Expect(0, 128512, '\p{ismiscpictographs}', "");
Expect(1, 128512, '\p{^ismiscpictographs}', "");
Expect(1, 128512, '\P{ismiscpictographs}', "");
Expect(0, 128512, '\P{^ismiscpictographs}', "");
Expect(1, 128511, '\p{-	Is_MISC_Pictographs}', "");
Expect(0, 128511, '\p{^-	Is_MISC_Pictographs}', "");
Expect(0, 128511, '\P{-	Is_MISC_Pictographs}', "");
Expect(1, 128511, '\P{^-	Is_MISC_Pictographs}', "");
Expect(0, 128512, '\p{-	Is_MISC_Pictographs}', "");
Expect(1, 128512, '\p{^-	Is_MISC_Pictographs}', "");
Expect(1, 128512, '\P{-	Is_MISC_Pictographs}', "");
Expect(0, 128512, '\P{^-	Is_MISC_Pictographs}', "");
Error('\p{	_In_Misc_Pictographs/a/}');
Error('\P{	_In_Misc_Pictographs/a/}');
Expect(1, 128511, '\p{inmiscpictographs}', "");
Expect(0, 128511, '\p{^inmiscpictographs}', "");
Expect(0, 128511, '\P{inmiscpictographs}', "");
Expect(1, 128511, '\P{^inmiscpictographs}', "");
Expect(0, 128512, '\p{inmiscpictographs}', "");
Expect(1, 128512, '\p{^inmiscpictographs}', "");
Expect(1, 128512, '\P{inmiscpictographs}', "");
Expect(0, 128512, '\P{^inmiscpictographs}', "");
Expect(1, 128511, '\p{_-In_MISC_PICTOGRAPHS}', "");
Expect(0, 128511, '\p{^_-In_MISC_PICTOGRAPHS}', "");
Expect(0, 128511, '\P{_-In_MISC_PICTOGRAPHS}', "");
Expect(1, 128511, '\P{^_-In_MISC_PICTOGRAPHS}', "");
Expect(0, 128512, '\p{_-In_MISC_PICTOGRAPHS}', "");
Expect(1, 128512, '\p{^_-In_MISC_PICTOGRAPHS}', "");
Expect(1, 128512, '\P{_-In_MISC_PICTOGRAPHS}', "");
Expect(0, 128512, '\P{^_-In_MISC_PICTOGRAPHS}', "");
Error('\p{-/a/Miscellaneous_TECHNICAL}');
Error('\P{-/a/Miscellaneous_TECHNICAL}');
Expect(1, 9215, '\p{miscellaneoustechnical}', "");
Expect(0, 9215, '\p{^miscellaneoustechnical}', "");
Expect(0, 9215, '\P{miscellaneoustechnical}', "");
Expect(1, 9215, '\P{^miscellaneoustechnical}', "");
Expect(0, 9216, '\p{miscellaneoustechnical}', "");
Expect(1, 9216, '\p{^miscellaneoustechnical}', "");
Expect(1, 9216, '\P{miscellaneoustechnical}', "");
Expect(0, 9216, '\P{^miscellaneoustechnical}', "");
Expect(1, 9215, '\p{ _MISCELLANEOUS_Technical}', "");
Expect(0, 9215, '\p{^ _MISCELLANEOUS_Technical}', "");
Expect(0, 9215, '\P{ _MISCELLANEOUS_Technical}', "");
Expect(1, 9215, '\P{^ _MISCELLANEOUS_Technical}', "");
Expect(0, 9216, '\p{ _MISCELLANEOUS_Technical}', "");
Expect(1, 9216, '\p{^ _MISCELLANEOUS_Technical}', "");
Expect(1, 9216, '\P{ _MISCELLANEOUS_Technical}', "");
Expect(0, 9216, '\P{^ _MISCELLANEOUS_Technical}', "");
Error('\p{	 Is_miscellaneous_TECHNICAL/a/}');
Error('\P{	 Is_miscellaneous_TECHNICAL/a/}');
Expect(1, 9215, '\p{ismiscellaneoustechnical}', "");
Expect(0, 9215, '\p{^ismiscellaneoustechnical}', "");
Expect(0, 9215, '\P{ismiscellaneoustechnical}', "");
Expect(1, 9215, '\P{^ismiscellaneoustechnical}', "");
Expect(0, 9216, '\p{ismiscellaneoustechnical}', "");
Expect(1, 9216, '\p{^ismiscellaneoustechnical}', "");
Expect(1, 9216, '\P{ismiscellaneoustechnical}', "");
Expect(0, 9216, '\P{^ismiscellaneoustechnical}', "");
Expect(1, 9215, '\p{__Is_miscellaneous_technical}', "");
Expect(0, 9215, '\p{^__Is_miscellaneous_technical}', "");
Expect(0, 9215, '\P{__Is_miscellaneous_technical}', "");
Expect(1, 9215, '\P{^__Is_miscellaneous_technical}', "");
Expect(0, 9216, '\p{__Is_miscellaneous_technical}', "");
Expect(1, 9216, '\p{^__Is_miscellaneous_technical}', "");
Expect(1, 9216, '\P{__Is_miscellaneous_technical}', "");
Expect(0, 9216, '\P{^__Is_miscellaneous_technical}', "");
Error('\p{-/a/In_Miscellaneous_Technical}');
Error('\P{-/a/In_Miscellaneous_Technical}');
Expect(1, 9215, '\p{inmiscellaneoustechnical}', "");
Expect(0, 9215, '\p{^inmiscellaneoustechnical}', "");
Expect(0, 9215, '\P{inmiscellaneoustechnical}', "");
Expect(1, 9215, '\P{^inmiscellaneoustechnical}', "");
Expect(0, 9216, '\p{inmiscellaneoustechnical}', "");
Expect(1, 9216, '\p{^inmiscellaneoustechnical}', "");
Expect(1, 9216, '\P{inmiscellaneoustechnical}', "");
Expect(0, 9216, '\P{^inmiscellaneoustechnical}', "");
Expect(1, 9215, '\p{	In_miscellaneous_Technical}', "");
Expect(0, 9215, '\p{^	In_miscellaneous_Technical}', "");
Expect(0, 9215, '\P{	In_miscellaneous_Technical}', "");
Expect(1, 9215, '\P{^	In_miscellaneous_Technical}', "");
Expect(0, 9216, '\p{	In_miscellaneous_Technical}', "");
Expect(1, 9216, '\p{^	In_miscellaneous_Technical}', "");
Expect(1, 9216, '\P{	In_miscellaneous_Technical}', "");
Expect(0, 9216, '\P{^	In_miscellaneous_Technical}', "");
Error('\p{ _MISC_Technical/a/}');
Error('\P{ _MISC_Technical/a/}');
Expect(1, 9215, '\p{misctechnical}', "");
Expect(0, 9215, '\p{^misctechnical}', "");
Expect(0, 9215, '\P{misctechnical}', "");
Expect(1, 9215, '\P{^misctechnical}', "");
Expect(0, 9216, '\p{misctechnical}', "");
Expect(1, 9216, '\p{^misctechnical}', "");
Expect(1, 9216, '\P{misctechnical}', "");
Expect(0, 9216, '\P{^misctechnical}', "");
Expect(1, 9215, '\p{	-Misc_TECHNICAL}', "");
Expect(0, 9215, '\p{^	-Misc_TECHNICAL}', "");
Expect(0, 9215, '\P{	-Misc_TECHNICAL}', "");
Expect(1, 9215, '\P{^	-Misc_TECHNICAL}', "");
Expect(0, 9216, '\p{	-Misc_TECHNICAL}', "");
Expect(1, 9216, '\p{^	-Misc_TECHNICAL}', "");
Expect(1, 9216, '\P{	-Misc_TECHNICAL}', "");
Expect(0, 9216, '\P{^	-Misc_TECHNICAL}', "");
Error('\p{ :=is_MISC_Technical}');
Error('\P{ :=is_MISC_Technical}');
Expect(1, 9215, '\p{ismisctechnical}', "");
Expect(0, 9215, '\p{^ismisctechnical}', "");
Expect(0, 9215, '\P{ismisctechnical}', "");
Expect(1, 9215, '\P{^ismisctechnical}', "");
Expect(0, 9216, '\p{ismisctechnical}', "");
Expect(1, 9216, '\p{^ismisctechnical}', "");
Expect(1, 9216, '\P{ismisctechnical}', "");
Expect(0, 9216, '\P{^ismisctechnical}', "");
Expect(1, 9215, '\p{ -is_misc_TECHNICAL}', "");
Expect(0, 9215, '\p{^ -is_misc_TECHNICAL}', "");
Expect(0, 9215, '\P{ -is_misc_TECHNICAL}', "");
Expect(1, 9215, '\P{^ -is_misc_TECHNICAL}', "");
Expect(0, 9216, '\p{ -is_misc_TECHNICAL}', "");
Expect(1, 9216, '\p{^ -is_misc_TECHNICAL}', "");
Expect(1, 9216, '\P{ -is_misc_TECHNICAL}', "");
Expect(0, 9216, '\P{^ -is_misc_TECHNICAL}', "");
Error('\p{/a/_In_Misc_Technical}');
Error('\P{/a/_In_Misc_Technical}');
Expect(1, 9215, '\p{inmisctechnical}', "");
Expect(0, 9215, '\p{^inmisctechnical}', "");
Expect(0, 9215, '\P{inmisctechnical}', "");
Expect(1, 9215, '\P{^inmisctechnical}', "");
Expect(0, 9216, '\p{inmisctechnical}', "");
Expect(1, 9216, '\p{^inmisctechnical}', "");
Expect(1, 9216, '\P{inmisctechnical}', "");
Expect(0, 9216, '\P{^inmisctechnical}', "");
Expect(1, 9215, '\p{	In_Misc_TECHNICAL}', "");
Expect(0, 9215, '\p{^	In_Misc_TECHNICAL}', "");
Expect(0, 9215, '\P{	In_Misc_TECHNICAL}', "");
Expect(1, 9215, '\P{^	In_Misc_TECHNICAL}', "");
Expect(0, 9216, '\p{	In_Misc_TECHNICAL}', "");
Expect(1, 9216, '\p{^	In_Misc_TECHNICAL}', "");
Expect(1, 9216, '\P{	In_Misc_TECHNICAL}', "");
Expect(0, 9216, '\P{^	In_Misc_TECHNICAL}', "");
Error('\p{ MODIFIER_Letter:=}');
Error('\P{ MODIFIER_Letter:=}');
Expect(1, 94111, '\p{modifierletter}', "");
Expect(0, 94111, '\p{^modifierletter}', "");
Expect(0, 94111, '\P{modifierletter}', "");
Expect(1, 94111, '\P{^modifierletter}', "");
Expect(0, 94112, '\p{modifierletter}', "");
Expect(1, 94112, '\p{^modifierletter}', "");
Expect(1, 94112, '\P{modifierletter}', "");
Expect(0, 94112, '\P{^modifierletter}', "");
Expect(1, 94111, '\p{Modifier_letter}', "");
Expect(0, 94111, '\p{^Modifier_letter}', "");
Expect(0, 94111, '\P{Modifier_letter}', "");
Expect(1, 94111, '\P{^Modifier_letter}', "");
Expect(0, 94112, '\p{Modifier_letter}', "");
Expect(1, 94112, '\p{^Modifier_letter}', "");
Expect(1, 94112, '\P{Modifier_letter}', "");
Expect(0, 94112, '\P{^Modifier_letter}', "");
Error('\p{:=- is_modifier_Letter}');
Error('\P{:=- is_modifier_Letter}');
Expect(1, 94111, '\p{ismodifierletter}', "");
Expect(0, 94111, '\p{^ismodifierletter}', "");
Expect(0, 94111, '\P{ismodifierletter}', "");
Expect(1, 94111, '\P{^ismodifierletter}', "");
Expect(0, 94112, '\p{ismodifierletter}', "");
Expect(1, 94112, '\p{^ismodifierletter}', "");
Expect(1, 94112, '\P{ismodifierletter}', "");
Expect(0, 94112, '\P{^ismodifierletter}', "");
Expect(1, 94111, '\p{		IS_Modifier_Letter}', "");
Expect(0, 94111, '\p{^		IS_Modifier_Letter}', "");
Expect(0, 94111, '\P{		IS_Modifier_Letter}', "");
Expect(1, 94111, '\P{^		IS_Modifier_Letter}', "");
Expect(0, 94112, '\p{		IS_Modifier_Letter}', "");
Expect(1, 94112, '\p{^		IS_Modifier_Letter}', "");
Expect(1, 94112, '\P{		IS_Modifier_Letter}', "");
Expect(0, 94112, '\P{^		IS_Modifier_Letter}', "");
Error('\p{ lm/a/}');
Error('\P{ lm/a/}');
Expect(1, 94111, '\p{lm}', "");
Expect(0, 94111, '\p{^lm}', "");
Expect(0, 94111, '\P{lm}', "");
Expect(1, 94111, '\P{^lm}', "");
Expect(0, 94112, '\p{lm}', "");
Expect(1, 94112, '\p{^lm}', "");
Expect(1, 94112, '\P{lm}', "");
Expect(0, 94112, '\P{^lm}', "");
Expect(1, 94111, '\p{_ LM}', "");
Expect(0, 94111, '\p{^_ LM}', "");
Expect(0, 94111, '\P{_ LM}', "");
Expect(1, 94111, '\P{^_ LM}', "");
Expect(0, 94112, '\p{_ LM}', "");
Expect(1, 94112, '\p{^_ LM}', "");
Expect(1, 94112, '\P{_ LM}', "");
Expect(0, 94112, '\P{^_ LM}', "");
Error('\p{ 	IS_LM/a/}');
Error('\P{ 	IS_LM/a/}');
Expect(1, 94111, '\p{islm}', "");
Expect(0, 94111, '\p{^islm}', "");
Expect(0, 94111, '\P{islm}', "");
Expect(1, 94111, '\P{^islm}', "");
Expect(0, 94112, '\p{islm}', "");
Expect(1, 94112, '\p{^islm}', "");
Expect(1, 94112, '\P{islm}', "");
Expect(0, 94112, '\P{^islm}', "");
Expect(1, 94111, '\p{ -IS_Lm}', "");
Expect(0, 94111, '\p{^ -IS_Lm}', "");
Expect(0, 94111, '\P{ -IS_Lm}', "");
Expect(1, 94111, '\P{^ -IS_Lm}', "");
Expect(0, 94112, '\p{ -IS_Lm}', "");
Expect(1, 94112, '\p{^ -IS_Lm}', "");
Expect(1, 94112, '\P{ -IS_Lm}', "");
Expect(0, 94112, '\P{^ -IS_Lm}', "");
Error('\p{	_Modifier_SYMBOL/a/}');
Error('\P{	_Modifier_SYMBOL/a/}');
Expect(1, 65507, '\p{modifiersymbol}', "");
Expect(0, 65507, '\p{^modifiersymbol}', "");
Expect(0, 65507, '\P{modifiersymbol}', "");
Expect(1, 65507, '\P{^modifiersymbol}', "");
Expect(0, 65508, '\p{modifiersymbol}', "");
Expect(1, 65508, '\p{^modifiersymbol}', "");
Expect(1, 65508, '\P{modifiersymbol}', "");
Expect(0, 65508, '\P{^modifiersymbol}', "");
Expect(1, 65507, '\p{	 Modifier_Symbol}', "");
Expect(0, 65507, '\p{^	 Modifier_Symbol}', "");
Expect(0, 65507, '\P{	 Modifier_Symbol}', "");
Expect(1, 65507, '\P{^	 Modifier_Symbol}', "");
Expect(0, 65508, '\p{	 Modifier_Symbol}', "");
Expect(1, 65508, '\p{^	 Modifier_Symbol}', "");
Expect(1, 65508, '\P{	 Modifier_Symbol}', "");
Expect(0, 65508, '\P{^	 Modifier_Symbol}', "");
Error('\p{- Is_Modifier_symbol/a/}');
Error('\P{- Is_Modifier_symbol/a/}');
Expect(1, 65507, '\p{ismodifiersymbol}', "");
Expect(0, 65507, '\p{^ismodifiersymbol}', "");
Expect(0, 65507, '\P{ismodifiersymbol}', "");
Expect(1, 65507, '\P{^ismodifiersymbol}', "");
Expect(0, 65508, '\p{ismodifiersymbol}', "");
Expect(1, 65508, '\p{^ismodifiersymbol}', "");
Expect(1, 65508, '\P{ismodifiersymbol}', "");
Expect(0, 65508, '\P{^ismodifiersymbol}', "");
Expect(1, 65507, '\p{_	Is_modifier_Symbol}', "");
Expect(0, 65507, '\p{^_	Is_modifier_Symbol}', "");
Expect(0, 65507, '\P{_	Is_modifier_Symbol}', "");
Expect(1, 65507, '\P{^_	Is_modifier_Symbol}', "");
Expect(0, 65508, '\p{_	Is_modifier_Symbol}', "");
Expect(1, 65508, '\p{^_	Is_modifier_Symbol}', "");
Expect(1, 65508, '\P{_	Is_modifier_Symbol}', "");
Expect(0, 65508, '\P{^_	Is_modifier_Symbol}', "");
Error('\p{-Sk:=}');
Error('\P{-Sk:=}');
Expect(1, 65507, '\p{sk}', "");
Expect(0, 65507, '\p{^sk}', "");
Expect(0, 65507, '\P{sk}', "");
Expect(1, 65507, '\P{^sk}', "");
Expect(0, 65508, '\p{sk}', "");
Expect(1, 65508, '\p{^sk}', "");
Expect(1, 65508, '\P{sk}', "");
Expect(0, 65508, '\P{^sk}', "");
Expect(1, 65507, '\p{-SK}', "");
Expect(0, 65507, '\p{^-SK}', "");
Expect(0, 65507, '\P{-SK}', "");
Expect(1, 65507, '\P{^-SK}', "");
Expect(0, 65508, '\p{-SK}', "");
Expect(1, 65508, '\p{^-SK}', "");
Expect(1, 65508, '\P{-SK}', "");
Expect(0, 65508, '\P{^-SK}', "");
Error('\p{/a/	is_Sk}');
Error('\P{/a/	is_Sk}');
Expect(1, 65507, '\p{issk}', "");
Expect(0, 65507, '\p{^issk}', "");
Expect(0, 65507, '\P{issk}', "");
Expect(1, 65507, '\P{^issk}', "");
Expect(0, 65508, '\p{issk}', "");
Expect(1, 65508, '\p{^issk}', "");
Expect(1, 65508, '\P{issk}', "");
Expect(0, 65508, '\P{^issk}', "");
Expect(1, 65507, '\p{_is_Sk}', "");
Expect(0, 65507, '\p{^_is_Sk}', "");
Expect(0, 65507, '\P{_is_Sk}', "");
Expect(1, 65507, '\P{^_is_Sk}', "");
Expect(0, 65508, '\p{_is_Sk}', "");
Expect(1, 65508, '\p{^_is_Sk}', "");
Expect(1, 65508, '\P{_is_Sk}', "");
Expect(0, 65508, '\P{^_is_Sk}', "");
Error('\p{ modifier_Tone_LETTERS:=}');
Error('\P{ modifier_Tone_LETTERS:=}');
Expect(1, 42783, '\p{modifiertoneletters}', "");
Expect(0, 42783, '\p{^modifiertoneletters}', "");
Expect(0, 42783, '\P{modifiertoneletters}', "");
Expect(1, 42783, '\P{^modifiertoneletters}', "");
Expect(0, 42784, '\p{modifiertoneletters}', "");
Expect(1, 42784, '\p{^modifiertoneletters}', "");
Expect(1, 42784, '\P{modifiertoneletters}', "");
Expect(0, 42784, '\P{^modifiertoneletters}', "");
Expect(1, 42783, '\p{ -Modifier_Tone_Letters}', "");
Expect(0, 42783, '\p{^ -Modifier_Tone_Letters}', "");
Expect(0, 42783, '\P{ -Modifier_Tone_Letters}', "");
Expect(1, 42783, '\P{^ -Modifier_Tone_Letters}', "");
Expect(0, 42784, '\p{ -Modifier_Tone_Letters}', "");
Expect(1, 42784, '\p{^ -Modifier_Tone_Letters}', "");
Expect(1, 42784, '\P{ -Modifier_Tone_Letters}', "");
Expect(0, 42784, '\P{^ -Modifier_Tone_Letters}', "");
Error('\p{ :=is_Modifier_tone_Letters}');
Error('\P{ :=is_Modifier_tone_Letters}');
Expect(1, 42783, '\p{ismodifiertoneletters}', "");
Expect(0, 42783, '\p{^ismodifiertoneletters}', "");
Expect(0, 42783, '\P{ismodifiertoneletters}', "");
Expect(1, 42783, '\P{^ismodifiertoneletters}', "");
Expect(0, 42784, '\p{ismodifiertoneletters}', "");
Expect(1, 42784, '\p{^ismodifiertoneletters}', "");
Expect(1, 42784, '\P{ismodifiertoneletters}', "");
Expect(0, 42784, '\P{^ismodifiertoneletters}', "");
Expect(1, 42783, '\p{-is_Modifier_tone_letters}', "");
Expect(0, 42783, '\p{^-is_Modifier_tone_letters}', "");
Expect(0, 42783, '\P{-is_Modifier_tone_letters}', "");
Expect(1, 42783, '\P{^-is_Modifier_tone_letters}', "");
Expect(0, 42784, '\p{-is_Modifier_tone_letters}', "");
Expect(1, 42784, '\p{^-is_Modifier_tone_letters}', "");
Expect(1, 42784, '\P{-is_Modifier_tone_letters}', "");
Expect(0, 42784, '\P{^-is_Modifier_tone_letters}', "");
Error('\p{:=_ in_Modifier_Tone_LETTERS}');
Error('\P{:=_ in_Modifier_Tone_LETTERS}');
Expect(1, 42783, '\p{inmodifiertoneletters}', "");
Expect(0, 42783, '\p{^inmodifiertoneletters}', "");
Expect(0, 42783, '\P{inmodifiertoneletters}', "");
Expect(1, 42783, '\P{^inmodifiertoneletters}', "");
Expect(0, 42784, '\p{inmodifiertoneletters}', "");
Expect(1, 42784, '\p{^inmodifiertoneletters}', "");
Expect(1, 42784, '\P{inmodifiertoneletters}', "");
Expect(0, 42784, '\P{^inmodifiertoneletters}', "");
Expect(1, 42783, '\p{--in_Modifier_Tone_LETTERS}', "");
Expect(0, 42783, '\p{^--in_Modifier_Tone_LETTERS}', "");
Expect(0, 42783, '\P{--in_Modifier_Tone_LETTERS}', "");
Expect(1, 42783, '\P{^--in_Modifier_Tone_LETTERS}', "");
Expect(0, 42784, '\p{--in_Modifier_Tone_LETTERS}', "");
Expect(1, 42784, '\p{^--in_Modifier_Tone_LETTERS}', "");
Expect(1, 42784, '\P{--in_Modifier_Tone_LETTERS}', "");
Expect(0, 42784, '\P{^--in_Modifier_Tone_LETTERS}', "");
Error('\p{-/a/Mongolian}');
Error('\P{-/a/Mongolian}');
Expect(1, 6314, '\p{mongolian}', "");
Expect(0, 6314, '\p{^mongolian}', "");
Expect(0, 6314, '\P{mongolian}', "");
Expect(1, 6314, '\P{^mongolian}', "");
Expect(0, 6315, '\p{mongolian}', "");
Expect(1, 6315, '\p{^mongolian}', "");
Expect(1, 6315, '\P{mongolian}', "");
Expect(0, 6315, '\P{^mongolian}', "");
Expect(1, 6314, '\p{	-MONGOLIAN}', "");
Expect(0, 6314, '\p{^	-MONGOLIAN}', "");
Expect(0, 6314, '\P{	-MONGOLIAN}', "");
Expect(1, 6314, '\P{^	-MONGOLIAN}', "");
Expect(0, 6315, '\p{	-MONGOLIAN}', "");
Expect(1, 6315, '\p{^	-MONGOLIAN}', "");
Expect(1, 6315, '\P{	-MONGOLIAN}', "");
Expect(0, 6315, '\P{^	-MONGOLIAN}', "");
Error('\p{/a/Is_Mongolian}');
Error('\P{/a/Is_Mongolian}');
Expect(1, 6314, '\p{ismongolian}', "");
Expect(0, 6314, '\p{^ismongolian}', "");
Expect(0, 6314, '\P{ismongolian}', "");
Expect(1, 6314, '\P{^ismongolian}', "");
Expect(0, 6315, '\p{ismongolian}', "");
Expect(1, 6315, '\p{^ismongolian}', "");
Expect(1, 6315, '\P{ismongolian}', "");
Expect(0, 6315, '\P{^ismongolian}', "");
Expect(1, 6314, '\p{ Is_Mongolian}', "");
Expect(0, 6314, '\p{^ Is_Mongolian}', "");
Expect(0, 6314, '\P{ Is_Mongolian}', "");
Expect(1, 6314, '\P{^ Is_Mongolian}', "");
Expect(0, 6315, '\p{ Is_Mongolian}', "");
Expect(1, 6315, '\p{^ Is_Mongolian}', "");
Expect(1, 6315, '\P{ Is_Mongolian}', "");
Expect(0, 6315, '\P{^ Is_Mongolian}', "");
Error('\p{/a/_ Mong}');
Error('\P{/a/_ Mong}');
Expect(1, 6314, '\p{mong}', "");
Expect(0, 6314, '\p{^mong}', "");
Expect(0, 6314, '\P{mong}', "");
Expect(1, 6314, '\P{^mong}', "");
Expect(0, 6315, '\p{mong}', "");
Expect(1, 6315, '\p{^mong}', "");
Expect(1, 6315, '\P{mong}', "");
Expect(0, 6315, '\P{^mong}', "");
Expect(1, 6314, '\p{ _mong}', "");
Expect(0, 6314, '\p{^ _mong}', "");
Expect(0, 6314, '\P{ _mong}', "");
Expect(1, 6314, '\P{^ _mong}', "");
Expect(0, 6315, '\p{ _mong}', "");
Expect(1, 6315, '\p{^ _mong}', "");
Expect(1, 6315, '\P{ _mong}', "");
Expect(0, 6315, '\P{^ _mong}', "");
Error('\p{ _is_MONG:=}');
Error('\P{ _is_MONG:=}');
Expect(1, 6314, '\p{ismong}', "");
Expect(0, 6314, '\p{^ismong}', "");
Expect(0, 6314, '\P{ismong}', "");
Expect(1, 6314, '\P{^ismong}', "");
Expect(0, 6315, '\p{ismong}', "");
Expect(1, 6315, '\p{^ismong}', "");
Expect(1, 6315, '\P{ismong}', "");
Expect(0, 6315, '\P{^ismong}', "");
Expect(1, 6314, '\p{--is_Mong}', "");
Expect(0, 6314, '\p{^--is_Mong}', "");
Expect(0, 6314, '\P{--is_Mong}', "");
Expect(1, 6314, '\P{^--is_Mong}', "");
Expect(0, 6315, '\p{--is_Mong}', "");
Expect(1, 6315, '\p{^--is_Mong}', "");
Expect(1, 6315, '\P{--is_Mong}', "");
Expect(0, 6315, '\P{^--is_Mong}', "");
Error('\p{ /a/Musical_SYMBOLS}');
Error('\P{ /a/Musical_SYMBOLS}');
Expect(1, 119295, '\p{musicalsymbols}', "");
Expect(0, 119295, '\p{^musicalsymbols}', "");
Expect(0, 119295, '\P{musicalsymbols}', "");
Expect(1, 119295, '\P{^musicalsymbols}', "");
Expect(0, 119296, '\p{musicalsymbols}', "");
Expect(1, 119296, '\p{^musicalsymbols}', "");
Expect(1, 119296, '\P{musicalsymbols}', "");
Expect(0, 119296, '\P{^musicalsymbols}', "");
Expect(1, 119295, '\p{__MUSICAL_SYMBOLS}', "");
Expect(0, 119295, '\p{^__MUSICAL_SYMBOLS}', "");
Expect(0, 119295, '\P{__MUSICAL_SYMBOLS}', "");
Expect(1, 119295, '\P{^__MUSICAL_SYMBOLS}', "");
Expect(0, 119296, '\p{__MUSICAL_SYMBOLS}', "");
Expect(1, 119296, '\p{^__MUSICAL_SYMBOLS}', "");
Expect(1, 119296, '\P{__MUSICAL_SYMBOLS}', "");
Expect(0, 119296, '\P{^__MUSICAL_SYMBOLS}', "");
Error('\p{:=-is_MUSICAL_Symbols}');
Error('\P{:=-is_MUSICAL_Symbols}');
Expect(1, 119295, '\p{ismusicalsymbols}', "");
Expect(0, 119295, '\p{^ismusicalsymbols}', "");
Expect(0, 119295, '\P{ismusicalsymbols}', "");
Expect(1, 119295, '\P{^ismusicalsymbols}', "");
Expect(0, 119296, '\p{ismusicalsymbols}', "");
Expect(1, 119296, '\p{^ismusicalsymbols}', "");
Expect(1, 119296, '\P{ismusicalsymbols}', "");
Expect(0, 119296, '\P{^ismusicalsymbols}', "");
Expect(1, 119295, '\p{ IS_musical_SYMBOLS}', "");
Expect(0, 119295, '\p{^ IS_musical_SYMBOLS}', "");
Expect(0, 119295, '\P{ IS_musical_SYMBOLS}', "");
Expect(1, 119295, '\P{^ IS_musical_SYMBOLS}', "");
Expect(0, 119296, '\p{ IS_musical_SYMBOLS}', "");
Expect(1, 119296, '\p{^ IS_musical_SYMBOLS}', "");
Expect(1, 119296, '\P{ IS_musical_SYMBOLS}', "");
Expect(0, 119296, '\P{^ IS_musical_SYMBOLS}', "");
Error('\p{		in_Musical_Symbols/a/}');
Error('\P{		in_Musical_Symbols/a/}');
Expect(1, 119295, '\p{inmusicalsymbols}', "");
Expect(0, 119295, '\p{^inmusicalsymbols}', "");
Expect(0, 119295, '\P{inmusicalsymbols}', "");
Expect(1, 119295, '\P{^inmusicalsymbols}', "");
Expect(0, 119296, '\p{inmusicalsymbols}', "");
Expect(1, 119296, '\p{^inmusicalsymbols}', "");
Expect(1, 119296, '\P{inmusicalsymbols}', "");
Expect(0, 119296, '\P{^inmusicalsymbols}', "");
Expect(1, 119295, '\p{	-in_Musical_Symbols}', "");
Expect(0, 119295, '\p{^	-in_Musical_Symbols}', "");
Expect(0, 119295, '\P{	-in_Musical_Symbols}', "");
Expect(1, 119295, '\P{^	-in_Musical_Symbols}', "");
Expect(0, 119296, '\p{	-in_Musical_Symbols}', "");
Expect(1, 119296, '\p{^	-in_Musical_Symbols}', "");
Expect(1, 119296, '\P{	-in_Musical_Symbols}', "");
Expect(0, 119296, '\P{^	-in_Musical_Symbols}', "");
Error('\p{-/a/Music}');
Error('\P{-/a/Music}');
Expect(1, 119295, '\p{music}', "");
Expect(0, 119295, '\p{^music}', "");
Expect(0, 119295, '\P{music}', "");
Expect(1, 119295, '\P{^music}', "");
Expect(0, 119296, '\p{music}', "");
Expect(1, 119296, '\p{^music}', "");
Expect(1, 119296, '\P{music}', "");
Expect(0, 119296, '\P{^music}', "");
Expect(1, 119295, '\p{	music}', "");
Expect(0, 119295, '\p{^	music}', "");
Expect(0, 119295, '\P{	music}', "");
Expect(1, 119295, '\P{^	music}', "");
Expect(0, 119296, '\p{	music}', "");
Expect(1, 119296, '\p{^	music}', "");
Expect(1, 119296, '\P{	music}', "");
Expect(0, 119296, '\P{^	music}', "");
Error('\p{	/a/Is_MUSIC}');
Error('\P{	/a/Is_MUSIC}');
Expect(1, 119295, '\p{ismusic}', "");
Expect(0, 119295, '\p{^ismusic}', "");
Expect(0, 119295, '\P{ismusic}', "");
Expect(1, 119295, '\P{^ismusic}', "");
Expect(0, 119296, '\p{ismusic}', "");
Expect(1, 119296, '\p{^ismusic}', "");
Expect(1, 119296, '\P{ismusic}', "");
Expect(0, 119296, '\P{^ismusic}', "");
Expect(1, 119295, '\p{	_Is_music}', "");
Expect(0, 119295, '\p{^	_Is_music}', "");
Expect(0, 119295, '\P{	_Is_music}', "");
Expect(1, 119295, '\P{^	_Is_music}', "");
Expect(0, 119296, '\p{	_Is_music}', "");
Expect(1, 119296, '\p{^	_Is_music}', "");
Expect(1, 119296, '\P{	_Is_music}', "");
Expect(0, 119296, '\P{^	_Is_music}', "");
Error('\p{IN_music:=}');
Error('\P{IN_music:=}');
Expect(1, 119295, '\p{inmusic}', "");
Expect(0, 119295, '\p{^inmusic}', "");
Expect(0, 119295, '\P{inmusic}', "");
Expect(1, 119295, '\P{^inmusic}', "");
Expect(0, 119296, '\p{inmusic}', "");
Expect(1, 119296, '\p{^inmusic}', "");
Expect(1, 119296, '\P{inmusic}', "");
Expect(0, 119296, '\P{^inmusic}', "");
Expect(1, 119295, '\p{In_MUSIC}', "");
Expect(0, 119295, '\p{^In_MUSIC}', "");
Expect(0, 119295, '\P{In_MUSIC}', "");
Expect(1, 119295, '\P{^In_MUSIC}', "");
Expect(0, 119296, '\p{In_MUSIC}', "");
Expect(1, 119296, '\p{^In_MUSIC}', "");
Expect(1, 119296, '\P{In_MUSIC}', "");
Expect(0, 119296, '\P{^In_MUSIC}', "");
Error('\p{ /a/Myanmar}');
Error('\P{ /a/Myanmar}');
Expect(1, 43643, '\p{myanmar}', "");
Expect(0, 43643, '\p{^myanmar}', "");
Expect(0, 43643, '\P{myanmar}', "");
Expect(1, 43643, '\P{^myanmar}', "");
Expect(0, 43644, '\p{myanmar}', "");
Expect(1, 43644, '\p{^myanmar}', "");
Expect(1, 43644, '\P{myanmar}', "");
Expect(0, 43644, '\P{^myanmar}', "");
Expect(1, 43643, '\p{--myanmar}', "");
Expect(0, 43643, '\p{^--myanmar}', "");
Expect(0, 43643, '\P{--myanmar}', "");
Expect(1, 43643, '\P{^--myanmar}', "");
Expect(0, 43644, '\p{--myanmar}', "");
Expect(1, 43644, '\p{^--myanmar}', "");
Expect(1, 43644, '\P{--myanmar}', "");
Expect(0, 43644, '\P{^--myanmar}', "");
Error('\p{__is_Myanmar:=}');
Error('\P{__is_Myanmar:=}');
Expect(1, 43643, '\p{ismyanmar}', "");
Expect(0, 43643, '\p{^ismyanmar}', "");
Expect(0, 43643, '\P{ismyanmar}', "");
Expect(1, 43643, '\P{^ismyanmar}', "");
Expect(0, 43644, '\p{ismyanmar}', "");
Expect(1, 43644, '\p{^ismyanmar}', "");
Expect(1, 43644, '\P{ismyanmar}', "");
Expect(0, 43644, '\P{^ismyanmar}', "");
Expect(1, 43643, '\p{_-is_Myanmar}', "");
Expect(0, 43643, '\p{^_-is_Myanmar}', "");
Expect(0, 43643, '\P{_-is_Myanmar}', "");
Expect(1, 43643, '\P{^_-is_Myanmar}', "");
Expect(0, 43644, '\p{_-is_Myanmar}', "");
Expect(1, 43644, '\p{^_-is_Myanmar}', "");
Expect(1, 43644, '\P{_-is_Myanmar}', "");
Expect(0, 43644, '\P{^_-is_Myanmar}', "");
Error('\p{/a/MYMR}');
Error('\P{/a/MYMR}');
Expect(1, 43643, '\p{mymr}', "");
Expect(0, 43643, '\p{^mymr}', "");
Expect(0, 43643, '\P{mymr}', "");
Expect(1, 43643, '\P{^mymr}', "");
Expect(0, 43644, '\p{mymr}', "");
Expect(1, 43644, '\p{^mymr}', "");
Expect(1, 43644, '\P{mymr}', "");
Expect(0, 43644, '\P{^mymr}', "");
Expect(1, 43643, '\p{ mymr}', "");
Expect(0, 43643, '\p{^ mymr}', "");
Expect(0, 43643, '\P{ mymr}', "");
Expect(1, 43643, '\P{^ mymr}', "");
Expect(0, 43644, '\p{ mymr}', "");
Expect(1, 43644, '\p{^ mymr}', "");
Expect(1, 43644, '\P{ mymr}', "");
Expect(0, 43644, '\P{^ mymr}', "");
Error('\p{:=	IS_MYMR}');
Error('\P{:=	IS_MYMR}');
Expect(1, 43643, '\p{ismymr}', "");
Expect(0, 43643, '\p{^ismymr}', "");
Expect(0, 43643, '\P{ismymr}', "");
Expect(1, 43643, '\P{^ismymr}', "");
Expect(0, 43644, '\p{ismymr}', "");
Expect(1, 43644, '\p{^ismymr}', "");
Expect(1, 43644, '\P{ismymr}', "");
Expect(0, 43644, '\P{^ismymr}', "");
Expect(1, 43643, '\p{	 Is_Mymr}', "");
Expect(0, 43643, '\p{^	 Is_Mymr}', "");
Expect(0, 43643, '\P{	 Is_Mymr}', "");
Expect(1, 43643, '\P{^	 Is_Mymr}', "");
Expect(0, 43644, '\p{	 Is_Mymr}', "");
Expect(1, 43644, '\p{^	 Is_Mymr}', "");
Expect(1, 43644, '\P{	 Is_Mymr}', "");
Expect(0, 43644, '\P{^	 Is_Mymr}', "");
Error('\p{		MYANMAR_EXTENDED_A:=}');
Error('\P{		MYANMAR_EXTENDED_A:=}');
Expect(1, 43647, '\p{myanmarextendeda}', "");
Expect(0, 43647, '\p{^myanmarextendeda}', "");
Expect(0, 43647, '\P{myanmarextendeda}', "");
Expect(1, 43647, '\P{^myanmarextendeda}', "");
Expect(0, 43648, '\p{myanmarextendeda}', "");
Expect(1, 43648, '\p{^myanmarextendeda}', "");
Expect(1, 43648, '\P{myanmarextendeda}', "");
Expect(0, 43648, '\P{^myanmarextendeda}', "");
Expect(1, 43647, '\p{  Myanmar_Extended_A}', "");
Expect(0, 43647, '\p{^  Myanmar_Extended_A}', "");
Expect(0, 43647, '\P{  Myanmar_Extended_A}', "");
Expect(1, 43647, '\P{^  Myanmar_Extended_A}', "");
Expect(0, 43648, '\p{  Myanmar_Extended_A}', "");
Expect(1, 43648, '\p{^  Myanmar_Extended_A}', "");
Expect(1, 43648, '\P{  Myanmar_Extended_A}', "");
Expect(0, 43648, '\P{^  Myanmar_Extended_A}', "");
Error('\p{:=Is_myanmar_EXTENDED_a}');
Error('\P{:=Is_myanmar_EXTENDED_a}');
Expect(1, 43647, '\p{ismyanmarextendeda}', "");
Expect(0, 43647, '\p{^ismyanmarextendeda}', "");
Expect(0, 43647, '\P{ismyanmarextendeda}', "");
Expect(1, 43647, '\P{^ismyanmarextendeda}', "");
Expect(0, 43648, '\p{ismyanmarextendeda}', "");
Expect(1, 43648, '\p{^ismyanmarextendeda}', "");
Expect(1, 43648, '\P{ismyanmarextendeda}', "");
Expect(0, 43648, '\P{^ismyanmarextendeda}', "");
Expect(1, 43647, '\p{	Is_myanmar_Extended_A}', "");
Expect(0, 43647, '\p{^	Is_myanmar_Extended_A}', "");
Expect(0, 43647, '\P{	Is_myanmar_Extended_A}', "");
Expect(1, 43647, '\P{^	Is_myanmar_Extended_A}', "");
Expect(0, 43648, '\p{	Is_myanmar_Extended_A}', "");
Expect(1, 43648, '\p{^	Is_myanmar_Extended_A}', "");
Expect(1, 43648, '\P{	Is_myanmar_Extended_A}', "");
Expect(0, 43648, '\P{^	Is_myanmar_Extended_A}', "");
Error('\p{:=_	in_myanmar_Extended_A}');
Error('\P{:=_	in_myanmar_Extended_A}');
Expect(1, 43647, '\p{inmyanmarextendeda}', "");
Expect(0, 43647, '\p{^inmyanmarextendeda}', "");
Expect(0, 43647, '\P{inmyanmarextendeda}', "");
Expect(1, 43647, '\P{^inmyanmarextendeda}', "");
Expect(0, 43648, '\p{inmyanmarextendeda}', "");
Expect(1, 43648, '\p{^inmyanmarextendeda}', "");
Expect(1, 43648, '\P{inmyanmarextendeda}', "");
Expect(0, 43648, '\P{^inmyanmarextendeda}', "");
Expect(1, 43647, '\p{ _in_Myanmar_Extended_a}', "");
Expect(0, 43647, '\p{^ _in_Myanmar_Extended_a}', "");
Expect(0, 43647, '\P{ _in_Myanmar_Extended_a}', "");
Expect(1, 43647, '\P{^ _in_Myanmar_Extended_a}', "");
Expect(0, 43648, '\p{ _in_Myanmar_Extended_a}', "");
Expect(1, 43648, '\p{^ _in_Myanmar_Extended_a}', "");
Expect(1, 43648, '\P{ _in_Myanmar_Extended_a}', "");
Expect(0, 43648, '\P{^ _in_Myanmar_Extended_a}', "");
Error('\p{		Myanmar_ext_A:=}');
Error('\P{		Myanmar_ext_A:=}');
Expect(1, 43647, '\p{myanmarexta}', "");
Expect(0, 43647, '\p{^myanmarexta}', "");
Expect(0, 43647, '\P{myanmarexta}', "");
Expect(1, 43647, '\P{^myanmarexta}', "");
Expect(0, 43648, '\p{myanmarexta}', "");
Expect(1, 43648, '\p{^myanmarexta}', "");
Expect(1, 43648, '\P{myanmarexta}', "");
Expect(0, 43648, '\P{^myanmarexta}', "");
Expect(1, 43647, '\p{_myanmar_Ext_A}', "");
Expect(0, 43647, '\p{^_myanmar_Ext_A}', "");
Expect(0, 43647, '\P{_myanmar_Ext_A}', "");
Expect(1, 43647, '\P{^_myanmar_Ext_A}', "");
Expect(0, 43648, '\p{_myanmar_Ext_A}', "");
Expect(1, 43648, '\p{^_myanmar_Ext_A}', "");
Expect(1, 43648, '\P{_myanmar_Ext_A}', "");
Expect(0, 43648, '\P{^_myanmar_Ext_A}', "");
Error('\p{_/a/is_MYANMAR_ext_A}');
Error('\P{_/a/is_MYANMAR_ext_A}');
Expect(1, 43647, '\p{ismyanmarexta}', "");
Expect(0, 43647, '\p{^ismyanmarexta}', "");
Expect(0, 43647, '\P{ismyanmarexta}', "");
Expect(1, 43647, '\P{^ismyanmarexta}', "");
Expect(0, 43648, '\p{ismyanmarexta}', "");
Expect(1, 43648, '\p{^ismyanmarexta}', "");
Expect(1, 43648, '\P{ismyanmarexta}', "");
Expect(0, 43648, '\P{^ismyanmarexta}', "");
Expect(1, 43647, '\p{	-is_Myanmar_Ext_A}', "");
Expect(0, 43647, '\p{^	-is_Myanmar_Ext_A}', "");
Expect(0, 43647, '\P{	-is_Myanmar_Ext_A}', "");
Expect(1, 43647, '\P{^	-is_Myanmar_Ext_A}', "");
Expect(0, 43648, '\p{	-is_Myanmar_Ext_A}', "");
Expect(1, 43648, '\p{^	-is_Myanmar_Ext_A}', "");
Expect(1, 43648, '\P{	-is_Myanmar_Ext_A}', "");
Expect(0, 43648, '\P{^	-is_Myanmar_Ext_A}', "");
Error('\p{:=IN_MYANMAR_ext_A}');
Error('\P{:=IN_MYANMAR_ext_A}');
Expect(1, 43647, '\p{inmyanmarexta}', "");
Expect(0, 43647, '\p{^inmyanmarexta}', "");
Expect(0, 43647, '\P{inmyanmarexta}', "");
Expect(1, 43647, '\P{^inmyanmarexta}', "");
Expect(0, 43648, '\p{inmyanmarexta}', "");
Expect(1, 43648, '\p{^inmyanmarexta}', "");
Expect(1, 43648, '\P{inmyanmarexta}', "");
Expect(0, 43648, '\P{^inmyanmarexta}', "");
Expect(1, 43647, '\p{- In_Myanmar_Ext_a}', "");
Expect(0, 43647, '\p{^- In_Myanmar_Ext_a}', "");
Expect(0, 43647, '\P{- In_Myanmar_Ext_a}', "");
Expect(1, 43647, '\P{^- In_Myanmar_Ext_a}', "");
Expect(0, 43648, '\p{- In_Myanmar_Ext_a}', "");
Expect(1, 43648, '\p{^- In_Myanmar_Ext_a}', "");
Expect(1, 43648, '\P{- In_Myanmar_Ext_a}', "");
Expect(0, 43648, '\P{^- In_Myanmar_Ext_a}', "");
Error('\p{:=NEW_Tai_Lue}');
Error('\P{:=NEW_Tai_Lue}');
Expect(1, 6623, '\p{newtailue}', "");
Expect(0, 6623, '\p{^newtailue}', "");
Expect(0, 6623, '\P{newtailue}', "");
Expect(1, 6623, '\P{^newtailue}', "");
Expect(0, 6624, '\p{newtailue}', "");
Expect(1, 6624, '\p{^newtailue}', "");
Expect(1, 6624, '\P{newtailue}', "");
Expect(0, 6624, '\P{^newtailue}', "");
Expect(1, 6623, '\p{		New_tai_lue}', "");
Expect(0, 6623, '\p{^		New_tai_lue}', "");
Expect(0, 6623, '\P{		New_tai_lue}', "");
Expect(1, 6623, '\P{^		New_tai_lue}', "");
Expect(0, 6624, '\p{		New_tai_lue}', "");
Expect(1, 6624, '\p{^		New_tai_lue}', "");
Expect(1, 6624, '\P{		New_tai_lue}', "");
Expect(0, 6624, '\P{^		New_tai_lue}', "");
Error('\p{:=is_NEW_Tai_Lue}');
Error('\P{:=is_NEW_Tai_Lue}');
Expect(1, 6623, '\p{isnewtailue}', "");
Expect(0, 6623, '\p{^isnewtailue}', "");
Expect(0, 6623, '\P{isnewtailue}', "");
Expect(1, 6623, '\P{^isnewtailue}', "");
Expect(0, 6624, '\p{isnewtailue}', "");
Expect(1, 6624, '\p{^isnewtailue}', "");
Expect(1, 6624, '\P{isnewtailue}', "");
Expect(0, 6624, '\P{^isnewtailue}', "");
Expect(1, 6623, '\p{is_new_TAI_Lue}', "");
Expect(0, 6623, '\p{^is_new_TAI_Lue}', "");
Expect(0, 6623, '\P{is_new_TAI_Lue}', "");
Expect(1, 6623, '\P{^is_new_TAI_Lue}', "");
Expect(0, 6624, '\p{is_new_TAI_Lue}', "");
Expect(1, 6624, '\p{^is_new_TAI_Lue}', "");
Expect(1, 6624, '\P{is_new_TAI_Lue}', "");
Expect(0, 6624, '\P{^is_new_TAI_Lue}', "");
Error('\p{		Talu/a/}');
Error('\P{		Talu/a/}');
Expect(1, 6623, '\p{talu}', "");
Expect(0, 6623, '\p{^talu}', "");
Expect(0, 6623, '\P{talu}', "");
Expect(1, 6623, '\P{^talu}', "");
Expect(0, 6624, '\p{talu}', "");
Expect(1, 6624, '\p{^talu}', "");
Expect(1, 6624, '\P{talu}', "");
Expect(0, 6624, '\P{^talu}', "");
Expect(1, 6623, '\p{_talu}', "");
Expect(0, 6623, '\p{^_talu}', "");
Expect(0, 6623, '\P{_talu}', "");
Expect(1, 6623, '\P{^_talu}', "");
Expect(0, 6624, '\p{_talu}', "");
Expect(1, 6624, '\p{^_talu}', "");
Expect(1, 6624, '\P{_talu}', "");
Expect(0, 6624, '\P{^_talu}', "");
Error('\p{ -Is_TALU:=}');
Error('\P{ -Is_TALU:=}');
Expect(1, 6623, '\p{istalu}', "");
Expect(0, 6623, '\p{^istalu}', "");
Expect(0, 6623, '\P{istalu}', "");
Expect(1, 6623, '\P{^istalu}', "");
Expect(0, 6624, '\p{istalu}', "");
Expect(1, 6624, '\p{^istalu}', "");
Expect(1, 6624, '\P{istalu}', "");
Expect(0, 6624, '\P{^istalu}', "");
Expect(1, 6623, '\p{- IS_talu}', "");
Expect(0, 6623, '\p{^- IS_talu}', "");
Expect(0, 6623, '\P{- IS_talu}', "");
Expect(1, 6623, '\P{^- IS_talu}', "");
Expect(0, 6624, '\p{- IS_talu}', "");
Expect(1, 6624, '\p{^- IS_talu}', "");
Expect(1, 6624, '\P{- IS_talu}', "");
Expect(0, 6624, '\P{^- IS_talu}', "");
Error('\p{ :=NKO}');
Error('\P{ :=NKO}');
Expect(1, 2042, '\p{nko}', "");
Expect(0, 2042, '\p{^nko}', "");
Expect(0, 2042, '\P{nko}', "");
Expect(1, 2042, '\P{^nko}', "");
Expect(0, 2043, '\p{nko}', "");
Expect(1, 2043, '\p{^nko}', "");
Expect(1, 2043, '\P{nko}', "");
Expect(0, 2043, '\P{^nko}', "");
Expect(1, 2042, '\p{_-NKO}', "");
Expect(0, 2042, '\p{^_-NKO}', "");
Expect(0, 2042, '\P{_-NKO}', "");
Expect(1, 2042, '\P{^_-NKO}', "");
Expect(0, 2043, '\p{_-NKO}', "");
Expect(1, 2043, '\p{^_-NKO}', "");
Expect(1, 2043, '\P{_-NKO}', "");
Expect(0, 2043, '\P{^_-NKO}', "");
Error('\p{/a/-IS_nko}');
Error('\P{/a/-IS_nko}');
Expect(1, 2042, '\p{isnko}', "");
Expect(0, 2042, '\p{^isnko}', "");
Expect(0, 2042, '\P{isnko}', "");
Expect(1, 2042, '\P{^isnko}', "");
Expect(0, 2043, '\p{isnko}', "");
Expect(1, 2043, '\p{^isnko}', "");
Expect(1, 2043, '\P{isnko}', "");
Expect(0, 2043, '\P{^isnko}', "");
Expect(1, 2042, '\p{  Is_Nko}', "");
Expect(0, 2042, '\p{^  Is_Nko}', "");
Expect(0, 2042, '\P{  Is_Nko}', "");
Expect(1, 2042, '\P{^  Is_Nko}', "");
Expect(0, 2043, '\p{  Is_Nko}', "");
Expect(1, 2043, '\p{^  Is_Nko}', "");
Expect(1, 2043, '\P{  Is_Nko}', "");
Expect(0, 2043, '\P{^  Is_Nko}', "");
Error('\p{/a/-	NKOO}');
Error('\P{/a/-	NKOO}');
Expect(1, 2042, '\p{nkoo}', "");
Expect(0, 2042, '\p{^nkoo}', "");
Expect(0, 2042, '\P{nkoo}', "");
Expect(1, 2042, '\P{^nkoo}', "");
Expect(0, 2043, '\p{nkoo}', "");
Expect(1, 2043, '\p{^nkoo}', "");
Expect(1, 2043, '\P{nkoo}', "");
Expect(0, 2043, '\P{^nkoo}', "");
Expect(1, 2042, '\p{_	nkoo}', "");
Expect(0, 2042, '\p{^_	nkoo}', "");
Expect(0, 2042, '\P{_	nkoo}', "");
Expect(1, 2042, '\P{^_	nkoo}', "");
Expect(0, 2043, '\p{_	nkoo}', "");
Expect(1, 2043, '\p{^_	nkoo}', "");
Expect(1, 2043, '\P{_	nkoo}', "");
Expect(0, 2043, '\P{^_	nkoo}', "");
Error('\p{_/a/IS_Nkoo}');
Error('\P{_/a/IS_Nkoo}');
Expect(1, 2042, '\p{isnkoo}', "");
Expect(0, 2042, '\p{^isnkoo}', "");
Expect(0, 2042, '\P{isnkoo}', "");
Expect(1, 2042, '\P{^isnkoo}', "");
Expect(0, 2043, '\p{isnkoo}', "");
Expect(1, 2043, '\p{^isnkoo}', "");
Expect(1, 2043, '\P{isnkoo}', "");
Expect(0, 2043, '\P{^isnkoo}', "");
Expect(1, 2042, '\p{_	Is_nkoo}', "");
Expect(0, 2042, '\p{^_	Is_nkoo}', "");
Expect(0, 2042, '\P{_	Is_nkoo}', "");
Expect(1, 2042, '\P{^_	Is_nkoo}', "");
Expect(0, 2043, '\p{_	Is_nkoo}', "");
Expect(1, 2043, '\p{^_	Is_nkoo}', "");
Expect(1, 2043, '\P{_	Is_nkoo}', "");
Expect(0, 2043, '\P{^_	Is_nkoo}', "");
Error('\p{		No_Block:=}');
Error('\P{		No_Block:=}');
Expect(1, 918000, '\p{noblock}', "");
Expect(0, 918000, '\p{^noblock}', "");
Expect(0, 918000, '\P{noblock}', "");
Expect(1, 918000, '\P{^noblock}', "");
Expect(0, 983040, '\p{noblock}', "");
Expect(1, 983040, '\p{^noblock}', "");
Expect(1, 983040, '\P{noblock}', "");
Expect(0, 983040, '\P{^noblock}', "");
Expect(1, 918000, '\p{-	No_Block}', "");
Expect(0, 918000, '\p{^-	No_Block}', "");
Expect(0, 918000, '\P{-	No_Block}', "");
Expect(1, 918000, '\P{^-	No_Block}', "");
Expect(0, 983040, '\p{-	No_Block}', "");
Expect(1, 983040, '\p{^-	No_Block}', "");
Expect(1, 983040, '\P{-	No_Block}', "");
Expect(0, 983040, '\P{^-	No_Block}', "");
Error('\p{-	Is_no_Block:=}');
Error('\P{-	Is_no_Block:=}');
Expect(1, 918000, '\p{isnoblock}', "");
Expect(0, 918000, '\p{^isnoblock}', "");
Expect(0, 918000, '\P{isnoblock}', "");
Expect(1, 918000, '\P{^isnoblock}', "");
Expect(0, 983040, '\p{isnoblock}', "");
Expect(1, 983040, '\p{^isnoblock}', "");
Expect(1, 983040, '\P{isnoblock}', "");
Expect(0, 983040, '\P{^isnoblock}', "");
Expect(1, 918000, '\p{_	Is_no_Block}', "");
Expect(0, 918000, '\p{^_	Is_no_Block}', "");
Expect(0, 918000, '\P{_	Is_no_Block}', "");
Expect(1, 918000, '\P{^_	Is_no_Block}', "");
Expect(0, 983040, '\p{_	Is_no_Block}', "");
Expect(1, 983040, '\p{^_	Is_no_Block}', "");
Expect(1, 983040, '\P{_	Is_no_Block}', "");
Expect(0, 983040, '\P{^_	Is_no_Block}', "");
Error('\p{-IN_no_Block:=}');
Error('\P{-IN_no_Block:=}');
Expect(1, 918000, '\p{innoblock}', "");
Expect(0, 918000, '\p{^innoblock}', "");
Expect(0, 918000, '\P{innoblock}', "");
Expect(1, 918000, '\P{^innoblock}', "");
Expect(0, 983040, '\p{innoblock}', "");
Expect(1, 983040, '\p{^innoblock}', "");
Expect(1, 983040, '\P{innoblock}', "");
Expect(0, 983040, '\P{^innoblock}', "");
Expect(1, 918000, '\p{-_IN_NO_Block}', "");
Expect(0, 918000, '\p{^-_IN_NO_Block}', "");
Expect(0, 918000, '\P{-_IN_NO_Block}', "");
Expect(1, 918000, '\P{^-_IN_NO_Block}', "");
Expect(0, 983040, '\p{-_IN_NO_Block}', "");
Expect(1, 983040, '\p{^-_IN_NO_Block}', "");
Expect(1, 983040, '\P{-_IN_NO_Block}', "");
Expect(0, 983040, '\P{^-_IN_NO_Block}', "");
Error('\p{	/a/NB}');
Error('\P{	/a/NB}');
Expect(1, 918000, '\p{nb}', "");
Expect(0, 918000, '\p{^nb}', "");
Expect(0, 918000, '\P{nb}', "");
Expect(1, 918000, '\P{^nb}', "");
Expect(0, 983040, '\p{nb}', "");
Expect(1, 983040, '\p{^nb}', "");
Expect(1, 983040, '\P{nb}', "");
Expect(0, 983040, '\P{^nb}', "");
Expect(1, 918000, '\p{ NB}', "");
Expect(0, 918000, '\p{^ NB}', "");
Expect(0, 918000, '\P{ NB}', "");
Expect(1, 918000, '\P{^ NB}', "");
Expect(0, 983040, '\p{ NB}', "");
Expect(1, 983040, '\p{^ NB}', "");
Expect(1, 983040, '\P{ NB}', "");
Expect(0, 983040, '\P{^ NB}', "");
Error('\p{/a/IS_NB}');
Error('\P{/a/IS_NB}');
Expect(1, 918000, '\p{isnb}', "");
Expect(0, 918000, '\p{^isnb}', "");
Expect(0, 918000, '\P{isnb}', "");
Expect(1, 918000, '\P{^isnb}', "");
Expect(0, 983040, '\p{isnb}', "");
Expect(1, 983040, '\p{^isnb}', "");
Expect(1, 983040, '\P{isnb}', "");
Expect(0, 983040, '\P{^isnb}', "");
Expect(1, 918000, '\p{--Is_NB}', "");
Expect(0, 918000, '\p{^--Is_NB}', "");
Expect(0, 918000, '\P{--Is_NB}', "");
Expect(1, 918000, '\P{^--Is_NB}', "");
Expect(0, 983040, '\p{--Is_NB}', "");
Expect(1, 983040, '\p{^--Is_NB}', "");
Expect(1, 983040, '\P{--Is_NB}', "");
Expect(0, 983040, '\P{^--Is_NB}', "");
Error('\p{-_In_NB/a/}');
Error('\P{-_In_NB/a/}');
Expect(1, 918000, '\p{innb}', "");
Expect(0, 918000, '\p{^innb}', "");
Expect(0, 918000, '\P{innb}', "");
Expect(1, 918000, '\P{^innb}', "");
Expect(0, 983040, '\p{innb}', "");
Expect(1, 983040, '\p{^innb}', "");
Expect(1, 983040, '\P{innb}', "");
Expect(0, 983040, '\P{^innb}', "");
Expect(1, 918000, '\p{ In_NB}', "");
Expect(0, 918000, '\p{^ In_NB}', "");
Expect(0, 918000, '\P{ In_NB}', "");
Expect(1, 918000, '\P{^ In_NB}', "");
Expect(0, 983040, '\p{ In_NB}', "");
Expect(1, 983040, '\p{^ In_NB}', "");
Expect(1, 983040, '\P{ In_NB}', "");
Expect(0, 983040, '\P{^ In_NB}', "");
Error('\p{:=	_Noncharacter_Code_POINT}');
Error('\P{:=	_Noncharacter_Code_POINT}');
Expect(1, 1114111, '\p{noncharactercodepoint}', "");
Expect(0, 1114111, '\p{^noncharactercodepoint}', "");
Expect(0, 1114111, '\P{noncharactercodepoint}', "");
Expect(1, 1114111, '\P{^noncharactercodepoint}', "");
Expect(0, 1114109, '\p{noncharactercodepoint}', "");
Expect(1, 1114109, '\p{^noncharactercodepoint}', "");
Expect(1, 1114109, '\P{noncharactercodepoint}', "");
Expect(0, 1114109, '\P{^noncharactercodepoint}', "");
Expect(1, 1114111, '\p{ NONCHARACTER_CODE_Point}', "");
Expect(0, 1114111, '\p{^ NONCHARACTER_CODE_Point}', "");
Expect(0, 1114111, '\P{ NONCHARACTER_CODE_Point}', "");
Expect(1, 1114111, '\P{^ NONCHARACTER_CODE_Point}', "");
Expect(0, 1114109, '\p{ NONCHARACTER_CODE_Point}', "");
Expect(1, 1114109, '\p{^ NONCHARACTER_CODE_Point}', "");
Expect(1, 1114109, '\P{ NONCHARACTER_CODE_Point}', "");
Expect(0, 1114109, '\P{^ NONCHARACTER_CODE_Point}', "");
Error('\p{:=	-IS_Noncharacter_code_Point}');
Error('\P{:=	-IS_Noncharacter_code_Point}');
Expect(1, 1114111, '\p{isnoncharactercodepoint}', "");
Expect(0, 1114111, '\p{^isnoncharactercodepoint}', "");
Expect(0, 1114111, '\P{isnoncharactercodepoint}', "");
Expect(1, 1114111, '\P{^isnoncharactercodepoint}', "");
Expect(0, 1114109, '\p{isnoncharactercodepoint}', "");
Expect(1, 1114109, '\p{^isnoncharactercodepoint}', "");
Expect(1, 1114109, '\P{isnoncharactercodepoint}', "");
Expect(0, 1114109, '\P{^isnoncharactercodepoint}', "");
Expect(1, 1114111, '\p{	Is_Noncharacter_CODE_POINT}', "");
Expect(0, 1114111, '\p{^	Is_Noncharacter_CODE_POINT}', "");
Expect(0, 1114111, '\P{	Is_Noncharacter_CODE_POINT}', "");
Expect(1, 1114111, '\P{^	Is_Noncharacter_CODE_POINT}', "");
Expect(0, 1114109, '\p{	Is_Noncharacter_CODE_POINT}', "");
Expect(1, 1114109, '\p{^	Is_Noncharacter_CODE_POINT}', "");
Expect(1, 1114109, '\P{	Is_Noncharacter_CODE_POINT}', "");
Expect(0, 1114109, '\P{^	Is_Noncharacter_CODE_POINT}', "");
Error('\p{	_nchar/a/}');
Error('\P{	_nchar/a/}');
Expect(1, 1114111, '\p{nchar}', "");
Expect(0, 1114111, '\p{^nchar}', "");
Expect(0, 1114111, '\P{nchar}', "");
Expect(1, 1114111, '\P{^nchar}', "");
Expect(0, 1114109, '\p{nchar}', "");
Expect(1, 1114109, '\p{^nchar}', "");
Expect(1, 1114109, '\P{nchar}', "");
Expect(0, 1114109, '\P{^nchar}', "");
Expect(1, 1114111, '\p{_ NChar}', "");
Expect(0, 1114111, '\p{^_ NChar}', "");
Expect(0, 1114111, '\P{_ NChar}', "");
Expect(1, 1114111, '\P{^_ NChar}', "");
Expect(0, 1114109, '\p{_ NChar}', "");
Expect(1, 1114109, '\p{^_ NChar}', "");
Expect(1, 1114109, '\P{_ NChar}', "");
Expect(0, 1114109, '\P{^_ NChar}', "");
Error('\p{:=-is_NCHAR}');
Error('\P{:=-is_NCHAR}');
Expect(1, 1114111, '\p{isnchar}', "");
Expect(0, 1114111, '\p{^isnchar}', "");
Expect(0, 1114111, '\P{isnchar}', "");
Expect(1, 1114111, '\P{^isnchar}', "");
Expect(0, 1114109, '\p{isnchar}', "");
Expect(1, 1114109, '\p{^isnchar}', "");
Expect(1, 1114109, '\P{isnchar}', "");
Expect(0, 1114109, '\P{^isnchar}', "");
Expect(1, 1114111, '\p{ is_NCHAR}', "");
Expect(0, 1114111, '\p{^ is_NCHAR}', "");
Expect(0, 1114111, '\P{ is_NCHAR}', "");
Expect(1, 1114111, '\P{^ is_NCHAR}', "");
Expect(0, 1114109, '\p{ is_NCHAR}', "");
Expect(1, 1114109, '\p{^ is_NCHAR}', "");
Expect(1, 1114109, '\P{ is_NCHAR}', "");
Expect(0, 1114109, '\P{^ is_NCHAR}', "");
Error('\p{-:=NONSPACING_mark}');
Error('\P{-:=NONSPACING_mark}');
Expect(1, 917999, '\p{nonspacingmark}', "");
Expect(0, 917999, '\p{^nonspacingmark}', "");
Expect(0, 917999, '\P{nonspacingmark}', "");
Expect(1, 917999, '\P{^nonspacingmark}', "");
Expect(0, 918000, '\p{nonspacingmark}', "");
Expect(1, 918000, '\p{^nonspacingmark}', "");
Expect(1, 918000, '\P{nonspacingmark}', "");
Expect(0, 918000, '\P{^nonspacingmark}', "");
Expect(1, 917999, '\p{	 nonspacing_mark}', "");
Expect(0, 917999, '\p{^	 nonspacing_mark}', "");
Expect(0, 917999, '\P{	 nonspacing_mark}', "");
Expect(1, 917999, '\P{^	 nonspacing_mark}', "");
Expect(0, 918000, '\p{	 nonspacing_mark}', "");
Expect(1, 918000, '\p{^	 nonspacing_mark}', "");
Expect(1, 918000, '\P{	 nonspacing_mark}', "");
Expect(0, 918000, '\P{^	 nonspacing_mark}', "");
Error('\p{ /a/is_nonspacing_Mark}');
Error('\P{ /a/is_nonspacing_Mark}');
Expect(1, 917999, '\p{isnonspacingmark}', "");
Expect(0, 917999, '\p{^isnonspacingmark}', "");
Expect(0, 917999, '\P{isnonspacingmark}', "");
Expect(1, 917999, '\P{^isnonspacingmark}', "");
Expect(0, 918000, '\p{isnonspacingmark}', "");
Expect(1, 918000, '\p{^isnonspacingmark}', "");
Expect(1, 918000, '\P{isnonspacingmark}', "");
Expect(0, 918000, '\P{^isnonspacingmark}', "");
Expect(1, 917999, '\p{	IS_NONSPACING_mark}', "");
Expect(0, 917999, '\p{^	IS_NONSPACING_mark}', "");
Expect(0, 917999, '\P{	IS_NONSPACING_mark}', "");
Expect(1, 917999, '\P{^	IS_NONSPACING_mark}', "");
Expect(0, 918000, '\p{	IS_NONSPACING_mark}', "");
Expect(1, 918000, '\p{^	IS_NONSPACING_mark}', "");
Expect(1, 918000, '\P{	IS_NONSPACING_mark}', "");
Expect(0, 918000, '\P{^	IS_NONSPACING_mark}', "");
Error('\p{/a/	Mn}');
Error('\P{/a/	Mn}');
Expect(1, 917999, '\p{mn}', "");
Expect(0, 917999, '\p{^mn}', "");
Expect(0, 917999, '\P{mn}', "");
Expect(1, 917999, '\P{^mn}', "");
Expect(0, 918000, '\p{mn}', "");
Expect(1, 918000, '\p{^mn}', "");
Expect(1, 918000, '\P{mn}', "");
Expect(0, 918000, '\P{^mn}', "");
Expect(1, 917999, '\p{		Mn}', "");
Expect(0, 917999, '\p{^		Mn}', "");
Expect(0, 917999, '\P{		Mn}', "");
Expect(1, 917999, '\P{^		Mn}', "");
Expect(0, 918000, '\p{		Mn}', "");
Expect(1, 918000, '\p{^		Mn}', "");
Expect(1, 918000, '\P{		Mn}', "");
Expect(0, 918000, '\P{^		Mn}', "");
Error('\p{--IS_Mn/a/}');
Error('\P{--IS_Mn/a/}');
Expect(1, 917999, '\p{ismn}', "");
Expect(0, 917999, '\p{^ismn}', "");
Expect(0, 917999, '\P{ismn}', "");
Expect(1, 917999, '\P{^ismn}', "");
Expect(0, 918000, '\p{ismn}', "");
Expect(1, 918000, '\p{^ismn}', "");
Expect(1, 918000, '\P{ismn}', "");
Expect(0, 918000, '\P{^ismn}', "");
Expect(1, 917999, '\p{ IS_MN}', "");
Expect(0, 917999, '\p{^ IS_MN}', "");
Expect(0, 917999, '\P{ IS_MN}', "");
Expect(1, 917999, '\P{^ IS_MN}', "");
Expect(0, 918000, '\p{ IS_MN}', "");
Expect(1, 918000, '\p{^ IS_MN}', "");
Expect(1, 918000, '\P{ IS_MN}', "");
Expect(0, 918000, '\P{^ IS_MN}', "");
Error('\p{/a/number}');
Error('\P{/a/number}');
Expect(1, 127242, '\p{number}', "");
Expect(0, 127242, '\p{^number}', "");
Expect(0, 127242, '\P{number}', "");
Expect(1, 127242, '\P{^number}', "");
Expect(0, 127243, '\p{number}', "");
Expect(1, 127243, '\p{^number}', "");
Expect(1, 127243, '\P{number}', "");
Expect(0, 127243, '\P{^number}', "");
Expect(1, 127242, '\p{-_Number}', "");
Expect(0, 127242, '\p{^-_Number}', "");
Expect(0, 127242, '\P{-_Number}', "");
Expect(1, 127242, '\P{^-_Number}', "");
Expect(0, 127243, '\p{-_Number}', "");
Expect(1, 127243, '\p{^-_Number}', "");
Expect(1, 127243, '\P{-_Number}', "");
Expect(0, 127243, '\P{^-_Number}', "");
Error('\p{/a/	is_Number}');
Error('\P{/a/	is_Number}');
Expect(1, 127242, '\p{isnumber}', "");
Expect(0, 127242, '\p{^isnumber}', "");
Expect(0, 127242, '\P{isnumber}', "");
Expect(1, 127242, '\P{^isnumber}', "");
Expect(0, 127243, '\p{isnumber}', "");
Expect(1, 127243, '\p{^isnumber}', "");
Expect(1, 127243, '\P{isnumber}', "");
Expect(0, 127243, '\P{^isnumber}', "");
Expect(1, 127242, '\p{--Is_Number}', "");
Expect(0, 127242, '\p{^--Is_Number}', "");
Expect(0, 127242, '\P{--Is_Number}', "");
Expect(1, 127242, '\P{^--Is_Number}', "");
Expect(0, 127243, '\p{--Is_Number}', "");
Expect(1, 127243, '\p{^--Is_Number}', "");
Expect(1, 127243, '\P{--Is_Number}', "");
Expect(0, 127243, '\P{^--Is_Number}', "");
Error('\p{_:=n}');
Error('\P{_:=n}');
Expect(1, 127242, '\p{n}', "");
Expect(0, 127242, '\p{^n}', "");
Expect(0, 127242, '\P{n}', "");
Expect(1, 127242, '\P{^n}', "");
Expect(0, 127243, '\p{n}', "");
Expect(1, 127243, '\p{^n}', "");
Expect(1, 127243, '\P{n}', "");
Expect(0, 127243, '\P{^n}', "");
Expect(1, 127242, '\p{-_N}', "");
Expect(0, 127242, '\p{^-_N}', "");
Expect(0, 127242, '\P{-_N}', "");
Expect(1, 127242, '\P{^-_N}', "");
Expect(0, 127243, '\p{-_N}', "");
Expect(1, 127243, '\p{^-_N}', "");
Expect(1, 127243, '\P{-_N}', "");
Expect(0, 127243, '\P{^-_N}', "");
Error('\p{		IS_N/a/}');
Error('\P{		IS_N/a/}');
Expect(1, 127242, '\p{isn}', "");
Expect(0, 127242, '\p{^isn}', "");
Expect(0, 127242, '\P{isn}', "");
Expect(1, 127242, '\P{^isn}', "");
Expect(0, 127243, '\p{isn}', "");
Expect(1, 127243, '\p{^isn}', "");
Expect(1, 127243, '\P{isn}', "");
Expect(0, 127243, '\P{^isn}', "");
Expect(1, 127242, '\p{	Is_n}', "");
Expect(0, 127242, '\p{^	Is_n}', "");
Expect(0, 127242, '\P{	Is_n}', "");
Expect(1, 127242, '\P{^	Is_n}', "");
Expect(0, 127243, '\p{	Is_n}', "");
Expect(1, 127243, '\p{^	Is_n}', "");
Expect(1, 127243, '\P{	Is_n}', "");
Expect(0, 127243, '\P{^	Is_n}', "");
Error('\p{:=--number_forms}');
Error('\P{:=--number_forms}');
Expect(1, 8591, '\p{numberforms}', "");
Expect(0, 8591, '\p{^numberforms}', "");
Expect(0, 8591, '\P{numberforms}', "");
Expect(1, 8591, '\P{^numberforms}', "");
Expect(0, 8592, '\p{numberforms}', "");
Expect(1, 8592, '\p{^numberforms}', "");
Expect(1, 8592, '\P{numberforms}', "");
Expect(0, 8592, '\P{^numberforms}', "");
Expect(1, 8591, '\p{	 NUMBER_Forms}', "");
Expect(0, 8591, '\p{^	 NUMBER_Forms}', "");
Expect(0, 8591, '\P{	 NUMBER_Forms}', "");
Expect(1, 8591, '\P{^	 NUMBER_Forms}', "");
Expect(0, 8592, '\p{	 NUMBER_Forms}', "");
Expect(1, 8592, '\p{^	 NUMBER_Forms}', "");
Expect(1, 8592, '\P{	 NUMBER_Forms}', "");
Expect(0, 8592, '\P{^	 NUMBER_Forms}', "");
Error('\p{:= _Is_Number_Forms}');
Error('\P{:= _Is_Number_Forms}');
Expect(1, 8591, '\p{isnumberforms}', "");
Expect(0, 8591, '\p{^isnumberforms}', "");
Expect(0, 8591, '\P{isnumberforms}', "");
Expect(1, 8591, '\P{^isnumberforms}', "");
Expect(0, 8592, '\p{isnumberforms}', "");
Expect(1, 8592, '\p{^isnumberforms}', "");
Expect(1, 8592, '\P{isnumberforms}', "");
Expect(0, 8592, '\P{^isnumberforms}', "");
Expect(1, 8591, '\p{ IS_Number_forms}', "");
Expect(0, 8591, '\p{^ IS_Number_forms}', "");
Expect(0, 8591, '\P{ IS_Number_forms}', "");
Expect(1, 8591, '\P{^ IS_Number_forms}', "");
Expect(0, 8592, '\p{ IS_Number_forms}', "");
Expect(1, 8592, '\p{^ IS_Number_forms}', "");
Expect(1, 8592, '\P{ IS_Number_forms}', "");
Expect(0, 8592, '\P{^ IS_Number_forms}', "");
Error('\p{-/a/in_Number_forms}');
Error('\P{-/a/in_Number_forms}');
Expect(1, 8591, '\p{innumberforms}', "");
Expect(0, 8591, '\p{^innumberforms}', "");
Expect(0, 8591, '\P{innumberforms}', "");
Expect(1, 8591, '\P{^innumberforms}', "");
Expect(0, 8592, '\p{innumberforms}', "");
Expect(1, 8592, '\p{^innumberforms}', "");
Expect(1, 8592, '\P{innumberforms}', "");
Expect(0, 8592, '\P{^innumberforms}', "");
Expect(1, 8591, '\p{ In_Number_FORMS}', "");
Expect(0, 8591, '\p{^ In_Number_FORMS}', "");
Expect(0, 8591, '\P{ In_Number_FORMS}', "");
Expect(1, 8591, '\P{^ In_Number_FORMS}', "");
Expect(0, 8592, '\p{ In_Number_FORMS}', "");
Expect(1, 8592, '\p{^ In_Number_FORMS}', "");
Expect(1, 8592, '\P{ In_Number_FORMS}', "");
Expect(0, 8592, '\P{^ In_Number_FORMS}', "");
Error('\p{:= ogham}');
Error('\P{:= ogham}');
Expect(1, 5788, '\p{ogham}', "");
Expect(0, 5788, '\p{^ogham}', "");
Expect(0, 5788, '\P{ogham}', "");
Expect(1, 5788, '\P{^ogham}', "");
Expect(0, 5789, '\p{ogham}', "");
Expect(1, 5789, '\p{^ogham}', "");
Expect(1, 5789, '\P{ogham}', "");
Expect(0, 5789, '\P{^ogham}', "");
Expect(1, 5788, '\p{--Ogham}', "");
Expect(0, 5788, '\p{^--Ogham}', "");
Expect(0, 5788, '\P{--Ogham}', "");
Expect(1, 5788, '\P{^--Ogham}', "");
Expect(0, 5789, '\p{--Ogham}', "");
Expect(1, 5789, '\p{^--Ogham}', "");
Expect(1, 5789, '\P{--Ogham}', "");
Expect(0, 5789, '\P{^--Ogham}', "");
Error('\p{		IS_OGHAM/a/}');
Error('\P{		IS_OGHAM/a/}');
Expect(1, 5788, '\p{isogham}', "");
Expect(0, 5788, '\p{^isogham}', "");
Expect(0, 5788, '\P{isogham}', "");
Expect(1, 5788, '\P{^isogham}', "");
Expect(0, 5789, '\p{isogham}', "");
Expect(1, 5789, '\p{^isogham}', "");
Expect(1, 5789, '\P{isogham}', "");
Expect(0, 5789, '\P{^isogham}', "");
Expect(1, 5788, '\p{ 	IS_OGHAM}', "");
Expect(0, 5788, '\p{^ 	IS_OGHAM}', "");
Expect(0, 5788, '\P{ 	IS_OGHAM}', "");
Expect(1, 5788, '\P{^ 	IS_OGHAM}', "");
Expect(0, 5789, '\p{ 	IS_OGHAM}', "");
Expect(1, 5789, '\p{^ 	IS_OGHAM}', "");
Expect(1, 5789, '\P{ 	IS_OGHAM}', "");
Expect(0, 5789, '\P{^ 	IS_OGHAM}', "");
Error('\p{-_Ogam:=}');
Error('\P{-_Ogam:=}');
Expect(1, 5788, '\p{ogam}', "");
Expect(0, 5788, '\p{^ogam}', "");
Expect(0, 5788, '\P{ogam}', "");
Expect(1, 5788, '\P{^ogam}', "");
Expect(0, 5789, '\p{ogam}', "");
Expect(1, 5789, '\p{^ogam}', "");
Expect(1, 5789, '\P{ogam}', "");
Expect(0, 5789, '\P{^ogam}', "");
Expect(1, 5788, '\p{-_Ogam}', "");
Expect(0, 5788, '\p{^-_Ogam}', "");
Expect(0, 5788, '\P{-_Ogam}', "");
Expect(1, 5788, '\P{^-_Ogam}', "");
Expect(0, 5789, '\p{-_Ogam}', "");
Expect(1, 5789, '\p{^-_Ogam}', "");
Expect(1, 5789, '\P{-_Ogam}', "");
Expect(0, 5789, '\P{^-_Ogam}', "");
Error('\p{:=		is_ogam}');
Error('\P{:=		is_ogam}');
Expect(1, 5788, '\p{isogam}', "");
Expect(0, 5788, '\p{^isogam}', "");
Expect(0, 5788, '\P{isogam}', "");
Expect(1, 5788, '\P{^isogam}', "");
Expect(0, 5789, '\p{isogam}', "");
Expect(1, 5789, '\p{^isogam}', "");
Expect(1, 5789, '\P{isogam}', "");
Expect(0, 5789, '\P{^isogam}', "");
Expect(1, 5788, '\p{ IS_OGAM}', "");
Expect(0, 5788, '\p{^ IS_OGAM}', "");
Expect(0, 5788, '\P{ IS_OGAM}', "");
Expect(1, 5788, '\P{^ IS_OGAM}', "");
Expect(0, 5789, '\p{ IS_OGAM}', "");
Expect(1, 5789, '\p{^ IS_OGAM}', "");
Expect(1, 5789, '\P{ IS_OGAM}', "");
Expect(0, 5789, '\P{^ IS_OGAM}', "");
Error('\p{_OL_Chiki/a/}');
Error('\P{_OL_Chiki/a/}');
Expect(1, 7295, '\p{olchiki}', "");
Expect(0, 7295, '\p{^olchiki}', "");
Expect(0, 7295, '\P{olchiki}', "");
Expect(1, 7295, '\P{^olchiki}', "");
Expect(0, 7296, '\p{olchiki}', "");
Expect(1, 7296, '\p{^olchiki}', "");
Expect(1, 7296, '\P{olchiki}', "");
Expect(0, 7296, '\P{^olchiki}', "");
Expect(1, 7295, '\p{_	OL_chiki}', "");
Expect(0, 7295, '\p{^_	OL_chiki}', "");
Expect(0, 7295, '\P{_	OL_chiki}', "");
Expect(1, 7295, '\P{^_	OL_chiki}', "");
Expect(0, 7296, '\p{_	OL_chiki}', "");
Expect(1, 7296, '\p{^_	OL_chiki}', "");
Expect(1, 7296, '\P{_	OL_chiki}', "");
Expect(0, 7296, '\P{^_	OL_chiki}', "");
Error('\p{- IS_ol_CHIKI:=}');
Error('\P{- IS_ol_CHIKI:=}');
Expect(1, 7295, '\p{isolchiki}', "");
Expect(0, 7295, '\p{^isolchiki}', "");
Expect(0, 7295, '\P{isolchiki}', "");
Expect(1, 7295, '\P{^isolchiki}', "");
Expect(0, 7296, '\p{isolchiki}', "");
Expect(1, 7296, '\p{^isolchiki}', "");
Expect(1, 7296, '\P{isolchiki}', "");
Expect(0, 7296, '\P{^isolchiki}', "");
Expect(1, 7295, '\p{- is_ol_Chiki}', "");
Expect(0, 7295, '\p{^- is_ol_Chiki}', "");
Expect(0, 7295, '\P{- is_ol_Chiki}', "");
Expect(1, 7295, '\P{^- is_ol_Chiki}', "");
Expect(0, 7296, '\p{- is_ol_Chiki}', "");
Expect(1, 7296, '\p{^- is_ol_Chiki}', "");
Expect(1, 7296, '\P{- is_ol_Chiki}', "");
Expect(0, 7296, '\P{^- is_ol_Chiki}', "");
Error('\p{_Olck:=}');
Error('\P{_Olck:=}');
Expect(1, 7295, '\p{olck}', "");
Expect(0, 7295, '\p{^olck}', "");
Expect(0, 7295, '\P{olck}', "");
Expect(1, 7295, '\P{^olck}', "");
Expect(0, 7296, '\p{olck}', "");
Expect(1, 7296, '\p{^olck}', "");
Expect(1, 7296, '\P{olck}', "");
Expect(0, 7296, '\P{^olck}', "");
Expect(1, 7295, '\p{- OLCK}', "");
Expect(0, 7295, '\p{^- OLCK}', "");
Expect(0, 7295, '\P{- OLCK}', "");
Expect(1, 7295, '\P{^- OLCK}', "");
Expect(0, 7296, '\p{- OLCK}', "");
Expect(1, 7296, '\p{^- OLCK}', "");
Expect(1, 7296, '\P{- OLCK}', "");
Expect(0, 7296, '\P{^- OLCK}', "");
Error('\p{:=_ is_olck}');
Error('\P{:=_ is_olck}');
Expect(1, 7295, '\p{isolck}', "");
Expect(0, 7295, '\p{^isolck}', "");
Expect(0, 7295, '\P{isolck}', "");
Expect(1, 7295, '\P{^isolck}', "");
Expect(0, 7296, '\p{isolck}', "");
Expect(1, 7296, '\p{^isolck}', "");
Expect(1, 7296, '\P{isolck}', "");
Expect(0, 7296, '\P{^isolck}', "");
Expect(1, 7295, '\p{	Is_olck}', "");
Expect(0, 7295, '\p{^	Is_olck}', "");
Expect(0, 7295, '\P{	Is_olck}', "");
Expect(1, 7295, '\P{^	Is_olck}', "");
Expect(0, 7296, '\p{	Is_olck}', "");
Expect(1, 7296, '\p{^	Is_olck}', "");
Expect(1, 7296, '\P{	Is_olck}', "");
Expect(0, 7296, '\P{^	Is_olck}', "");
Error('\p{	_old_ITALIC/a/}');
Error('\P{	_old_ITALIC/a/}');
Expect(1, 66339, '\p{olditalic}', "");
Expect(0, 66339, '\p{^olditalic}', "");
Expect(0, 66339, '\P{olditalic}', "");
Expect(1, 66339, '\P{^olditalic}', "");
Expect(0, 66340, '\p{olditalic}', "");
Expect(1, 66340, '\p{^olditalic}', "");
Expect(1, 66340, '\P{olditalic}', "");
Expect(0, 66340, '\P{^olditalic}', "");
Expect(1, 66339, '\p{Old_ITALIC}', "");
Expect(0, 66339, '\p{^Old_ITALIC}', "");
Expect(0, 66339, '\P{Old_ITALIC}', "");
Expect(1, 66339, '\P{^Old_ITALIC}', "");
Expect(0, 66340, '\p{Old_ITALIC}', "");
Expect(1, 66340, '\p{^Old_ITALIC}', "");
Expect(1, 66340, '\P{Old_ITALIC}', "");
Expect(0, 66340, '\P{^Old_ITALIC}', "");
Error('\p{Is_Old_italic/a/}');
Error('\P{Is_Old_italic/a/}');
Expect(1, 66339, '\p{isolditalic}', "");
Expect(0, 66339, '\p{^isolditalic}', "");
Expect(0, 66339, '\P{isolditalic}', "");
Expect(1, 66339, '\P{^isolditalic}', "");
Expect(0, 66340, '\p{isolditalic}', "");
Expect(1, 66340, '\p{^isolditalic}', "");
Expect(1, 66340, '\P{isolditalic}', "");
Expect(0, 66340, '\P{^isolditalic}', "");
Expect(1, 66339, '\p{_	is_Old_ITALIC}', "");
Expect(0, 66339, '\p{^_	is_Old_ITALIC}', "");
Expect(0, 66339, '\P{_	is_Old_ITALIC}', "");
Expect(1, 66339, '\P{^_	is_Old_ITALIC}', "");
Expect(0, 66340, '\p{_	is_Old_ITALIC}', "");
Expect(1, 66340, '\p{^_	is_Old_ITALIC}', "");
Expect(1, 66340, '\P{_	is_Old_ITALIC}', "");
Expect(0, 66340, '\P{^_	is_Old_ITALIC}', "");
Error('\p{_-Ital:=}');
Error('\P{_-Ital:=}');
Expect(1, 66339, '\p{ital}', "");
Expect(0, 66339, '\p{^ital}', "");
Expect(0, 66339, '\P{ital}', "");
Expect(1, 66339, '\P{^ital}', "");
Expect(0, 66340, '\p{ital}', "");
Expect(1, 66340, '\p{^ital}', "");
Expect(1, 66340, '\P{ital}', "");
Expect(0, 66340, '\P{^ital}', "");
Expect(1, 66339, '\p{__Ital}', "");
Expect(0, 66339, '\p{^__Ital}', "");
Expect(0, 66339, '\P{__Ital}', "");
Expect(1, 66339, '\P{^__Ital}', "");
Expect(0, 66340, '\p{__Ital}', "");
Expect(1, 66340, '\p{^__Ital}', "");
Expect(1, 66340, '\P{__Ital}', "");
Expect(0, 66340, '\P{^__Ital}', "");
Error('\p{/a/__is_ITAL}');
Error('\P{/a/__is_ITAL}');
Expect(1, 66339, '\p{isital}', "");
Expect(0, 66339, '\p{^isital}', "");
Expect(0, 66339, '\P{isital}', "");
Expect(1, 66339, '\P{^isital}', "");
Expect(0, 66340, '\p{isital}', "");
Expect(1, 66340, '\p{^isital}', "");
Expect(1, 66340, '\P{isital}', "");
Expect(0, 66340, '\P{^isital}', "");
Expect(1, 66339, '\p{_Is_ital}', "");
Expect(0, 66339, '\p{^_Is_ital}', "");
Expect(0, 66339, '\P{_Is_ital}', "");
Expect(1, 66339, '\P{^_Is_ital}', "");
Expect(0, 66340, '\p{_Is_ital}', "");
Expect(1, 66340, '\p{^_Is_ital}', "");
Expect(1, 66340, '\P{_Is_ital}', "");
Expect(0, 66340, '\P{^_Is_ital}', "");
Error('\p{/a/	OLD_PERSIAN}');
Error('\P{/a/	OLD_PERSIAN}');
Expect(1, 66517, '\p{oldpersian}', "");
Expect(0, 66517, '\p{^oldpersian}', "");
Expect(0, 66517, '\P{oldpersian}', "");
Expect(1, 66517, '\P{^oldpersian}', "");
Expect(0, 66518, '\p{oldpersian}', "");
Expect(1, 66518, '\p{^oldpersian}', "");
Expect(1, 66518, '\P{oldpersian}', "");
Expect(0, 66518, '\P{^oldpersian}', "");
Expect(1, 66517, '\p{- OLD_Persian}', "");
Expect(0, 66517, '\p{^- OLD_Persian}', "");
Expect(0, 66517, '\P{- OLD_Persian}', "");
Expect(1, 66517, '\P{^- OLD_Persian}', "");
Expect(0, 66518, '\p{- OLD_Persian}', "");
Expect(1, 66518, '\p{^- OLD_Persian}', "");
Expect(1, 66518, '\P{- OLD_Persian}', "");
Expect(0, 66518, '\P{^- OLD_Persian}', "");
Error('\p{_Is_Old_Persian/a/}');
Error('\P{_Is_Old_Persian/a/}');
Expect(1, 66517, '\p{isoldpersian}', "");
Expect(0, 66517, '\p{^isoldpersian}', "");
Expect(0, 66517, '\P{isoldpersian}', "");
Expect(1, 66517, '\P{^isoldpersian}', "");
Expect(0, 66518, '\p{isoldpersian}', "");
Expect(1, 66518, '\p{^isoldpersian}', "");
Expect(1, 66518, '\P{isoldpersian}', "");
Expect(0, 66518, '\P{^isoldpersian}', "");
Expect(1, 66517, '\p{_	Is_Old_Persian}', "");
Expect(0, 66517, '\p{^_	Is_Old_Persian}', "");
Expect(0, 66517, '\P{_	Is_Old_Persian}', "");
Expect(1, 66517, '\P{^_	Is_Old_Persian}', "");
Expect(0, 66518, '\p{_	Is_Old_Persian}', "");
Expect(1, 66518, '\p{^_	Is_Old_Persian}', "");
Expect(1, 66518, '\P{_	Is_Old_Persian}', "");
Expect(0, 66518, '\P{^_	Is_Old_Persian}', "");
Error('\p{	 xpeo:=}');
Error('\P{	 xpeo:=}');
Expect(1, 66517, '\p{xpeo}', "");
Expect(0, 66517, '\p{^xpeo}', "");
Expect(0, 66517, '\P{xpeo}', "");
Expect(1, 66517, '\P{^xpeo}', "");
Expect(0, 66518, '\p{xpeo}', "");
Expect(1, 66518, '\p{^xpeo}', "");
Expect(1, 66518, '\P{xpeo}', "");
Expect(0, 66518, '\P{^xpeo}', "");
Expect(1, 66517, '\p{	Xpeo}', "");
Expect(0, 66517, '\p{^	Xpeo}', "");
Expect(0, 66517, '\P{	Xpeo}', "");
Expect(1, 66517, '\P{^	Xpeo}', "");
Expect(0, 66518, '\p{	Xpeo}', "");
Expect(1, 66518, '\p{^	Xpeo}', "");
Expect(1, 66518, '\P{	Xpeo}', "");
Expect(0, 66518, '\P{^	Xpeo}', "");
Error('\p{		IS_XPEO:=}');
Error('\P{		IS_XPEO:=}');
Expect(1, 66517, '\p{isxpeo}', "");
Expect(0, 66517, '\p{^isxpeo}', "");
Expect(0, 66517, '\P{isxpeo}', "");
Expect(1, 66517, '\P{^isxpeo}', "");
Expect(0, 66518, '\p{isxpeo}', "");
Expect(1, 66518, '\p{^isxpeo}', "");
Expect(1, 66518, '\P{isxpeo}', "");
Expect(0, 66518, '\P{^isxpeo}', "");
Expect(1, 66517, '\p{ _is_xpeo}', "");
Expect(0, 66517, '\p{^ _is_xpeo}', "");
Expect(0, 66517, '\P{ _is_xpeo}', "");
Expect(1, 66517, '\P{^ _is_xpeo}', "");
Expect(0, 66518, '\p{ _is_xpeo}', "");
Expect(1, 66518, '\p{^ _is_xpeo}', "");
Expect(1, 66518, '\P{ _is_xpeo}', "");
Expect(0, 66518, '\P{^ _is_xpeo}', "");
Error('\p{__old_SOUTH_Arabian/a/}');
Error('\P{__old_SOUTH_Arabian/a/}');
Expect(1, 68223, '\p{oldsoutharabian}', "");
Expect(0, 68223, '\p{^oldsoutharabian}', "");
Expect(0, 68223, '\P{oldsoutharabian}', "");
Expect(1, 68223, '\P{^oldsoutharabian}', "");
Expect(0, 68224, '\p{oldsoutharabian}', "");
Expect(1, 68224, '\p{^oldsoutharabian}', "");
Expect(1, 68224, '\P{oldsoutharabian}', "");
Expect(0, 68224, '\P{^oldsoutharabian}', "");
Expect(1, 68223, '\p{ 	Old_south_Arabian}', "");
Expect(0, 68223, '\p{^ 	Old_south_Arabian}', "");
Expect(0, 68223, '\P{ 	Old_south_Arabian}', "");
Expect(1, 68223, '\P{^ 	Old_south_Arabian}', "");
Expect(0, 68224, '\p{ 	Old_south_Arabian}', "");
Expect(1, 68224, '\p{^ 	Old_south_Arabian}', "");
Expect(1, 68224, '\P{ 	Old_south_Arabian}', "");
Expect(0, 68224, '\P{^ 	Old_south_Arabian}', "");
Error('\p{:= 	Is_Old_SOUTH_arabian}');
Error('\P{:= 	Is_Old_SOUTH_arabian}');
Expect(1, 68223, '\p{isoldsoutharabian}', "");
Expect(0, 68223, '\p{^isoldsoutharabian}', "");
Expect(0, 68223, '\P{isoldsoutharabian}', "");
Expect(1, 68223, '\P{^isoldsoutharabian}', "");
Expect(0, 68224, '\p{isoldsoutharabian}', "");
Expect(1, 68224, '\p{^isoldsoutharabian}', "");
Expect(1, 68224, '\P{isoldsoutharabian}', "");
Expect(0, 68224, '\P{^isoldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Old_south_Arabian}', "");
Expect(0, 68223, '\p{^Is_Old_south_Arabian}', "");
Expect(0, 68223, '\P{Is_Old_south_Arabian}', "");
Expect(1, 68223, '\P{^Is_Old_south_Arabian}', "");
Expect(0, 68224, '\p{Is_Old_south_Arabian}', "");
Expect(1, 68224, '\p{^Is_Old_south_Arabian}', "");
Expect(1, 68224, '\P{Is_Old_south_Arabian}', "");
Expect(0, 68224, '\P{^Is_Old_south_Arabian}', "");
Error('\p{/a/_	Sarb}');
Error('\P{/a/_	Sarb}');
Expect(1, 68223, '\p{sarb}', "");
Expect(0, 68223, '\p{^sarb}', "");
Expect(0, 68223, '\P{sarb}', "");
Expect(1, 68223, '\P{^sarb}', "");
Expect(0, 68224, '\p{sarb}', "");
Expect(1, 68224, '\p{^sarb}', "");
Expect(1, 68224, '\P{sarb}', "");
Expect(0, 68224, '\P{^sarb}', "");
Expect(1, 68223, '\p{ -SARB}', "");
Expect(0, 68223, '\p{^ -SARB}', "");
Expect(0, 68223, '\P{ -SARB}', "");
Expect(1, 68223, '\P{^ -SARB}', "");
Expect(0, 68224, '\p{ -SARB}', "");
Expect(1, 68224, '\p{^ -SARB}', "");
Expect(1, 68224, '\P{ -SARB}', "");
Expect(0, 68224, '\P{^ -SARB}', "");
Error('\p{_is_sarb:=}');
Error('\P{_is_sarb:=}');
Expect(1, 68223, '\p{issarb}', "");
Expect(0, 68223, '\p{^issarb}', "");
Expect(0, 68223, '\P{issarb}', "");
Expect(1, 68223, '\P{^issarb}', "");
Expect(0, 68224, '\p{issarb}', "");
Expect(1, 68224, '\p{^issarb}', "");
Expect(1, 68224, '\P{issarb}', "");
Expect(0, 68224, '\P{^issarb}', "");
Expect(1, 68223, '\p{__Is_Sarb}', "");
Expect(0, 68223, '\p{^__Is_Sarb}', "");
Expect(0, 68223, '\P{__Is_Sarb}', "");
Expect(1, 68223, '\P{^__Is_Sarb}', "");
Expect(0, 68224, '\p{__Is_Sarb}', "");
Expect(1, 68224, '\p{^__Is_Sarb}', "");
Expect(1, 68224, '\P{__Is_Sarb}', "");
Expect(0, 68224, '\P{^__Is_Sarb}', "");
Error('\p{ :=old_Turkic}');
Error('\P{ :=old_Turkic}');
Expect(1, 68680, '\p{oldturkic}', "");
Expect(0, 68680, '\p{^oldturkic}', "");
Expect(0, 68680, '\P{oldturkic}', "");
Expect(1, 68680, '\P{^oldturkic}', "");
Expect(0, 68681, '\p{oldturkic}', "");
Expect(1, 68681, '\p{^oldturkic}', "");
Expect(1, 68681, '\P{oldturkic}', "");
Expect(0, 68681, '\P{^oldturkic}', "");
Expect(1, 68680, '\p{__Old_Turkic}', "");
Expect(0, 68680, '\p{^__Old_Turkic}', "");
Expect(0, 68680, '\P{__Old_Turkic}', "");
Expect(1, 68680, '\P{^__Old_Turkic}', "");
Expect(0, 68681, '\p{__Old_Turkic}', "");
Expect(1, 68681, '\p{^__Old_Turkic}', "");
Expect(1, 68681, '\P{__Old_Turkic}', "");
Expect(0, 68681, '\P{^__Old_Turkic}', "");
Error('\p{-/a/Is_old_TURKIC}');
Error('\P{-/a/Is_old_TURKIC}');
Expect(1, 68680, '\p{isoldturkic}', "");
Expect(0, 68680, '\p{^isoldturkic}', "");
Expect(0, 68680, '\P{isoldturkic}', "");
Expect(1, 68680, '\P{^isoldturkic}', "");
Expect(0, 68681, '\p{isoldturkic}', "");
Expect(1, 68681, '\p{^isoldturkic}', "");
Expect(1, 68681, '\P{isoldturkic}', "");
Expect(0, 68681, '\P{^isoldturkic}', "");
Expect(1, 68680, '\p{  IS_Old_turkic}', "");
Expect(0, 68680, '\p{^  IS_Old_turkic}', "");
Expect(0, 68680, '\P{  IS_Old_turkic}', "");
Expect(1, 68680, '\P{^  IS_Old_turkic}', "");
Expect(0, 68681, '\p{  IS_Old_turkic}', "");
Expect(1, 68681, '\p{^  IS_Old_turkic}', "");
Expect(1, 68681, '\P{  IS_Old_turkic}', "");
Expect(0, 68681, '\P{^  IS_Old_turkic}', "");
Error('\p{-	Orkh/a/}');
Error('\P{-	Orkh/a/}');
Expect(1, 68680, '\p{orkh}', "");
Expect(0, 68680, '\p{^orkh}', "");
Expect(0, 68680, '\P{orkh}', "");
Expect(1, 68680, '\P{^orkh}', "");
Expect(0, 68681, '\p{orkh}', "");
Expect(1, 68681, '\p{^orkh}', "");
Expect(1, 68681, '\P{orkh}', "");
Expect(0, 68681, '\P{^orkh}', "");
Expect(1, 68680, '\p{-_ORKH}', "");
Expect(0, 68680, '\p{^-_ORKH}', "");
Expect(0, 68680, '\P{-_ORKH}', "");
Expect(1, 68680, '\P{^-_ORKH}', "");
Expect(0, 68681, '\p{-_ORKH}', "");
Expect(1, 68681, '\p{^-_ORKH}', "");
Expect(1, 68681, '\P{-_ORKH}', "");
Expect(0, 68681, '\P{^-_ORKH}', "");
Error('\p{	:=is_Orkh}');
Error('\P{	:=is_Orkh}');
Expect(1, 68680, '\p{isorkh}', "");
Expect(0, 68680, '\p{^isorkh}', "");
Expect(0, 68680, '\P{isorkh}', "");
Expect(1, 68680, '\P{^isorkh}', "");
Expect(0, 68681, '\p{isorkh}', "");
Expect(1, 68681, '\p{^isorkh}', "");
Expect(1, 68681, '\P{isorkh}', "");
Expect(0, 68681, '\P{^isorkh}', "");
Expect(1, 68680, '\p{	 Is_ORKH}', "");
Expect(0, 68680, '\p{^	 Is_ORKH}', "");
Expect(0, 68680, '\P{	 Is_ORKH}', "");
Expect(1, 68680, '\P{^	 Is_ORKH}', "");
Expect(0, 68681, '\p{	 Is_ORKH}', "");
Expect(1, 68681, '\p{^	 Is_ORKH}', "");
Expect(1, 68681, '\P{	 Is_ORKH}', "");
Expect(0, 68681, '\P{^	 Is_ORKH}', "");
Error('\p{-	Open_PUNCTUATION:=}');
Error('\P{-	Open_PUNCTUATION:=}');
Expect(1, 65378, '\p{openpunctuation}', "");
Expect(0, 65378, '\p{^openpunctuation}', "");
Expect(0, 65378, '\P{openpunctuation}', "");
Expect(1, 65378, '\P{^openpunctuation}', "");
Expect(0, 65379, '\p{openpunctuation}', "");
Expect(1, 65379, '\p{^openpunctuation}', "");
Expect(1, 65379, '\P{openpunctuation}', "");
Expect(0, 65379, '\P{^openpunctuation}', "");
Expect(1, 65378, '\p{ -OPEN_Punctuation}', "");
Expect(0, 65378, '\p{^ -OPEN_Punctuation}', "");
Expect(0, 65378, '\P{ -OPEN_Punctuation}', "");
Expect(1, 65378, '\P{^ -OPEN_Punctuation}', "");
Expect(0, 65379, '\p{ -OPEN_Punctuation}', "");
Expect(1, 65379, '\p{^ -OPEN_Punctuation}', "");
Expect(1, 65379, '\P{ -OPEN_Punctuation}', "");
Expect(0, 65379, '\P{^ -OPEN_Punctuation}', "");
Error('\p{/a/is_Open_Punctuation}');
Error('\P{/a/is_Open_Punctuation}');
Expect(1, 65378, '\p{isopenpunctuation}', "");
Expect(0, 65378, '\p{^isopenpunctuation}', "");
Expect(0, 65378, '\P{isopenpunctuation}', "");
Expect(1, 65378, '\P{^isopenpunctuation}', "");
Expect(0, 65379, '\p{isopenpunctuation}', "");
Expect(1, 65379, '\p{^isopenpunctuation}', "");
Expect(1, 65379, '\P{isopenpunctuation}', "");
Expect(0, 65379, '\P{^isopenpunctuation}', "");
Expect(1, 65378, '\p{	is_Open_Punctuation}', "");
Expect(0, 65378, '\p{^	is_Open_Punctuation}', "");
Expect(0, 65378, '\P{	is_Open_Punctuation}', "");
Expect(1, 65378, '\P{^	is_Open_Punctuation}', "");
Expect(0, 65379, '\p{	is_Open_Punctuation}', "");
Expect(1, 65379, '\p{^	is_Open_Punctuation}', "");
Expect(1, 65379, '\P{	is_Open_Punctuation}', "");
Expect(0, 65379, '\P{^	is_Open_Punctuation}', "");
Error('\p{:=- Ps}');
Error('\P{:=- Ps}');
Expect(1, 65378, '\p{ps}', "");
Expect(0, 65378, '\p{^ps}', "");
Expect(0, 65378, '\P{ps}', "");
Expect(1, 65378, '\P{^ps}', "");
Expect(0, 65379, '\p{ps}', "");
Expect(1, 65379, '\p{^ps}', "");
Expect(1, 65379, '\P{ps}', "");
Expect(0, 65379, '\P{^ps}', "");
Expect(1, 65378, '\p{ PS}', "");
Expect(0, 65378, '\p{^ PS}', "");
Expect(0, 65378, '\P{ PS}', "");
Expect(1, 65378, '\P{^ PS}', "");
Expect(0, 65379, '\p{ PS}', "");
Expect(1, 65379, '\p{^ PS}', "");
Expect(1, 65379, '\P{ PS}', "");
Expect(0, 65379, '\P{^ PS}', "");
Error('\p{- Is_ps/a/}');
Error('\P{- Is_ps/a/}');
Expect(1, 65378, '\p{isps}', "");
Expect(0, 65378, '\p{^isps}', "");
Expect(0, 65378, '\P{isps}', "");
Expect(1, 65378, '\P{^isps}', "");
Expect(0, 65379, '\p{isps}', "");
Expect(1, 65379, '\p{^isps}', "");
Expect(1, 65379, '\P{isps}', "");
Expect(0, 65379, '\P{^isps}', "");
Expect(1, 65378, '\p{--Is_PS}', "");
Expect(0, 65378, '\p{^--Is_PS}', "");
Expect(0, 65378, '\P{--Is_PS}', "");
Expect(1, 65378, '\P{^--Is_PS}', "");
Expect(0, 65379, '\p{--Is_PS}', "");
Expect(1, 65379, '\p{^--Is_PS}', "");
Expect(1, 65379, '\P{--Is_PS}', "");
Expect(0, 65379, '\P{^--Is_PS}', "");
Error('\p{ OPTICAL_Character_recognition/a/}');
Error('\P{ OPTICAL_Character_recognition/a/}');
Expect(1, 9311, '\p{opticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^opticalcharacterrecognition}', "");
Expect(0, 9311, '\P{opticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^opticalcharacterrecognition}', "");
Expect(0, 9312, '\p{opticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^opticalcharacterrecognition}', "");
Expect(1, 9312, '\P{opticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^opticalcharacterrecognition}', "");
Expect(1, 9311, '\p{_ optical_Character_RECOGNITION}', "");
Expect(0, 9311, '\p{^_ optical_Character_RECOGNITION}', "");
Expect(0, 9311, '\P{_ optical_Character_RECOGNITION}', "");
Expect(1, 9311, '\P{^_ optical_Character_RECOGNITION}', "");
Expect(0, 9312, '\p{_ optical_Character_RECOGNITION}', "");
Expect(1, 9312, '\p{^_ optical_Character_RECOGNITION}', "");
Expect(1, 9312, '\P{_ optical_Character_RECOGNITION}', "");
Expect(0, 9312, '\P{^_ optical_Character_RECOGNITION}', "");
Error('\p{:=	-Is_OPTICAL_character_Recognition}');
Error('\P{:=	-Is_OPTICAL_character_Recognition}');
Expect(1, 9311, '\p{isopticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^isopticalcharacterrecognition}', "");
Expect(0, 9311, '\P{isopticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^isopticalcharacterrecognition}', "");
Expect(0, 9312, '\p{isopticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^isopticalcharacterrecognition}', "");
Expect(1, 9312, '\P{isopticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^isopticalcharacterrecognition}', "");
Expect(1, 9311, '\p{ _Is_Optical_Character_Recognition}', "");
Expect(0, 9311, '\p{^ _Is_Optical_Character_Recognition}', "");
Expect(0, 9311, '\P{ _Is_Optical_Character_Recognition}', "");
Expect(1, 9311, '\P{^ _Is_Optical_Character_Recognition}', "");
Expect(0, 9312, '\p{ _Is_Optical_Character_Recognition}', "");
Expect(1, 9312, '\p{^ _Is_Optical_Character_Recognition}', "");
Expect(1, 9312, '\P{ _Is_Optical_Character_Recognition}', "");
Expect(0, 9312, '\P{^ _Is_Optical_Character_Recognition}', "");
Error('\p{-:=In_OPTICAL_Character_Recognition}');
Error('\P{-:=In_OPTICAL_Character_Recognition}');
Expect(1, 9311, '\p{inopticalcharacterrecognition}', "");
Expect(0, 9311, '\p{^inopticalcharacterrecognition}', "");
Expect(0, 9311, '\P{inopticalcharacterrecognition}', "");
Expect(1, 9311, '\P{^inopticalcharacterrecognition}', "");
Expect(0, 9312, '\p{inopticalcharacterrecognition}', "");
Expect(1, 9312, '\p{^inopticalcharacterrecognition}', "");
Expect(1, 9312, '\P{inopticalcharacterrecognition}', "");
Expect(0, 9312, '\P{^inopticalcharacterrecognition}', "");
Expect(1, 9311, '\p{_ IN_OPTICAL_Character_Recognition}', "");
Expect(0, 9311, '\p{^_ IN_OPTICAL_Character_Recognition}', "");
Expect(0, 9311, '\P{_ IN_OPTICAL_Character_Recognition}', "");
Expect(1, 9311, '\P{^_ IN_OPTICAL_Character_Recognition}', "");
Expect(0, 9312, '\p{_ IN_OPTICAL_Character_Recognition}', "");
Expect(1, 9312, '\p{^_ IN_OPTICAL_Character_Recognition}', "");
Expect(1, 9312, '\P{_ IN_OPTICAL_Character_Recognition}', "");
Expect(0, 9312, '\P{^_ IN_OPTICAL_Character_Recognition}', "");
Error('\p{ OCR/a/}');
Error('\P{ OCR/a/}');
Expect(1, 9311, '\p{ocr}', "");
Expect(0, 9311, '\p{^ocr}', "");
Expect(0, 9311, '\P{ocr}', "");
Expect(1, 9311, '\P{^ocr}', "");
Expect(0, 9312, '\p{ocr}', "");
Expect(1, 9312, '\p{^ocr}', "");
Expect(1, 9312, '\P{ocr}', "");
Expect(0, 9312, '\P{^ocr}', "");
Expect(1, 9311, '\p{_	ocr}', "");
Expect(0, 9311, '\p{^_	ocr}', "");
Expect(0, 9311, '\P{_	ocr}', "");
Expect(1, 9311, '\P{^_	ocr}', "");
Expect(0, 9312, '\p{_	ocr}', "");
Expect(1, 9312, '\p{^_	ocr}', "");
Expect(1, 9312, '\P{_	ocr}', "");
Expect(0, 9312, '\P{^_	ocr}', "");
Error('\p{:=IS_OCR}');
Error('\P{:=IS_OCR}');
Expect(1, 9311, '\p{isocr}', "");
Expect(0, 9311, '\p{^isocr}', "");
Expect(0, 9311, '\P{isocr}', "");
Expect(1, 9311, '\P{^isocr}', "");
Expect(0, 9312, '\p{isocr}', "");
Expect(1, 9312, '\p{^isocr}', "");
Expect(1, 9312, '\P{isocr}', "");
Expect(0, 9312, '\P{^isocr}', "");
Expect(1, 9311, '\p{_Is_OCR}', "");
Expect(0, 9311, '\p{^_Is_OCR}', "");
Expect(0, 9311, '\P{_Is_OCR}', "");
Expect(1, 9311, '\P{^_Is_OCR}', "");
Expect(0, 9312, '\p{_Is_OCR}', "");
Expect(1, 9312, '\p{^_Is_OCR}', "");
Expect(1, 9312, '\P{_Is_OCR}', "");
Expect(0, 9312, '\P{^_Is_OCR}', "");
Error('\p{/a/		In_OCR}');
Error('\P{/a/		In_OCR}');
Expect(1, 9311, '\p{inocr}', "");
Expect(0, 9311, '\p{^inocr}', "");
Expect(0, 9311, '\P{inocr}', "");
Expect(1, 9311, '\P{^inocr}', "");
Expect(0, 9312, '\p{inocr}', "");
Expect(1, 9312, '\p{^inocr}', "");
Expect(1, 9312, '\P{inocr}', "");
Expect(0, 9312, '\P{^inocr}', "");
Expect(1, 9311, '\p{- In_OCR}', "");
Expect(0, 9311, '\p{^- In_OCR}', "");
Expect(0, 9311, '\P{- In_OCR}', "");
Expect(1, 9311, '\P{^- In_OCR}', "");
Expect(0, 9312, '\p{- In_OCR}', "");
Expect(1, 9312, '\p{^- In_OCR}', "");
Expect(1, 9312, '\P{- In_OCR}', "");
Expect(0, 9312, '\P{^- In_OCR}', "");
Error('\p{/a/-oriya}');
Error('\P{/a/-oriya}');
Expect(1, 2935, '\p{oriya}', "");
Expect(0, 2935, '\p{^oriya}', "");
Expect(0, 2935, '\P{oriya}', "");
Expect(1, 2935, '\P{^oriya}', "");
Expect(0, 2936, '\p{oriya}', "");
Expect(1, 2936, '\p{^oriya}', "");
Expect(1, 2936, '\P{oriya}', "");
Expect(0, 2936, '\P{^oriya}', "");
Expect(1, 2935, '\p{-	ORIYA}', "");
Expect(0, 2935, '\p{^-	ORIYA}', "");
Expect(0, 2935, '\P{-	ORIYA}', "");
Expect(1, 2935, '\P{^-	ORIYA}', "");
Expect(0, 2936, '\p{-	ORIYA}', "");
Expect(1, 2936, '\p{^-	ORIYA}', "");
Expect(1, 2936, '\P{-	ORIYA}', "");
Expect(0, 2936, '\P{^-	ORIYA}', "");
Error('\p{:=IS_Oriya}');
Error('\P{:=IS_Oriya}');
Expect(1, 2935, '\p{isoriya}', "");
Expect(0, 2935, '\p{^isoriya}', "");
Expect(0, 2935, '\P{isoriya}', "");
Expect(1, 2935, '\P{^isoriya}', "");
Expect(0, 2936, '\p{isoriya}', "");
Expect(1, 2936, '\p{^isoriya}', "");
Expect(1, 2936, '\P{isoriya}', "");
Expect(0, 2936, '\P{^isoriya}', "");
Expect(1, 2935, '\p{-is_oriya}', "");
Expect(0, 2935, '\p{^-is_oriya}', "");
Expect(0, 2935, '\P{-is_oriya}', "");
Expect(1, 2935, '\P{^-is_oriya}', "");
Expect(0, 2936, '\p{-is_oriya}', "");
Expect(1, 2936, '\p{^-is_oriya}', "");
Expect(1, 2936, '\P{-is_oriya}', "");
Expect(0, 2936, '\P{^-is_oriya}', "");
Error('\p{-:=Orya}');
Error('\P{-:=Orya}');
Expect(1, 2935, '\p{orya}', "");
Expect(0, 2935, '\p{^orya}', "");
Expect(0, 2935, '\P{orya}', "");
Expect(1, 2935, '\P{^orya}', "");
Expect(0, 2936, '\p{orya}', "");
Expect(1, 2936, '\p{^orya}', "");
Expect(1, 2936, '\P{orya}', "");
Expect(0, 2936, '\P{^orya}', "");
Expect(1, 2935, '\p{ -orya}', "");
Expect(0, 2935, '\p{^ -orya}', "");
Expect(0, 2935, '\P{ -orya}', "");
Expect(1, 2935, '\P{^ -orya}', "");
Expect(0, 2936, '\p{ -orya}', "");
Expect(1, 2936, '\p{^ -orya}', "");
Expect(1, 2936, '\P{ -orya}', "");
Expect(0, 2936, '\P{^ -orya}', "");
Error('\p{  is_ORYA:=}');
Error('\P{  is_ORYA:=}');
Expect(1, 2935, '\p{isorya}', "");
Expect(0, 2935, '\p{^isorya}', "");
Expect(0, 2935, '\P{isorya}', "");
Expect(1, 2935, '\P{^isorya}', "");
Expect(0, 2936, '\p{isorya}', "");
Expect(1, 2936, '\p{^isorya}', "");
Expect(1, 2936, '\P{isorya}', "");
Expect(0, 2936, '\P{^isorya}', "");
Expect(1, 2935, '\p{--Is_orya}', "");
Expect(0, 2935, '\p{^--Is_orya}', "");
Expect(0, 2935, '\P{--Is_orya}', "");
Expect(1, 2935, '\P{^--Is_orya}', "");
Expect(0, 2936, '\p{--Is_orya}', "");
Expect(1, 2936, '\p{^--Is_orya}', "");
Expect(1, 2936, '\P{--Is_orya}', "");
Expect(0, 2936, '\P{^--Is_orya}', "");
Error('\p{:=__OSMANYA}');
Error('\P{:=__OSMANYA}');
Expect(1, 66729, '\p{osmanya}', "");
Expect(0, 66729, '\p{^osmanya}', "");
Expect(0, 66729, '\P{osmanya}', "");
Expect(1, 66729, '\P{^osmanya}', "");
Expect(0, 66730, '\p{osmanya}', "");
Expect(1, 66730, '\p{^osmanya}', "");
Expect(1, 66730, '\P{osmanya}', "");
Expect(0, 66730, '\P{^osmanya}', "");
Expect(1, 66729, '\p{	OSMANYA}', "");
Expect(0, 66729, '\p{^	OSMANYA}', "");
Expect(0, 66729, '\P{	OSMANYA}', "");
Expect(1, 66729, '\P{^	OSMANYA}', "");
Expect(0, 66730, '\p{	OSMANYA}', "");
Expect(1, 66730, '\p{^	OSMANYA}', "");
Expect(1, 66730, '\P{	OSMANYA}', "");
Expect(0, 66730, '\P{^	OSMANYA}', "");
Error('\p{:= Is_Osmanya}');
Error('\P{:= Is_Osmanya}');
Expect(1, 66729, '\p{isosmanya}', "");
Expect(0, 66729, '\p{^isosmanya}', "");
Expect(0, 66729, '\P{isosmanya}', "");
Expect(1, 66729, '\P{^isosmanya}', "");
Expect(0, 66730, '\p{isosmanya}', "");
Expect(1, 66730, '\p{^isosmanya}', "");
Expect(1, 66730, '\P{isosmanya}', "");
Expect(0, 66730, '\P{^isosmanya}', "");
Expect(1, 66729, '\p{__Is_Osmanya}', "");
Expect(0, 66729, '\p{^__Is_Osmanya}', "");
Expect(0, 66729, '\P{__Is_Osmanya}', "");
Expect(1, 66729, '\P{^__Is_Osmanya}', "");
Expect(0, 66730, '\p{__Is_Osmanya}', "");
Expect(1, 66730, '\p{^__Is_Osmanya}', "");
Expect(1, 66730, '\P{__Is_Osmanya}', "");
Expect(0, 66730, '\P{^__Is_Osmanya}', "");
Error('\p{-OSMA/a/}');
Error('\P{-OSMA/a/}');
Expect(1, 66729, '\p{osma}', "");
Expect(0, 66729, '\p{^osma}', "");
Expect(0, 66729, '\P{osma}', "");
Expect(1, 66729, '\P{^osma}', "");
Expect(0, 66730, '\p{osma}', "");
Expect(1, 66730, '\p{^osma}', "");
Expect(1, 66730, '\P{osma}', "");
Expect(0, 66730, '\P{^osma}', "");
Expect(1, 66729, '\p{_ Osma}', "");
Expect(0, 66729, '\p{^_ Osma}', "");
Expect(0, 66729, '\P{_ Osma}', "");
Expect(1, 66729, '\P{^_ Osma}', "");
Expect(0, 66730, '\p{_ Osma}', "");
Expect(1, 66730, '\p{^_ Osma}', "");
Expect(1, 66730, '\P{_ Osma}', "");
Expect(0, 66730, '\P{^_ Osma}', "");
Error('\p{-	IS_osma:=}');
Error('\P{-	IS_osma:=}');
Expect(1, 66729, '\p{isosma}', "");
Expect(0, 66729, '\p{^isosma}', "");
Expect(0, 66729, '\P{isosma}', "");
Expect(1, 66729, '\P{^isosma}', "");
Expect(0, 66730, '\p{isosma}', "");
Expect(1, 66730, '\p{^isosma}', "");
Expect(1, 66730, '\P{isosma}', "");
Expect(0, 66730, '\P{^isosma}', "");
Expect(1, 66729, '\p{-Is_osma}', "");
Expect(0, 66729, '\p{^-Is_osma}', "");
Expect(0, 66729, '\P{-Is_osma}', "");
Expect(1, 66729, '\P{^-Is_osma}', "");
Expect(0, 66730, '\p{-Is_osma}', "");
Expect(1, 66730, '\p{^-Is_osma}', "");
Expect(1, 66730, '\P{-Is_osma}', "");
Expect(0, 66730, '\P{^-Is_osma}', "");
Error('\p{-_Other:=}');
Error('\P{-_Other:=}');
Expect(1, 918000, '\p{other}', "");
Expect(0, 918000, '\p{^other}', "");
Expect(0, 918000, '\P{other}', "");
Expect(1, 918000, '\P{^other}', "");
Expect(0, 917999, '\p{other}', "");
Expect(1, 917999, '\p{^other}', "");
Expect(1, 917999, '\P{other}', "");
Expect(0, 917999, '\P{^other}', "");
Expect(1, 918000, '\p{_Other}', "");
Expect(0, 918000, '\p{^_Other}', "");
Expect(0, 918000, '\P{_Other}', "");
Expect(1, 918000, '\P{^_Other}', "");
Expect(0, 917999, '\p{_Other}', "");
Expect(1, 917999, '\p{^_Other}', "");
Expect(1, 917999, '\P{_Other}', "");
Expect(0, 917999, '\P{^_Other}', "");
Error('\p{-/a/IS_Other}');
Error('\P{-/a/IS_Other}');
Expect(1, 918000, '\p{isother}', "");
Expect(0, 918000, '\p{^isother}', "");
Expect(0, 918000, '\P{isother}', "");
Expect(1, 918000, '\P{^isother}', "");
Expect(0, 917999, '\p{isother}', "");
Expect(1, 917999, '\p{^isother}', "");
Expect(1, 917999, '\P{isother}', "");
Expect(0, 917999, '\P{^isother}', "");
Expect(1, 918000, '\p{_ is_other}', "");
Expect(0, 918000, '\p{^_ is_other}', "");
Expect(0, 918000, '\P{_ is_other}', "");
Expect(1, 918000, '\P{^_ is_other}', "");
Expect(0, 917999, '\p{_ is_other}', "");
Expect(1, 917999, '\p{^_ is_other}', "");
Expect(1, 917999, '\P{_ is_other}', "");
Expect(0, 917999, '\P{^_ is_other}', "");
Error('\p{/a/_ c}');
Error('\P{/a/_ c}');
Expect(1, 918000, '\p{c}', "");
Expect(0, 918000, '\p{^c}', "");
Expect(0, 918000, '\P{c}', "");
Expect(1, 918000, '\P{^c}', "");
Expect(0, 917999, '\p{c}', "");
Expect(1, 917999, '\p{^c}', "");
Expect(1, 917999, '\P{c}', "");
Expect(0, 917999, '\P{^c}', "");
Expect(1, 918000, '\p{__C}', "");
Expect(0, 918000, '\p{^__C}', "");
Expect(0, 918000, '\P{__C}', "");
Expect(1, 918000, '\P{^__C}', "");
Expect(0, 917999, '\p{__C}', "");
Expect(1, 917999, '\p{^__C}', "");
Expect(1, 917999, '\P{__C}', "");
Expect(0, 917999, '\P{^__C}', "");
Error('\p{-_Is_C:=}');
Error('\P{-_Is_C:=}');
Expect(1, 918000, '\p{isc}', "");
Expect(0, 918000, '\p{^isc}', "");
Expect(0, 918000, '\P{isc}', "");
Expect(1, 918000, '\P{^isc}', "");
Expect(0, 917999, '\p{isc}', "");
Expect(1, 917999, '\p{^isc}', "");
Expect(1, 917999, '\P{isc}', "");
Expect(0, 917999, '\P{^isc}', "");
Expect(1, 918000, '\p{_Is_C}', "");
Expect(0, 918000, '\p{^_Is_C}', "");
Expect(0, 918000, '\P{_Is_C}', "");
Expect(1, 918000, '\P{^_Is_C}', "");
Expect(0, 917999, '\p{_Is_C}', "");
Expect(1, 917999, '\p{^_Is_C}', "");
Expect(1, 917999, '\P{_Is_C}', "");
Expect(0, 917999, '\P{^_Is_C}', "");
Error('\p{Other_Alphabetic}');
Error('\P{Other_Alphabetic}');
Error('\p{Is_Other_Alphabetic}');
Error('\P{Is_Other_Alphabetic}');
Error('\p{OAlpha}');
Error('\P{OAlpha}');
Error('\p{Is_OAlpha}');
Error('\P{Is_OAlpha}');
Error('\p{Other_Default_Ignorable_Code_Point}');
Error('\P{Other_Default_Ignorable_Code_Point}');
Error('\p{Is_Other_Default_Ignorable_Code_Point}');
Error('\P{Is_Other_Default_Ignorable_Code_Point}');
Error('\p{ODI}');
Error('\P{ODI}');
Error('\p{Is_ODI}');
Error('\P{Is_ODI}');
Error('\p{Other_Grapheme_Extend}');
Error('\P{Other_Grapheme_Extend}');
Error('\p{Is_Other_Grapheme_Extend}');
Error('\P{Is_Other_Grapheme_Extend}');
Error('\p{OGr_Ext}');
Error('\P{OGr_Ext}');
Error('\p{Is_OGr_Ext}');
Error('\P{Is_OGr_Ext}');
Error('\p{Other_ID_Continue}');
Error('\P{Other_ID_Continue}');
Error('\p{Is_Other_ID_Continue}');
Error('\P{Is_Other_ID_Continue}');
Error('\p{OIDC}');
Error('\P{OIDC}');
Error('\p{Is_OIDC}');
Error('\P{Is_OIDC}');
Error('\p{Other_ID_Start}');
Error('\P{Other_ID_Start}');
Error('\p{Is_Other_ID_Start}');
Error('\P{Is_Other_ID_Start}');
Error('\p{OIDS}');
Error('\P{OIDS}');
Error('\p{Is_OIDS}');
Error('\P{Is_OIDS}');
Error('\p{		OTHER_Letter:=}');
Error('\P{		OTHER_Letter:=}');
Expect(1, 195101, '\p{otherletter}', "");
Expect(0, 195101, '\p{^otherletter}', "");
Expect(0, 195101, '\P{otherletter}', "");
Expect(1, 195101, '\P{^otherletter}', "");
Expect(0, 195102, '\p{otherletter}', "");
Expect(1, 195102, '\p{^otherletter}', "");
Expect(1, 195102, '\P{otherletter}', "");
Expect(0, 195102, '\P{^otherletter}', "");
Expect(1, 195101, '\p{ OTHER_Letter}', "");
Expect(0, 195101, '\p{^ OTHER_Letter}', "");
Expect(0, 195101, '\P{ OTHER_Letter}', "");
Expect(1, 195101, '\P{^ OTHER_Letter}', "");
Expect(0, 195102, '\p{ OTHER_Letter}', "");
Expect(1, 195102, '\p{^ OTHER_Letter}', "");
Expect(1, 195102, '\P{ OTHER_Letter}', "");
Expect(0, 195102, '\P{^ OTHER_Letter}', "");
Error('\p{-IS_OTHER_letter/a/}');
Error('\P{-IS_OTHER_letter/a/}');
Expect(1, 195101, '\p{isotherletter}', "");
Expect(0, 195101, '\p{^isotherletter}', "");
Expect(0, 195101, '\P{isotherletter}', "");
Expect(1, 195101, '\P{^isotherletter}', "");
Expect(0, 195102, '\p{isotherletter}', "");
Expect(1, 195102, '\p{^isotherletter}', "");
Expect(1, 195102, '\P{isotherletter}', "");
Expect(0, 195102, '\P{^isotherletter}', "");
Expect(1, 195101, '\p{_-Is_OTHER_Letter}', "");
Expect(0, 195101, '\p{^_-Is_OTHER_Letter}', "");
Expect(0, 195101, '\P{_-Is_OTHER_Letter}', "");
Expect(1, 195101, '\P{^_-Is_OTHER_Letter}', "");
Expect(0, 195102, '\p{_-Is_OTHER_Letter}', "");
Expect(1, 195102, '\p{^_-Is_OTHER_Letter}', "");
Expect(1, 195102, '\P{_-Is_OTHER_Letter}', "");
Expect(0, 195102, '\P{^_-Is_OTHER_Letter}', "");
Error('\p{ 	Lo:=}');
Error('\P{ 	Lo:=}');
Expect(1, 195101, '\p{lo}', "");
Expect(0, 195101, '\p{^lo}', "");
Expect(0, 195101, '\P{lo}', "");
Expect(1, 195101, '\P{^lo}', "");
Expect(0, 195102, '\p{lo}', "");
Expect(1, 195102, '\p{^lo}', "");
Expect(1, 195102, '\P{lo}', "");
Expect(0, 195102, '\P{^lo}', "");
Expect(1, 195101, '\p{_lo}', "");
Expect(0, 195101, '\p{^_lo}', "");
Expect(0, 195101, '\P{_lo}', "");
Expect(1, 195101, '\P{^_lo}', "");
Expect(0, 195102, '\p{_lo}', "");
Expect(1, 195102, '\p{^_lo}', "");
Expect(1, 195102, '\P{_lo}', "");
Expect(0, 195102, '\P{^_lo}', "");
Error('\p{	/a/IS_lo}');
Error('\P{	/a/IS_lo}');
Expect(1, 195101, '\p{islo}', "");
Expect(0, 195101, '\p{^islo}', "");
Expect(0, 195101, '\P{islo}', "");
Expect(1, 195101, '\P{^islo}', "");
Expect(0, 195102, '\p{islo}', "");
Expect(1, 195102, '\p{^islo}', "");
Expect(1, 195102, '\P{islo}', "");
Expect(0, 195102, '\P{^islo}', "");
Expect(1, 195101, '\p{_ Is_LO}', "");
Expect(0, 195101, '\p{^_ Is_LO}', "");
Expect(0, 195101, '\P{_ Is_LO}', "");
Expect(1, 195101, '\P{^_ Is_LO}', "");
Expect(0, 195102, '\p{_ Is_LO}', "");
Expect(1, 195102, '\p{^_ Is_LO}', "");
Expect(1, 195102, '\P{_ Is_LO}', "");
Expect(0, 195102, '\P{^_ Is_LO}', "");
Error('\p{Other_Lowercase}');
Error('\P{Other_Lowercase}');
Error('\p{Is_Other_Lowercase}');
Error('\P{Is_Other_Lowercase}');
Error('\p{OLower}');
Error('\P{OLower}');
Error('\p{Is_OLower}');
Error('\P{Is_OLower}');
Error('\p{Other_Math}');
Error('\P{Other_Math}');
Error('\p{Is_Other_Math}');
Error('\P{Is_Other_Math}');
Error('\p{OMath}');
Error('\P{OMath}');
Error('\p{Is_OMath}');
Error('\P{Is_OMath}');
Error('\p{_	OTHER_NUMBER/a/}');
Error('\P{_	OTHER_NUMBER/a/}');
Expect(1, 127242, '\p{othernumber}', "");
Expect(0, 127242, '\p{^othernumber}', "");
Expect(0, 127242, '\P{othernumber}', "");
Expect(1, 127242, '\P{^othernumber}', "");
Expect(0, 127243, '\p{othernumber}', "");
Expect(1, 127243, '\p{^othernumber}', "");
Expect(1, 127243, '\P{othernumber}', "");
Expect(0, 127243, '\P{^othernumber}', "");
Expect(1, 127242, '\p{	Other_NUMBER}', "");
Expect(0, 127242, '\p{^	Other_NUMBER}', "");
Expect(0, 127242, '\P{	Other_NUMBER}', "");
Expect(1, 127242, '\P{^	Other_NUMBER}', "");
Expect(0, 127243, '\p{	Other_NUMBER}', "");
Expect(1, 127243, '\p{^	Other_NUMBER}', "");
Expect(1, 127243, '\P{	Other_NUMBER}', "");
Expect(0, 127243, '\P{^	Other_NUMBER}', "");
Error('\p{		Is_Other_number:=}');
Error('\P{		Is_Other_number:=}');
Expect(1, 127242, '\p{isothernumber}', "");
Expect(0, 127242, '\p{^isothernumber}', "");
Expect(0, 127242, '\P{isothernumber}', "");
Expect(1, 127242, '\P{^isothernumber}', "");
Expect(0, 127243, '\p{isothernumber}', "");
Expect(1, 127243, '\p{^isothernumber}', "");
Expect(1, 127243, '\P{isothernumber}', "");
Expect(0, 127243, '\P{^isothernumber}', "");
Expect(1, 127242, '\p{-	IS_other_number}', "");
Expect(0, 127242, '\p{^-	IS_other_number}', "");
Expect(0, 127242, '\P{-	IS_other_number}', "");
Expect(1, 127242, '\P{^-	IS_other_number}', "");
Expect(0, 127243, '\p{-	IS_other_number}', "");
Expect(1, 127243, '\p{^-	IS_other_number}', "");
Expect(1, 127243, '\P{-	IS_other_number}', "");
Expect(0, 127243, '\P{^-	IS_other_number}', "");
Error('\p{/a/_No}');
Error('\P{/a/_No}');
Expect(1, 127242, '\p{no}', "");
Expect(0, 127242, '\p{^no}', "");
Expect(0, 127242, '\P{no}', "");
Expect(1, 127242, '\P{^no}', "");
Expect(0, 127243, '\p{no}', "");
Expect(1, 127243, '\p{^no}', "");
Expect(1, 127243, '\P{no}', "");
Expect(0, 127243, '\P{^no}', "");
Expect(1, 127242, '\p{  no}', "");
Expect(0, 127242, '\p{^  no}', "");
Expect(0, 127242, '\P{  no}', "");
Expect(1, 127242, '\P{^  no}', "");
Expect(0, 127243, '\p{  no}', "");
Expect(1, 127243, '\p{^  no}', "");
Expect(1, 127243, '\P{  no}', "");
Expect(0, 127243, '\P{^  no}', "");
Error('\p{ Is_No/a/}');
Error('\P{ Is_No/a/}');
Expect(1, 127242, '\p{isno}', "");
Expect(0, 127242, '\p{^isno}', "");
Expect(0, 127242, '\P{isno}', "");
Expect(1, 127242, '\P{^isno}', "");
Expect(0, 127243, '\p{isno}', "");
Expect(1, 127243, '\p{^isno}', "");
Expect(1, 127243, '\P{isno}', "");
Expect(0, 127243, '\P{^isno}', "");
Expect(1, 127242, '\p{-	Is_NO}', "");
Expect(0, 127242, '\p{^-	Is_NO}', "");
Expect(0, 127242, '\P{-	Is_NO}', "");
Expect(1, 127242, '\P{^-	Is_NO}', "");
Expect(0, 127243, '\p{-	Is_NO}', "");
Expect(1, 127243, '\p{^-	Is_NO}', "");
Expect(1, 127243, '\P{-	Is_NO}', "");
Expect(0, 127243, '\P{^-	Is_NO}', "");
Error('\p{_Other_Punctuation:=}');
Error('\P{_Other_Punctuation:=}');
Expect(1, 74867, '\p{otherpunctuation}', "");
Expect(0, 74867, '\p{^otherpunctuation}', "");
Expect(0, 74867, '\P{otherpunctuation}', "");
Expect(1, 74867, '\P{^otherpunctuation}', "");
Expect(0, 74868, '\p{otherpunctuation}', "");
Expect(1, 74868, '\p{^otherpunctuation}', "");
Expect(1, 74868, '\P{otherpunctuation}', "");
Expect(0, 74868, '\P{^otherpunctuation}', "");
Expect(1, 74867, '\p{__other_punctuation}', "");
Expect(0, 74867, '\p{^__other_punctuation}', "");
Expect(0, 74867, '\P{__other_punctuation}', "");
Expect(1, 74867, '\P{^__other_punctuation}', "");
Expect(0, 74868, '\p{__other_punctuation}', "");
Expect(1, 74868, '\p{^__other_punctuation}', "");
Expect(1, 74868, '\P{__other_punctuation}', "");
Expect(0, 74868, '\P{^__other_punctuation}', "");
Error('\p{:= -IS_Other_Punctuation}');
Error('\P{:= -IS_Other_Punctuation}');
Expect(1, 74867, '\p{isotherpunctuation}', "");
Expect(0, 74867, '\p{^isotherpunctuation}', "");
Expect(0, 74867, '\P{isotherpunctuation}', "");
Expect(1, 74867, '\P{^isotherpunctuation}', "");
Expect(0, 74868, '\p{isotherpunctuation}', "");
Expect(1, 74868, '\p{^isotherpunctuation}', "");
Expect(1, 74868, '\P{isotherpunctuation}', "");
Expect(0, 74868, '\P{^isotherpunctuation}', "");
Expect(1, 74867, '\p{  Is_OTHER_Punctuation}', "");
Expect(0, 74867, '\p{^  Is_OTHER_Punctuation}', "");
Expect(0, 74867, '\P{  Is_OTHER_Punctuation}', "");
Expect(1, 74867, '\P{^  Is_OTHER_Punctuation}', "");
Expect(0, 74868, '\p{  Is_OTHER_Punctuation}', "");
Expect(1, 74868, '\p{^  Is_OTHER_Punctuation}', "");
Expect(1, 74868, '\P{  Is_OTHER_Punctuation}', "");
Expect(0, 74868, '\P{^  Is_OTHER_Punctuation}', "");
Error('\p{_Po/a/}');
Error('\P{_Po/a/}');
Expect(1, 74867, '\p{po}', "");
Expect(0, 74867, '\p{^po}', "");
Expect(0, 74867, '\P{po}', "");
Expect(1, 74867, '\P{^po}', "");
Expect(0, 74868, '\p{po}', "");
Expect(1, 74868, '\p{^po}', "");
Expect(1, 74868, '\P{po}', "");
Expect(0, 74868, '\P{^po}', "");
Expect(1, 74867, '\p{ po}', "");
Expect(0, 74867, '\p{^ po}', "");
Expect(0, 74867, '\P{ po}', "");
Expect(1, 74867, '\P{^ po}', "");
Expect(0, 74868, '\p{ po}', "");
Expect(1, 74868, '\p{^ po}', "");
Expect(1, 74868, '\P{ po}', "");
Expect(0, 74868, '\P{^ po}', "");
Error('\p{ Is_Po/a/}');
Error('\P{ Is_Po/a/}');
Expect(1, 74867, '\p{ispo}', "");
Expect(0, 74867, '\p{^ispo}', "");
Expect(0, 74867, '\P{ispo}', "");
Expect(1, 74867, '\P{^ispo}', "");
Expect(0, 74868, '\p{ispo}', "");
Expect(1, 74868, '\p{^ispo}', "");
Expect(1, 74868, '\P{ispo}', "");
Expect(0, 74868, '\P{^ispo}', "");
Expect(1, 74867, '\p{_is_po}', "");
Expect(0, 74867, '\p{^_is_po}', "");
Expect(0, 74867, '\P{_is_po}', "");
Expect(1, 74867, '\P{^_is_po}', "");
Expect(0, 74868, '\p{_is_po}', "");
Expect(1, 74868, '\p{^_is_po}', "");
Expect(1, 74868, '\P{_is_po}', "");
Expect(0, 74868, '\P{^_is_po}', "");
Error('\p{- other_Symbol:=}');
Error('\P{- other_Symbol:=}');
Expect(1, 128883, '\p{othersymbol}', "");
Expect(0, 128883, '\p{^othersymbol}', "");
Expect(0, 128883, '\P{othersymbol}', "");
Expect(1, 128883, '\P{^othersymbol}', "");
Expect(0, 128884, '\p{othersymbol}', "");
Expect(1, 128884, '\p{^othersymbol}', "");
Expect(1, 128884, '\P{othersymbol}', "");
Expect(0, 128884, '\P{^othersymbol}', "");
Expect(1, 128883, '\p{ 	Other_Symbol}', "");
Expect(0, 128883, '\p{^ 	Other_Symbol}', "");
Expect(0, 128883, '\P{ 	Other_Symbol}', "");
Expect(1, 128883, '\P{^ 	Other_Symbol}', "");
Expect(0, 128884, '\p{ 	Other_Symbol}', "");
Expect(1, 128884, '\p{^ 	Other_Symbol}', "");
Expect(1, 128884, '\P{ 	Other_Symbol}', "");
Expect(0, 128884, '\P{^ 	Other_Symbol}', "");
Error('\p{	/a/Is_OTHER_Symbol}');
Error('\P{	/a/Is_OTHER_Symbol}');
Expect(1, 128883, '\p{isothersymbol}', "");
Expect(0, 128883, '\p{^isothersymbol}', "");
Expect(0, 128883, '\P{isothersymbol}', "");
Expect(1, 128883, '\P{^isothersymbol}', "");
Expect(0, 128884, '\p{isothersymbol}', "");
Expect(1, 128884, '\p{^isothersymbol}', "");
Expect(1, 128884, '\P{isothersymbol}', "");
Expect(0, 128884, '\P{^isothersymbol}', "");
Expect(1, 128883, '\p{ 	IS_other_Symbol}', "");
Expect(0, 128883, '\p{^ 	IS_other_Symbol}', "");
Expect(0, 128883, '\P{ 	IS_other_Symbol}', "");
Expect(1, 128883, '\P{^ 	IS_other_Symbol}', "");
Expect(0, 128884, '\p{ 	IS_other_Symbol}', "");
Expect(1, 128884, '\p{^ 	IS_other_Symbol}', "");
Expect(1, 128884, '\P{ 	IS_other_Symbol}', "");
Expect(0, 128884, '\P{^ 	IS_other_Symbol}', "");
Error('\p{	SO/a/}');
Error('\P{	SO/a/}');
Expect(1, 128883, '\p{so}', "");
Expect(0, 128883, '\p{^so}', "");
Expect(0, 128883, '\P{so}', "");
Expect(1, 128883, '\P{^so}', "");
Expect(0, 128884, '\p{so}', "");
Expect(1, 128884, '\p{^so}', "");
Expect(1, 128884, '\P{so}', "");
Expect(0, 128884, '\P{^so}', "");
Expect(1, 128883, '\p{	 So}', "");
Expect(0, 128883, '\p{^	 So}', "");
Expect(0, 128883, '\P{	 So}', "");
Expect(1, 128883, '\P{^	 So}', "");
Expect(0, 128884, '\p{	 So}', "");
Expect(1, 128884, '\p{^	 So}', "");
Expect(1, 128884, '\P{	 So}', "");
Expect(0, 128884, '\P{^	 So}', "");
Error('\p{:=_Is_SO}');
Error('\P{:=_Is_SO}');
Expect(1, 128883, '\p{isso}', "");
Expect(0, 128883, '\p{^isso}', "");
Expect(0, 128883, '\P{isso}', "");
Expect(1, 128883, '\P{^isso}', "");
Expect(0, 128884, '\p{isso}', "");
Expect(1, 128884, '\p{^isso}', "");
Expect(1, 128884, '\P{isso}', "");
Expect(0, 128884, '\P{^isso}', "");
Expect(1, 128883, '\p{_-Is_So}', "");
Expect(0, 128883, '\p{^_-Is_So}', "");
Expect(0, 128883, '\P{_-Is_So}', "");
Expect(1, 128883, '\P{^_-Is_So}', "");
Expect(0, 128884, '\p{_-Is_So}', "");
Expect(1, 128884, '\p{^_-Is_So}', "");
Expect(1, 128884, '\P{_-Is_So}', "");
Expect(0, 128884, '\P{^_-Is_So}', "");
Error('\p{Other_Uppercase}');
Error('\P{Other_Uppercase}');
Error('\p{Is_Other_Uppercase}');
Error('\P{Is_Other_Uppercase}');
Error('\p{OUpper}');
Error('\P{OUpper}');
Error('\p{Is_OUpper}');
Error('\P{Is_OUpper}');
Error('\p{:=	Paragraph_Separator}');
Error('\P{:=	Paragraph_Separator}');
Expect(1, 8233, '\p{paragraphseparator}', "");
Expect(0, 8233, '\p{^paragraphseparator}', "");
Expect(0, 8233, '\P{paragraphseparator}', "");
Expect(1, 8233, '\P{^paragraphseparator}', "");
Expect(0, 8234, '\p{paragraphseparator}', "");
Expect(1, 8234, '\p{^paragraphseparator}', "");
Expect(1, 8234, '\P{paragraphseparator}', "");
Expect(0, 8234, '\P{^paragraphseparator}', "");
Expect(1, 8233, '\p{_-paragraph_SEPARATOR}', "");
Expect(0, 8233, '\p{^_-paragraph_SEPARATOR}', "");
Expect(0, 8233, '\P{_-paragraph_SEPARATOR}', "");
Expect(1, 8233, '\P{^_-paragraph_SEPARATOR}', "");
Expect(0, 8234, '\p{_-paragraph_SEPARATOR}', "");
Expect(1, 8234, '\p{^_-paragraph_SEPARATOR}', "");
Expect(1, 8234, '\P{_-paragraph_SEPARATOR}', "");
Expect(0, 8234, '\P{^_-paragraph_SEPARATOR}', "");
Error('\p{:=is_paragraph_SEPARATOR}');
Error('\P{:=is_paragraph_SEPARATOR}');
Expect(1, 8233, '\p{isparagraphseparator}', "");
Expect(0, 8233, '\p{^isparagraphseparator}', "");
Expect(0, 8233, '\P{isparagraphseparator}', "");
Expect(1, 8233, '\P{^isparagraphseparator}', "");
Expect(0, 8234, '\p{isparagraphseparator}', "");
Expect(1, 8234, '\p{^isparagraphseparator}', "");
Expect(1, 8234, '\P{isparagraphseparator}', "");
Expect(0, 8234, '\P{^isparagraphseparator}', "");
Expect(1, 8233, '\p{	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(0, 8233, '\p{^	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(0, 8233, '\P{	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(1, 8233, '\P{^	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(0, 8234, '\p{	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(1, 8234, '\p{^	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(1, 8234, '\P{	_IS_PARAGRAPH_SEPARATOR}', "");
Expect(0, 8234, '\P{^	_IS_PARAGRAPH_SEPARATOR}', "");
Error('\p{ :=Zp}');
Error('\P{ :=Zp}');
Expect(1, 8233, '\p{zp}', "");
Expect(0, 8233, '\p{^zp}', "");
Expect(0, 8233, '\P{zp}', "");
Expect(1, 8233, '\P{^zp}', "");
Expect(0, 8234, '\p{zp}', "");
Expect(1, 8234, '\p{^zp}', "");
Expect(1, 8234, '\P{zp}', "");
Expect(0, 8234, '\P{^zp}', "");
Expect(1, 8233, '\p{_zp}', "");
Expect(0, 8233, '\p{^_zp}', "");
Expect(0, 8233, '\P{_zp}', "");
Expect(1, 8233, '\P{^_zp}', "");
Expect(0, 8234, '\p{_zp}', "");
Expect(1, 8234, '\p{^_zp}', "");
Expect(1, 8234, '\P{_zp}', "");
Expect(0, 8234, '\P{^_zp}', "");
Error('\p{ 	IS_Zp/a/}');
Error('\P{ 	IS_Zp/a/}');
Expect(1, 8233, '\p{iszp}', "");
Expect(0, 8233, '\p{^iszp}', "");
Expect(0, 8233, '\P{iszp}', "");
Expect(1, 8233, '\P{^iszp}', "");
Expect(0, 8234, '\p{iszp}', "");
Expect(1, 8234, '\p{^iszp}', "");
Expect(1, 8234, '\P{iszp}', "");
Expect(0, 8234, '\P{^iszp}', "");
Expect(1, 8233, '\p{ is_Zp}', "");
Expect(0, 8233, '\p{^ is_Zp}', "");
Expect(0, 8233, '\P{ is_Zp}', "");
Expect(1, 8233, '\P{^ is_Zp}', "");
Expect(0, 8234, '\p{ is_Zp}', "");
Expect(1, 8234, '\p{^ is_Zp}', "");
Expect(1, 8234, '\P{ is_Zp}', "");
Expect(0, 8234, '\P{^ is_Zp}', "");
Error('\p{	Pattern_SYNTAX:=}');
Error('\P{	Pattern_SYNTAX:=}');
Expect(1, 65094, '\p{patternsyntax}', "");
Expect(0, 65094, '\p{^patternsyntax}', "");
Expect(0, 65094, '\P{patternsyntax}', "");
Expect(1, 65094, '\P{^patternsyntax}', "");
Expect(0, 65095, '\p{patternsyntax}', "");
Expect(1, 65095, '\p{^patternsyntax}', "");
Expect(1, 65095, '\P{patternsyntax}', "");
Expect(0, 65095, '\P{^patternsyntax}', "");
Expect(1, 65094, '\p{Pattern_Syntax}', "");
Expect(0, 65094, '\p{^Pattern_Syntax}', "");
Expect(0, 65094, '\P{Pattern_Syntax}', "");
Expect(1, 65094, '\P{^Pattern_Syntax}', "");
Expect(0, 65095, '\p{Pattern_Syntax}', "");
Expect(1, 65095, '\p{^Pattern_Syntax}', "");
Expect(1, 65095, '\P{Pattern_Syntax}', "");
Expect(0, 65095, '\P{^Pattern_Syntax}', "");
Error('\p{:=__is_Pattern_SYNTAX}');
Error('\P{:=__is_Pattern_SYNTAX}');
Expect(1, 65094, '\p{ispatternsyntax}', "");
Expect(0, 65094, '\p{^ispatternsyntax}', "");
Expect(0, 65094, '\P{ispatternsyntax}', "");
Expect(1, 65094, '\P{^ispatternsyntax}', "");
Expect(0, 65095, '\p{ispatternsyntax}', "");
Expect(1, 65095, '\p{^ispatternsyntax}', "");
Expect(1, 65095, '\P{ispatternsyntax}', "");
Expect(0, 65095, '\P{^ispatternsyntax}', "");
Expect(1, 65094, '\p{__Is_Pattern_Syntax}', "");
Expect(0, 65094, '\p{^__Is_Pattern_Syntax}', "");
Expect(0, 65094, '\P{__Is_Pattern_Syntax}', "");
Expect(1, 65094, '\P{^__Is_Pattern_Syntax}', "");
Expect(0, 65095, '\p{__Is_Pattern_Syntax}', "");
Expect(1, 65095, '\p{^__Is_Pattern_Syntax}', "");
Expect(1, 65095, '\P{__Is_Pattern_Syntax}', "");
Expect(0, 65095, '\P{^__Is_Pattern_Syntax}', "");
Error('\p{ Pat_SYN:=}');
Error('\P{ Pat_SYN:=}');
Expect(1, 65094, '\p{patsyn}', "");
Expect(0, 65094, '\p{^patsyn}', "");
Expect(0, 65094, '\P{patsyn}', "");
Expect(1, 65094, '\P{^patsyn}', "");
Expect(0, 65095, '\p{patsyn}', "");
Expect(1, 65095, '\p{^patsyn}', "");
Expect(1, 65095, '\P{patsyn}', "");
Expect(0, 65095, '\P{^patsyn}', "");
Expect(1, 65094, '\p{-_Pat_syn}', "");
Expect(0, 65094, '\p{^-_Pat_syn}', "");
Expect(0, 65094, '\P{-_Pat_syn}', "");
Expect(1, 65094, '\P{^-_Pat_syn}', "");
Expect(0, 65095, '\p{-_Pat_syn}', "");
Expect(1, 65095, '\p{^-_Pat_syn}', "");
Expect(1, 65095, '\P{-_Pat_syn}', "");
Expect(0, 65095, '\P{^-_Pat_syn}', "");
Error('\p{ _Is_PAT_syn:=}');
Error('\P{ _Is_PAT_syn:=}');
Expect(1, 65094, '\p{ispatsyn}', "");
Expect(0, 65094, '\p{^ispatsyn}', "");
Expect(0, 65094, '\P{ispatsyn}', "");
Expect(1, 65094, '\P{^ispatsyn}', "");
Expect(0, 65095, '\p{ispatsyn}', "");
Expect(1, 65095, '\p{^ispatsyn}', "");
Expect(1, 65095, '\P{ispatsyn}', "");
Expect(0, 65095, '\P{^ispatsyn}', "");
Expect(1, 65094, '\p{Is_PAT_SYN}', "");
Expect(0, 65094, '\p{^Is_PAT_SYN}', "");
Expect(0, 65094, '\P{Is_PAT_SYN}', "");
Expect(1, 65094, '\P{^Is_PAT_SYN}', "");
Expect(0, 65095, '\p{Is_PAT_SYN}', "");
Expect(1, 65095, '\p{^Is_PAT_SYN}', "");
Expect(1, 65095, '\P{Is_PAT_SYN}', "");
Expect(0, 65095, '\P{^Is_PAT_SYN}', "");
Error('\p{/a/PATTERN_WHITE_SPACE}');
Error('\P{/a/PATTERN_WHITE_SPACE}');
Expect(1, 8233, '\p{patternwhitespace}', "");
Expect(0, 8233, '\p{^patternwhitespace}', "");
Expect(0, 8233, '\P{patternwhitespace}', "");
Expect(1, 8233, '\P{^patternwhitespace}', "");
Expect(0, 8234, '\p{patternwhitespace}', "");
Expect(1, 8234, '\p{^patternwhitespace}', "");
Expect(1, 8234, '\P{patternwhitespace}', "");
Expect(0, 8234, '\P{^patternwhitespace}', "");
Expect(1, 8233, '\p{_Pattern_WHITE_SPACE}', "");
Expect(0, 8233, '\p{^_Pattern_WHITE_SPACE}', "");
Expect(0, 8233, '\P{_Pattern_WHITE_SPACE}', "");
Expect(1, 8233, '\P{^_Pattern_WHITE_SPACE}', "");
Expect(0, 8234, '\p{_Pattern_WHITE_SPACE}', "");
Expect(1, 8234, '\p{^_Pattern_WHITE_SPACE}', "");
Expect(1, 8234, '\P{_Pattern_WHITE_SPACE}', "");
Expect(0, 8234, '\P{^_Pattern_WHITE_SPACE}', "");
Error('\p{	/a/Is_Pattern_white_Space}');
Error('\P{	/a/Is_Pattern_white_Space}');
Expect(1, 8233, '\p{ispatternwhitespace}', "");
Expect(0, 8233, '\p{^ispatternwhitespace}', "");
Expect(0, 8233, '\P{ispatternwhitespace}', "");
Expect(1, 8233, '\P{^ispatternwhitespace}', "");
Expect(0, 8234, '\p{ispatternwhitespace}', "");
Expect(1, 8234, '\p{^ispatternwhitespace}', "");
Expect(1, 8234, '\P{ispatternwhitespace}', "");
Expect(0, 8234, '\P{^ispatternwhitespace}', "");
Expect(1, 8233, '\p{		is_Pattern_WHITE_space}', "");
Expect(0, 8233, '\p{^		is_Pattern_WHITE_space}', "");
Expect(0, 8233, '\P{		is_Pattern_WHITE_space}', "");
Expect(1, 8233, '\P{^		is_Pattern_WHITE_space}', "");
Expect(0, 8234, '\p{		is_Pattern_WHITE_space}', "");
Expect(1, 8234, '\p{^		is_Pattern_WHITE_space}', "");
Expect(1, 8234, '\P{		is_Pattern_WHITE_space}', "");
Expect(0, 8234, '\P{^		is_Pattern_WHITE_space}', "");
Error('\p{-/a/PAT_ws}');
Error('\P{-/a/PAT_ws}');
Expect(1, 8233, '\p{patws}', "");
Expect(0, 8233, '\p{^patws}', "");
Expect(0, 8233, '\P{patws}', "");
Expect(1, 8233, '\P{^patws}', "");
Expect(0, 8234, '\p{patws}', "");
Expect(1, 8234, '\p{^patws}', "");
Expect(1, 8234, '\P{patws}', "");
Expect(0, 8234, '\P{^patws}', "");
Expect(1, 8233, '\p{		Pat_WS}', "");
Expect(0, 8233, '\p{^		Pat_WS}', "");
Expect(0, 8233, '\P{		Pat_WS}', "");
Expect(1, 8233, '\P{^		Pat_WS}', "");
Expect(0, 8234, '\p{		Pat_WS}', "");
Expect(1, 8234, '\p{^		Pat_WS}', "");
Expect(1, 8234, '\P{		Pat_WS}', "");
Expect(0, 8234, '\P{^		Pat_WS}', "");
Error('\p{/a/IS_PAT_WS}');
Error('\P{/a/IS_PAT_WS}');
Expect(1, 8233, '\p{ispatws}', "");
Expect(0, 8233, '\p{^ispatws}', "");
Expect(0, 8233, '\P{ispatws}', "");
Expect(1, 8233, '\P{^ispatws}', "");
Expect(0, 8234, '\p{ispatws}', "");
Expect(1, 8234, '\p{^ispatws}', "");
Expect(1, 8234, '\P{ispatws}', "");
Expect(0, 8234, '\P{^ispatws}', "");
Expect(1, 8233, '\p{	IS_Pat_ws}', "");
Expect(0, 8233, '\p{^	IS_Pat_ws}', "");
Expect(0, 8233, '\P{	IS_Pat_ws}', "");
Expect(1, 8233, '\P{^	IS_Pat_ws}', "");
Expect(0, 8234, '\p{	IS_Pat_ws}', "");
Expect(1, 8234, '\p{^	IS_Pat_ws}', "");
Expect(1, 8234, '\P{	IS_Pat_ws}', "");
Expect(0, 8234, '\P{^	IS_Pat_ws}', "");
Error('\p{:=	 PerlSpace}');
Error('\P{:=	 PerlSpace}');
Expect(1, 32, '\p{perlspace}', "");
Expect(0, 32, '\p{^perlspace}', "");
Expect(0, 32, '\P{perlspace}', "");
Expect(1, 32, '\P{^perlspace}', "");
Expect(0, 33, '\p{perlspace}', "");
Expect(1, 33, '\p{^perlspace}', "");
Expect(1, 33, '\P{perlspace}', "");
Expect(0, 33, '\P{^perlspace}', "");
Expect(1, 32, '\p{ PerlSpace}', "");
Expect(0, 32, '\p{^ PerlSpace}', "");
Expect(0, 32, '\P{ PerlSpace}', "");
Expect(1, 32, '\P{^ PerlSpace}', "");
Expect(0, 33, '\p{ PerlSpace}', "");
Expect(1, 33, '\p{^ PerlSpace}', "");
Expect(1, 33, '\P{ PerlSpace}', "");
Expect(0, 33, '\P{^ PerlSpace}', "");
Error('\p{	is_PerlSpace:=}');
Error('\P{	is_PerlSpace:=}');
Expect(1, 32, '\p{isperlspace}', "");
Expect(0, 32, '\p{^isperlspace}', "");
Expect(0, 32, '\P{isperlspace}', "");
Expect(1, 32, '\P{^isperlspace}', "");
Expect(0, 33, '\p{isperlspace}', "");
Expect(1, 33, '\p{^isperlspace}', "");
Expect(1, 33, '\P{isperlspace}', "");
Expect(0, 33, '\P{^isperlspace}', "");
Expect(1, 32, '\p{--IS_PerlSpace}', "");
Expect(0, 32, '\p{^--IS_PerlSpace}', "");
Expect(0, 32, '\P{--IS_PerlSpace}', "");
Expect(1, 32, '\P{^--IS_PerlSpace}', "");
Expect(0, 33, '\p{--IS_PerlSpace}', "");
Expect(1, 33, '\p{^--IS_PerlSpace}', "");
Expect(1, 33, '\P{--IS_PerlSpace}', "");
Expect(0, 33, '\P{^--IS_PerlSpace}', "");
Error('\p{-/a/perlword}');
Error('\P{-/a/perlword}');
Expect(1, 122, '\p{perlword}', "");
Expect(0, 122, '\p{^perlword}', "");
Expect(0, 122, '\P{perlword}', "");
Expect(1, 122, '\P{^perlword}', "");
Expect(0, 123, '\p{perlword}', "");
Expect(1, 123, '\p{^perlword}', "");
Expect(1, 123, '\P{perlword}', "");
Expect(0, 123, '\P{^perlword}', "");
Expect(1, 122, '\p{-	perlword}', "");
Expect(0, 122, '\p{^-	perlword}', "");
Expect(0, 122, '\P{-	perlword}', "");
Expect(1, 122, '\P{^-	perlword}', "");
Expect(0, 123, '\p{-	perlword}', "");
Expect(1, 123, '\p{^-	perlword}', "");
Expect(1, 123, '\P{-	perlword}', "");
Expect(0, 123, '\P{^-	perlword}', "");
Error('\p{	 PosixWord/a/}');
Error('\P{	 PosixWord/a/}');
Expect(1, 122, '\p{posixword}', "");
Expect(0, 122, '\p{^posixword}', "");
Expect(0, 122, '\P{posixword}', "");
Expect(1, 122, '\P{^posixword}', "");
Expect(0, 123, '\p{posixword}', "");
Expect(1, 123, '\p{^posixword}', "");
Expect(1, 123, '\P{posixword}', "");
Expect(0, 123, '\P{^posixword}', "");
Expect(1, 122, '\p{ POSIXWORD}', "");
Expect(0, 122, '\p{^ POSIXWORD}', "");
Expect(0, 122, '\P{ POSIXWORD}', "");
Expect(1, 122, '\P{^ POSIXWORD}', "");
Expect(0, 123, '\p{ POSIXWORD}', "");
Expect(1, 123, '\p{^ POSIXWORD}', "");
Expect(1, 123, '\P{ POSIXWORD}', "");
Expect(0, 123, '\P{^ POSIXWORD}', "");
Error('\p{ 	is_perlword/a/}');
Error('\P{ 	is_perlword/a/}');
Expect(1, 122, '\p{isperlword}', "");
Expect(0, 122, '\p{^isperlword}', "");
Expect(0, 122, '\P{isperlword}', "");
Expect(1, 122, '\P{^isperlword}', "");
Expect(0, 123, '\p{isperlword}', "");
Expect(1, 123, '\p{^isperlword}', "");
Expect(1, 123, '\P{isperlword}', "");
Expect(0, 123, '\P{^isperlword}', "");
Expect(1, 122, '\p{_-is_PERLWORD}', "");
Expect(0, 122, '\p{^_-is_PERLWORD}', "");
Expect(0, 122, '\P{_-is_PERLWORD}', "");
Expect(1, 122, '\P{^_-is_PERLWORD}', "");
Expect(0, 123, '\p{_-is_PERLWORD}', "");
Expect(1, 123, '\p{^_-is_PERLWORD}', "");
Expect(1, 123, '\P{_-is_PERLWORD}', "");
Expect(0, 123, '\P{^_-is_PERLWORD}', "");
Error('\p{  Is_PosixWord:=}');
Error('\P{  Is_PosixWord:=}');
Expect(1, 122, '\p{isposixword}', "");
Expect(0, 122, '\p{^isposixword}', "");
Expect(0, 122, '\P{isposixword}', "");
Expect(1, 122, '\P{^isposixword}', "");
Expect(0, 123, '\p{isposixword}', "");
Expect(1, 123, '\p{^isposixword}', "");
Expect(1, 123, '\P{isposixword}', "");
Expect(0, 123, '\P{^isposixword}', "");
Expect(1, 122, '\p{ Is_POSIXWORD}', "");
Expect(0, 122, '\p{^ Is_POSIXWORD}', "");
Expect(0, 122, '\P{ Is_POSIXWORD}', "");
Expect(1, 122, '\P{^ Is_POSIXWORD}', "");
Expect(0, 123, '\p{ Is_POSIXWORD}', "");
Expect(1, 123, '\p{^ Is_POSIXWORD}', "");
Expect(1, 123, '\P{ Is_POSIXWORD}', "");
Expect(0, 123, '\P{^ Is_POSIXWORD}', "");
Error('\p{/a/	_phags_PA}');
Error('\P{/a/	_phags_PA}');
Expect(1, 43127, '\p{phagspa}', "");
Expect(0, 43127, '\p{^phagspa}', "");
Expect(0, 43127, '\P{phagspa}', "");
Expect(1, 43127, '\P{^phagspa}', "");
Expect(0, 43128, '\p{phagspa}', "");
Expect(1, 43128, '\p{^phagspa}', "");
Expect(1, 43128, '\P{phagspa}', "");
Expect(0, 43128, '\P{^phagspa}', "");
Expect(1, 43127, '\p{_ Phags_pa}', "");
Expect(0, 43127, '\p{^_ Phags_pa}', "");
Expect(0, 43127, '\P{_ Phags_pa}', "");
Expect(1, 43127, '\P{^_ Phags_pa}', "");
Expect(0, 43128, '\p{_ Phags_pa}', "");
Expect(1, 43128, '\p{^_ Phags_pa}', "");
Expect(1, 43128, '\P{_ Phags_pa}', "");
Expect(0, 43128, '\P{^_ Phags_pa}', "");
Error('\p{/a/ Is_Phags_Pa}');
Error('\P{/a/ Is_Phags_Pa}');
Expect(1, 43127, '\p{isphagspa}', "");
Expect(0, 43127, '\p{^isphagspa}', "");
Expect(0, 43127, '\P{isphagspa}', "");
Expect(1, 43127, '\P{^isphagspa}', "");
Expect(0, 43128, '\p{isphagspa}', "");
Expect(1, 43128, '\p{^isphagspa}', "");
Expect(1, 43128, '\P{isphagspa}', "");
Expect(0, 43128, '\P{^isphagspa}', "");
Expect(1, 43127, '\p{ _Is_PHAGS_Pa}', "");
Expect(0, 43127, '\p{^ _Is_PHAGS_Pa}', "");
Expect(0, 43127, '\P{ _Is_PHAGS_Pa}', "");
Expect(1, 43127, '\P{^ _Is_PHAGS_Pa}', "");
Expect(0, 43128, '\p{ _Is_PHAGS_Pa}', "");
Expect(1, 43128, '\p{^ _Is_PHAGS_Pa}', "");
Expect(1, 43128, '\P{ _Is_PHAGS_Pa}', "");
Expect(0, 43128, '\P{^ _Is_PHAGS_Pa}', "");
Error('\p{ -PHAG:=}');
Error('\P{ -PHAG:=}');
Expect(1, 43127, '\p{phag}', "");
Expect(0, 43127, '\p{^phag}', "");
Expect(0, 43127, '\P{phag}', "");
Expect(1, 43127, '\P{^phag}', "");
Expect(0, 43128, '\p{phag}', "");
Expect(1, 43128, '\p{^phag}', "");
Expect(1, 43128, '\P{phag}', "");
Expect(0, 43128, '\P{^phag}', "");
Expect(1, 43127, '\p{_Phag}', "");
Expect(0, 43127, '\p{^_Phag}', "");
Expect(0, 43127, '\P{_Phag}', "");
Expect(1, 43127, '\P{^_Phag}', "");
Expect(0, 43128, '\p{_Phag}', "");
Expect(1, 43128, '\p{^_Phag}', "");
Expect(1, 43128, '\P{_Phag}', "");
Expect(0, 43128, '\P{^_Phag}', "");
Error('\p{_:=is_phag}');
Error('\P{_:=is_phag}');
Expect(1, 43127, '\p{isphag}', "");
Expect(0, 43127, '\p{^isphag}', "");
Expect(0, 43127, '\P{isphag}', "");
Expect(1, 43127, '\P{^isphag}', "");
Expect(0, 43128, '\p{isphag}', "");
Expect(1, 43128, '\p{^isphag}', "");
Expect(1, 43128, '\P{isphag}', "");
Expect(0, 43128, '\P{^isphag}', "");
Expect(1, 43127, '\p{		IS_Phag}', "");
Expect(0, 43127, '\p{^		IS_Phag}', "");
Expect(0, 43127, '\P{		IS_Phag}', "");
Expect(1, 43127, '\P{^		IS_Phag}', "");
Expect(0, 43128, '\p{		IS_Phag}', "");
Expect(1, 43128, '\p{^		IS_Phag}', "");
Expect(1, 43128, '\P{		IS_Phag}', "");
Expect(0, 43128, '\P{^		IS_Phag}', "");
Error('\p{__Phaistos_Disc:=}');
Error('\P{__Phaistos_Disc:=}');
Expect(1, 66047, '\p{phaistosdisc}', "");
Expect(0, 66047, '\p{^phaistosdisc}', "");
Expect(0, 66047, '\P{phaistosdisc}', "");
Expect(1, 66047, '\P{^phaistosdisc}', "");
Expect(0, 66048, '\p{phaistosdisc}', "");
Expect(1, 66048, '\p{^phaistosdisc}', "");
Expect(1, 66048, '\P{phaistosdisc}', "");
Expect(0, 66048, '\P{^phaistosdisc}', "");
Expect(1, 66047, '\p{	_Phaistos_Disc}', "");
Expect(0, 66047, '\p{^	_Phaistos_Disc}', "");
Expect(0, 66047, '\P{	_Phaistos_Disc}', "");
Expect(1, 66047, '\P{^	_Phaistos_Disc}', "");
Expect(0, 66048, '\p{	_Phaistos_Disc}', "");
Expect(1, 66048, '\p{^	_Phaistos_Disc}', "");
Expect(1, 66048, '\P{	_Phaistos_Disc}', "");
Expect(0, 66048, '\P{^	_Phaistos_Disc}', "");
Error('\p{	 is_Phaistos_Disc:=}');
Error('\P{	 is_Phaistos_Disc:=}');
Expect(1, 66047, '\p{isphaistosdisc}', "");
Expect(0, 66047, '\p{^isphaistosdisc}', "");
Expect(0, 66047, '\P{isphaistosdisc}', "");
Expect(1, 66047, '\P{^isphaistosdisc}', "");
Expect(0, 66048, '\p{isphaistosdisc}', "");
Expect(1, 66048, '\p{^isphaistosdisc}', "");
Expect(1, 66048, '\P{isphaistosdisc}', "");
Expect(0, 66048, '\P{^isphaistosdisc}', "");
Expect(1, 66047, '\p{ Is_PHAISTOS_Disc}', "");
Expect(0, 66047, '\p{^ Is_PHAISTOS_Disc}', "");
Expect(0, 66047, '\P{ Is_PHAISTOS_Disc}', "");
Expect(1, 66047, '\P{^ Is_PHAISTOS_Disc}', "");
Expect(0, 66048, '\p{ Is_PHAISTOS_Disc}', "");
Expect(1, 66048, '\p{^ Is_PHAISTOS_Disc}', "");
Expect(1, 66048, '\P{ Is_PHAISTOS_Disc}', "");
Expect(0, 66048, '\P{^ Is_PHAISTOS_Disc}', "");
Error('\p{:=In_Phaistos_Disc}');
Error('\P{:=In_Phaistos_Disc}');
Expect(1, 66047, '\p{inphaistosdisc}', "");
Expect(0, 66047, '\p{^inphaistosdisc}', "");
Expect(0, 66047, '\P{inphaistosdisc}', "");
Expect(1, 66047, '\P{^inphaistosdisc}', "");
Expect(0, 66048, '\p{inphaistosdisc}', "");
Expect(1, 66048, '\p{^inphaistosdisc}', "");
Expect(1, 66048, '\P{inphaistosdisc}', "");
Expect(0, 66048, '\P{^inphaistosdisc}', "");
Expect(1, 66047, '\p{ -In_Phaistos_Disc}', "");
Expect(0, 66047, '\p{^ -In_Phaistos_Disc}', "");
Expect(0, 66047, '\P{ -In_Phaistos_Disc}', "");
Expect(1, 66047, '\P{^ -In_Phaistos_Disc}', "");
Expect(0, 66048, '\p{ -In_Phaistos_Disc}', "");
Expect(1, 66048, '\p{^ -In_Phaistos_Disc}', "");
Expect(1, 66048, '\P{ -In_Phaistos_Disc}', "");
Expect(0, 66048, '\P{^ -In_Phaistos_Disc}', "");
Error('\p{ /a/Phaistos}');
Error('\P{ /a/Phaistos}');
Expect(1, 66047, '\p{phaistos}', "");
Expect(0, 66047, '\p{^phaistos}', "");
Expect(0, 66047, '\P{phaistos}', "");
Expect(1, 66047, '\P{^phaistos}', "");
Expect(0, 66048, '\p{phaistos}', "");
Expect(1, 66048, '\p{^phaistos}', "");
Expect(1, 66048, '\P{phaistos}', "");
Expect(0, 66048, '\P{^phaistos}', "");
Expect(1, 66047, '\p{ -PHAISTOS}', "");
Expect(0, 66047, '\p{^ -PHAISTOS}', "");
Expect(0, 66047, '\P{ -PHAISTOS}', "");
Expect(1, 66047, '\P{^ -PHAISTOS}', "");
Expect(0, 66048, '\p{ -PHAISTOS}', "");
Expect(1, 66048, '\p{^ -PHAISTOS}', "");
Expect(1, 66048, '\P{ -PHAISTOS}', "");
Expect(0, 66048, '\P{^ -PHAISTOS}', "");
Error('\p{		is_PHAISTOS:=}');
Error('\P{		is_PHAISTOS:=}');
Expect(1, 66047, '\p{isphaistos}', "");
Expect(0, 66047, '\p{^isphaistos}', "");
Expect(0, 66047, '\P{isphaistos}', "");
Expect(1, 66047, '\P{^isphaistos}', "");
Expect(0, 66048, '\p{isphaistos}', "");
Expect(1, 66048, '\p{^isphaistos}', "");
Expect(1, 66048, '\P{isphaistos}', "");
Expect(0, 66048, '\P{^isphaistos}', "");
Expect(1, 66047, '\p{	-IS_Phaistos}', "");
Expect(0, 66047, '\p{^	-IS_Phaistos}', "");
Expect(0, 66047, '\P{	-IS_Phaistos}', "");
Expect(1, 66047, '\P{^	-IS_Phaistos}', "");
Expect(0, 66048, '\p{	-IS_Phaistos}', "");
Expect(1, 66048, '\p{^	-IS_Phaistos}', "");
Expect(1, 66048, '\P{	-IS_Phaistos}', "");
Expect(0, 66048, '\P{^	-IS_Phaistos}', "");
Error('\p{/a/ _in_PHAISTOS}');
Error('\P{/a/ _in_PHAISTOS}');
Expect(1, 66047, '\p{inphaistos}', "");
Expect(0, 66047, '\p{^inphaistos}', "");
Expect(0, 66047, '\P{inphaistos}', "");
Expect(1, 66047, '\P{^inphaistos}', "");
Expect(0, 66048, '\p{inphaistos}', "");
Expect(1, 66048, '\p{^inphaistos}', "");
Expect(1, 66048, '\P{inphaistos}', "");
Expect(0, 66048, '\P{^inphaistos}', "");
Expect(1, 66047, '\p{		in_Phaistos}', "");
Expect(0, 66047, '\p{^		in_Phaistos}', "");
Expect(0, 66047, '\P{		in_Phaistos}', "");
Expect(1, 66047, '\P{^		in_Phaistos}', "");
Expect(0, 66048, '\p{		in_Phaistos}', "");
Expect(1, 66048, '\p{^		in_Phaistos}', "");
Expect(1, 66048, '\P{		in_Phaistos}', "");
Expect(0, 66048, '\P{^		in_Phaistos}', "");
Error('\p{- PHOENICIAN:=}');
Error('\P{- PHOENICIAN:=}');
Expect(1, 67871, '\p{phoenician}', "");
Expect(0, 67871, '\p{^phoenician}', "");
Expect(0, 67871, '\P{phoenician}', "");
Expect(1, 67871, '\P{^phoenician}', "");
Expect(0, 67872, '\p{phoenician}', "");
Expect(1, 67872, '\p{^phoenician}', "");
Expect(1, 67872, '\P{phoenician}', "");
Expect(0, 67872, '\P{^phoenician}', "");
Expect(1, 67871, '\p{ _Phoenician}', "");
Expect(0, 67871, '\p{^ _Phoenician}', "");
Expect(0, 67871, '\P{ _Phoenician}', "");
Expect(1, 67871, '\P{^ _Phoenician}', "");
Expect(0, 67872, '\p{ _Phoenician}', "");
Expect(1, 67872, '\p{^ _Phoenician}', "");
Expect(1, 67872, '\P{ _Phoenician}', "");
Expect(0, 67872, '\P{^ _Phoenician}', "");
Error('\p{/a/_Is_phoenician}');
Error('\P{/a/_Is_phoenician}');
Expect(1, 67871, '\p{isphoenician}', "");
Expect(0, 67871, '\p{^isphoenician}', "");
Expect(0, 67871, '\P{isphoenician}', "");
Expect(1, 67871, '\P{^isphoenician}', "");
Expect(0, 67872, '\p{isphoenician}', "");
Expect(1, 67872, '\p{^isphoenician}', "");
Expect(1, 67872, '\P{isphoenician}', "");
Expect(0, 67872, '\P{^isphoenician}', "");
Expect(1, 67871, '\p{	IS_Phoenician}', "");
Expect(0, 67871, '\p{^	IS_Phoenician}', "");
Expect(0, 67871, '\P{	IS_Phoenician}', "");
Expect(1, 67871, '\P{^	IS_Phoenician}', "");
Expect(0, 67872, '\p{	IS_Phoenician}', "");
Expect(1, 67872, '\p{^	IS_Phoenician}', "");
Expect(1, 67872, '\P{	IS_Phoenician}', "");
Expect(0, 67872, '\P{^	IS_Phoenician}', "");
Error('\p{-:=PHNX}');
Error('\P{-:=PHNX}');
Expect(1, 67871, '\p{phnx}', "");
Expect(0, 67871, '\p{^phnx}', "");
Expect(0, 67871, '\P{phnx}', "");
Expect(1, 67871, '\P{^phnx}', "");
Expect(0, 67872, '\p{phnx}', "");
Expect(1, 67872, '\p{^phnx}', "");
Expect(1, 67872, '\P{phnx}', "");
Expect(0, 67872, '\P{^phnx}', "");
Expect(1, 67871, '\p{_	Phnx}', "");
Expect(0, 67871, '\p{^_	Phnx}', "");
Expect(0, 67871, '\P{_	Phnx}', "");
Expect(1, 67871, '\P{^_	Phnx}', "");
Expect(0, 67872, '\p{_	Phnx}', "");
Expect(1, 67872, '\p{^_	Phnx}', "");
Expect(1, 67872, '\P{_	Phnx}', "");
Expect(0, 67872, '\P{^_	Phnx}', "");
Error('\p{/a/	is_Phnx}');
Error('\P{/a/	is_Phnx}');
Expect(1, 67871, '\p{isphnx}', "");
Expect(0, 67871, '\p{^isphnx}', "");
Expect(0, 67871, '\P{isphnx}', "");
Expect(1, 67871, '\P{^isphnx}', "");
Expect(0, 67872, '\p{isphnx}', "");
Expect(1, 67872, '\p{^isphnx}', "");
Expect(1, 67872, '\P{isphnx}', "");
Expect(0, 67872, '\P{^isphnx}', "");
Expect(1, 67871, '\p{	Is_Phnx}', "");
Expect(0, 67871, '\p{^	Is_Phnx}', "");
Expect(0, 67871, '\P{	Is_Phnx}', "");
Expect(1, 67871, '\P{^	Is_Phnx}', "");
Expect(0, 67872, '\p{	Is_Phnx}', "");
Expect(1, 67872, '\p{^	Is_Phnx}', "");
Expect(1, 67872, '\P{	Is_Phnx}', "");
Expect(0, 67872, '\P{^	Is_Phnx}', "");
Error('\p{	/a/PHONETIC_Extensions}');
Error('\P{	/a/PHONETIC_Extensions}');
Expect(1, 7551, '\p{phoneticextensions}', "");
Expect(0, 7551, '\p{^phoneticextensions}', "");
Expect(0, 7551, '\P{phoneticextensions}', "");
Expect(1, 7551, '\P{^phoneticextensions}', "");
Expect(0, 7552, '\p{phoneticextensions}', "");
Expect(1, 7552, '\p{^phoneticextensions}', "");
Expect(1, 7552, '\P{phoneticextensions}', "");
Expect(0, 7552, '\P{^phoneticextensions}', "");
Expect(1, 7551, '\p{ _PHONETIC_Extensions}', "");
Expect(0, 7551, '\p{^ _PHONETIC_Extensions}', "");
Expect(0, 7551, '\P{ _PHONETIC_Extensions}', "");
Expect(1, 7551, '\P{^ _PHONETIC_Extensions}', "");
Expect(0, 7552, '\p{ _PHONETIC_Extensions}', "");
Expect(1, 7552, '\p{^ _PHONETIC_Extensions}', "");
Expect(1, 7552, '\P{ _PHONETIC_Extensions}', "");
Expect(0, 7552, '\P{^ _PHONETIC_Extensions}', "");
Error('\p{:=	_IS_Phonetic_Extensions}');
Error('\P{:=	_IS_Phonetic_Extensions}');
Expect(1, 7551, '\p{isphoneticextensions}', "");
Expect(0, 7551, '\p{^isphoneticextensions}', "");
Expect(0, 7551, '\P{isphoneticextensions}', "");
Expect(1, 7551, '\P{^isphoneticextensions}', "");
Expect(0, 7552, '\p{isphoneticextensions}', "");
Expect(1, 7552, '\p{^isphoneticextensions}', "");
Expect(1, 7552, '\P{isphoneticextensions}', "");
Expect(0, 7552, '\P{^isphoneticextensions}', "");
Expect(1, 7551, '\p{_-Is_phonetic_Extensions}', "");
Expect(0, 7551, '\p{^_-Is_phonetic_Extensions}', "");
Expect(0, 7551, '\P{_-Is_phonetic_Extensions}', "");
Expect(1, 7551, '\P{^_-Is_phonetic_Extensions}', "");
Expect(0, 7552, '\p{_-Is_phonetic_Extensions}', "");
Expect(1, 7552, '\p{^_-Is_phonetic_Extensions}', "");
Expect(1, 7552, '\P{_-Is_phonetic_Extensions}', "");
Expect(0, 7552, '\P{^_-Is_phonetic_Extensions}', "");
Error('\p{	/a/In_Phonetic_Extensions}');
Error('\P{	/a/In_Phonetic_Extensions}');
Expect(1, 7551, '\p{inphoneticextensions}', "");
Expect(0, 7551, '\p{^inphoneticextensions}', "");
Expect(0, 7551, '\P{inphoneticextensions}', "");
Expect(1, 7551, '\P{^inphoneticextensions}', "");
Expect(0, 7552, '\p{inphoneticextensions}', "");
Expect(1, 7552, '\p{^inphoneticextensions}', "");
Expect(1, 7552, '\P{inphoneticextensions}', "");
Expect(0, 7552, '\P{^inphoneticextensions}', "");
Expect(1, 7551, '\p{- In_Phonetic_Extensions}', "");
Expect(0, 7551, '\p{^- In_Phonetic_Extensions}', "");
Expect(0, 7551, '\P{- In_Phonetic_Extensions}', "");
Expect(1, 7551, '\P{^- In_Phonetic_Extensions}', "");
Expect(0, 7552, '\p{- In_Phonetic_Extensions}', "");
Expect(1, 7552, '\p{^- In_Phonetic_Extensions}', "");
Expect(1, 7552, '\P{- In_Phonetic_Extensions}', "");
Expect(0, 7552, '\P{^- In_Phonetic_Extensions}', "");
Error('\p{ /a/phonetic_ext}');
Error('\P{ /a/phonetic_ext}');
Expect(1, 7551, '\p{phoneticext}', "");
Expect(0, 7551, '\p{^phoneticext}', "");
Expect(0, 7551, '\P{phoneticext}', "");
Expect(1, 7551, '\P{^phoneticext}', "");
Expect(0, 7552, '\p{phoneticext}', "");
Expect(1, 7552, '\p{^phoneticext}', "");
Expect(1, 7552, '\P{phoneticext}', "");
Expect(0, 7552, '\P{^phoneticext}', "");
Expect(1, 7551, '\p{PHONETIC_EXT}', "");
Expect(0, 7551, '\p{^PHONETIC_EXT}', "");
Expect(0, 7551, '\P{PHONETIC_EXT}', "");
Expect(1, 7551, '\P{^PHONETIC_EXT}', "");
Expect(0, 7552, '\p{PHONETIC_EXT}', "");
Expect(1, 7552, '\p{^PHONETIC_EXT}', "");
Expect(1, 7552, '\P{PHONETIC_EXT}', "");
Expect(0, 7552, '\P{^PHONETIC_EXT}', "");
Error('\p{-Is_Phonetic_Ext/a/}');
Error('\P{-Is_Phonetic_Ext/a/}');
Expect(1, 7551, '\p{isphoneticext}', "");
Expect(0, 7551, '\p{^isphoneticext}', "");
Expect(0, 7551, '\P{isphoneticext}', "");
Expect(1, 7551, '\P{^isphoneticext}', "");
Expect(0, 7552, '\p{isphoneticext}', "");
Expect(1, 7552, '\p{^isphoneticext}', "");
Expect(1, 7552, '\P{isphoneticext}', "");
Expect(0, 7552, '\P{^isphoneticext}', "");
Expect(1, 7551, '\p{ 	IS_Phonetic_Ext}', "");
Expect(0, 7551, '\p{^ 	IS_Phonetic_Ext}', "");
Expect(0, 7551, '\P{ 	IS_Phonetic_Ext}', "");
Expect(1, 7551, '\P{^ 	IS_Phonetic_Ext}', "");
Expect(0, 7552, '\p{ 	IS_Phonetic_Ext}', "");
Expect(1, 7552, '\p{^ 	IS_Phonetic_Ext}', "");
Expect(1, 7552, '\P{ 	IS_Phonetic_Ext}', "");
Expect(0, 7552, '\P{^ 	IS_Phonetic_Ext}', "");
Error('\p{/a/  In_Phonetic_ext}');
Error('\P{/a/  In_Phonetic_ext}');
Expect(1, 7551, '\p{inphoneticext}', "");
Expect(0, 7551, '\p{^inphoneticext}', "");
Expect(0, 7551, '\P{inphoneticext}', "");
Expect(1, 7551, '\P{^inphoneticext}', "");
Expect(0, 7552, '\p{inphoneticext}', "");
Expect(1, 7552, '\p{^inphoneticext}', "");
Expect(1, 7552, '\P{inphoneticext}', "");
Expect(0, 7552, '\P{^inphoneticext}', "");
Expect(1, 7551, '\p{	In_phonetic_Ext}', "");
Expect(0, 7551, '\p{^	In_phonetic_Ext}', "");
Expect(0, 7551, '\P{	In_phonetic_Ext}', "");
Expect(1, 7551, '\P{^	In_phonetic_Ext}', "");
Expect(0, 7552, '\p{	In_phonetic_Ext}', "");
Expect(1, 7552, '\p{^	In_phonetic_Ext}', "");
Expect(1, 7552, '\P{	In_phonetic_Ext}', "");
Expect(0, 7552, '\P{^	In_phonetic_Ext}', "");
Error('\p{/a/_Phonetic_Extensions_Supplement}');
Error('\P{/a/_Phonetic_Extensions_Supplement}');
Expect(1, 7615, '\p{phoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^phoneticextensionssupplement}', "");
Expect(0, 7615, '\P{phoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^phoneticextensionssupplement}', "");
Expect(0, 7616, '\p{phoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^phoneticextensionssupplement}', "");
Expect(1, 7616, '\P{phoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^phoneticextensionssupplement}', "");
Expect(1, 7615, '\p{--phonetic_Extensions_Supplement}', "");
Expect(0, 7615, '\p{^--phonetic_Extensions_Supplement}', "");
Expect(0, 7615, '\P{--phonetic_Extensions_Supplement}', "");
Expect(1, 7615, '\P{^--phonetic_Extensions_Supplement}', "");
Expect(0, 7616, '\p{--phonetic_Extensions_Supplement}', "");
Expect(1, 7616, '\p{^--phonetic_Extensions_Supplement}', "");
Expect(1, 7616, '\P{--phonetic_Extensions_Supplement}', "");
Expect(0, 7616, '\P{^--phonetic_Extensions_Supplement}', "");
Error('\p{	 is_PHONETIC_Extensions_supplement/a/}');
Error('\P{	 is_PHONETIC_Extensions_supplement/a/}');
Expect(1, 7615, '\p{isphoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^isphoneticextensionssupplement}', "");
Expect(0, 7615, '\P{isphoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^isphoneticextensionssupplement}', "");
Expect(0, 7616, '\p{isphoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^isphoneticextensionssupplement}', "");
Expect(1, 7616, '\P{isphoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^isphoneticextensionssupplement}', "");
Expect(1, 7615, '\p{is_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7615, '\p{^is_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7615, '\P{is_PHONETIC_Extensions_Supplement}', "");
Expect(1, 7615, '\P{^is_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7616, '\p{is_PHONETIC_Extensions_Supplement}', "");
Expect(1, 7616, '\p{^is_PHONETIC_Extensions_Supplement}', "");
Expect(1, 7616, '\P{is_PHONETIC_Extensions_Supplement}', "");
Expect(0, 7616, '\P{^is_PHONETIC_Extensions_Supplement}', "");
Error('\p{ In_Phonetic_EXTENSIONS_SUPPLEMENT:=}');
Error('\P{ In_Phonetic_EXTENSIONS_SUPPLEMENT:=}');
Expect(1, 7615, '\p{inphoneticextensionssupplement}', "");
Expect(0, 7615, '\p{^inphoneticextensionssupplement}', "");
Expect(0, 7615, '\P{inphoneticextensionssupplement}', "");
Expect(1, 7615, '\P{^inphoneticextensionssupplement}', "");
Expect(0, 7616, '\p{inphoneticextensionssupplement}', "");
Expect(1, 7616, '\p{^inphoneticextensionssupplement}', "");
Expect(1, 7616, '\P{inphoneticextensionssupplement}', "");
Expect(0, 7616, '\P{^inphoneticextensionssupplement}', "");
Expect(1, 7615, '\p{_ in_phonetic_Extensions_supplement}', "");
Expect(0, 7615, '\p{^_ in_phonetic_Extensions_supplement}', "");
Expect(0, 7615, '\P{_ in_phonetic_Extensions_supplement}', "");
Expect(1, 7615, '\P{^_ in_phonetic_Extensions_supplement}', "");
Expect(0, 7616, '\p{_ in_phonetic_Extensions_supplement}', "");
Expect(1, 7616, '\p{^_ in_phonetic_Extensions_supplement}', "");
Expect(1, 7616, '\P{_ in_phonetic_Extensions_supplement}', "");
Expect(0, 7616, '\P{^_ in_phonetic_Extensions_supplement}', "");
Error('\p{	 Phonetic_ext_Sup:=}');
Error('\P{	 Phonetic_ext_Sup:=}');
Expect(1, 7615, '\p{phoneticextsup}', "");
Expect(0, 7615, '\p{^phoneticextsup}', "");
Expect(0, 7615, '\P{phoneticextsup}', "");
Expect(1, 7615, '\P{^phoneticextsup}', "");
Expect(0, 7616, '\p{phoneticextsup}', "");
Expect(1, 7616, '\p{^phoneticextsup}', "");
Expect(1, 7616, '\P{phoneticextsup}', "");
Expect(0, 7616, '\P{^phoneticextsup}', "");
Expect(1, 7615, '\p{ phonetic_Ext_Sup}', "");
Expect(0, 7615, '\p{^ phonetic_Ext_Sup}', "");
Expect(0, 7615, '\P{ phonetic_Ext_Sup}', "");
Expect(1, 7615, '\P{^ phonetic_Ext_Sup}', "");
Expect(0, 7616, '\p{ phonetic_Ext_Sup}', "");
Expect(1, 7616, '\p{^ phonetic_Ext_Sup}', "");
Expect(1, 7616, '\P{ phonetic_Ext_Sup}', "");
Expect(0, 7616, '\P{^ phonetic_Ext_Sup}', "");
Error('\p{/a/_	Is_phonetic_ext_sup}');
Error('\P{/a/_	Is_phonetic_ext_sup}');
Expect(1, 7615, '\p{isphoneticextsup}', "");
Expect(0, 7615, '\p{^isphoneticextsup}', "");
Expect(0, 7615, '\P{isphoneticextsup}', "");
Expect(1, 7615, '\P{^isphoneticextsup}', "");
Expect(0, 7616, '\p{isphoneticextsup}', "");
Expect(1, 7616, '\p{^isphoneticextsup}', "");
Expect(1, 7616, '\P{isphoneticextsup}', "");
Expect(0, 7616, '\P{^isphoneticextsup}', "");
Expect(1, 7615, '\p{	Is_PHONETIC_Ext_SUP}', "");
Expect(0, 7615, '\p{^	Is_PHONETIC_Ext_SUP}', "");
Expect(0, 7615, '\P{	Is_PHONETIC_Ext_SUP}', "");
Expect(1, 7615, '\P{^	Is_PHONETIC_Ext_SUP}', "");
Expect(0, 7616, '\p{	Is_PHONETIC_Ext_SUP}', "");
Expect(1, 7616, '\p{^	Is_PHONETIC_Ext_SUP}', "");
Expect(1, 7616, '\P{	Is_PHONETIC_Ext_SUP}', "");
Expect(0, 7616, '\P{^	Is_PHONETIC_Ext_SUP}', "");
Error('\p{ :=In_Phonetic_Ext_Sup}');
Error('\P{ :=In_Phonetic_Ext_Sup}');
Expect(1, 7615, '\p{inphoneticextsup}', "");
Expect(0, 7615, '\p{^inphoneticextsup}', "");
Expect(0, 7615, '\P{inphoneticextsup}', "");
Expect(1, 7615, '\P{^inphoneticextsup}', "");
Expect(0, 7616, '\p{inphoneticextsup}', "");
Expect(1, 7616, '\p{^inphoneticextsup}', "");
Expect(1, 7616, '\P{inphoneticextsup}', "");
Expect(0, 7616, '\P{^inphoneticextsup}', "");
Expect(1, 7615, '\p{ _In_PHONETIC_ext_SUP}', "");
Expect(0, 7615, '\p{^ _In_PHONETIC_ext_SUP}', "");
Expect(0, 7615, '\P{ _In_PHONETIC_ext_SUP}', "");
Expect(1, 7615, '\P{^ _In_PHONETIC_ext_SUP}', "");
Expect(0, 7616, '\p{ _In_PHONETIC_ext_SUP}', "");
Expect(1, 7616, '\p{^ _In_PHONETIC_ext_SUP}', "");
Expect(1, 7616, '\P{ _In_PHONETIC_ext_SUP}', "");
Expect(0, 7616, '\P{^ _In_PHONETIC_ext_SUP}', "");
Error('\p{:=	_Playing_cards}');
Error('\P{:=	_Playing_cards}');
Expect(1, 127231, '\p{playingcards}', "");
Expect(0, 127231, '\p{^playingcards}', "");
Expect(0, 127231, '\P{playingcards}', "");
Expect(1, 127231, '\P{^playingcards}', "");
Expect(0, 127232, '\p{playingcards}', "");
Expect(1, 127232, '\p{^playingcards}', "");
Expect(1, 127232, '\P{playingcards}', "");
Expect(0, 127232, '\P{^playingcards}', "");
Expect(1, 127231, '\p{_-PLAYING_Cards}', "");
Expect(0, 127231, '\p{^_-PLAYING_Cards}', "");
Expect(0, 127231, '\P{_-PLAYING_Cards}', "");
Expect(1, 127231, '\P{^_-PLAYING_Cards}', "");
Expect(0, 127232, '\p{_-PLAYING_Cards}', "");
Expect(1, 127232, '\p{^_-PLAYING_Cards}', "");
Expect(1, 127232, '\P{_-PLAYING_Cards}', "");
Expect(0, 127232, '\P{^_-PLAYING_Cards}', "");
Error('\p{:=--Is_playing_Cards}');
Error('\P{:=--Is_playing_Cards}');
Expect(1, 127231, '\p{isplayingcards}', "");
Expect(0, 127231, '\p{^isplayingcards}', "");
Expect(0, 127231, '\P{isplayingcards}', "");
Expect(1, 127231, '\P{^isplayingcards}', "");
Expect(0, 127232, '\p{isplayingcards}', "");
Expect(1, 127232, '\p{^isplayingcards}', "");
Expect(1, 127232, '\P{isplayingcards}', "");
Expect(0, 127232, '\P{^isplayingcards}', "");
Expect(1, 127231, '\p{ is_playing_Cards}', "");
Expect(0, 127231, '\p{^ is_playing_Cards}', "");
Expect(0, 127231, '\P{ is_playing_Cards}', "");
Expect(1, 127231, '\P{^ is_playing_Cards}', "");
Expect(0, 127232, '\p{ is_playing_Cards}', "");
Expect(1, 127232, '\p{^ is_playing_Cards}', "");
Expect(1, 127232, '\P{ is_playing_Cards}', "");
Expect(0, 127232, '\P{^ is_playing_Cards}', "");
Error('\p{/a/-_In_Playing_Cards}');
Error('\P{/a/-_In_Playing_Cards}');
Expect(1, 127231, '\p{inplayingcards}', "");
Expect(0, 127231, '\p{^inplayingcards}', "");
Expect(0, 127231, '\P{inplayingcards}', "");
Expect(1, 127231, '\P{^inplayingcards}', "");
Expect(0, 127232, '\p{inplayingcards}', "");
Expect(1, 127232, '\p{^inplayingcards}', "");
Expect(1, 127232, '\P{inplayingcards}', "");
Expect(0, 127232, '\P{^inplayingcards}', "");
Expect(1, 127231, '\p{-In_playing_cards}', "");
Expect(0, 127231, '\p{^-In_playing_cards}', "");
Expect(0, 127231, '\P{-In_playing_cards}', "");
Expect(1, 127231, '\P{^-In_playing_cards}', "");
Expect(0, 127232, '\p{-In_playing_cards}', "");
Expect(1, 127232, '\p{^-In_playing_cards}', "");
Expect(1, 127232, '\P{-In_playing_cards}', "");
Expect(0, 127232, '\P{^-In_playing_cards}', "");
Error('\p{:=_posixalnum}');
Error('\P{:=_posixalnum}');
Expect(1, 122, '\p{posixalnum}', "");
Expect(0, 122, '\p{^posixalnum}', "");
Expect(0, 122, '\P{posixalnum}', "");
Expect(1, 122, '\P{^posixalnum}', "");
Expect(0, 123, '\p{posixalnum}', "");
Expect(1, 123, '\p{^posixalnum}', "");
Expect(1, 123, '\P{posixalnum}', "");
Expect(0, 123, '\P{^posixalnum}', "");
Expect(1, 122, '\p{	 posixalnum}', "");
Expect(0, 122, '\p{^	 posixalnum}', "");
Expect(0, 122, '\P{	 posixalnum}', "");
Expect(1, 122, '\P{^	 posixalnum}', "");
Expect(0, 123, '\p{	 posixalnum}', "");
Expect(1, 123, '\p{^	 posixalnum}', "");
Expect(1, 123, '\P{	 posixalnum}', "");
Expect(0, 123, '\P{^	 posixalnum}', "");
Error('\p{/a/  is_PosixAlnum}');
Error('\P{/a/  is_PosixAlnum}');
Expect(1, 122, '\p{isposixalnum}', "");
Expect(0, 122, '\p{^isposixalnum}', "");
Expect(0, 122, '\P{isposixalnum}', "");
Expect(1, 122, '\P{^isposixalnum}', "");
Expect(0, 123, '\p{isposixalnum}', "");
Expect(1, 123, '\p{^isposixalnum}', "");
Expect(1, 123, '\P{isposixalnum}', "");
Expect(0, 123, '\P{^isposixalnum}', "");
Expect(1, 122, '\p{_-IS_POSIXALNUM}', "");
Expect(0, 122, '\p{^_-IS_POSIXALNUM}', "");
Expect(0, 122, '\P{_-IS_POSIXALNUM}', "");
Expect(1, 122, '\P{^_-IS_POSIXALNUM}', "");
Expect(0, 123, '\p{_-IS_POSIXALNUM}', "");
Expect(1, 123, '\p{^_-IS_POSIXALNUM}', "");
Expect(1, 123, '\P{_-IS_POSIXALNUM}', "");
Expect(0, 123, '\P{^_-IS_POSIXALNUM}', "");
Error('\p{_/a/POSIXALPHA}');
Error('\P{_/a/POSIXALPHA}');
Expect(1, 122, '\p{posixalpha}', "");
Expect(0, 122, '\p{^posixalpha}', "");
Expect(0, 122, '\P{posixalpha}', "");
Expect(1, 122, '\P{^posixalpha}', "");
Expect(0, 123, '\p{posixalpha}', "");
Expect(1, 123, '\p{^posixalpha}', "");
Expect(1, 123, '\P{posixalpha}', "");
Expect(0, 123, '\P{^posixalpha}', "");
Expect(1, 122, '\p{POSIXALPHA}', "");
Expect(0, 122, '\p{^POSIXALPHA}', "");
Expect(0, 122, '\P{POSIXALPHA}', "");
Expect(1, 122, '\P{^POSIXALPHA}', "");
Expect(0, 123, '\p{POSIXALPHA}', "");
Expect(1, 123, '\p{^POSIXALPHA}', "");
Expect(1, 123, '\P{POSIXALPHA}', "");
Expect(0, 123, '\P{^POSIXALPHA}', "");
Error('\p{_:=IS_PosixAlpha}');
Error('\P{_:=IS_PosixAlpha}');
Expect(1, 122, '\p{isposixalpha}', "");
Expect(0, 122, '\p{^isposixalpha}', "");
Expect(0, 122, '\P{isposixalpha}', "");
Expect(1, 122, '\P{^isposixalpha}', "");
Expect(0, 123, '\p{isposixalpha}', "");
Expect(1, 123, '\p{^isposixalpha}', "");
Expect(1, 123, '\P{isposixalpha}', "");
Expect(0, 123, '\P{^isposixalpha}', "");
Expect(1, 122, '\p{	Is_PosixAlpha}', "");
Expect(0, 122, '\p{^	Is_PosixAlpha}', "");
Expect(0, 122, '\P{	Is_PosixAlpha}', "");
Expect(1, 122, '\P{^	Is_PosixAlpha}', "");
Expect(0, 123, '\p{	Is_PosixAlpha}', "");
Expect(1, 123, '\p{^	Is_PosixAlpha}', "");
Expect(1, 123, '\P{	Is_PosixAlpha}', "");
Expect(0, 123, '\P{^	Is_PosixAlpha}', "");
Error('\p{		POSIXBLANK:=}');
Error('\P{		POSIXBLANK:=}');
Expect(1, 32, '\p{posixblank}', "");
Expect(0, 32, '\p{^posixblank}', "");
Expect(0, 32, '\P{posixblank}', "");
Expect(1, 32, '\P{^posixblank}', "");
Expect(0, 33, '\p{posixblank}', "");
Expect(1, 33, '\p{^posixblank}', "");
Expect(1, 33, '\P{posixblank}', "");
Expect(0, 33, '\P{^posixblank}', "");
Expect(1, 32, '\p{_	PosixBlank}', "");
Expect(0, 32, '\p{^_	PosixBlank}', "");
Expect(0, 32, '\P{_	PosixBlank}', "");
Expect(1, 32, '\P{^_	PosixBlank}', "");
Expect(0, 33, '\p{_	PosixBlank}', "");
Expect(1, 33, '\p{^_	PosixBlank}', "");
Expect(1, 33, '\P{_	PosixBlank}', "");
Expect(0, 33, '\P{^_	PosixBlank}', "");
Error('\p{ /a/IS_PosixBlank}');
Error('\P{ /a/IS_PosixBlank}');
Expect(1, 32, '\p{isposixblank}', "");
Expect(0, 32, '\p{^isposixblank}', "");
Expect(0, 32, '\P{isposixblank}', "");
Expect(1, 32, '\P{^isposixblank}', "");
Expect(0, 33, '\p{isposixblank}', "");
Expect(1, 33, '\p{^isposixblank}', "");
Expect(1, 33, '\P{isposixblank}', "");
Expect(0, 33, '\P{^isposixblank}', "");
Expect(1, 32, '\p{- Is_POSIXBLANK}', "");
Expect(0, 32, '\p{^- Is_POSIXBLANK}', "");
Expect(0, 32, '\P{- Is_POSIXBLANK}', "");
Expect(1, 32, '\P{^- Is_POSIXBLANK}', "");
Expect(0, 33, '\p{- Is_POSIXBLANK}', "");
Expect(1, 33, '\p{^- Is_POSIXBLANK}', "");
Expect(1, 33, '\P{- Is_POSIXBLANK}', "");
Expect(0, 33, '\P{^- Is_POSIXBLANK}', "");
Error('\p{-:=PosixCntrl}');
Error('\P{-:=PosixCntrl}');
Expect(1, 127, '\p{posixcntrl}', "");
Expect(0, 127, '\p{^posixcntrl}', "");
Expect(0, 127, '\P{posixcntrl}', "");
Expect(1, 127, '\P{^posixcntrl}', "");
Expect(0, 128, '\p{posixcntrl}', "");
Expect(1, 128, '\p{^posixcntrl}', "");
Expect(1, 128, '\P{posixcntrl}', "");
Expect(0, 128, '\P{^posixcntrl}', "");
Expect(1, 127, '\p{	_PosixCntrl}', "");
Expect(0, 127, '\p{^	_PosixCntrl}', "");
Expect(0, 127, '\P{	_PosixCntrl}', "");
Expect(1, 127, '\P{^	_PosixCntrl}', "");
Expect(0, 128, '\p{	_PosixCntrl}', "");
Expect(1, 128, '\p{^	_PosixCntrl}', "");
Expect(1, 128, '\P{	_PosixCntrl}', "");
Expect(0, 128, '\P{^	_PosixCntrl}', "");
Error('\p{/a/--IS_PosixCntrl}');
Error('\P{/a/--IS_PosixCntrl}');
Expect(1, 127, '\p{isposixcntrl}', "");
Expect(0, 127, '\p{^isposixcntrl}', "");
Expect(0, 127, '\P{isposixcntrl}', "");
Expect(1, 127, '\P{^isposixcntrl}', "");
Expect(0, 128, '\p{isposixcntrl}', "");
Expect(1, 128, '\p{^isposixcntrl}', "");
Expect(1, 128, '\P{isposixcntrl}', "");
Expect(0, 128, '\P{^isposixcntrl}', "");
Expect(1, 127, '\p{ 	Is_posixcntrl}', "");
Expect(0, 127, '\p{^ 	Is_posixcntrl}', "");
Expect(0, 127, '\P{ 	Is_posixcntrl}', "");
Expect(1, 127, '\P{^ 	Is_posixcntrl}', "");
Expect(0, 128, '\p{ 	Is_posixcntrl}', "");
Expect(1, 128, '\p{^ 	Is_posixcntrl}', "");
Expect(1, 128, '\P{ 	Is_posixcntrl}', "");
Expect(0, 128, '\P{^ 	Is_posixcntrl}', "");
Error('\p{:=-_posixdigit}');
Error('\P{:=-_posixdigit}');
Expect(1, 57, '\p{posixdigit}', "");
Expect(0, 57, '\p{^posixdigit}', "");
Expect(0, 57, '\P{posixdigit}', "");
Expect(1, 57, '\P{^posixdigit}', "");
Expect(0, 58, '\p{posixdigit}', "");
Expect(1, 58, '\p{^posixdigit}', "");
Expect(1, 58, '\P{posixdigit}', "");
Expect(0, 58, '\P{^posixdigit}', "");
Expect(1, 57, '\p{ PosixDigit}', "");
Expect(0, 57, '\p{^ PosixDigit}', "");
Expect(0, 57, '\P{ PosixDigit}', "");
Expect(1, 57, '\P{^ PosixDigit}', "");
Expect(0, 58, '\p{ PosixDigit}', "");
Expect(1, 58, '\p{^ PosixDigit}', "");
Expect(1, 58, '\P{ PosixDigit}', "");
Expect(0, 58, '\P{^ PosixDigit}', "");
Error('\p{_/a/Is_PosixDigit}');
Error('\P{_/a/Is_PosixDigit}');
Expect(1, 57, '\p{isposixdigit}', "");
Expect(0, 57, '\p{^isposixdigit}', "");
Expect(0, 57, '\P{isposixdigit}', "");
Expect(1, 57, '\P{^isposixdigit}', "");
Expect(0, 58, '\p{isposixdigit}', "");
Expect(1, 58, '\p{^isposixdigit}', "");
Expect(1, 58, '\P{isposixdigit}', "");
Expect(0, 58, '\P{^isposixdigit}', "");
Expect(1, 57, '\p{-Is_POSIXDIGIT}', "");
Expect(0, 57, '\p{^-Is_POSIXDIGIT}', "");
Expect(0, 57, '\P{-Is_POSIXDIGIT}', "");
Expect(1, 57, '\P{^-Is_POSIXDIGIT}', "");
Expect(0, 58, '\p{-Is_POSIXDIGIT}', "");
Expect(1, 58, '\p{^-Is_POSIXDIGIT}', "");
Expect(1, 58, '\P{-Is_POSIXDIGIT}', "");
Expect(0, 58, '\P{^-Is_POSIXDIGIT}', "");
Error('\p{/a/PosixGraph}');
Error('\P{/a/PosixGraph}');
Expect(1, 126, '\p{posixgraph}', "");
Expect(0, 126, '\p{^posixgraph}', "");
Expect(0, 126, '\P{posixgraph}', "");
Expect(1, 126, '\P{^posixgraph}', "");
Expect(0, 127, '\p{posixgraph}', "");
Expect(1, 127, '\p{^posixgraph}', "");
Expect(1, 127, '\P{posixgraph}', "");
Expect(0, 127, '\P{^posixgraph}', "");
Expect(1, 126, '\p{	PosixGraph}', "");
Expect(0, 126, '\p{^	PosixGraph}', "");
Expect(0, 126, '\P{	PosixGraph}', "");
Expect(1, 126, '\P{^	PosixGraph}', "");
Expect(0, 127, '\p{	PosixGraph}', "");
Expect(1, 127, '\p{^	PosixGraph}', "");
Expect(1, 127, '\P{	PosixGraph}', "");
Expect(0, 127, '\P{^	PosixGraph}', "");
Error('\p{_/a/Is_PosixGraph}');
Error('\P{_/a/Is_PosixGraph}');
Expect(1, 126, '\p{isposixgraph}', "");
Expect(0, 126, '\p{^isposixgraph}', "");
Expect(0, 126, '\P{isposixgraph}', "");
Expect(1, 126, '\P{^isposixgraph}', "");
Expect(0, 127, '\p{isposixgraph}', "");
Expect(1, 127, '\p{^isposixgraph}', "");
Expect(1, 127, '\P{isposixgraph}', "");
Expect(0, 127, '\P{^isposixgraph}', "");
Expect(1, 126, '\p{_Is_PosixGraph}', "");
Expect(0, 126, '\p{^_Is_PosixGraph}', "");
Expect(0, 126, '\P{_Is_PosixGraph}', "");
Expect(1, 126, '\P{^_Is_PosixGraph}', "");
Expect(0, 127, '\p{_Is_PosixGraph}', "");
Expect(1, 127, '\p{^_Is_PosixGraph}', "");
Expect(1, 127, '\P{_Is_PosixGraph}', "");
Expect(0, 127, '\P{^_Is_PosixGraph}', "");
Error('\p{ PosixLower/a/}');
Error('\P{ PosixLower/a/}');
Expect(1, 122, '\p{posixlower}', "");
Expect(0, 122, '\p{^posixlower}', "");
Expect(0, 122, '\P{posixlower}', "");
Expect(1, 122, '\P{^posixlower}', "");
Expect(0, 123, '\p{posixlower}', "");
Expect(1, 123, '\p{^posixlower}', "");
Expect(1, 123, '\P{posixlower}', "");
Expect(0, 123, '\P{^posixlower}', "");
Expect(1, 122, '\p{_POSIXLOWER}', "");
Expect(0, 122, '\p{^_POSIXLOWER}', "");
Expect(0, 122, '\P{_POSIXLOWER}', "");
Expect(1, 122, '\P{^_POSIXLOWER}', "");
Expect(0, 123, '\p{_POSIXLOWER}', "");
Expect(1, 123, '\p{^_POSIXLOWER}', "");
Expect(1, 123, '\P{_POSIXLOWER}', "");
Expect(0, 123, '\P{^_POSIXLOWER}', "");
Error('\p{		Is_posixlower/a/}');
Error('\P{		Is_posixlower/a/}');
Expect(1, 122, '\p{isposixlower}', "");
Expect(0, 122, '\p{^isposixlower}', "");
Expect(0, 122, '\P{isposixlower}', "");
Expect(1, 122, '\P{^isposixlower}', "");
Expect(0, 123, '\p{isposixlower}', "");
Expect(1, 123, '\p{^isposixlower}', "");
Expect(1, 123, '\P{isposixlower}', "");
Expect(0, 123, '\P{^isposixlower}', "");
Expect(1, 122, '\p{	-Is_posixlower}', "");
Expect(0, 122, '\p{^	-Is_posixlower}', "");
Expect(0, 122, '\P{	-Is_posixlower}', "");
Expect(1, 122, '\P{^	-Is_posixlower}', "");
Expect(0, 123, '\p{	-Is_posixlower}', "");
Expect(1, 123, '\p{^	-Is_posixlower}', "");
Expect(1, 123, '\P{	-Is_posixlower}', "");
Expect(0, 123, '\P{^	-Is_posixlower}', "");
Error('\p{/a/ POSIXPRINT}');
Error('\P{/a/ POSIXPRINT}');
Expect(1, 126, '\p{posixprint}', "");
Expect(0, 126, '\p{^posixprint}', "");
Expect(0, 126, '\P{posixprint}', "");
Expect(1, 126, '\P{^posixprint}', "");
Expect(0, 127, '\p{posixprint}', "");
Expect(1, 127, '\p{^posixprint}', "");
Expect(1, 127, '\P{posixprint}', "");
Expect(0, 127, '\P{^posixprint}', "");
Expect(1, 126, '\p{ PosixPrint}', "");
Expect(0, 126, '\p{^ PosixPrint}', "");
Expect(0, 126, '\P{ PosixPrint}', "");
Expect(1, 126, '\P{^ PosixPrint}', "");
Expect(0, 127, '\p{ PosixPrint}', "");
Expect(1, 127, '\p{^ PosixPrint}', "");
Expect(1, 127, '\P{ PosixPrint}', "");
Expect(0, 127, '\P{^ PosixPrint}', "");
Error('\p{IS_PosixPrint/a/}');
Error('\P{IS_PosixPrint/a/}');
Expect(1, 126, '\p{isposixprint}', "");
Expect(0, 126, '\p{^isposixprint}', "");
Expect(0, 126, '\P{isposixprint}', "");
Expect(1, 126, '\P{^isposixprint}', "");
Expect(0, 127, '\p{isposixprint}', "");
Expect(1, 127, '\p{^isposixprint}', "");
Expect(1, 127, '\P{isposixprint}', "");
Expect(0, 127, '\P{^isposixprint}', "");
Expect(1, 126, '\p{_Is_PosixPrint}', "");
Expect(0, 126, '\p{^_Is_PosixPrint}', "");
Expect(0, 126, '\P{_Is_PosixPrint}', "");
Expect(1, 126, '\P{^_Is_PosixPrint}', "");
Expect(0, 127, '\p{_Is_PosixPrint}', "");
Expect(1, 127, '\p{^_Is_PosixPrint}', "");
Expect(1, 127, '\P{_Is_PosixPrint}', "");
Expect(0, 127, '\P{^_Is_PosixPrint}', "");
Error('\p{ PosixPunct/a/}');
Error('\P{ PosixPunct/a/}');
Expect(1, 126, '\p{posixpunct}', "");
Expect(0, 126, '\p{^posixpunct}', "");
Expect(0, 126, '\P{posixpunct}', "");
Expect(1, 126, '\P{^posixpunct}', "");
Expect(0, 127, '\p{posixpunct}', "");
Expect(1, 127, '\p{^posixpunct}', "");
Expect(1, 127, '\P{posixpunct}', "");
Expect(0, 127, '\P{^posixpunct}', "");
Expect(1, 126, '\p{ POSIXPUNCT}', "");
Expect(0, 126, '\p{^ POSIXPUNCT}', "");
Expect(0, 126, '\P{ POSIXPUNCT}', "");
Expect(1, 126, '\P{^ POSIXPUNCT}', "");
Expect(0, 127, '\p{ POSIXPUNCT}', "");
Expect(1, 127, '\p{^ POSIXPUNCT}', "");
Expect(1, 127, '\P{ POSIXPUNCT}', "");
Expect(0, 127, '\P{^ POSIXPUNCT}', "");
Error('\p{/a/	Is_PosixPunct}');
Error('\P{/a/	Is_PosixPunct}');
Expect(1, 126, '\p{isposixpunct}', "");
Expect(0, 126, '\p{^isposixpunct}', "");
Expect(0, 126, '\P{isposixpunct}', "");
Expect(1, 126, '\P{^isposixpunct}', "");
Expect(0, 127, '\p{isposixpunct}', "");
Expect(1, 127, '\p{^isposixpunct}', "");
Expect(1, 127, '\P{isposixpunct}', "");
Expect(0, 127, '\P{^isposixpunct}', "");
Expect(1, 126, '\p{__is_POSIXPUNCT}', "");
Expect(0, 126, '\p{^__is_POSIXPUNCT}', "");
Expect(0, 126, '\P{__is_POSIXPUNCT}', "");
Expect(1, 126, '\P{^__is_POSIXPUNCT}', "");
Expect(0, 127, '\p{__is_POSIXPUNCT}', "");
Expect(1, 127, '\p{^__is_POSIXPUNCT}', "");
Expect(1, 127, '\P{__is_POSIXPUNCT}', "");
Expect(0, 127, '\P{^__is_POSIXPUNCT}', "");
Error('\p{	:=posixspace}');
Error('\P{	:=posixspace}');
Expect(1, 32, '\p{posixspace}', "");
Expect(0, 32, '\p{^posixspace}', "");
Expect(0, 32, '\P{posixspace}', "");
Expect(1, 32, '\P{^posixspace}', "");
Expect(0, 33, '\p{posixspace}', "");
Expect(1, 33, '\p{^posixspace}', "");
Expect(1, 33, '\P{posixspace}', "");
Expect(0, 33, '\P{^posixspace}', "");
Expect(1, 32, '\p{--POSIXSPACE}', "");
Expect(0, 32, '\p{^--POSIXSPACE}', "");
Expect(0, 32, '\P{--POSIXSPACE}', "");
Expect(1, 32, '\P{^--POSIXSPACE}', "");
Expect(0, 33, '\p{--POSIXSPACE}', "");
Expect(1, 33, '\p{^--POSIXSPACE}', "");
Expect(1, 33, '\P{--POSIXSPACE}', "");
Expect(0, 33, '\P{^--POSIXSPACE}', "");
Error('\p{-Is_POSIXSPACE:=}');
Error('\P{-Is_POSIXSPACE:=}');
Expect(1, 32, '\p{isposixspace}', "");
Expect(0, 32, '\p{^isposixspace}', "");
Expect(0, 32, '\P{isposixspace}', "");
Expect(1, 32, '\P{^isposixspace}', "");
Expect(0, 33, '\p{isposixspace}', "");
Expect(1, 33, '\p{^isposixspace}', "");
Expect(1, 33, '\P{isposixspace}', "");
Expect(0, 33, '\P{^isposixspace}', "");
Expect(1, 32, '\p{Is_POSIXSPACE}', "");
Expect(0, 32, '\p{^Is_POSIXSPACE}', "");
Expect(0, 32, '\P{Is_POSIXSPACE}', "");
Expect(1, 32, '\P{^Is_POSIXSPACE}', "");
Expect(0, 33, '\p{Is_POSIXSPACE}', "");
Expect(1, 33, '\p{^Is_POSIXSPACE}', "");
Expect(1, 33, '\P{Is_POSIXSPACE}', "");
Expect(0, 33, '\P{^Is_POSIXSPACE}', "");
Error('\p{/a/posixupper}');
Error('\P{/a/posixupper}');
Expect(1, 90, '\p{posixupper}', "");
Expect(0, 90, '\p{^posixupper}', "");
Expect(0, 90, '\P{posixupper}', "");
Expect(1, 90, '\P{^posixupper}', "");
Expect(0, 91, '\p{posixupper}', "");
Expect(1, 91, '\p{^posixupper}', "");
Expect(1, 91, '\P{posixupper}', "");
Expect(0, 91, '\P{^posixupper}', "");
Expect(1, 90, '\p{		PosixUpper}', "");
Expect(0, 90, '\p{^		PosixUpper}', "");
Expect(0, 90, '\P{		PosixUpper}', "");
Expect(1, 90, '\P{^		PosixUpper}', "");
Expect(0, 91, '\p{		PosixUpper}', "");
Expect(1, 91, '\p{^		PosixUpper}', "");
Expect(1, 91, '\P{		PosixUpper}', "");
Expect(0, 91, '\P{^		PosixUpper}', "");
Error('\p{/a/Is_posixupper}');
Error('\P{/a/Is_posixupper}');
Expect(1, 90, '\p{isposixupper}', "");
Expect(0, 90, '\p{^isposixupper}', "");
Expect(0, 90, '\P{isposixupper}', "");
Expect(1, 90, '\P{^isposixupper}', "");
Expect(0, 91, '\p{isposixupper}', "");
Expect(1, 91, '\p{^isposixupper}', "");
Expect(1, 91, '\P{isposixupper}', "");
Expect(0, 91, '\P{^isposixupper}', "");
Expect(1, 90, '\p{ 	is_POSIXUPPER}', "");
Expect(0, 90, '\p{^ 	is_POSIXUPPER}', "");
Expect(0, 90, '\P{ 	is_POSIXUPPER}', "");
Expect(1, 90, '\P{^ 	is_POSIXUPPER}', "");
Expect(0, 91, '\p{ 	is_POSIXUPPER}', "");
Expect(1, 91, '\p{^ 	is_POSIXUPPER}', "");
Expect(1, 91, '\P{ 	is_POSIXUPPER}', "");
Expect(0, 91, '\P{^ 	is_POSIXUPPER}', "");
Error('\p{:=_ PosixXDigit}');
Error('\P{:=_ PosixXDigit}');
Expect(1, 102, '\p{posixxdigit}', "");
Expect(0, 102, '\p{^posixxdigit}', "");
Expect(0, 102, '\P{posixxdigit}', "");
Expect(1, 102, '\P{^posixxdigit}', "");
Expect(0, 103, '\p{posixxdigit}', "");
Expect(1, 103, '\p{^posixxdigit}', "");
Expect(1, 103, '\P{posixxdigit}', "");
Expect(0, 103, '\P{^posixxdigit}', "");
Expect(1, 102, '\p{	PosixXDigit}', "");
Expect(0, 102, '\p{^	PosixXDigit}', "");
Expect(0, 102, '\P{	PosixXDigit}', "");
Expect(1, 102, '\P{^	PosixXDigit}', "");
Expect(0, 103, '\p{	PosixXDigit}', "");
Expect(1, 103, '\p{^	PosixXDigit}', "");
Expect(1, 103, '\P{	PosixXDigit}', "");
Expect(0, 103, '\P{^	PosixXDigit}', "");
Error('\p{-is_PosixXDigit:=}');
Error('\P{-is_PosixXDigit:=}');
Expect(1, 102, '\p{isposixxdigit}', "");
Expect(0, 102, '\p{^isposixxdigit}', "");
Expect(0, 102, '\P{isposixxdigit}', "");
Expect(1, 102, '\P{^isposixxdigit}', "");
Expect(0, 103, '\p{isposixxdigit}', "");
Expect(1, 103, '\p{^isposixxdigit}', "");
Expect(1, 103, '\P{isposixxdigit}', "");
Expect(0, 103, '\P{^isposixxdigit}', "");
Expect(1, 102, '\p{__is_PosixXDigit}', "");
Expect(0, 102, '\p{^__is_PosixXDigit}', "");
Expect(0, 102, '\P{__is_PosixXDigit}', "");
Expect(1, 102, '\P{^__is_PosixXDigit}', "");
Expect(0, 103, '\p{__is_PosixXDigit}', "");
Expect(1, 103, '\p{^__is_PosixXDigit}', "");
Expect(1, 103, '\P{__is_PosixXDigit}', "");
Expect(0, 103, '\P{^__is_PosixXDigit}', "");
Error('\p{/a/-ASCII_hex_digit}');
Error('\P{/a/-ASCII_hex_digit}');
Expect(1, 102, '\p{asciihexdigit}', "");
Expect(0, 102, '\p{^asciihexdigit}', "");
Expect(0, 102, '\P{asciihexdigit}', "");
Expect(1, 102, '\P{^asciihexdigit}', "");
Expect(0, 103, '\p{asciihexdigit}', "");
Expect(1, 103, '\p{^asciihexdigit}', "");
Expect(1, 103, '\P{asciihexdigit}', "");
Expect(0, 103, '\P{^asciihexdigit}', "");
Expect(1, 102, '\p{  ASCII_Hex_DIGIT}', "");
Expect(0, 102, '\p{^  ASCII_Hex_DIGIT}', "");
Expect(0, 102, '\P{  ASCII_Hex_DIGIT}', "");
Expect(1, 102, '\P{^  ASCII_Hex_DIGIT}', "");
Expect(0, 103, '\p{  ASCII_Hex_DIGIT}', "");
Expect(1, 103, '\p{^  ASCII_Hex_DIGIT}', "");
Expect(1, 103, '\P{  ASCII_Hex_DIGIT}', "");
Expect(0, 103, '\P{^  ASCII_Hex_DIGIT}', "");
Error('\p{ is_ascii_HEX_Digit/a/}');
Error('\P{ is_ascii_HEX_Digit/a/}');
Expect(1, 102, '\p{isasciihexdigit}', "");
Expect(0, 102, '\p{^isasciihexdigit}', "");
Expect(0, 102, '\P{isasciihexdigit}', "");
Expect(1, 102, '\P{^isasciihexdigit}', "");
Expect(0, 103, '\p{isasciihexdigit}', "");
Expect(1, 103, '\p{^isasciihexdigit}', "");
Expect(1, 103, '\P{isasciihexdigit}', "");
Expect(0, 103, '\P{^isasciihexdigit}', "");
Expect(1, 102, '\p{-	Is_ASCII_Hex_Digit}', "");
Expect(0, 102, '\p{^-	Is_ASCII_Hex_Digit}', "");
Expect(0, 102, '\P{-	Is_ASCII_Hex_Digit}', "");
Expect(1, 102, '\P{^-	Is_ASCII_Hex_Digit}', "");
Expect(0, 103, '\p{-	Is_ASCII_Hex_Digit}', "");
Expect(1, 103, '\p{^-	Is_ASCII_Hex_Digit}', "");
Expect(1, 103, '\P{-	Is_ASCII_Hex_Digit}', "");
Expect(0, 103, '\P{^-	Is_ASCII_Hex_Digit}', "");
Error('\p{/a/_ahex}');
Error('\P{/a/_ahex}');
Expect(1, 102, '\p{ahex}', "");
Expect(0, 102, '\p{^ahex}', "");
Expect(0, 102, '\P{ahex}', "");
Expect(1, 102, '\P{^ahex}', "");
Expect(0, 103, '\p{ahex}', "");
Expect(1, 103, '\p{^ahex}', "");
Expect(1, 103, '\P{ahex}', "");
Expect(0, 103, '\P{^ahex}', "");
Expect(1, 102, '\p{ AHEX}', "");
Expect(0, 102, '\p{^ AHEX}', "");
Expect(0, 102, '\P{ AHEX}', "");
Expect(1, 102, '\P{^ AHEX}', "");
Expect(0, 103, '\p{ AHEX}', "");
Expect(1, 103, '\p{^ AHEX}', "");
Expect(1, 103, '\P{ AHEX}', "");
Expect(0, 103, '\P{^ AHEX}', "");
Error('\p{-/a/Is_ahex}');
Error('\P{-/a/Is_ahex}');
Expect(1, 102, '\p{isahex}', "");
Expect(0, 102, '\p{^isahex}', "");
Expect(0, 102, '\P{isahex}', "");
Expect(1, 102, '\P{^isahex}', "");
Expect(0, 103, '\p{isahex}', "");
Expect(1, 103, '\p{^isahex}', "");
Expect(1, 103, '\P{isahex}', "");
Expect(0, 103, '\P{^isahex}', "");
Expect(1, 102, '\p{  is_AHex}', "");
Expect(0, 102, '\p{^  is_AHex}', "");
Expect(0, 102, '\P{  is_AHex}', "");
Expect(1, 102, '\P{^  is_AHex}', "");
Expect(0, 103, '\p{  is_AHex}', "");
Expect(1, 103, '\p{^  is_AHex}', "");
Expect(1, 103, '\P{  is_AHex}', "");
Expect(0, 103, '\P{^  is_AHex}', "");
Error('\p{  Print:=}');
Error('\P{  Print:=}');
Expect(1, 1114109, '\p{print}', "");
Expect(0, 1114109, '\p{^print}', "");
Expect(0, 1114109, '\P{print}', "");
Expect(1, 1114109, '\P{^print}', "");
Expect(0, 918000, '\p{print}', "");
Expect(1, 918000, '\p{^print}', "");
Expect(1, 918000, '\P{print}', "");
Expect(0, 918000, '\P{^print}', "");
Expect(1, 1114109, '\p{_Print}', "");
Expect(0, 1114109, '\p{^_Print}', "");
Expect(0, 1114109, '\P{_Print}', "");
Expect(1, 1114109, '\P{^_Print}', "");
Expect(0, 918000, '\p{_Print}', "");
Expect(1, 918000, '\p{^_Print}', "");
Expect(1, 918000, '\P{_Print}', "");
Expect(0, 918000, '\P{^_Print}', "");
Error('\p{_/a/xposixprint}');
Error('\P{_/a/xposixprint}');
Expect(1, 1114109, '\p{xposixprint}', "");
Expect(0, 1114109, '\p{^xposixprint}', "");
Expect(0, 1114109, '\P{xposixprint}', "");
Expect(1, 1114109, '\P{^xposixprint}', "");
Expect(0, 918000, '\p{xposixprint}', "");
Expect(1, 918000, '\p{^xposixprint}', "");
Expect(1, 918000, '\P{xposixprint}', "");
Expect(0, 918000, '\P{^xposixprint}', "");
Expect(1, 1114109, '\p{	-XPosixPrint}', "");
Expect(0, 1114109, '\p{^	-XPosixPrint}', "");
Expect(0, 1114109, '\P{	-XPosixPrint}', "");
Expect(1, 1114109, '\P{^	-XPosixPrint}', "");
Expect(0, 918000, '\p{	-XPosixPrint}', "");
Expect(1, 918000, '\p{^	-XPosixPrint}', "");
Expect(1, 918000, '\P{	-XPosixPrint}', "");
Expect(0, 918000, '\P{^	-XPosixPrint}', "");
Error('\p{_Is_Print:=}');
Error('\P{_Is_Print:=}');
Expect(1, 1114109, '\p{isprint}', "");
Expect(0, 1114109, '\p{^isprint}', "");
Expect(0, 1114109, '\P{isprint}', "");
Expect(1, 1114109, '\P{^isprint}', "");
Expect(0, 918000, '\p{isprint}', "");
Expect(1, 918000, '\p{^isprint}', "");
Expect(1, 918000, '\P{isprint}', "");
Expect(0, 918000, '\P{^isprint}', "");
Expect(1, 1114109, '\p{--Is_Print}', "");
Expect(0, 1114109, '\p{^--Is_Print}', "");
Expect(0, 1114109, '\P{--Is_Print}', "");
Expect(1, 1114109, '\P{^--Is_Print}', "");
Expect(0, 918000, '\p{--Is_Print}', "");
Expect(1, 918000, '\p{^--Is_Print}', "");
Expect(1, 918000, '\P{--Is_Print}', "");
Expect(0, 918000, '\P{^--Is_Print}', "");
Error('\p{:= -is_XPOSIXPRINT}');
Error('\P{:= -is_XPOSIXPRINT}');
Expect(1, 1114109, '\p{isxposixprint}', "");
Expect(0, 1114109, '\p{^isxposixprint}', "");
Expect(0, 1114109, '\P{isxposixprint}', "");
Expect(1, 1114109, '\P{^isxposixprint}', "");
Expect(0, 918000, '\p{isxposixprint}', "");
Expect(1, 918000, '\p{^isxposixprint}', "");
Expect(1, 918000, '\P{isxposixprint}', "");
Expect(0, 918000, '\P{^isxposixprint}', "");
Expect(1, 1114109, '\p{-	Is_XPOSIXPRINT}', "");
Expect(0, 1114109, '\p{^-	Is_XPOSIXPRINT}', "");
Expect(0, 1114109, '\P{-	Is_XPOSIXPRINT}', "");
Expect(1, 1114109, '\P{^-	Is_XPOSIXPRINT}', "");
Expect(0, 918000, '\p{-	Is_XPOSIXPRINT}', "");
Expect(1, 918000, '\p{^-	Is_XPOSIXPRINT}', "");
Expect(1, 918000, '\P{-	Is_XPOSIXPRINT}', "");
Expect(0, 918000, '\P{^-	Is_XPOSIXPRINT}', "");
Error('\p{/a/ -private_Use}');
Error('\P{/a/ -private_Use}');
Expect(1, 1114109, '\p{privateuse}', "");
Expect(0, 1114109, '\p{^privateuse}', "");
Expect(0, 1114109, '\P{privateuse}', "");
Expect(1, 1114109, '\P{^privateuse}', "");
Expect(0, 63744, '\p{privateuse}', "");
Expect(1, 63744, '\p{^privateuse}', "");
Expect(1, 63744, '\P{privateuse}', "");
Expect(0, 63744, '\P{^privateuse}', "");
Expect(1, 1114109, '\p{ _PRIVATE_Use}', "");
Expect(0, 1114109, '\p{^ _PRIVATE_Use}', "");
Expect(0, 1114109, '\P{ _PRIVATE_Use}', "");
Expect(1, 1114109, '\P{^ _PRIVATE_Use}', "");
Expect(0, 63744, '\p{ _PRIVATE_Use}', "");
Expect(1, 63744, '\p{^ _PRIVATE_Use}', "");
Expect(1, 63744, '\P{ _PRIVATE_Use}', "");
Expect(0, 63744, '\P{^ _PRIVATE_Use}', "");
Error('\p{/a/_	IS_PRIVATE_Use}');
Error('\P{/a/_	IS_PRIVATE_Use}');
Expect(1, 1114109, '\p{isprivateuse}', "");
Expect(0, 1114109, '\p{^isprivateuse}', "");
Expect(0, 1114109, '\P{isprivateuse}', "");
Expect(1, 1114109, '\P{^isprivateuse}', "");
Expect(0, 63744, '\p{isprivateuse}', "");
Expect(1, 63744, '\p{^isprivateuse}', "");
Expect(1, 63744, '\P{isprivateuse}', "");
Expect(0, 63744, '\P{^isprivateuse}', "");
Expect(1, 1114109, '\p{-	IS_private_use}', "");
Expect(0, 1114109, '\p{^-	IS_private_use}', "");
Expect(0, 1114109, '\P{-	IS_private_use}', "");
Expect(1, 1114109, '\P{^-	IS_private_use}', "");
Expect(0, 63744, '\p{-	IS_private_use}', "");
Expect(1, 63744, '\p{^-	IS_private_use}', "");
Expect(1, 63744, '\P{-	IS_private_use}', "");
Expect(0, 63744, '\P{^-	IS_private_use}', "");
Error('\p{/a/_ Co}');
Error('\P{/a/_ Co}');
Expect(1, 1114109, '\p{co}', "");
Expect(0, 1114109, '\p{^co}', "");
Expect(0, 1114109, '\P{co}', "");
Expect(1, 1114109, '\P{^co}', "");
Expect(0, 63744, '\p{co}', "");
Expect(1, 63744, '\p{^co}', "");
Expect(1, 63744, '\P{co}', "");
Expect(0, 63744, '\P{^co}', "");
Expect(1, 1114109, '\p{_CO}', "");
Expect(0, 1114109, '\p{^_CO}', "");
Expect(0, 1114109, '\P{_CO}', "");
Expect(1, 1114109, '\P{^_CO}', "");
Expect(0, 63744, '\p{_CO}', "");
Expect(1, 63744, '\p{^_CO}', "");
Expect(1, 63744, '\P{_CO}', "");
Expect(0, 63744, '\P{^_CO}', "");
Error('\p{/a/Is_Co}');
Error('\P{/a/Is_Co}');
Expect(1, 1114109, '\p{isco}', "");
Expect(0, 1114109, '\p{^isco}', "");
Expect(0, 1114109, '\P{isco}', "");
Expect(1, 1114109, '\P{^isco}', "");
Expect(0, 63744, '\p{isco}', "");
Expect(1, 63744, '\p{^isco}', "");
Expect(1, 63744, '\P{isco}', "");
Expect(0, 63744, '\P{^isco}', "");
Expect(1, 1114109, '\p{_	IS_co}', "");
Expect(0, 1114109, '\p{^_	IS_co}', "");
Expect(0, 1114109, '\P{_	IS_co}', "");
Expect(1, 1114109, '\P{^_	IS_co}', "");
Expect(0, 63744, '\p{_	IS_co}', "");
Expect(1, 63744, '\p{^_	IS_co}', "");
Expect(1, 63744, '\P{_	IS_co}', "");
Expect(0, 63744, '\P{^_	IS_co}', "");
Error('\p{_	Private_use_area:=}');
Error('\P{_	Private_use_area:=}');
Expect(1, 63743, '\p{privateusearea}', "");
Expect(0, 63743, '\p{^privateusearea}', "");
Expect(0, 63743, '\P{privateusearea}', "");
Expect(1, 63743, '\P{^privateusearea}', "");
Expect(0, 63744, '\p{privateusearea}', "");
Expect(1, 63744, '\p{^privateusearea}', "");
Expect(1, 63744, '\P{privateusearea}', "");
Expect(0, 63744, '\P{^privateusearea}', "");
Expect(1, 63743, '\p{_PRIVATE_USE_Area}', "");
Expect(0, 63743, '\p{^_PRIVATE_USE_Area}', "");
Expect(0, 63743, '\P{_PRIVATE_USE_Area}', "");
Expect(1, 63743, '\P{^_PRIVATE_USE_Area}', "");
Expect(0, 63744, '\p{_PRIVATE_USE_Area}', "");
Expect(1, 63744, '\p{^_PRIVATE_USE_Area}', "");
Expect(1, 63744, '\P{_PRIVATE_USE_Area}', "");
Expect(0, 63744, '\P{^_PRIVATE_USE_Area}', "");
Error('\p{/a/ Is_PRIVATE_use_area}');
Error('\P{/a/ Is_PRIVATE_use_area}');
Expect(1, 63743, '\p{isprivateusearea}', "");
Expect(0, 63743, '\p{^isprivateusearea}', "");
Expect(0, 63743, '\P{isprivateusearea}', "");
Expect(1, 63743, '\P{^isprivateusearea}', "");
Expect(0, 63744, '\p{isprivateusearea}', "");
Expect(1, 63744, '\p{^isprivateusearea}', "");
Expect(1, 63744, '\P{isprivateusearea}', "");
Expect(0, 63744, '\P{^isprivateusearea}', "");
Expect(1, 63743, '\p{ is_PRIVATE_Use_Area}', "");
Expect(0, 63743, '\p{^ is_PRIVATE_Use_Area}', "");
Expect(0, 63743, '\P{ is_PRIVATE_Use_Area}', "");
Expect(1, 63743, '\P{^ is_PRIVATE_Use_Area}', "");
Expect(0, 63744, '\p{ is_PRIVATE_Use_Area}', "");
Expect(1, 63744, '\p{^ is_PRIVATE_Use_Area}', "");
Expect(1, 63744, '\P{ is_PRIVATE_Use_Area}', "");
Expect(0, 63744, '\P{^ is_PRIVATE_Use_Area}', "");
Error('\p{--IN_private_use_area:=}');
Error('\P{--IN_private_use_area:=}');
Expect(1, 63743, '\p{inprivateusearea}', "");
Expect(0, 63743, '\p{^inprivateusearea}', "");
Expect(0, 63743, '\P{inprivateusearea}', "");
Expect(1, 63743, '\P{^inprivateusearea}', "");
Expect(0, 63744, '\p{inprivateusearea}', "");
Expect(1, 63744, '\p{^inprivateusearea}', "");
Expect(1, 63744, '\P{inprivateusearea}', "");
Expect(0, 63744, '\P{^inprivateusearea}', "");
Expect(1, 63743, '\p{ _In_PRIVATE_Use_area}', "");
Expect(0, 63743, '\p{^ _In_PRIVATE_Use_area}', "");
Expect(0, 63743, '\P{ _In_PRIVATE_Use_area}', "");
Expect(1, 63743, '\P{^ _In_PRIVATE_Use_area}', "");
Expect(0, 63744, '\p{ _In_PRIVATE_Use_area}', "");
Expect(1, 63744, '\p{^ _In_PRIVATE_Use_area}', "");
Expect(1, 63744, '\P{ _In_PRIVATE_Use_area}', "");
Expect(0, 63744, '\P{^ _In_PRIVATE_Use_area}', "");
Error('\p{	PUA:=}');
Error('\P{	PUA:=}');
Expect(1, 63743, '\p{pua}', "");
Expect(0, 63743, '\p{^pua}', "");
Expect(0, 63743, '\P{pua}', "");
Expect(1, 63743, '\P{^pua}', "");
Expect(0, 63744, '\p{pua}', "");
Expect(1, 63744, '\p{^pua}', "");
Expect(1, 63744, '\P{pua}', "");
Expect(0, 63744, '\P{^pua}', "");
Expect(1, 63743, '\p{_	pua}', "");
Expect(0, 63743, '\p{^_	pua}', "");
Expect(0, 63743, '\P{_	pua}', "");
Expect(1, 63743, '\P{^_	pua}', "");
Expect(0, 63744, '\p{_	pua}', "");
Expect(1, 63744, '\p{^_	pua}', "");
Expect(1, 63744, '\P{_	pua}', "");
Expect(0, 63744, '\P{^_	pua}', "");
Error('\p{/a/	 Is_PUA}');
Error('\P{/a/	 Is_PUA}');
Expect(1, 63743, '\p{ispua}', "");
Expect(0, 63743, '\p{^ispua}', "");
Expect(0, 63743, '\P{ispua}', "");
Expect(1, 63743, '\P{^ispua}', "");
Expect(0, 63744, '\p{ispua}', "");
Expect(1, 63744, '\p{^ispua}', "");
Expect(1, 63744, '\P{ispua}', "");
Expect(0, 63744, '\P{^ispua}', "");
Expect(1, 63743, '\p{is_PUA}', "");
Expect(0, 63743, '\p{^is_PUA}', "");
Expect(0, 63743, '\P{is_PUA}', "");
Expect(1, 63743, '\P{^is_PUA}', "");
Expect(0, 63744, '\p{is_PUA}', "");
Expect(1, 63744, '\p{^is_PUA}', "");
Expect(1, 63744, '\P{is_PUA}', "");
Expect(0, 63744, '\P{^is_PUA}', "");
Error('\p{:=_IN_PUA}');
Error('\P{:=_IN_PUA}');
Expect(1, 63743, '\p{inpua}', "");
Expect(0, 63743, '\p{^inpua}', "");
Expect(0, 63743, '\P{inpua}', "");
Expect(1, 63743, '\P{^inpua}', "");
Expect(0, 63744, '\p{inpua}', "");
Expect(1, 63744, '\p{^inpua}', "");
Expect(1, 63744, '\P{inpua}', "");
Expect(0, 63744, '\P{^inpua}', "");
Expect(1, 63743, '\p{_in_pua}', "");
Expect(0, 63743, '\p{^_in_pua}', "");
Expect(0, 63743, '\P{_in_pua}', "");
Expect(1, 63743, '\P{^_in_pua}', "");
Expect(0, 63744, '\p{_in_pua}', "");
Expect(1, 63744, '\p{^_in_pua}', "");
Expect(1, 63744, '\P{_in_pua}', "");
Expect(0, 63744, '\P{^_in_pua}', "");
Error('\p{/a/	-IN_private_Use}');
Error('\P{/a/	-IN_private_Use}');
Expect(1, 63743, '\p{inprivateuse}', "");
Expect(0, 63743, '\p{^inprivateuse}', "");
Expect(0, 63743, '\P{inprivateuse}', "");
Expect(1, 63743, '\P{^inprivateuse}', "");
Expect(0, 63744, '\p{inprivateuse}', "");
Expect(1, 63744, '\p{^inprivateuse}', "");
Expect(1, 63744, '\P{inprivateuse}', "");
Expect(0, 63744, '\P{^inprivateuse}', "");
Expect(1, 63743, '\p{	IN_Private_Use}', "");
Expect(0, 63743, '\p{^	IN_Private_Use}', "");
Expect(0, 63743, '\P{	IN_Private_Use}', "");
Expect(1, 63743, '\P{^	IN_Private_Use}', "");
Expect(0, 63744, '\p{	IN_Private_Use}', "");
Expect(1, 63744, '\p{^	IN_Private_Use}', "");
Expect(1, 63744, '\P{	IN_Private_Use}', "");
Expect(0, 63744, '\P{^	IN_Private_Use}', "");
Error('\p{/a/ -punct}');
Error('\P{/a/ -punct}');
Expect(1, 74867, '\p{punct}', "");
Expect(0, 74867, '\p{^punct}', "");
Expect(0, 74867, '\P{punct}', "");
Expect(1, 74867, '\P{^punct}', "");
Expect(0, 74868, '\p{punct}', "");
Expect(1, 74868, '\p{^punct}', "");
Expect(1, 74868, '\P{punct}', "");
Expect(0, 74868, '\P{^punct}', "");
Expect(1, 74867, '\p{_ PUNCT}', "");
Expect(0, 74867, '\p{^_ PUNCT}', "");
Expect(0, 74867, '\P{_ PUNCT}', "");
Expect(1, 74867, '\P{^_ PUNCT}', "");
Expect(0, 74868, '\p{_ PUNCT}', "");
Expect(1, 74868, '\p{^_ PUNCT}', "");
Expect(1, 74868, '\P{_ PUNCT}', "");
Expect(0, 74868, '\P{^_ PUNCT}', "");
Error('\p{:=	_Is_Punct}');
Error('\P{:=	_Is_Punct}');
Expect(1, 74867, '\p{ispunct}', "");
Expect(0, 74867, '\p{^ispunct}', "");
Expect(0, 74867, '\P{ispunct}', "");
Expect(1, 74867, '\P{^ispunct}', "");
Expect(0, 74868, '\p{ispunct}', "");
Expect(1, 74868, '\p{^ispunct}', "");
Expect(1, 74868, '\P{ispunct}', "");
Expect(0, 74868, '\P{^ispunct}', "");
Expect(1, 74867, '\p{-_Is_punct}', "");
Expect(0, 74867, '\p{^-_Is_punct}', "");
Expect(0, 74867, '\P{-_Is_punct}', "");
Expect(1, 74867, '\P{^-_Is_punct}', "");
Expect(0, 74868, '\p{-_Is_punct}', "");
Expect(1, 74868, '\p{^-_Is_punct}', "");
Expect(1, 74868, '\P{-_Is_punct}', "");
Expect(0, 74868, '\P{^-_Is_punct}', "");
Error('\p{-PUNCTUATION:=}');
Error('\P{-PUNCTUATION:=}');
Expect(1, 74867, '\p{punctuation}', "");
Expect(0, 74867, '\p{^punctuation}', "");
Expect(0, 74867, '\P{punctuation}', "");
Expect(1, 74867, '\P{^punctuation}', "");
Expect(0, 74868, '\p{punctuation}', "");
Expect(1, 74868, '\p{^punctuation}', "");
Expect(1, 74868, '\P{punctuation}', "");
Expect(0, 74868, '\P{^punctuation}', "");
Expect(1, 74867, '\p{_	Punctuation}', "");
Expect(0, 74867, '\p{^_	Punctuation}', "");
Expect(0, 74867, '\P{_	Punctuation}', "");
Expect(1, 74867, '\P{^_	Punctuation}', "");
Expect(0, 74868, '\p{_	Punctuation}', "");
Expect(1, 74868, '\p{^_	Punctuation}', "");
Expect(1, 74868, '\P{_	Punctuation}', "");
Expect(0, 74868, '\P{^_	Punctuation}', "");
Error('\p{:= 	IS_PUNCTUATION}');
Error('\P{:= 	IS_PUNCTUATION}');
Expect(1, 74867, '\p{ispunctuation}', "");
Expect(0, 74867, '\p{^ispunctuation}', "");
Expect(0, 74867, '\P{ispunctuation}', "");
Expect(1, 74867, '\P{^ispunctuation}', "");
Expect(0, 74868, '\p{ispunctuation}', "");
Expect(1, 74868, '\p{^ispunctuation}', "");
Expect(1, 74868, '\P{ispunctuation}', "");
Expect(0, 74868, '\P{^ispunctuation}', "");
Expect(1, 74867, '\p{	_IS_punctuation}', "");
Expect(0, 74867, '\p{^	_IS_punctuation}', "");
Expect(0, 74867, '\P{	_IS_punctuation}', "");
Expect(1, 74867, '\P{^	_IS_punctuation}', "");
Expect(0, 74868, '\p{	_IS_punctuation}', "");
Expect(1, 74868, '\p{^	_IS_punctuation}', "");
Expect(1, 74868, '\P{	_IS_punctuation}', "");
Expect(0, 74868, '\P{^	_IS_punctuation}', "");
Error('\p{/a/  P}');
Error('\P{/a/  P}');
Expect(1, 74867, '\p{p}', "");
Expect(0, 74867, '\p{^p}', "");
Expect(0, 74867, '\P{p}', "");
Expect(1, 74867, '\P{^p}', "");
Expect(0, 74868, '\p{p}', "");
Expect(1, 74868, '\p{^p}', "");
Expect(1, 74868, '\P{p}', "");
Expect(0, 74868, '\P{^p}', "");
Expect(1, 74867, '\p{	p}', "");
Expect(0, 74867, '\p{^	p}', "");
Expect(0, 74867, '\P{	p}', "");
Expect(1, 74867, '\P{^	p}', "");
Expect(0, 74868, '\p{	p}', "");
Expect(1, 74868, '\p{^	p}', "");
Expect(1, 74868, '\P{	p}', "");
Expect(0, 74868, '\P{^	p}', "");
Error('\p{_IS_P:=}');
Error('\P{_IS_P:=}');
Expect(1, 74867, '\p{isp}', "");
Expect(0, 74867, '\p{^isp}', "");
Expect(0, 74867, '\P{isp}', "");
Expect(1, 74867, '\P{^isp}', "");
Expect(0, 74868, '\p{isp}', "");
Expect(1, 74868, '\p{^isp}', "");
Expect(1, 74868, '\P{isp}', "");
Expect(0, 74868, '\P{^isp}', "");
Expect(1, 74867, '\p{-_IS_p}', "");
Expect(0, 74867, '\p{^-_IS_p}', "");
Expect(0, 74867, '\P{-_IS_p}', "");
Expect(1, 74867, '\P{^-_IS_p}', "");
Expect(0, 74868, '\p{-_IS_p}', "");
Expect(1, 74868, '\p{^-_IS_p}', "");
Expect(1, 74868, '\P{-_IS_p}', "");
Expect(0, 74868, '\P{^-_IS_p}', "");
Error('\p{:= _Quotation_MARK}');
Error('\P{:= _Quotation_MARK}');
Expect(1, 65379, '\p{quotationmark}', "");
Expect(0, 65379, '\p{^quotationmark}', "");
Expect(0, 65379, '\P{quotationmark}', "");
Expect(1, 65379, '\P{^quotationmark}', "");
Expect(0, 65380, '\p{quotationmark}', "");
Expect(1, 65380, '\p{^quotationmark}', "");
Expect(1, 65380, '\P{quotationmark}', "");
Expect(0, 65380, '\P{^quotationmark}', "");
Expect(1, 65379, '\p{- quotation_Mark}', "");
Expect(0, 65379, '\p{^- quotation_Mark}', "");
Expect(0, 65379, '\P{- quotation_Mark}', "");
Expect(1, 65379, '\P{^- quotation_Mark}', "");
Expect(0, 65380, '\p{- quotation_Mark}', "");
Expect(1, 65380, '\p{^- quotation_Mark}', "");
Expect(1, 65380, '\P{- quotation_Mark}', "");
Expect(0, 65380, '\P{^- quotation_Mark}', "");
Error('\p{-IS_Quotation_mark:=}');
Error('\P{-IS_Quotation_mark:=}');
Expect(1, 65379, '\p{isquotationmark}', "");
Expect(0, 65379, '\p{^isquotationmark}', "");
Expect(0, 65379, '\P{isquotationmark}', "");
Expect(1, 65379, '\P{^isquotationmark}', "");
Expect(0, 65380, '\p{isquotationmark}', "");
Expect(1, 65380, '\p{^isquotationmark}', "");
Expect(1, 65380, '\P{isquotationmark}', "");
Expect(0, 65380, '\P{^isquotationmark}', "");
Expect(1, 65379, '\p{ 	Is_Quotation_mark}', "");
Expect(0, 65379, '\p{^ 	Is_Quotation_mark}', "");
Expect(0, 65379, '\P{ 	Is_Quotation_mark}', "");
Expect(1, 65379, '\P{^ 	Is_Quotation_mark}', "");
Expect(0, 65380, '\p{ 	Is_Quotation_mark}', "");
Expect(1, 65380, '\p{^ 	Is_Quotation_mark}', "");
Expect(1, 65380, '\P{ 	Is_Quotation_mark}', "");
Expect(0, 65380, '\P{^ 	Is_Quotation_mark}', "");
Error('\p{/a/	-QMARK}');
Error('\P{/a/	-QMARK}');
Expect(1, 65379, '\p{qmark}', "");
Expect(0, 65379, '\p{^qmark}', "");
Expect(0, 65379, '\P{qmark}', "");
Expect(1, 65379, '\P{^qmark}', "");
Expect(0, 65380, '\p{qmark}', "");
Expect(1, 65380, '\p{^qmark}', "");
Expect(1, 65380, '\P{qmark}', "");
Expect(0, 65380, '\P{^qmark}', "");
Expect(1, 65379, '\p{ _QMARK}', "");
Expect(0, 65379, '\p{^ _QMARK}', "");
Expect(0, 65379, '\P{ _QMARK}', "");
Expect(1, 65379, '\P{^ _QMARK}', "");
Expect(0, 65380, '\p{ _QMARK}', "");
Expect(1, 65380, '\p{^ _QMARK}', "");
Expect(1, 65380, '\P{ _QMARK}', "");
Expect(0, 65380, '\P{^ _QMARK}', "");
Error('\p{/a/__Is_QMark}');
Error('\P{/a/__Is_QMark}');
Expect(1, 65379, '\p{isqmark}', "");
Expect(0, 65379, '\p{^isqmark}', "");
Expect(0, 65379, '\P{isqmark}', "");
Expect(1, 65379, '\P{^isqmark}', "");
Expect(0, 65380, '\p{isqmark}', "");
Expect(1, 65380, '\p{^isqmark}', "");
Expect(1, 65380, '\P{isqmark}', "");
Expect(0, 65380, '\P{^isqmark}', "");
Expect(1, 65379, '\p{	 IS_QMark}', "");
Expect(0, 65379, '\p{^	 IS_QMark}', "");
Expect(0, 65379, '\P{	 IS_QMark}', "");
Expect(1, 65379, '\P{^	 IS_QMark}', "");
Expect(0, 65380, '\p{	 IS_QMark}', "");
Expect(1, 65380, '\p{^	 IS_QMark}', "");
Expect(1, 65380, '\P{	 IS_QMark}', "");
Expect(0, 65380, '\P{^	 IS_QMark}', "");
Error('\p{/a/RADICAL}');
Error('\P{/a/RADICAL}');
Expect(1, 12245, '\p{radical}', "");
Expect(0, 12245, '\p{^radical}', "");
Expect(0, 12245, '\P{radical}', "");
Expect(1, 12245, '\P{^radical}', "");
Expect(0, 12246, '\p{radical}', "");
Expect(1, 12246, '\p{^radical}', "");
Expect(1, 12246, '\P{radical}', "");
Expect(0, 12246, '\P{^radical}', "");
Expect(1, 12245, '\p{ RADICAL}', "");
Expect(0, 12245, '\p{^ RADICAL}', "");
Expect(0, 12245, '\P{ RADICAL}', "");
Expect(1, 12245, '\P{^ RADICAL}', "");
Expect(0, 12246, '\p{ RADICAL}', "");
Expect(1, 12246, '\p{^ RADICAL}', "");
Expect(1, 12246, '\P{ RADICAL}', "");
Expect(0, 12246, '\P{^ RADICAL}', "");
Error('\p{	:=IS_RADICAL}');
Error('\P{	:=IS_RADICAL}');
Expect(1, 12245, '\p{isradical}', "");
Expect(0, 12245, '\p{^isradical}', "");
Expect(0, 12245, '\P{isradical}', "");
Expect(1, 12245, '\P{^isradical}', "");
Expect(0, 12246, '\p{isradical}', "");
Expect(1, 12246, '\p{^isradical}', "");
Expect(1, 12246, '\P{isradical}', "");
Expect(0, 12246, '\P{^isradical}', "");
Expect(1, 12245, '\p{_Is_Radical}', "");
Expect(0, 12245, '\p{^_Is_Radical}', "");
Expect(0, 12245, '\P{_Is_Radical}', "");
Expect(1, 12245, '\P{^_Is_Radical}', "");
Expect(0, 12246, '\p{_Is_Radical}', "");
Expect(1, 12246, '\p{^_Is_Radical}', "");
Expect(1, 12246, '\P{_Is_Radical}', "");
Expect(0, 12246, '\P{^_Is_Radical}', "");
Error('\p{-:=Rejang}');
Error('\P{-:=Rejang}');
Expect(1, 43359, '\p{rejang}', "");
Expect(0, 43359, '\p{^rejang}', "");
Expect(0, 43359, '\P{rejang}', "");
Expect(1, 43359, '\P{^rejang}', "");
Expect(0, 43360, '\p{rejang}', "");
Expect(1, 43360, '\p{^rejang}', "");
Expect(1, 43360, '\P{rejang}', "");
Expect(0, 43360, '\P{^rejang}', "");
Expect(1, 43359, '\p{	REJANG}', "");
Expect(0, 43359, '\p{^	REJANG}', "");
Expect(0, 43359, '\P{	REJANG}', "");
Expect(1, 43359, '\P{^	REJANG}', "");
Expect(0, 43360, '\p{	REJANG}', "");
Expect(1, 43360, '\p{^	REJANG}', "");
Expect(1, 43360, '\P{	REJANG}', "");
Expect(0, 43360, '\P{^	REJANG}', "");
Error('\p{/a/ _Is_rejang}');
Error('\P{/a/ _Is_rejang}');
Expect(1, 43359, '\p{isrejang}', "");
Expect(0, 43359, '\p{^isrejang}', "");
Expect(0, 43359, '\P{isrejang}', "");
Expect(1, 43359, '\P{^isrejang}', "");
Expect(0, 43360, '\p{isrejang}', "");
Expect(1, 43360, '\p{^isrejang}', "");
Expect(1, 43360, '\P{isrejang}', "");
Expect(0, 43360, '\P{^isrejang}', "");
Expect(1, 43359, '\p{	IS_Rejang}', "");
Expect(0, 43359, '\p{^	IS_Rejang}', "");
Expect(0, 43359, '\P{	IS_Rejang}', "");
Expect(1, 43359, '\P{^	IS_Rejang}', "");
Expect(0, 43360, '\p{	IS_Rejang}', "");
Expect(1, 43360, '\p{^	IS_Rejang}', "");
Expect(1, 43360, '\P{	IS_Rejang}', "");
Expect(0, 43360, '\P{^	IS_Rejang}', "");
Error('\p{/a/Rjng}');
Error('\P{/a/Rjng}');
Expect(1, 43359, '\p{rjng}', "");
Expect(0, 43359, '\p{^rjng}', "");
Expect(0, 43359, '\P{rjng}', "");
Expect(1, 43359, '\P{^rjng}', "");
Expect(0, 43360, '\p{rjng}', "");
Expect(1, 43360, '\p{^rjng}', "");
Expect(1, 43360, '\P{rjng}', "");
Expect(0, 43360, '\P{^rjng}', "");
Expect(1, 43359, '\p{_	Rjng}', "");
Expect(0, 43359, '\p{^_	Rjng}', "");
Expect(0, 43359, '\P{_	Rjng}', "");
Expect(1, 43359, '\P{^_	Rjng}', "");
Expect(0, 43360, '\p{_	Rjng}', "");
Expect(1, 43360, '\p{^_	Rjng}', "");
Expect(1, 43360, '\P{_	Rjng}', "");
Expect(0, 43360, '\P{^_	Rjng}', "");
Error('\p{-Is_Rjng/a/}');
Error('\P{-Is_Rjng/a/}');
Expect(1, 43359, '\p{isrjng}', "");
Expect(0, 43359, '\p{^isrjng}', "");
Expect(0, 43359, '\P{isrjng}', "");
Expect(1, 43359, '\P{^isrjng}', "");
Expect(0, 43360, '\p{isrjng}', "");
Expect(1, 43360, '\p{^isrjng}', "");
Expect(1, 43360, '\P{isrjng}', "");
Expect(0, 43360, '\P{^isrjng}', "");
Expect(1, 43359, '\p{	 Is_Rjng}', "");
Expect(0, 43359, '\p{^	 Is_Rjng}', "");
Expect(0, 43359, '\P{	 Is_Rjng}', "");
Expect(1, 43359, '\P{^	 Is_Rjng}', "");
Expect(0, 43360, '\p{	 Is_Rjng}', "");
Expect(1, 43360, '\p{^	 Is_Rjng}', "");
Expect(1, 43360, '\P{	 Is_Rjng}', "");
Expect(0, 43360, '\P{^	 Is_Rjng}', "");
Error('\p{- RUMI_NUMERAL_SYMBOLS:=}');
Error('\P{- RUMI_NUMERAL_SYMBOLS:=}');
Expect(1, 69247, '\p{ruminumeralsymbols}', "");
Expect(0, 69247, '\p{^ruminumeralsymbols}', "");
Expect(0, 69247, '\P{ruminumeralsymbols}', "");
Expect(1, 69247, '\P{^ruminumeralsymbols}', "");
Expect(0, 69248, '\p{ruminumeralsymbols}', "");
Expect(1, 69248, '\p{^ruminumeralsymbols}', "");
Expect(1, 69248, '\P{ruminumeralsymbols}', "");
Expect(0, 69248, '\P{^ruminumeralsymbols}', "");
Expect(1, 69247, '\p{	RUMI_numeral_Symbols}', "");
Expect(0, 69247, '\p{^	RUMI_numeral_Symbols}', "");
Expect(0, 69247, '\P{	RUMI_numeral_Symbols}', "");
Expect(1, 69247, '\P{^	RUMI_numeral_Symbols}', "");
Expect(0, 69248, '\p{	RUMI_numeral_Symbols}', "");
Expect(1, 69248, '\p{^	RUMI_numeral_Symbols}', "");
Expect(1, 69248, '\P{	RUMI_numeral_Symbols}', "");
Expect(0, 69248, '\P{^	RUMI_numeral_Symbols}', "");
Error('\p{	Is_rumi_NUMERAL_Symbols:=}');
Error('\P{	Is_rumi_NUMERAL_Symbols:=}');
Expect(1, 69247, '\p{isruminumeralsymbols}', "");
Expect(0, 69247, '\p{^isruminumeralsymbols}', "");
Expect(0, 69247, '\P{isruminumeralsymbols}', "");
Expect(1, 69247, '\P{^isruminumeralsymbols}', "");
Expect(0, 69248, '\p{isruminumeralsymbols}', "");
Expect(1, 69248, '\p{^isruminumeralsymbols}', "");
Expect(1, 69248, '\P{isruminumeralsymbols}', "");
Expect(0, 69248, '\P{^isruminumeralsymbols}', "");
Expect(1, 69247, '\p{- IS_Rumi_numeral_Symbols}', "");
Expect(0, 69247, '\p{^- IS_Rumi_numeral_Symbols}', "");
Expect(0, 69247, '\P{- IS_Rumi_numeral_Symbols}', "");
Expect(1, 69247, '\P{^- IS_Rumi_numeral_Symbols}', "");
Expect(0, 69248, '\p{- IS_Rumi_numeral_Symbols}', "");
Expect(1, 69248, '\p{^- IS_Rumi_numeral_Symbols}', "");
Expect(1, 69248, '\P{- IS_Rumi_numeral_Symbols}', "");
Expect(0, 69248, '\P{^- IS_Rumi_numeral_Symbols}', "");
Error('\p{ in_Rumi_NUMERAL_Symbols/a/}');
Error('\P{ in_Rumi_NUMERAL_Symbols/a/}');
Expect(1, 69247, '\p{inruminumeralsymbols}', "");
Expect(0, 69247, '\p{^inruminumeralsymbols}', "");
Expect(0, 69247, '\P{inruminumeralsymbols}', "");
Expect(1, 69247, '\P{^inruminumeralsymbols}', "");
Expect(0, 69248, '\p{inruminumeralsymbols}', "");
Expect(1, 69248, '\p{^inruminumeralsymbols}', "");
Expect(1, 69248, '\P{inruminumeralsymbols}', "");
Expect(0, 69248, '\P{^inruminumeralsymbols}', "");
Expect(1, 69247, '\p{_ In_Rumi_NUMERAL_symbols}', "");
Expect(0, 69247, '\p{^_ In_Rumi_NUMERAL_symbols}', "");
Expect(0, 69247, '\P{_ In_Rumi_NUMERAL_symbols}', "");
Expect(1, 69247, '\P{^_ In_Rumi_NUMERAL_symbols}', "");
Expect(0, 69248, '\p{_ In_Rumi_NUMERAL_symbols}', "");
Expect(1, 69248, '\p{^_ In_Rumi_NUMERAL_symbols}', "");
Expect(1, 69248, '\P{_ In_Rumi_NUMERAL_symbols}', "");
Expect(0, 69248, '\P{^_ In_Rumi_NUMERAL_symbols}', "");
Error('\p{:=-Rumi}');
Error('\P{:=-Rumi}');
Expect(1, 69247, '\p{rumi}', "");
Expect(0, 69247, '\p{^rumi}', "");
Expect(0, 69247, '\P{rumi}', "");
Expect(1, 69247, '\P{^rumi}', "");
Expect(0, 69248, '\p{rumi}', "");
Expect(1, 69248, '\p{^rumi}', "");
Expect(1, 69248, '\P{rumi}', "");
Expect(0, 69248, '\P{^rumi}', "");
Expect(1, 69247, '\p{_	rumi}', "");
Expect(0, 69247, '\p{^_	rumi}', "");
Expect(0, 69247, '\P{_	rumi}', "");
Expect(1, 69247, '\P{^_	rumi}', "");
Expect(0, 69248, '\p{_	rumi}', "");
Expect(1, 69248, '\p{^_	rumi}', "");
Expect(1, 69248, '\P{_	rumi}', "");
Expect(0, 69248, '\P{^_	rumi}', "");
Error('\p{/a/Is_Rumi}');
Error('\P{/a/Is_Rumi}');
Expect(1, 69247, '\p{isrumi}', "");
Expect(0, 69247, '\p{^isrumi}', "");
Expect(0, 69247, '\P{isrumi}', "");
Expect(1, 69247, '\P{^isrumi}', "");
Expect(0, 69248, '\p{isrumi}', "");
Expect(1, 69248, '\p{^isrumi}', "");
Expect(1, 69248, '\P{isrumi}', "");
Expect(0, 69248, '\P{^isrumi}', "");
Expect(1, 69247, '\p{	Is_Rumi}', "");
Expect(0, 69247, '\p{^	Is_Rumi}', "");
Expect(0, 69247, '\P{	Is_Rumi}', "");
Expect(1, 69247, '\P{^	Is_Rumi}', "");
Expect(0, 69248, '\p{	Is_Rumi}', "");
Expect(1, 69248, '\p{^	Is_Rumi}', "");
Expect(1, 69248, '\P{	Is_Rumi}', "");
Expect(0, 69248, '\P{^	Is_Rumi}', "");
Error('\p{/a/-	in_Rumi}');
Error('\P{/a/-	in_Rumi}');
Expect(1, 69247, '\p{inrumi}', "");
Expect(0, 69247, '\p{^inrumi}', "");
Expect(0, 69247, '\P{inrumi}', "");
Expect(1, 69247, '\P{^inrumi}', "");
Expect(0, 69248, '\p{inrumi}', "");
Expect(1, 69248, '\p{^inrumi}', "");
Expect(1, 69248, '\P{inrumi}', "");
Expect(0, 69248, '\P{^inrumi}', "");
Expect(1, 69247, '\p{_IN_RUMI}', "");
Expect(0, 69247, '\p{^_IN_RUMI}', "");
Expect(0, 69247, '\P{_IN_RUMI}', "");
Expect(1, 69247, '\P{^_IN_RUMI}', "");
Expect(0, 69248, '\p{_IN_RUMI}', "");
Expect(1, 69248, '\p{^_IN_RUMI}', "");
Expect(1, 69248, '\P{_IN_RUMI}', "");
Expect(0, 69248, '\P{^_IN_RUMI}', "");
Error('\p{		runic:=}');
Error('\P{		runic:=}');
Expect(1, 5872, '\p{runic}', "");
Expect(0, 5872, '\p{^runic}', "");
Expect(0, 5872, '\P{runic}', "");
Expect(1, 5872, '\P{^runic}', "");
Expect(0, 5873, '\p{runic}', "");
Expect(1, 5873, '\p{^runic}', "");
Expect(1, 5873, '\P{runic}', "");
Expect(0, 5873, '\P{^runic}', "");
Expect(1, 5872, '\p{_-Runic}', "");
Expect(0, 5872, '\p{^_-Runic}', "");
Expect(0, 5872, '\P{_-Runic}', "");
Expect(1, 5872, '\P{^_-Runic}', "");
Expect(0, 5873, '\p{_-Runic}', "");
Expect(1, 5873, '\p{^_-Runic}', "");
Expect(1, 5873, '\P{_-Runic}', "");
Expect(0, 5873, '\P{^_-Runic}', "");
Error('\p{_:=is_Runic}');
Error('\P{_:=is_Runic}');
Expect(1, 5872, '\p{isrunic}', "");
Expect(0, 5872, '\p{^isrunic}', "");
Expect(0, 5872, '\P{isrunic}', "");
Expect(1, 5872, '\P{^isrunic}', "");
Expect(0, 5873, '\p{isrunic}', "");
Expect(1, 5873, '\p{^isrunic}', "");
Expect(1, 5873, '\P{isrunic}', "");
Expect(0, 5873, '\P{^isrunic}', "");
Expect(1, 5872, '\p{ Is_RUNIC}', "");
Expect(0, 5872, '\p{^ Is_RUNIC}', "");
Expect(0, 5872, '\P{ Is_RUNIC}', "");
Expect(1, 5872, '\P{^ Is_RUNIC}', "");
Expect(0, 5873, '\p{ Is_RUNIC}', "");
Expect(1, 5873, '\p{^ Is_RUNIC}', "");
Expect(1, 5873, '\P{ Is_RUNIC}', "");
Expect(0, 5873, '\P{^ Is_RUNIC}', "");
Error('\p{_/a/Runr}');
Error('\P{_/a/Runr}');
Expect(1, 5872, '\p{runr}', "");
Expect(0, 5872, '\p{^runr}', "");
Expect(0, 5872, '\P{runr}', "");
Expect(1, 5872, '\P{^runr}', "");
Expect(0, 5873, '\p{runr}', "");
Expect(1, 5873, '\p{^runr}', "");
Expect(1, 5873, '\P{runr}', "");
Expect(0, 5873, '\P{^runr}', "");
Expect(1, 5872, '\p{-	runr}', "");
Expect(0, 5872, '\p{^-	runr}', "");
Expect(0, 5872, '\P{-	runr}', "");
Expect(1, 5872, '\P{^-	runr}', "");
Expect(0, 5873, '\p{-	runr}', "");
Expect(1, 5873, '\p{^-	runr}', "");
Expect(1, 5873, '\P{-	runr}', "");
Expect(0, 5873, '\P{^-	runr}', "");
Error('\p{/a/-IS_Runr}');
Error('\P{/a/-IS_Runr}');
Expect(1, 5872, '\p{isrunr}', "");
Expect(0, 5872, '\p{^isrunr}', "");
Expect(0, 5872, '\P{isrunr}', "");
Expect(1, 5872, '\P{^isrunr}', "");
Expect(0, 5873, '\p{isrunr}', "");
Expect(1, 5873, '\p{^isrunr}', "");
Expect(1, 5873, '\P{isrunr}', "");
Expect(0, 5873, '\P{^isrunr}', "");
Expect(1, 5872, '\p{_Is_runr}', "");
Expect(0, 5872, '\p{^_Is_runr}', "");
Expect(0, 5872, '\P{_Is_runr}', "");
Expect(1, 5872, '\P{^_Is_runr}', "");
Expect(0, 5873, '\p{_Is_runr}', "");
Expect(1, 5873, '\p{^_Is_runr}', "");
Expect(1, 5873, '\P{_Is_runr}', "");
Expect(0, 5873, '\P{^_Is_runr}', "");
Error('\p{	:=sterm}');
Error('\P{	:=sterm}');
Expect(1, 70086, '\p{sterm}', "");
Expect(0, 70086, '\p{^sterm}', "");
Expect(0, 70086, '\P{sterm}', "");
Expect(1, 70086, '\P{^sterm}', "");
Expect(0, 70087, '\p{sterm}', "");
Expect(1, 70087, '\p{^sterm}', "");
Expect(1, 70087, '\P{sterm}', "");
Expect(0, 70087, '\P{^sterm}', "");
Expect(1, 70086, '\p{-STerm}', "");
Expect(0, 70086, '\p{^-STerm}', "");
Expect(0, 70086, '\P{-STerm}', "");
Expect(1, 70086, '\P{^-STerm}', "");
Expect(0, 70087, '\p{-STerm}', "");
Expect(1, 70087, '\p{^-STerm}', "");
Expect(1, 70087, '\P{-STerm}', "");
Expect(0, 70087, '\P{^-STerm}', "");
Error('\p{	_is_STERM:=}');
Error('\P{	_is_STERM:=}');
Expect(1, 70086, '\p{issterm}', "");
Expect(0, 70086, '\p{^issterm}', "");
Expect(0, 70086, '\P{issterm}', "");
Expect(1, 70086, '\P{^issterm}', "");
Expect(0, 70087, '\p{issterm}', "");
Expect(1, 70087, '\p{^issterm}', "");
Expect(1, 70087, '\P{issterm}', "");
Expect(0, 70087, '\P{^issterm}', "");
Expect(1, 70086, '\p{_is_STerm}', "");
Expect(0, 70086, '\p{^_is_STerm}', "");
Expect(0, 70086, '\P{_is_STerm}', "");
Expect(1, 70086, '\P{^_is_STerm}', "");
Expect(0, 70087, '\p{_is_STerm}', "");
Expect(1, 70087, '\p{^_is_STerm}', "");
Expect(1, 70087, '\P{_is_STerm}', "");
Expect(0, 70087, '\P{^_is_STerm}', "");
Error('\p{ SAMARITAN/a/}');
Error('\P{ SAMARITAN/a/}');
Expect(1, 2110, '\p{samaritan}', "");
Expect(0, 2110, '\p{^samaritan}', "");
Expect(0, 2110, '\P{samaritan}', "");
Expect(1, 2110, '\P{^samaritan}', "");
Expect(0, 2111, '\p{samaritan}', "");
Expect(1, 2111, '\p{^samaritan}', "");
Expect(1, 2111, '\P{samaritan}', "");
Expect(0, 2111, '\P{^samaritan}', "");
Expect(1, 2110, '\p{-Samaritan}', "");
Expect(0, 2110, '\p{^-Samaritan}', "");
Expect(0, 2110, '\P{-Samaritan}', "");
Expect(1, 2110, '\P{^-Samaritan}', "");
Expect(0, 2111, '\p{-Samaritan}', "");
Expect(1, 2111, '\p{^-Samaritan}', "");
Expect(1, 2111, '\P{-Samaritan}', "");
Expect(0, 2111, '\P{^-Samaritan}', "");
Error('\p{ /a/Is_Samaritan}');
Error('\P{ /a/Is_Samaritan}');
Expect(1, 2110, '\p{issamaritan}', "");
Expect(0, 2110, '\p{^issamaritan}', "");
Expect(0, 2110, '\P{issamaritan}', "");
Expect(1, 2110, '\P{^issamaritan}', "");
Expect(0, 2111, '\p{issamaritan}', "");
Expect(1, 2111, '\p{^issamaritan}', "");
Expect(1, 2111, '\P{issamaritan}', "");
Expect(0, 2111, '\P{^issamaritan}', "");
Expect(1, 2110, '\p{ is_Samaritan}', "");
Expect(0, 2110, '\p{^ is_Samaritan}', "");
Expect(0, 2110, '\P{ is_Samaritan}', "");
Expect(1, 2110, '\P{^ is_Samaritan}', "");
Expect(0, 2111, '\p{ is_Samaritan}', "");
Expect(1, 2111, '\p{^ is_Samaritan}', "");
Expect(1, 2111, '\P{ is_Samaritan}', "");
Expect(0, 2111, '\P{^ is_Samaritan}', "");
Error('\p{_-samr:=}');
Error('\P{_-samr:=}');
Expect(1, 2110, '\p{samr}', "");
Expect(0, 2110, '\p{^samr}', "");
Expect(0, 2110, '\P{samr}', "");
Expect(1, 2110, '\P{^samr}', "");
Expect(0, 2111, '\p{samr}', "");
Expect(1, 2111, '\p{^samr}', "");
Expect(1, 2111, '\P{samr}', "");
Expect(0, 2111, '\P{^samr}', "");
Expect(1, 2110, '\p{__samr}', "");
Expect(0, 2110, '\p{^__samr}', "");
Expect(0, 2110, '\P{__samr}', "");
Expect(1, 2110, '\P{^__samr}', "");
Expect(0, 2111, '\p{__samr}', "");
Expect(1, 2111, '\p{^__samr}', "");
Expect(1, 2111, '\P{__samr}', "");
Expect(0, 2111, '\P{^__samr}', "");
Error('\p{-/a/Is_Samr}');
Error('\P{-/a/Is_Samr}');
Expect(1, 2110, '\p{issamr}', "");
Expect(0, 2110, '\p{^issamr}', "");
Expect(0, 2110, '\P{issamr}', "");
Expect(1, 2110, '\P{^issamr}', "");
Expect(0, 2111, '\p{issamr}', "");
Expect(1, 2111, '\p{^issamr}', "");
Expect(1, 2111, '\P{issamr}', "");
Expect(0, 2111, '\P{^issamr}', "");
Expect(1, 2110, '\p{_	IS_Samr}', "");
Expect(0, 2110, '\p{^_	IS_Samr}', "");
Expect(0, 2110, '\P{_	IS_Samr}', "");
Expect(1, 2110, '\P{^_	IS_Samr}', "");
Expect(0, 2111, '\p{_	IS_Samr}', "");
Expect(1, 2111, '\p{^_	IS_Samr}', "");
Expect(1, 2111, '\P{_	IS_Samr}', "");
Expect(0, 2111, '\P{^_	IS_Samr}', "");
Error('\p{/a/Saurashtra}');
Error('\P{/a/Saurashtra}');
Expect(1, 43225, '\p{saurashtra}', "");
Expect(0, 43225, '\p{^saurashtra}', "");
Expect(0, 43225, '\P{saurashtra}', "");
Expect(1, 43225, '\P{^saurashtra}', "");
Expect(0, 43226, '\p{saurashtra}', "");
Expect(1, 43226, '\p{^saurashtra}', "");
Expect(1, 43226, '\P{saurashtra}', "");
Expect(0, 43226, '\P{^saurashtra}', "");
Expect(1, 43225, '\p{_ saurashtra}', "");
Expect(0, 43225, '\p{^_ saurashtra}', "");
Expect(0, 43225, '\P{_ saurashtra}', "");
Expect(1, 43225, '\P{^_ saurashtra}', "");
Expect(0, 43226, '\p{_ saurashtra}', "");
Expect(1, 43226, '\p{^_ saurashtra}', "");
Expect(1, 43226, '\P{_ saurashtra}', "");
Expect(0, 43226, '\P{^_ saurashtra}', "");
Error('\p{	/a/Is_Saurashtra}');
Error('\P{	/a/Is_Saurashtra}');
Expect(1, 43225, '\p{issaurashtra}', "");
Expect(0, 43225, '\p{^issaurashtra}', "");
Expect(0, 43225, '\P{issaurashtra}', "");
Expect(1, 43225, '\P{^issaurashtra}', "");
Expect(0, 43226, '\p{issaurashtra}', "");
Expect(1, 43226, '\p{^issaurashtra}', "");
Expect(1, 43226, '\P{issaurashtra}', "");
Expect(0, 43226, '\P{^issaurashtra}', "");
Expect(1, 43225, '\p{_Is_saurashtra}', "");
Expect(0, 43225, '\p{^_Is_saurashtra}', "");
Expect(0, 43225, '\P{_Is_saurashtra}', "");
Expect(1, 43225, '\P{^_Is_saurashtra}', "");
Expect(0, 43226, '\p{_Is_saurashtra}', "");
Expect(1, 43226, '\p{^_Is_saurashtra}', "");
Expect(1, 43226, '\P{_Is_saurashtra}', "");
Expect(0, 43226, '\P{^_Is_saurashtra}', "");
Error('\p{ :=Saur}');
Error('\P{ :=Saur}');
Expect(1, 43225, '\p{saur}', "");
Expect(0, 43225, '\p{^saur}', "");
Expect(0, 43225, '\P{saur}', "");
Expect(1, 43225, '\P{^saur}', "");
Expect(0, 43226, '\p{saur}', "");
Expect(1, 43226, '\p{^saur}', "");
Expect(1, 43226, '\P{saur}', "");
Expect(0, 43226, '\P{^saur}', "");
Expect(1, 43225, '\p{	_Saur}', "");
Expect(0, 43225, '\p{^	_Saur}', "");
Expect(0, 43225, '\P{	_Saur}', "");
Expect(1, 43225, '\P{^	_Saur}', "");
Expect(0, 43226, '\p{	_Saur}', "");
Expect(1, 43226, '\p{^	_Saur}', "");
Expect(1, 43226, '\P{	_Saur}', "");
Expect(0, 43226, '\P{^	_Saur}', "");
Error('\p{ is_Saur:=}');
Error('\P{ is_Saur:=}');
Expect(1, 43225, '\p{issaur}', "");
Expect(0, 43225, '\p{^issaur}', "");
Expect(0, 43225, '\P{issaur}', "");
Expect(1, 43225, '\P{^issaur}', "");
Expect(0, 43226, '\p{issaur}', "");
Expect(1, 43226, '\p{^issaur}', "");
Expect(1, 43226, '\P{issaur}', "");
Expect(0, 43226, '\P{^issaur}', "");
Expect(1, 43225, '\p{_	is_Saur}', "");
Expect(0, 43225, '\p{^_	is_Saur}', "");
Expect(0, 43225, '\P{_	is_Saur}', "");
Expect(1, 43225, '\P{^_	is_Saur}', "");
Expect(0, 43226, '\p{_	is_Saur}', "");
Expect(1, 43226, '\p{^_	is_Saur}', "");
Expect(1, 43226, '\P{_	is_Saur}', "");
Expect(0, 43226, '\P{^_	is_Saur}', "");
Error('\p{:=-_Separator}');
Error('\P{:=-_Separator}');
Expect(1, 12288, '\p{separator}', "");
Expect(0, 12288, '\p{^separator}', "");
Expect(0, 12288, '\P{separator}', "");
Expect(1, 12288, '\P{^separator}', "");
Expect(0, 12289, '\p{separator}', "");
Expect(1, 12289, '\p{^separator}', "");
Expect(1, 12289, '\P{separator}', "");
Expect(0, 12289, '\P{^separator}', "");
Expect(1, 12288, '\p{_Separator}', "");
Expect(0, 12288, '\p{^_Separator}', "");
Expect(0, 12288, '\P{_Separator}', "");
Expect(1, 12288, '\P{^_Separator}', "");
Expect(0, 12289, '\p{_Separator}', "");
Expect(1, 12289, '\p{^_Separator}', "");
Expect(1, 12289, '\P{_Separator}', "");
Expect(0, 12289, '\P{^_Separator}', "");
Error('\p{/a/	_Is_SEPARATOR}');
Error('\P{/a/	_Is_SEPARATOR}');
Expect(1, 12288, '\p{isseparator}', "");
Expect(0, 12288, '\p{^isseparator}', "");
Expect(0, 12288, '\P{isseparator}', "");
Expect(1, 12288, '\P{^isseparator}', "");
Expect(0, 12289, '\p{isseparator}', "");
Expect(1, 12289, '\p{^isseparator}', "");
Expect(1, 12289, '\P{isseparator}', "");
Expect(0, 12289, '\P{^isseparator}', "");
Expect(1, 12288, '\p{-_is_SEPARATOR}', "");
Expect(0, 12288, '\p{^-_is_SEPARATOR}', "");
Expect(0, 12288, '\P{-_is_SEPARATOR}', "");
Expect(1, 12288, '\P{^-_is_SEPARATOR}', "");
Expect(0, 12289, '\p{-_is_SEPARATOR}', "");
Expect(1, 12289, '\p{^-_is_SEPARATOR}', "");
Expect(1, 12289, '\P{-_is_SEPARATOR}', "");
Expect(0, 12289, '\P{^-_is_SEPARATOR}', "");
Error('\p{:=Z}');
Error('\P{:=Z}');
Expect(1, 12288, '\p{z}', "");
Expect(0, 12288, '\p{^z}', "");
Expect(0, 12288, '\P{z}', "");
Expect(1, 12288, '\P{^z}', "");
Expect(0, 12289, '\p{z}', "");
Expect(1, 12289, '\p{^z}', "");
Expect(1, 12289, '\P{z}', "");
Expect(0, 12289, '\P{^z}', "");
Expect(1, 12288, '\p{_	z}', "");
Expect(0, 12288, '\p{^_	z}', "");
Expect(0, 12288, '\P{_	z}', "");
Expect(1, 12288, '\P{^_	z}', "");
Expect(0, 12289, '\p{_	z}', "");
Expect(1, 12289, '\p{^_	z}', "");
Expect(1, 12289, '\P{_	z}', "");
Expect(0, 12289, '\P{^_	z}', "");
Error('\p{	:=is_Z}');
Error('\P{	:=is_Z}');
Expect(1, 12288, '\p{isz}', "");
Expect(0, 12288, '\p{^isz}', "");
Expect(0, 12288, '\P{isz}', "");
Expect(1, 12288, '\P{^isz}', "");
Expect(0, 12289, '\p{isz}', "");
Expect(1, 12289, '\p{^isz}', "");
Expect(1, 12289, '\P{isz}', "");
Expect(0, 12289, '\P{^isz}', "");
Expect(1, 12288, '\p{ IS_z}', "");
Expect(0, 12288, '\p{^ IS_z}', "");
Expect(0, 12288, '\P{ IS_z}', "");
Expect(1, 12288, '\P{^ IS_z}', "");
Expect(0, 12289, '\p{ IS_z}', "");
Expect(1, 12289, '\p{^ IS_z}', "");
Expect(1, 12289, '\P{ IS_z}', "");
Expect(0, 12289, '\P{^ IS_z}', "");
Error('\p{-/a/sharada}');
Error('\P{-/a/sharada}');
Expect(1, 70105, '\p{sharada}', "");
Expect(0, 70105, '\p{^sharada}', "");
Expect(0, 70105, '\P{sharada}', "");
Expect(1, 70105, '\P{^sharada}', "");
Expect(0, 70106, '\p{sharada}', "");
Expect(1, 70106, '\p{^sharada}', "");
Expect(1, 70106, '\P{sharada}', "");
Expect(0, 70106, '\P{^sharada}', "");
Expect(1, 70105, '\p{SHARADA}', "");
Expect(0, 70105, '\p{^SHARADA}', "");
Expect(0, 70105, '\P{SHARADA}', "");
Expect(1, 70105, '\P{^SHARADA}', "");
Expect(0, 70106, '\p{SHARADA}', "");
Expect(1, 70106, '\p{^SHARADA}', "");
Expect(1, 70106, '\P{SHARADA}', "");
Expect(0, 70106, '\P{^SHARADA}', "");
Error('\p{:=IS_SHARADA}');
Error('\P{:=IS_SHARADA}');
Expect(1, 70105, '\p{issharada}', "");
Expect(0, 70105, '\p{^issharada}', "");
Expect(0, 70105, '\P{issharada}', "");
Expect(1, 70105, '\P{^issharada}', "");
Expect(0, 70106, '\p{issharada}', "");
Expect(1, 70106, '\p{^issharada}', "");
Expect(1, 70106, '\P{issharada}', "");
Expect(0, 70106, '\P{^issharada}', "");
Expect(1, 70105, '\p{ Is_sharada}', "");
Expect(0, 70105, '\p{^ Is_sharada}', "");
Expect(0, 70105, '\P{ Is_sharada}', "");
Expect(1, 70105, '\P{^ Is_sharada}', "");
Expect(0, 70106, '\p{ Is_sharada}', "");
Expect(1, 70106, '\p{^ Is_sharada}', "");
Expect(1, 70106, '\P{ Is_sharada}', "");
Expect(0, 70106, '\P{^ Is_sharada}', "");
Error('\p{	:=SHRD}');
Error('\P{	:=SHRD}');
Expect(1, 70105, '\p{shrd}', "");
Expect(0, 70105, '\p{^shrd}', "");
Expect(0, 70105, '\P{shrd}', "");
Expect(1, 70105, '\P{^shrd}', "");
Expect(0, 70106, '\p{shrd}', "");
Expect(1, 70106, '\p{^shrd}', "");
Expect(1, 70106, '\P{shrd}', "");
Expect(0, 70106, '\P{^shrd}', "");
Expect(1, 70105, '\p{ Shrd}', "");
Expect(0, 70105, '\p{^ Shrd}', "");
Expect(0, 70105, '\P{ Shrd}', "");
Expect(1, 70105, '\P{^ Shrd}', "");
Expect(0, 70106, '\p{ Shrd}', "");
Expect(1, 70106, '\p{^ Shrd}', "");
Expect(1, 70106, '\P{ Shrd}', "");
Expect(0, 70106, '\P{^ Shrd}', "");
Error('\p{_/a/is_Shrd}');
Error('\P{_/a/is_Shrd}');
Expect(1, 70105, '\p{isshrd}', "");
Expect(0, 70105, '\p{^isshrd}', "");
Expect(0, 70105, '\P{isshrd}', "");
Expect(1, 70105, '\P{^isshrd}', "");
Expect(0, 70106, '\p{isshrd}', "");
Expect(1, 70106, '\p{^isshrd}', "");
Expect(1, 70106, '\P{isshrd}', "");
Expect(0, 70106, '\P{^isshrd}', "");
Expect(1, 70105, '\p{  Is_Shrd}', "");
Expect(0, 70105, '\p{^  Is_Shrd}', "");
Expect(0, 70105, '\P{  Is_Shrd}', "");
Expect(1, 70105, '\P{^  Is_Shrd}', "");
Expect(0, 70106, '\p{  Is_Shrd}', "");
Expect(1, 70106, '\p{^  Is_Shrd}', "");
Expect(1, 70106, '\P{  Is_Shrd}', "");
Expect(0, 70106, '\P{^  Is_Shrd}', "");
Error('\p{		Shavian/a/}');
Error('\P{		Shavian/a/}');
Expect(1, 66687, '\p{shavian}', "");
Expect(0, 66687, '\p{^shavian}', "");
Expect(0, 66687, '\P{shavian}', "");
Expect(1, 66687, '\P{^shavian}', "");
Expect(0, 66688, '\p{shavian}', "");
Expect(1, 66688, '\p{^shavian}', "");
Expect(1, 66688, '\P{shavian}', "");
Expect(0, 66688, '\P{^shavian}', "");
Expect(1, 66687, '\p{-Shavian}', "");
Expect(0, 66687, '\p{^-Shavian}', "");
Expect(0, 66687, '\P{-Shavian}', "");
Expect(1, 66687, '\P{^-Shavian}', "");
Expect(0, 66688, '\p{-Shavian}', "");
Expect(1, 66688, '\p{^-Shavian}', "");
Expect(1, 66688, '\P{-Shavian}', "");
Expect(0, 66688, '\P{^-Shavian}', "");
Error('\p{/a/ Is_shavian}');
Error('\P{/a/ Is_shavian}');
Expect(1, 66687, '\p{isshavian}', "");
Expect(0, 66687, '\p{^isshavian}', "");
Expect(0, 66687, '\P{isshavian}', "");
Expect(1, 66687, '\P{^isshavian}', "");
Expect(0, 66688, '\p{isshavian}', "");
Expect(1, 66688, '\p{^isshavian}', "");
Expect(1, 66688, '\P{isshavian}', "");
Expect(0, 66688, '\P{^isshavian}', "");
Expect(1, 66687, '\p{_ Is_SHAVIAN}', "");
Expect(0, 66687, '\p{^_ Is_SHAVIAN}', "");
Expect(0, 66687, '\P{_ Is_SHAVIAN}', "");
Expect(1, 66687, '\P{^_ Is_SHAVIAN}', "");
Expect(0, 66688, '\p{_ Is_SHAVIAN}', "");
Expect(1, 66688, '\p{^_ Is_SHAVIAN}', "");
Expect(1, 66688, '\P{_ Is_SHAVIAN}', "");
Expect(0, 66688, '\P{^_ Is_SHAVIAN}', "");
Error('\p{ /a/Shaw}');
Error('\P{ /a/Shaw}');
Expect(1, 66687, '\p{shaw}', "");
Expect(0, 66687, '\p{^shaw}', "");
Expect(0, 66687, '\P{shaw}', "");
Expect(1, 66687, '\P{^shaw}', "");
Expect(0, 66688, '\p{shaw}', "");
Expect(1, 66688, '\p{^shaw}', "");
Expect(1, 66688, '\P{shaw}', "");
Expect(0, 66688, '\P{^shaw}', "");
Expect(1, 66687, '\p{ 	shaw}', "");
Expect(0, 66687, '\p{^ 	shaw}', "");
Expect(0, 66687, '\P{ 	shaw}', "");
Expect(1, 66687, '\P{^ 	shaw}', "");
Expect(0, 66688, '\p{ 	shaw}', "");
Expect(1, 66688, '\p{^ 	shaw}', "");
Expect(1, 66688, '\P{ 	shaw}', "");
Expect(0, 66688, '\P{^ 	shaw}', "");
Error('\p{/a/ _IS_shaw}');
Error('\P{/a/ _IS_shaw}');
Expect(1, 66687, '\p{isshaw}', "");
Expect(0, 66687, '\p{^isshaw}', "");
Expect(0, 66687, '\P{isshaw}', "");
Expect(1, 66687, '\P{^isshaw}', "");
Expect(0, 66688, '\p{isshaw}', "");
Expect(1, 66688, '\p{^isshaw}', "");
Expect(1, 66688, '\P{isshaw}', "");
Expect(0, 66688, '\P{^isshaw}', "");
Expect(1, 66687, '\p{	-Is_Shaw}', "");
Expect(0, 66687, '\p{^	-Is_Shaw}', "");
Expect(0, 66687, '\P{	-Is_Shaw}', "");
Expect(1, 66687, '\P{^	-Is_Shaw}', "");
Expect(0, 66688, '\p{	-Is_Shaw}', "");
Expect(1, 66688, '\p{^	-Is_Shaw}', "");
Expect(1, 66688, '\P{	-Is_Shaw}', "");
Expect(0, 66688, '\P{^	-Is_Shaw}', "");
Error('\p{:=Sinhala}');
Error('\P{:=Sinhala}');
Expect(1, 3572, '\p{sinhala}', "");
Expect(0, 3572, '\p{^sinhala}', "");
Expect(0, 3572, '\P{sinhala}', "");
Expect(1, 3572, '\P{^sinhala}', "");
Expect(0, 3573, '\p{sinhala}', "");
Expect(1, 3573, '\p{^sinhala}', "");
Expect(1, 3573, '\P{sinhala}', "");
Expect(0, 3573, '\P{^sinhala}', "");
Expect(1, 3572, '\p{ sinhala}', "");
Expect(0, 3572, '\p{^ sinhala}', "");
Expect(0, 3572, '\P{ sinhala}', "");
Expect(1, 3572, '\P{^ sinhala}', "");
Expect(0, 3573, '\p{ sinhala}', "");
Expect(1, 3573, '\p{^ sinhala}', "");
Expect(1, 3573, '\P{ sinhala}', "");
Expect(0, 3573, '\P{^ sinhala}', "");
Error('\p{	/a/Is_Sinhala}');
Error('\P{	/a/Is_Sinhala}');
Expect(1, 3572, '\p{issinhala}', "");
Expect(0, 3572, '\p{^issinhala}', "");
Expect(0, 3572, '\P{issinhala}', "");
Expect(1, 3572, '\P{^issinhala}', "");
Expect(0, 3573, '\p{issinhala}', "");
Expect(1, 3573, '\p{^issinhala}', "");
Expect(1, 3573, '\P{issinhala}', "");
Expect(0, 3573, '\P{^issinhala}', "");
Expect(1, 3572, '\p{	_is_SINHALA}', "");
Expect(0, 3572, '\p{^	_is_SINHALA}', "");
Expect(0, 3572, '\P{	_is_SINHALA}', "");
Expect(1, 3572, '\P{^	_is_SINHALA}', "");
Expect(0, 3573, '\p{	_is_SINHALA}', "");
Expect(1, 3573, '\p{^	_is_SINHALA}', "");
Expect(1, 3573, '\P{	_is_SINHALA}', "");
Expect(0, 3573, '\P{^	_is_SINHALA}', "");
Error('\p{	:=sinh}');
Error('\P{	:=sinh}');
Expect(1, 3572, '\p{sinh}', "");
Expect(0, 3572, '\p{^sinh}', "");
Expect(0, 3572, '\P{sinh}', "");
Expect(1, 3572, '\P{^sinh}', "");
Expect(0, 3573, '\p{sinh}', "");
Expect(1, 3573, '\p{^sinh}', "");
Expect(1, 3573, '\P{sinh}', "");
Expect(0, 3573, '\P{^sinh}', "");
Expect(1, 3572, '\p{_Sinh}', "");
Expect(0, 3572, '\p{^_Sinh}', "");
Expect(0, 3572, '\P{_Sinh}', "");
Expect(1, 3572, '\P{^_Sinh}', "");
Expect(0, 3573, '\p{_Sinh}', "");
Expect(1, 3573, '\p{^_Sinh}', "");
Expect(1, 3573, '\P{_Sinh}', "");
Expect(0, 3573, '\P{^_Sinh}', "");
Error('\p{/a/ 	is_SINH}');
Error('\P{/a/ 	is_SINH}');
Expect(1, 3572, '\p{issinh}', "");
Expect(0, 3572, '\p{^issinh}', "");
Expect(0, 3572, '\P{issinh}', "");
Expect(1, 3572, '\P{^issinh}', "");
Expect(0, 3573, '\p{issinh}', "");
Expect(1, 3573, '\p{^issinh}', "");
Expect(1, 3573, '\P{issinh}', "");
Expect(0, 3573, '\P{^issinh}', "");
Expect(1, 3572, '\p{_	Is_Sinh}', "");
Expect(0, 3572, '\p{^_	Is_Sinh}', "");
Expect(0, 3572, '\P{_	Is_Sinh}', "");
Expect(1, 3572, '\P{^_	Is_Sinh}', "");
Expect(0, 3573, '\p{_	Is_Sinh}', "");
Expect(1, 3573, '\p{^_	Is_Sinh}', "");
Expect(1, 3573, '\P{_	Is_Sinh}', "");
Expect(0, 3573, '\P{^_	Is_Sinh}', "");
Error('\p{	/a/Small_FORM_Variants}');
Error('\P{	/a/Small_FORM_Variants}');
Expect(1, 65135, '\p{smallformvariants}', "");
Expect(0, 65135, '\p{^smallformvariants}', "");
Expect(0, 65135, '\P{smallformvariants}', "");
Expect(1, 65135, '\P{^smallformvariants}', "");
Expect(0, 65136, '\p{smallformvariants}', "");
Expect(1, 65136, '\p{^smallformvariants}', "");
Expect(1, 65136, '\P{smallformvariants}', "");
Expect(0, 65136, '\P{^smallformvariants}', "");
Expect(1, 65135, '\p{	-small_FORM_Variants}', "");
Expect(0, 65135, '\p{^	-small_FORM_Variants}', "");
Expect(0, 65135, '\P{	-small_FORM_Variants}', "");
Expect(1, 65135, '\P{^	-small_FORM_Variants}', "");
Expect(0, 65136, '\p{	-small_FORM_Variants}', "");
Expect(1, 65136, '\p{^	-small_FORM_Variants}', "");
Expect(1, 65136, '\P{	-small_FORM_Variants}', "");
Expect(0, 65136, '\P{^	-small_FORM_Variants}', "");
Error('\p{	:=Is_SMALL_Form_variants}');
Error('\P{	:=Is_SMALL_Form_variants}');
Expect(1, 65135, '\p{issmallformvariants}', "");
Expect(0, 65135, '\p{^issmallformvariants}', "");
Expect(0, 65135, '\P{issmallformvariants}', "");
Expect(1, 65135, '\P{^issmallformvariants}', "");
Expect(0, 65136, '\p{issmallformvariants}', "");
Expect(1, 65136, '\p{^issmallformvariants}', "");
Expect(1, 65136, '\P{issmallformvariants}', "");
Expect(0, 65136, '\P{^issmallformvariants}', "");
Expect(1, 65135, '\p{- Is_Small_Form_Variants}', "");
Expect(0, 65135, '\p{^- Is_Small_Form_Variants}', "");
Expect(0, 65135, '\P{- Is_Small_Form_Variants}', "");
Expect(1, 65135, '\P{^- Is_Small_Form_Variants}', "");
Expect(0, 65136, '\p{- Is_Small_Form_Variants}', "");
Expect(1, 65136, '\p{^- Is_Small_Form_Variants}', "");
Expect(1, 65136, '\P{- Is_Small_Form_Variants}', "");
Expect(0, 65136, '\P{^- Is_Small_Form_Variants}', "");
Error('\p{-:=In_Small_Form_Variants}');
Error('\P{-:=In_Small_Form_Variants}');
Expect(1, 65135, '\p{insmallformvariants}', "");
Expect(0, 65135, '\p{^insmallformvariants}', "");
Expect(0, 65135, '\P{insmallformvariants}', "");
Expect(1, 65135, '\P{^insmallformvariants}', "");
Expect(0, 65136, '\p{insmallformvariants}', "");
Expect(1, 65136, '\p{^insmallformvariants}', "");
Expect(1, 65136, '\P{insmallformvariants}', "");
Expect(0, 65136, '\P{^insmallformvariants}', "");
Expect(1, 65135, '\p{	In_SMALL_Form_variants}', "");
Expect(0, 65135, '\p{^	In_SMALL_Form_variants}', "");
Expect(0, 65135, '\P{	In_SMALL_Form_variants}', "");
Expect(1, 65135, '\P{^	In_SMALL_Form_variants}', "");
Expect(0, 65136, '\p{	In_SMALL_Form_variants}', "");
Expect(1, 65136, '\p{^	In_SMALL_Form_variants}', "");
Expect(1, 65136, '\P{	In_SMALL_Form_variants}', "");
Expect(0, 65136, '\P{^	In_SMALL_Form_variants}', "");
Error('\p{/a/		Small_forms}');
Error('\P{/a/		Small_forms}');
Expect(1, 65135, '\p{smallforms}', "");
Expect(0, 65135, '\p{^smallforms}', "");
Expect(0, 65135, '\P{smallforms}', "");
Expect(1, 65135, '\P{^smallforms}', "");
Expect(0, 65136, '\p{smallforms}', "");
Expect(1, 65136, '\p{^smallforms}', "");
Expect(1, 65136, '\P{smallforms}', "");
Expect(0, 65136, '\P{^smallforms}', "");
Expect(1, 65135, '\p{ _Small_Forms}', "");
Expect(0, 65135, '\p{^ _Small_Forms}', "");
Expect(0, 65135, '\P{ _Small_Forms}', "");
Expect(1, 65135, '\P{^ _Small_Forms}', "");
Expect(0, 65136, '\p{ _Small_Forms}', "");
Expect(1, 65136, '\p{^ _Small_Forms}', "");
Expect(1, 65136, '\P{ _Small_Forms}', "");
Expect(0, 65136, '\P{^ _Small_Forms}', "");
Error('\p{:=__is_Small_forms}');
Error('\P{:=__is_Small_forms}');
Expect(1, 65135, '\p{issmallforms}', "");
Expect(0, 65135, '\p{^issmallforms}', "");
Expect(0, 65135, '\P{issmallforms}', "");
Expect(1, 65135, '\P{^issmallforms}', "");
Expect(0, 65136, '\p{issmallforms}', "");
Expect(1, 65136, '\p{^issmallforms}', "");
Expect(1, 65136, '\P{issmallforms}', "");
Expect(0, 65136, '\P{^issmallforms}', "");
Expect(1, 65135, '\p{ _is_small_Forms}', "");
Expect(0, 65135, '\p{^ _is_small_Forms}', "");
Expect(0, 65135, '\P{ _is_small_Forms}', "");
Expect(1, 65135, '\P{^ _is_small_Forms}', "");
Expect(0, 65136, '\p{ _is_small_Forms}', "");
Expect(1, 65136, '\p{^ _is_small_Forms}', "");
Expect(1, 65136, '\P{ _is_small_Forms}', "");
Expect(0, 65136, '\P{^ _is_small_Forms}', "");
Error('\p{:=_-In_small_forms}');
Error('\P{:=_-In_small_forms}');
Expect(1, 65135, '\p{insmallforms}', "");
Expect(0, 65135, '\p{^insmallforms}', "");
Expect(0, 65135, '\P{insmallforms}', "");
Expect(1, 65135, '\P{^insmallforms}', "");
Expect(0, 65136, '\p{insmallforms}', "");
Expect(1, 65136, '\p{^insmallforms}', "");
Expect(1, 65136, '\P{insmallforms}', "");
Expect(0, 65136, '\P{^insmallforms}', "");
Expect(1, 65135, '\p{-	In_Small_Forms}', "");
Expect(0, 65135, '\p{^-	In_Small_Forms}', "");
Expect(0, 65135, '\P{-	In_Small_Forms}', "");
Expect(1, 65135, '\P{^-	In_Small_Forms}', "");
Expect(0, 65136, '\p{-	In_Small_Forms}', "");
Expect(1, 65136, '\p{^-	In_Small_Forms}', "");
Expect(1, 65136, '\P{-	In_Small_Forms}', "");
Expect(0, 65136, '\P{^-	In_Small_Forms}', "");
Error('\p{:=_SORA_Sompeng}');
Error('\P{:=_SORA_Sompeng}');
Expect(1, 69881, '\p{sorasompeng}', "");
Expect(0, 69881, '\p{^sorasompeng}', "");
Expect(0, 69881, '\P{sorasompeng}', "");
Expect(1, 69881, '\P{^sorasompeng}', "");
Expect(0, 69882, '\p{sorasompeng}', "");
Expect(1, 69882, '\p{^sorasompeng}', "");
Expect(1, 69882, '\P{sorasompeng}', "");
Expect(0, 69882, '\P{^sorasompeng}', "");
Expect(1, 69881, '\p{ sora_Sompeng}', "");
Expect(0, 69881, '\p{^ sora_Sompeng}', "");
Expect(0, 69881, '\P{ sora_Sompeng}', "");
Expect(1, 69881, '\P{^ sora_Sompeng}', "");
Expect(0, 69882, '\p{ sora_Sompeng}', "");
Expect(1, 69882, '\p{^ sora_Sompeng}', "");
Expect(1, 69882, '\P{ sora_Sompeng}', "");
Expect(0, 69882, '\P{^ sora_Sompeng}', "");
Error('\p{/a/Is_sora_sompeng}');
Error('\P{/a/Is_sora_sompeng}');
Expect(1, 69881, '\p{issorasompeng}', "");
Expect(0, 69881, '\p{^issorasompeng}', "");
Expect(0, 69881, '\P{issorasompeng}', "");
Expect(1, 69881, '\P{^issorasompeng}', "");
Expect(0, 69882, '\p{issorasompeng}', "");
Expect(1, 69882, '\p{^issorasompeng}', "");
Expect(1, 69882, '\P{issorasompeng}', "");
Expect(0, 69882, '\P{^issorasompeng}', "");
Expect(1, 69881, '\p{_	is_Sora_sompeng}', "");
Expect(0, 69881, '\p{^_	is_Sora_sompeng}', "");
Expect(0, 69881, '\P{_	is_Sora_sompeng}', "");
Expect(1, 69881, '\P{^_	is_Sora_sompeng}', "");
Expect(0, 69882, '\p{_	is_Sora_sompeng}', "");
Expect(1, 69882, '\p{^_	is_Sora_sompeng}', "");
Expect(1, 69882, '\P{_	is_Sora_sompeng}', "");
Expect(0, 69882, '\P{^_	is_Sora_sompeng}', "");
Error('\p{-/a/Sora}');
Error('\P{-/a/Sora}');
Expect(1, 69881, '\p{sora}', "");
Expect(0, 69881, '\p{^sora}', "");
Expect(0, 69881, '\P{sora}', "");
Expect(1, 69881, '\P{^sora}', "");
Expect(0, 69882, '\p{sora}', "");
Expect(1, 69882, '\p{^sora}', "");
Expect(1, 69882, '\P{sora}', "");
Expect(0, 69882, '\P{^sora}', "");
Expect(1, 69881, '\p{_Sora}', "");
Expect(0, 69881, '\p{^_Sora}', "");
Expect(0, 69881, '\P{_Sora}', "");
Expect(1, 69881, '\P{^_Sora}', "");
Expect(0, 69882, '\p{_Sora}', "");
Expect(1, 69882, '\p{^_Sora}', "");
Expect(1, 69882, '\P{_Sora}', "");
Expect(0, 69882, '\P{^_Sora}', "");
Error('\p{	/a/Is_SORA}');
Error('\P{	/a/Is_SORA}');
Expect(1, 69881, '\p{issora}', "");
Expect(0, 69881, '\p{^issora}', "");
Expect(0, 69881, '\P{issora}', "");
Expect(1, 69881, '\P{^issora}', "");
Expect(0, 69882, '\p{issora}', "");
Expect(1, 69882, '\p{^issora}', "");
Expect(1, 69882, '\P{issora}', "");
Expect(0, 69882, '\P{^issora}', "");
Expect(1, 69881, '\p{ IS_Sora}', "");
Expect(0, 69881, '\p{^ IS_Sora}', "");
Expect(0, 69881, '\P{ IS_Sora}', "");
Expect(1, 69881, '\P{^ IS_Sora}', "");
Expect(0, 69882, '\p{ IS_Sora}', "");
Expect(1, 69882, '\p{^ IS_Sora}', "");
Expect(1, 69882, '\P{ IS_Sora}', "");
Expect(0, 69882, '\P{^ IS_Sora}', "");
Error('\p{:=_	space}');
Error('\P{:=_	space}');
Expect(1, 12288, '\p{space}', "");
Expect(0, 12288, '\p{^space}', "");
Expect(0, 12288, '\P{space}', "");
Expect(1, 12288, '\P{^space}', "");
Expect(0, 12289, '\p{space}', "");
Expect(1, 12289, '\p{^space}', "");
Expect(1, 12289, '\P{space}', "");
Expect(0, 12289, '\P{^space}', "");
Expect(1, 12288, '\p{  Space}', "");
Expect(0, 12288, '\p{^  Space}', "");
Expect(0, 12288, '\P{  Space}', "");
Expect(1, 12288, '\P{^  Space}', "");
Expect(0, 12289, '\p{  Space}', "");
Expect(1, 12289, '\p{^  Space}', "");
Expect(1, 12289, '\P{  Space}', "");
Expect(0, 12289, '\P{^  Space}', "");
Error('\p{	:=XPosixSpace}');
Error('\P{	:=XPosixSpace}');
Expect(1, 12288, '\p{xposixspace}', "");
Expect(0, 12288, '\p{^xposixspace}', "");
Expect(0, 12288, '\P{xposixspace}', "");
Expect(1, 12288, '\P{^xposixspace}', "");
Expect(0, 12289, '\p{xposixspace}', "");
Expect(1, 12289, '\p{^xposixspace}', "");
Expect(1, 12289, '\P{xposixspace}', "");
Expect(0, 12289, '\P{^xposixspace}', "");
Expect(1, 12288, '\p{--XPOSIXSPACE}', "");
Expect(0, 12288, '\p{^--XPOSIXSPACE}', "");
Expect(0, 12288, '\P{--XPOSIXSPACE}', "");
Expect(1, 12288, '\P{^--XPOSIXSPACE}', "");
Expect(0, 12289, '\p{--XPOSIXSPACE}', "");
Expect(1, 12289, '\p{^--XPOSIXSPACE}', "");
Expect(1, 12289, '\P{--XPOSIXSPACE}', "");
Expect(0, 12289, '\P{^--XPOSIXSPACE}', "");
Error('\p{ IS_SPACE/a/}');
Error('\P{ IS_SPACE/a/}');
Expect(1, 12288, '\p{isspace}', "");
Expect(0, 12288, '\p{^isspace}', "");
Expect(0, 12288, '\P{isspace}', "");
Expect(1, 12288, '\P{^isspace}', "");
Expect(0, 12289, '\p{isspace}', "");
Expect(1, 12289, '\p{^isspace}', "");
Expect(1, 12289, '\P{isspace}', "");
Expect(0, 12289, '\P{^isspace}', "");
Expect(1, 12288, '\p{_ IS_Space}', "");
Expect(0, 12288, '\p{^_ IS_Space}', "");
Expect(0, 12288, '\P{_ IS_Space}', "");
Expect(1, 12288, '\P{^_ IS_Space}', "");
Expect(0, 12289, '\p{_ IS_Space}', "");
Expect(1, 12289, '\p{^_ IS_Space}', "");
Expect(1, 12289, '\P{_ IS_Space}', "");
Expect(0, 12289, '\P{^_ IS_Space}', "");
Error('\p{_:=is_XPosixSpace}');
Error('\P{_:=is_XPosixSpace}');
Expect(1, 12288, '\p{isxposixspace}', "");
Expect(0, 12288, '\p{^isxposixspace}', "");
Expect(0, 12288, '\P{isxposixspace}', "");
Expect(1, 12288, '\P{^isxposixspace}', "");
Expect(0, 12289, '\p{isxposixspace}', "");
Expect(1, 12289, '\p{^isxposixspace}', "");
Expect(1, 12289, '\P{isxposixspace}', "");
Expect(0, 12289, '\P{^isxposixspace}', "");
Expect(1, 12288, '\p{_-is_XPOSIXSPACE}', "");
Expect(0, 12288, '\p{^_-is_XPOSIXSPACE}', "");
Expect(0, 12288, '\P{_-is_XPOSIXSPACE}', "");
Expect(1, 12288, '\P{^_-is_XPOSIXSPACE}', "");
Expect(0, 12289, '\p{_-is_XPOSIXSPACE}', "");
Expect(1, 12289, '\p{^_-is_XPOSIXSPACE}', "");
Expect(1, 12289, '\P{_-is_XPOSIXSPACE}', "");
Expect(0, 12289, '\P{^_-is_XPOSIXSPACE}', "");
Error('\p{/a/Space_Separator}');
Error('\P{/a/Space_Separator}');
Expect(1, 12288, '\p{spaceseparator}', "");
Expect(0, 12288, '\p{^spaceseparator}', "");
Expect(0, 12288, '\P{spaceseparator}', "");
Expect(1, 12288, '\P{^spaceseparator}', "");
Expect(0, 12289, '\p{spaceseparator}', "");
Expect(1, 12289, '\p{^spaceseparator}', "");
Expect(1, 12289, '\P{spaceseparator}', "");
Expect(0, 12289, '\P{^spaceseparator}', "");
Expect(1, 12288, '\p{-Space_Separator}', "");
Expect(0, 12288, '\p{^-Space_Separator}', "");
Expect(0, 12288, '\P{-Space_Separator}', "");
Expect(1, 12288, '\P{^-Space_Separator}', "");
Expect(0, 12289, '\p{-Space_Separator}', "");
Expect(1, 12289, '\p{^-Space_Separator}', "");
Expect(1, 12289, '\P{-Space_Separator}', "");
Expect(0, 12289, '\P{^-Space_Separator}', "");
Error('\p{	_IS_space_SEPARATOR/a/}');
Error('\P{	_IS_space_SEPARATOR/a/}');
Expect(1, 12288, '\p{isspaceseparator}', "");
Expect(0, 12288, '\p{^isspaceseparator}', "");
Expect(0, 12288, '\P{isspaceseparator}', "");
Expect(1, 12288, '\P{^isspaceseparator}', "");
Expect(0, 12289, '\p{isspaceseparator}', "");
Expect(1, 12289, '\p{^isspaceseparator}', "");
Expect(1, 12289, '\P{isspaceseparator}', "");
Expect(0, 12289, '\P{^isspaceseparator}', "");
Expect(1, 12288, '\p{_	Is_space_Separator}', "");
Expect(0, 12288, '\p{^_	Is_space_Separator}', "");
Expect(0, 12288, '\P{_	Is_space_Separator}', "");
Expect(1, 12288, '\P{^_	Is_space_Separator}', "");
Expect(0, 12289, '\p{_	Is_space_Separator}', "");
Expect(1, 12289, '\p{^_	Is_space_Separator}', "");
Expect(1, 12289, '\P{_	Is_space_Separator}', "");
Expect(0, 12289, '\P{^_	Is_space_Separator}', "");
Error('\p{ _zs/a/}');
Error('\P{ _zs/a/}');
Expect(1, 12288, '\p{zs}', "");
Expect(0, 12288, '\p{^zs}', "");
Expect(0, 12288, '\P{zs}', "");
Expect(1, 12288, '\P{^zs}', "");
Expect(0, 12289, '\p{zs}', "");
Expect(1, 12289, '\p{^zs}', "");
Expect(1, 12289, '\P{zs}', "");
Expect(0, 12289, '\P{^zs}', "");
Expect(1, 12288, '\p{  Zs}', "");
Expect(0, 12288, '\p{^  Zs}', "");
Expect(0, 12288, '\P{  Zs}', "");
Expect(1, 12288, '\P{^  Zs}', "");
Expect(0, 12289, '\p{  Zs}', "");
Expect(1, 12289, '\p{^  Zs}', "");
Expect(1, 12289, '\P{  Zs}', "");
Expect(0, 12289, '\P{^  Zs}', "");
Error('\p{	-Is_Zs/a/}');
Error('\P{	-Is_Zs/a/}');
Expect(1, 12288, '\p{iszs}', "");
Expect(0, 12288, '\p{^iszs}', "");
Expect(0, 12288, '\P{iszs}', "");
Expect(1, 12288, '\P{^iszs}', "");
Expect(0, 12289, '\p{iszs}', "");
Expect(1, 12289, '\p{^iszs}', "");
Expect(1, 12289, '\P{iszs}', "");
Expect(0, 12289, '\P{^iszs}', "");
Expect(1, 12288, '\p{  Is_zs}', "");
Expect(0, 12288, '\p{^  Is_zs}', "");
Expect(0, 12288, '\P{  Is_zs}', "");
Expect(1, 12288, '\P{^  Is_zs}', "");
Expect(0, 12289, '\p{  Is_zs}', "");
Expect(1, 12289, '\p{^  Is_zs}', "");
Expect(1, 12289, '\P{  Is_zs}', "");
Expect(0, 12289, '\P{^  Is_zs}', "");
Error('\p{:= -SPACING_mark}');
Error('\P{:= -SPACING_mark}');
Expect(1, 119154, '\p{spacingmark}', "");
Expect(0, 119154, '\p{^spacingmark}', "");
Expect(0, 119154, '\P{spacingmark}', "");
Expect(1, 119154, '\P{^spacingmark}', "");
Expect(0, 119155, '\p{spacingmark}', "");
Expect(1, 119155, '\p{^spacingmark}', "");
Expect(1, 119155, '\P{spacingmark}', "");
Expect(0, 119155, '\P{^spacingmark}', "");
Expect(1, 119154, '\p{	 SPACING_Mark}', "");
Expect(0, 119154, '\p{^	 SPACING_Mark}', "");
Expect(0, 119154, '\P{	 SPACING_Mark}', "");
Expect(1, 119154, '\P{^	 SPACING_Mark}', "");
Expect(0, 119155, '\p{	 SPACING_Mark}', "");
Expect(1, 119155, '\p{^	 SPACING_Mark}', "");
Expect(1, 119155, '\P{	 SPACING_Mark}', "");
Expect(0, 119155, '\P{^	 SPACING_Mark}', "");
Error('\p{  is_Spacing_mark/a/}');
Error('\P{  is_Spacing_mark/a/}');
Expect(1, 119154, '\p{isspacingmark}', "");
Expect(0, 119154, '\p{^isspacingmark}', "");
Expect(0, 119154, '\P{isspacingmark}', "");
Expect(1, 119154, '\P{^isspacingmark}', "");
Expect(0, 119155, '\p{isspacingmark}', "");
Expect(1, 119155, '\p{^isspacingmark}', "");
Expect(1, 119155, '\P{isspacingmark}', "");
Expect(0, 119155, '\P{^isspacingmark}', "");
Expect(1, 119154, '\p{ -Is_spacing_Mark}', "");
Expect(0, 119154, '\p{^ -Is_spacing_Mark}', "");
Expect(0, 119154, '\P{ -Is_spacing_Mark}', "");
Expect(1, 119154, '\P{^ -Is_spacing_Mark}', "");
Expect(0, 119155, '\p{ -Is_spacing_Mark}', "");
Expect(1, 119155, '\p{^ -Is_spacing_Mark}', "");
Expect(1, 119155, '\P{ -Is_spacing_Mark}', "");
Expect(0, 119155, '\P{^ -Is_spacing_Mark}', "");
Error('\p{ _mc/a/}');
Error('\P{ _mc/a/}');
Expect(1, 119154, '\p{mc}', "");
Expect(0, 119154, '\p{^mc}', "");
Expect(0, 119154, '\P{mc}', "");
Expect(1, 119154, '\P{^mc}', "");
Expect(0, 119155, '\p{mc}', "");
Expect(1, 119155, '\p{^mc}', "");
Expect(1, 119155, '\P{mc}', "");
Expect(0, 119155, '\P{^mc}', "");
Expect(1, 119154, '\p{__Mc}', "");
Expect(0, 119154, '\p{^__Mc}', "");
Expect(0, 119154, '\P{__Mc}', "");
Expect(1, 119154, '\P{^__Mc}', "");
Expect(0, 119155, '\p{__Mc}', "");
Expect(1, 119155, '\p{^__Mc}', "");
Expect(1, 119155, '\P{__Mc}', "");
Expect(0, 119155, '\P{^__Mc}', "");
Error('\p{/a/Is_MC}');
Error('\P{/a/Is_MC}');
Expect(1, 119154, '\p{ismc}', "");
Expect(0, 119154, '\p{^ismc}', "");
Expect(0, 119154, '\P{ismc}', "");
Expect(1, 119154, '\P{^ismc}', "");
Expect(0, 119155, '\p{ismc}', "");
Expect(1, 119155, '\p{^ismc}', "");
Expect(1, 119155, '\P{ismc}', "");
Expect(0, 119155, '\P{^ismc}', "");
Expect(1, 119154, '\p{_is_Mc}', "");
Expect(0, 119154, '\p{^_is_Mc}', "");
Expect(0, 119154, '\P{_is_Mc}', "");
Expect(1, 119154, '\P{^_is_Mc}', "");
Expect(0, 119155, '\p{_is_Mc}', "");
Expect(1, 119155, '\p{^_is_Mc}', "");
Expect(1, 119155, '\P{_is_Mc}', "");
Expect(0, 119155, '\P{^_is_Mc}', "");
Error('\p{:=Spacing_Modifier_LETTERS}');
Error('\P{:=Spacing_Modifier_LETTERS}');
Expect(1, 767, '\p{spacingmodifierletters}', "");
Expect(0, 767, '\p{^spacingmodifierletters}', "");
Expect(0, 767, '\P{spacingmodifierletters}', "");
Expect(1, 767, '\P{^spacingmodifierletters}', "");
Expect(0, 768, '\p{spacingmodifierletters}', "");
Expect(1, 768, '\p{^spacingmodifierletters}', "");
Expect(1, 768, '\P{spacingmodifierletters}', "");
Expect(0, 768, '\P{^spacingmodifierletters}', "");
Expect(1, 767, '\p{_SPACING_MODIFIER_LETTERS}', "");
Expect(0, 767, '\p{^_SPACING_MODIFIER_LETTERS}', "");
Expect(0, 767, '\P{_SPACING_MODIFIER_LETTERS}', "");
Expect(1, 767, '\P{^_SPACING_MODIFIER_LETTERS}', "");
Expect(0, 768, '\p{_SPACING_MODIFIER_LETTERS}', "");
Expect(1, 768, '\p{^_SPACING_MODIFIER_LETTERS}', "");
Expect(1, 768, '\P{_SPACING_MODIFIER_LETTERS}', "");
Expect(0, 768, '\P{^_SPACING_MODIFIER_LETTERS}', "");
Error('\p{:=_is_Spacing_Modifier_Letters}');
Error('\P{:=_is_Spacing_Modifier_Letters}');
Expect(1, 767, '\p{isspacingmodifierletters}', "");
Expect(0, 767, '\p{^isspacingmodifierletters}', "");
Expect(0, 767, '\P{isspacingmodifierletters}', "");
Expect(1, 767, '\P{^isspacingmodifierletters}', "");
Expect(0, 768, '\p{isspacingmodifierletters}', "");
Expect(1, 768, '\p{^isspacingmodifierletters}', "");
Expect(1, 768, '\P{isspacingmodifierletters}', "");
Expect(0, 768, '\P{^isspacingmodifierletters}', "");
Expect(1, 767, '\p{_Is_Spacing_modifier_LETTERS}', "");
Expect(0, 767, '\p{^_Is_Spacing_modifier_LETTERS}', "");
Expect(0, 767, '\P{_Is_Spacing_modifier_LETTERS}', "");
Expect(1, 767, '\P{^_Is_Spacing_modifier_LETTERS}', "");
Expect(0, 768, '\p{_Is_Spacing_modifier_LETTERS}', "");
Expect(1, 768, '\p{^_Is_Spacing_modifier_LETTERS}', "");
Expect(1, 768, '\P{_Is_Spacing_modifier_LETTERS}', "");
Expect(0, 768, '\P{^_Is_Spacing_modifier_LETTERS}', "");
Error('\p{	/a/in_SPACING_MODIFIER_Letters}');
Error('\P{	/a/in_SPACING_MODIFIER_Letters}');
Expect(1, 767, '\p{inspacingmodifierletters}', "");
Expect(0, 767, '\p{^inspacingmodifierletters}', "");
Expect(0, 767, '\P{inspacingmodifierletters}', "");
Expect(1, 767, '\P{^inspacingmodifierletters}', "");
Expect(0, 768, '\p{inspacingmodifierletters}', "");
Expect(1, 768, '\p{^inspacingmodifierletters}', "");
Expect(1, 768, '\P{inspacingmodifierletters}', "");
Expect(0, 768, '\P{^inspacingmodifierletters}', "");
Expect(1, 767, '\p{ 	IN_Spacing_Modifier_Letters}', "");
Expect(0, 767, '\p{^ 	IN_Spacing_Modifier_Letters}', "");
Expect(0, 767, '\P{ 	IN_Spacing_Modifier_Letters}', "");
Expect(1, 767, '\P{^ 	IN_Spacing_Modifier_Letters}', "");
Expect(0, 768, '\p{ 	IN_Spacing_Modifier_Letters}', "");
Expect(1, 768, '\p{^ 	IN_Spacing_Modifier_Letters}', "");
Expect(1, 768, '\P{ 	IN_Spacing_Modifier_Letters}', "");
Expect(0, 768, '\P{^ 	IN_Spacing_Modifier_Letters}', "");
Error('\p{_/a/Modifier_LETTERS}');
Error('\P{_/a/Modifier_LETTERS}');
Expect(1, 767, '\p{modifierletters}', "");
Expect(0, 767, '\p{^modifierletters}', "");
Expect(0, 767, '\P{modifierletters}', "");
Expect(1, 767, '\P{^modifierletters}', "");
Expect(0, 768, '\p{modifierletters}', "");
Expect(1, 768, '\p{^modifierletters}', "");
Expect(1, 768, '\P{modifierletters}', "");
Expect(0, 768, '\P{^modifierletters}', "");
Expect(1, 767, '\p{	modifier_letters}', "");
Expect(0, 767, '\p{^	modifier_letters}', "");
Expect(0, 767, '\P{	modifier_letters}', "");
Expect(1, 767, '\P{^	modifier_letters}', "");
Expect(0, 768, '\p{	modifier_letters}', "");
Expect(1, 768, '\p{^	modifier_letters}', "");
Expect(1, 768, '\P{	modifier_letters}', "");
Expect(0, 768, '\P{^	modifier_letters}', "");
Error('\p{:=	 IS_MODIFIER_Letters}');
Error('\P{:=	 IS_MODIFIER_Letters}');
Expect(1, 767, '\p{ismodifierletters}', "");
Expect(0, 767, '\p{^ismodifierletters}', "");
Expect(0, 767, '\P{ismodifierletters}', "");
Expect(1, 767, '\P{^ismodifierletters}', "");
Expect(0, 768, '\p{ismodifierletters}', "");
Expect(1, 768, '\p{^ismodifierletters}', "");
Expect(1, 768, '\P{ismodifierletters}', "");
Expect(0, 768, '\P{^ismodifierletters}', "");
Expect(1, 767, '\p{	-Is_Modifier_Letters}', "");
Expect(0, 767, '\p{^	-Is_Modifier_Letters}', "");
Expect(0, 767, '\P{	-Is_Modifier_Letters}', "");
Expect(1, 767, '\P{^	-Is_Modifier_Letters}', "");
Expect(0, 768, '\p{	-Is_Modifier_Letters}', "");
Expect(1, 768, '\p{^	-Is_Modifier_Letters}', "");
Expect(1, 768, '\P{	-Is_Modifier_Letters}', "");
Expect(0, 768, '\P{^	-Is_Modifier_Letters}', "");
Error('\p{:=_In_Modifier_letters}');
Error('\P{:=_In_Modifier_letters}');
Expect(1, 767, '\p{inmodifierletters}', "");
Expect(0, 767, '\p{^inmodifierletters}', "");
Expect(0, 767, '\P{inmodifierletters}', "");
Expect(1, 767, '\P{^inmodifierletters}', "");
Expect(0, 768, '\p{inmodifierletters}', "");
Expect(1, 768, '\p{^inmodifierletters}', "");
Expect(1, 768, '\P{inmodifierletters}', "");
Expect(0, 768, '\P{^inmodifierletters}', "");
Expect(1, 767, '\p{ IN_Modifier_Letters}', "");
Expect(0, 767, '\p{^ IN_Modifier_Letters}', "");
Expect(0, 767, '\P{ IN_Modifier_Letters}', "");
Expect(1, 767, '\P{^ IN_Modifier_Letters}', "");
Expect(0, 768, '\p{ IN_Modifier_Letters}', "");
Expect(1, 768, '\p{^ IN_Modifier_Letters}', "");
Expect(1, 768, '\P{ IN_Modifier_Letters}', "");
Expect(0, 768, '\P{^ IN_Modifier_Letters}', "");
Error('\p{-	Specials/a/}');
Error('\P{-	Specials/a/}');
Expect(1, 65520, '\p{specials}', "");
Expect(0, 65520, '\p{^specials}', "");
Expect(0, 65520, '\P{specials}', "");
Expect(1, 65520, '\P{^specials}', "");
Expect(0, 65536, '\p{specials}', "");
Expect(1, 65536, '\p{^specials}', "");
Expect(1, 65536, '\P{specials}', "");
Expect(0, 65536, '\P{^specials}', "");
Error('\p{/a/	 Is_Specials}');
Error('\P{/a/	 Is_Specials}');
Expect(1, 65520, '\p{isspecials}', "");
Expect(0, 65520, '\p{^isspecials}', "");
Expect(0, 65520, '\P{isspecials}', "");
Expect(1, 65520, '\P{^isspecials}', "");
Expect(0, 65536, '\p{isspecials}', "");
Expect(1, 65536, '\p{^isspecials}', "");
Expect(1, 65536, '\P{isspecials}', "");
Expect(0, 65536, '\P{^isspecials}', "");
Expect(1, 65520, '\p{IS_SPECIALS}', "");
Expect(0, 65520, '\p{^IS_SPECIALS}', "");
Expect(0, 65520, '\P{IS_SPECIALS}', "");
Expect(1, 65520, '\P{^IS_SPECIALS}', "");
Expect(0, 65536, '\p{IS_SPECIALS}', "");
Expect(1, 65536, '\p{^IS_SPECIALS}', "");
Expect(1, 65536, '\P{IS_SPECIALS}', "");
Expect(0, 65536, '\P{^IS_SPECIALS}', "");
Error('\p{ :=In_Specials}');
Error('\P{ :=In_Specials}');
Expect(1, 65520, '\p{inspecials}', "");
Expect(0, 65520, '\p{^inspecials}', "");
Expect(0, 65520, '\P{inspecials}', "");
Expect(1, 65520, '\P{^inspecials}', "");
Expect(0, 65536, '\p{inspecials}', "");
Expect(1, 65536, '\p{^inspecials}', "");
Expect(1, 65536, '\P{inspecials}', "");
Expect(0, 65536, '\P{^inspecials}', "");
Expect(1, 65520, '\p{- in_Specials}', "");
Expect(0, 65520, '\p{^- in_Specials}', "");
Expect(0, 65520, '\P{- in_Specials}', "");
Expect(1, 65520, '\P{^- in_Specials}', "");
Expect(0, 65536, '\p{- in_Specials}', "");
Expect(1, 65536, '\p{^- in_Specials}', "");
Expect(1, 65536, '\P{- in_Specials}', "");
Expect(0, 65536, '\P{^- in_Specials}', "");
Error('\p{-:=Sundanese}');
Error('\P{-:=Sundanese}');
Expect(1, 7367, '\p{sundanese}', "");
Expect(0, 7367, '\p{^sundanese}', "");
Expect(0, 7367, '\P{sundanese}', "");
Expect(1, 7367, '\P{^sundanese}', "");
Expect(0, 7368, '\p{sundanese}', "");
Expect(1, 7368, '\p{^sundanese}', "");
Expect(1, 7368, '\P{sundanese}', "");
Expect(0, 7368, '\P{^sundanese}', "");
Expect(1, 7367, '\p{__SUNDANESE}', "");
Expect(0, 7367, '\p{^__SUNDANESE}', "");
Expect(0, 7367, '\P{__SUNDANESE}', "");
Expect(1, 7367, '\P{^__SUNDANESE}', "");
Expect(0, 7368, '\p{__SUNDANESE}', "");
Expect(1, 7368, '\p{^__SUNDANESE}', "");
Expect(1, 7368, '\P{__SUNDANESE}', "");
Expect(0, 7368, '\P{^__SUNDANESE}', "");
Error('\p{:=is_SUNDANESE}');
Error('\P{:=is_SUNDANESE}');
Expect(1, 7367, '\p{issundanese}', "");
Expect(0, 7367, '\p{^issundanese}', "");
Expect(0, 7367, '\P{issundanese}', "");
Expect(1, 7367, '\P{^issundanese}', "");
Expect(0, 7368, '\p{issundanese}', "");
Expect(1, 7368, '\p{^issundanese}', "");
Expect(1, 7368, '\P{issundanese}', "");
Expect(0, 7368, '\P{^issundanese}', "");
Expect(1, 7367, '\p{	 IS_sundanese}', "");
Expect(0, 7367, '\p{^	 IS_sundanese}', "");
Expect(0, 7367, '\P{	 IS_sundanese}', "");
Expect(1, 7367, '\P{^	 IS_sundanese}', "");
Expect(0, 7368, '\p{	 IS_sundanese}', "");
Expect(1, 7368, '\p{^	 IS_sundanese}', "");
Expect(1, 7368, '\P{	 IS_sundanese}', "");
Expect(0, 7368, '\P{^	 IS_sundanese}', "");
Error('\p{_Sund:=}');
Error('\P{_Sund:=}');
Expect(1, 7367, '\p{sund}', "");
Expect(0, 7367, '\p{^sund}', "");
Expect(0, 7367, '\P{sund}', "");
Expect(1, 7367, '\P{^sund}', "");
Expect(0, 7368, '\p{sund}', "");
Expect(1, 7368, '\p{^sund}', "");
Expect(1, 7368, '\P{sund}', "");
Expect(0, 7368, '\P{^sund}', "");
Expect(1, 7367, '\p{-	Sund}', "");
Expect(0, 7367, '\p{^-	Sund}', "");
Expect(0, 7367, '\P{-	Sund}', "");
Expect(1, 7367, '\P{^-	Sund}', "");
Expect(0, 7368, '\p{-	Sund}', "");
Expect(1, 7368, '\p{^-	Sund}', "");
Expect(1, 7368, '\P{-	Sund}', "");
Expect(0, 7368, '\P{^-	Sund}', "");
Error('\p{-/a/IS_Sund}');
Error('\P{-/a/IS_Sund}');
Expect(1, 7367, '\p{issund}', "");
Expect(0, 7367, '\p{^issund}', "");
Expect(0, 7367, '\P{issund}', "");
Expect(1, 7367, '\P{^issund}', "");
Expect(0, 7368, '\p{issund}', "");
Expect(1, 7368, '\p{^issund}', "");
Expect(1, 7368, '\P{issund}', "");
Expect(0, 7368, '\P{^issund}', "");
Expect(1, 7367, '\p{-_Is_Sund}', "");
Expect(0, 7367, '\p{^-_Is_Sund}', "");
Expect(0, 7367, '\P{-_Is_Sund}', "");
Expect(1, 7367, '\P{^-_Is_Sund}', "");
Expect(0, 7368, '\p{-_Is_Sund}', "");
Expect(1, 7368, '\p{^-_Is_Sund}', "");
Expect(1, 7368, '\P{-_Is_Sund}', "");
Expect(0, 7368, '\P{^-_Is_Sund}', "");
Error('\p{	SUNDANESE_Supplement/a/}');
Error('\P{	SUNDANESE_Supplement/a/}');
Expect(1, 7375, '\p{sundanesesupplement}', "");
Expect(0, 7375, '\p{^sundanesesupplement}', "");
Expect(0, 7375, '\P{sundanesesupplement}', "");
Expect(1, 7375, '\P{^sundanesesupplement}', "");
Expect(0, 7376, '\p{sundanesesupplement}', "");
Expect(1, 7376, '\p{^sundanesesupplement}', "");
Expect(1, 7376, '\P{sundanesesupplement}', "");
Expect(0, 7376, '\P{^sundanesesupplement}', "");
Expect(1, 7375, '\p{ Sundanese_supplement}', "");
Expect(0, 7375, '\p{^ Sundanese_supplement}', "");
Expect(0, 7375, '\P{ Sundanese_supplement}', "");
Expect(1, 7375, '\P{^ Sundanese_supplement}', "");
Expect(0, 7376, '\p{ Sundanese_supplement}', "");
Expect(1, 7376, '\p{^ Sundanese_supplement}', "");
Expect(1, 7376, '\P{ Sundanese_supplement}', "");
Expect(0, 7376, '\P{^ Sundanese_supplement}', "");
Error('\p{ 	is_SUNDANESE_supplement:=}');
Error('\P{ 	is_SUNDANESE_supplement:=}');
Expect(1, 7375, '\p{issundanesesupplement}', "");
Expect(0, 7375, '\p{^issundanesesupplement}', "");
Expect(0, 7375, '\P{issundanesesupplement}', "");
Expect(1, 7375, '\P{^issundanesesupplement}', "");
Expect(0, 7376, '\p{issundanesesupplement}', "");
Expect(1, 7376, '\p{^issundanesesupplement}', "");
Expect(1, 7376, '\P{issundanesesupplement}', "");
Expect(0, 7376, '\P{^issundanesesupplement}', "");
Expect(1, 7375, '\p{ IS_sundanese_supplement}', "");
Expect(0, 7375, '\p{^ IS_sundanese_supplement}', "");
Expect(0, 7375, '\P{ IS_sundanese_supplement}', "");
Expect(1, 7375, '\P{^ IS_sundanese_supplement}', "");
Expect(0, 7376, '\p{ IS_sundanese_supplement}', "");
Expect(1, 7376, '\p{^ IS_sundanese_supplement}', "");
Expect(1, 7376, '\P{ IS_sundanese_supplement}', "");
Expect(0, 7376, '\P{^ IS_sundanese_supplement}', "");
Error('\p{_IN_SUNDANESE_SUPPLEMENT/a/}');
Error('\P{_IN_SUNDANESE_SUPPLEMENT/a/}');
Expect(1, 7375, '\p{insundanesesupplement}', "");
Expect(0, 7375, '\p{^insundanesesupplement}', "");
Expect(0, 7375, '\P{insundanesesupplement}', "");
Expect(1, 7375, '\P{^insundanesesupplement}', "");
Expect(0, 7376, '\p{insundanesesupplement}', "");
Expect(1, 7376, '\p{^insundanesesupplement}', "");
Expect(1, 7376, '\P{insundanesesupplement}', "");
Expect(0, 7376, '\P{^insundanesesupplement}', "");
Expect(1, 7375, '\p{-IN_Sundanese_supplement}', "");
Expect(0, 7375, '\p{^-IN_Sundanese_supplement}', "");
Expect(0, 7375, '\P{-IN_Sundanese_supplement}', "");
Expect(1, 7375, '\P{^-IN_Sundanese_supplement}', "");
Expect(0, 7376, '\p{-IN_Sundanese_supplement}', "");
Expect(1, 7376, '\p{^-IN_Sundanese_supplement}', "");
Expect(1, 7376, '\P{-IN_Sundanese_supplement}', "");
Expect(0, 7376, '\P{^-IN_Sundanese_supplement}', "");
Error('\p{:= Sundanese_Sup}');
Error('\P{:= Sundanese_Sup}');
Expect(1, 7375, '\p{sundanesesup}', "");
Expect(0, 7375, '\p{^sundanesesup}', "");
Expect(0, 7375, '\P{sundanesesup}', "");
Expect(1, 7375, '\P{^sundanesesup}', "");
Expect(0, 7376, '\p{sundanesesup}', "");
Expect(1, 7376, '\p{^sundanesesup}', "");
Expect(1, 7376, '\P{sundanesesup}', "");
Expect(0, 7376, '\P{^sundanesesup}', "");
Expect(1, 7375, '\p{	-SUNDANESE_Sup}', "");
Expect(0, 7375, '\p{^	-SUNDANESE_Sup}', "");
Expect(0, 7375, '\P{	-SUNDANESE_Sup}', "");
Expect(1, 7375, '\P{^	-SUNDANESE_Sup}', "");
Expect(0, 7376, '\p{	-SUNDANESE_Sup}', "");
Expect(1, 7376, '\p{^	-SUNDANESE_Sup}', "");
Expect(1, 7376, '\P{	-SUNDANESE_Sup}', "");
Expect(0, 7376, '\P{^	-SUNDANESE_Sup}', "");
Error('\p{/a/_IS_Sundanese_Sup}');
Error('\P{/a/_IS_Sundanese_Sup}');
Expect(1, 7375, '\p{issundanesesup}', "");
Expect(0, 7375, '\p{^issundanesesup}', "");
Expect(0, 7375, '\P{issundanesesup}', "");
Expect(1, 7375, '\P{^issundanesesup}', "");
Expect(0, 7376, '\p{issundanesesup}', "");
Expect(1, 7376, '\p{^issundanesesup}', "");
Expect(1, 7376, '\P{issundanesesup}', "");
Expect(0, 7376, '\P{^issundanesesup}', "");
Expect(1, 7375, '\p{	-IS_sundanese_SUP}', "");
Expect(0, 7375, '\p{^	-IS_sundanese_SUP}', "");
Expect(0, 7375, '\P{	-IS_sundanese_SUP}', "");
Expect(1, 7375, '\P{^	-IS_sundanese_SUP}', "");
Expect(0, 7376, '\p{	-IS_sundanese_SUP}', "");
Expect(1, 7376, '\p{^	-IS_sundanese_SUP}', "");
Expect(1, 7376, '\P{	-IS_sundanese_SUP}', "");
Expect(0, 7376, '\P{^	-IS_sundanese_SUP}', "");
Error('\p{/a/-In_sundanese_SUP}');
Error('\P{/a/-In_sundanese_SUP}');
Expect(1, 7375, '\p{insundanesesup}', "");
Expect(0, 7375, '\p{^insundanesesup}', "");
Expect(0, 7375, '\P{insundanesesup}', "");
Expect(1, 7375, '\P{^insundanesesup}', "");
Expect(0, 7376, '\p{insundanesesup}', "");
Expect(1, 7376, '\p{^insundanesesup}', "");
Expect(1, 7376, '\P{insundanesesup}', "");
Expect(0, 7376, '\P{^insundanesesup}', "");
Expect(1, 7375, '\p{ -IN_sundanese_SUP}', "");
Expect(0, 7375, '\p{^ -IN_sundanese_SUP}', "");
Expect(0, 7375, '\P{ -IN_sundanese_SUP}', "");
Expect(1, 7375, '\P{^ -IN_sundanese_SUP}', "");
Expect(0, 7376, '\p{ -IN_sundanese_SUP}', "");
Expect(1, 7376, '\p{^ -IN_sundanese_SUP}', "");
Expect(1, 7376, '\P{ -IN_sundanese_SUP}', "");
Expect(0, 7376, '\P{^ -IN_sundanese_SUP}', "");
Error('\p{	_SUPERSCRIPTS_AND_Subscripts:=}');
Error('\P{	_SUPERSCRIPTS_AND_Subscripts:=}');
Expect(1, 8351, '\p{superscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^superscriptsandsubscripts}', "");
Expect(0, 8351, '\P{superscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^superscriptsandsubscripts}', "");
Expect(0, 8352, '\p{superscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^superscriptsandsubscripts}', "");
Expect(1, 8352, '\P{superscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^superscriptsandsubscripts}', "");
Expect(1, 8351, '\p{	-Superscripts_AND_Subscripts}', "");
Expect(0, 8351, '\p{^	-Superscripts_AND_Subscripts}', "");
Expect(0, 8351, '\P{	-Superscripts_AND_Subscripts}', "");
Expect(1, 8351, '\P{^	-Superscripts_AND_Subscripts}', "");
Expect(0, 8352, '\p{	-Superscripts_AND_Subscripts}', "");
Expect(1, 8352, '\p{^	-Superscripts_AND_Subscripts}', "");
Expect(1, 8352, '\P{	-Superscripts_AND_Subscripts}', "");
Expect(0, 8352, '\P{^	-Superscripts_AND_Subscripts}', "");
Error('\p{/a/	IS_Superscripts_And_subscripts}');
Error('\P{/a/	IS_Superscripts_And_subscripts}');
Expect(1, 8351, '\p{issuperscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^issuperscriptsandsubscripts}', "");
Expect(0, 8351, '\P{issuperscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^issuperscriptsandsubscripts}', "");
Expect(0, 8352, '\p{issuperscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^issuperscriptsandsubscripts}', "");
Expect(1, 8352, '\P{issuperscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^issuperscriptsandsubscripts}', "");
Expect(1, 8351, '\p{- Is_Superscripts_and_subscripts}', "");
Expect(0, 8351, '\p{^- Is_Superscripts_and_subscripts}', "");
Expect(0, 8351, '\P{- Is_Superscripts_and_subscripts}', "");
Expect(1, 8351, '\P{^- Is_Superscripts_and_subscripts}', "");
Expect(0, 8352, '\p{- Is_Superscripts_and_subscripts}', "");
Expect(1, 8352, '\p{^- Is_Superscripts_and_subscripts}', "");
Expect(1, 8352, '\P{- Is_Superscripts_and_subscripts}', "");
Expect(0, 8352, '\P{^- Is_Superscripts_and_subscripts}', "");
Error('\p{/a/ IN_superscripts_AND_Subscripts}');
Error('\P{/a/ IN_superscripts_AND_Subscripts}');
Expect(1, 8351, '\p{insuperscriptsandsubscripts}', "");
Expect(0, 8351, '\p{^insuperscriptsandsubscripts}', "");
Expect(0, 8351, '\P{insuperscriptsandsubscripts}', "");
Expect(1, 8351, '\P{^insuperscriptsandsubscripts}', "");
Expect(0, 8352, '\p{insuperscriptsandsubscripts}', "");
Expect(1, 8352, '\p{^insuperscriptsandsubscripts}', "");
Expect(1, 8352, '\P{insuperscriptsandsubscripts}', "");
Expect(0, 8352, '\P{^insuperscriptsandsubscripts}', "");
Expect(1, 8351, '\p{		In_Superscripts_And_Subscripts}', "");
Expect(0, 8351, '\p{^		In_Superscripts_And_Subscripts}', "");
Expect(0, 8351, '\P{		In_Superscripts_And_Subscripts}', "");
Expect(1, 8351, '\P{^		In_Superscripts_And_Subscripts}', "");
Expect(0, 8352, '\p{		In_Superscripts_And_Subscripts}', "");
Expect(1, 8352, '\p{^		In_Superscripts_And_Subscripts}', "");
Expect(1, 8352, '\P{		In_Superscripts_And_Subscripts}', "");
Expect(0, 8352, '\P{^		In_Superscripts_And_Subscripts}', "");
Error('\p{- super_And_SUB:=}');
Error('\P{- super_And_SUB:=}');
Expect(1, 8351, '\p{superandsub}', "");
Expect(0, 8351, '\p{^superandsub}', "");
Expect(0, 8351, '\P{superandsub}', "");
Expect(1, 8351, '\P{^superandsub}', "");
Expect(0, 8352, '\p{superandsub}', "");
Expect(1, 8352, '\p{^superandsub}', "");
Expect(1, 8352, '\P{superandsub}', "");
Expect(0, 8352, '\P{^superandsub}', "");
Expect(1, 8351, '\p{	_Super_And_Sub}', "");
Expect(0, 8351, '\p{^	_Super_And_Sub}', "");
Expect(0, 8351, '\P{	_Super_And_Sub}', "");
Expect(1, 8351, '\P{^	_Super_And_Sub}', "");
Expect(0, 8352, '\p{	_Super_And_Sub}', "");
Expect(1, 8352, '\p{^	_Super_And_Sub}', "");
Expect(1, 8352, '\P{	_Super_And_Sub}', "");
Expect(0, 8352, '\P{^	_Super_And_Sub}', "");
Error('\p{:=  Is_Super_AND_Sub}');
Error('\P{:=  Is_Super_AND_Sub}');
Expect(1, 8351, '\p{issuperandsub}', "");
Expect(0, 8351, '\p{^issuperandsub}', "");
Expect(0, 8351, '\P{issuperandsub}', "");
Expect(1, 8351, '\P{^issuperandsub}', "");
Expect(0, 8352, '\p{issuperandsub}', "");
Expect(1, 8352, '\p{^issuperandsub}', "");
Expect(1, 8352, '\P{issuperandsub}', "");
Expect(0, 8352, '\P{^issuperandsub}', "");
Expect(1, 8351, '\p{-	Is_Super_And_Sub}', "");
Expect(0, 8351, '\p{^-	Is_Super_And_Sub}', "");
Expect(0, 8351, '\P{-	Is_Super_And_Sub}', "");
Expect(1, 8351, '\P{^-	Is_Super_And_Sub}', "");
Expect(0, 8352, '\p{-	Is_Super_And_Sub}', "");
Expect(1, 8352, '\p{^-	Is_Super_And_Sub}', "");
Expect(1, 8352, '\P{-	Is_Super_And_Sub}', "");
Expect(0, 8352, '\P{^-	Is_Super_And_Sub}', "");
Error('\p{ in_super_and_Sub:=}');
Error('\P{ in_super_and_Sub:=}');
Expect(1, 8351, '\p{insuperandsub}', "");
Expect(0, 8351, '\p{^insuperandsub}', "");
Expect(0, 8351, '\P{insuperandsub}', "");
Expect(1, 8351, '\P{^insuperandsub}', "");
Expect(0, 8352, '\p{insuperandsub}', "");
Expect(1, 8352, '\p{^insuperandsub}', "");
Expect(1, 8352, '\P{insuperandsub}', "");
Expect(0, 8352, '\P{^insuperandsub}', "");
Expect(1, 8351, '\p{ 	In_Super_and_sub}', "");
Expect(0, 8351, '\p{^ 	In_Super_and_sub}', "");
Expect(0, 8351, '\P{ 	In_Super_and_sub}', "");
Expect(1, 8351, '\P{^ 	In_Super_and_sub}', "");
Expect(0, 8352, '\p{ 	In_Super_and_sub}', "");
Expect(1, 8352, '\p{^ 	In_Super_and_sub}', "");
Expect(1, 8352, '\P{ 	In_Super_and_sub}', "");
Expect(0, 8352, '\P{^ 	In_Super_and_sub}', "");
Error('\p{ Supplemental_Arrows_a:=}');
Error('\P{ Supplemental_Arrows_a:=}');
Expect(1, 10239, '\p{supplementalarrowsa}', "");
Expect(0, 10239, '\p{^supplementalarrowsa}', "");
Expect(0, 10239, '\P{supplementalarrowsa}', "");
Expect(1, 10239, '\P{^supplementalarrowsa}', "");
Expect(0, 10240, '\p{supplementalarrowsa}', "");
Expect(1, 10240, '\p{^supplementalarrowsa}', "");
Expect(1, 10240, '\P{supplementalarrowsa}', "");
Expect(0, 10240, '\P{^supplementalarrowsa}', "");
Expect(1, 10239, '\p{ _Supplemental_Arrows_A}', "");
Expect(0, 10239, '\p{^ _Supplemental_Arrows_A}', "");
Expect(0, 10239, '\P{ _Supplemental_Arrows_A}', "");
Expect(1, 10239, '\P{^ _Supplemental_Arrows_A}', "");
Expect(0, 10240, '\p{ _Supplemental_Arrows_A}', "");
Expect(1, 10240, '\p{^ _Supplemental_Arrows_A}', "");
Expect(1, 10240, '\P{ _Supplemental_Arrows_A}', "");
Expect(0, 10240, '\P{^ _Supplemental_Arrows_A}', "");
Error('\p{:=  Is_Supplemental_arrows_A}');
Error('\P{:=  Is_Supplemental_arrows_A}');
Expect(1, 10239, '\p{issupplementalarrowsa}', "");
Expect(0, 10239, '\p{^issupplementalarrowsa}', "");
Expect(0, 10239, '\P{issupplementalarrowsa}', "");
Expect(1, 10239, '\P{^issupplementalarrowsa}', "");
Expect(0, 10240, '\p{issupplementalarrowsa}', "");
Expect(1, 10240, '\p{^issupplementalarrowsa}', "");
Expect(1, 10240, '\P{issupplementalarrowsa}', "");
Expect(0, 10240, '\P{^issupplementalarrowsa}', "");
Expect(1, 10239, '\p{		is_Supplemental_arrows_a}', "");
Expect(0, 10239, '\p{^		is_Supplemental_arrows_a}', "");
Expect(0, 10239, '\P{		is_Supplemental_arrows_a}', "");
Expect(1, 10239, '\P{^		is_Supplemental_arrows_a}', "");
Expect(0, 10240, '\p{		is_Supplemental_arrows_a}', "");
Expect(1, 10240, '\p{^		is_Supplemental_arrows_a}', "");
Expect(1, 10240, '\P{		is_Supplemental_arrows_a}', "");
Expect(0, 10240, '\P{^		is_Supplemental_arrows_a}', "");
Error('\p{_-IN_Supplemental_arrows_A/a/}');
Error('\P{_-IN_Supplemental_arrows_A/a/}');
Expect(1, 10239, '\p{insupplementalarrowsa}', "");
Expect(0, 10239, '\p{^insupplementalarrowsa}', "");
Expect(0, 10239, '\P{insupplementalarrowsa}', "");
Expect(1, 10239, '\P{^insupplementalarrowsa}', "");
Expect(0, 10240, '\p{insupplementalarrowsa}', "");
Expect(1, 10240, '\p{^insupplementalarrowsa}', "");
Expect(1, 10240, '\P{insupplementalarrowsa}', "");
Expect(0, 10240, '\P{^insupplementalarrowsa}', "");
Expect(1, 10239, '\p{ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(0, 10239, '\p{^ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(0, 10239, '\P{ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(1, 10239, '\P{^ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(0, 10240, '\p{ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(1, 10240, '\p{^ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(1, 10240, '\P{ 	In_SUPPLEMENTAL_arrows_A}', "");
Expect(0, 10240, '\P{^ 	In_SUPPLEMENTAL_arrows_A}', "");
Error('\p{/a/sup_Arrows_A}');
Error('\P{/a/sup_Arrows_A}');
Expect(1, 10239, '\p{suparrowsa}', "");
Expect(0, 10239, '\p{^suparrowsa}', "");
Expect(0, 10239, '\P{suparrowsa}', "");
Expect(1, 10239, '\P{^suparrowsa}', "");
Expect(0, 10240, '\p{suparrowsa}', "");
Expect(1, 10240, '\p{^suparrowsa}', "");
Expect(1, 10240, '\P{suparrowsa}', "");
Expect(0, 10240, '\P{^suparrowsa}', "");
Expect(1, 10239, '\p{_SUP_Arrows_A}', "");
Expect(0, 10239, '\p{^_SUP_Arrows_A}', "");
Expect(0, 10239, '\P{_SUP_Arrows_A}', "");
Expect(1, 10239, '\P{^_SUP_Arrows_A}', "");
Expect(0, 10240, '\p{_SUP_Arrows_A}', "");
Expect(1, 10240, '\p{^_SUP_Arrows_A}', "");
Expect(1, 10240, '\P{_SUP_Arrows_A}', "");
Expect(0, 10240, '\P{^_SUP_Arrows_A}', "");
Error('\p{:=IS_Sup_Arrows_A}');
Error('\P{:=IS_Sup_Arrows_A}');
Expect(1, 10239, '\p{issuparrowsa}', "");
Expect(0, 10239, '\p{^issuparrowsa}', "");
Expect(0, 10239, '\P{issuparrowsa}', "");
Expect(1, 10239, '\P{^issuparrowsa}', "");
Expect(0, 10240, '\p{issuparrowsa}', "");
Expect(1, 10240, '\p{^issuparrowsa}', "");
Expect(1, 10240, '\P{issuparrowsa}', "");
Expect(0, 10240, '\P{^issuparrowsa}', "");
Expect(1, 10239, '\p{_Is_SUP_Arrows_A}', "");
Expect(0, 10239, '\p{^_Is_SUP_Arrows_A}', "");
Expect(0, 10239, '\P{_Is_SUP_Arrows_A}', "");
Expect(1, 10239, '\P{^_Is_SUP_Arrows_A}', "");
Expect(0, 10240, '\p{_Is_SUP_Arrows_A}', "");
Expect(1, 10240, '\p{^_Is_SUP_Arrows_A}', "");
Expect(1, 10240, '\P{_Is_SUP_Arrows_A}', "");
Expect(0, 10240, '\P{^_Is_SUP_Arrows_A}', "");
Error('\p{-IN_Sup_Arrows_A:=}');
Error('\P{-IN_Sup_Arrows_A:=}');
Expect(1, 10239, '\p{insuparrowsa}', "");
Expect(0, 10239, '\p{^insuparrowsa}', "");
Expect(0, 10239, '\P{insuparrowsa}', "");
Expect(1, 10239, '\P{^insuparrowsa}', "");
Expect(0, 10240, '\p{insuparrowsa}', "");
Expect(1, 10240, '\p{^insuparrowsa}', "");
Expect(1, 10240, '\P{insuparrowsa}', "");
Expect(0, 10240, '\P{^insuparrowsa}', "");
Expect(1, 10239, '\p{	_In_sup_Arrows_A}', "");
Expect(0, 10239, '\p{^	_In_sup_Arrows_A}', "");
Expect(0, 10239, '\P{	_In_sup_Arrows_A}', "");
Expect(1, 10239, '\P{^	_In_sup_Arrows_A}', "");
Expect(0, 10240, '\p{	_In_sup_Arrows_A}', "");
Expect(1, 10240, '\p{^	_In_sup_Arrows_A}', "");
Expect(1, 10240, '\P{	_In_sup_Arrows_A}', "");
Expect(0, 10240, '\P{^	_In_sup_Arrows_A}', "");
Error('\p{:= -supplemental_arrows_B}');
Error('\P{:= -supplemental_arrows_B}');
Expect(1, 10623, '\p{supplementalarrowsb}', "");
Expect(0, 10623, '\p{^supplementalarrowsb}', "");
Expect(0, 10623, '\P{supplementalarrowsb}', "");
Expect(1, 10623, '\P{^supplementalarrowsb}', "");
Expect(0, 10624, '\p{supplementalarrowsb}', "");
Expect(1, 10624, '\p{^supplementalarrowsb}', "");
Expect(1, 10624, '\P{supplementalarrowsb}', "");
Expect(0, 10624, '\P{^supplementalarrowsb}', "");
Expect(1, 10623, '\p{ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10623, '\p{^ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10623, '\P{ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(1, 10623, '\P{^ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10624, '\p{ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(1, 10624, '\p{^ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(1, 10624, '\P{ 	SUPPLEMENTAL_Arrows_B}', "");
Expect(0, 10624, '\P{^ 	SUPPLEMENTAL_Arrows_B}', "");
Error('\p{_-IS_Supplemental_arrows_b/a/}');
Error('\P{_-IS_Supplemental_arrows_b/a/}');
Expect(1, 10623, '\p{issupplementalarrowsb}', "");
Expect(0, 10623, '\p{^issupplementalarrowsb}', "");
Expect(0, 10623, '\P{issupplementalarrowsb}', "");
Expect(1, 10623, '\P{^issupplementalarrowsb}', "");
Expect(0, 10624, '\p{issupplementalarrowsb}', "");
Expect(1, 10624, '\p{^issupplementalarrowsb}', "");
Expect(1, 10624, '\P{issupplementalarrowsb}', "");
Expect(0, 10624, '\P{^issupplementalarrowsb}', "");
Expect(1, 10623, '\p{_	is_Supplemental_ARROWS_b}', "");
Expect(0, 10623, '\p{^_	is_Supplemental_ARROWS_b}', "");
Expect(0, 10623, '\P{_	is_Supplemental_ARROWS_b}', "");
Expect(1, 10623, '\P{^_	is_Supplemental_ARROWS_b}', "");
Expect(0, 10624, '\p{_	is_Supplemental_ARROWS_b}', "");
Expect(1, 10624, '\p{^_	is_Supplemental_ARROWS_b}', "");
Expect(1, 10624, '\P{_	is_Supplemental_ARROWS_b}', "");
Expect(0, 10624, '\P{^_	is_Supplemental_ARROWS_b}', "");
Error('\p{:=In_supplemental_ARROWS_B}');
Error('\P{:=In_supplemental_ARROWS_B}');
Expect(1, 10623, '\p{insupplementalarrowsb}', "");
Expect(0, 10623, '\p{^insupplementalarrowsb}', "");
Expect(0, 10623, '\P{insupplementalarrowsb}', "");
Expect(1, 10623, '\P{^insupplementalarrowsb}', "");
Expect(0, 10624, '\p{insupplementalarrowsb}', "");
Expect(1, 10624, '\p{^insupplementalarrowsb}', "");
Expect(1, 10624, '\P{insupplementalarrowsb}', "");
Expect(0, 10624, '\P{^insupplementalarrowsb}', "");
Expect(1, 10623, '\p{ in_supplemental_ARROWS_B}', "");
Expect(0, 10623, '\p{^ in_supplemental_ARROWS_B}', "");
Expect(0, 10623, '\P{ in_supplemental_ARROWS_B}', "");
Expect(1, 10623, '\P{^ in_supplemental_ARROWS_B}', "");
Expect(0, 10624, '\p{ in_supplemental_ARROWS_B}', "");
Expect(1, 10624, '\p{^ in_supplemental_ARROWS_B}', "");
Expect(1, 10624, '\P{ in_supplemental_ARROWS_B}', "");
Expect(0, 10624, '\P{^ in_supplemental_ARROWS_B}', "");
Error('\p{:=_-SUP_Arrows_B}');
Error('\P{:=_-SUP_Arrows_B}');
Expect(1, 10623, '\p{suparrowsb}', "");
Expect(0, 10623, '\p{^suparrowsb}', "");
Expect(0, 10623, '\P{suparrowsb}', "");
Expect(1, 10623, '\P{^suparrowsb}', "");
Expect(0, 10624, '\p{suparrowsb}', "");
Expect(1, 10624, '\p{^suparrowsb}', "");
Expect(1, 10624, '\P{suparrowsb}', "");
Expect(0, 10624, '\P{^suparrowsb}', "");
Expect(1, 10623, '\p{ Sup_Arrows_B}', "");
Expect(0, 10623, '\p{^ Sup_Arrows_B}', "");
Expect(0, 10623, '\P{ Sup_Arrows_B}', "");
Expect(1, 10623, '\P{^ Sup_Arrows_B}', "");
Expect(0, 10624, '\p{ Sup_Arrows_B}', "");
Expect(1, 10624, '\p{^ Sup_Arrows_B}', "");
Expect(1, 10624, '\P{ Sup_Arrows_B}', "");
Expect(0, 10624, '\P{^ Sup_Arrows_B}', "");
Error('\p{__is_Sup_arrows_B/a/}');
Error('\P{__is_Sup_arrows_B/a/}');
Expect(1, 10623, '\p{issuparrowsb}', "");
Expect(0, 10623, '\p{^issuparrowsb}', "");
Expect(0, 10623, '\P{issuparrowsb}', "");
Expect(1, 10623, '\P{^issuparrowsb}', "");
Expect(0, 10624, '\p{issuparrowsb}', "");
Expect(1, 10624, '\p{^issuparrowsb}', "");
Expect(1, 10624, '\P{issuparrowsb}', "");
Expect(0, 10624, '\P{^issuparrowsb}', "");
Expect(1, 10623, '\p{ Is_SUP_Arrows_b}', "");
Expect(0, 10623, '\p{^ Is_SUP_Arrows_b}', "");
Expect(0, 10623, '\P{ Is_SUP_Arrows_b}', "");
Expect(1, 10623, '\P{^ Is_SUP_Arrows_b}', "");
Expect(0, 10624, '\p{ Is_SUP_Arrows_b}', "");
Expect(1, 10624, '\p{^ Is_SUP_Arrows_b}', "");
Expect(1, 10624, '\P{ Is_SUP_Arrows_b}', "");
Expect(0, 10624, '\P{^ Is_SUP_Arrows_b}', "");
Error('\p{_in_SUP_Arrows_b/a/}');
Error('\P{_in_SUP_Arrows_b/a/}');
Expect(1, 10623, '\p{insuparrowsb}', "");
Expect(0, 10623, '\p{^insuparrowsb}', "");
Expect(0, 10623, '\P{insuparrowsb}', "");
Expect(1, 10623, '\P{^insuparrowsb}', "");
Expect(0, 10624, '\p{insuparrowsb}', "");
Expect(1, 10624, '\p{^insuparrowsb}', "");
Expect(1, 10624, '\P{insuparrowsb}', "");
Expect(0, 10624, '\P{^insuparrowsb}', "");
Expect(1, 10623, '\p{	_IN_sup_Arrows_B}', "");
Expect(0, 10623, '\p{^	_IN_sup_Arrows_B}', "");
Expect(0, 10623, '\P{	_IN_sup_Arrows_B}', "");
Expect(1, 10623, '\P{^	_IN_sup_Arrows_B}', "");
Expect(0, 10624, '\p{	_IN_sup_Arrows_B}', "");
Expect(1, 10624, '\p{^	_IN_sup_Arrows_B}', "");
Expect(1, 10624, '\P{	_IN_sup_Arrows_B}', "");
Expect(0, 10624, '\P{^	_IN_sup_Arrows_B}', "");
Error('\p{:=Supplemental_Mathematical_Operators}');
Error('\P{:=Supplemental_Mathematical_Operators}');
Expect(1, 11007, '\p{supplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^supplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{supplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^supplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{supplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^supplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{supplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^supplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(0, 11007, '\p{^ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(0, 11007, '\P{ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(1, 11007, '\P{^ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(0, 11008, '\p{ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(1, 11008, '\p{^ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(1, 11008, '\P{ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Expect(0, 11008, '\P{^ 	SUPPLEMENTAL_MATHEMATICAL_Operators}', "");
Error('\p{:=	Is_Supplemental_Mathematical_Operators}');
Error('\P{:=	Is_Supplemental_Mathematical_Operators}');
Expect(1, 11007, '\p{issupplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^issupplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{issupplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^issupplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{issupplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^issupplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{issupplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^issupplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{--Is_Supplemental_Mathematical_Operators}', "");
Expect(0, 11007, '\p{^--Is_Supplemental_Mathematical_Operators}', "");
Expect(0, 11007, '\P{--Is_Supplemental_Mathematical_Operators}', "");
Expect(1, 11007, '\P{^--Is_Supplemental_Mathematical_Operators}', "");
Expect(0, 11008, '\p{--Is_Supplemental_Mathematical_Operators}', "");
Expect(1, 11008, '\p{^--Is_Supplemental_Mathematical_Operators}', "");
Expect(1, 11008, '\P{--Is_Supplemental_Mathematical_Operators}', "");
Expect(0, 11008, '\P{^--Is_Supplemental_Mathematical_Operators}', "");
Error('\p{ 	IN_Supplemental_Mathematical_Operators/a/}');
Error('\P{ 	IN_Supplemental_Mathematical_Operators/a/}');
Expect(1, 11007, '\p{insupplementalmathematicaloperators}', "");
Expect(0, 11007, '\p{^insupplementalmathematicaloperators}', "");
Expect(0, 11007, '\P{insupplementalmathematicaloperators}', "");
Expect(1, 11007, '\P{^insupplementalmathematicaloperators}', "");
Expect(0, 11008, '\p{insupplementalmathematicaloperators}', "");
Expect(1, 11008, '\p{^insupplementalmathematicaloperators}', "");
Expect(1, 11008, '\P{insupplementalmathematicaloperators}', "");
Expect(0, 11008, '\P{^insupplementalmathematicaloperators}', "");
Expect(1, 11007, '\p{ _In_Supplemental_mathematical_operators}', "");
Expect(0, 11007, '\p{^ _In_Supplemental_mathematical_operators}', "");
Expect(0, 11007, '\P{ _In_Supplemental_mathematical_operators}', "");
Expect(1, 11007, '\P{^ _In_Supplemental_mathematical_operators}', "");
Expect(0, 11008, '\p{ _In_Supplemental_mathematical_operators}', "");
Expect(1, 11008, '\p{^ _In_Supplemental_mathematical_operators}', "");
Expect(1, 11008, '\P{ _In_Supplemental_mathematical_operators}', "");
Expect(0, 11008, '\P{^ _In_Supplemental_mathematical_operators}', "");
Error('\p{ :=sup_Math_Operators}');
Error('\P{ :=sup_Math_Operators}');
Expect(1, 11007, '\p{supmathoperators}', "");
Expect(0, 11007, '\p{^supmathoperators}', "");
Expect(0, 11007, '\P{supmathoperators}', "");
Expect(1, 11007, '\P{^supmathoperators}', "");
Expect(0, 11008, '\p{supmathoperators}', "");
Expect(1, 11008, '\p{^supmathoperators}', "");
Expect(1, 11008, '\P{supmathoperators}', "");
Expect(0, 11008, '\P{^supmathoperators}', "");
Expect(1, 11007, '\p{	_Sup_Math_OPERATORS}', "");
Expect(0, 11007, '\p{^	_Sup_Math_OPERATORS}', "");
Expect(0, 11007, '\P{	_Sup_Math_OPERATORS}', "");
Expect(1, 11007, '\P{^	_Sup_Math_OPERATORS}', "");
Expect(0, 11008, '\p{	_Sup_Math_OPERATORS}', "");
Expect(1, 11008, '\p{^	_Sup_Math_OPERATORS}', "");
Expect(1, 11008, '\P{	_Sup_Math_OPERATORS}', "");
Expect(0, 11008, '\P{^	_Sup_Math_OPERATORS}', "");
Error('\p{_/a/Is_sup_math_Operators}');
Error('\P{_/a/Is_sup_math_Operators}');
Expect(1, 11007, '\p{issupmathoperators}', "");
Expect(0, 11007, '\p{^issupmathoperators}', "");
Expect(0, 11007, '\P{issupmathoperators}', "");
Expect(1, 11007, '\P{^issupmathoperators}', "");
Expect(0, 11008, '\p{issupmathoperators}', "");
Expect(1, 11008, '\p{^issupmathoperators}', "");
Expect(1, 11008, '\P{issupmathoperators}', "");
Expect(0, 11008, '\P{^issupmathoperators}', "");
Expect(1, 11007, '\p{_-Is_sup_math_OPERATORS}', "");
Expect(0, 11007, '\p{^_-Is_sup_math_OPERATORS}', "");
Expect(0, 11007, '\P{_-Is_sup_math_OPERATORS}', "");
Expect(1, 11007, '\P{^_-Is_sup_math_OPERATORS}', "");
Expect(0, 11008, '\p{_-Is_sup_math_OPERATORS}', "");
Expect(1, 11008, '\p{^_-Is_sup_math_OPERATORS}', "");
Expect(1, 11008, '\P{_-Is_sup_math_OPERATORS}', "");
Expect(0, 11008, '\P{^_-Is_sup_math_OPERATORS}', "");
Error('\p{ :=In_sup_MATH_operators}');
Error('\P{ :=In_sup_MATH_operators}');
Expect(1, 11007, '\p{insupmathoperators}', "");
Expect(0, 11007, '\p{^insupmathoperators}', "");
Expect(0, 11007, '\P{insupmathoperators}', "");
Expect(1, 11007, '\P{^insupmathoperators}', "");
Expect(0, 11008, '\p{insupmathoperators}', "");
Expect(1, 11008, '\p{^insupmathoperators}', "");
Expect(1, 11008, '\P{insupmathoperators}', "");
Expect(0, 11008, '\P{^insupmathoperators}', "");
Expect(1, 11007, '\p{-	in_Sup_MATH_Operators}', "");
Expect(0, 11007, '\p{^-	in_Sup_MATH_Operators}', "");
Expect(0, 11007, '\P{-	in_Sup_MATH_Operators}', "");
Expect(1, 11007, '\P{^-	in_Sup_MATH_Operators}', "");
Expect(0, 11008, '\p{-	in_Sup_MATH_Operators}', "");
Expect(1, 11008, '\p{^-	in_Sup_MATH_Operators}', "");
Expect(1, 11008, '\P{-	in_Sup_MATH_Operators}', "");
Expect(0, 11008, '\P{^-	in_Sup_MATH_Operators}', "");
Error('\p{	_SUPPLEMENTAL_Punctuation/a/}');
Error('\P{	_SUPPLEMENTAL_Punctuation/a/}');
Expect(1, 11903, '\p{supplementalpunctuation}', "");
Expect(0, 11903, '\p{^supplementalpunctuation}', "");
Expect(0, 11903, '\P{supplementalpunctuation}', "");
Expect(1, 11903, '\P{^supplementalpunctuation}', "");
Expect(0, 11904, '\p{supplementalpunctuation}', "");
Expect(1, 11904, '\p{^supplementalpunctuation}', "");
Expect(1, 11904, '\P{supplementalpunctuation}', "");
Expect(0, 11904, '\P{^supplementalpunctuation}', "");
Expect(1, 11903, '\p{_Supplemental_punctuation}', "");
Expect(0, 11903, '\p{^_Supplemental_punctuation}', "");
Expect(0, 11903, '\P{_Supplemental_punctuation}', "");
Expect(1, 11903, '\P{^_Supplemental_punctuation}', "");
Expect(0, 11904, '\p{_Supplemental_punctuation}', "");
Expect(1, 11904, '\p{^_Supplemental_punctuation}', "");
Expect(1, 11904, '\P{_Supplemental_punctuation}', "");
Expect(0, 11904, '\P{^_Supplemental_punctuation}', "");
Error('\p{	:=Is_Supplemental_PUNCTUATION}');
Error('\P{	:=Is_Supplemental_PUNCTUATION}');
Expect(1, 11903, '\p{issupplementalpunctuation}', "");
Expect(0, 11903, '\p{^issupplementalpunctuation}', "");
Expect(0, 11903, '\P{issupplementalpunctuation}', "");
Expect(1, 11903, '\P{^issupplementalpunctuation}', "");
Expect(0, 11904, '\p{issupplementalpunctuation}', "");
Expect(1, 11904, '\p{^issupplementalpunctuation}', "");
Expect(1, 11904, '\P{issupplementalpunctuation}', "");
Expect(0, 11904, '\P{^issupplementalpunctuation}', "");
Expect(1, 11903, '\p{ 	IS_Supplemental_PUNCTUATION}', "");
Expect(0, 11903, '\p{^ 	IS_Supplemental_PUNCTUATION}', "");
Expect(0, 11903, '\P{ 	IS_Supplemental_PUNCTUATION}', "");
Expect(1, 11903, '\P{^ 	IS_Supplemental_PUNCTUATION}', "");
Expect(0, 11904, '\p{ 	IS_Supplemental_PUNCTUATION}', "");
Expect(1, 11904, '\p{^ 	IS_Supplemental_PUNCTUATION}', "");
Expect(1, 11904, '\P{ 	IS_Supplemental_PUNCTUATION}', "");
Expect(0, 11904, '\P{^ 	IS_Supplemental_PUNCTUATION}', "");
Error('\p{-	In_SUPPLEMENTAL_Punctuation/a/}');
Error('\P{-	In_SUPPLEMENTAL_Punctuation/a/}');
Expect(1, 11903, '\p{insupplementalpunctuation}', "");
Expect(0, 11903, '\p{^insupplementalpunctuation}', "");
Expect(0, 11903, '\P{insupplementalpunctuation}', "");
Expect(1, 11903, '\P{^insupplementalpunctuation}', "");
Expect(0, 11904, '\p{insupplementalpunctuation}', "");
Expect(1, 11904, '\p{^insupplementalpunctuation}', "");
Expect(1, 11904, '\P{insupplementalpunctuation}', "");
Expect(0, 11904, '\P{^insupplementalpunctuation}', "");
Expect(1, 11903, '\p{	 In_Supplemental_PUNCTUATION}', "");
Expect(0, 11903, '\p{^	 In_Supplemental_PUNCTUATION}', "");
Expect(0, 11903, '\P{	 In_Supplemental_PUNCTUATION}', "");
Expect(1, 11903, '\P{^	 In_Supplemental_PUNCTUATION}', "");
Expect(0, 11904, '\p{	 In_Supplemental_PUNCTUATION}', "");
Expect(1, 11904, '\p{^	 In_Supplemental_PUNCTUATION}', "");
Expect(1, 11904, '\P{	 In_Supplemental_PUNCTUATION}', "");
Expect(0, 11904, '\P{^	 In_Supplemental_PUNCTUATION}', "");
Error('\p{__SUP_Punctuation:=}');
Error('\P{__SUP_Punctuation:=}');
Expect(1, 11903, '\p{suppunctuation}', "");
Expect(0, 11903, '\p{^suppunctuation}', "");
Expect(0, 11903, '\P{suppunctuation}', "");
Expect(1, 11903, '\P{^suppunctuation}', "");
Expect(0, 11904, '\p{suppunctuation}', "");
Expect(1, 11904, '\p{^suppunctuation}', "");
Expect(1, 11904, '\P{suppunctuation}', "");
Expect(0, 11904, '\P{^suppunctuation}', "");
Expect(1, 11903, '\p{ _Sup_PUNCTUATION}', "");
Expect(0, 11903, '\p{^ _Sup_PUNCTUATION}', "");
Expect(0, 11903, '\P{ _Sup_PUNCTUATION}', "");
Expect(1, 11903, '\P{^ _Sup_PUNCTUATION}', "");
Expect(0, 11904, '\p{ _Sup_PUNCTUATION}', "");
Expect(1, 11904, '\p{^ _Sup_PUNCTUATION}', "");
Expect(1, 11904, '\P{ _Sup_PUNCTUATION}', "");
Expect(0, 11904, '\P{^ _Sup_PUNCTUATION}', "");
Error('\p{:=-IS_Sup_Punctuation}');
Error('\P{:=-IS_Sup_Punctuation}');
Expect(1, 11903, '\p{issuppunctuation}', "");
Expect(0, 11903, '\p{^issuppunctuation}', "");
Expect(0, 11903, '\P{issuppunctuation}', "");
Expect(1, 11903, '\P{^issuppunctuation}', "");
Expect(0, 11904, '\p{issuppunctuation}', "");
Expect(1, 11904, '\p{^issuppunctuation}', "");
Expect(1, 11904, '\P{issuppunctuation}', "");
Expect(0, 11904, '\P{^issuppunctuation}', "");
Expect(1, 11903, '\p{_Is_Sup_Punctuation}', "");
Expect(0, 11903, '\p{^_Is_Sup_Punctuation}', "");
Expect(0, 11903, '\P{_Is_Sup_Punctuation}', "");
Expect(1, 11903, '\P{^_Is_Sup_Punctuation}', "");
Expect(0, 11904, '\p{_Is_Sup_Punctuation}', "");
Expect(1, 11904, '\p{^_Is_Sup_Punctuation}', "");
Expect(1, 11904, '\P{_Is_Sup_Punctuation}', "");
Expect(0, 11904, '\P{^_Is_Sup_Punctuation}', "");
Error('\p{_/a/IN_Sup_Punctuation}');
Error('\P{_/a/IN_Sup_Punctuation}');
Expect(1, 11903, '\p{insuppunctuation}', "");
Expect(0, 11903, '\p{^insuppunctuation}', "");
Expect(0, 11903, '\P{insuppunctuation}', "");
Expect(1, 11903, '\P{^insuppunctuation}', "");
Expect(0, 11904, '\p{insuppunctuation}', "");
Expect(1, 11904, '\p{^insuppunctuation}', "");
Expect(1, 11904, '\P{insuppunctuation}', "");
Expect(0, 11904, '\P{^insuppunctuation}', "");
Expect(1, 11903, '\p{In_Sup_Punctuation}', "");
Expect(0, 11903, '\p{^In_Sup_Punctuation}', "");
Expect(0, 11903, '\P{In_Sup_Punctuation}', "");
Expect(1, 11903, '\P{^In_Sup_Punctuation}', "");
Expect(0, 11904, '\p{In_Sup_Punctuation}', "");
Expect(1, 11904, '\p{^In_Sup_Punctuation}', "");
Expect(1, 11904, '\P{In_Sup_Punctuation}', "");
Expect(0, 11904, '\P{^In_Sup_Punctuation}', "");
Error('\p{	-supplementary_PRIVATE_Use_Area_A/a/}');
Error('\P{	-supplementary_PRIVATE_Use_Area_A/a/}');
Expect(1, 983040, '\p{supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^supplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^supplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{supplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^supplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{	 Supplementary_Private_Use_AREA_A}', "");
Expect(0, 983040, '\p{^	 Supplementary_Private_Use_AREA_A}', "");
Expect(0, 983040, '\P{	 Supplementary_Private_Use_AREA_A}', "");
Expect(1, 983040, '\P{^	 Supplementary_Private_Use_AREA_A}', "");
Expect(0, 1048576, '\p{	 Supplementary_Private_Use_AREA_A}', "");
Expect(1, 1048576, '\p{^	 Supplementary_Private_Use_AREA_A}', "");
Expect(1, 1048576, '\P{	 Supplementary_Private_Use_AREA_A}', "");
Expect(0, 1048576, '\P{^	 Supplementary_Private_Use_AREA_A}', "");
Error('\p{ /a/Is_supplementary_PRIVATE_Use_Area_A}');
Error('\P{ /a/Is_supplementary_PRIVATE_Use_Area_A}');
Expect(1, 983040, '\p{issupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^issupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{issupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^issupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{issupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^issupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{issupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^issupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{	is_supplementary_Private_Use_Area_A}', "");
Expect(0, 983040, '\p{^	is_supplementary_Private_Use_Area_A}', "");
Expect(0, 983040, '\P{	is_supplementary_Private_Use_Area_A}', "");
Expect(1, 983040, '\P{^	is_supplementary_Private_Use_Area_A}', "");
Expect(0, 1048576, '\p{	is_supplementary_Private_Use_Area_A}', "");
Expect(1, 1048576, '\p{^	is_supplementary_Private_Use_Area_A}', "");
Expect(1, 1048576, '\P{	is_supplementary_Private_Use_Area_A}', "");
Expect(0, 1048576, '\P{^	is_supplementary_Private_Use_Area_A}', "");
Error('\p{ 	IN_SUPPLEMENTARY_private_Use_Area_A:=}');
Error('\P{ 	IN_SUPPLEMENTARY_private_Use_Area_A:=}');
Expect(1, 983040, '\p{insupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\p{^insupplementaryprivateuseareaa}', "");
Expect(0, 983040, '\P{insupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\P{^insupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\p{insupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\p{^insupplementaryprivateuseareaa}', "");
Expect(1, 1048576, '\P{insupplementaryprivateuseareaa}', "");
Expect(0, 1048576, '\P{^insupplementaryprivateuseareaa}', "");
Expect(1, 983040, '\p{_in_Supplementary_Private_Use_AREA_A}', "");
Expect(0, 983040, '\p{^_in_Supplementary_Private_Use_AREA_A}', "");
Expect(0, 983040, '\P{_in_Supplementary_Private_Use_AREA_A}', "");
Expect(1, 983040, '\P{^_in_Supplementary_Private_Use_AREA_A}', "");
Expect(0, 1048576, '\p{_in_Supplementary_Private_Use_AREA_A}', "");
Expect(1, 1048576, '\p{^_in_Supplementary_Private_Use_AREA_A}', "");
Expect(1, 1048576, '\P{_in_Supplementary_Private_Use_AREA_A}', "");
Expect(0, 1048576, '\P{^_in_Supplementary_Private_Use_AREA_A}', "");
Error('\p{	/a/sup_PUA_A}');
Error('\P{	/a/sup_PUA_A}');
Expect(1, 983040, '\p{suppuaa}', "");
Expect(0, 983040, '\p{^suppuaa}', "");
Expect(0, 983040, '\P{suppuaa}', "");
Expect(1, 983040, '\P{^suppuaa}', "");
Expect(0, 1048576, '\p{suppuaa}', "");
Expect(1, 1048576, '\p{^suppuaa}', "");
Expect(1, 1048576, '\P{suppuaa}', "");
Expect(0, 1048576, '\P{^suppuaa}', "");
Expect(1, 983040, '\p{ sup_PUA_A}', "");
Expect(0, 983040, '\p{^ sup_PUA_A}', "");
Expect(0, 983040, '\P{ sup_PUA_A}', "");
Expect(1, 983040, '\P{^ sup_PUA_A}', "");
Expect(0, 1048576, '\p{ sup_PUA_A}', "");
Expect(1, 1048576, '\p{^ sup_PUA_A}', "");
Expect(1, 1048576, '\P{ sup_PUA_A}', "");
Expect(0, 1048576, '\P{^ sup_PUA_A}', "");
Error('\p{:=Is_sup_PUA_A}');
Error('\P{:=Is_sup_PUA_A}');
Expect(1, 983040, '\p{issuppuaa}', "");
Expect(0, 983040, '\p{^issuppuaa}', "");
Expect(0, 983040, '\P{issuppuaa}', "");
Expect(1, 983040, '\P{^issuppuaa}', "");
Expect(0, 1048576, '\p{issuppuaa}', "");
Expect(1, 1048576, '\p{^issuppuaa}', "");
Expect(1, 1048576, '\P{issuppuaa}', "");
Expect(0, 1048576, '\P{^issuppuaa}', "");
Expect(1, 983040, '\p{-IS_Sup_PUA_A}', "");
Expect(0, 983040, '\p{^-IS_Sup_PUA_A}', "");
Expect(0, 983040, '\P{-IS_Sup_PUA_A}', "");
Expect(1, 983040, '\P{^-IS_Sup_PUA_A}', "");
Expect(0, 1048576, '\p{-IS_Sup_PUA_A}', "");
Expect(1, 1048576, '\p{^-IS_Sup_PUA_A}', "");
Expect(1, 1048576, '\P{-IS_Sup_PUA_A}', "");
Expect(0, 1048576, '\P{^-IS_Sup_PUA_A}', "");
Error('\p{ IN_Sup_PUA_A:=}');
Error('\P{ IN_Sup_PUA_A:=}');
Expect(1, 983040, '\p{insuppuaa}', "");
Expect(0, 983040, '\p{^insuppuaa}', "");
Expect(0, 983040, '\P{insuppuaa}', "");
Expect(1, 983040, '\P{^insuppuaa}', "");
Expect(0, 1048576, '\p{insuppuaa}', "");
Expect(1, 1048576, '\p{^insuppuaa}', "");
Expect(1, 1048576, '\P{insuppuaa}', "");
Expect(0, 1048576, '\P{^insuppuaa}', "");
Expect(1, 983040, '\p{	In_Sup_PUA_A}', "");
Expect(0, 983040, '\p{^	In_Sup_PUA_A}', "");
Expect(0, 983040, '\P{	In_Sup_PUA_A}', "");
Expect(1, 983040, '\P{^	In_Sup_PUA_A}', "");
Expect(0, 1048576, '\p{	In_Sup_PUA_A}', "");
Expect(1, 1048576, '\p{^	In_Sup_PUA_A}', "");
Expect(1, 1048576, '\P{	In_Sup_PUA_A}', "");
Expect(0, 1048576, '\P{^	In_Sup_PUA_A}', "");
Error('\p{	/a/SUPPLEMENTARY_Private_Use_area_b}');
Error('\P{	/a/SUPPLEMENTARY_Private_Use_area_b}');
Expect(1, 1048576, '\p{supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^supplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^supplementaryprivateuseareab}', "");
Expect(0, 1, '\p{supplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^supplementaryprivateuseareab}', "");
Expect(1, 1, '\P{supplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^supplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(0, 1048576, '\p{^_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(0, 1048576, '\P{_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(1, 1048576, '\P{^_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(0, 1, '\p{_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(1, 1, '\p{^_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(1, 1, '\P{_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Expect(0, 1, '\P{^_	SUPPLEMENTARY_private_USE_AREA_B}', "");
Error('\p{ -Is_Supplementary_PRIVATE_use_Area_B/a/}');
Error('\P{ -Is_Supplementary_PRIVATE_use_Area_B/a/}');
Expect(1, 1048576, '\p{issupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^issupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{issupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^issupplementaryprivateuseareab}', "");
Expect(0, 1, '\p{issupplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^issupplementaryprivateuseareab}', "");
Expect(1, 1, '\P{issupplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^issupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{	is_Supplementary_Private_Use_AREA_b}', "");
Expect(0, 1048576, '\p{^	is_Supplementary_Private_Use_AREA_b}', "");
Expect(0, 1048576, '\P{	is_Supplementary_Private_Use_AREA_b}', "");
Expect(1, 1048576, '\P{^	is_Supplementary_Private_Use_AREA_b}', "");
Expect(0, 1, '\p{	is_Supplementary_Private_Use_AREA_b}', "");
Expect(1, 1, '\p{^	is_Supplementary_Private_Use_AREA_b}', "");
Expect(1, 1, '\P{	is_Supplementary_Private_Use_AREA_b}', "");
Expect(0, 1, '\P{^	is_Supplementary_Private_Use_AREA_b}', "");
Error('\p{:=in_Supplementary_private_Use_Area_b}');
Error('\P{:=in_Supplementary_private_Use_Area_b}');
Expect(1, 1048576, '\p{insupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\p{^insupplementaryprivateuseareab}', "");
Expect(0, 1048576, '\P{insupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\P{^insupplementaryprivateuseareab}', "");
Expect(0, 1, '\p{insupplementaryprivateuseareab}', "");
Expect(1, 1, '\p{^insupplementaryprivateuseareab}', "");
Expect(1, 1, '\P{insupplementaryprivateuseareab}', "");
Expect(0, 1, '\P{^insupplementaryprivateuseareab}', "");
Expect(1, 1048576, '\p{_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(0, 1048576, '\p{^_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(0, 1048576, '\P{_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(1, 1048576, '\P{^_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(0, 1, '\p{_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(1, 1, '\p{^_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(1, 1, '\P{_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Expect(0, 1, '\P{^_-IN_SUPPLEMENTARY_private_Use_AREA_b}', "");
Error('\p{	:=Sup_PUA_B}');
Error('\P{	:=Sup_PUA_B}');
Expect(1, 1048576, '\p{suppuab}', "");
Expect(0, 1048576, '\p{^suppuab}', "");
Expect(0, 1048576, '\P{suppuab}', "");
Expect(1, 1048576, '\P{^suppuab}', "");
Expect(0, 1, '\p{suppuab}', "");
Expect(1, 1, '\p{^suppuab}', "");
Expect(1, 1, '\P{suppuab}', "");
Expect(0, 1, '\P{^suppuab}', "");
Expect(1, 1048576, '\p{ 	SUP_pua_B}', "");
Expect(0, 1048576, '\p{^ 	SUP_pua_B}', "");
Expect(0, 1048576, '\P{ 	SUP_pua_B}', "");
Expect(1, 1048576, '\P{^ 	SUP_pua_B}', "");
Expect(0, 1, '\p{ 	SUP_pua_B}', "");
Expect(1, 1, '\p{^ 	SUP_pua_B}', "");
Expect(1, 1, '\P{ 	SUP_pua_B}', "");
Expect(0, 1, '\P{^ 	SUP_pua_B}', "");
Error('\p{:=__IS_Sup_PUA_b}');
Error('\P{:=__IS_Sup_PUA_b}');
Expect(1, 1048576, '\p{issuppuab}', "");
Expect(0, 1048576, '\p{^issuppuab}', "");
Expect(0, 1048576, '\P{issuppuab}', "");
Expect(1, 1048576, '\P{^issuppuab}', "");
Expect(0, 1, '\p{issuppuab}', "");
Expect(1, 1, '\p{^issuppuab}', "");
Expect(1, 1, '\P{issuppuab}', "");
Expect(0, 1, '\P{^issuppuab}', "");
Expect(1, 1048576, '\p{--IS_Sup_PUA_B}', "");
Expect(0, 1048576, '\p{^--IS_Sup_PUA_B}', "");
Expect(0, 1048576, '\P{--IS_Sup_PUA_B}', "");
Expect(1, 1048576, '\P{^--IS_Sup_PUA_B}', "");
Expect(0, 1, '\p{--IS_Sup_PUA_B}', "");
Expect(1, 1, '\p{^--IS_Sup_PUA_B}', "");
Expect(1, 1, '\P{--IS_Sup_PUA_B}', "");
Expect(0, 1, '\P{^--IS_Sup_PUA_B}', "");
Error('\p{/a/__IN_Sup_PUA_B}');
Error('\P{/a/__IN_Sup_PUA_B}');
Expect(1, 1048576, '\p{insuppuab}', "");
Expect(0, 1048576, '\p{^insuppuab}', "");
Expect(0, 1048576, '\P{insuppuab}', "");
Expect(1, 1048576, '\P{^insuppuab}', "");
Expect(0, 1, '\p{insuppuab}', "");
Expect(1, 1, '\p{^insuppuab}', "");
Expect(1, 1, '\P{insuppuab}', "");
Expect(0, 1, '\P{^insuppuab}', "");
Expect(1, 1048576, '\p{__In_sup_PUA_b}', "");
Expect(0, 1048576, '\p{^__In_sup_PUA_b}', "");
Expect(0, 1048576, '\P{__In_sup_PUA_b}', "");
Expect(1, 1048576, '\P{^__In_sup_PUA_b}', "");
Expect(0, 1, '\p{__In_sup_PUA_b}', "");
Expect(1, 1, '\p{^__In_sup_PUA_b}', "");
Expect(1, 1, '\P{__In_sup_PUA_b}', "");
Expect(0, 1, '\P{^__In_sup_PUA_b}', "");
Error('\p{:= surrogate}');
Error('\P{:= surrogate}');
Expect(1, 57343, '\p{surrogate}', "");
Expect(0, 57343, '\p{^surrogate}', "");
Expect(0, 57343, '\P{surrogate}', "");
Expect(1, 57343, '\P{^surrogate}', "");
Expect(0, 57344, '\p{surrogate}', "");
Expect(1, 57344, '\p{^surrogate}', "");
Expect(1, 57344, '\P{surrogate}', "");
Expect(0, 57344, '\P{^surrogate}', "");
Expect(1, 57343, '\p{_SURROGATE}', "");
Expect(0, 57343, '\p{^_SURROGATE}', "");
Expect(0, 57343, '\P{_SURROGATE}', "");
Expect(1, 57343, '\P{^_SURROGATE}', "");
Expect(0, 57344, '\p{_SURROGATE}', "");
Expect(1, 57344, '\p{^_SURROGATE}', "");
Expect(1, 57344, '\P{_SURROGATE}', "");
Expect(0, 57344, '\P{^_SURROGATE}', "");
Error('\p{ /a/Is_Surrogate}');
Error('\P{ /a/Is_Surrogate}');
Expect(1, 57343, '\p{issurrogate}', "");
Expect(0, 57343, '\p{^issurrogate}', "");
Expect(0, 57343, '\P{issurrogate}', "");
Expect(1, 57343, '\P{^issurrogate}', "");
Expect(0, 57344, '\p{issurrogate}', "");
Expect(1, 57344, '\p{^issurrogate}', "");
Expect(1, 57344, '\P{issurrogate}', "");
Expect(0, 57344, '\P{^issurrogate}', "");
Expect(1, 57343, '\p{_Is_Surrogate}', "");
Expect(0, 57343, '\p{^_Is_Surrogate}', "");
Expect(0, 57343, '\P{_Is_Surrogate}', "");
Expect(1, 57343, '\P{^_Is_Surrogate}', "");
Expect(0, 57344, '\p{_Is_Surrogate}', "");
Expect(1, 57344, '\p{^_Is_Surrogate}', "");
Expect(1, 57344, '\P{_Is_Surrogate}', "");
Expect(0, 57344, '\P{^_Is_Surrogate}', "");
Error('\p{ _Cs/a/}');
Error('\P{ _Cs/a/}');
Expect(1, 57343, '\p{cs}', "");
Expect(0, 57343, '\p{^cs}', "");
Expect(0, 57343, '\P{cs}', "");
Expect(1, 57343, '\P{^cs}', "");
Expect(0, 57344, '\p{cs}', "");
Expect(1, 57344, '\p{^cs}', "");
Expect(1, 57344, '\P{cs}', "");
Expect(0, 57344, '\P{^cs}', "");
Expect(1, 57343, '\p{ 	CS}', "");
Expect(0, 57343, '\p{^ 	CS}', "");
Expect(0, 57343, '\P{ 	CS}', "");
Expect(1, 57343, '\P{^ 	CS}', "");
Expect(0, 57344, '\p{ 	CS}', "");
Expect(1, 57344, '\p{^ 	CS}', "");
Expect(1, 57344, '\P{ 	CS}', "");
Expect(0, 57344, '\P{^ 	CS}', "");
Error('\p{	_IS_Cs/a/}');
Error('\P{	_IS_Cs/a/}');
Expect(1, 57343, '\p{iscs}', "");
Expect(0, 57343, '\p{^iscs}', "");
Expect(0, 57343, '\P{iscs}', "");
Expect(1, 57343, '\P{^iscs}', "");
Expect(0, 57344, '\p{iscs}', "");
Expect(1, 57344, '\p{^iscs}', "");
Expect(1, 57344, '\P{iscs}', "");
Expect(0, 57344, '\P{^iscs}', "");
Expect(1, 57343, '\p{ Is_Cs}', "");
Expect(0, 57343, '\p{^ Is_Cs}', "");
Expect(0, 57343, '\P{ Is_Cs}', "");
Expect(1, 57343, '\P{^ Is_Cs}', "");
Expect(0, 57344, '\p{ Is_Cs}', "");
Expect(1, 57344, '\p{^ Is_Cs}', "");
Expect(1, 57344, '\P{ Is_Cs}', "");
Expect(0, 57344, '\P{^ Is_Cs}', "");
Error('\p{-:=Syloti_NAGRI}');
Error('\P{-:=Syloti_NAGRI}');
Expect(1, 43051, '\p{sylotinagri}', "");
Expect(0, 43051, '\p{^sylotinagri}', "");
Expect(0, 43051, '\P{sylotinagri}', "");
Expect(1, 43051, '\P{^sylotinagri}', "");
Expect(0, 43052, '\p{sylotinagri}', "");
Expect(1, 43052, '\p{^sylotinagri}', "");
Expect(1, 43052, '\P{sylotinagri}', "");
Expect(0, 43052, '\P{^sylotinagri}', "");
Expect(1, 43051, '\p{	Syloti_NAGRI}', "");
Expect(0, 43051, '\p{^	Syloti_NAGRI}', "");
Expect(0, 43051, '\P{	Syloti_NAGRI}', "");
Expect(1, 43051, '\P{^	Syloti_NAGRI}', "");
Expect(0, 43052, '\p{	Syloti_NAGRI}', "");
Expect(1, 43052, '\p{^	Syloti_NAGRI}', "");
Expect(1, 43052, '\P{	Syloti_NAGRI}', "");
Expect(0, 43052, '\P{^	Syloti_NAGRI}', "");
Error('\p{_-is_SYLOTI_Nagri:=}');
Error('\P{_-is_SYLOTI_Nagri:=}');
Expect(1, 43051, '\p{issylotinagri}', "");
Expect(0, 43051, '\p{^issylotinagri}', "");
Expect(0, 43051, '\P{issylotinagri}', "");
Expect(1, 43051, '\P{^issylotinagri}', "");
Expect(0, 43052, '\p{issylotinagri}', "");
Expect(1, 43052, '\p{^issylotinagri}', "");
Expect(1, 43052, '\P{issylotinagri}', "");
Expect(0, 43052, '\P{^issylotinagri}', "");
Expect(1, 43051, '\p{-Is_Syloti_NAGRI}', "");
Expect(0, 43051, '\p{^-Is_Syloti_NAGRI}', "");
Expect(0, 43051, '\P{-Is_Syloti_NAGRI}', "");
Expect(1, 43051, '\P{^-Is_Syloti_NAGRI}', "");
Expect(0, 43052, '\p{-Is_Syloti_NAGRI}', "");
Expect(1, 43052, '\p{^-Is_Syloti_NAGRI}', "");
Expect(1, 43052, '\P{-Is_Syloti_NAGRI}', "");
Expect(0, 43052, '\P{^-Is_Syloti_NAGRI}', "");
Error('\p{-sylo:=}');
Error('\P{-sylo:=}');
Expect(1, 43051, '\p{sylo}', "");
Expect(0, 43051, '\p{^sylo}', "");
Expect(0, 43051, '\P{sylo}', "");
Expect(1, 43051, '\P{^sylo}', "");
Expect(0, 43052, '\p{sylo}', "");
Expect(1, 43052, '\p{^sylo}', "");
Expect(1, 43052, '\P{sylo}', "");
Expect(0, 43052, '\P{^sylo}', "");
Expect(1, 43051, '\p{-_Sylo}', "");
Expect(0, 43051, '\p{^-_Sylo}', "");
Expect(0, 43051, '\P{-_Sylo}', "");
Expect(1, 43051, '\P{^-_Sylo}', "");
Expect(0, 43052, '\p{-_Sylo}', "");
Expect(1, 43052, '\p{^-_Sylo}', "");
Expect(1, 43052, '\P{-_Sylo}', "");
Expect(0, 43052, '\P{^-_Sylo}', "");
Error('\p{	 IS_sylo/a/}');
Error('\P{	 IS_sylo/a/}');
Expect(1, 43051, '\p{issylo}', "");
Expect(0, 43051, '\p{^issylo}', "");
Expect(0, 43051, '\P{issylo}', "");
Expect(1, 43051, '\P{^issylo}', "");
Expect(0, 43052, '\p{issylo}', "");
Expect(1, 43052, '\p{^issylo}', "");
Expect(1, 43052, '\P{issylo}', "");
Expect(0, 43052, '\P{^issylo}', "");
Expect(1, 43051, '\p{		Is_Sylo}', "");
Expect(0, 43051, '\p{^		Is_Sylo}', "");
Expect(0, 43051, '\P{		Is_Sylo}', "");
Expect(1, 43051, '\P{^		Is_Sylo}', "");
Expect(0, 43052, '\p{		Is_Sylo}', "");
Expect(1, 43052, '\p{^		Is_Sylo}', "");
Expect(1, 43052, '\P{		Is_Sylo}', "");
Expect(0, 43052, '\P{^		Is_Sylo}', "");
Error('\p{_-symbol:=}');
Error('\P{_-symbol:=}');
Expect(1, 128883, '\p{symbol}', "");
Expect(0, 128883, '\p{^symbol}', "");
Expect(0, 128883, '\P{symbol}', "");
Expect(1, 128883, '\P{^symbol}', "");
Expect(0, 128884, '\p{symbol}', "");
Expect(1, 128884, '\p{^symbol}', "");
Expect(1, 128884, '\P{symbol}', "");
Expect(0, 128884, '\P{^symbol}', "");
Expect(1, 128883, '\p{_Symbol}', "");
Expect(0, 128883, '\p{^_Symbol}', "");
Expect(0, 128883, '\P{_Symbol}', "");
Expect(1, 128883, '\P{^_Symbol}', "");
Expect(0, 128884, '\p{_Symbol}', "");
Expect(1, 128884, '\p{^_Symbol}', "");
Expect(1, 128884, '\P{_Symbol}', "");
Expect(0, 128884, '\P{^_Symbol}', "");
Error('\p{-	Is_SYMBOL:=}');
Error('\P{-	Is_SYMBOL:=}');
Expect(1, 128883, '\p{issymbol}', "");
Expect(0, 128883, '\p{^issymbol}', "");
Expect(0, 128883, '\P{issymbol}', "");
Expect(1, 128883, '\P{^issymbol}', "");
Expect(0, 128884, '\p{issymbol}', "");
Expect(1, 128884, '\p{^issymbol}', "");
Expect(1, 128884, '\P{issymbol}', "");
Expect(0, 128884, '\P{^issymbol}', "");
Expect(1, 128883, '\p{	 Is_symbol}', "");
Expect(0, 128883, '\p{^	 Is_symbol}', "");
Expect(0, 128883, '\P{	 Is_symbol}', "");
Expect(1, 128883, '\P{^	 Is_symbol}', "");
Expect(0, 128884, '\p{	 Is_symbol}', "");
Expect(1, 128884, '\p{^	 Is_symbol}', "");
Expect(1, 128884, '\P{	 Is_symbol}', "");
Expect(0, 128884, '\P{^	 Is_symbol}', "");
Error('\p{/a/ 	S}');
Error('\P{/a/ 	S}');
Expect(1, 128883, '\p{s}', "");
Expect(0, 128883, '\p{^s}', "");
Expect(0, 128883, '\P{s}', "");
Expect(1, 128883, '\P{^s}', "");
Expect(0, 128884, '\p{s}', "");
Expect(1, 128884, '\p{^s}', "");
Expect(1, 128884, '\P{s}', "");
Expect(0, 128884, '\P{^s}', "");
Expect(1, 128883, '\p{_s}', "");
Expect(0, 128883, '\p{^_s}', "");
Expect(0, 128883, '\P{_s}', "");
Expect(1, 128883, '\P{^_s}', "");
Expect(0, 128884, '\p{_s}', "");
Expect(1, 128884, '\p{^_s}', "");
Expect(1, 128884, '\P{_s}', "");
Expect(0, 128884, '\P{^_s}', "");
Error('\p{/a/_-Is_S}');
Error('\P{/a/_-Is_S}');
Expect(1, 128883, '\p{iss}', "");
Expect(0, 128883, '\p{^iss}', "");
Expect(0, 128883, '\P{iss}', "");
Expect(1, 128883, '\P{^iss}', "");
Expect(0, 128884, '\p{iss}', "");
Expect(1, 128884, '\p{^iss}', "");
Expect(1, 128884, '\P{iss}', "");
Expect(0, 128884, '\P{^iss}', "");
Expect(1, 128883, '\p{	 is_S}', "");
Expect(0, 128883, '\p{^	 is_S}', "");
Expect(0, 128883, '\P{	 is_S}', "");
Expect(1, 128883, '\P{^	 is_S}', "");
Expect(0, 128884, '\p{	 is_S}', "");
Expect(1, 128884, '\p{^	 is_S}', "");
Expect(1, 128884, '\P{	 is_S}', "");
Expect(0, 128884, '\P{^	 is_S}', "");
Error('\p{-syriac/a/}');
Error('\P{-syriac/a/}');
Expect(1, 1871, '\p{syriac}', "");
Expect(0, 1871, '\p{^syriac}', "");
Expect(0, 1871, '\P{syriac}', "");
Expect(1, 1871, '\P{^syriac}', "");
Expect(0, 1872, '\p{syriac}', "");
Expect(1, 1872, '\p{^syriac}', "");
Expect(1, 1872, '\P{syriac}', "");
Expect(0, 1872, '\P{^syriac}', "");
Expect(1, 1871, '\p{	 Syriac}', "");
Expect(0, 1871, '\p{^	 Syriac}', "");
Expect(0, 1871, '\P{	 Syriac}', "");
Expect(1, 1871, '\P{^	 Syriac}', "");
Expect(0, 1872, '\p{	 Syriac}', "");
Expect(1, 1872, '\p{^	 Syriac}', "");
Expect(1, 1872, '\P{	 Syriac}', "");
Expect(0, 1872, '\P{^	 Syriac}', "");
Error('\p{/a/--Is_Syriac}');
Error('\P{/a/--Is_Syriac}');
Expect(1, 1871, '\p{issyriac}', "");
Expect(0, 1871, '\p{^issyriac}', "");
Expect(0, 1871, '\P{issyriac}', "");
Expect(1, 1871, '\P{^issyriac}', "");
Expect(0, 1872, '\p{issyriac}', "");
Expect(1, 1872, '\p{^issyriac}', "");
Expect(1, 1872, '\P{issyriac}', "");
Expect(0, 1872, '\P{^issyriac}', "");
Expect(1, 1871, '\p{-Is_syriac}', "");
Expect(0, 1871, '\p{^-Is_syriac}', "");
Expect(0, 1871, '\P{-Is_syriac}', "");
Expect(1, 1871, '\P{^-Is_syriac}', "");
Expect(0, 1872, '\p{-Is_syriac}', "");
Expect(1, 1872, '\p{^-Is_syriac}', "");
Expect(1, 1872, '\P{-Is_syriac}', "");
Expect(0, 1872, '\P{^-Is_syriac}', "");
Error('\p{-	SYRC:=}');
Error('\P{-	SYRC:=}');
Expect(1, 1871, '\p{syrc}', "");
Expect(0, 1871, '\p{^syrc}', "");
Expect(0, 1871, '\P{syrc}', "");
Expect(1, 1871, '\P{^syrc}', "");
Expect(0, 1872, '\p{syrc}', "");
Expect(1, 1872, '\p{^syrc}', "");
Expect(1, 1872, '\P{syrc}', "");
Expect(0, 1872, '\P{^syrc}', "");
Expect(1, 1871, '\p{ -Syrc}', "");
Expect(0, 1871, '\p{^ -Syrc}', "");
Expect(0, 1871, '\P{ -Syrc}', "");
Expect(1, 1871, '\P{^ -Syrc}', "");
Expect(0, 1872, '\p{ -Syrc}', "");
Expect(1, 1872, '\p{^ -Syrc}', "");
Expect(1, 1872, '\P{ -Syrc}', "");
Expect(0, 1872, '\P{^ -Syrc}', "");
Error('\p{-	IS_Syrc/a/}');
Error('\P{-	IS_Syrc/a/}');
Expect(1, 1871, '\p{issyrc}', "");
Expect(0, 1871, '\p{^issyrc}', "");
Expect(0, 1871, '\P{issyrc}', "");
Expect(1, 1871, '\P{^issyrc}', "");
Expect(0, 1872, '\p{issyrc}', "");
Expect(1, 1872, '\p{^issyrc}', "");
Expect(1, 1872, '\P{issyrc}', "");
Expect(0, 1872, '\P{^issyrc}', "");
Expect(1, 1871, '\p{-Is_Syrc}', "");
Expect(0, 1871, '\p{^-Is_Syrc}', "");
Expect(0, 1871, '\P{-Is_Syrc}', "");
Expect(1, 1871, '\P{^-Is_Syrc}', "");
Expect(0, 1872, '\p{-Is_Syrc}', "");
Expect(1, 1872, '\p{^-Is_Syrc}', "");
Expect(1, 1872, '\P{-Is_Syrc}', "");
Expect(0, 1872, '\P{^-Is_Syrc}', "");
Error('\p{/a/	-Tagalog}');
Error('\P{/a/	-Tagalog}');
Expect(1, 5908, '\p{tagalog}', "");
Expect(0, 5908, '\p{^tagalog}', "");
Expect(0, 5908, '\P{tagalog}', "");
Expect(1, 5908, '\P{^tagalog}', "");
Expect(0, 5909, '\p{tagalog}', "");
Expect(1, 5909, '\p{^tagalog}', "");
Expect(1, 5909, '\P{tagalog}', "");
Expect(0, 5909, '\P{^tagalog}', "");
Expect(1, 5908, '\p{ _Tagalog}', "");
Expect(0, 5908, '\p{^ _Tagalog}', "");
Expect(0, 5908, '\P{ _Tagalog}', "");
Expect(1, 5908, '\P{^ _Tagalog}', "");
Expect(0, 5909, '\p{ _Tagalog}', "");
Expect(1, 5909, '\p{^ _Tagalog}', "");
Expect(1, 5909, '\P{ _Tagalog}', "");
Expect(0, 5909, '\P{^ _Tagalog}', "");
Error('\p{/a/-	is_tagalog}');
Error('\P{/a/-	is_tagalog}');
Expect(1, 5908, '\p{istagalog}', "");
Expect(0, 5908, '\p{^istagalog}', "");
Expect(0, 5908, '\P{istagalog}', "");
Expect(1, 5908, '\P{^istagalog}', "");
Expect(0, 5909, '\p{istagalog}', "");
Expect(1, 5909, '\p{^istagalog}', "");
Expect(1, 5909, '\P{istagalog}', "");
Expect(0, 5909, '\P{^istagalog}', "");
Expect(1, 5908, '\p{- is_tagalog}', "");
Expect(0, 5908, '\p{^- is_tagalog}', "");
Expect(0, 5908, '\P{- is_tagalog}', "");
Expect(1, 5908, '\P{^- is_tagalog}', "");
Expect(0, 5909, '\p{- is_tagalog}', "");
Expect(1, 5909, '\p{^- is_tagalog}', "");
Expect(1, 5909, '\P{- is_tagalog}', "");
Expect(0, 5909, '\P{^- is_tagalog}', "");
Error('\p{-/a/Tglg}');
Error('\P{-/a/Tglg}');
Expect(1, 5908, '\p{tglg}', "");
Expect(0, 5908, '\p{^tglg}', "");
Expect(0, 5908, '\P{tglg}', "");
Expect(1, 5908, '\P{^tglg}', "");
Expect(0, 5909, '\p{tglg}', "");
Expect(1, 5909, '\p{^tglg}', "");
Expect(1, 5909, '\P{tglg}', "");
Expect(0, 5909, '\P{^tglg}', "");
Expect(1, 5908, '\p{_ Tglg}', "");
Expect(0, 5908, '\p{^_ Tglg}', "");
Expect(0, 5908, '\P{_ Tglg}', "");
Expect(1, 5908, '\P{^_ Tglg}', "");
Expect(0, 5909, '\p{_ Tglg}', "");
Expect(1, 5909, '\p{^_ Tglg}', "");
Expect(1, 5909, '\P{_ Tglg}', "");
Expect(0, 5909, '\P{^_ Tglg}', "");
Error('\p{:=IS_Tglg}');
Error('\P{:=IS_Tglg}');
Expect(1, 5908, '\p{istglg}', "");
Expect(0, 5908, '\p{^istglg}', "");
Expect(0, 5908, '\P{istglg}', "");
Expect(1, 5908, '\P{^istglg}', "");
Expect(0, 5909, '\p{istglg}', "");
Expect(1, 5909, '\p{^istglg}', "");
Expect(1, 5909, '\P{istglg}', "");
Expect(0, 5909, '\P{^istglg}', "");
Expect(1, 5908, '\p{Is_TGLG}', "");
Expect(0, 5908, '\p{^Is_TGLG}', "");
Expect(0, 5908, '\P{Is_TGLG}', "");
Expect(1, 5908, '\P{^Is_TGLG}', "");
Expect(0, 5909, '\p{Is_TGLG}', "");
Expect(1, 5909, '\p{^Is_TGLG}', "");
Expect(1, 5909, '\P{Is_TGLG}', "");
Expect(0, 5909, '\P{^Is_TGLG}', "");
Error('\p{:=_ tagbanwa}');
Error('\P{:=_ tagbanwa}');
Expect(1, 6003, '\p{tagbanwa}', "");
Expect(0, 6003, '\p{^tagbanwa}', "");
Expect(0, 6003, '\P{tagbanwa}', "");
Expect(1, 6003, '\P{^tagbanwa}', "");
Expect(0, 6004, '\p{tagbanwa}', "");
Expect(1, 6004, '\p{^tagbanwa}', "");
Expect(1, 6004, '\P{tagbanwa}', "");
Expect(0, 6004, '\P{^tagbanwa}', "");
Expect(1, 6003, '\p{	_TAGBANWA}', "");
Expect(0, 6003, '\p{^	_TAGBANWA}', "");
Expect(0, 6003, '\P{	_TAGBANWA}', "");
Expect(1, 6003, '\P{^	_TAGBANWA}', "");
Expect(0, 6004, '\p{	_TAGBANWA}', "");
Expect(1, 6004, '\p{^	_TAGBANWA}', "");
Expect(1, 6004, '\P{	_TAGBANWA}', "");
Expect(0, 6004, '\P{^	_TAGBANWA}', "");
Error('\p{:= _is_Tagbanwa}');
Error('\P{:= _is_Tagbanwa}');
Expect(1, 6003, '\p{istagbanwa}', "");
Expect(0, 6003, '\p{^istagbanwa}', "");
Expect(0, 6003, '\P{istagbanwa}', "");
Expect(1, 6003, '\P{^istagbanwa}', "");
Expect(0, 6004, '\p{istagbanwa}', "");
Expect(1, 6004, '\p{^istagbanwa}', "");
Expect(1, 6004, '\P{istagbanwa}', "");
Expect(0, 6004, '\P{^istagbanwa}', "");
Expect(1, 6003, '\p{_-Is_Tagbanwa}', "");
Expect(0, 6003, '\p{^_-Is_Tagbanwa}', "");
Expect(0, 6003, '\P{_-Is_Tagbanwa}', "");
Expect(1, 6003, '\P{^_-Is_Tagbanwa}', "");
Expect(0, 6004, '\p{_-Is_Tagbanwa}', "");
Expect(1, 6004, '\p{^_-Is_Tagbanwa}', "");
Expect(1, 6004, '\P{_-Is_Tagbanwa}', "");
Expect(0, 6004, '\P{^_-Is_Tagbanwa}', "");
Error('\p{/a/	TAGB}');
Error('\P{/a/	TAGB}');
Expect(1, 6003, '\p{tagb}', "");
Expect(0, 6003, '\p{^tagb}', "");
Expect(0, 6003, '\P{tagb}', "");
Expect(1, 6003, '\P{^tagb}', "");
Expect(0, 6004, '\p{tagb}', "");
Expect(1, 6004, '\p{^tagb}', "");
Expect(1, 6004, '\P{tagb}', "");
Expect(0, 6004, '\P{^tagb}', "");
Expect(1, 6003, '\p{	 TAGB}', "");
Expect(0, 6003, '\p{^	 TAGB}', "");
Expect(0, 6003, '\P{	 TAGB}', "");
Expect(1, 6003, '\P{^	 TAGB}', "");
Expect(0, 6004, '\p{	 TAGB}', "");
Expect(1, 6004, '\p{^	 TAGB}', "");
Expect(1, 6004, '\P{	 TAGB}', "");
Expect(0, 6004, '\P{^	 TAGB}', "");
Error('\p{_/a/is_Tagb}');
Error('\P{_/a/is_Tagb}');
Expect(1, 6003, '\p{istagb}', "");
Expect(0, 6003, '\p{^istagb}', "");
Expect(0, 6003, '\P{istagb}', "");
Expect(1, 6003, '\P{^istagb}', "");
Expect(0, 6004, '\p{istagb}', "");
Expect(1, 6004, '\p{^istagb}', "");
Expect(1, 6004, '\P{istagb}', "");
Expect(0, 6004, '\P{^istagb}', "");
Expect(1, 6003, '\p{ _is_TAGB}', "");
Expect(0, 6003, '\p{^ _is_TAGB}', "");
Expect(0, 6003, '\P{ _is_TAGB}', "");
Expect(1, 6003, '\P{^ _is_TAGB}', "");
Expect(0, 6004, '\p{ _is_TAGB}', "");
Expect(1, 6004, '\p{^ _is_TAGB}', "");
Expect(1, 6004, '\P{ _is_TAGB}', "");
Expect(0, 6004, '\P{^ _is_TAGB}', "");
Error('\p{TAGS/a/}');
Error('\P{TAGS/a/}');
Expect(1, 917631, '\p{tags}', "");
Expect(0, 917631, '\p{^tags}', "");
Expect(0, 917631, '\P{tags}', "");
Expect(1, 917631, '\P{^tags}', "");
Expect(0, 917632, '\p{tags}', "");
Expect(1, 917632, '\p{^tags}', "");
Expect(1, 917632, '\P{tags}', "");
Expect(0, 917632, '\P{^tags}', "");
Expect(1, 917631, '\p{		TAGS}', "");
Expect(0, 917631, '\p{^		TAGS}', "");
Expect(0, 917631, '\P{		TAGS}', "");
Expect(1, 917631, '\P{^		TAGS}', "");
Expect(0, 917632, '\p{		TAGS}', "");
Expect(1, 917632, '\p{^		TAGS}', "");
Expect(1, 917632, '\P{		TAGS}', "");
Expect(0, 917632, '\P{^		TAGS}', "");
Error('\p{_ Is_Tags/a/}');
Error('\P{_ Is_Tags/a/}');
Expect(1, 917631, '\p{istags}', "");
Expect(0, 917631, '\p{^istags}', "");
Expect(0, 917631, '\P{istags}', "");
Expect(1, 917631, '\P{^istags}', "");
Expect(0, 917632, '\p{istags}', "");
Expect(1, 917632, '\p{^istags}', "");
Expect(1, 917632, '\P{istags}', "");
Expect(0, 917632, '\P{^istags}', "");
Expect(1, 917631, '\p{ -IS_tags}', "");
Expect(0, 917631, '\p{^ -IS_tags}', "");
Expect(0, 917631, '\P{ -IS_tags}', "");
Expect(1, 917631, '\P{^ -IS_tags}', "");
Expect(0, 917632, '\p{ -IS_tags}', "");
Expect(1, 917632, '\p{^ -IS_tags}', "");
Expect(1, 917632, '\P{ -IS_tags}', "");
Expect(0, 917632, '\P{^ -IS_tags}', "");
Error('\p{:=- in_tags}');
Error('\P{:=- in_tags}');
Expect(1, 917631, '\p{intags}', "");
Expect(0, 917631, '\p{^intags}', "");
Expect(0, 917631, '\P{intags}', "");
Expect(1, 917631, '\P{^intags}', "");
Expect(0, 917632, '\p{intags}', "");
Expect(1, 917632, '\p{^intags}', "");
Expect(1, 917632, '\P{intags}', "");
Expect(0, 917632, '\P{^intags}', "");
Expect(1, 917631, '\p{	-In_tags}', "");
Expect(0, 917631, '\p{^	-In_tags}', "");
Expect(0, 917631, '\P{	-In_tags}', "");
Expect(1, 917631, '\P{^	-In_tags}', "");
Expect(0, 917632, '\p{	-In_tags}', "");
Expect(1, 917632, '\p{^	-In_tags}', "");
Expect(1, 917632, '\P{	-In_tags}', "");
Expect(0, 917632, '\P{^	-In_tags}', "");
Error('\p{/a/-Tai_Le}');
Error('\P{/a/-Tai_Le}');
Expect(1, 6516, '\p{taile}', "");
Expect(0, 6516, '\p{^taile}', "");
Expect(0, 6516, '\P{taile}', "");
Expect(1, 6516, '\P{^taile}', "");
Expect(0, 6517, '\p{taile}', "");
Expect(1, 6517, '\p{^taile}', "");
Expect(1, 6517, '\P{taile}', "");
Expect(0, 6517, '\P{^taile}', "");
Expect(1, 6516, '\p{-TAI_Le}', "");
Expect(0, 6516, '\p{^-TAI_Le}', "");
Expect(0, 6516, '\P{-TAI_Le}', "");
Expect(1, 6516, '\P{^-TAI_Le}', "");
Expect(0, 6517, '\p{-TAI_Le}', "");
Expect(1, 6517, '\p{^-TAI_Le}', "");
Expect(1, 6517, '\P{-TAI_Le}', "");
Expect(0, 6517, '\P{^-TAI_Le}', "");
Error('\p{/a/is_Tai_Le}');
Error('\P{/a/is_Tai_Le}');
Expect(1, 6516, '\p{istaile}', "");
Expect(0, 6516, '\p{^istaile}', "");
Expect(0, 6516, '\P{istaile}', "");
Expect(1, 6516, '\P{^istaile}', "");
Expect(0, 6517, '\p{istaile}', "");
Expect(1, 6517, '\p{^istaile}', "");
Expect(1, 6517, '\P{istaile}', "");
Expect(0, 6517, '\P{^istaile}', "");
Expect(1, 6516, '\p{ _is_TAI_Le}', "");
Expect(0, 6516, '\p{^ _is_TAI_Le}', "");
Expect(0, 6516, '\P{ _is_TAI_Le}', "");
Expect(1, 6516, '\P{^ _is_TAI_Le}', "");
Expect(0, 6517, '\p{ _is_TAI_Le}', "");
Expect(1, 6517, '\p{^ _is_TAI_Le}', "");
Expect(1, 6517, '\P{ _is_TAI_Le}', "");
Expect(0, 6517, '\P{^ _is_TAI_Le}', "");
Error('\p{	Tale:=}');
Error('\P{	Tale:=}');
Expect(1, 6516, '\p{tale}', "");
Expect(0, 6516, '\p{^tale}', "");
Expect(0, 6516, '\P{tale}', "");
Expect(1, 6516, '\P{^tale}', "");
Expect(0, 6517, '\p{tale}', "");
Expect(1, 6517, '\p{^tale}', "");
Expect(1, 6517, '\P{tale}', "");
Expect(0, 6517, '\P{^tale}', "");
Expect(1, 6516, '\p{Tale}', "");
Expect(0, 6516, '\p{^Tale}', "");
Expect(0, 6516, '\P{Tale}', "");
Expect(1, 6516, '\P{^Tale}', "");
Expect(0, 6517, '\p{Tale}', "");
Expect(1, 6517, '\p{^Tale}', "");
Expect(1, 6517, '\P{Tale}', "");
Expect(0, 6517, '\P{^Tale}', "");
Error('\p{-:=IS_tale}');
Error('\P{-:=IS_tale}');
Expect(1, 6516, '\p{istale}', "");
Expect(0, 6516, '\p{^istale}', "");
Expect(0, 6516, '\P{istale}', "");
Expect(1, 6516, '\P{^istale}', "");
Expect(0, 6517, '\p{istale}', "");
Expect(1, 6517, '\p{^istale}', "");
Expect(1, 6517, '\P{istale}', "");
Expect(0, 6517, '\P{^istale}', "");
Expect(1, 6516, '\p{ -Is_Tale}', "");
Expect(0, 6516, '\p{^ -Is_Tale}', "");
Expect(0, 6516, '\P{ -Is_Tale}', "");
Expect(1, 6516, '\P{^ -Is_Tale}', "");
Expect(0, 6517, '\p{ -Is_Tale}', "");
Expect(1, 6517, '\p{^ -Is_Tale}', "");
Expect(1, 6517, '\P{ -Is_Tale}', "");
Expect(0, 6517, '\P{^ -Is_Tale}', "");
Error('\p{-:=TAI_tham}');
Error('\P{-:=TAI_tham}');
Expect(1, 6829, '\p{taitham}', "");
Expect(0, 6829, '\p{^taitham}', "");
Expect(0, 6829, '\P{taitham}', "");
Expect(1, 6829, '\P{^taitham}', "");
Expect(0, 6830, '\p{taitham}', "");
Expect(1, 6830, '\p{^taitham}', "");
Expect(1, 6830, '\P{taitham}', "");
Expect(0, 6830, '\P{^taitham}', "");
Expect(1, 6829, '\p{  Tai_Tham}', "");
Expect(0, 6829, '\p{^  Tai_Tham}', "");
Expect(0, 6829, '\P{  Tai_Tham}', "");
Expect(1, 6829, '\P{^  Tai_Tham}', "");
Expect(0, 6830, '\p{  Tai_Tham}', "");
Expect(1, 6830, '\p{^  Tai_Tham}', "");
Expect(1, 6830, '\P{  Tai_Tham}', "");
Expect(0, 6830, '\P{^  Tai_Tham}', "");
Error('\p{/a/ Is_TAI_THAM}');
Error('\P{/a/ Is_TAI_THAM}');
Expect(1, 6829, '\p{istaitham}', "");
Expect(0, 6829, '\p{^istaitham}', "");
Expect(0, 6829, '\P{istaitham}', "");
Expect(1, 6829, '\P{^istaitham}', "");
Expect(0, 6830, '\p{istaitham}', "");
Expect(1, 6830, '\p{^istaitham}', "");
Expect(1, 6830, '\P{istaitham}', "");
Expect(0, 6830, '\P{^istaitham}', "");
Expect(1, 6829, '\p{	 Is_Tai_THAM}', "");
Expect(0, 6829, '\p{^	 Is_Tai_THAM}', "");
Expect(0, 6829, '\P{	 Is_Tai_THAM}', "");
Expect(1, 6829, '\P{^	 Is_Tai_THAM}', "");
Expect(0, 6830, '\p{	 Is_Tai_THAM}', "");
Expect(1, 6830, '\p{^	 Is_Tai_THAM}', "");
Expect(1, 6830, '\P{	 Is_Tai_THAM}', "");
Expect(0, 6830, '\P{^	 Is_Tai_THAM}', "");
Error('\p{-/a/lana}');
Error('\P{-/a/lana}');
Expect(1, 6829, '\p{lana}', "");
Expect(0, 6829, '\p{^lana}', "");
Expect(0, 6829, '\P{lana}', "");
Expect(1, 6829, '\P{^lana}', "");
Expect(0, 6830, '\p{lana}', "");
Expect(1, 6830, '\p{^lana}', "");
Expect(1, 6830, '\P{lana}', "");
Expect(0, 6830, '\P{^lana}', "");
Expect(1, 6829, '\p{-Lana}', "");
Expect(0, 6829, '\p{^-Lana}', "");
Expect(0, 6829, '\P{-Lana}', "");
Expect(1, 6829, '\P{^-Lana}', "");
Expect(0, 6830, '\p{-Lana}', "");
Expect(1, 6830, '\p{^-Lana}', "");
Expect(1, 6830, '\P{-Lana}', "");
Expect(0, 6830, '\P{^-Lana}', "");
Error('\p{	:=is_Lana}');
Error('\P{	:=is_Lana}');
Expect(1, 6829, '\p{islana}', "");
Expect(0, 6829, '\p{^islana}', "");
Expect(0, 6829, '\P{islana}', "");
Expect(1, 6829, '\P{^islana}', "");
Expect(0, 6830, '\p{islana}', "");
Expect(1, 6830, '\p{^islana}', "");
Expect(1, 6830, '\P{islana}', "");
Expect(0, 6830, '\P{^islana}', "");
Expect(1, 6829, '\p{ is_lana}', "");
Expect(0, 6829, '\p{^ is_lana}', "");
Expect(0, 6829, '\P{ is_lana}', "");
Expect(1, 6829, '\P{^ is_lana}', "");
Expect(0, 6830, '\p{ is_lana}', "");
Expect(1, 6830, '\p{^ is_lana}', "");
Expect(1, 6830, '\P{ is_lana}', "");
Expect(0, 6830, '\P{^ is_lana}', "");
Error('\p{_tai_VIET:=}');
Error('\P{_tai_VIET:=}');
Expect(1, 43743, '\p{taiviet}', "");
Expect(0, 43743, '\p{^taiviet}', "");
Expect(0, 43743, '\P{taiviet}', "");
Expect(1, 43743, '\P{^taiviet}', "");
Expect(0, 43744, '\p{taiviet}', "");
Expect(1, 43744, '\p{^taiviet}', "");
Expect(1, 43744, '\P{taiviet}', "");
Expect(0, 43744, '\P{^taiviet}', "");
Expect(1, 43743, '\p{	Tai_VIET}', "");
Expect(0, 43743, '\p{^	Tai_VIET}', "");
Expect(0, 43743, '\P{	Tai_VIET}', "");
Expect(1, 43743, '\P{^	Tai_VIET}', "");
Expect(0, 43744, '\p{	Tai_VIET}', "");
Expect(1, 43744, '\p{^	Tai_VIET}', "");
Expect(1, 43744, '\P{	Tai_VIET}', "");
Expect(0, 43744, '\P{^	Tai_VIET}', "");
Error('\p{_:=Is_TAI_Viet}');
Error('\P{_:=Is_TAI_Viet}');
Expect(1, 43743, '\p{istaiviet}', "");
Expect(0, 43743, '\p{^istaiviet}', "");
Expect(0, 43743, '\P{istaiviet}', "");
Expect(1, 43743, '\P{^istaiviet}', "");
Expect(0, 43744, '\p{istaiviet}', "");
Expect(1, 43744, '\p{^istaiviet}', "");
Expect(1, 43744, '\P{istaiviet}', "");
Expect(0, 43744, '\P{^istaiviet}', "");
Expect(1, 43743, '\p{-_Is_Tai_VIET}', "");
Expect(0, 43743, '\p{^-_Is_Tai_VIET}', "");
Expect(0, 43743, '\P{-_Is_Tai_VIET}', "");
Expect(1, 43743, '\P{^-_Is_Tai_VIET}', "");
Expect(0, 43744, '\p{-_Is_Tai_VIET}', "");
Expect(1, 43744, '\p{^-_Is_Tai_VIET}', "");
Expect(1, 43744, '\P{-_Is_Tai_VIET}', "");
Expect(0, 43744, '\P{^-_Is_Tai_VIET}', "");
Error('\p{-/a/tavt}');
Error('\P{-/a/tavt}');
Expect(1, 43743, '\p{tavt}', "");
Expect(0, 43743, '\p{^tavt}', "");
Expect(0, 43743, '\P{tavt}', "");
Expect(1, 43743, '\P{^tavt}', "");
Expect(0, 43744, '\p{tavt}', "");
Expect(1, 43744, '\p{^tavt}', "");
Expect(1, 43744, '\P{tavt}', "");
Expect(0, 43744, '\P{^tavt}', "");
Error('\p{/a/Is_Tavt}');
Error('\P{/a/Is_Tavt}');
Expect(1, 43743, '\p{istavt}', "");
Expect(0, 43743, '\p{^istavt}', "");
Expect(0, 43743, '\P{istavt}', "");
Expect(1, 43743, '\P{^istavt}', "");
Expect(0, 43744, '\p{istavt}', "");
Expect(1, 43744, '\p{^istavt}', "");
Expect(1, 43744, '\P{istavt}', "");
Expect(0, 43744, '\P{^istavt}', "");
Expect(1, 43743, '\p{ Is_Tavt}', "");
Expect(0, 43743, '\p{^ Is_Tavt}', "");
Expect(0, 43743, '\P{ Is_Tavt}', "");
Expect(1, 43743, '\P{^ Is_Tavt}', "");
Expect(0, 43744, '\p{ Is_Tavt}', "");
Expect(1, 43744, '\p{^ Is_Tavt}', "");
Expect(1, 43744, '\P{ Is_Tavt}', "");
Expect(0, 43744, '\P{^ Is_Tavt}', "");
Error('\p{		TAI_Xuan_Jing_Symbols/a/}');
Error('\P{		TAI_Xuan_Jing_Symbols/a/}');
Expect(1, 119647, '\p{taixuanjingsymbols}', "");
Expect(0, 119647, '\p{^taixuanjingsymbols}', "");
Expect(0, 119647, '\P{taixuanjingsymbols}', "");
Expect(1, 119647, '\P{^taixuanjingsymbols}', "");
Expect(0, 119648, '\p{taixuanjingsymbols}', "");
Expect(1, 119648, '\p{^taixuanjingsymbols}', "");
Expect(1, 119648, '\P{taixuanjingsymbols}', "");
Expect(0, 119648, '\P{^taixuanjingsymbols}', "");
Expect(1, 119647, '\p{ TAI_Xuan_Jing_Symbols}', "");
Expect(0, 119647, '\p{^ TAI_Xuan_Jing_Symbols}', "");
Expect(0, 119647, '\P{ TAI_Xuan_Jing_Symbols}', "");
Expect(1, 119647, '\P{^ TAI_Xuan_Jing_Symbols}', "");
Expect(0, 119648, '\p{ TAI_Xuan_Jing_Symbols}', "");
Expect(1, 119648, '\p{^ TAI_Xuan_Jing_Symbols}', "");
Expect(1, 119648, '\P{ TAI_Xuan_Jing_Symbols}', "");
Expect(0, 119648, '\P{^ TAI_Xuan_Jing_Symbols}', "");
Error('\p{_IS_tai_Xuan_Jing_Symbols:=}');
Error('\P{_IS_tai_Xuan_Jing_Symbols:=}');
Expect(1, 119647, '\p{istaixuanjingsymbols}', "");
Expect(0, 119647, '\p{^istaixuanjingsymbols}', "");
Expect(0, 119647, '\P{istaixuanjingsymbols}', "");
Expect(1, 119647, '\P{^istaixuanjingsymbols}', "");
Expect(0, 119648, '\p{istaixuanjingsymbols}', "");
Expect(1, 119648, '\p{^istaixuanjingsymbols}', "");
Expect(1, 119648, '\P{istaixuanjingsymbols}', "");
Expect(0, 119648, '\P{^istaixuanjingsymbols}', "");
Expect(1, 119647, '\p{- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(0, 119647, '\p{^- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(0, 119647, '\P{- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(1, 119647, '\P{^- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(0, 119648, '\p{- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(1, 119648, '\p{^- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(1, 119648, '\P{- Is_Tai_Xuan_Jing_Symbols}', "");
Expect(0, 119648, '\P{^- Is_Tai_Xuan_Jing_Symbols}', "");
Error('\p{_in_Tai_Xuan_Jing_symbols/a/}');
Error('\P{_in_Tai_Xuan_Jing_symbols/a/}');
Expect(1, 119647, '\p{intaixuanjingsymbols}', "");
Expect(0, 119647, '\p{^intaixuanjingsymbols}', "");
Expect(0, 119647, '\P{intaixuanjingsymbols}', "");
Expect(1, 119647, '\P{^intaixuanjingsymbols}', "");
Expect(0, 119648, '\p{intaixuanjingsymbols}', "");
Expect(1, 119648, '\p{^intaixuanjingsymbols}', "");
Expect(1, 119648, '\P{intaixuanjingsymbols}', "");
Expect(0, 119648, '\P{^intaixuanjingsymbols}', "");
Expect(1, 119647, '\p{	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(0, 119647, '\p{^	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(0, 119647, '\P{	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(1, 119647, '\P{^	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(0, 119648, '\p{	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(1, 119648, '\p{^	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(1, 119648, '\P{	 IN_Tai_xuan_JING_SYMBOLS}', "");
Expect(0, 119648, '\P{^	 IN_Tai_xuan_JING_SYMBOLS}', "");
Error('\p{ /a/TAI_Xuan_Jing}');
Error('\P{ /a/TAI_Xuan_Jing}');
Expect(1, 119647, '\p{taixuanjing}', "");
Expect(0, 119647, '\p{^taixuanjing}', "");
Expect(0, 119647, '\P{taixuanjing}', "");
Expect(1, 119647, '\P{^taixuanjing}', "");
Expect(0, 119648, '\p{taixuanjing}', "");
Expect(1, 119648, '\p{^taixuanjing}', "");
Expect(1, 119648, '\P{taixuanjing}', "");
Expect(0, 119648, '\P{^taixuanjing}', "");
Expect(1, 119647, '\p{	-Tai_xuan_jing}', "");
Expect(0, 119647, '\p{^	-Tai_xuan_jing}', "");
Expect(0, 119647, '\P{	-Tai_xuan_jing}', "");
Expect(1, 119647, '\P{^	-Tai_xuan_jing}', "");
Expect(0, 119648, '\p{	-Tai_xuan_jing}', "");
Expect(1, 119648, '\p{^	-Tai_xuan_jing}', "");
Expect(1, 119648, '\P{	-Tai_xuan_jing}', "");
Expect(0, 119648, '\P{^	-Tai_xuan_jing}', "");
Error('\p{/a/  Is_TAI_xuan_JING}');
Error('\P{/a/  Is_TAI_xuan_JING}');
Expect(1, 119647, '\p{istaixuanjing}', "");
Expect(0, 119647, '\p{^istaixuanjing}', "");
Expect(0, 119647, '\P{istaixuanjing}', "");
Expect(1, 119647, '\P{^istaixuanjing}', "");
Expect(0, 119648, '\p{istaixuanjing}', "");
Expect(1, 119648, '\p{^istaixuanjing}', "");
Expect(1, 119648, '\P{istaixuanjing}', "");
Expect(0, 119648, '\P{^istaixuanjing}', "");
Expect(1, 119647, '\p{ _Is_Tai_Xuan_JING}', "");
Expect(0, 119647, '\p{^ _Is_Tai_Xuan_JING}', "");
Expect(0, 119647, '\P{ _Is_Tai_Xuan_JING}', "");
Expect(1, 119647, '\P{^ _Is_Tai_Xuan_JING}', "");
Expect(0, 119648, '\p{ _Is_Tai_Xuan_JING}', "");
Expect(1, 119648, '\p{^ _Is_Tai_Xuan_JING}', "");
Expect(1, 119648, '\P{ _Is_Tai_Xuan_JING}', "");
Expect(0, 119648, '\P{^ _Is_Tai_Xuan_JING}', "");
Error('\p{-IN_tai_Xuan_Jing:=}');
Error('\P{-IN_tai_Xuan_Jing:=}');
Expect(1, 119647, '\p{intaixuanjing}', "");
Expect(0, 119647, '\p{^intaixuanjing}', "");
Expect(0, 119647, '\P{intaixuanjing}', "");
Expect(1, 119647, '\P{^intaixuanjing}', "");
Expect(0, 119648, '\p{intaixuanjing}', "");
Expect(1, 119648, '\p{^intaixuanjing}', "");
Expect(1, 119648, '\P{intaixuanjing}', "");
Expect(0, 119648, '\P{^intaixuanjing}', "");
Expect(1, 119647, '\p{- In_Tai_XUAN_Jing}', "");
Expect(0, 119647, '\p{^- In_Tai_XUAN_Jing}', "");
Expect(0, 119647, '\P{- In_Tai_XUAN_Jing}', "");
Expect(1, 119647, '\P{^- In_Tai_XUAN_Jing}', "");
Expect(0, 119648, '\p{- In_Tai_XUAN_Jing}', "");
Expect(1, 119648, '\p{^- In_Tai_XUAN_Jing}', "");
Expect(1, 119648, '\P{- In_Tai_XUAN_Jing}', "");
Expect(0, 119648, '\P{^- In_Tai_XUAN_Jing}', "");
Error('\p{:= 	takri}');
Error('\P{:= 	takri}');
Expect(1, 71369, '\p{takri}', "");
Expect(0, 71369, '\p{^takri}', "");
Expect(0, 71369, '\P{takri}', "");
Expect(1, 71369, '\P{^takri}', "");
Expect(0, 71370, '\p{takri}', "");
Expect(1, 71370, '\p{^takri}', "");
Expect(1, 71370, '\P{takri}', "");
Expect(0, 71370, '\P{^takri}', "");
Expect(1, 71369, '\p{_-TAKRI}', "");
Expect(0, 71369, '\p{^_-TAKRI}', "");
Expect(0, 71369, '\P{_-TAKRI}', "");
Expect(1, 71369, '\P{^_-TAKRI}', "");
Expect(0, 71370, '\p{_-TAKRI}', "");
Expect(1, 71370, '\p{^_-TAKRI}', "");
Expect(1, 71370, '\P{_-TAKRI}', "");
Expect(0, 71370, '\P{^_-TAKRI}', "");
Error('\p{-:=is_Takri}');
Error('\P{-:=is_Takri}');
Expect(1, 71369, '\p{istakri}', "");
Expect(0, 71369, '\p{^istakri}', "");
Expect(0, 71369, '\P{istakri}', "");
Expect(1, 71369, '\P{^istakri}', "");
Expect(0, 71370, '\p{istakri}', "");
Expect(1, 71370, '\p{^istakri}', "");
Expect(1, 71370, '\P{istakri}', "");
Expect(0, 71370, '\P{^istakri}', "");
Expect(1, 71369, '\p{_ IS_Takri}', "");
Expect(0, 71369, '\p{^_ IS_Takri}', "");
Expect(0, 71369, '\P{_ IS_Takri}', "");
Expect(1, 71369, '\P{^_ IS_Takri}', "");
Expect(0, 71370, '\p{_ IS_Takri}', "");
Expect(1, 71370, '\p{^_ IS_Takri}', "");
Expect(1, 71370, '\P{_ IS_Takri}', "");
Expect(0, 71370, '\P{^_ IS_Takri}', "");
Error('\p{-Takr/a/}');
Error('\P{-Takr/a/}');
Expect(1, 71369, '\p{takr}', "");
Expect(0, 71369, '\p{^takr}', "");
Expect(0, 71369, '\P{takr}', "");
Expect(1, 71369, '\P{^takr}', "");
Expect(0, 71370, '\p{takr}', "");
Expect(1, 71370, '\p{^takr}', "");
Expect(1, 71370, '\P{takr}', "");
Expect(0, 71370, '\P{^takr}', "");
Expect(1, 71369, '\p{_Takr}', "");
Expect(0, 71369, '\p{^_Takr}', "");
Expect(0, 71369, '\P{_Takr}', "");
Expect(1, 71369, '\P{^_Takr}', "");
Expect(0, 71370, '\p{_Takr}', "");
Expect(1, 71370, '\p{^_Takr}', "");
Expect(1, 71370, '\P{_Takr}', "");
Expect(0, 71370, '\P{^_Takr}', "");
Error('\p{	 Is_Takr:=}');
Error('\P{	 Is_Takr:=}');
Expect(1, 71369, '\p{istakr}', "");
Expect(0, 71369, '\p{^istakr}', "");
Expect(0, 71369, '\P{istakr}', "");
Expect(1, 71369, '\P{^istakr}', "");
Expect(0, 71370, '\p{istakr}', "");
Expect(1, 71370, '\p{^istakr}', "");
Expect(1, 71370, '\P{istakr}', "");
Expect(0, 71370, '\P{^istakr}', "");
Expect(1, 71369, '\p{ IS_takr}', "");
Expect(0, 71369, '\p{^ IS_takr}', "");
Expect(0, 71369, '\P{ IS_takr}', "");
Expect(1, 71369, '\P{^ IS_takr}', "");
Expect(0, 71370, '\p{ IS_takr}', "");
Expect(1, 71370, '\p{^ IS_takr}', "");
Expect(1, 71370, '\P{ IS_takr}', "");
Expect(0, 71370, '\P{^ IS_takr}', "");
Error('\p{_Tamil:=}');
Error('\P{_Tamil:=}');
Expect(1, 3066, '\p{tamil}', "");
Expect(0, 3066, '\p{^tamil}', "");
Expect(0, 3066, '\P{tamil}', "");
Expect(1, 3066, '\P{^tamil}', "");
Expect(0, 3067, '\p{tamil}', "");
Expect(1, 3067, '\p{^tamil}', "");
Expect(1, 3067, '\P{tamil}', "");
Expect(0, 3067, '\P{^tamil}', "");
Expect(1, 3066, '\p{	tamil}', "");
Expect(0, 3066, '\p{^	tamil}', "");
Expect(0, 3066, '\P{	tamil}', "");
Expect(1, 3066, '\P{^	tamil}', "");
Expect(0, 3067, '\p{	tamil}', "");
Expect(1, 3067, '\p{^	tamil}', "");
Expect(1, 3067, '\P{	tamil}', "");
Expect(0, 3067, '\P{^	tamil}', "");
Error('\p{	Is_Tamil:=}');
Error('\P{	Is_Tamil:=}');
Expect(1, 3066, '\p{istamil}', "");
Expect(0, 3066, '\p{^istamil}', "");
Expect(0, 3066, '\P{istamil}', "");
Expect(1, 3066, '\P{^istamil}', "");
Expect(0, 3067, '\p{istamil}', "");
Expect(1, 3067, '\p{^istamil}', "");
Expect(1, 3067, '\P{istamil}', "");
Expect(0, 3067, '\P{^istamil}', "");
Expect(1, 3066, '\p{_	Is_Tamil}', "");
Expect(0, 3066, '\p{^_	Is_Tamil}', "");
Expect(0, 3066, '\P{_	Is_Tamil}', "");
Expect(1, 3066, '\P{^_	Is_Tamil}', "");
Expect(0, 3067, '\p{_	Is_Tamil}', "");
Expect(1, 3067, '\p{^_	Is_Tamil}', "");
Expect(1, 3067, '\P{_	Is_Tamil}', "");
Expect(0, 3067, '\P{^_	Is_Tamil}', "");
Error('\p{ _taml/a/}');
Error('\P{ _taml/a/}');
Expect(1, 3066, '\p{taml}', "");
Expect(0, 3066, '\p{^taml}', "");
Expect(0, 3066, '\P{taml}', "");
Expect(1, 3066, '\P{^taml}', "");
Expect(0, 3067, '\p{taml}', "");
Expect(1, 3067, '\p{^taml}', "");
Expect(1, 3067, '\P{taml}', "");
Expect(0, 3067, '\P{^taml}', "");
Expect(1, 3066, '\p{		taml}', "");
Expect(0, 3066, '\p{^		taml}', "");
Expect(0, 3066, '\P{		taml}', "");
Expect(1, 3066, '\P{^		taml}', "");
Expect(0, 3067, '\p{		taml}', "");
Expect(1, 3067, '\p{^		taml}', "");
Expect(1, 3067, '\P{		taml}', "");
Expect(0, 3067, '\P{^		taml}', "");
Error('\p{ /a/IS_taml}');
Error('\P{ /a/IS_taml}');
Expect(1, 3066, '\p{istaml}', "");
Expect(0, 3066, '\p{^istaml}', "");
Expect(0, 3066, '\P{istaml}', "");
Expect(1, 3066, '\P{^istaml}', "");
Expect(0, 3067, '\p{istaml}', "");
Expect(1, 3067, '\p{^istaml}', "");
Expect(1, 3067, '\P{istaml}', "");
Expect(0, 3067, '\P{^istaml}', "");
Expect(1, 3066, '\p{-Is_taml}', "");
Expect(0, 3066, '\p{^-Is_taml}', "");
Expect(0, 3066, '\P{-Is_taml}', "");
Expect(1, 3066, '\P{^-Is_taml}', "");
Expect(0, 3067, '\p{-Is_taml}', "");
Expect(1, 3067, '\p{^-Is_taml}', "");
Expect(1, 3067, '\P{-Is_taml}', "");
Expect(0, 3067, '\P{^-Is_taml}', "");
Error('\p{/a/_TELUGU}');
Error('\P{/a/_TELUGU}');
Expect(1, 3199, '\p{telugu}', "");
Expect(0, 3199, '\p{^telugu}', "");
Expect(0, 3199, '\P{telugu}', "");
Expect(1, 3199, '\P{^telugu}', "");
Expect(0, 3200, '\p{telugu}', "");
Expect(1, 3200, '\p{^telugu}', "");
Expect(1, 3200, '\P{telugu}', "");
Expect(0, 3200, '\P{^telugu}', "");
Expect(1, 3199, '\p{-	TELUGU}', "");
Expect(0, 3199, '\p{^-	TELUGU}', "");
Expect(0, 3199, '\P{-	TELUGU}', "");
Expect(1, 3199, '\P{^-	TELUGU}', "");
Expect(0, 3200, '\p{-	TELUGU}', "");
Expect(1, 3200, '\p{^-	TELUGU}', "");
Expect(1, 3200, '\P{-	TELUGU}', "");
Expect(0, 3200, '\P{^-	TELUGU}', "");
Error('\p{	 Is_telugu/a/}');
Error('\P{	 Is_telugu/a/}');
Expect(1, 3199, '\p{istelugu}', "");
Expect(0, 3199, '\p{^istelugu}', "");
Expect(0, 3199, '\P{istelugu}', "");
Expect(1, 3199, '\P{^istelugu}', "");
Expect(0, 3200, '\p{istelugu}', "");
Expect(1, 3200, '\p{^istelugu}', "");
Expect(1, 3200, '\P{istelugu}', "");
Expect(0, 3200, '\P{^istelugu}', "");
Expect(1, 3199, '\p{-	Is_Telugu}', "");
Expect(0, 3199, '\p{^-	Is_Telugu}', "");
Expect(0, 3199, '\P{-	Is_Telugu}', "");
Expect(1, 3199, '\P{^-	Is_Telugu}', "");
Expect(0, 3200, '\p{-	Is_Telugu}', "");
Expect(1, 3200, '\p{^-	Is_Telugu}', "");
Expect(1, 3200, '\P{-	Is_Telugu}', "");
Expect(0, 3200, '\P{^-	Is_Telugu}', "");
Error('\p{_telu:=}');
Error('\P{_telu:=}');
Expect(1, 3199, '\p{telu}', "");
Expect(0, 3199, '\p{^telu}', "");
Expect(0, 3199, '\P{telu}', "");
Expect(1, 3199, '\P{^telu}', "");
Expect(0, 3200, '\p{telu}', "");
Expect(1, 3200, '\p{^telu}', "");
Expect(1, 3200, '\P{telu}', "");
Expect(0, 3200, '\P{^telu}', "");
Expect(1, 3199, '\p{-_Telu}', "");
Expect(0, 3199, '\p{^-_Telu}', "");
Expect(0, 3199, '\P{-_Telu}', "");
Expect(1, 3199, '\P{^-_Telu}', "");
Expect(0, 3200, '\p{-_Telu}', "");
Expect(1, 3200, '\p{^-_Telu}', "");
Expect(1, 3200, '\P{-_Telu}', "");
Expect(0, 3200, '\P{^-_Telu}', "");
Error('\p{:=-Is_Telu}');
Error('\P{:=-Is_Telu}');
Expect(1, 3199, '\p{istelu}', "");
Expect(0, 3199, '\p{^istelu}', "");
Expect(0, 3199, '\P{istelu}', "");
Expect(1, 3199, '\P{^istelu}', "");
Expect(0, 3200, '\p{istelu}', "");
Expect(1, 3200, '\p{^istelu}', "");
Expect(1, 3200, '\P{istelu}', "");
Expect(0, 3200, '\P{^istelu}', "");
Expect(1, 3199, '\p{ IS_Telu}', "");
Expect(0, 3199, '\p{^ IS_Telu}', "");
Expect(0, 3199, '\P{ IS_Telu}', "");
Expect(1, 3199, '\P{^ IS_Telu}', "");
Expect(0, 3200, '\p{ IS_Telu}', "");
Expect(1, 3200, '\p{^ IS_Telu}', "");
Expect(1, 3200, '\P{ IS_Telu}', "");
Expect(0, 3200, '\P{^ IS_Telu}', "");
Error('\p{ Terminal_PUNCTUATION/a/}');
Error('\P{ Terminal_PUNCTUATION/a/}');
Expect(1, 74867, '\p{terminalpunctuation}', "");
Expect(0, 74867, '\p{^terminalpunctuation}', "");
Expect(0, 74867, '\P{terminalpunctuation}', "");
Expect(1, 74867, '\P{^terminalpunctuation}', "");
Expect(0, 74868, '\p{terminalpunctuation}', "");
Expect(1, 74868, '\p{^terminalpunctuation}', "");
Expect(1, 74868, '\P{terminalpunctuation}', "");
Expect(0, 74868, '\P{^terminalpunctuation}', "");
Expect(1, 74867, '\p{ 	TERMINAL_PUNCTUATION}', "");
Expect(0, 74867, '\p{^ 	TERMINAL_PUNCTUATION}', "");
Expect(0, 74867, '\P{ 	TERMINAL_PUNCTUATION}', "");
Expect(1, 74867, '\P{^ 	TERMINAL_PUNCTUATION}', "");
Expect(0, 74868, '\p{ 	TERMINAL_PUNCTUATION}', "");
Expect(1, 74868, '\p{^ 	TERMINAL_PUNCTUATION}', "");
Expect(1, 74868, '\P{ 	TERMINAL_PUNCTUATION}', "");
Expect(0, 74868, '\P{^ 	TERMINAL_PUNCTUATION}', "");
Error('\p{_:=IS_terminal_punctuation}');
Error('\P{_:=IS_terminal_punctuation}');
Expect(1, 74867, '\p{isterminalpunctuation}', "");
Expect(0, 74867, '\p{^isterminalpunctuation}', "");
Expect(0, 74867, '\P{isterminalpunctuation}', "");
Expect(1, 74867, '\P{^isterminalpunctuation}', "");
Expect(0, 74868, '\p{isterminalpunctuation}', "");
Expect(1, 74868, '\p{^isterminalpunctuation}', "");
Expect(1, 74868, '\P{isterminalpunctuation}', "");
Expect(0, 74868, '\P{^isterminalpunctuation}', "");
Expect(1, 74867, '\p{ 	is_Terminal_punctuation}', "");
Expect(0, 74867, '\p{^ 	is_Terminal_punctuation}', "");
Expect(0, 74867, '\P{ 	is_Terminal_punctuation}', "");
Expect(1, 74867, '\P{^ 	is_Terminal_punctuation}', "");
Expect(0, 74868, '\p{ 	is_Terminal_punctuation}', "");
Expect(1, 74868, '\p{^ 	is_Terminal_punctuation}', "");
Expect(1, 74868, '\P{ 	is_Terminal_punctuation}', "");
Expect(0, 74868, '\P{^ 	is_Terminal_punctuation}', "");
Error('\p{	/a/TERM}');
Error('\P{	/a/TERM}');
Expect(1, 74867, '\p{term}', "");
Expect(0, 74867, '\p{^term}', "");
Expect(0, 74867, '\P{term}', "");
Expect(1, 74867, '\P{^term}', "");
Expect(0, 74868, '\p{term}', "");
Expect(1, 74868, '\p{^term}', "");
Expect(1, 74868, '\P{term}', "");
Expect(0, 74868, '\P{^term}', "");
Expect(1, 74867, '\p{	_TERM}', "");
Expect(0, 74867, '\p{^	_TERM}', "");
Expect(0, 74867, '\P{	_TERM}', "");
Expect(1, 74867, '\P{^	_TERM}', "");
Expect(0, 74868, '\p{	_TERM}', "");
Expect(1, 74868, '\p{^	_TERM}', "");
Expect(1, 74868, '\P{	_TERM}', "");
Expect(0, 74868, '\P{^	_TERM}', "");
Error('\p{ -Is_Term:=}');
Error('\P{ -Is_Term:=}');
Expect(1, 74867, '\p{isterm}', "");
Expect(0, 74867, '\p{^isterm}', "");
Expect(0, 74867, '\P{isterm}', "");
Expect(1, 74867, '\P{^isterm}', "");
Expect(0, 74868, '\p{isterm}', "");
Expect(1, 74868, '\p{^isterm}', "");
Expect(1, 74868, '\P{isterm}', "");
Expect(0, 74868, '\P{^isterm}', "");
Expect(1, 74867, '\p{  Is_Term}', "");
Expect(0, 74867, '\p{^  Is_Term}', "");
Expect(0, 74867, '\P{  Is_Term}', "");
Expect(1, 74867, '\P{^  Is_Term}', "");
Expect(0, 74868, '\p{  Is_Term}', "");
Expect(1, 74868, '\p{^  Is_Term}', "");
Expect(1, 74868, '\P{  Is_Term}', "");
Expect(0, 74868, '\P{^  Is_Term}', "");
Error('\p{:=	Thaana}');
Error('\P{:=	Thaana}');
Expect(1, 1969, '\p{thaana}', "");
Expect(0, 1969, '\p{^thaana}', "");
Expect(0, 1969, '\P{thaana}', "");
Expect(1, 1969, '\P{^thaana}', "");
Expect(0, 1970, '\p{thaana}', "");
Expect(1, 1970, '\p{^thaana}', "");
Expect(1, 1970, '\P{thaana}', "");
Expect(0, 1970, '\P{^thaana}', "");
Expect(1, 1969, '\p{ Thaana}', "");
Expect(0, 1969, '\p{^ Thaana}', "");
Expect(0, 1969, '\P{ Thaana}', "");
Expect(1, 1969, '\P{^ Thaana}', "");
Expect(0, 1970, '\p{ Thaana}', "");
Expect(1, 1970, '\p{^ Thaana}', "");
Expect(1, 1970, '\P{ Thaana}', "");
Expect(0, 1970, '\P{^ Thaana}', "");
Error('\p{	IS_THAANA/a/}');
Error('\P{	IS_THAANA/a/}');
Expect(1, 1969, '\p{isthaana}', "");
Expect(0, 1969, '\p{^isthaana}', "");
Expect(0, 1969, '\P{isthaana}', "");
Expect(1, 1969, '\P{^isthaana}', "");
Expect(0, 1970, '\p{isthaana}', "");
Expect(1, 1970, '\p{^isthaana}', "");
Expect(1, 1970, '\P{isthaana}', "");
Expect(0, 1970, '\P{^isthaana}', "");
Expect(1, 1969, '\p{		is_THAANA}', "");
Expect(0, 1969, '\p{^		is_THAANA}', "");
Expect(0, 1969, '\P{		is_THAANA}', "");
Expect(1, 1969, '\P{^		is_THAANA}', "");
Expect(0, 1970, '\p{		is_THAANA}', "");
Expect(1, 1970, '\p{^		is_THAANA}', "");
Expect(1, 1970, '\P{		is_THAANA}', "");
Expect(0, 1970, '\P{^		is_THAANA}', "");
Error('\p{/a/-_THAA}');
Error('\P{/a/-_THAA}');
Expect(1, 1969, '\p{thaa}', "");
Expect(0, 1969, '\p{^thaa}', "");
Expect(0, 1969, '\P{thaa}', "");
Expect(1, 1969, '\P{^thaa}', "");
Expect(0, 1970, '\p{thaa}', "");
Expect(1, 1970, '\p{^thaa}', "");
Expect(1, 1970, '\P{thaa}', "");
Expect(0, 1970, '\P{^thaa}', "");
Expect(1, 1969, '\p{ 	thaa}', "");
Expect(0, 1969, '\p{^ 	thaa}', "");
Expect(0, 1969, '\P{ 	thaa}', "");
Expect(1, 1969, '\P{^ 	thaa}', "");
Expect(0, 1970, '\p{ 	thaa}', "");
Expect(1, 1970, '\p{^ 	thaa}', "");
Expect(1, 1970, '\P{ 	thaa}', "");
Expect(0, 1970, '\P{^ 	thaa}', "");
Error('\p{/a/ Is_thaa}');
Error('\P{/a/ Is_thaa}');
Expect(1, 1969, '\p{isthaa}', "");
Expect(0, 1969, '\p{^isthaa}', "");
Expect(0, 1969, '\P{isthaa}', "");
Expect(1, 1969, '\P{^isthaa}', "");
Expect(0, 1970, '\p{isthaa}', "");
Expect(1, 1970, '\p{^isthaa}', "");
Expect(1, 1970, '\P{isthaa}', "");
Expect(0, 1970, '\P{^isthaa}', "");
Expect(1, 1969, '\p{-	Is_THAA}', "");
Expect(0, 1969, '\p{^-	Is_THAA}', "");
Expect(0, 1969, '\P{-	Is_THAA}', "");
Expect(1, 1969, '\P{^-	Is_THAA}', "");
Expect(0, 1970, '\p{-	Is_THAA}', "");
Expect(1, 1970, '\p{^-	Is_THAA}', "");
Expect(1, 1970, '\P{-	Is_THAA}', "");
Expect(0, 1970, '\P{^-	Is_THAA}', "");
Error('\p{_/a/THAI}');
Error('\P{_/a/THAI}');
Expect(1, 3675, '\p{thai}', "");
Expect(0, 3675, '\p{^thai}', "");
Expect(0, 3675, '\P{thai}', "");
Expect(1, 3675, '\P{^thai}', "");
Expect(0, 3676, '\p{thai}', "");
Expect(1, 3676, '\p{^thai}', "");
Expect(1, 3676, '\P{thai}', "");
Expect(0, 3676, '\P{^thai}', "");
Expect(1, 3675, '\p{	_thai}', "");
Expect(0, 3675, '\p{^	_thai}', "");
Expect(0, 3675, '\P{	_thai}', "");
Expect(1, 3675, '\P{^	_thai}', "");
Expect(0, 3676, '\p{	_thai}', "");
Expect(1, 3676, '\p{^	_thai}', "");
Expect(1, 3676, '\P{	_thai}', "");
Expect(0, 3676, '\P{^	_thai}', "");
Error('\p{	/a/Is_Thai}');
Error('\P{	/a/Is_Thai}');
Expect(1, 3675, '\p{isthai}', "");
Expect(0, 3675, '\p{^isthai}', "");
Expect(0, 3675, '\P{isthai}', "");
Expect(1, 3675, '\P{^isthai}', "");
Expect(0, 3676, '\p{isthai}', "");
Expect(1, 3676, '\p{^isthai}', "");
Expect(1, 3676, '\P{isthai}', "");
Expect(0, 3676, '\P{^isthai}', "");
Expect(1, 3675, '\p{	Is_Thai}', "");
Expect(0, 3675, '\p{^	Is_Thai}', "");
Expect(0, 3675, '\P{	Is_Thai}', "");
Expect(1, 3675, '\P{^	Is_Thai}', "");
Expect(0, 3676, '\p{	Is_Thai}', "");
Expect(1, 3676, '\p{^	Is_Thai}', "");
Expect(1, 3676, '\P{	Is_Thai}', "");
Expect(0, 3676, '\P{^	Is_Thai}', "");
Error('\p{_TIBETAN:=}');
Error('\P{_TIBETAN:=}');
Expect(1, 4058, '\p{tibetan}', "");
Expect(0, 4058, '\p{^tibetan}', "");
Expect(0, 4058, '\P{tibetan}', "");
Expect(1, 4058, '\P{^tibetan}', "");
Expect(0, 4059, '\p{tibetan}', "");
Expect(1, 4059, '\p{^tibetan}', "");
Expect(1, 4059, '\P{tibetan}', "");
Expect(0, 4059, '\P{^tibetan}', "");
Expect(1, 4058, '\p{	TIBETAN}', "");
Expect(0, 4058, '\p{^	TIBETAN}', "");
Expect(0, 4058, '\P{	TIBETAN}', "");
Expect(1, 4058, '\P{^	TIBETAN}', "");
Expect(0, 4059, '\p{	TIBETAN}', "");
Expect(1, 4059, '\p{^	TIBETAN}', "");
Expect(1, 4059, '\P{	TIBETAN}', "");
Expect(0, 4059, '\P{^	TIBETAN}', "");
Error('\p{-Is_Tibetan/a/}');
Error('\P{-Is_Tibetan/a/}');
Expect(1, 4058, '\p{istibetan}', "");
Expect(0, 4058, '\p{^istibetan}', "");
Expect(0, 4058, '\P{istibetan}', "");
Expect(1, 4058, '\P{^istibetan}', "");
Expect(0, 4059, '\p{istibetan}', "");
Expect(1, 4059, '\p{^istibetan}', "");
Expect(1, 4059, '\P{istibetan}', "");
Expect(0, 4059, '\P{^istibetan}', "");
Expect(1, 4058, '\p{-Is_TIBETAN}', "");
Expect(0, 4058, '\p{^-Is_TIBETAN}', "");
Expect(0, 4058, '\P{-Is_TIBETAN}', "");
Expect(1, 4058, '\P{^-Is_TIBETAN}', "");
Expect(0, 4059, '\p{-Is_TIBETAN}', "");
Expect(1, 4059, '\p{^-Is_TIBETAN}', "");
Expect(1, 4059, '\P{-Is_TIBETAN}', "");
Expect(0, 4059, '\P{^-Is_TIBETAN}', "");
Error('\p{/a/ _TIBT}');
Error('\P{/a/ _TIBT}');
Expect(1, 4058, '\p{tibt}', "");
Expect(0, 4058, '\p{^tibt}', "");
Expect(0, 4058, '\P{tibt}', "");
Expect(1, 4058, '\P{^tibt}', "");
Expect(0, 4059, '\p{tibt}', "");
Expect(1, 4059, '\p{^tibt}', "");
Expect(1, 4059, '\P{tibt}', "");
Expect(0, 4059, '\P{^tibt}', "");
Expect(1, 4058, '\p{ -TIBT}', "");
Expect(0, 4058, '\p{^ -TIBT}', "");
Expect(0, 4058, '\P{ -TIBT}', "");
Expect(1, 4058, '\P{^ -TIBT}', "");
Expect(0, 4059, '\p{ -TIBT}', "");
Expect(1, 4059, '\p{^ -TIBT}', "");
Expect(1, 4059, '\P{ -TIBT}', "");
Expect(0, 4059, '\P{^ -TIBT}', "");
Error('\p{	-is_Tibt/a/}');
Error('\P{	-is_Tibt/a/}');
Expect(1, 4058, '\p{istibt}', "");
Expect(0, 4058, '\p{^istibt}', "");
Expect(0, 4058, '\P{istibt}', "");
Expect(1, 4058, '\P{^istibt}', "");
Expect(0, 4059, '\p{istibt}', "");
Expect(1, 4059, '\p{^istibt}', "");
Expect(1, 4059, '\P{istibt}', "");
Expect(0, 4059, '\P{^istibt}', "");
Expect(1, 4058, '\p{ _IS_Tibt}', "");
Expect(0, 4058, '\p{^ _IS_Tibt}', "");
Expect(0, 4058, '\P{ _IS_Tibt}', "");
Expect(1, 4058, '\P{^ _IS_Tibt}', "");
Expect(0, 4059, '\p{ _IS_Tibt}', "");
Expect(1, 4059, '\p{^ _IS_Tibt}', "");
Expect(1, 4059, '\P{ _IS_Tibt}', "");
Expect(0, 4059, '\P{^ _IS_Tibt}', "");
Error('\p{-/a/TIFINAGH}');
Error('\P{-/a/TIFINAGH}');
Expect(1, 11647, '\p{tifinagh}', "");
Expect(0, 11647, '\p{^tifinagh}', "");
Expect(0, 11647, '\P{tifinagh}', "");
Expect(1, 11647, '\P{^tifinagh}', "");
Expect(0, 11648, '\p{tifinagh}', "");
Expect(1, 11648, '\p{^tifinagh}', "");
Expect(1, 11648, '\P{tifinagh}', "");
Expect(0, 11648, '\P{^tifinagh}', "");
Expect(1, 11647, '\p{-	Tifinagh}', "");
Expect(0, 11647, '\p{^-	Tifinagh}', "");
Expect(0, 11647, '\P{-	Tifinagh}', "");
Expect(1, 11647, '\P{^-	Tifinagh}', "");
Expect(0, 11648, '\p{-	Tifinagh}', "");
Expect(1, 11648, '\p{^-	Tifinagh}', "");
Expect(1, 11648, '\P{-	Tifinagh}', "");
Expect(0, 11648, '\P{^-	Tifinagh}', "");
Error('\p{ is_tifinagh:=}');
Error('\P{ is_tifinagh:=}');
Expect(1, 11647, '\p{istifinagh}', "");
Expect(0, 11647, '\p{^istifinagh}', "");
Expect(0, 11647, '\P{istifinagh}', "");
Expect(1, 11647, '\P{^istifinagh}', "");
Expect(0, 11648, '\p{istifinagh}', "");
Expect(1, 11648, '\p{^istifinagh}', "");
Expect(1, 11648, '\P{istifinagh}', "");
Expect(0, 11648, '\P{^istifinagh}', "");
Expect(1, 11647, '\p{	 Is_Tifinagh}', "");
Expect(0, 11647, '\p{^	 Is_Tifinagh}', "");
Expect(0, 11647, '\P{	 Is_Tifinagh}', "");
Expect(1, 11647, '\P{^	 Is_Tifinagh}', "");
Expect(0, 11648, '\p{	 Is_Tifinagh}', "");
Expect(1, 11648, '\p{^	 Is_Tifinagh}', "");
Expect(1, 11648, '\P{	 Is_Tifinagh}', "");
Expect(0, 11648, '\P{^	 Is_Tifinagh}', "");
Error('\p{_	Tfng:=}');
Error('\P{_	Tfng:=}');
Expect(1, 11647, '\p{tfng}', "");
Expect(0, 11647, '\p{^tfng}', "");
Expect(0, 11647, '\P{tfng}', "");
Expect(1, 11647, '\P{^tfng}', "");
Expect(0, 11648, '\p{tfng}', "");
Expect(1, 11648, '\p{^tfng}', "");
Expect(1, 11648, '\P{tfng}', "");
Expect(0, 11648, '\P{^tfng}', "");
Expect(1, 11647, '\p{- Tfng}', "");
Expect(0, 11647, '\p{^- Tfng}', "");
Expect(0, 11647, '\P{- Tfng}', "");
Expect(1, 11647, '\P{^- Tfng}', "");
Expect(0, 11648, '\p{- Tfng}', "");
Expect(1, 11648, '\p{^- Tfng}', "");
Expect(1, 11648, '\P{- Tfng}', "");
Expect(0, 11648, '\P{^- Tfng}', "");
Error('\p{:=	 IS_TFNG}');
Error('\P{:=	 IS_TFNG}');
Expect(1, 11647, '\p{istfng}', "");
Expect(0, 11647, '\p{^istfng}', "");
Expect(0, 11647, '\P{istfng}', "");
Expect(1, 11647, '\P{^istfng}', "");
Expect(0, 11648, '\p{istfng}', "");
Expect(1, 11648, '\p{^istfng}', "");
Expect(1, 11648, '\P{istfng}', "");
Expect(0, 11648, '\P{^istfng}', "");
Expect(1, 11647, '\p{ Is_Tfng}', "");
Expect(0, 11647, '\p{^ Is_Tfng}', "");
Expect(0, 11647, '\P{ Is_Tfng}', "");
Expect(1, 11647, '\P{^ Is_Tfng}', "");
Expect(0, 11648, '\p{ Is_Tfng}', "");
Expect(1, 11648, '\p{^ Is_Tfng}', "");
Expect(1, 11648, '\P{ Is_Tfng}', "");
Expect(0, 11648, '\P{^ Is_Tfng}', "");
Error('\p{:=TITLECASE}');
Error('\P{:=TITLECASE}');
Expect(1, 8188, '\p{titlecase}', "");
Expect(0, 8188, '\p{^titlecase}', "");
Expect(0, 8188, '\P{titlecase}', "");
Expect(1, 8188, '\P{^titlecase}', "");
Expect(0, 8189, '\p{titlecase}', "");
Expect(1, 8189, '\p{^titlecase}', "");
Expect(1, 8189, '\P{titlecase}', "");
Expect(0, 8189, '\P{^titlecase}', "");
Expect(1, 8188, '\p{	_Titlecase}', "");
Expect(0, 8188, '\p{^	_Titlecase}', "");
Expect(0, 8188, '\P{	_Titlecase}', "");
Expect(1, 8188, '\P{^	_Titlecase}', "");
Expect(0, 8189, '\p{	_Titlecase}', "");
Expect(1, 8189, '\p{^	_Titlecase}', "");
Expect(1, 8189, '\P{	_Titlecase}', "");
Expect(0, 8189, '\P{^	_Titlecase}', "");
Error('\p{ :=TITLE}');
Error('\P{ :=TITLE}');
Expect(1, 8188, '\p{title}', "");
Expect(0, 8188, '\p{^title}', "");
Expect(0, 8188, '\P{title}', "");
Expect(1, 8188, '\P{^title}', "");
Expect(0, 8189, '\p{title}', "");
Expect(1, 8189, '\p{^title}', "");
Expect(1, 8189, '\P{title}', "");
Expect(0, 8189, '\P{^title}', "");
Expect(1, 8188, '\p{ 	title}', "");
Expect(0, 8188, '\p{^ 	title}', "");
Expect(0, 8188, '\P{ 	title}', "");
Expect(1, 8188, '\P{^ 	title}', "");
Expect(0, 8189, '\p{ 	title}', "");
Expect(1, 8189, '\p{^ 	title}', "");
Expect(1, 8189, '\P{ 	title}', "");
Expect(0, 8189, '\P{^ 	title}', "");
Error('\p{/a/ 	Is_Titlecase}');
Error('\P{/a/ 	Is_Titlecase}');
Expect(1, 8188, '\p{istitlecase}', "");
Expect(0, 8188, '\p{^istitlecase}', "");
Expect(0, 8188, '\P{istitlecase}', "");
Expect(1, 8188, '\P{^istitlecase}', "");
Expect(0, 8189, '\p{istitlecase}', "");
Expect(1, 8189, '\p{^istitlecase}', "");
Expect(1, 8189, '\P{istitlecase}', "");
Expect(0, 8189, '\P{^istitlecase}', "");
Expect(1, 8188, '\p{		is_TITLECASE}', "");
Expect(0, 8188, '\p{^		is_TITLECASE}', "");
Expect(0, 8188, '\P{		is_TITLECASE}', "");
Expect(1, 8188, '\P{^		is_TITLECASE}', "");
Expect(0, 8189, '\p{		is_TITLECASE}', "");
Expect(1, 8189, '\p{^		is_TITLECASE}', "");
Expect(1, 8189, '\P{		is_TITLECASE}', "");
Expect(0, 8189, '\P{^		is_TITLECASE}', "");
Error('\p{- is_Title/a/}');
Error('\P{- is_Title/a/}');
Expect(1, 8188, '\p{istitle}', "");
Expect(0, 8188, '\p{^istitle}', "");
Expect(0, 8188, '\P{istitle}', "");
Expect(1, 8188, '\P{^istitle}', "");
Expect(0, 8189, '\p{istitle}', "");
Expect(1, 8189, '\p{^istitle}', "");
Expect(1, 8189, '\P{istitle}', "");
Expect(0, 8189, '\P{^istitle}', "");
Expect(1, 8188, '\p{ 	IS_TITLE}', "");
Expect(0, 8188, '\p{^ 	IS_TITLE}', "");
Expect(0, 8188, '\P{ 	IS_TITLE}', "");
Expect(1, 8188, '\P{^ 	IS_TITLE}', "");
Expect(0, 8189, '\p{ 	IS_TITLE}', "");
Expect(1, 8189, '\p{^ 	IS_TITLE}', "");
Expect(1, 8189, '\P{ 	IS_TITLE}', "");
Expect(0, 8189, '\P{^ 	IS_TITLE}', "");
Error('\p{:=_Titlecase_LETTER}');
Error('\P{:=_Titlecase_LETTER}');
Expect(1, 8188, '\p{titlecaseletter}', "");
Expect(0, 8188, '\p{^titlecaseletter}', "");
Expect(0, 8188, '\P{titlecaseletter}', "");
Expect(1, 8188, '\P{^titlecaseletter}', "");
Expect(0, 8189, '\p{titlecaseletter}', "");
Expect(1, 8189, '\p{^titlecaseletter}', "");
Expect(1, 8189, '\P{titlecaseletter}', "");
Expect(0, 8189, '\P{^titlecaseletter}', "");
Expect(1, 8188, '\p{ TITLECASE_Letter}', "");
Expect(0, 8188, '\p{^ TITLECASE_Letter}', "");
Expect(0, 8188, '\P{ TITLECASE_Letter}', "");
Expect(1, 8188, '\P{^ TITLECASE_Letter}', "");
Expect(0, 8189, '\p{ TITLECASE_Letter}', "");
Expect(1, 8189, '\p{^ TITLECASE_Letter}', "");
Expect(1, 8189, '\P{ TITLECASE_Letter}', "");
Expect(0, 8189, '\P{^ TITLECASE_Letter}', "");
Error('\p{- is_titlecase_letter:=}');
Error('\P{- is_titlecase_letter:=}');
Expect(1, 8188, '\p{istitlecaseletter}', "");
Expect(0, 8188, '\p{^istitlecaseletter}', "");
Expect(0, 8188, '\P{istitlecaseletter}', "");
Expect(1, 8188, '\P{^istitlecaseletter}', "");
Expect(0, 8189, '\p{istitlecaseletter}', "");
Expect(1, 8189, '\p{^istitlecaseletter}', "");
Expect(1, 8189, '\P{istitlecaseletter}', "");
Expect(0, 8189, '\P{^istitlecaseletter}', "");
Expect(1, 8188, '\p{--Is_Titlecase_Letter}', "");
Expect(0, 8188, '\p{^--Is_Titlecase_Letter}', "");
Expect(0, 8188, '\P{--Is_Titlecase_Letter}', "");
Expect(1, 8188, '\P{^--Is_Titlecase_Letter}', "");
Expect(0, 8189, '\p{--Is_Titlecase_Letter}', "");
Expect(1, 8189, '\p{^--Is_Titlecase_Letter}', "");
Expect(1, 8189, '\P{--Is_Titlecase_Letter}', "");
Expect(0, 8189, '\P{^--Is_Titlecase_Letter}', "");
Error('\p{:=lt}');
Error('\P{:=lt}');
Expect(1, 8188, '\p{lt}', "");
Expect(0, 8188, '\p{^lt}', "");
Expect(0, 8188, '\P{lt}', "");
Expect(1, 8188, '\P{^lt}', "");
Expect(0, 8189, '\p{lt}', "");
Expect(1, 8189, '\p{^lt}', "");
Expect(1, 8189, '\P{lt}', "");
Expect(0, 8189, '\P{^lt}', "");
Expect(1, 8188, '\p{ Lt}', "");
Expect(0, 8188, '\p{^ Lt}', "");
Expect(0, 8188, '\P{ Lt}', "");
Expect(1, 8188, '\P{^ Lt}', "");
Expect(0, 8189, '\p{ Lt}', "");
Expect(1, 8189, '\p{^ Lt}', "");
Expect(1, 8189, '\P{ Lt}', "");
Expect(0, 8189, '\P{^ Lt}', "");
Error('\p{_/a/is_LT}');
Error('\P{_/a/is_LT}');
Expect(1, 8188, '\p{islt}', "");
Expect(0, 8188, '\p{^islt}', "");
Expect(0, 8188, '\P{islt}', "");
Expect(1, 8188, '\P{^islt}', "");
Expect(0, 8189, '\p{islt}', "");
Expect(1, 8189, '\p{^islt}', "");
Expect(1, 8189, '\P{islt}', "");
Expect(0, 8189, '\P{^islt}', "");
Expect(1, 8188, '\p{-	Is_Lt}', "");
Expect(0, 8188, '\p{^-	Is_Lt}', "");
Expect(0, 8188, '\P{-	Is_Lt}', "");
Expect(1, 8188, '\P{^-	Is_Lt}', "");
Expect(0, 8189, '\p{-	Is_Lt}', "");
Expect(1, 8189, '\p{^-	Is_Lt}', "");
Expect(1, 8189, '\P{-	Is_Lt}', "");
Expect(0, 8189, '\P{^-	Is_Lt}', "");
Error('\p{:=--transport_AND_Map_SYMBOLS}');
Error('\P{:=--transport_AND_Map_SYMBOLS}');
Expect(1, 128767, '\p{transportandmapsymbols}', "");
Expect(0, 128767, '\p{^transportandmapsymbols}', "");
Expect(0, 128767, '\P{transportandmapsymbols}', "");
Expect(1, 128767, '\P{^transportandmapsymbols}', "");
Expect(0, 128768, '\p{transportandmapsymbols}', "");
Expect(1, 128768, '\p{^transportandmapsymbols}', "");
Expect(1, 128768, '\P{transportandmapsymbols}', "");
Expect(0, 128768, '\P{^transportandmapsymbols}', "");
Expect(1, 128767, '\p{- Transport_and_map_Symbols}', "");
Expect(0, 128767, '\p{^- Transport_and_map_Symbols}', "");
Expect(0, 128767, '\P{- Transport_and_map_Symbols}', "");
Expect(1, 128767, '\P{^- Transport_and_map_Symbols}', "");
Expect(0, 128768, '\p{- Transport_and_map_Symbols}', "");
Expect(1, 128768, '\p{^- Transport_and_map_Symbols}', "");
Expect(1, 128768, '\P{- Transport_and_map_Symbols}', "");
Expect(0, 128768, '\P{^- Transport_and_map_Symbols}', "");
Error('\p{:=_is_Transport_And_MAP_Symbols}');
Error('\P{:=_is_Transport_And_MAP_Symbols}');
Expect(1, 128767, '\p{istransportandmapsymbols}', "");
Expect(0, 128767, '\p{^istransportandmapsymbols}', "");
Expect(0, 128767, '\P{istransportandmapsymbols}', "");
Expect(1, 128767, '\P{^istransportandmapsymbols}', "");
Expect(0, 128768, '\p{istransportandmapsymbols}', "");
Expect(1, 128768, '\p{^istransportandmapsymbols}', "");
Expect(1, 128768, '\P{istransportandmapsymbols}', "");
Expect(0, 128768, '\P{^istransportandmapsymbols}', "");
Expect(1, 128767, '\p{-Is_Transport_And_MAP_symbols}', "");
Expect(0, 128767, '\p{^-Is_Transport_And_MAP_symbols}', "");
Expect(0, 128767, '\P{-Is_Transport_And_MAP_symbols}', "");
Expect(1, 128767, '\P{^-Is_Transport_And_MAP_symbols}', "");
Expect(0, 128768, '\p{-Is_Transport_And_MAP_symbols}', "");
Expect(1, 128768, '\p{^-Is_Transport_And_MAP_symbols}', "");
Expect(1, 128768, '\P{-Is_Transport_And_MAP_symbols}', "");
Expect(0, 128768, '\P{^-Is_Transport_And_MAP_symbols}', "");
Error('\p{:=IN_transport_And_MAP_SYMBOLS}');
Error('\P{:=IN_transport_And_MAP_SYMBOLS}');
Expect(1, 128767, '\p{intransportandmapsymbols}', "");
Expect(0, 128767, '\p{^intransportandmapsymbols}', "");
Expect(0, 128767, '\P{intransportandmapsymbols}', "");
Expect(1, 128767, '\P{^intransportandmapsymbols}', "");
Expect(0, 128768, '\p{intransportandmapsymbols}', "");
Expect(1, 128768, '\p{^intransportandmapsymbols}', "");
Expect(1, 128768, '\P{intransportandmapsymbols}', "");
Expect(0, 128768, '\P{^intransportandmapsymbols}', "");
Expect(1, 128767, '\p{ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(0, 128767, '\p{^ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(0, 128767, '\P{ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(1, 128767, '\P{^ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(0, 128768, '\p{ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(1, 128768, '\p{^ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(1, 128768, '\P{ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Expect(0, 128768, '\P{^ 	IN_TRANSPORT_AND_MAP_Symbols}', "");
Error('\p{ _transport_AND_MAP:=}');
Error('\P{ _transport_AND_MAP:=}');
Expect(1, 128767, '\p{transportandmap}', "");
Expect(0, 128767, '\p{^transportandmap}', "");
Expect(0, 128767, '\P{transportandmap}', "");
Expect(1, 128767, '\P{^transportandmap}', "");
Expect(0, 128768, '\p{transportandmap}', "");
Expect(1, 128768, '\p{^transportandmap}', "");
Expect(1, 128768, '\P{transportandmap}', "");
Expect(0, 128768, '\P{^transportandmap}', "");
Expect(1, 128767, '\p{_-TRANSPORT_and_MAP}', "");
Expect(0, 128767, '\p{^_-TRANSPORT_and_MAP}', "");
Expect(0, 128767, '\P{_-TRANSPORT_and_MAP}', "");
Expect(1, 128767, '\P{^_-TRANSPORT_and_MAP}', "");
Expect(0, 128768, '\p{_-TRANSPORT_and_MAP}', "");
Expect(1, 128768, '\p{^_-TRANSPORT_and_MAP}', "");
Expect(1, 128768, '\P{_-TRANSPORT_and_MAP}', "");
Expect(0, 128768, '\P{^_-TRANSPORT_and_MAP}', "");
Error('\p{ :=Is_Transport_And_Map}');
Error('\P{ :=Is_Transport_And_Map}');
Expect(1, 128767, '\p{istransportandmap}', "");
Expect(0, 128767, '\p{^istransportandmap}', "");
Expect(0, 128767, '\P{istransportandmap}', "");
Expect(1, 128767, '\P{^istransportandmap}', "");
Expect(0, 128768, '\p{istransportandmap}', "");
Expect(1, 128768, '\p{^istransportandmap}', "");
Expect(1, 128768, '\P{istransportandmap}', "");
Expect(0, 128768, '\P{^istransportandmap}', "");
Expect(1, 128767, '\p{_is_Transport_AND_Map}', "");
Expect(0, 128767, '\p{^_is_Transport_AND_Map}', "");
Expect(0, 128767, '\P{_is_Transport_AND_Map}', "");
Expect(1, 128767, '\P{^_is_Transport_AND_Map}', "");
Expect(0, 128768, '\p{_is_Transport_AND_Map}', "");
Expect(1, 128768, '\p{^_is_Transport_AND_Map}', "");
Expect(1, 128768, '\P{_is_Transport_AND_Map}', "");
Expect(0, 128768, '\P{^_is_Transport_AND_Map}', "");
Error('\p{_In_Transport_And_Map:=}');
Error('\P{_In_Transport_And_Map:=}');
Expect(1, 128767, '\p{intransportandmap}', "");
Expect(0, 128767, '\p{^intransportandmap}', "");
Expect(0, 128767, '\P{intransportandmap}', "");
Expect(1, 128767, '\P{^intransportandmap}', "");
Expect(0, 128768, '\p{intransportandmap}', "");
Expect(1, 128768, '\p{^intransportandmap}', "");
Expect(1, 128768, '\P{intransportandmap}', "");
Expect(0, 128768, '\P{^intransportandmap}', "");
Expect(1, 128767, '\p{		IN_transport_And_Map}', "");
Expect(0, 128767, '\p{^		IN_transport_And_Map}', "");
Expect(0, 128767, '\P{		IN_transport_And_Map}', "");
Expect(1, 128767, '\P{^		IN_transport_And_Map}', "");
Expect(0, 128768, '\p{		IN_transport_And_Map}', "");
Expect(1, 128768, '\p{^		IN_transport_And_Map}', "");
Expect(1, 128768, '\P{		IN_transport_And_Map}', "");
Expect(0, 128768, '\P{^		IN_transport_And_Map}', "");
Error('\p{_:=ugaritic}');
Error('\P{_:=ugaritic}');
Expect(1, 66463, '\p{ugaritic}', "");
Expect(0, 66463, '\p{^ugaritic}', "");
Expect(0, 66463, '\P{ugaritic}', "");
Expect(1, 66463, '\P{^ugaritic}', "");
Expect(0, 66464, '\p{ugaritic}', "");
Expect(1, 66464, '\p{^ugaritic}', "");
Expect(1, 66464, '\P{ugaritic}', "");
Expect(0, 66464, '\P{^ugaritic}', "");
Expect(1, 66463, '\p{-UGARITIC}', "");
Expect(0, 66463, '\p{^-UGARITIC}', "");
Expect(0, 66463, '\P{-UGARITIC}', "");
Expect(1, 66463, '\P{^-UGARITIC}', "");
Expect(0, 66464, '\p{-UGARITIC}', "");
Expect(1, 66464, '\p{^-UGARITIC}', "");
Expect(1, 66464, '\P{-UGARITIC}', "");
Expect(0, 66464, '\P{^-UGARITIC}', "");
Error('\p{:= IS_ugaritic}');
Error('\P{:= IS_ugaritic}');
Expect(1, 66463, '\p{isugaritic}', "");
Expect(0, 66463, '\p{^isugaritic}', "");
Expect(0, 66463, '\P{isugaritic}', "");
Expect(1, 66463, '\P{^isugaritic}', "");
Expect(0, 66464, '\p{isugaritic}', "");
Expect(1, 66464, '\p{^isugaritic}', "");
Expect(1, 66464, '\P{isugaritic}', "");
Expect(0, 66464, '\P{^isugaritic}', "");
Expect(1, 66463, '\p{	Is_UGARITIC}', "");
Expect(0, 66463, '\p{^	Is_UGARITIC}', "");
Expect(0, 66463, '\P{	Is_UGARITIC}', "");
Expect(1, 66463, '\P{^	Is_UGARITIC}', "");
Expect(0, 66464, '\p{	Is_UGARITIC}', "");
Expect(1, 66464, '\p{^	Is_UGARITIC}', "");
Expect(1, 66464, '\P{	Is_UGARITIC}', "");
Expect(0, 66464, '\P{^	Is_UGARITIC}', "");
Error('\p{:=  Ugar}');
Error('\P{:=  Ugar}');
Expect(1, 66463, '\p{ugar}', "");
Expect(0, 66463, '\p{^ugar}', "");
Expect(0, 66463, '\P{ugar}', "");
Expect(1, 66463, '\P{^ugar}', "");
Expect(0, 66464, '\p{ugar}', "");
Expect(1, 66464, '\p{^ugar}', "");
Expect(1, 66464, '\P{ugar}', "");
Expect(0, 66464, '\P{^ugar}', "");
Expect(1, 66463, '\p{-Ugar}', "");
Expect(0, 66463, '\p{^-Ugar}', "");
Expect(0, 66463, '\P{-Ugar}', "");
Expect(1, 66463, '\P{^-Ugar}', "");
Expect(0, 66464, '\p{-Ugar}', "");
Expect(1, 66464, '\p{^-Ugar}', "");
Expect(1, 66464, '\P{-Ugar}', "");
Expect(0, 66464, '\P{^-Ugar}', "");
Error('\p{ IS_UGAR/a/}');
Error('\P{ IS_UGAR/a/}');
Expect(1, 66463, '\p{isugar}', "");
Expect(0, 66463, '\p{^isugar}', "");
Expect(0, 66463, '\P{isugar}', "");
Expect(1, 66463, '\P{^isugar}', "");
Expect(0, 66464, '\p{isugar}', "");
Expect(1, 66464, '\p{^isugar}', "");
Expect(1, 66464, '\P{isugar}', "");
Expect(0, 66464, '\P{^isugar}', "");
Expect(1, 66463, '\p{--IS_ugar}', "");
Expect(0, 66463, '\p{^--IS_ugar}', "");
Expect(0, 66463, '\P{--IS_ugar}', "");
Expect(1, 66463, '\P{^--IS_ugar}', "");
Expect(0, 66464, '\p{--IS_ugar}', "");
Expect(1, 66464, '\p{^--IS_ugar}', "");
Expect(1, 66464, '\P{--IS_ugar}', "");
Expect(0, 66464, '\P{^--IS_ugar}', "");
Error('\p{/a/ -unassigned}');
Error('\P{/a/ -unassigned}');
Expect(1, 918000, '\p{unassigned}', "");
Expect(0, 918000, '\p{^unassigned}', "");
Expect(0, 918000, '\P{unassigned}', "");
Expect(1, 918000, '\P{^unassigned}', "");
Expect(0, 1114109, '\p{unassigned}', "");
Expect(1, 1114109, '\p{^unassigned}', "");
Expect(1, 1114109, '\P{unassigned}', "");
Expect(0, 1114109, '\P{^unassigned}', "");
Expect(1, 918000, '\p{_-Unassigned}', "");
Expect(0, 918000, '\p{^_-Unassigned}', "");
Expect(0, 918000, '\P{_-Unassigned}', "");
Expect(1, 918000, '\P{^_-Unassigned}', "");
Expect(0, 1114109, '\p{_-Unassigned}', "");
Expect(1, 1114109, '\p{^_-Unassigned}', "");
Expect(1, 1114109, '\P{_-Unassigned}', "");
Expect(0, 1114109, '\P{^_-Unassigned}', "");
Error('\p{:=_	Is_UNASSIGNED}');
Error('\P{:=_	Is_UNASSIGNED}');
Expect(1, 918000, '\p{isunassigned}', "");
Expect(0, 918000, '\p{^isunassigned}', "");
Expect(0, 918000, '\P{isunassigned}', "");
Expect(1, 918000, '\P{^isunassigned}', "");
Expect(0, 1114109, '\p{isunassigned}', "");
Expect(1, 1114109, '\p{^isunassigned}', "");
Expect(1, 1114109, '\P{isunassigned}', "");
Expect(0, 1114109, '\P{^isunassigned}', "");
Expect(1, 918000, '\p{ Is_Unassigned}', "");
Expect(0, 918000, '\p{^ Is_Unassigned}', "");
Expect(0, 918000, '\P{ Is_Unassigned}', "");
Expect(1, 918000, '\P{^ Is_Unassigned}', "");
Expect(0, 1114109, '\p{ Is_Unassigned}', "");
Expect(1, 1114109, '\p{^ Is_Unassigned}', "");
Expect(1, 1114109, '\P{ Is_Unassigned}', "");
Expect(0, 1114109, '\P{^ Is_Unassigned}', "");
Error('\p{_CN/a/}');
Error('\P{_CN/a/}');
Expect(1, 918000, '\p{cn}', "");
Expect(0, 918000, '\p{^cn}', "");
Expect(0, 918000, '\P{cn}', "");
Expect(1, 918000, '\P{^cn}', "");
Expect(0, 1114109, '\p{cn}', "");
Expect(1, 1114109, '\p{^cn}', "");
Expect(1, 1114109, '\P{cn}', "");
Expect(0, 1114109, '\P{^cn}', "");
Expect(1, 918000, '\p{_CN}', "");
Expect(0, 918000, '\p{^_CN}', "");
Expect(0, 918000, '\P{_CN}', "");
Expect(1, 918000, '\P{^_CN}', "");
Expect(0, 1114109, '\p{_CN}', "");
Expect(1, 1114109, '\p{^_CN}', "");
Expect(1, 1114109, '\P{_CN}', "");
Expect(0, 1114109, '\P{^_CN}', "");
Error('\p{ 	Is_CN:=}');
Error('\P{ 	Is_CN:=}');
Expect(1, 918000, '\p{iscn}', "");
Expect(0, 918000, '\p{^iscn}', "");
Expect(0, 918000, '\P{iscn}', "");
Expect(1, 918000, '\P{^iscn}', "");
Expect(0, 1114109, '\p{iscn}', "");
Expect(1, 1114109, '\p{^iscn}', "");
Expect(1, 1114109, '\P{iscn}', "");
Expect(0, 1114109, '\P{^iscn}', "");
Expect(1, 918000, '\p{ is_CN}', "");
Expect(0, 918000, '\p{^ is_CN}', "");
Expect(0, 918000, '\P{ is_CN}', "");
Expect(1, 918000, '\P{^ is_CN}', "");
Expect(0, 1114109, '\p{ is_CN}', "");
Expect(1, 1114109, '\p{^ is_CN}', "");
Expect(1, 1114109, '\P{ is_CN}', "");
Expect(0, 1114109, '\P{^ is_CN}', "");
Error('\p{:= -UNIFIED_Canadian_ABORIGINAL_Syllabics}');
Error('\P{:= -UNIFIED_Canadian_ABORIGINAL_Syllabics}');
Expect(1, 5759, '\p{unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{unifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^unifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{ unified_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^ unified_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{ unified_Canadian_aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^ unified_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{ unified_Canadian_aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^ unified_Canadian_aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{ unified_Canadian_aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^ unified_Canadian_aboriginal_Syllabics}', "");
Error('\p{_Is_unified_Canadian_Aboriginal_Syllabics/a/}');
Error('\P{_Is_unified_Canadian_Aboriginal_Syllabics/a/}');
Expect(1, 5759, '\p{isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{isunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^isunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^_	is_Unified_CANADIAN_Aboriginal_Syllabics}', "");
Error('\p{:=-_IN_Unified_CANADIAN_Aboriginal_Syllabics}');
Error('\P{:=-_IN_Unified_CANADIAN_Aboriginal_Syllabics}');
Expect(1, 5759, '\p{inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\p{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5759, '\P{inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\P{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\p{inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\p{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5760, '\P{inunifiedcanadianaboriginalsyllabics}', "");
Expect(0, 5760, '\P{^inunifiedcanadianaboriginalsyllabics}', "");
Expect(1, 5759, '\p{	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\p{^	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5759, '\P{	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5759, '\P{^	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\p{	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\p{^	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(1, 5760, '\P{	In_unified_Canadian_Aboriginal_Syllabics}', "");
Expect(0, 5760, '\P{^	In_unified_Canadian_Aboriginal_Syllabics}', "");
Error('\p{_ucas/a/}');
Error('\P{_ucas/a/}');
Expect(1, 5759, '\p{ucas}', "");
Expect(0, 5759, '\p{^ucas}', "");
Expect(0, 5759, '\P{ucas}', "");
Expect(1, 5759, '\P{^ucas}', "");
Expect(0, 5760, '\p{ucas}', "");
Expect(1, 5760, '\p{^ucas}', "");
Expect(1, 5760, '\P{ucas}', "");
Expect(0, 5760, '\P{^ucas}', "");
Expect(1, 5759, '\p{  UCAS}', "");
Expect(0, 5759, '\p{^  UCAS}', "");
Expect(0, 5759, '\P{  UCAS}', "");
Expect(1, 5759, '\P{^  UCAS}', "");
Expect(0, 5760, '\p{  UCAS}', "");
Expect(1, 5760, '\p{^  UCAS}', "");
Expect(1, 5760, '\P{  UCAS}', "");
Expect(0, 5760, '\P{^  UCAS}', "");
Error('\p{_is_UCAS:=}');
Error('\P{_is_UCAS:=}');
Expect(1, 5759, '\p{isucas}', "");
Expect(0, 5759, '\p{^isucas}', "");
Expect(0, 5759, '\P{isucas}', "");
Expect(1, 5759, '\P{^isucas}', "");
Expect(0, 5760, '\p{isucas}', "");
Expect(1, 5760, '\p{^isucas}', "");
Expect(1, 5760, '\P{isucas}', "");
Expect(0, 5760, '\P{^isucas}', "");
Expect(1, 5759, '\p{	-Is_ucas}', "");
Expect(0, 5759, '\p{^	-Is_ucas}', "");
Expect(0, 5759, '\P{	-Is_ucas}', "");
Expect(1, 5759, '\P{^	-Is_ucas}', "");
Expect(0, 5760, '\p{	-Is_ucas}', "");
Expect(1, 5760, '\p{^	-Is_ucas}', "");
Expect(1, 5760, '\P{	-Is_ucas}', "");
Expect(0, 5760, '\P{^	-Is_ucas}', "");
Error('\p{ In_ucas:=}');
Error('\P{ In_ucas:=}');
Expect(1, 5759, '\p{inucas}', "");
Expect(0, 5759, '\p{^inucas}', "");
Expect(0, 5759, '\P{inucas}', "");
Expect(1, 5759, '\P{^inucas}', "");
Expect(0, 5760, '\p{inucas}', "");
Expect(1, 5760, '\p{^inucas}', "");
Expect(1, 5760, '\P{inucas}', "");
Expect(0, 5760, '\P{^inucas}', "");
Expect(1, 5759, '\p{		in_UCAS}', "");
Expect(0, 5759, '\p{^		in_UCAS}', "");
Expect(0, 5759, '\P{		in_UCAS}', "");
Expect(1, 5759, '\P{^		in_UCAS}', "");
Expect(0, 5760, '\p{		in_UCAS}', "");
Expect(1, 5760, '\p{^		in_UCAS}', "");
Expect(1, 5760, '\P{		in_UCAS}', "");
Expect(0, 5760, '\P{^		in_UCAS}', "");
Error('\p{-Canadian_SYLLABICS/a/}');
Error('\P{-Canadian_SYLLABICS/a/}');
Expect(1, 5759, '\p{canadiansyllabics}', "");
Expect(0, 5759, '\p{^canadiansyllabics}', "");
Expect(0, 5759, '\P{canadiansyllabics}', "");
Expect(1, 5759, '\P{^canadiansyllabics}', "");
Expect(0, 5760, '\p{canadiansyllabics}', "");
Expect(1, 5760, '\p{^canadiansyllabics}', "");
Expect(1, 5760, '\P{canadiansyllabics}', "");
Expect(0, 5760, '\P{^canadiansyllabics}', "");
Expect(1, 5759, '\p{		canadian_Syllabics}', "");
Expect(0, 5759, '\p{^		canadian_Syllabics}', "");
Expect(0, 5759, '\P{		canadian_Syllabics}', "");
Expect(1, 5759, '\P{^		canadian_Syllabics}', "");
Expect(0, 5760, '\p{		canadian_Syllabics}', "");
Expect(1, 5760, '\p{^		canadian_Syllabics}', "");
Expect(1, 5760, '\P{		canadian_Syllabics}', "");
Expect(0, 5760, '\P{^		canadian_Syllabics}', "");
Error('\p{_:=IS_canadian_SYLLABICS}');
Error('\P{_:=IS_canadian_SYLLABICS}');
Expect(1, 5759, '\p{iscanadiansyllabics}', "");
Expect(0, 5759, '\p{^iscanadiansyllabics}', "");
Expect(0, 5759, '\P{iscanadiansyllabics}', "");
Expect(1, 5759, '\P{^iscanadiansyllabics}', "");
Expect(0, 5760, '\p{iscanadiansyllabics}', "");
Expect(1, 5760, '\p{^iscanadiansyllabics}', "");
Expect(1, 5760, '\P{iscanadiansyllabics}', "");
Expect(0, 5760, '\P{^iscanadiansyllabics}', "");
Expect(1, 5759, '\p{--Is_canadian_Syllabics}', "");
Expect(0, 5759, '\p{^--Is_canadian_Syllabics}', "");
Expect(0, 5759, '\P{--Is_canadian_Syllabics}', "");
Expect(1, 5759, '\P{^--Is_canadian_Syllabics}', "");
Expect(0, 5760, '\p{--Is_canadian_Syllabics}', "");
Expect(1, 5760, '\p{^--Is_canadian_Syllabics}', "");
Expect(1, 5760, '\P{--Is_canadian_Syllabics}', "");
Expect(0, 5760, '\P{^--Is_canadian_Syllabics}', "");
Error('\p{:= In_Canadian_syllabics}');
Error('\P{:= In_Canadian_syllabics}');
Expect(1, 5759, '\p{incanadiansyllabics}', "");
Expect(0, 5759, '\p{^incanadiansyllabics}', "");
Expect(0, 5759, '\P{incanadiansyllabics}', "");
Expect(1, 5759, '\P{^incanadiansyllabics}', "");
Expect(0, 5760, '\p{incanadiansyllabics}', "");
Expect(1, 5760, '\p{^incanadiansyllabics}', "");
Expect(1, 5760, '\P{incanadiansyllabics}', "");
Expect(0, 5760, '\P{^incanadiansyllabics}', "");
Expect(1, 5759, '\p{-In_Canadian_syllabics}', "");
Expect(0, 5759, '\p{^-In_Canadian_syllabics}', "");
Expect(0, 5759, '\P{-In_Canadian_syllabics}', "");
Expect(1, 5759, '\P{^-In_Canadian_syllabics}', "");
Expect(0, 5760, '\p{-In_Canadian_syllabics}', "");
Expect(1, 5760, '\p{^-In_Canadian_syllabics}', "");
Expect(1, 5760, '\P{-In_Canadian_syllabics}', "");
Expect(0, 5760, '\P{^-In_Canadian_syllabics}', "");
Error('\p{Unified_Canadian_Aboriginal_Syllabics_Extended:=}');
Error('\P{Unified_Canadian_Aboriginal_Syllabics_Extended:=}');
Expect(1, 6399, '\p{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^unifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(0, 6399, '\p{^ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(0, 6399, '\P{ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(1, 6399, '\P{^ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(0, 6400, '\p{ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(1, 6400, '\p{^ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(1, 6400, '\P{ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Expect(0, 6400, '\P{^ _unified_Canadian_ABORIGINAL_syllabics_extended}', "");
Error('\p{/a/_-Is_Unified_CANADIAN_Aboriginal_SYLLABICS_extended}');
Error('\P{/a/_-Is_Unified_CANADIAN_Aboriginal_SYLLABICS_extended}');
Expect(1, 6399, '\p{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^isunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6399, '\p{^	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6399, '\P{	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(1, 6399, '\P{^	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6400, '\p{	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(1, 6400, '\p{^	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(1, 6400, '\P{	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Expect(0, 6400, '\P{^	 Is_unified_Canadian_Aboriginal_Syllabics_extended}', "");
Error('\p{/a/ IN_Unified_canadian_Aboriginal_Syllabics_Extended}');
Error('\P{/a/ IN_Unified_canadian_Aboriginal_Syllabics_Extended}');
Expect(1, 6399, '\p{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\p{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6399, '\P{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\P{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\p{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\p{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6400, '\P{inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(0, 6400, '\P{^inunifiedcanadianaboriginalsyllabicsextended}', "");
Expect(1, 6399, '\p{--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(0, 6399, '\p{^--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(0, 6399, '\P{--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(1, 6399, '\P{^--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(0, 6400, '\p{--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(1, 6400, '\p{^--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(1, 6400, '\P{--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Expect(0, 6400, '\P{^--In_Unified_CANADIAN_Aboriginal_SYLLABICS_Extended}', "");
Error('\p{ -UCAS_ext:=}');
Error('\P{ -UCAS_ext:=}');
Expect(1, 6399, '\p{ucasext}', "");
Expect(0, 6399, '\p{^ucasext}', "");
Expect(0, 6399, '\P{ucasext}', "");
Expect(1, 6399, '\P{^ucasext}', "");
Expect(0, 6400, '\p{ucasext}', "");
Expect(1, 6400, '\p{^ucasext}', "");
Expect(1, 6400, '\P{ucasext}', "");
Expect(0, 6400, '\P{^ucasext}', "");
Expect(1, 6399, '\p{-	ucas_ext}', "");
Expect(0, 6399, '\p{^-	ucas_ext}', "");
Expect(0, 6399, '\P{-	ucas_ext}', "");
Expect(1, 6399, '\P{^-	ucas_ext}', "");
Expect(0, 6400, '\p{-	ucas_ext}', "");
Expect(1, 6400, '\p{^-	ucas_ext}', "");
Expect(1, 6400, '\P{-	ucas_ext}', "");
Expect(0, 6400, '\P{^-	ucas_ext}', "");
Error('\p{/a/  is_ucas_Ext}');
Error('\P{/a/  is_ucas_Ext}');
Expect(1, 6399, '\p{isucasext}', "");
Expect(0, 6399, '\p{^isucasext}', "");
Expect(0, 6399, '\P{isucasext}', "");
Expect(1, 6399, '\P{^isucasext}', "");
Expect(0, 6400, '\p{isucasext}', "");
Expect(1, 6400, '\p{^isucasext}', "");
Expect(1, 6400, '\P{isucasext}', "");
Expect(0, 6400, '\P{^isucasext}', "");
Expect(1, 6399, '\p{-	Is_ucas_Ext}', "");
Expect(0, 6399, '\p{^-	Is_ucas_Ext}', "");
Expect(0, 6399, '\P{-	Is_ucas_Ext}', "");
Expect(1, 6399, '\P{^-	Is_ucas_Ext}', "");
Expect(0, 6400, '\p{-	Is_ucas_Ext}', "");
Expect(1, 6400, '\p{^-	Is_ucas_Ext}', "");
Expect(1, 6400, '\P{-	Is_ucas_Ext}', "");
Expect(0, 6400, '\P{^-	Is_ucas_Ext}', "");
Error('\p{ /a/IN_UCAS_EXT}');
Error('\P{ /a/IN_UCAS_EXT}');
Expect(1, 6399, '\p{inucasext}', "");
Expect(0, 6399, '\p{^inucasext}', "");
Expect(0, 6399, '\P{inucasext}', "");
Expect(1, 6399, '\P{^inucasext}', "");
Expect(0, 6400, '\p{inucasext}', "");
Expect(1, 6400, '\p{^inucasext}', "");
Expect(1, 6400, '\P{inucasext}', "");
Expect(0, 6400, '\P{^inucasext}', "");
Expect(1, 6399, '\p{_	in_UCAS_EXT}', "");
Expect(0, 6399, '\p{^_	in_UCAS_EXT}', "");
Expect(0, 6399, '\P{_	in_UCAS_EXT}', "");
Expect(1, 6399, '\P{^_	in_UCAS_EXT}', "");
Expect(0, 6400, '\p{_	in_UCAS_EXT}', "");
Expect(1, 6400, '\p{^_	in_UCAS_EXT}', "");
Expect(1, 6400, '\P{_	in_UCAS_EXT}', "");
Expect(0, 6400, '\P{^_	in_UCAS_EXT}', "");
Error('\p{  UNIFIED_Ideograph:=}');
Error('\P{  UNIFIED_Ideograph:=}');
Expect(1, 178205, '\p{unifiedideograph}', "");
Expect(0, 178205, '\p{^unifiedideograph}', "");
Expect(0, 178205, '\P{unifiedideograph}', "");
Expect(1, 178205, '\P{^unifiedideograph}', "");
Expect(0, 178206, '\p{unifiedideograph}', "");
Expect(1, 178206, '\p{^unifiedideograph}', "");
Expect(1, 178206, '\P{unifiedideograph}', "");
Expect(0, 178206, '\P{^unifiedideograph}', "");
Expect(1, 178205, '\p{-unified_ideograph}', "");
Expect(0, 178205, '\p{^-unified_ideograph}', "");
Expect(0, 178205, '\P{-unified_ideograph}', "");
Expect(1, 178205, '\P{^-unified_ideograph}', "");
Expect(0, 178206, '\p{-unified_ideograph}', "");
Expect(1, 178206, '\p{^-unified_ideograph}', "");
Expect(1, 178206, '\P{-unified_ideograph}', "");
Expect(0, 178206, '\P{^-unified_ideograph}', "");
Error('\p{	/a/is_unified_ideograph}');
Error('\P{	/a/is_unified_ideograph}');
Expect(1, 178205, '\p{isunifiedideograph}', "");
Expect(0, 178205, '\p{^isunifiedideograph}', "");
Expect(0, 178205, '\P{isunifiedideograph}', "");
Expect(1, 178205, '\P{^isunifiedideograph}', "");
Expect(0, 178206, '\p{isunifiedideograph}', "");
Expect(1, 178206, '\p{^isunifiedideograph}', "");
Expect(1, 178206, '\P{isunifiedideograph}', "");
Expect(0, 178206, '\P{^isunifiedideograph}', "");
Expect(1, 178205, '\p{ is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178205, '\p{^ is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178205, '\P{ is_UNIFIED_IDEOGRAPH}', "");
Expect(1, 178205, '\P{^ is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178206, '\p{ is_UNIFIED_IDEOGRAPH}', "");
Expect(1, 178206, '\p{^ is_UNIFIED_IDEOGRAPH}', "");
Expect(1, 178206, '\P{ is_UNIFIED_IDEOGRAPH}', "");
Expect(0, 178206, '\P{^ is_UNIFIED_IDEOGRAPH}', "");
Error('\p{_/a/uideo}');
Error('\P{_/a/uideo}');
Expect(1, 178205, '\p{uideo}', "");
Expect(0, 178205, '\p{^uideo}', "");
Expect(0, 178205, '\P{uideo}', "");
Expect(1, 178205, '\P{^uideo}', "");
Expect(0, 178206, '\p{uideo}', "");
Expect(1, 178206, '\p{^uideo}', "");
Expect(1, 178206, '\P{uideo}', "");
Expect(0, 178206, '\P{^uideo}', "");
Expect(1, 178205, '\p{ -UIdeo}', "");
Expect(0, 178205, '\p{^ -UIdeo}', "");
Expect(0, 178205, '\P{ -UIdeo}', "");
Expect(1, 178205, '\P{^ -UIdeo}', "");
Expect(0, 178206, '\p{ -UIdeo}', "");
Expect(1, 178206, '\p{^ -UIdeo}', "");
Expect(1, 178206, '\P{ -UIdeo}', "");
Expect(0, 178206, '\P{^ -UIdeo}', "");
Error('\p{/a/ Is_UIDEO}');
Error('\P{/a/ Is_UIDEO}');
Expect(1, 178205, '\p{isuideo}', "");
Expect(0, 178205, '\p{^isuideo}', "");
Expect(0, 178205, '\P{isuideo}', "");
Expect(1, 178205, '\P{^isuideo}', "");
Expect(0, 178206, '\p{isuideo}', "");
Expect(1, 178206, '\p{^isuideo}', "");
Expect(1, 178206, '\P{isuideo}', "");
Expect(0, 178206, '\P{^isuideo}', "");
Expect(1, 178205, '\p{ is_UIDEO}', "");
Expect(0, 178205, '\p{^ is_UIDEO}', "");
Expect(0, 178205, '\P{ is_UIDEO}', "");
Expect(1, 178205, '\P{^ is_UIDEO}', "");
Expect(0, 178206, '\p{ is_UIDEO}', "");
Expect(1, 178206, '\p{^ is_UIDEO}', "");
Expect(1, 178206, '\P{ is_UIDEO}', "");
Expect(0, 178206, '\P{^ is_UIDEO}', "");
Error('\p{ :=Unknown}');
Error('\P{ :=Unknown}');
Expect(1, 918000, '\p{unknown}', "");
Expect(0, 918000, '\p{^unknown}', "");
Expect(0, 918000, '\P{unknown}', "");
Expect(1, 918000, '\P{^unknown}', "");
Expect(0, 917999, '\p{unknown}', "");
Expect(1, 917999, '\p{^unknown}', "");
Expect(1, 917999, '\P{unknown}', "");
Expect(0, 917999, '\P{^unknown}', "");
Expect(1, 918000, '\p{ _UNKNOWN}', "");
Expect(0, 918000, '\p{^ _UNKNOWN}', "");
Expect(0, 918000, '\P{ _UNKNOWN}', "");
Expect(1, 918000, '\P{^ _UNKNOWN}', "");
Expect(0, 917999, '\p{ _UNKNOWN}', "");
Expect(1, 917999, '\p{^ _UNKNOWN}', "");
Expect(1, 917999, '\P{ _UNKNOWN}', "");
Expect(0, 917999, '\P{^ _UNKNOWN}', "");
Error('\p{:=  is_Unknown}');
Error('\P{:=  is_Unknown}');
Expect(1, 918000, '\p{isunknown}', "");
Expect(0, 918000, '\p{^isunknown}', "");
Expect(0, 918000, '\P{isunknown}', "");
Expect(1, 918000, '\P{^isunknown}', "");
Expect(0, 917999, '\p{isunknown}', "");
Expect(1, 917999, '\p{^isunknown}', "");
Expect(1, 917999, '\P{isunknown}', "");
Expect(0, 917999, '\P{^isunknown}', "");
Expect(1, 918000, '\p{		IS_UNKNOWN}', "");
Expect(0, 918000, '\p{^		IS_UNKNOWN}', "");
Expect(0, 918000, '\P{		IS_UNKNOWN}', "");
Expect(1, 918000, '\P{^		IS_UNKNOWN}', "");
Expect(0, 917999, '\p{		IS_UNKNOWN}', "");
Expect(1, 917999, '\p{^		IS_UNKNOWN}', "");
Expect(1, 917999, '\P{		IS_UNKNOWN}', "");
Expect(0, 917999, '\P{^		IS_UNKNOWN}', "");
Error('\p{	 Zzzz/a/}');
Error('\P{	 Zzzz/a/}');
Expect(1, 918000, '\p{zzzz}', "");
Expect(0, 918000, '\p{^zzzz}', "");
Expect(0, 918000, '\P{zzzz}', "");
Expect(1, 918000, '\P{^zzzz}', "");
Expect(0, 917999, '\p{zzzz}', "");
Expect(1, 917999, '\p{^zzzz}', "");
Expect(1, 917999, '\P{zzzz}', "");
Expect(0, 917999, '\P{^zzzz}', "");
Expect(1, 918000, '\p{	_Zzzz}', "");
Expect(0, 918000, '\p{^	_Zzzz}', "");
Expect(0, 918000, '\P{	_Zzzz}', "");
Expect(1, 918000, '\P{^	_Zzzz}', "");
Expect(0, 917999, '\p{	_Zzzz}', "");
Expect(1, 917999, '\p{^	_Zzzz}', "");
Expect(1, 917999, '\P{	_Zzzz}', "");
Expect(0, 917999, '\P{^	_Zzzz}', "");
Error('\p{_/a/Is_ZZZZ}');
Error('\P{_/a/Is_ZZZZ}');
Expect(1, 918000, '\p{iszzzz}', "");
Expect(0, 918000, '\p{^iszzzz}', "");
Expect(0, 918000, '\P{iszzzz}', "");
Expect(1, 918000, '\P{^iszzzz}', "");
Expect(0, 917999, '\p{iszzzz}', "");
Expect(1, 917999, '\p{^iszzzz}', "");
Expect(1, 917999, '\P{iszzzz}', "");
Expect(0, 917999, '\P{^iszzzz}', "");
Expect(1, 918000, '\p{- Is_Zzzz}', "");
Expect(0, 918000, '\p{^- Is_Zzzz}', "");
Expect(0, 918000, '\P{- Is_Zzzz}', "");
Expect(1, 918000, '\P{^- Is_Zzzz}', "");
Expect(0, 917999, '\p{- Is_Zzzz}', "");
Expect(1, 917999, '\p{^- Is_Zzzz}', "");
Expect(1, 917999, '\P{- Is_Zzzz}', "");
Expect(0, 917999, '\P{^- Is_Zzzz}', "");
Error('\p{	/a/upper}');
Error('\P{	/a/upper}');
Expect(1, 120778, '\p{upper}', "");
Expect(0, 120778, '\p{^upper}', "");
Expect(0, 120778, '\P{upper}', "");
Expect(1, 120778, '\P{^upper}', "");
Expect(0, 120779, '\p{upper}', "");
Expect(1, 120779, '\p{^upper}', "");
Expect(1, 120779, '\P{upper}', "");
Expect(0, 120779, '\P{^upper}', "");
Expect(1, 120778, '\p{_UPPER}', "");
Expect(0, 120778, '\p{^_UPPER}', "");
Expect(0, 120778, '\P{_UPPER}', "");
Expect(1, 120778, '\P{^_UPPER}', "");
Expect(0, 120779, '\p{_UPPER}', "");
Expect(1, 120779, '\p{^_UPPER}', "");
Expect(1, 120779, '\P{_UPPER}', "");
Expect(0, 120779, '\P{^_UPPER}', "");
Error('\p{-XPosixUpper:=}');
Error('\P{-XPosixUpper:=}');
Expect(1, 120778, '\p{xposixupper}', "");
Expect(0, 120778, '\p{^xposixupper}', "");
Expect(0, 120778, '\P{xposixupper}', "");
Expect(1, 120778, '\P{^xposixupper}', "");
Expect(0, 120779, '\p{xposixupper}', "");
Expect(1, 120779, '\p{^xposixupper}', "");
Expect(1, 120779, '\P{xposixupper}', "");
Expect(0, 120779, '\P{^xposixupper}', "");
Expect(1, 120778, '\p{-_XPOSIXUPPER}', "");
Expect(0, 120778, '\p{^-_XPOSIXUPPER}', "");
Expect(0, 120778, '\P{-_XPOSIXUPPER}', "");
Expect(1, 120778, '\P{^-_XPOSIXUPPER}', "");
Expect(0, 120779, '\p{-_XPOSIXUPPER}', "");
Expect(1, 120779, '\p{^-_XPOSIXUPPER}', "");
Expect(1, 120779, '\P{-_XPOSIXUPPER}', "");
Expect(0, 120779, '\P{^-_XPOSIXUPPER}', "");
Error('\p{		Is_Upper:=}');
Error('\P{		Is_Upper:=}');
Expect(1, 120778, '\p{isupper}', "");
Expect(0, 120778, '\p{^isupper}', "");
Expect(0, 120778, '\P{isupper}', "");
Expect(1, 120778, '\P{^isupper}', "");
Expect(0, 120779, '\p{isupper}', "");
Expect(1, 120779, '\p{^isupper}', "");
Expect(1, 120779, '\P{isupper}', "");
Expect(0, 120779, '\P{^isupper}', "");
Expect(1, 120778, '\p{ IS_Upper}', "");
Expect(0, 120778, '\p{^ IS_Upper}', "");
Expect(0, 120778, '\P{ IS_Upper}', "");
Expect(1, 120778, '\P{^ IS_Upper}', "");
Expect(0, 120779, '\p{ IS_Upper}', "");
Expect(1, 120779, '\p{^ IS_Upper}', "");
Expect(1, 120779, '\P{ IS_Upper}', "");
Expect(0, 120779, '\P{^ IS_Upper}', "");
Error('\p{/a/_	IS_XPosixUpper}');
Error('\P{/a/_	IS_XPosixUpper}');
Expect(1, 120778, '\p{isxposixupper}', "");
Expect(0, 120778, '\p{^isxposixupper}', "");
Expect(0, 120778, '\P{isxposixupper}', "");
Expect(1, 120778, '\P{^isxposixupper}', "");
Expect(0, 120779, '\p{isxposixupper}', "");
Expect(1, 120779, '\p{^isxposixupper}', "");
Expect(1, 120779, '\P{isxposixupper}', "");
Expect(0, 120779, '\P{^isxposixupper}', "");
Expect(1, 120778, '\p{	Is_XPosixUpper}', "");
Expect(0, 120778, '\p{^	Is_XPosixUpper}', "");
Expect(0, 120778, '\P{	Is_XPosixUpper}', "");
Expect(1, 120778, '\P{^	Is_XPosixUpper}', "");
Expect(0, 120779, '\p{	Is_XPosixUpper}', "");
Expect(1, 120779, '\p{^	Is_XPosixUpper}', "");
Expect(1, 120779, '\P{	Is_XPosixUpper}', "");
Expect(0, 120779, '\P{^	Is_XPosixUpper}', "");
Error('\p{-/a/Uppercase}');
Error('\P{-/a/Uppercase}');
Expect(1, 120778, '\p{uppercase}', "");
Expect(0, 120778, '\p{^uppercase}', "");
Expect(0, 120778, '\P{uppercase}', "");
Expect(1, 120778, '\P{^uppercase}', "");
Expect(0, 120779, '\p{uppercase}', "");
Expect(1, 120779, '\p{^uppercase}', "");
Expect(1, 120779, '\P{uppercase}', "");
Expect(0, 120779, '\P{^uppercase}', "");
Expect(1, 120778, '\p{_uppercase}', "");
Expect(0, 120778, '\p{^_uppercase}', "");
Expect(0, 120778, '\P{_uppercase}', "");
Expect(1, 120778, '\P{^_uppercase}', "");
Expect(0, 120779, '\p{_uppercase}', "");
Expect(1, 120779, '\p{^_uppercase}', "");
Expect(1, 120779, '\P{_uppercase}', "");
Expect(0, 120779, '\P{^_uppercase}', "");
Error('\p{_:=is_UPPERCASE}');
Error('\P{_:=is_UPPERCASE}');
Expect(1, 120778, '\p{isuppercase}', "");
Expect(0, 120778, '\p{^isuppercase}', "");
Expect(0, 120778, '\P{isuppercase}', "");
Expect(1, 120778, '\P{^isuppercase}', "");
Expect(0, 120779, '\p{isuppercase}', "");
Expect(1, 120779, '\p{^isuppercase}', "");
Expect(1, 120779, '\P{isuppercase}', "");
Expect(0, 120779, '\P{^isuppercase}', "");
Expect(1, 120778, '\p{_-Is_Uppercase}', "");
Expect(0, 120778, '\p{^_-Is_Uppercase}', "");
Expect(0, 120778, '\P{_-Is_Uppercase}', "");
Expect(1, 120778, '\P{^_-Is_Uppercase}', "");
Expect(0, 120779, '\p{_-Is_Uppercase}', "");
Expect(1, 120779, '\p{^_-Is_Uppercase}', "");
Expect(1, 120779, '\P{_-Is_Uppercase}', "");
Expect(0, 120779, '\P{^_-Is_Uppercase}', "");
Error('\p{__uppercase_LETTER/a/}');
Error('\P{__uppercase_LETTER/a/}');
Expect(1, 120778, '\p{uppercaseletter}', "");
Expect(0, 120778, '\p{^uppercaseletter}', "");
Expect(0, 120778, '\P{uppercaseletter}', "");
Expect(1, 120778, '\P{^uppercaseletter}', "");
Expect(0, 120779, '\p{uppercaseletter}', "");
Expect(1, 120779, '\p{^uppercaseletter}', "");
Expect(1, 120779, '\P{uppercaseletter}', "");
Expect(0, 120779, '\P{^uppercaseletter}', "");
Expect(1, 120778, '\p{-_UPPERCASE_Letter}', "");
Expect(0, 120778, '\p{^-_UPPERCASE_Letter}', "");
Expect(0, 120778, '\P{-_UPPERCASE_Letter}', "");
Expect(1, 120778, '\P{^-_UPPERCASE_Letter}', "");
Expect(0, 120779, '\p{-_UPPERCASE_Letter}', "");
Expect(1, 120779, '\p{^-_UPPERCASE_Letter}', "");
Expect(1, 120779, '\P{-_UPPERCASE_Letter}', "");
Expect(0, 120779, '\P{^-_UPPERCASE_Letter}', "");
Error('\p{ /a/Is_Uppercase_Letter}');
Error('\P{ /a/Is_Uppercase_Letter}');
Expect(1, 120778, '\p{isuppercaseletter}', "");
Expect(0, 120778, '\p{^isuppercaseletter}', "");
Expect(0, 120778, '\P{isuppercaseletter}', "");
Expect(1, 120778, '\P{^isuppercaseletter}', "");
Expect(0, 120779, '\p{isuppercaseletter}', "");
Expect(1, 120779, '\p{^isuppercaseletter}', "");
Expect(1, 120779, '\P{isuppercaseletter}', "");
Expect(0, 120779, '\P{^isuppercaseletter}', "");
Expect(1, 120778, '\p{_is_UPPERCASE_letter}', "");
Expect(0, 120778, '\p{^_is_UPPERCASE_letter}', "");
Expect(0, 120778, '\P{_is_UPPERCASE_letter}', "");
Expect(1, 120778, '\P{^_is_UPPERCASE_letter}', "");
Expect(0, 120779, '\p{_is_UPPERCASE_letter}', "");
Expect(1, 120779, '\p{^_is_UPPERCASE_letter}', "");
Expect(1, 120779, '\P{_is_UPPERCASE_letter}', "");
Expect(0, 120779, '\P{^_is_UPPERCASE_letter}', "");
Error('\p{-Lu/a/}');
Error('\P{-Lu/a/}');
Expect(1, 120778, '\p{lu}', "");
Expect(0, 120778, '\p{^lu}', "");
Expect(0, 120778, '\P{lu}', "");
Expect(1, 120778, '\P{^lu}', "");
Expect(0, 120779, '\p{lu}', "");
Expect(1, 120779, '\p{^lu}', "");
Expect(1, 120779, '\P{lu}', "");
Expect(0, 120779, '\P{^lu}', "");
Expect(1, 120778, '\p{	LU}', "");
Expect(0, 120778, '\p{^	LU}', "");
Expect(0, 120778, '\P{	LU}', "");
Expect(1, 120778, '\P{^	LU}', "");
Expect(0, 120779, '\p{	LU}', "");
Expect(1, 120779, '\p{^	LU}', "");
Expect(1, 120779, '\P{	LU}', "");
Expect(0, 120779, '\P{^	LU}', "");
Error('\p{_:=is_Lu}');
Error('\P{_:=is_Lu}');
Expect(1, 120778, '\p{islu}', "");
Expect(0, 120778, '\p{^islu}', "");
Expect(0, 120778, '\P{islu}', "");
Expect(1, 120778, '\P{^islu}', "");
Expect(0, 120779, '\p{islu}', "");
Expect(1, 120779, '\p{^islu}', "");
Expect(1, 120779, '\P{islu}', "");
Expect(0, 120779, '\P{^islu}', "");
Expect(1, 120778, '\p{	_Is_lu}', "");
Expect(0, 120778, '\p{^	_Is_lu}', "");
Expect(0, 120778, '\P{	_Is_lu}', "");
Expect(1, 120778, '\P{^	_Is_lu}', "");
Expect(0, 120779, '\p{	_Is_lu}', "");
Expect(1, 120779, '\p{^	_Is_lu}', "");
Expect(1, 120779, '\P{	_Is_lu}', "");
Expect(0, 120779, '\P{^	_Is_lu}', "");
Error('\p{/a/_	Vai}');
Error('\P{/a/_	Vai}');
Expect(1, 42539, '\p{vai}', "");
Expect(0, 42539, '\p{^vai}', "");
Expect(0, 42539, '\P{vai}', "");
Expect(1, 42539, '\P{^vai}', "");
Expect(0, 42540, '\p{vai}', "");
Expect(1, 42540, '\p{^vai}', "");
Expect(1, 42540, '\P{vai}', "");
Expect(0, 42540, '\P{^vai}', "");
Expect(1, 42539, '\p{ 	VAI}', "");
Expect(0, 42539, '\p{^ 	VAI}', "");
Expect(0, 42539, '\P{ 	VAI}', "");
Expect(1, 42539, '\P{^ 	VAI}', "");
Expect(0, 42540, '\p{ 	VAI}', "");
Expect(1, 42540, '\p{^ 	VAI}', "");
Expect(1, 42540, '\P{ 	VAI}', "");
Expect(0, 42540, '\P{^ 	VAI}', "");
Error('\p{ -Is_Vai:=}');
Error('\P{ -Is_Vai:=}');
Expect(1, 42539, '\p{isvai}', "");
Expect(0, 42539, '\p{^isvai}', "");
Expect(0, 42539, '\P{isvai}', "");
Expect(1, 42539, '\P{^isvai}', "");
Expect(0, 42540, '\p{isvai}', "");
Expect(1, 42540, '\p{^isvai}', "");
Expect(1, 42540, '\P{isvai}', "");
Expect(0, 42540, '\P{^isvai}', "");
Expect(1, 42539, '\p{_Is_VAI}', "");
Expect(0, 42539, '\p{^_Is_VAI}', "");
Expect(0, 42539, '\P{_Is_VAI}', "");
Expect(1, 42539, '\P{^_Is_VAI}', "");
Expect(0, 42540, '\p{_Is_VAI}', "");
Expect(1, 42540, '\p{^_Is_VAI}', "");
Expect(1, 42540, '\P{_Is_VAI}', "");
Expect(0, 42540, '\P{^_Is_VAI}', "");
Error('\p{_	VAII:=}');
Error('\P{_	VAII:=}');
Expect(1, 42539, '\p{vaii}', "");
Expect(0, 42539, '\p{^vaii}', "");
Expect(0, 42539, '\P{vaii}', "");
Expect(1, 42539, '\P{^vaii}', "");
Expect(0, 42540, '\p{vaii}', "");
Expect(1, 42540, '\p{^vaii}', "");
Expect(1, 42540, '\P{vaii}', "");
Expect(0, 42540, '\P{^vaii}', "");
Expect(1, 42539, '\p{__VAII}', "");
Expect(0, 42539, '\p{^__VAII}', "");
Expect(0, 42539, '\P{__VAII}', "");
Expect(1, 42539, '\P{^__VAII}', "");
Expect(0, 42540, '\p{__VAII}', "");
Expect(1, 42540, '\p{^__VAII}', "");
Expect(1, 42540, '\P{__VAII}', "");
Expect(0, 42540, '\P{^__VAII}', "");
Error('\p{_/a/Is_vaii}');
Error('\P{_/a/Is_vaii}');
Expect(1, 42539, '\p{isvaii}', "");
Expect(0, 42539, '\p{^isvaii}', "");
Expect(0, 42539, '\P{isvaii}', "");
Expect(1, 42539, '\P{^isvaii}', "");
Expect(0, 42540, '\p{isvaii}', "");
Expect(1, 42540, '\p{^isvaii}', "");
Expect(1, 42540, '\P{isvaii}', "");
Expect(0, 42540, '\P{^isvaii}', "");
Expect(1, 42539, '\p{__Is_vaii}', "");
Expect(0, 42539, '\p{^__Is_vaii}', "");
Expect(0, 42539, '\P{__Is_vaii}', "");
Expect(1, 42539, '\P{^__Is_vaii}', "");
Expect(0, 42540, '\p{__Is_vaii}', "");
Expect(1, 42540, '\p{^__Is_vaii}', "");
Expect(1, 42540, '\P{__Is_vaii}', "");
Expect(0, 42540, '\P{^__Is_vaii}', "");
Error('\p{	/a/VARIATION_Selector}');
Error('\P{	/a/VARIATION_Selector}');
Expect(1, 917999, '\p{variationselector}', "");
Expect(0, 917999, '\p{^variationselector}', "");
Expect(0, 917999, '\P{variationselector}', "");
Expect(1, 917999, '\P{^variationselector}', "");
Expect(0, 918000, '\p{variationselector}', "");
Expect(1, 918000, '\p{^variationselector}', "");
Expect(1, 918000, '\P{variationselector}', "");
Expect(0, 918000, '\P{^variationselector}', "");
Expect(1, 917999, '\p{	-Variation_Selector}', "");
Expect(0, 917999, '\p{^	-Variation_Selector}', "");
Expect(0, 917999, '\P{	-Variation_Selector}', "");
Expect(1, 917999, '\P{^	-Variation_Selector}', "");
Expect(0, 918000, '\p{	-Variation_Selector}', "");
Expect(1, 918000, '\p{^	-Variation_Selector}', "");
Expect(1, 918000, '\P{	-Variation_Selector}', "");
Expect(0, 918000, '\P{^	-Variation_Selector}', "");
Error('\p{/a/ -Is_Variation_selector}');
Error('\P{/a/ -Is_Variation_selector}');
Expect(1, 917999, '\p{isvariationselector}', "");
Expect(0, 917999, '\p{^isvariationselector}', "");
Expect(0, 917999, '\P{isvariationselector}', "");
Expect(1, 917999, '\P{^isvariationselector}', "");
Expect(0, 918000, '\p{isvariationselector}', "");
Expect(1, 918000, '\p{^isvariationselector}', "");
Expect(1, 918000, '\P{isvariationselector}', "");
Expect(0, 918000, '\P{^isvariationselector}', "");
Expect(1, 917999, '\p{_IS_Variation_Selector}', "");
Expect(0, 917999, '\p{^_IS_Variation_Selector}', "");
Expect(0, 917999, '\P{_IS_Variation_Selector}', "");
Expect(1, 917999, '\P{^_IS_Variation_Selector}', "");
Expect(0, 918000, '\p{_IS_Variation_Selector}', "");
Expect(1, 918000, '\p{^_IS_Variation_Selector}', "");
Expect(1, 918000, '\P{_IS_Variation_Selector}', "");
Expect(0, 918000, '\P{^_IS_Variation_Selector}', "");
Error('\p{-:=VS}');
Error('\P{-:=VS}');
Expect(1, 917999, '\p{vs}', "");
Expect(0, 917999, '\p{^vs}', "");
Expect(0, 917999, '\P{vs}', "");
Expect(1, 917999, '\P{^vs}', "");
Expect(0, 918000, '\p{vs}', "");
Expect(1, 918000, '\p{^vs}', "");
Expect(1, 918000, '\P{vs}', "");
Expect(0, 918000, '\P{^vs}', "");
Expect(1, 917999, '\p{_	vs}', "");
Expect(0, 917999, '\p{^_	vs}', "");
Expect(0, 917999, '\P{_	vs}', "");
Expect(1, 917999, '\P{^_	vs}', "");
Expect(0, 918000, '\p{_	vs}', "");
Expect(1, 918000, '\p{^_	vs}', "");
Expect(1, 918000, '\P{_	vs}', "");
Expect(0, 918000, '\P{^_	vs}', "");
Error('\p{- Is_vs:=}');
Error('\P{- Is_vs:=}');
Expect(1, 917999, '\p{isvs}', "");
Expect(0, 917999, '\p{^isvs}', "");
Expect(0, 917999, '\P{isvs}', "");
Expect(1, 917999, '\P{^isvs}', "");
Expect(0, 918000, '\p{isvs}', "");
Expect(1, 918000, '\p{^isvs}', "");
Expect(1, 918000, '\P{isvs}', "");
Expect(0, 918000, '\P{^isvs}', "");
Expect(1, 917999, '\p{-Is_VS}', "");
Expect(0, 917999, '\p{^-Is_VS}', "");
Expect(0, 917999, '\P{-Is_VS}', "");
Expect(1, 917999, '\P{^-Is_VS}', "");
Expect(0, 918000, '\p{-Is_VS}', "");
Expect(1, 918000, '\p{^-Is_VS}', "");
Expect(1, 918000, '\P{-Is_VS}', "");
Expect(0, 918000, '\P{^-Is_VS}', "");
Error('\p{/a/-	Variation_SELECTORS}');
Error('\P{/a/-	Variation_SELECTORS}');
Expect(1, 65039, '\p{variationselectors}', "");
Expect(0, 65039, '\p{^variationselectors}', "");
Expect(0, 65039, '\P{variationselectors}', "");
Expect(1, 65039, '\P{^variationselectors}', "");
Expect(0, 65040, '\p{variationselectors}', "");
Expect(1, 65040, '\p{^variationselectors}', "");
Expect(1, 65040, '\P{variationselectors}', "");
Expect(0, 65040, '\P{^variationselectors}', "");
Expect(1, 65039, '\p{_Variation_Selectors}', "");
Expect(0, 65039, '\p{^_Variation_Selectors}', "");
Expect(0, 65039, '\P{_Variation_Selectors}', "");
Expect(1, 65039, '\P{^_Variation_Selectors}', "");
Expect(0, 65040, '\p{_Variation_Selectors}', "");
Expect(1, 65040, '\p{^_Variation_Selectors}', "");
Expect(1, 65040, '\P{_Variation_Selectors}', "");
Expect(0, 65040, '\P{^_Variation_Selectors}', "");
Error('\p{ :=IS_Variation_SELECTORS}');
Error('\P{ :=IS_Variation_SELECTORS}');
Expect(1, 65039, '\p{isvariationselectors}', "");
Expect(0, 65039, '\p{^isvariationselectors}', "");
Expect(0, 65039, '\P{isvariationselectors}', "");
Expect(1, 65039, '\P{^isvariationselectors}', "");
Expect(0, 65040, '\p{isvariationselectors}', "");
Expect(1, 65040, '\p{^isvariationselectors}', "");
Expect(1, 65040, '\P{isvariationselectors}', "");
Expect(0, 65040, '\P{^isvariationselectors}', "");
Expect(1, 65039, '\p{ -IS_variation_selectors}', "");
Expect(0, 65039, '\p{^ -IS_variation_selectors}', "");
Expect(0, 65039, '\P{ -IS_variation_selectors}', "");
Expect(1, 65039, '\P{^ -IS_variation_selectors}', "");
Expect(0, 65040, '\p{ -IS_variation_selectors}', "");
Expect(1, 65040, '\p{^ -IS_variation_selectors}', "");
Expect(1, 65040, '\P{ -IS_variation_selectors}', "");
Expect(0, 65040, '\P{^ -IS_variation_selectors}', "");
Error('\p{	:=In_variation_Selectors}');
Error('\P{	:=In_variation_Selectors}');
Expect(1, 65039, '\p{invariationselectors}', "");
Expect(0, 65039, '\p{^invariationselectors}', "");
Expect(0, 65039, '\P{invariationselectors}', "");
Expect(1, 65039, '\P{^invariationselectors}', "");
Expect(0, 65040, '\p{invariationselectors}', "");
Expect(1, 65040, '\p{^invariationselectors}', "");
Expect(1, 65040, '\P{invariationselectors}', "");
Expect(0, 65040, '\P{^invariationselectors}', "");
Expect(1, 65039, '\p{	 In_variation_SELECTORS}', "");
Expect(0, 65039, '\p{^	 In_variation_SELECTORS}', "");
Expect(0, 65039, '\P{	 In_variation_SELECTORS}', "");
Expect(1, 65039, '\P{^	 In_variation_SELECTORS}', "");
Expect(0, 65040, '\p{	 In_variation_SELECTORS}', "");
Expect(1, 65040, '\p{^	 In_variation_SELECTORS}', "");
Expect(1, 65040, '\P{	 In_variation_SELECTORS}', "");
Expect(0, 65040, '\P{^	 In_variation_SELECTORS}', "");
Error('\p{ in_VS/a/}');
Error('\P{ in_VS/a/}');
Expect(1, 65039, '\p{invs}', "");
Expect(0, 65039, '\p{^invs}', "");
Expect(0, 65039, '\P{invs}', "");
Expect(1, 65039, '\P{^invs}', "");
Expect(0, 65040, '\p{invs}', "");
Expect(1, 65040, '\p{^invs}', "");
Expect(1, 65040, '\P{invs}', "");
Expect(0, 65040, '\P{^invs}', "");
Expect(1, 65039, '\p{	_in_vs}', "");
Expect(0, 65039, '\p{^	_in_vs}', "");
Expect(0, 65039, '\P{	_in_vs}', "");
Expect(1, 65039, '\P{^	_in_vs}', "");
Expect(0, 65040, '\p{	_in_vs}', "");
Expect(1, 65040, '\p{^	_in_vs}', "");
Expect(1, 65040, '\P{	_in_vs}', "");
Expect(0, 65040, '\P{^	_in_vs}', "");
Error('\p{-:=Variation_SELECTORS_Supplement}');
Error('\P{-:=Variation_SELECTORS_Supplement}');
Expect(1, 917999, '\p{variationselectorssupplement}', "");
Expect(0, 917999, '\p{^variationselectorssupplement}', "");
Expect(0, 917999, '\P{variationselectorssupplement}', "");
Expect(1, 917999, '\P{^variationselectorssupplement}', "");
Expect(0, 918000, '\p{variationselectorssupplement}', "");
Expect(1, 918000, '\p{^variationselectorssupplement}', "");
Expect(1, 918000, '\P{variationselectorssupplement}', "");
Expect(0, 918000, '\P{^variationselectorssupplement}', "");
Expect(1, 917999, '\p{variation_SELECTORS_Supplement}', "");
Expect(0, 917999, '\p{^variation_SELECTORS_Supplement}', "");
Expect(0, 917999, '\P{variation_SELECTORS_Supplement}', "");
Expect(1, 917999, '\P{^variation_SELECTORS_Supplement}', "");
Expect(0, 918000, '\p{variation_SELECTORS_Supplement}', "");
Expect(1, 918000, '\p{^variation_SELECTORS_Supplement}', "");
Expect(1, 918000, '\P{variation_SELECTORS_Supplement}', "");
Expect(0, 918000, '\P{^variation_SELECTORS_Supplement}', "");
Error('\p{/a/	_Is_variation_selectors_Supplement}');
Error('\P{/a/	_Is_variation_selectors_Supplement}');
Expect(1, 917999, '\p{isvariationselectorssupplement}', "");
Expect(0, 917999, '\p{^isvariationselectorssupplement}', "");
Expect(0, 917999, '\P{isvariationselectorssupplement}', "");
Expect(1, 917999, '\P{^isvariationselectorssupplement}', "");
Expect(0, 918000, '\p{isvariationselectorssupplement}', "");
Expect(1, 918000, '\p{^isvariationselectorssupplement}', "");
Expect(1, 918000, '\P{isvariationselectorssupplement}', "");
Expect(0, 918000, '\P{^isvariationselectorssupplement}', "");
Expect(1, 917999, '\p{		IS_VARIATION_SELECTORS_supplement}', "");
Expect(0, 917999, '\p{^		IS_VARIATION_SELECTORS_supplement}', "");
Expect(0, 917999, '\P{		IS_VARIATION_SELECTORS_supplement}', "");
Expect(1, 917999, '\P{^		IS_VARIATION_SELECTORS_supplement}', "");
Expect(0, 918000, '\p{		IS_VARIATION_SELECTORS_supplement}', "");
Expect(1, 918000, '\p{^		IS_VARIATION_SELECTORS_supplement}', "");
Expect(1, 918000, '\P{		IS_VARIATION_SELECTORS_supplement}', "");
Expect(0, 918000, '\P{^		IS_VARIATION_SELECTORS_supplement}', "");
Error('\p{:=_-In_Variation_SELECTORS_Supplement}');
Error('\P{:=_-In_Variation_SELECTORS_Supplement}');
Expect(1, 917999, '\p{invariationselectorssupplement}', "");
Expect(0, 917999, '\p{^invariationselectorssupplement}', "");
Expect(0, 917999, '\P{invariationselectorssupplement}', "");
Expect(1, 917999, '\P{^invariationselectorssupplement}', "");
Expect(0, 918000, '\p{invariationselectorssupplement}', "");
Expect(1, 918000, '\p{^invariationselectorssupplement}', "");
Expect(1, 918000, '\P{invariationselectorssupplement}', "");
Expect(0, 918000, '\P{^invariationselectorssupplement}', "");
Expect(1, 917999, '\p{_-In_variation_Selectors_Supplement}', "");
Expect(0, 917999, '\p{^_-In_variation_Selectors_Supplement}', "");
Expect(0, 917999, '\P{_-In_variation_Selectors_Supplement}', "");
Expect(1, 917999, '\P{^_-In_variation_Selectors_Supplement}', "");
Expect(0, 918000, '\p{_-In_variation_Selectors_Supplement}', "");
Expect(1, 918000, '\p{^_-In_variation_Selectors_Supplement}', "");
Expect(1, 918000, '\P{_-In_variation_Selectors_Supplement}', "");
Expect(0, 918000, '\P{^_-In_variation_Selectors_Supplement}', "");
Error('\p{--vs_Sup:=}');
Error('\P{--vs_Sup:=}');
Expect(1, 917999, '\p{vssup}', "");
Expect(0, 917999, '\p{^vssup}', "");
Expect(0, 917999, '\P{vssup}', "");
Expect(1, 917999, '\P{^vssup}', "");
Expect(0, 918000, '\p{vssup}', "");
Expect(1, 918000, '\p{^vssup}', "");
Expect(1, 918000, '\P{vssup}', "");
Expect(0, 918000, '\P{^vssup}', "");
Expect(1, 917999, '\p{_	VS_Sup}', "");
Expect(0, 917999, '\p{^_	VS_Sup}', "");
Expect(0, 917999, '\P{_	VS_Sup}', "");
Expect(1, 917999, '\P{^_	VS_Sup}', "");
Expect(0, 918000, '\p{_	VS_Sup}', "");
Expect(1, 918000, '\p{^_	VS_Sup}', "");
Expect(1, 918000, '\P{_	VS_Sup}', "");
Expect(0, 918000, '\P{^_	VS_Sup}', "");
Error('\p{:=-	is_VS_Sup}');
Error('\P{:=-	is_VS_Sup}');
Expect(1, 917999, '\p{isvssup}', "");
Expect(0, 917999, '\p{^isvssup}', "");
Expect(0, 917999, '\P{isvssup}', "");
Expect(1, 917999, '\P{^isvssup}', "");
Expect(0, 918000, '\p{isvssup}', "");
Expect(1, 918000, '\p{^isvssup}', "");
Expect(1, 918000, '\P{isvssup}', "");
Expect(0, 918000, '\P{^isvssup}', "");
Expect(1, 917999, '\p{IS_VS_SUP}', "");
Expect(0, 917999, '\p{^IS_VS_SUP}', "");
Expect(0, 917999, '\P{IS_VS_SUP}', "");
Expect(1, 917999, '\P{^IS_VS_SUP}', "");
Expect(0, 918000, '\p{IS_VS_SUP}', "");
Expect(1, 918000, '\p{^IS_VS_SUP}', "");
Expect(1, 918000, '\P{IS_VS_SUP}', "");
Expect(0, 918000, '\P{^IS_VS_SUP}', "");
Error('\p{ _IN_VS_Sup:=}');
Error('\P{ _IN_VS_Sup:=}');
Expect(1, 917999, '\p{invssup}', "");
Expect(0, 917999, '\p{^invssup}', "");
Expect(0, 917999, '\P{invssup}', "");
Expect(1, 917999, '\P{^invssup}', "");
Expect(0, 918000, '\p{invssup}', "");
Expect(1, 918000, '\p{^invssup}', "");
Expect(1, 918000, '\P{invssup}', "");
Expect(0, 918000, '\P{^invssup}', "");
Expect(1, 917999, '\p{  IN_VS_SUP}', "");
Expect(0, 917999, '\p{^  IN_VS_SUP}', "");
Expect(0, 917999, '\P{  IN_VS_SUP}', "");
Expect(1, 917999, '\P{^  IN_VS_SUP}', "");
Expect(0, 918000, '\p{  IN_VS_SUP}', "");
Expect(1, 918000, '\p{^  IN_VS_SUP}', "");
Expect(1, 918000, '\P{  IN_VS_SUP}', "");
Expect(0, 918000, '\P{^  IN_VS_SUP}', "");
Error('\p{__VEDIC_Extensions/a/}');
Error('\P{__VEDIC_Extensions/a/}');
Expect(1, 7423, '\p{vedicextensions}', "");
Expect(0, 7423, '\p{^vedicextensions}', "");
Expect(0, 7423, '\P{vedicextensions}', "");
Expect(1, 7423, '\P{^vedicextensions}', "");
Expect(0, 7424, '\p{vedicextensions}', "");
Expect(1, 7424, '\p{^vedicextensions}', "");
Expect(1, 7424, '\P{vedicextensions}', "");
Expect(0, 7424, '\P{^vedicextensions}', "");
Expect(1, 7423, '\p{ -vedic_Extensions}', "");
Expect(0, 7423, '\p{^ -vedic_Extensions}', "");
Expect(0, 7423, '\P{ -vedic_Extensions}', "");
Expect(1, 7423, '\P{^ -vedic_Extensions}', "");
Expect(0, 7424, '\p{ -vedic_Extensions}', "");
Expect(1, 7424, '\p{^ -vedic_Extensions}', "");
Expect(1, 7424, '\P{ -vedic_Extensions}', "");
Expect(0, 7424, '\P{^ -vedic_Extensions}', "");
Error('\p{	-is_Vedic_extensions:=}');
Error('\P{	-is_Vedic_extensions:=}');
Expect(1, 7423, '\p{isvedicextensions}', "");
Expect(0, 7423, '\p{^isvedicextensions}', "");
Expect(0, 7423, '\P{isvedicextensions}', "");
Expect(1, 7423, '\P{^isvedicextensions}', "");
Expect(0, 7424, '\p{isvedicextensions}', "");
Expect(1, 7424, '\p{^isvedicextensions}', "");
Expect(1, 7424, '\P{isvedicextensions}', "");
Expect(0, 7424, '\P{^isvedicextensions}', "");
Expect(1, 7423, '\p{_ IS_Vedic_Extensions}', "");
Expect(0, 7423, '\p{^_ IS_Vedic_Extensions}', "");
Expect(0, 7423, '\P{_ IS_Vedic_Extensions}', "");
Expect(1, 7423, '\P{^_ IS_Vedic_Extensions}', "");
Expect(0, 7424, '\p{_ IS_Vedic_Extensions}', "");
Expect(1, 7424, '\p{^_ IS_Vedic_Extensions}', "");
Expect(1, 7424, '\P{_ IS_Vedic_Extensions}', "");
Expect(0, 7424, '\P{^_ IS_Vedic_Extensions}', "");
Error('\p{_:=In_Vedic_extensions}');
Error('\P{_:=In_Vedic_extensions}');
Expect(1, 7423, '\p{invedicextensions}', "");
Expect(0, 7423, '\p{^invedicextensions}', "");
Expect(0, 7423, '\P{invedicextensions}', "");
Expect(1, 7423, '\P{^invedicextensions}', "");
Expect(0, 7424, '\p{invedicextensions}', "");
Expect(1, 7424, '\p{^invedicextensions}', "");
Expect(1, 7424, '\P{invedicextensions}', "");
Expect(0, 7424, '\P{^invedicextensions}', "");
Expect(1, 7423, '\p{	In_vedic_Extensions}', "");
Expect(0, 7423, '\p{^	In_vedic_Extensions}', "");
Expect(0, 7423, '\P{	In_vedic_Extensions}', "");
Expect(1, 7423, '\P{^	In_vedic_Extensions}', "");
Expect(0, 7424, '\p{	In_vedic_Extensions}', "");
Expect(1, 7424, '\p{^	In_vedic_Extensions}', "");
Expect(1, 7424, '\P{	In_vedic_Extensions}', "");
Expect(0, 7424, '\P{^	In_vedic_Extensions}', "");
Error('\p{_ VEDIC_Ext/a/}');
Error('\P{_ VEDIC_Ext/a/}');
Expect(1, 7423, '\p{vedicext}', "");
Expect(0, 7423, '\p{^vedicext}', "");
Expect(0, 7423, '\P{vedicext}', "");
Expect(1, 7423, '\P{^vedicext}', "");
Expect(0, 7424, '\p{vedicext}', "");
Expect(1, 7424, '\p{^vedicext}', "");
Expect(1, 7424, '\P{vedicext}', "");
Expect(0, 7424, '\P{^vedicext}', "");
Expect(1, 7423, '\p{ _Vedic_ext}', "");
Expect(0, 7423, '\p{^ _Vedic_ext}', "");
Expect(0, 7423, '\P{ _Vedic_ext}', "");
Expect(1, 7423, '\P{^ _Vedic_ext}', "");
Expect(0, 7424, '\p{ _Vedic_ext}', "");
Expect(1, 7424, '\p{^ _Vedic_ext}', "");
Expect(1, 7424, '\P{ _Vedic_ext}', "");
Expect(0, 7424, '\P{^ _Vedic_ext}', "");
Error('\p{	/a/Is_Vedic_Ext}');
Error('\P{	/a/Is_Vedic_Ext}');
Expect(1, 7423, '\p{isvedicext}', "");
Expect(0, 7423, '\p{^isvedicext}', "");
Expect(0, 7423, '\P{isvedicext}', "");
Expect(1, 7423, '\P{^isvedicext}', "");
Expect(0, 7424, '\p{isvedicext}', "");
Expect(1, 7424, '\p{^isvedicext}', "");
Expect(1, 7424, '\P{isvedicext}', "");
Expect(0, 7424, '\P{^isvedicext}', "");
Expect(1, 7423, '\p{- Is_VEDIC_Ext}', "");
Expect(0, 7423, '\p{^- Is_VEDIC_Ext}', "");
Expect(0, 7423, '\P{- Is_VEDIC_Ext}', "");
Expect(1, 7423, '\P{^- Is_VEDIC_Ext}', "");
Expect(0, 7424, '\p{- Is_VEDIC_Ext}', "");
Expect(1, 7424, '\p{^- Is_VEDIC_Ext}', "");
Expect(1, 7424, '\P{- Is_VEDIC_Ext}', "");
Expect(0, 7424, '\P{^- Is_VEDIC_Ext}', "");
Error('\p{:=__In_Vedic_EXT}');
Error('\P{:=__In_Vedic_EXT}');
Expect(1, 7423, '\p{invedicext}', "");
Expect(0, 7423, '\p{^invedicext}', "");
Expect(0, 7423, '\P{invedicext}', "");
Expect(1, 7423, '\P{^invedicext}', "");
Expect(0, 7424, '\p{invedicext}', "");
Expect(1, 7424, '\p{^invedicext}', "");
Expect(1, 7424, '\P{invedicext}', "");
Expect(0, 7424, '\P{^invedicext}', "");
Expect(1, 7423, '\p{	 IN_Vedic_Ext}', "");
Expect(0, 7423, '\p{^	 IN_Vedic_Ext}', "");
Expect(0, 7423, '\P{	 IN_Vedic_Ext}', "");
Expect(1, 7423, '\P{^	 IN_Vedic_Ext}', "");
Expect(0, 7424, '\p{	 IN_Vedic_Ext}', "");
Expect(1, 7424, '\p{^	 IN_Vedic_Ext}', "");
Expect(1, 7424, '\P{	 IN_Vedic_Ext}', "");
Expect(0, 7424, '\P{^	 IN_Vedic_Ext}', "");
Error('\p{/a/vertspace}');
Error('\P{/a/vertspace}');
Expect(1, 8233, '\p{vertspace}', "");
Expect(0, 8233, '\p{^vertspace}', "");
Expect(0, 8233, '\P{vertspace}', "");
Expect(1, 8233, '\P{^vertspace}', "");
Expect(0, 8234, '\p{vertspace}', "");
Expect(1, 8234, '\p{^vertspace}', "");
Expect(1, 8234, '\P{vertspace}', "");
Expect(0, 8234, '\P{^vertspace}', "");
Expect(1, 8233, '\p{	vertspace}', "");
Expect(0, 8233, '\p{^	vertspace}', "");
Expect(0, 8233, '\P{	vertspace}', "");
Expect(1, 8233, '\P{^	vertspace}', "");
Expect(0, 8234, '\p{	vertspace}', "");
Expect(1, 8234, '\p{^	vertspace}', "");
Expect(1, 8234, '\P{	vertspace}', "");
Expect(0, 8234, '\P{^	vertspace}', "");
Error('\p{:= Is_VertSpace}');
Error('\P{:= Is_VertSpace}');
Expect(1, 8233, '\p{isvertspace}', "");
Expect(0, 8233, '\p{^isvertspace}', "");
Expect(0, 8233, '\P{isvertspace}', "");
Expect(1, 8233, '\P{^isvertspace}', "");
Expect(0, 8234, '\p{isvertspace}', "");
Expect(1, 8234, '\p{^isvertspace}', "");
Expect(1, 8234, '\P{isvertspace}', "");
Expect(0, 8234, '\P{^isvertspace}', "");
Expect(1, 8233, '\p{	is_VertSpace}', "");
Expect(0, 8233, '\p{^	is_VertSpace}', "");
Expect(0, 8233, '\P{	is_VertSpace}', "");
Expect(1, 8233, '\P{^	is_VertSpace}', "");
Expect(0, 8234, '\p{	is_VertSpace}', "");
Expect(1, 8234, '\p{^	is_VertSpace}', "");
Expect(1, 8234, '\P{	is_VertSpace}', "");
Expect(0, 8234, '\P{^	is_VertSpace}', "");
Error('\p{ _Vertical_FORMS:=}');
Error('\P{ _Vertical_FORMS:=}');
Expect(1, 65055, '\p{verticalforms}', "");
Expect(0, 65055, '\p{^verticalforms}', "");
Expect(0, 65055, '\P{verticalforms}', "");
Expect(1, 65055, '\P{^verticalforms}', "");
Expect(0, 65056, '\p{verticalforms}', "");
Expect(1, 65056, '\p{^verticalforms}', "");
Expect(1, 65056, '\P{verticalforms}', "");
Expect(0, 65056, '\P{^verticalforms}', "");
Expect(1, 65055, '\p{ Vertical_Forms}', "");
Expect(0, 65055, '\p{^ Vertical_Forms}', "");
Expect(0, 65055, '\P{ Vertical_Forms}', "");
Expect(1, 65055, '\P{^ Vertical_Forms}', "");
Expect(0, 65056, '\p{ Vertical_Forms}', "");
Expect(1, 65056, '\p{^ Vertical_Forms}', "");
Expect(1, 65056, '\P{ Vertical_Forms}', "");
Expect(0, 65056, '\P{^ Vertical_Forms}', "");
Error('\p{__Is_Vertical_Forms/a/}');
Error('\P{__Is_Vertical_Forms/a/}');
Expect(1, 65055, '\p{isverticalforms}', "");
Expect(0, 65055, '\p{^isverticalforms}', "");
Expect(0, 65055, '\P{isverticalforms}', "");
Expect(1, 65055, '\P{^isverticalforms}', "");
Expect(0, 65056, '\p{isverticalforms}', "");
Expect(1, 65056, '\p{^isverticalforms}', "");
Expect(1, 65056, '\P{isverticalforms}', "");
Expect(0, 65056, '\P{^isverticalforms}', "");
Expect(1, 65055, '\p{-	Is_Vertical_FORMS}', "");
Expect(0, 65055, '\p{^-	Is_Vertical_FORMS}', "");
Expect(0, 65055, '\P{-	Is_Vertical_FORMS}', "");
Expect(1, 65055, '\P{^-	Is_Vertical_FORMS}', "");
Expect(0, 65056, '\p{-	Is_Vertical_FORMS}', "");
Expect(1, 65056, '\p{^-	Is_Vertical_FORMS}', "");
Expect(1, 65056, '\P{-	Is_Vertical_FORMS}', "");
Expect(0, 65056, '\P{^-	Is_Vertical_FORMS}', "");
Error('\p{ /a/IN_VERTICAL_forms}');
Error('\P{ /a/IN_VERTICAL_forms}');
Expect(1, 65055, '\p{inverticalforms}', "");
Expect(0, 65055, '\p{^inverticalforms}', "");
Expect(0, 65055, '\P{inverticalforms}', "");
Expect(1, 65055, '\P{^inverticalforms}', "");
Expect(0, 65056, '\p{inverticalforms}', "");
Expect(1, 65056, '\p{^inverticalforms}', "");
Expect(1, 65056, '\P{inverticalforms}', "");
Expect(0, 65056, '\P{^inverticalforms}', "");
Expect(1, 65055, '\p{--IN_VERTICAL_FORMS}', "");
Expect(0, 65055, '\p{^--IN_VERTICAL_FORMS}', "");
Expect(0, 65055, '\P{--IN_VERTICAL_FORMS}', "");
Expect(1, 65055, '\P{^--IN_VERTICAL_FORMS}', "");
Expect(0, 65056, '\p{--IN_VERTICAL_FORMS}', "");
Expect(1, 65056, '\p{^--IN_VERTICAL_FORMS}', "");
Expect(1, 65056, '\P{--IN_VERTICAL_FORMS}', "");
Expect(0, 65056, '\P{^--IN_VERTICAL_FORMS}', "");
Error('\p{ /a/White_SPACE}');
Error('\P{ /a/White_SPACE}');
Expect(1, 12288, '\p{whitespace}', "");
Expect(0, 12288, '\p{^whitespace}', "");
Expect(0, 12288, '\P{whitespace}', "");
Expect(1, 12288, '\P{^whitespace}', "");
Expect(0, 12289, '\p{whitespace}', "");
Expect(1, 12289, '\p{^whitespace}', "");
Expect(1, 12289, '\P{whitespace}', "");
Expect(0, 12289, '\P{^whitespace}', "");
Expect(1, 12288, '\p{		white_Space}', "");
Expect(0, 12288, '\p{^		white_Space}', "");
Expect(0, 12288, '\P{		white_Space}', "");
Expect(1, 12288, '\P{^		white_Space}', "");
Expect(0, 12289, '\p{		white_Space}', "");
Expect(1, 12289, '\p{^		white_Space}', "");
Expect(1, 12289, '\P{		white_Space}', "");
Expect(0, 12289, '\P{^		white_Space}', "");
Error('\p{/a/	 Is_White_Space}');
Error('\P{/a/	 Is_White_Space}');
Expect(1, 12288, '\p{iswhitespace}', "");
Expect(0, 12288, '\p{^iswhitespace}', "");
Expect(0, 12288, '\P{iswhitespace}', "");
Expect(1, 12288, '\P{^iswhitespace}', "");
Expect(0, 12289, '\p{iswhitespace}', "");
Expect(1, 12289, '\p{^iswhitespace}', "");
Expect(1, 12289, '\P{iswhitespace}', "");
Expect(0, 12289, '\P{^iswhitespace}', "");
Expect(1, 12288, '\p{ _is_White_space}', "");
Expect(0, 12288, '\p{^ _is_White_space}', "");
Expect(0, 12288, '\P{ _is_White_space}', "");
Expect(1, 12288, '\P{^ _is_White_space}', "");
Expect(0, 12289, '\p{ _is_White_space}', "");
Expect(1, 12289, '\p{^ _is_White_space}', "");
Expect(1, 12289, '\P{ _is_White_space}', "");
Expect(0, 12289, '\P{^ _is_White_space}', "");
Error('\p{ /a/WSPACE}');
Error('\P{ /a/WSPACE}');
Expect(1, 12288, '\p{wspace}', "");
Expect(0, 12288, '\p{^wspace}', "");
Expect(0, 12288, '\P{wspace}', "");
Expect(1, 12288, '\P{^wspace}', "");
Expect(0, 12289, '\p{wspace}', "");
Expect(1, 12289, '\p{^wspace}', "");
Expect(1, 12289, '\P{wspace}', "");
Expect(0, 12289, '\P{^wspace}', "");
Expect(1, 12288, '\p{_WSpace}', "");
Expect(0, 12288, '\p{^_WSpace}', "");
Expect(0, 12288, '\P{_WSpace}', "");
Expect(1, 12288, '\P{^_WSpace}', "");
Expect(0, 12289, '\p{_WSpace}', "");
Expect(1, 12289, '\p{^_WSpace}', "");
Expect(1, 12289, '\P{_WSpace}', "");
Expect(0, 12289, '\P{^_WSpace}', "");
Error('\p{	:=Is_WSPACE}');
Error('\P{	:=Is_WSPACE}');
Expect(1, 12288, '\p{iswspace}', "");
Expect(0, 12288, '\p{^iswspace}', "");
Expect(0, 12288, '\P{iswspace}', "");
Expect(1, 12288, '\P{^iswspace}', "");
Expect(0, 12289, '\p{iswspace}', "");
Expect(1, 12289, '\p{^iswspace}', "");
Expect(1, 12289, '\P{iswspace}', "");
Expect(0, 12289, '\P{^iswspace}', "");
Expect(1, 12288, '\p{ Is_WSpace}', "");
Expect(0, 12288, '\p{^ Is_WSpace}', "");
Expect(0, 12288, '\P{ Is_WSpace}', "");
Expect(1, 12288, '\P{^ Is_WSpace}', "");
Expect(0, 12289, '\p{ Is_WSpace}', "");
Expect(1, 12289, '\p{^ Is_WSpace}', "");
Expect(1, 12289, '\P{ Is_WSpace}', "");
Expect(0, 12289, '\P{^ Is_WSpace}', "");
Error('\p{ -word/a/}');
Error('\P{ -word/a/}');
Expect(1, 917999, '\p{word}', "");
Expect(0, 917999, '\p{^word}', "");
Expect(0, 917999, '\P{word}', "");
Expect(1, 917999, '\P{^word}', "");
Expect(0, 918000, '\p{word}', "");
Expect(1, 918000, '\p{^word}', "");
Expect(1, 918000, '\P{word}', "");
Expect(0, 918000, '\P{^word}', "");
Expect(1, 917999, '\p{_-word}', "");
Expect(0, 917999, '\p{^_-word}', "");
Expect(0, 917999, '\P{_-word}', "");
Expect(1, 917999, '\P{^_-word}', "");
Expect(0, 918000, '\p{_-word}', "");
Expect(1, 918000, '\p{^_-word}', "");
Expect(1, 918000, '\P{_-word}', "");
Expect(0, 918000, '\P{^_-word}', "");
Error('\p{:=  XPOSIXWORD}');
Error('\P{:=  XPOSIXWORD}');
Expect(1, 917999, '\p{xposixword}', "");
Expect(0, 917999, '\p{^xposixword}', "");
Expect(0, 917999, '\P{xposixword}', "");
Expect(1, 917999, '\P{^xposixword}', "");
Expect(0, 918000, '\p{xposixword}', "");
Expect(1, 918000, '\p{^xposixword}', "");
Expect(1, 918000, '\P{xposixword}', "");
Expect(0, 918000, '\P{^xposixword}', "");
Expect(1, 917999, '\p{ XPosixWord}', "");
Expect(0, 917999, '\p{^ XPosixWord}', "");
Expect(0, 917999, '\P{ XPosixWord}', "");
Expect(1, 917999, '\P{^ XPosixWord}', "");
Expect(0, 918000, '\p{ XPosixWord}', "");
Expect(1, 918000, '\p{^ XPosixWord}', "");
Expect(1, 918000, '\P{ XPosixWord}', "");
Expect(0, 918000, '\P{^ XPosixWord}', "");
Error('\p{	/a/is_word}');
Error('\P{	/a/is_word}');
Expect(1, 917999, '\p{isword}', "");
Expect(0, 917999, '\p{^isword}', "");
Expect(0, 917999, '\P{isword}', "");
Expect(1, 917999, '\P{^isword}', "");
Expect(0, 918000, '\p{isword}', "");
Expect(1, 918000, '\p{^isword}', "");
Expect(1, 918000, '\P{isword}', "");
Expect(0, 918000, '\P{^isword}', "");
Expect(1, 917999, '\p{ is_WORD}', "");
Expect(0, 917999, '\p{^ is_WORD}', "");
Expect(0, 917999, '\P{ is_WORD}', "");
Expect(1, 917999, '\P{^ is_WORD}', "");
Expect(0, 918000, '\p{ is_WORD}', "");
Expect(1, 918000, '\p{^ is_WORD}', "");
Expect(1, 918000, '\P{ is_WORD}', "");
Expect(0, 918000, '\P{^ is_WORD}', "");
Error('\p{_/a/is_XPosixWord}');
Error('\P{_/a/is_XPosixWord}');
Expect(1, 917999, '\p{isxposixword}', "");
Expect(0, 917999, '\p{^isxposixword}', "");
Expect(0, 917999, '\P{isxposixword}', "");
Expect(1, 917999, '\P{^isxposixword}', "");
Expect(0, 918000, '\p{isxposixword}', "");
Expect(1, 918000, '\p{^isxposixword}', "");
Expect(1, 918000, '\P{isxposixword}', "");
Expect(0, 918000, '\P{^isxposixword}', "");
Expect(1, 917999, '\p{  IS_XPOSIXWORD}', "");
Expect(0, 917999, '\p{^  IS_XPOSIXWORD}', "");
Expect(0, 917999, '\P{  IS_XPOSIXWORD}', "");
Expect(1, 917999, '\P{^  IS_XPOSIXWORD}', "");
Expect(0, 918000, '\p{  IS_XPOSIXWORD}', "");
Expect(1, 918000, '\p{^  IS_XPOSIXWORD}', "");
Expect(1, 918000, '\P{  IS_XPOSIXWORD}', "");
Expect(0, 918000, '\P{^  IS_XPOSIXWORD}', "");
Error('\p{:=	 XDIGIT}');
Error('\P{:=	 XDIGIT}');
Expect(1, 65350, '\p{xdigit}', "");
Expect(0, 65350, '\p{^xdigit}', "");
Expect(0, 65350, '\P{xdigit}', "");
Expect(1, 65350, '\P{^xdigit}', "");
Expect(0, 65351, '\p{xdigit}', "");
Expect(1, 65351, '\p{^xdigit}', "");
Expect(1, 65351, '\P{xdigit}', "");
Expect(0, 65351, '\P{^xdigit}', "");
Expect(1, 65350, '\p{_-xdigit}', "");
Expect(0, 65350, '\p{^_-xdigit}', "");
Expect(0, 65350, '\P{_-xdigit}', "");
Expect(1, 65350, '\P{^_-xdigit}', "");
Expect(0, 65351, '\p{_-xdigit}', "");
Expect(1, 65351, '\p{^_-xdigit}', "");
Expect(1, 65351, '\P{_-xdigit}', "");
Expect(0, 65351, '\P{^_-xdigit}', "");
Error('\p{	_XPosixXDigit/a/}');
Error('\P{	_XPosixXDigit/a/}');
Expect(1, 65350, '\p{xposixxdigit}', "");
Expect(0, 65350, '\p{^xposixxdigit}', "");
Expect(0, 65350, '\P{xposixxdigit}', "");
Expect(1, 65350, '\P{^xposixxdigit}', "");
Expect(0, 65351, '\p{xposixxdigit}', "");
Expect(1, 65351, '\p{^xposixxdigit}', "");
Expect(1, 65351, '\P{xposixxdigit}', "");
Expect(0, 65351, '\P{^xposixxdigit}', "");
Expect(1, 65350, '\p{_XPOSIXXDIGIT}', "");
Expect(0, 65350, '\p{^_XPOSIXXDIGIT}', "");
Expect(0, 65350, '\P{_XPOSIXXDIGIT}', "");
Expect(1, 65350, '\P{^_XPOSIXXDIGIT}', "");
Expect(0, 65351, '\p{_XPOSIXXDIGIT}', "");
Expect(1, 65351, '\p{^_XPOSIXXDIGIT}', "");
Expect(1, 65351, '\P{_XPOSIXXDIGIT}', "");
Expect(0, 65351, '\P{^_XPOSIXXDIGIT}', "");
Error('\p{	Is_XDIGIT:=}');
Error('\P{	Is_XDIGIT:=}');
Expect(1, 65350, '\p{isxdigit}', "");
Expect(0, 65350, '\p{^isxdigit}', "");
Expect(0, 65350, '\P{isxdigit}', "");
Expect(1, 65350, '\P{^isxdigit}', "");
Expect(0, 65351, '\p{isxdigit}', "");
Expect(1, 65351, '\p{^isxdigit}', "");
Expect(1, 65351, '\P{isxdigit}', "");
Expect(0, 65351, '\P{^isxdigit}', "");
Expect(1, 65350, '\p{-Is_XDigit}', "");
Expect(0, 65350, '\p{^-Is_XDigit}', "");
Expect(0, 65350, '\P{-Is_XDigit}', "");
Expect(1, 65350, '\P{^-Is_XDigit}', "");
Expect(0, 65351, '\p{-Is_XDigit}', "");
Expect(1, 65351, '\p{^-Is_XDigit}', "");
Expect(1, 65351, '\P{-Is_XDigit}', "");
Expect(0, 65351, '\P{^-Is_XDigit}', "");
Error('\p{	 is_XPosixXDigit:=}');
Error('\P{	 is_XPosixXDigit:=}');
Expect(1, 65350, '\p{isxposixxdigit}', "");
Expect(0, 65350, '\p{^isxposixxdigit}', "");
Expect(0, 65350, '\P{isxposixxdigit}', "");
Expect(1, 65350, '\P{^isxposixxdigit}', "");
Expect(0, 65351, '\p{isxposixxdigit}', "");
Expect(1, 65351, '\p{^isxposixxdigit}', "");
Expect(1, 65351, '\P{isxposixxdigit}', "");
Expect(0, 65351, '\P{^isxposixxdigit}', "");
Expect(1, 65350, '\p{_is_xposixxdigit}', "");
Expect(0, 65350, '\p{^_is_xposixxdigit}', "");
Expect(0, 65350, '\P{_is_xposixxdigit}', "");
Expect(1, 65350, '\P{^_is_xposixxdigit}', "");
Expect(0, 65351, '\p{_is_xposixxdigit}', "");
Expect(1, 65351, '\p{^_is_xposixxdigit}', "");
Expect(1, 65351, '\P{_is_xposixxdigit}', "");
Expect(0, 65351, '\P{^_is_xposixxdigit}', "");
Error('\p{:=-_hex_Digit}');
Error('\P{:=-_hex_Digit}');
Expect(1, 65350, '\p{hexdigit}', "");
Expect(0, 65350, '\p{^hexdigit}', "");
Expect(0, 65350, '\P{hexdigit}', "");
Expect(1, 65350, '\P{^hexdigit}', "");
Expect(0, 65351, '\p{hexdigit}', "");
Expect(1, 65351, '\p{^hexdigit}', "");
Expect(1, 65351, '\P{hexdigit}', "");
Expect(0, 65351, '\P{^hexdigit}', "");
Expect(1, 65350, '\p{  hex_DIGIT}', "");
Expect(0, 65350, '\p{^  hex_DIGIT}', "");
Expect(0, 65350, '\P{  hex_DIGIT}', "");
Expect(1, 65350, '\P{^  hex_DIGIT}', "");
Expect(0, 65351, '\p{  hex_DIGIT}', "");
Expect(1, 65351, '\p{^  hex_DIGIT}', "");
Expect(1, 65351, '\P{  hex_DIGIT}', "");
Expect(0, 65351, '\P{^  hex_DIGIT}', "");
Error('\p{  is_HEX_DIGIT/a/}');
Error('\P{  is_HEX_DIGIT/a/}');
Expect(1, 65350, '\p{ishexdigit}', "");
Expect(0, 65350, '\p{^ishexdigit}', "");
Expect(0, 65350, '\P{ishexdigit}', "");
Expect(1, 65350, '\P{^ishexdigit}', "");
Expect(0, 65351, '\p{ishexdigit}', "");
Expect(1, 65351, '\p{^ishexdigit}', "");
Expect(1, 65351, '\P{ishexdigit}', "");
Expect(0, 65351, '\P{^ishexdigit}', "");
Expect(1, 65350, '\p{		is_HEX_Digit}', "");
Expect(0, 65350, '\p{^		is_HEX_Digit}', "");
Expect(0, 65350, '\P{		is_HEX_Digit}', "");
Expect(1, 65350, '\P{^		is_HEX_Digit}', "");
Expect(0, 65351, '\p{		is_HEX_Digit}', "");
Expect(1, 65351, '\p{^		is_HEX_Digit}', "");
Expect(1, 65351, '\P{		is_HEX_Digit}', "");
Expect(0, 65351, '\P{^		is_HEX_Digit}', "");
Error('\p{__hex:=}');
Error('\P{__hex:=}');
Expect(1, 65350, '\p{hex}', "");
Expect(0, 65350, '\p{^hex}', "");
Expect(0, 65350, '\P{hex}', "");
Expect(1, 65350, '\P{^hex}', "");
Expect(0, 65351, '\p{hex}', "");
Expect(1, 65351, '\p{^hex}', "");
Expect(1, 65351, '\P{hex}', "");
Expect(0, 65351, '\P{^hex}', "");
Expect(1, 65350, '\p{	-Hex}', "");
Expect(0, 65350, '\p{^	-Hex}', "");
Expect(0, 65350, '\P{	-Hex}', "");
Expect(1, 65350, '\P{^	-Hex}', "");
Expect(0, 65351, '\p{	-Hex}', "");
Expect(1, 65351, '\p{^	-Hex}', "");
Expect(1, 65351, '\P{	-Hex}', "");
Expect(0, 65351, '\P{^	-Hex}', "");
Error('\p{/a/  is_HEX}');
Error('\P{/a/  is_HEX}');
Expect(1, 65350, '\p{ishex}', "");
Expect(0, 65350, '\p{^ishex}', "");
Expect(0, 65350, '\P{ishex}', "");
Expect(1, 65350, '\P{^ishex}', "");
Expect(0, 65351, '\p{ishex}', "");
Expect(1, 65351, '\p{^ishex}', "");
Expect(1, 65351, '\P{ishex}', "");
Expect(0, 65351, '\P{^ishex}', "");
Expect(1, 65350, '\p{ is_HEX}', "");
Expect(0, 65350, '\p{^ is_HEX}', "");
Expect(0, 65350, '\P{ is_HEX}', "");
Expect(1, 65350, '\P{^ is_HEX}', "");
Expect(0, 65351, '\p{ is_HEX}', "");
Expect(1, 65351, '\p{^ is_HEX}', "");
Expect(1, 65351, '\P{ is_HEX}', "");
Expect(0, 65351, '\P{^ is_HEX}', "");
Error('\p{XID_continue:=}');
Error('\P{XID_continue:=}');
Expect(1, 917999, '\p{xidcontinue}', "");
Expect(0, 917999, '\p{^xidcontinue}', "");
Expect(0, 917999, '\P{xidcontinue}', "");
Expect(1, 917999, '\P{^xidcontinue}', "");
Expect(0, 918000, '\p{xidcontinue}', "");
Expect(1, 918000, '\p{^xidcontinue}', "");
Expect(1, 918000, '\P{xidcontinue}', "");
Expect(0, 918000, '\P{^xidcontinue}', "");
Expect(1, 917999, '\p{_ xid_Continue}', "");
Expect(0, 917999, '\p{^_ xid_Continue}', "");
Expect(0, 917999, '\P{_ xid_Continue}', "");
Expect(1, 917999, '\P{^_ xid_Continue}', "");
Expect(0, 918000, '\p{_ xid_Continue}', "");
Expect(1, 918000, '\p{^_ xid_Continue}', "");
Expect(1, 918000, '\P{_ xid_Continue}', "");
Expect(0, 918000, '\P{^_ xid_Continue}', "");
Error('\p{/a/ Is_XID_CONTINUE}');
Error('\P{/a/ Is_XID_CONTINUE}');
Expect(1, 917999, '\p{isxidcontinue}', "");
Expect(0, 917999, '\p{^isxidcontinue}', "");
Expect(0, 917999, '\P{isxidcontinue}', "");
Expect(1, 917999, '\P{^isxidcontinue}', "");
Expect(0, 918000, '\p{isxidcontinue}', "");
Expect(1, 918000, '\p{^isxidcontinue}', "");
Expect(1, 918000, '\P{isxidcontinue}', "");
Expect(0, 918000, '\P{^isxidcontinue}', "");
Expect(1, 917999, '\p{_-Is_XID_continue}', "");
Expect(0, 917999, '\p{^_-Is_XID_continue}', "");
Expect(0, 917999, '\P{_-Is_XID_continue}', "");
Expect(1, 917999, '\P{^_-Is_XID_continue}', "");
Expect(0, 918000, '\p{_-Is_XID_continue}', "");
Expect(1, 918000, '\p{^_-Is_XID_continue}', "");
Expect(1, 918000, '\P{_-Is_XID_continue}', "");
Expect(0, 918000, '\P{^_-Is_XID_continue}', "");
Error('\p{/a/	-XIDC}');
Error('\P{/a/	-XIDC}');
Expect(1, 917999, '\p{xidc}', "");
Expect(0, 917999, '\p{^xidc}', "");
Expect(0, 917999, '\P{xidc}', "");
Expect(1, 917999, '\P{^xidc}', "");
Expect(0, 918000, '\p{xidc}', "");
Expect(1, 918000, '\p{^xidc}', "");
Expect(1, 918000, '\P{xidc}', "");
Expect(0, 918000, '\P{^xidc}', "");
Expect(1, 917999, '\p{ xidc}', "");
Expect(0, 917999, '\p{^ xidc}', "");
Expect(0, 917999, '\P{ xidc}', "");
Expect(1, 917999, '\P{^ xidc}', "");
Expect(0, 918000, '\p{ xidc}', "");
Expect(1, 918000, '\p{^ xidc}', "");
Expect(1, 918000, '\P{ xidc}', "");
Expect(0, 918000, '\P{^ xidc}', "");
Error('\p{	_is_XIDC/a/}');
Error('\P{	_is_XIDC/a/}');
Expect(1, 917999, '\p{isxidc}', "");
Expect(0, 917999, '\p{^isxidc}', "");
Expect(0, 917999, '\P{isxidc}', "");
Expect(1, 917999, '\P{^isxidc}', "");
Expect(0, 918000, '\p{isxidc}', "");
Expect(1, 918000, '\p{^isxidc}', "");
Expect(1, 918000, '\P{isxidc}', "");
Expect(0, 918000, '\P{^isxidc}', "");
Expect(1, 917999, '\p{		Is_XIDC}', "");
Expect(0, 917999, '\p{^		Is_XIDC}', "");
Expect(0, 917999, '\P{		Is_XIDC}', "");
Expect(1, 917999, '\P{^		Is_XIDC}', "");
Expect(0, 918000, '\p{		Is_XIDC}', "");
Expect(1, 918000, '\p{^		Is_XIDC}', "");
Expect(1, 918000, '\P{		Is_XIDC}', "");
Expect(0, 918000, '\P{^		Is_XIDC}', "");
Error('\p{-XID_START/a/}');
Error('\P{-XID_START/a/}');
Expect(1, 195101, '\p{xidstart}', "");
Expect(0, 195101, '\p{^xidstart}', "");
Expect(0, 195101, '\P{xidstart}', "");
Expect(1, 195101, '\P{^xidstart}', "");
Expect(0, 195102, '\p{xidstart}', "");
Expect(1, 195102, '\p{^xidstart}', "");
Expect(1, 195102, '\P{xidstart}', "");
Expect(0, 195102, '\P{^xidstart}', "");
Expect(1, 195101, '\p{- XID_Start}', "");
Expect(0, 195101, '\p{^- XID_Start}', "");
Expect(0, 195101, '\P{- XID_Start}', "");
Expect(1, 195101, '\P{^- XID_Start}', "");
Expect(0, 195102, '\p{- XID_Start}', "");
Expect(1, 195102, '\p{^- XID_Start}', "");
Expect(1, 195102, '\P{- XID_Start}', "");
Expect(0, 195102, '\P{^- XID_Start}', "");
Error('\p{	/a/Is_XID_Start}');
Error('\P{	/a/Is_XID_Start}');
Expect(1, 195101, '\p{isxidstart}', "");
Expect(0, 195101, '\p{^isxidstart}', "");
Expect(0, 195101, '\P{isxidstart}', "");
Expect(1, 195101, '\P{^isxidstart}', "");
Expect(0, 195102, '\p{isxidstart}', "");
Expect(1, 195102, '\p{^isxidstart}', "");
Expect(1, 195102, '\P{isxidstart}', "");
Expect(0, 195102, '\P{^isxidstart}', "");
Expect(1, 195101, '\p{Is_XID_Start}', "");
Expect(0, 195101, '\p{^Is_XID_Start}', "");
Expect(0, 195101, '\P{Is_XID_Start}', "");
Expect(1, 195101, '\P{^Is_XID_Start}', "");
Expect(0, 195102, '\p{Is_XID_Start}', "");
Expect(1, 195102, '\p{^Is_XID_Start}', "");
Expect(1, 195102, '\P{Is_XID_Start}', "");
Expect(0, 195102, '\P{^Is_XID_Start}', "");
Error('\p{/a/	XIDS}');
Error('\P{/a/	XIDS}');
Expect(1, 195101, '\p{xids}', "");
Expect(0, 195101, '\p{^xids}', "");
Expect(0, 195101, '\P{xids}', "");
Expect(1, 195101, '\P{^xids}', "");
Expect(0, 195102, '\p{xids}', "");
Expect(1, 195102, '\p{^xids}', "");
Expect(1, 195102, '\P{xids}', "");
Expect(0, 195102, '\P{^xids}', "");
Expect(1, 195101, '\p{ XIDS}', "");
Expect(0, 195101, '\p{^ XIDS}', "");
Expect(0, 195101, '\P{ XIDS}', "");
Expect(1, 195101, '\P{^ XIDS}', "");
Expect(0, 195102, '\p{ XIDS}', "");
Expect(1, 195102, '\p{^ XIDS}', "");
Expect(1, 195102, '\P{ XIDS}', "");
Expect(0, 195102, '\P{^ XIDS}', "");
Error('\p{/a/--is_XIDS}');
Error('\P{/a/--is_XIDS}');
Expect(1, 195101, '\p{isxids}', "");
Expect(0, 195101, '\p{^isxids}', "");
Expect(0, 195101, '\P{isxids}', "");
Expect(1, 195101, '\P{^isxids}', "");
Expect(0, 195102, '\p{isxids}', "");
Expect(1, 195102, '\p{^isxids}', "");
Expect(1, 195102, '\P{isxids}', "");
Expect(0, 195102, '\P{^isxids}', "");
Expect(1, 195101, '\p{-Is_XIDS}', "");
Expect(0, 195101, '\p{^-Is_XIDS}', "");
Expect(0, 195101, '\P{-Is_XIDS}', "");
Expect(1, 195101, '\P{^-Is_XIDS}', "");
Expect(0, 195102, '\p{-Is_XIDS}', "");
Expect(1, 195102, '\p{^-Is_XIDS}', "");
Expect(1, 195102, '\P{-Is_XIDS}', "");
Expect(0, 195102, '\P{^-Is_XIDS}', "");
Error('\p{ /a/XPerlSpace}');
Error('\P{ /a/XPerlSpace}');
Expect(1, 12288, '\p{xperlspace}', "");
Expect(0, 12288, '\p{^xperlspace}', "");
Expect(0, 12288, '\P{xperlspace}', "");
Expect(1, 12288, '\P{^xperlspace}', "");
Expect(0, 12289, '\p{xperlspace}', "");
Expect(1, 12289, '\p{^xperlspace}', "");
Expect(1, 12289, '\P{xperlspace}', "");
Expect(0, 12289, '\P{^xperlspace}', "");
Expect(1, 12288, '\p{_XPerlSpace}', "");
Expect(0, 12288, '\p{^_XPerlSpace}', "");
Expect(0, 12288, '\P{_XPerlSpace}', "");
Expect(1, 12288, '\P{^_XPerlSpace}', "");
Expect(0, 12289, '\p{_XPerlSpace}', "");
Expect(1, 12289, '\p{^_XPerlSpace}', "");
Expect(1, 12289, '\P{_XPerlSpace}', "");
Expect(0, 12289, '\P{^_XPerlSpace}', "");
Error('\p{:=	-SPACEPERL}');
Error('\P{:=	-SPACEPERL}');
Expect(1, 12288, '\p{spaceperl}', "");
Expect(0, 12288, '\p{^spaceperl}', "");
Expect(0, 12288, '\P{spaceperl}', "");
Expect(1, 12288, '\P{^spaceperl}', "");
Expect(0, 12289, '\p{spaceperl}', "");
Expect(1, 12289, '\p{^spaceperl}', "");
Expect(1, 12289, '\P{spaceperl}', "");
Expect(0, 12289, '\P{^spaceperl}', "");
Expect(1, 12288, '\p{-SpacePerl}', "");
Expect(0, 12288, '\p{^-SpacePerl}', "");
Expect(0, 12288, '\P{-SpacePerl}', "");
Expect(1, 12288, '\P{^-SpacePerl}', "");
Expect(0, 12289, '\p{-SpacePerl}', "");
Expect(1, 12289, '\p{^-SpacePerl}', "");
Expect(1, 12289, '\P{-SpacePerl}', "");
Expect(0, 12289, '\P{^-SpacePerl}', "");
Error('\p{:=-Is_xperlspace}');
Error('\P{:=-Is_xperlspace}');
Expect(1, 12288, '\p{isxperlspace}', "");
Expect(0, 12288, '\p{^isxperlspace}', "");
Expect(0, 12288, '\P{isxperlspace}', "");
Expect(1, 12288, '\P{^isxperlspace}', "");
Expect(0, 12289, '\p{isxperlspace}', "");
Expect(1, 12289, '\p{^isxperlspace}', "");
Expect(1, 12289, '\P{isxperlspace}', "");
Expect(0, 12289, '\P{^isxperlspace}', "");
Expect(1, 12288, '\p{_ is_xperlspace}', "");
Expect(0, 12288, '\p{^_ is_xperlspace}', "");
Expect(0, 12288, '\P{_ is_xperlspace}', "");
Expect(1, 12288, '\P{^_ is_xperlspace}', "");
Expect(0, 12289, '\p{_ is_xperlspace}', "");
Expect(1, 12289, '\p{^_ is_xperlspace}', "");
Expect(1, 12289, '\P{_ is_xperlspace}', "");
Expect(0, 12289, '\P{^_ is_xperlspace}', "");
Error('\p{:=__is_SPACEPERL}');
Error('\P{:=__is_SPACEPERL}');
Expect(1, 12288, '\p{isspaceperl}', "");
Expect(0, 12288, '\p{^isspaceperl}', "");
Expect(0, 12288, '\P{isspaceperl}', "");
Expect(1, 12288, '\P{^isspaceperl}', "");
Expect(0, 12289, '\p{isspaceperl}', "");
Expect(1, 12289, '\p{^isspaceperl}', "");
Expect(1, 12289, '\P{isspaceperl}', "");
Expect(0, 12289, '\P{^isspaceperl}', "");
Expect(1, 12288, '\p{--IS_SPACEPERL}', "");
Expect(0, 12288, '\p{^--IS_SPACEPERL}', "");
Expect(0, 12288, '\P{--IS_SPACEPERL}', "");
Expect(1, 12288, '\P{^--IS_SPACEPERL}', "");
Expect(0, 12289, '\p{--IS_SPACEPERL}', "");
Expect(1, 12289, '\p{^--IS_SPACEPERL}', "");
Expect(1, 12289, '\P{--IS_SPACEPERL}', "");
Expect(0, 12289, '\P{^--IS_SPACEPERL}', "");
Error('\p{XPOSIXPUNCT:=}');
Error('\P{XPOSIXPUNCT:=}');
Expect(1, 74867, '\p{xposixpunct}', "");
Expect(0, 74867, '\p{^xposixpunct}', "");
Expect(0, 74867, '\P{xposixpunct}', "");
Expect(1, 74867, '\P{^xposixpunct}', "");
Expect(0, 74868, '\p{xposixpunct}', "");
Expect(1, 74868, '\p{^xposixpunct}', "");
Expect(1, 74868, '\P{xposixpunct}', "");
Expect(0, 74868, '\P{^xposixpunct}', "");
Expect(1, 74867, '\p{ XPOSIXPUNCT}', "");
Expect(0, 74867, '\p{^ XPOSIXPUNCT}', "");
Expect(0, 74867, '\P{ XPOSIXPUNCT}', "");
Expect(1, 74867, '\P{^ XPOSIXPUNCT}', "");
Expect(0, 74868, '\p{ XPOSIXPUNCT}', "");
Expect(1, 74868, '\p{^ XPOSIXPUNCT}', "");
Expect(1, 74868, '\P{ XPOSIXPUNCT}', "");
Expect(0, 74868, '\P{^ XPOSIXPUNCT}', "");
Error('\p{:=	-IS_XPosixPunct}');
Error('\P{:=	-IS_XPosixPunct}');
Expect(1, 74867, '\p{isxposixpunct}', "");
Expect(0, 74867, '\p{^isxposixpunct}', "");
Expect(0, 74867, '\P{isxposixpunct}', "");
Expect(1, 74867, '\P{^isxposixpunct}', "");
Expect(0, 74868, '\p{isxposixpunct}', "");
Expect(1, 74868, '\p{^isxposixpunct}', "");
Expect(1, 74868, '\P{isxposixpunct}', "");
Expect(0, 74868, '\P{^isxposixpunct}', "");
Expect(1, 74867, '\p{	 Is_XPOSIXPUNCT}', "");
Expect(0, 74867, '\p{^	 Is_XPOSIXPUNCT}', "");
Expect(0, 74867, '\P{	 Is_XPOSIXPUNCT}', "");
Expect(1, 74867, '\P{^	 Is_XPOSIXPUNCT}', "");
Expect(0, 74868, '\p{	 Is_XPOSIXPUNCT}', "");
Expect(1, 74868, '\p{^	 Is_XPOSIXPUNCT}', "");
Expect(1, 74868, '\P{	 Is_XPOSIXPUNCT}', "");
Expect(0, 74868, '\P{^	 Is_XPOSIXPUNCT}', "");
Error('\p{	:=YI}');
Error('\P{	:=YI}');
Expect(1, 42182, '\p{yi}', "");
Expect(0, 42182, '\p{^yi}', "");
Expect(0, 42182, '\P{yi}', "");
Expect(1, 42182, '\P{^yi}', "");
Expect(0, 42183, '\p{yi}', "");
Expect(1, 42183, '\p{^yi}', "");
Expect(1, 42183, '\P{yi}', "");
Expect(0, 42183, '\P{^yi}', "");
Expect(1, 42182, '\p{	-Yi}', "");
Expect(0, 42182, '\p{^	-Yi}', "");
Expect(0, 42182, '\P{	-Yi}', "");
Expect(1, 42182, '\P{^	-Yi}', "");
Expect(0, 42183, '\p{	-Yi}', "");
Expect(1, 42183, '\p{^	-Yi}', "");
Expect(1, 42183, '\P{	-Yi}', "");
Expect(0, 42183, '\P{^	-Yi}', "");
Error('\p{	:=Is_Yi}');
Error('\P{	:=Is_Yi}');
Expect(1, 42182, '\p{isyi}', "");
Expect(0, 42182, '\p{^isyi}', "");
Expect(0, 42182, '\P{isyi}', "");
Expect(1, 42182, '\P{^isyi}', "");
Expect(0, 42183, '\p{isyi}', "");
Expect(1, 42183, '\p{^isyi}', "");
Expect(1, 42183, '\P{isyi}', "");
Expect(0, 42183, '\P{^isyi}', "");
Expect(1, 42182, '\p{-	Is_YI}', "");
Expect(0, 42182, '\p{^-	Is_YI}', "");
Expect(0, 42182, '\P{-	Is_YI}', "");
Expect(1, 42182, '\P{^-	Is_YI}', "");
Expect(0, 42183, '\p{-	Is_YI}', "");
Expect(1, 42183, '\p{^-	Is_YI}', "");
Expect(1, 42183, '\P{-	Is_YI}', "");
Expect(0, 42183, '\P{^-	Is_YI}', "");
Error('\p{  yiii:=}');
Error('\P{  yiii:=}');
Expect(1, 42182, '\p{yiii}', "");
Expect(0, 42182, '\p{^yiii}', "");
Expect(0, 42182, '\P{yiii}', "");
Expect(1, 42182, '\P{^yiii}', "");
Expect(0, 42183, '\p{yiii}', "");
Expect(1, 42183, '\p{^yiii}', "");
Expect(1, 42183, '\P{yiii}', "");
Expect(0, 42183, '\P{^yiii}', "");
Expect(1, 42182, '\p{__Yiii}', "");
Expect(0, 42182, '\p{^__Yiii}', "");
Expect(0, 42182, '\P{__Yiii}', "");
Expect(1, 42182, '\P{^__Yiii}', "");
Expect(0, 42183, '\p{__Yiii}', "");
Expect(1, 42183, '\p{^__Yiii}', "");
Expect(1, 42183, '\P{__Yiii}', "");
Expect(0, 42183, '\P{^__Yiii}', "");
Error('\p{/a/ _Is_YIII}');
Error('\P{/a/ _Is_YIII}');
Expect(1, 42182, '\p{isyiii}', "");
Expect(0, 42182, '\p{^isyiii}', "");
Expect(0, 42182, '\P{isyiii}', "");
Expect(1, 42182, '\P{^isyiii}', "");
Expect(0, 42183, '\p{isyiii}', "");
Expect(1, 42183, '\p{^isyiii}', "");
Expect(1, 42183, '\P{isyiii}', "");
Expect(0, 42183, '\P{^isyiii}', "");
Expect(1, 42182, '\p{	_is_Yiii}', "");
Expect(0, 42182, '\p{^	_is_Yiii}', "");
Expect(0, 42182, '\P{	_is_Yiii}', "");
Expect(1, 42182, '\P{^	_is_Yiii}', "");
Expect(0, 42183, '\p{	_is_Yiii}', "");
Expect(1, 42183, '\p{^	_is_Yiii}', "");
Expect(1, 42183, '\P{	_is_Yiii}', "");
Expect(0, 42183, '\P{^	_is_Yiii}', "");
Error('\p{- yi_RADICALS:=}');
Error('\P{- yi_RADICALS:=}');
Expect(1, 42191, '\p{yiradicals}', "");
Expect(0, 42191, '\p{^yiradicals}', "");
Expect(0, 42191, '\P{yiradicals}', "");
Expect(1, 42191, '\P{^yiradicals}', "");
Expect(0, 42192, '\p{yiradicals}', "");
Expect(1, 42192, '\p{^yiradicals}', "");
Expect(1, 42192, '\P{yiradicals}', "");
Expect(0, 42192, '\P{^yiradicals}', "");
Expect(1, 42191, '\p{	Yi_RADICALS}', "");
Expect(0, 42191, '\p{^	Yi_RADICALS}', "");
Expect(0, 42191, '\P{	Yi_RADICALS}', "");
Expect(1, 42191, '\P{^	Yi_RADICALS}', "");
Expect(0, 42192, '\p{	Yi_RADICALS}', "");
Expect(1, 42192, '\p{^	Yi_RADICALS}', "");
Expect(1, 42192, '\P{	Yi_RADICALS}', "");
Expect(0, 42192, '\P{^	Yi_RADICALS}', "");
Error('\p{_ Is_YI_Radicals/a/}');
Error('\P{_ Is_YI_Radicals/a/}');
Expect(1, 42191, '\p{isyiradicals}', "");
Expect(0, 42191, '\p{^isyiradicals}', "");
Expect(0, 42191, '\P{isyiradicals}', "");
Expect(1, 42191, '\P{^isyiradicals}', "");
Expect(0, 42192, '\p{isyiradicals}', "");
Expect(1, 42192, '\p{^isyiradicals}', "");
Expect(1, 42192, '\P{isyiradicals}', "");
Expect(0, 42192, '\P{^isyiradicals}', "");
Expect(1, 42191, '\p{		is_yi_Radicals}', "");
Expect(0, 42191, '\p{^		is_yi_Radicals}', "");
Expect(0, 42191, '\P{		is_yi_Radicals}', "");
Expect(1, 42191, '\P{^		is_yi_Radicals}', "");
Expect(0, 42192, '\p{		is_yi_Radicals}', "");
Expect(1, 42192, '\p{^		is_yi_Radicals}', "");
Expect(1, 42192, '\P{		is_yi_Radicals}', "");
Expect(0, 42192, '\P{^		is_yi_Radicals}', "");
Error('\p{/a/IN_Yi_Radicals}');
Error('\P{/a/IN_Yi_Radicals}');
Expect(1, 42191, '\p{inyiradicals}', "");
Expect(0, 42191, '\p{^inyiradicals}', "");
Expect(0, 42191, '\P{inyiradicals}', "");
Expect(1, 42191, '\P{^inyiradicals}', "");
Expect(0, 42192, '\p{inyiradicals}', "");
Expect(1, 42192, '\p{^inyiradicals}', "");
Expect(1, 42192, '\P{inyiradicals}', "");
Expect(0, 42192, '\P{^inyiradicals}', "");
Expect(1, 42191, '\p{	In_yi_radicals}', "");
Expect(0, 42191, '\p{^	In_yi_radicals}', "");
Expect(0, 42191, '\P{	In_yi_radicals}', "");
Expect(1, 42191, '\P{^	In_yi_radicals}', "");
Expect(0, 42192, '\p{	In_yi_radicals}', "");
Expect(1, 42192, '\p{^	In_yi_radicals}', "");
Expect(1, 42192, '\P{	In_yi_radicals}', "");
Expect(0, 42192, '\P{^	In_yi_radicals}', "");
Error('\p{_ YI_SYLLABLES:=}');
Error('\P{_ YI_SYLLABLES:=}');
Expect(1, 42127, '\p{yisyllables}', "");
Expect(0, 42127, '\p{^yisyllables}', "");
Expect(0, 42127, '\P{yisyllables}', "");
Expect(1, 42127, '\P{^yisyllables}', "");
Expect(0, 42128, '\p{yisyllables}', "");
Expect(1, 42128, '\p{^yisyllables}', "");
Expect(1, 42128, '\P{yisyllables}', "");
Expect(0, 42128, '\P{^yisyllables}', "");
Expect(1, 42127, '\p{-	Yi_SYLLABLES}', "");
Expect(0, 42127, '\p{^-	Yi_SYLLABLES}', "");
Expect(0, 42127, '\P{-	Yi_SYLLABLES}', "");
Expect(1, 42127, '\P{^-	Yi_SYLLABLES}', "");
Expect(0, 42128, '\p{-	Yi_SYLLABLES}', "");
Expect(1, 42128, '\p{^-	Yi_SYLLABLES}', "");
Expect(1, 42128, '\P{-	Yi_SYLLABLES}', "");
Expect(0, 42128, '\P{^-	Yi_SYLLABLES}', "");
Error('\p{:=_	Is_Yi_SYLLABLES}');
Error('\P{:=_	Is_Yi_SYLLABLES}');
Expect(1, 42127, '\p{isyisyllables}', "");
Expect(0, 42127, '\p{^isyisyllables}', "");
Expect(0, 42127, '\P{isyisyllables}', "");
Expect(1, 42127, '\P{^isyisyllables}', "");
Expect(0, 42128, '\p{isyisyllables}', "");
Expect(1, 42128, '\p{^isyisyllables}', "");
Expect(1, 42128, '\P{isyisyllables}', "");
Expect(0, 42128, '\P{^isyisyllables}', "");
Expect(1, 42127, '\p{_-Is_Yi_Syllables}', "");
Expect(0, 42127, '\p{^_-Is_Yi_Syllables}', "");
Expect(0, 42127, '\P{_-Is_Yi_Syllables}', "");
Expect(1, 42127, '\P{^_-Is_Yi_Syllables}', "");
Expect(0, 42128, '\p{_-Is_Yi_Syllables}', "");
Expect(1, 42128, '\p{^_-Is_Yi_Syllables}', "");
Expect(1, 42128, '\P{_-Is_Yi_Syllables}', "");
Expect(0, 42128, '\P{^_-Is_Yi_Syllables}', "");
Error('\p{/a/_IN_Yi_Syllables}');
Error('\P{/a/_IN_Yi_Syllables}');
Expect(1, 42127, '\p{inyisyllables}', "");
Expect(0, 42127, '\p{^inyisyllables}', "");
Expect(0, 42127, '\P{inyisyllables}', "");
Expect(1, 42127, '\P{^inyisyllables}', "");
Expect(0, 42128, '\p{inyisyllables}', "");
Expect(1, 42128, '\p{^inyisyllables}', "");
Expect(1, 42128, '\P{inyisyllables}', "");
Expect(0, 42128, '\P{^inyisyllables}', "");
Expect(1, 42127, '\p{_ In_Yi_SYLLABLES}', "");
Expect(0, 42127, '\p{^_ In_Yi_SYLLABLES}', "");
Expect(0, 42127, '\P{_ In_Yi_SYLLABLES}', "");
Expect(1, 42127, '\P{^_ In_Yi_SYLLABLES}', "");
Expect(0, 42128, '\p{_ In_Yi_SYLLABLES}', "");
Expect(1, 42128, '\p{^_ In_Yi_SYLLABLES}', "");
Expect(1, 42128, '\P{_ In_Yi_SYLLABLES}', "");
Expect(0, 42128, '\P{^_ In_Yi_SYLLABLES}', "");
Error('\p{:=_YIJING_Hexagram_Symbols}');
Error('\P{:=_YIJING_Hexagram_Symbols}');
Expect(1, 19967, '\p{yijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^yijinghexagramsymbols}', "");
Expect(0, 19967, '\P{yijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^yijinghexagramsymbols}', "");
Expect(0, 19968, '\p{yijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^yijinghexagramsymbols}', "");
Expect(1, 19968, '\P{yijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^yijinghexagramsymbols}', "");
Expect(1, 19967, '\p{-	yijing_HEXAGRAM_symbols}', "");
Expect(0, 19967, '\p{^-	yijing_HEXAGRAM_symbols}', "");
Expect(0, 19967, '\P{-	yijing_HEXAGRAM_symbols}', "");
Expect(1, 19967, '\P{^-	yijing_HEXAGRAM_symbols}', "");
Expect(0, 19968, '\p{-	yijing_HEXAGRAM_symbols}', "");
Expect(1, 19968, '\p{^-	yijing_HEXAGRAM_symbols}', "");
Expect(1, 19968, '\P{-	yijing_HEXAGRAM_symbols}', "");
Expect(0, 19968, '\P{^-	yijing_HEXAGRAM_symbols}', "");
Error('\p{	/a/IS_yijing_hexagram_SYMBOLS}');
Error('\P{	/a/IS_yijing_hexagram_SYMBOLS}');
Expect(1, 19967, '\p{isyijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^isyijinghexagramsymbols}', "");
Expect(0, 19967, '\P{isyijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^isyijinghexagramsymbols}', "");
Expect(0, 19968, '\p{isyijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^isyijinghexagramsymbols}', "");
Expect(1, 19968, '\P{isyijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^isyijinghexagramsymbols}', "");
Expect(1, 19967, '\p{	 IS_YIJING_Hexagram_Symbols}', "");
Expect(0, 19967, '\p{^	 IS_YIJING_Hexagram_Symbols}', "");
Expect(0, 19967, '\P{	 IS_YIJING_Hexagram_Symbols}', "");
Expect(1, 19967, '\P{^	 IS_YIJING_Hexagram_Symbols}', "");
Expect(0, 19968, '\p{	 IS_YIJING_Hexagram_Symbols}', "");
Expect(1, 19968, '\p{^	 IS_YIJING_Hexagram_Symbols}', "");
Expect(1, 19968, '\P{	 IS_YIJING_Hexagram_Symbols}', "");
Expect(0, 19968, '\P{^	 IS_YIJING_Hexagram_Symbols}', "");
Error('\p{  in_Yijing_Hexagram_Symbols:=}');
Error('\P{  in_Yijing_Hexagram_Symbols:=}');
Expect(1, 19967, '\p{inyijinghexagramsymbols}', "");
Expect(0, 19967, '\p{^inyijinghexagramsymbols}', "");
Expect(0, 19967, '\P{inyijinghexagramsymbols}', "");
Expect(1, 19967, '\P{^inyijinghexagramsymbols}', "");
Expect(0, 19968, '\p{inyijinghexagramsymbols}', "");
Expect(1, 19968, '\p{^inyijinghexagramsymbols}', "");
Expect(1, 19968, '\P{inyijinghexagramsymbols}', "");
Expect(0, 19968, '\P{^inyijinghexagramsymbols}', "");
Expect(1, 19967, '\p{ 	In_Yijing_hexagram_symbols}', "");
Expect(0, 19967, '\p{^ 	In_Yijing_hexagram_symbols}', "");
Expect(0, 19967, '\P{ 	In_Yijing_hexagram_symbols}', "");
Expect(1, 19967, '\P{^ 	In_Yijing_hexagram_symbols}', "");
Expect(0, 19968, '\p{ 	In_Yijing_hexagram_symbols}', "");
Expect(1, 19968, '\p{^ 	In_Yijing_hexagram_symbols}', "");
Expect(1, 19968, '\P{ 	In_Yijing_hexagram_symbols}', "");
Expect(0, 19968, '\P{^ 	In_Yijing_hexagram_symbols}', "");
Error('\p{/a/  yijing}');
Error('\P{/a/  yijing}');
Expect(1, 19967, '\p{yijing}', "");
Expect(0, 19967, '\p{^yijing}', "");
Expect(0, 19967, '\P{yijing}', "");
Expect(1, 19967, '\P{^yijing}', "");
Expect(0, 19968, '\p{yijing}', "");
Expect(1, 19968, '\p{^yijing}', "");
Expect(1, 19968, '\P{yijing}', "");
Expect(0, 19968, '\P{^yijing}', "");
Expect(1, 19967, '\p{ _Yijing}', "");
Expect(0, 19967, '\p{^ _Yijing}', "");
Expect(0, 19967, '\P{ _Yijing}', "");
Expect(1, 19967, '\P{^ _Yijing}', "");
Expect(0, 19968, '\p{ _Yijing}', "");
Expect(1, 19968, '\p{^ _Yijing}', "");
Expect(1, 19968, '\P{ _Yijing}', "");
Expect(0, 19968, '\P{^ _Yijing}', "");
Error('\p{_IS_yijing:=}');
Error('\P{_IS_yijing:=}');
Expect(1, 19967, '\p{isyijing}', "");
Expect(0, 19967, '\p{^isyijing}', "");
Expect(0, 19967, '\P{isyijing}', "");
Expect(1, 19967, '\P{^isyijing}', "");
Expect(0, 19968, '\p{isyijing}', "");
Expect(1, 19968, '\p{^isyijing}', "");
Expect(1, 19968, '\P{isyijing}', "");
Expect(0, 19968, '\P{^isyijing}', "");
Expect(1, 19967, '\p{	-is_yijing}', "");
Expect(0, 19967, '\p{^	-is_yijing}', "");
Expect(0, 19967, '\P{	-is_yijing}', "");
Expect(1, 19967, '\P{^	-is_yijing}', "");
Expect(0, 19968, '\p{	-is_yijing}', "");
Expect(1, 19968, '\p{^	-is_yijing}', "");
Expect(1, 19968, '\P{	-is_yijing}', "");
Expect(0, 19968, '\P{^	-is_yijing}', "");
Error('\p{	/a/IN_Yijing}');
Error('\P{	/a/IN_Yijing}');
Expect(1, 19967, '\p{inyijing}', "");
Expect(0, 19967, '\p{^inyijing}', "");
Expect(0, 19967, '\P{inyijing}', "");
Expect(1, 19967, '\P{^inyijing}', "");
Expect(0, 19968, '\p{inyijing}', "");
Expect(1, 19968, '\p{^inyijing}', "");
Expect(1, 19968, '\P{inyijing}', "");
Expect(0, 19968, '\P{^inyijing}', "");
Expect(1, 19967, '\p{	In_Yijing}', "");
Expect(0, 19967, '\p{^	In_Yijing}', "");
Expect(0, 19967, '\P{	In_Yijing}', "");
Expect(1, 19967, '\P{^	In_Yijing}', "");
Expect(0, 19968, '\p{	In_Yijing}', "");
Expect(1, 19968, '\p{^	In_Yijing}', "");
Expect(1, 19968, '\P{	In_Yijing}', "");
Expect(0, 19968, '\P{^	In_Yijing}', "");
Error('\p{/a/	 Soft_dotted}');
Error('\P{/a/	 Soft_dotted}');
Expect(1, 120467, '\p{softdotted}', "");
Expect(0, 120467, '\p{^softdotted}', "");
Expect(0, 120467, '\P{softdotted}', "");
Expect(1, 120467, '\P{^softdotted}', "");
Expect(0, 120468, '\p{softdotted}', "");
Expect(1, 120468, '\p{^softdotted}', "");
Expect(1, 120468, '\P{softdotted}', "");
Expect(0, 120468, '\P{^softdotted}', "");
Expect(1, 120467, '\p{- Soft_Dotted}', "");
Expect(0, 120467, '\p{^- Soft_Dotted}', "");
Expect(0, 120467, '\P{- Soft_Dotted}', "");
Expect(1, 120467, '\P{^- Soft_Dotted}', "");
Expect(0, 120468, '\p{- Soft_Dotted}', "");
Expect(1, 120468, '\p{^- Soft_Dotted}', "");
Expect(1, 120468, '\P{- Soft_Dotted}', "");
Expect(0, 120468, '\P{^- Soft_Dotted}', "");
Error('\p{_/a/IS_SOFT_dotted}');
Error('\P{_/a/IS_SOFT_dotted}');
Expect(1, 120467, '\p{issoftdotted}', "");
Expect(0, 120467, '\p{^issoftdotted}', "");
Expect(0, 120467, '\P{issoftdotted}', "");
Expect(1, 120467, '\P{^issoftdotted}', "");
Expect(0, 120468, '\p{issoftdotted}', "");
Expect(1, 120468, '\p{^issoftdotted}', "");
Expect(1, 120468, '\P{issoftdotted}', "");
Expect(0, 120468, '\P{^issoftdotted}', "");
Expect(1, 120467, '\p{  Is_Soft_Dotted}', "");
Expect(0, 120467, '\p{^  Is_Soft_Dotted}', "");
Expect(0, 120467, '\P{  Is_Soft_Dotted}', "");
Expect(1, 120467, '\P{^  Is_Soft_Dotted}', "");
Expect(0, 120468, '\p{  Is_Soft_Dotted}', "");
Expect(1, 120468, '\p{^  Is_Soft_Dotted}', "");
Expect(1, 120468, '\P{  Is_Soft_Dotted}', "");
Expect(0, 120468, '\P{^  Is_Soft_Dotted}', "");
Error('\p{/a/	-SD}');
Error('\P{/a/	-SD}');
Expect(1, 120467, '\p{sd}', "");
Expect(0, 120467, '\p{^sd}', "");
Expect(0, 120467, '\P{sd}', "");
Expect(1, 120467, '\P{^sd}', "");
Expect(0, 120468, '\p{sd}', "");
Expect(1, 120468, '\p{^sd}', "");
Expect(1, 120468, '\P{sd}', "");
Expect(0, 120468, '\P{^sd}', "");
Expect(1, 120467, '\p{	sd}', "");
Expect(0, 120467, '\p{^	sd}', "");
Expect(0, 120467, '\P{	sd}', "");
Expect(1, 120467, '\P{^	sd}', "");
Expect(0, 120468, '\p{	sd}', "");
Expect(1, 120468, '\p{^	sd}', "");
Expect(1, 120468, '\P{	sd}', "");
Expect(0, 120468, '\P{^	sd}', "");
Error('\p{	:=is_SD}');
Error('\P{	:=is_SD}');
Expect(1, 120467, '\p{issd}', "");
Expect(0, 120467, '\p{^issd}', "");
Expect(0, 120467, '\P{issd}', "");
Expect(1, 120467, '\P{^issd}', "");
Expect(0, 120468, '\p{issd}', "");
Expect(1, 120468, '\p{^issd}', "");
Expect(1, 120468, '\P{issd}', "");
Expect(0, 120468, '\P{^issd}', "");
Expect(1, 120467, '\p{ Is_SD}', "");
Expect(0, 120467, '\p{^ Is_SD}', "");
Expect(0, 120467, '\P{ Is_SD}', "");
Expect(1, 120467, '\P{^ Is_SD}', "");
Expect(0, 120468, '\p{ Is_SD}', "");
Expect(1, 120468, '\p{^ Is_SD}', "");
Expect(1, 120468, '\P{ Is_SD}', "");
Expect(0, 120468, '\P{^ Is_SD}', "");
Error('\p{- _CANONDCIJ:=}');
Error('\P{- _CANONDCIJ:=}');
Expect(1, 120467, '\p{_canondcij}', "");
Expect(0, 120467, '\p{^_canondcij}', "");
Expect(0, 120467, '\P{_canondcij}', "");
Expect(1, 120467, '\P{^_canondcij}', "");
Expect(0, 120468, '\p{_canondcij}', "");
Expect(1, 120468, '\p{^_canondcij}', "");
Expect(1, 120468, '\P{_canondcij}', "");
Expect(0, 120468, '\P{^_canondcij}', "");
Error('\p{	/a/Case_Ignorable}');
Error('\P{	/a/Case_Ignorable}');
Expect(1, 917999, '\p{caseignorable}', "");
Expect(0, 917999, '\p{^caseignorable}', "");
Expect(0, 917999, '\P{caseignorable}', "");
Expect(1, 917999, '\P{^caseignorable}', "");
Expect(0, 918000, '\p{caseignorable}', "");
Expect(1, 918000, '\p{^caseignorable}', "");
Expect(1, 918000, '\P{caseignorable}', "");
Expect(0, 918000, '\P{^caseignorable}', "");
Expect(1, 917999, '\p{Case_ignorable}', "");
Expect(0, 917999, '\p{^Case_ignorable}', "");
Expect(0, 917999, '\P{Case_ignorable}', "");
Expect(1, 917999, '\P{^Case_ignorable}', "");
Expect(0, 918000, '\p{Case_ignorable}', "");
Expect(1, 918000, '\p{^Case_ignorable}', "");
Expect(1, 918000, '\P{Case_ignorable}', "");
Expect(0, 918000, '\P{^Case_ignorable}', "");
Error('\p{/a/--is_Case_ignorable}');
Error('\P{/a/--is_Case_ignorable}');
Expect(1, 917999, '\p{iscaseignorable}', "");
Expect(0, 917999, '\p{^iscaseignorable}', "");
Expect(0, 917999, '\P{iscaseignorable}', "");
Expect(1, 917999, '\P{^iscaseignorable}', "");
Expect(0, 918000, '\p{iscaseignorable}', "");
Expect(1, 918000, '\p{^iscaseignorable}', "");
Expect(1, 918000, '\P{iscaseignorable}', "");
Expect(0, 918000, '\P{^iscaseignorable}', "");
Expect(1, 917999, '\p{_	Is_Case_Ignorable}', "");
Expect(0, 917999, '\p{^_	Is_Case_Ignorable}', "");
Expect(0, 917999, '\P{_	Is_Case_Ignorable}', "");
Expect(1, 917999, '\P{^_	Is_Case_Ignorable}', "");
Expect(0, 918000, '\p{_	Is_Case_Ignorable}', "");
Expect(1, 918000, '\p{^_	Is_Case_Ignorable}', "");
Expect(1, 918000, '\P{_	Is_Case_Ignorable}', "");
Expect(0, 918000, '\P{^_	Is_Case_Ignorable}', "");
Error('\p{:=ci}');
Error('\P{:=ci}');
Expect(1, 917999, '\p{ci}', "");
Expect(0, 917999, '\p{^ci}', "");
Expect(0, 917999, '\P{ci}', "");
Expect(1, 917999, '\P{^ci}', "");
Expect(0, 918000, '\p{ci}', "");
Expect(1, 918000, '\p{^ci}', "");
Expect(1, 918000, '\P{ci}', "");
Expect(0, 918000, '\P{^ci}', "");
Expect(1, 917999, '\p{	 ci}', "");
Expect(0, 917999, '\p{^	 ci}', "");
Expect(0, 917999, '\P{	 ci}', "");
Expect(1, 917999, '\P{^	 ci}', "");
Expect(0, 918000, '\p{	 ci}', "");
Expect(1, 918000, '\p{^	 ci}', "");
Expect(1, 918000, '\P{	 ci}', "");
Expect(0, 918000, '\P{^	 ci}', "");
Error('\p{		IS_ci:=}');
Error('\P{		IS_ci:=}');
Expect(1, 917999, '\p{isci}', "");
Expect(0, 917999, '\p{^isci}', "");
Expect(0, 917999, '\P{isci}', "");
Expect(1, 917999, '\P{^isci}', "");
Expect(0, 918000, '\p{isci}', "");
Expect(1, 918000, '\p{^isci}', "");
Expect(1, 918000, '\P{isci}', "");
Expect(0, 918000, '\P{^isci}', "");
Expect(1, 917999, '\p{-Is_ci}', "");
Expect(0, 917999, '\p{^-Is_ci}', "");
Expect(0, 917999, '\P{-Is_ci}', "");
Expect(1, 917999, '\P{^-Is_ci}', "");
Expect(0, 918000, '\p{-Is_ci}', "");
Expect(1, 918000, '\p{^-Is_ci}', "");
Expect(1, 918000, '\P{-Is_ci}', "");
Expect(0, 918000, '\P{^-Is_ci}', "");
Error('\p{	 _Case_Ignorable/a/}');
Error('\P{	 _Case_Ignorable/a/}');
Expect(1, 917999, '\p{_Case_Ignorable}', "");
Expect(0, 917999, '\p{^_Case_Ignorable}', "");
Expect(0, 917999, '\P{_Case_Ignorable}', "");
Expect(1, 917999, '\P{^_Case_Ignorable}', "");
Expect(0, 918000, '\p{_Case_Ignorable}', "");
Expect(1, 918000, '\p{^_Case_Ignorable}', "");
Expect(1, 918000, '\P{_Case_Ignorable}', "");
Expect(0, 918000, '\P{^_Case_Ignorable}', "");
Error('\p{-	_CombAbove/a/}');
Error('\P{-	_CombAbove/a/}');
Expect(1, 119364, '\p{_combabove}', "");
Expect(0, 119364, '\p{^_combabove}', "");
Expect(0, 119364, '\P{_combabove}', "");
Expect(1, 119364, '\P{^_combabove}', "");
Expect(0, 119365, '\p{_combabove}', "");
Expect(1, 119365, '\p{^_combabove}', "");
Expect(1, 119365, '\P{_combabove}', "");
Expect(0, 119365, '\P{^_combabove}', "");
Error('\p{		_COMBABOVE/a/}');
Error('\P{		_COMBABOVE/a/}');
Expect(1, 119364, '\p{_COMBABOVE}', "");
Expect(0, 119364, '\p{^_COMBABOVE}', "");
Expect(0, 119364, '\P{_COMBABOVE}', "");
Expect(1, 119364, '\P{^_COMBABOVE}', "");
Expect(0, 119365, '\p{_COMBABOVE}', "");
Expect(1, 119365, '\p{^_COMBABOVE}', "");
Expect(1, 119365, '\P{_COMBABOVE}', "");
Expect(0, 119365, '\P{^_COMBABOVE}', "");
Error('\p{/a/___PERL_Any_Folds}');
Error('\P{/a/___PERL_Any_Folds}');
Expect(1, 66639, '\p{_Perl_Any_folds}', "");
Expect(0, 66639, '\p{^_Perl_Any_folds}', "");
Expect(0, 66639, '\P{_Perl_Any_folds}', "");
Expect(1, 66639, '\P{^_Perl_Any_folds}', "");
Expect(0, 66640, '\p{_Perl_Any_folds}', "");
Expect(1, 66640, '\p{^_Perl_Any_folds}', "");
Expect(1, 66640, '\P{_Perl_Any_folds}', "");
Expect(0, 66640, '\P{^_Perl_Any_folds}', "");
Error('\p{/a/_	_perl_ANY_Folds}');
Error('\P{/a/_	_perl_ANY_Folds}');
Error('\p{-/a/_perl_Charname_Begin}');
Error('\P{-/a/_perl_Charname_Begin}');
Expect(1, 195101, '\p{_PERL_Charname_Begin}', "");
Expect(0, 195101, '\p{^_PERL_Charname_Begin}', "");
Expect(0, 195101, '\P{_PERL_Charname_Begin}', "");
Expect(1, 195101, '\P{^_PERL_Charname_Begin}', "");
Expect(0, 195102, '\p{_PERL_Charname_Begin}', "");
Expect(1, 195102, '\p{^_PERL_Charname_Begin}', "");
Expect(1, 195102, '\P{_PERL_Charname_Begin}', "");
Expect(0, 195102, '\P{^_PERL_Charname_Begin}', "");
Error('\p{/a/_	_PERL_charname_Begin}');
Error('\P{/a/_	_PERL_charname_Begin}');
Expect(1, 195101, '\p{_perl_CHARNAME_Begin}', "");
Expect(0, 195101, '\p{^_perl_CHARNAME_Begin}', "");
Expect(0, 195101, '\P{_perl_CHARNAME_Begin}', "");
Expect(1, 195101, '\P{^_perl_CHARNAME_Begin}', "");
Expect(0, 195102, '\p{_perl_CHARNAME_Begin}', "");
Expect(1, 195102, '\p{^_perl_CHARNAME_Begin}', "");
Expect(1, 195102, '\P{_perl_CHARNAME_Begin}', "");
Expect(0, 195102, '\P{^_perl_CHARNAME_Begin}', "");
Error('\p{/a/_PERL_Charname_continue}');
Error('\P{/a/_PERL_Charname_continue}');
Expect(1, 917999, '\p{_perl_charname_Continue}', "");
Expect(0, 917999, '\p{^_perl_charname_Continue}', "");
Expect(0, 917999, '\P{_perl_charname_Continue}', "");
Expect(1, 917999, '\P{^_perl_charname_Continue}', "");
Expect(0, 918000, '\p{_perl_charname_Continue}', "");
Expect(1, 918000, '\p{^_perl_charname_Continue}', "");
Expect(1, 918000, '\P{_perl_charname_Continue}', "");
Expect(0, 918000, '\P{^_perl_charname_Continue}', "");
Error('\p{	 _perl_Charname_continue/a/}');
Error('\P{	 _perl_Charname_continue/a/}');
Expect(1, 917999, '\p{_Perl_CHARNAME_CONTINUE}', "");
Expect(0, 917999, '\p{^_Perl_CHARNAME_CONTINUE}', "");
Expect(0, 917999, '\P{_Perl_CHARNAME_CONTINUE}', "");
Expect(1, 917999, '\P{^_Perl_CHARNAME_CONTINUE}', "");
Expect(0, 918000, '\p{_Perl_CHARNAME_CONTINUE}', "");
Expect(1, 918000, '\p{^_Perl_CHARNAME_CONTINUE}', "");
Expect(1, 918000, '\P{_Perl_CHARNAME_CONTINUE}', "");
Expect(0, 918000, '\P{^_Perl_CHARNAME_CONTINUE}', "");
Error('\p{-/a/_Perl_IDCONT}');
Error('\P{-/a/_Perl_IDCONT}');
Expect(1, 917999, '\p{_PERL_IDCont}', "");
Expect(0, 917999, '\p{^_PERL_IDCont}', "");
Expect(0, 917999, '\P{_PERL_IDCont}', "");
Expect(1, 917999, '\P{^_PERL_IDCont}', "");
Expect(0, 918000, '\p{_PERL_IDCont}', "");
Expect(1, 918000, '\p{^_PERL_IDCont}', "");
Expect(1, 918000, '\P{_PERL_IDCont}', "");
Expect(0, 918000, '\P{^_PERL_IDCont}', "");
Error('\p{:=__PERL_IDCONT}');
Error('\P{:=__PERL_IDCONT}');
Expect(1, 917999, '\p{_Perl_IDCont}', "");
Expect(0, 917999, '\p{^_Perl_IDCont}', "");
Expect(0, 917999, '\P{_Perl_IDCont}', "");
Expect(1, 917999, '\P{^_Perl_IDCont}', "");
Expect(0, 918000, '\p{_Perl_IDCont}', "");
Expect(1, 918000, '\p{^_Perl_IDCont}', "");
Expect(1, 918000, '\P{_Perl_IDCont}', "");
Expect(0, 918000, '\P{^_Perl_IDCont}', "");
Error('\p{:=__Perl_IDSTART}');
Error('\P{:=__Perl_IDSTART}');
Expect(1, 195101, '\p{_Perl_IDSTART}', "");
Expect(0, 195101, '\p{^_Perl_IDSTART}', "");
Expect(0, 195101, '\P{_Perl_IDSTART}', "");
Expect(1, 195101, '\P{^_Perl_IDSTART}', "");
Expect(0, 195102, '\p{_Perl_IDSTART}', "");
Expect(1, 195102, '\p{^_Perl_IDSTART}', "");
Expect(1, 195102, '\P{_Perl_IDSTART}', "");
Expect(0, 195102, '\P{^_Perl_IDSTART}', "");
Error('\p{	 _perl_idstart/a/}');
Error('\P{	 _perl_idstart/a/}');
Expect(1, 195101, '\p{_Perl_IDStart}', "");
Expect(0, 195101, '\p{^_Perl_IDStart}', "");
Expect(0, 195101, '\P{_Perl_IDStart}', "");
Expect(1, 195101, '\P{^_Perl_IDStart}', "");
Expect(0, 195102, '\p{_Perl_IDStart}', "");
Expect(1, 195102, '\p{^_Perl_IDStart}', "");
Expect(1, 195102, '\P{_Perl_IDStart}', "");
Expect(0, 195102, '\P{^_Perl_IDStart}', "");
Error('\p{_perl_Quotemeta:=}');
Error('\P{_perl_Quotemeta:=}');
Expect(1, 921599, '\p{_perl_quotemeta}', "");
Expect(0, 921599, '\p{^_perl_quotemeta}', "");
Expect(0, 921599, '\P{_perl_quotemeta}', "");
Expect(1, 921599, '\P{^_perl_quotemeta}', "");
Expect(0, 921600, '\p{_perl_quotemeta}', "");
Expect(1, 921600, '\p{^_perl_quotemeta}', "");
Expect(1, 921600, '\P{_perl_quotemeta}', "");
Expect(0, 921600, '\P{^_perl_quotemeta}', "");
Error('\p{ :=_PERL_Quotemeta}');
Error('\P{ :=_PERL_Quotemeta}');
Expect(1, 921599, '\p{_Perl_Quotemeta}', "");
Expect(0, 921599, '\p{^_Perl_Quotemeta}', "");
Expect(0, 921599, '\P{_Perl_Quotemeta}', "");
Expect(1, 921599, '\P{^_Perl_Quotemeta}', "");
Expect(0, 921600, '\p{_Perl_Quotemeta}', "");
Expect(1, 921600, '\p{^_Perl_Quotemeta}', "");
Expect(1, 921600, '\P{_Perl_Quotemeta}', "");
Expect(0, 921600, '\P{^_Perl_Quotemeta}', "");
Error('\p{-_X_Extend/a/}');
Error('\P{-_X_Extend/a/}');
Expect(1, 917999, '\p{_x_extend}', "");
Expect(0, 917999, '\p{^_x_extend}', "");
Expect(0, 917999, '\P{_x_extend}', "");
Expect(1, 917999, '\P{^_x_extend}', "");
Expect(0, 918000, '\p{_x_extend}', "");
Expect(1, 918000, '\p{^_x_extend}', "");
Expect(1, 918000, '\P{_x_extend}', "");
Expect(0, 918000, '\P{^_x_extend}', "");
Error('\p{/a/-_x_EXTEND}');
Error('\P{/a/-_x_EXTEND}');
Expect(1, 917999, '\p{_X_EXTEND}', "");
Expect(0, 917999, '\p{^_X_EXTEND}', "");
Expect(0, 917999, '\P{_X_EXTEND}', "");
Expect(1, 917999, '\P{^_X_EXTEND}', "");
Expect(0, 918000, '\p{_X_EXTEND}', "");
Expect(1, 918000, '\p{^_X_EXTEND}', "");
Expect(1, 918000, '\P{_X_EXTEND}', "");
Expect(0, 918000, '\P{^_X_EXTEND}', "");
Error('\p{-	_x_gcb_L:=}');
Error('\P{-	_x_gcb_L:=}');
Expect(1, 43388, '\p{_x_gcb_l}', "");
Expect(0, 43388, '\p{^_x_gcb_l}', "");
Expect(0, 43388, '\P{_x_gcb_l}', "");
Expect(1, 43388, '\P{^_x_gcb_l}', "");
Expect(0, 43389, '\p{_x_gcb_l}', "");
Expect(1, 43389, '\p{^_x_gcb_l}', "");
Expect(1, 43389, '\P{_x_gcb_l}', "");
Expect(0, 43389, '\P{^_x_gcb_l}', "");
Error('\p{:=-__X_GCB_L}');
Error('\P{:=-__X_GCB_L}');
Expect(1, 43388, '\p{_X_GCB_l}', "");
Expect(0, 43388, '\p{^_X_GCB_l}', "");
Expect(0, 43388, '\P{_X_GCB_l}', "");
Expect(1, 43388, '\P{^_X_GCB_l}', "");
Expect(0, 43389, '\p{_X_GCB_l}', "");
Expect(1, 43389, '\p{^_X_GCB_l}', "");
Expect(1, 43389, '\P{_X_GCB_l}', "");
Expect(0, 43389, '\P{^_X_GCB_l}', "");
Error('\p{	 _x_GCB_LV/a/}');
Error('\P{	 _x_GCB_LV/a/}');
Expect(1, 55176, '\p{_X_gcb_LV}', "");
Expect(0, 55176, '\p{^_X_gcb_LV}', "");
Expect(0, 55176, '\P{_X_gcb_LV}', "");
Expect(1, 55176, '\P{^_X_gcb_LV}', "");
Expect(0, 55177, '\p{_X_gcb_LV}', "");
Expect(1, 55177, '\p{^_X_gcb_LV}', "");
Expect(1, 55177, '\P{_X_gcb_LV}', "");
Expect(0, 55177, '\P{^_X_gcb_LV}', "");
Error('\p{/a/_X_GCB_LV}');
Error('\P{/a/_X_GCB_LV}');
Expect(1, 55176, '\p{_X_GCB_lv}', "");
Expect(0, 55176, '\p{^_X_GCB_lv}', "");
Expect(0, 55176, '\P{_X_GCB_lv}', "");
Expect(1, 55176, '\P{^_X_GCB_lv}', "");
Expect(0, 55177, '\p{_X_GCB_lv}', "");
Expect(1, 55177, '\p{^_X_GCB_lv}', "");
Expect(1, 55177, '\P{_X_GCB_lv}', "");
Expect(0, 55177, '\P{^_X_GCB_lv}', "");
Error('\p{	-_X_GCB_LVT/a/}');
Error('\P{	-_X_GCB_LVT/a/}');
Expect(1, 55203, '\p{_x_GCB_LVT}', "");
Expect(0, 55203, '\p{^_x_GCB_LVT}', "");
Expect(0, 55203, '\P{_x_GCB_LVT}', "");
Expect(1, 55203, '\P{^_x_GCB_LVT}', "");
Expect(0, 55204, '\p{_x_GCB_LVT}', "");
Expect(1, 55204, '\p{^_x_GCB_LVT}', "");
Expect(1, 55204, '\P{_x_GCB_LVT}', "");
Expect(0, 55204, '\P{^_x_GCB_LVT}', "");
Error('\p{ _x_GCB_LVT:=}');
Error('\P{ _x_GCB_LVT:=}');
Expect(1, 55203, '\p{_X_GCB_lvt}', "");
Expect(0, 55203, '\p{^_X_GCB_lvt}', "");
Expect(0, 55203, '\P{_X_GCB_lvt}', "");
Expect(1, 55203, '\P{^_X_GCB_lvt}', "");
Expect(0, 55204, '\p{_X_GCB_lvt}', "");
Expect(1, 55204, '\p{^_X_GCB_lvt}', "");
Expect(1, 55204, '\P{_X_GCB_lvt}', "");
Expect(0, 55204, '\P{^_X_GCB_lvt}', "");
Error('\p{__X_gcb_Prepend:=}');
Error('\P{__X_gcb_Prepend:=}');
Expect(0, 1, '\p{_X_GCB_Prepend}', "");
Expect(1, 1, '\p{^_X_GCB_Prepend}', "");
Expect(1, 1, '\P{_X_GCB_Prepend}', "");
Expect(0, 1, '\P{^_X_GCB_Prepend}', "");
Error('\p{:=_X_GCB_Prepend}');
Error('\P{:=_X_GCB_Prepend}');
Expect(0, 1, '\p{_x_GCB_prepend}', "");
Expect(1, 1, '\p{^_x_GCB_prepend}', "");
Expect(1, 1, '\P{_x_GCB_prepend}', "");
Expect(0, 1, '\P{^_x_GCB_prepend}', "");
Error('\p{-/a/_X_GCB_t}');
Error('\P{-/a/_X_GCB_t}');
Expect(1, 55291, '\p{_x_gcb_t}', "");
Expect(0, 55291, '\p{^_x_gcb_t}', "");
Expect(0, 55291, '\P{_x_gcb_t}', "");
Expect(1, 55291, '\P{^_x_gcb_t}', "");
Expect(0, 55292, '\p{_x_gcb_t}', "");
Expect(1, 55292, '\p{^_x_gcb_t}', "");
Expect(1, 55292, '\P{_x_gcb_t}', "");
Expect(0, 55292, '\P{^_x_gcb_t}', "");
Error('\p{__x_GCB_T:=}');
Error('\P{__x_GCB_T:=}');
Expect(1, 55291, '\p{_X_GCB_T}', "");
Expect(0, 55291, '\p{^_X_GCB_T}', "");
Expect(0, 55291, '\P{_X_GCB_T}', "");
Expect(1, 55291, '\P{^_X_GCB_T}', "");
Expect(0, 55292, '\p{_X_GCB_T}', "");
Expect(1, 55292, '\p{^_X_GCB_T}', "");
Expect(1, 55292, '\P{_X_GCB_T}', "");
Expect(0, 55292, '\P{^_X_GCB_T}', "");
Error('\p{  _X_GCB_V/a/}');
Error('\P{  _X_GCB_V/a/}');
Expect(1, 55238, '\p{_x_GCB_v}', "");
Expect(0, 55238, '\p{^_x_GCB_v}', "");
Expect(0, 55238, '\P{_x_GCB_v}', "");
Expect(1, 55238, '\P{^_x_GCB_v}', "");
Expect(0, 55239, '\p{_x_GCB_v}', "");
Expect(1, 55239, '\p{^_x_GCB_v}', "");
Expect(1, 55239, '\P{_x_GCB_v}', "");
Expect(0, 55239, '\P{^_x_GCB_v}', "");
Error('\p{	:=_X_GCB_V}');
Error('\P{	:=_X_GCB_V}');
Expect(1, 55238, '\p{_X_GCB_V}', "");
Expect(0, 55238, '\p{^_X_GCB_V}', "");
Expect(0, 55238, '\P{_X_GCB_V}', "");
Expect(1, 55238, '\P{^_X_GCB_V}', "");
Expect(0, 55239, '\p{_X_GCB_V}', "");
Expect(1, 55239, '\p{^_X_GCB_V}', "");
Expect(1, 55239, '\P{_X_GCB_V}', "");
Expect(0, 55239, '\P{^_X_GCB_V}', "");
Error('\p{:= 	_x_lv_LVT_V}');
Error('\P{:= 	_x_lv_LVT_V}');
Expect(1, 55238, '\p{_X_LV_LVT_V}', "");
Expect(0, 55238, '\p{^_X_LV_LVT_V}', "");
Expect(0, 55238, '\P{_X_LV_LVT_V}', "");
Expect(1, 55238, '\P{^_X_LV_LVT_V}', "");
Expect(0, 55239, '\p{_X_LV_LVT_V}', "");
Expect(1, 55239, '\p{^_X_LV_LVT_V}', "");
Expect(1, 55239, '\P{_X_LV_LVT_V}', "");
Expect(0, 55239, '\P{^_X_LV_LVT_V}', "");
Error('\p{ :=_X_LV_LVT_V}');
Error('\P{ :=_X_LV_LVT_V}');
Error('\p{ __x_ri/a/}');
Error('\P{ __x_ri/a/}');
Expect(1, 127487, '\p{_X_RI}', "");
Expect(0, 127487, '\p{^_X_RI}', "");
Expect(0, 127487, '\P{_X_RI}', "");
Expect(1, 127487, '\P{^_X_RI}', "");
Expect(0, 127488, '\p{_X_RI}', "");
Expect(1, 127488, '\p{^_X_RI}', "");
Expect(1, 127488, '\P{_X_RI}', "");
Expect(0, 127488, '\P{^_X_RI}', "");
Error('\p{	/a/_X_RI}');
Error('\P{	/a/_X_RI}');
Error('\p{:=  _X_Regular_begin}');
Error('\P{:=  _X_Regular_begin}');
Expect(1, 921600, '\p{_X_Regular_Begin}', "");
Expect(0, 921600, '\p{^_X_Regular_Begin}', "");
Expect(0, 921600, '\P{_X_Regular_Begin}', "");
Expect(1, 921600, '\P{^_X_Regular_Begin}', "");
Expect(0, 921599, '\p{_X_Regular_Begin}', "");
Expect(1, 921599, '\p{^_X_Regular_Begin}', "");
Expect(1, 921599, '\P{_X_Regular_Begin}', "");
Expect(0, 921599, '\P{^_X_Regular_Begin}', "");
Error('\p{-_x_regular_Begin/a/}');
Error('\P{-_x_regular_Begin/a/}');
Expect(1, 921600, '\p{_x_REGULAR_Begin}', "");
Expect(0, 921600, '\p{^_x_REGULAR_Begin}', "");
Expect(0, 921600, '\P{_x_REGULAR_Begin}', "");
Expect(1, 921600, '\P{^_x_REGULAR_Begin}', "");
Expect(0, 921599, '\p{_x_REGULAR_Begin}', "");
Expect(1, 921599, '\p{^_x_REGULAR_Begin}', "");
Expect(1, 921599, '\P{_x_REGULAR_Begin}', "");
Expect(0, 921599, '\P{^_x_REGULAR_Begin}', "");
Error('\p{ __X_special_Begin_Start:=}');
Error('\P{ __X_special_Begin_Start:=}');
Expect(1, 127487, '\p{_x_Special_begin_Start}', "");
Expect(0, 127487, '\p{^_x_Special_begin_Start}', "");
Expect(0, 127487, '\P{_x_Special_begin_Start}', "");
Expect(1, 127487, '\P{^_x_Special_begin_Start}', "");
Expect(0, 127488, '\p{_x_Special_begin_Start}', "");
Expect(1, 127488, '\p{^_x_Special_begin_Start}', "");
Expect(1, 127488, '\P{_x_Special_begin_Start}', "");
Expect(0, 127488, '\P{^_x_Special_begin_Start}', "");
Error('\p{:=  _X_Special_begin_Start}');
Error('\P{:=  _X_Special_begin_Start}');
Expect(1, 127487, '\p{_X_Special_Begin_START}', "");
Expect(0, 127487, '\p{^_X_Special_Begin_START}', "");
Expect(0, 127487, '\P{_X_Special_Begin_START}', "");
Expect(1, 127487, '\P{^_X_Special_Begin_START}', "");
Expect(0, 127488, '\p{_X_Special_Begin_START}', "");
Expect(1, 127488, '\p{^_X_Special_Begin_START}', "");
Expect(1, 127488, '\P{_X_Special_Begin_START}', "");
Expect(0, 127488, '\P{^_X_Special_Begin_START}', "");
Error('\p{Script=/a/	 Arabic}');
Error('\P{Script=/a/	 Arabic}');
Expect(1, 126705, '\p{Script=arabic}', "");
Expect(0, 126705, '\p{^Script=arabic}', "");
Expect(0, 126705, '\P{Script=arabic}', "");
Expect(1, 126705, '\P{^Script=arabic}', "");
Expect(0, 126706, '\p{Script=arabic}', "");
Expect(1, 126706, '\p{^Script=arabic}', "");
Expect(1, 126706, '\P{Script=arabic}', "");
Expect(0, 126706, '\P{^Script=arabic}', "");
Expect(1, 126705, '\p{Script:	_Arabic}', "");
Expect(0, 126705, '\p{^Script:	_Arabic}', "");
Expect(0, 126705, '\P{Script:	_Arabic}', "");
Expect(1, 126705, '\P{^Script:	_Arabic}', "");
Expect(0, 126706, '\p{Script:	_Arabic}', "");
Expect(1, 126706, '\p{^Script:	_Arabic}', "");
Expect(1, 126706, '\P{Script:	_Arabic}', "");
Expect(0, 126706, '\P{^Script:	_Arabic}', "");
Error('\p{Sc=_	ARAB:=}');
Error('\P{Sc=_	ARAB:=}');
Expect(1, 126705, '\p{Sc=arab}', "");
Expect(0, 126705, '\p{^Sc=arab}', "");
Expect(0, 126705, '\P{Sc=arab}', "");
Expect(1, 126705, '\P{^Sc=arab}', "");
Expect(0, 126706, '\p{Sc=arab}', "");
Expect(1, 126706, '\p{^Sc=arab}', "");
Expect(1, 126706, '\P{Sc=arab}', "");
Expect(0, 126706, '\P{^Sc=arab}', "");
Expect(1, 126705, '\p{Sc= 	ARAB}', "");
Expect(0, 126705, '\p{^Sc= 	ARAB}', "");
Expect(0, 126705, '\P{Sc= 	ARAB}', "");
Expect(1, 126705, '\P{^Sc= 	ARAB}', "");
Expect(0, 126706, '\p{Sc= 	ARAB}', "");
Expect(1, 126706, '\p{^Sc= 	ARAB}', "");
Expect(1, 126706, '\P{Sc= 	ARAB}', "");
Expect(0, 126706, '\P{^Sc= 	ARAB}', "");
Error('\p{Is_Script: /a/ -ARABIC}');
Error('\P{Is_Script: /a/ -ARABIC}');
Expect(1, 126705, '\p{Is_Script=arabic}', "");
Expect(0, 126705, '\p{^Is_Script=arabic}', "");
Expect(0, 126705, '\P{Is_Script=arabic}', "");
Expect(1, 126705, '\P{^Is_Script=arabic}', "");
Expect(0, 126706, '\p{Is_Script=arabic}', "");
Expect(1, 126706, '\p{^Is_Script=arabic}', "");
Expect(1, 126706, '\P{Is_Script=arabic}', "");
Expect(0, 126706, '\P{^Is_Script=arabic}', "");
Expect(1, 126705, '\p{Is_Script=- Arabic}', "");
Expect(0, 126705, '\p{^Is_Script=- Arabic}', "");
Expect(0, 126705, '\P{Is_Script=- Arabic}', "");
Expect(1, 126705, '\P{^Is_Script=- Arabic}', "");
Expect(0, 126706, '\p{Is_Script=- Arabic}', "");
Expect(1, 126706, '\p{^Is_Script=- Arabic}', "");
Expect(1, 126706, '\P{Is_Script=- Arabic}', "");
Expect(0, 126706, '\P{^Is_Script=- Arabic}', "");
Error('\p{Is_Sc=	/a/arab}');
Error('\P{Is_Sc=	/a/arab}');
Expect(1, 126705, '\p{Is_Sc=arab}', "");
Expect(0, 126705, '\p{^Is_Sc=arab}', "");
Expect(0, 126705, '\P{Is_Sc=arab}', "");
Expect(1, 126705, '\P{^Is_Sc=arab}', "");
Expect(0, 126706, '\p{Is_Sc=arab}', "");
Expect(1, 126706, '\p{^Is_Sc=arab}', "");
Expect(1, 126706, '\P{Is_Sc=arab}', "");
Expect(0, 126706, '\P{^Is_Sc=arab}', "");
Expect(1, 126705, '\p{Is_Sc= -ARAB}', "");
Expect(0, 126705, '\p{^Is_Sc= -ARAB}', "");
Expect(0, 126705, '\P{Is_Sc= -ARAB}', "");
Expect(1, 126705, '\P{^Is_Sc= -ARAB}', "");
Expect(0, 126706, '\p{Is_Sc= -ARAB}', "");
Expect(1, 126706, '\p{^Is_Sc= -ARAB}', "");
Expect(1, 126706, '\P{Is_Sc= -ARAB}', "");
Expect(0, 126706, '\P{^Is_Sc= -ARAB}', "");
Error('\p{Script=:=	imperial_ARAMAIC}');
Error('\P{Script=:=	imperial_ARAMAIC}');
Expect(1, 67679, '\p{Script=imperialaramaic}', "");
Expect(0, 67679, '\p{^Script=imperialaramaic}', "");
Expect(0, 67679, '\P{Script=imperialaramaic}', "");
Expect(1, 67679, '\P{^Script=imperialaramaic}', "");
Expect(0, 67680, '\p{Script=imperialaramaic}', "");
Expect(1, 67680, '\p{^Script=imperialaramaic}', "");
Expect(1, 67680, '\P{Script=imperialaramaic}', "");
Expect(0, 67680, '\P{^Script=imperialaramaic}', "");
Expect(1, 67679, '\p{Script=	 Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Script=	 Imperial_Aramaic}', "");
Expect(0, 67679, '\P{Script=	 Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Script=	 Imperial_Aramaic}', "");
Expect(0, 67680, '\p{Script=	 Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Script=	 Imperial_Aramaic}', "");
Expect(1, 67680, '\P{Script=	 Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Script=	 Imperial_Aramaic}', "");
Error('\p{Sc=:=-Armi}');
Error('\P{Sc=:=-Armi}');
Expect(1, 67679, '\p{Sc=armi}', "");
Expect(0, 67679, '\p{^Sc=armi}', "");
Expect(0, 67679, '\P{Sc=armi}', "");
Expect(1, 67679, '\P{^Sc=armi}', "");
Expect(0, 67680, '\p{Sc=armi}', "");
Expect(1, 67680, '\p{^Sc=armi}', "");
Expect(1, 67680, '\P{Sc=armi}', "");
Expect(0, 67680, '\P{^Sc=armi}', "");
Expect(1, 67679, '\p{Sc=-_ARMI}', "");
Expect(0, 67679, '\p{^Sc=-_ARMI}', "");
Expect(0, 67679, '\P{Sc=-_ARMI}', "");
Expect(1, 67679, '\P{^Sc=-_ARMI}', "");
Expect(0, 67680, '\p{Sc=-_ARMI}', "");
Expect(1, 67680, '\p{^Sc=-_ARMI}', "");
Expect(1, 67680, '\P{Sc=-_ARMI}', "");
Expect(0, 67680, '\P{^Sc=-_ARMI}', "");
Error('\p{Is_Script=_	Imperial_Aramaic:=}');
Error('\P{Is_Script=_	Imperial_Aramaic:=}');
Expect(1, 67679, '\p{Is_Script=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Script=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Script=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Script=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Script=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Script=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Script=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Script=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Script=_ imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Is_Script=_ imperial_Aramaic}', "");
Expect(0, 67679, '\P{Is_Script=_ imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Is_Script=_ imperial_Aramaic}', "");
Expect(0, 67680, '\p{Is_Script=_ imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Is_Script=_ imperial_Aramaic}', "");
Expect(1, 67680, '\P{Is_Script=_ imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Is_Script=_ imperial_Aramaic}', "");
Error('\p{Is_Sc=_Armi:=}');
Error('\P{Is_Sc=_Armi:=}');
Expect(1, 67679, '\p{Is_Sc=armi}', "");
Expect(0, 67679, '\p{^Is_Sc=armi}', "");
Expect(0, 67679, '\P{Is_Sc=armi}', "");
Expect(1, 67679, '\P{^Is_Sc=armi}', "");
Expect(0, 67680, '\p{Is_Sc=armi}', "");
Expect(1, 67680, '\p{^Is_Sc=armi}', "");
Expect(1, 67680, '\P{Is_Sc=armi}', "");
Expect(0, 67680, '\P{^Is_Sc=armi}', "");
Expect(1, 67679, '\p{Is_Sc=	 Armi}', "");
Expect(0, 67679, '\p{^Is_Sc=	 Armi}', "");
Expect(0, 67679, '\P{Is_Sc=	 Armi}', "");
Expect(1, 67679, '\P{^Is_Sc=	 Armi}', "");
Expect(0, 67680, '\p{Is_Sc=	 Armi}', "");
Expect(1, 67680, '\p{^Is_Sc=	 Armi}', "");
Expect(1, 67680, '\P{Is_Sc=	 Armi}', "");
Expect(0, 67680, '\P{^Is_Sc=	 Armi}', "");
Error('\p{Script=:=ARMENIAN}');
Error('\P{Script=:=ARMENIAN}');
Expect(1, 64279, '\p{Script=armenian}', "");
Expect(0, 64279, '\p{^Script=armenian}', "");
Expect(0, 64279, '\P{Script=armenian}', "");
Expect(1, 64279, '\P{^Script=armenian}', "");
Expect(0, 64280, '\p{Script=armenian}', "");
Expect(1, 64280, '\p{^Script=armenian}', "");
Expect(1, 64280, '\P{Script=armenian}', "");
Expect(0, 64280, '\P{^Script=armenian}', "");
Expect(1, 64279, '\p{Script=_Armenian}', "");
Expect(0, 64279, '\p{^Script=_Armenian}', "");
Expect(0, 64279, '\P{Script=_Armenian}', "");
Expect(1, 64279, '\P{^Script=_Armenian}', "");
Expect(0, 64280, '\p{Script=_Armenian}', "");
Expect(1, 64280, '\p{^Script=_Armenian}', "");
Expect(1, 64280, '\P{Script=_Armenian}', "");
Expect(0, 64280, '\P{^Script=_Armenian}', "");
Error('\p{Sc=/a/_ Armn}');
Error('\P{Sc=/a/_ Armn}');
Expect(1, 64279, '\p{Sc=armn}', "");
Expect(0, 64279, '\p{^Sc=armn}', "");
Expect(0, 64279, '\P{Sc=armn}', "");
Expect(1, 64279, '\P{^Sc=armn}', "");
Expect(0, 64280, '\p{Sc=armn}', "");
Expect(1, 64280, '\p{^Sc=armn}', "");
Expect(1, 64280, '\P{Sc=armn}', "");
Expect(0, 64280, '\P{^Sc=armn}', "");
Expect(1, 64279, '\p{Sc: _Armn}', "");
Expect(0, 64279, '\p{^Sc: _Armn}', "");
Expect(0, 64279, '\P{Sc: _Armn}', "");
Expect(1, 64279, '\P{^Sc: _Armn}', "");
Expect(0, 64280, '\p{Sc: _Armn}', "");
Expect(1, 64280, '\p{^Sc: _Armn}', "");
Expect(1, 64280, '\P{Sc: _Armn}', "");
Expect(0, 64280, '\P{^Sc: _Armn}', "");
Error('\p{Is_Script=/a/Armenian}');
Error('\P{Is_Script=/a/Armenian}');
Expect(1, 64279, '\p{Is_Script=armenian}', "");
Expect(0, 64279, '\p{^Is_Script=armenian}', "");
Expect(0, 64279, '\P{Is_Script=armenian}', "");
Expect(1, 64279, '\P{^Is_Script=armenian}', "");
Expect(0, 64280, '\p{Is_Script=armenian}', "");
Expect(1, 64280, '\p{^Is_Script=armenian}', "");
Expect(1, 64280, '\P{Is_Script=armenian}', "");
Expect(0, 64280, '\P{^Is_Script=armenian}', "");
Expect(1, 64279, '\p{Is_Script=-	Armenian}', "");
Expect(0, 64279, '\p{^Is_Script=-	Armenian}', "");
Expect(0, 64279, '\P{Is_Script=-	Armenian}', "");
Expect(1, 64279, '\P{^Is_Script=-	Armenian}', "");
Expect(0, 64280, '\p{Is_Script=-	Armenian}', "");
Expect(1, 64280, '\p{^Is_Script=-	Armenian}', "");
Expect(1, 64280, '\P{Is_Script=-	Armenian}', "");
Expect(0, 64280, '\P{^Is_Script=-	Armenian}', "");
Error('\p{Is_Sc=/a/	-Armn}');
Error('\P{Is_Sc=/a/	-Armn}');
Expect(1, 64279, '\p{Is_Sc=armn}', "");
Expect(0, 64279, '\p{^Is_Sc=armn}', "");
Expect(0, 64279, '\P{Is_Sc=armn}', "");
Expect(1, 64279, '\P{^Is_Sc=armn}', "");
Expect(0, 64280, '\p{Is_Sc=armn}', "");
Expect(1, 64280, '\p{^Is_Sc=armn}', "");
Expect(1, 64280, '\P{Is_Sc=armn}', "");
Expect(0, 64280, '\P{^Is_Sc=armn}', "");
Expect(1, 64279, '\p{Is_Sc= Armn}', "");
Expect(0, 64279, '\p{^Is_Sc= Armn}', "");
Expect(0, 64279, '\P{Is_Sc= Armn}', "");
Expect(1, 64279, '\P{^Is_Sc= Armn}', "");
Expect(0, 64280, '\p{Is_Sc= Armn}', "");
Expect(1, 64280, '\p{^Is_Sc= Armn}', "");
Expect(1, 64280, '\P{Is_Sc= Armn}', "");
Expect(0, 64280, '\P{^Is_Sc= Armn}', "");
Error('\p{Script=/a/ Avestan}');
Error('\P{Script=/a/ Avestan}');
Expect(1, 68415, '\p{Script=avestan}', "");
Expect(0, 68415, '\p{^Script=avestan}', "");
Expect(0, 68415, '\P{Script=avestan}', "");
Expect(1, 68415, '\P{^Script=avestan}', "");
Expect(0, 68416, '\p{Script=avestan}', "");
Expect(1, 68416, '\p{^Script=avestan}', "");
Expect(1, 68416, '\P{Script=avestan}', "");
Expect(0, 68416, '\P{^Script=avestan}', "");
Expect(1, 68415, '\p{Script=-_Avestan}', "");
Expect(0, 68415, '\p{^Script=-_Avestan}', "");
Expect(0, 68415, '\P{Script=-_Avestan}', "");
Expect(1, 68415, '\P{^Script=-_Avestan}', "");
Expect(0, 68416, '\p{Script=-_Avestan}', "");
Expect(1, 68416, '\p{^Script=-_Avestan}', "");
Expect(1, 68416, '\P{Script=-_Avestan}', "");
Expect(0, 68416, '\P{^Script=-_Avestan}', "");
Error('\p{Sc=/a/-Avst}');
Error('\P{Sc=/a/-Avst}');
Expect(1, 68415, '\p{Sc=avst}', "");
Expect(0, 68415, '\p{^Sc=avst}', "");
Expect(0, 68415, '\P{Sc=avst}', "");
Expect(1, 68415, '\P{^Sc=avst}', "");
Expect(0, 68416, '\p{Sc=avst}', "");
Expect(1, 68416, '\p{^Sc=avst}', "");
Expect(1, 68416, '\P{Sc=avst}', "");
Expect(0, 68416, '\P{^Sc=avst}', "");
Expect(1, 68415, '\p{Sc=	-Avst}', "");
Expect(0, 68415, '\p{^Sc=	-Avst}', "");
Expect(0, 68415, '\P{Sc=	-Avst}', "");
Expect(1, 68415, '\P{^Sc=	-Avst}', "");
Expect(0, 68416, '\p{Sc=	-Avst}', "");
Expect(1, 68416, '\p{^Sc=	-Avst}', "");
Expect(1, 68416, '\P{Sc=	-Avst}', "");
Expect(0, 68416, '\P{^Sc=	-Avst}', "");
Error('\p{Is_Script=/a/AVESTAN}');
Error('\P{Is_Script=/a/AVESTAN}');
Expect(1, 68415, '\p{Is_Script=avestan}', "");
Expect(0, 68415, '\p{^Is_Script=avestan}', "");
Expect(0, 68415, '\P{Is_Script=avestan}', "");
Expect(1, 68415, '\P{^Is_Script=avestan}', "");
Expect(0, 68416, '\p{Is_Script=avestan}', "");
Expect(1, 68416, '\p{^Is_Script=avestan}', "");
Expect(1, 68416, '\P{Is_Script=avestan}', "");
Expect(0, 68416, '\P{^Is_Script=avestan}', "");
Expect(1, 68415, '\p{Is_Script=__Avestan}', "");
Expect(0, 68415, '\p{^Is_Script=__Avestan}', "");
Expect(0, 68415, '\P{Is_Script=__Avestan}', "");
Expect(1, 68415, '\P{^Is_Script=__Avestan}', "");
Expect(0, 68416, '\p{Is_Script=__Avestan}', "");
Expect(1, 68416, '\p{^Is_Script=__Avestan}', "");
Expect(1, 68416, '\P{Is_Script=__Avestan}', "");
Expect(0, 68416, '\P{^Is_Script=__Avestan}', "");
Error('\p{Is_Sc= _Avst/a/}');
Error('\P{Is_Sc= _Avst/a/}');
Expect(1, 68415, '\p{Is_Sc=avst}', "");
Expect(0, 68415, '\p{^Is_Sc=avst}', "");
Expect(0, 68415, '\P{Is_Sc=avst}', "");
Expect(1, 68415, '\P{^Is_Sc=avst}', "");
Expect(0, 68416, '\p{Is_Sc=avst}', "");
Expect(1, 68416, '\p{^Is_Sc=avst}', "");
Expect(1, 68416, '\P{Is_Sc=avst}', "");
Expect(0, 68416, '\P{^Is_Sc=avst}', "");
Expect(1, 68415, '\p{Is_Sc= Avst}', "");
Expect(0, 68415, '\p{^Is_Sc= Avst}', "");
Expect(0, 68415, '\P{Is_Sc= Avst}', "");
Expect(1, 68415, '\P{^Is_Sc= Avst}', "");
Expect(0, 68416, '\p{Is_Sc= Avst}', "");
Expect(1, 68416, '\p{^Is_Sc= Avst}', "");
Expect(1, 68416, '\P{Is_Sc= Avst}', "");
Expect(0, 68416, '\P{^Is_Sc= Avst}', "");
Error('\p{Script: 	Balinese:=}');
Error('\P{Script: 	Balinese:=}');
Expect(1, 7036, '\p{Script:   balinese}', "");
Expect(0, 7036, '\p{^Script:   balinese}', "");
Expect(0, 7036, '\P{Script:   balinese}', "");
Expect(1, 7036, '\P{^Script:   balinese}', "");
Expect(0, 7037, '\p{Script:   balinese}', "");
Expect(1, 7037, '\p{^Script:   balinese}', "");
Expect(1, 7037, '\P{Script:   balinese}', "");
Expect(0, 7037, '\P{^Script:   balinese}', "");
Expect(1, 7036, '\p{Script=Balinese}', "");
Expect(0, 7036, '\p{^Script=Balinese}', "");
Expect(0, 7036, '\P{Script=Balinese}', "");
Expect(1, 7036, '\P{^Script=Balinese}', "");
Expect(0, 7037, '\p{Script=Balinese}', "");
Expect(1, 7037, '\p{^Script=Balinese}', "");
Expect(1, 7037, '\P{Script=Balinese}', "");
Expect(0, 7037, '\P{^Script=Balinese}', "");
Error('\p{Sc=_ bali/a/}');
Error('\P{Sc=_ bali/a/}');
Expect(1, 7036, '\p{Sc=bali}', "");
Expect(0, 7036, '\p{^Sc=bali}', "");
Expect(0, 7036, '\P{Sc=bali}', "");
Expect(1, 7036, '\P{^Sc=bali}', "");
Expect(0, 7037, '\p{Sc=bali}', "");
Expect(1, 7037, '\p{^Sc=bali}', "");
Expect(1, 7037, '\P{Sc=bali}', "");
Expect(0, 7037, '\P{^Sc=bali}', "");
Expect(1, 7036, '\p{Sc=-BALI}', "");
Expect(0, 7036, '\p{^Sc=-BALI}', "");
Expect(0, 7036, '\P{Sc=-BALI}', "");
Expect(1, 7036, '\P{^Sc=-BALI}', "");
Expect(0, 7037, '\p{Sc=-BALI}', "");
Expect(1, 7037, '\p{^Sc=-BALI}', "");
Expect(1, 7037, '\P{Sc=-BALI}', "");
Expect(0, 7037, '\P{^Sc=-BALI}', "");
Error('\p{Is_Script=/a/  BALINESE}');
Error('\P{Is_Script=/a/  BALINESE}');
Expect(1, 7036, '\p{Is_Script=balinese}', "");
Expect(0, 7036, '\p{^Is_Script=balinese}', "");
Expect(0, 7036, '\P{Is_Script=balinese}', "");
Expect(1, 7036, '\P{^Is_Script=balinese}', "");
Expect(0, 7037, '\p{Is_Script=balinese}', "");
Expect(1, 7037, '\p{^Is_Script=balinese}', "");
Expect(1, 7037, '\P{Is_Script=balinese}', "");
Expect(0, 7037, '\P{^Is_Script=balinese}', "");
Expect(1, 7036, '\p{Is_Script=_Balinese}', "");
Expect(0, 7036, '\p{^Is_Script=_Balinese}', "");
Expect(0, 7036, '\P{Is_Script=_Balinese}', "");
Expect(1, 7036, '\P{^Is_Script=_Balinese}', "");
Expect(0, 7037, '\p{Is_Script=_Balinese}', "");
Expect(1, 7037, '\p{^Is_Script=_Balinese}', "");
Expect(1, 7037, '\P{Is_Script=_Balinese}', "");
Expect(0, 7037, '\P{^Is_Script=_Balinese}', "");
Error('\p{Is_Sc: -/a/bali}');
Error('\P{Is_Sc: -/a/bali}');
Expect(1, 7036, '\p{Is_Sc=bali}', "");
Expect(0, 7036, '\p{^Is_Sc=bali}', "");
Expect(0, 7036, '\P{Is_Sc=bali}', "");
Expect(1, 7036, '\P{^Is_Sc=bali}', "");
Expect(0, 7037, '\p{Is_Sc=bali}', "");
Expect(1, 7037, '\p{^Is_Sc=bali}', "");
Expect(1, 7037, '\P{Is_Sc=bali}', "");
Expect(0, 7037, '\P{^Is_Sc=bali}', "");
Expect(1, 7036, '\p{Is_Sc:	--BALI}', "");
Expect(0, 7036, '\p{^Is_Sc:	--BALI}', "");
Expect(0, 7036, '\P{Is_Sc:	--BALI}', "");
Expect(1, 7036, '\P{^Is_Sc:	--BALI}', "");
Expect(0, 7037, '\p{Is_Sc:	--BALI}', "");
Expect(1, 7037, '\p{^Is_Sc:	--BALI}', "");
Expect(1, 7037, '\P{Is_Sc:	--BALI}', "");
Expect(0, 7037, '\P{^Is_Sc:	--BALI}', "");
Error('\p{Script=-	BAMUM:=}');
Error('\P{Script=-	BAMUM:=}');
Expect(1, 92728, '\p{Script=bamum}', "");
Expect(0, 92728, '\p{^Script=bamum}', "");
Expect(0, 92728, '\P{Script=bamum}', "");
Expect(1, 92728, '\P{^Script=bamum}', "");
Expect(0, 92729, '\p{Script=bamum}', "");
Expect(1, 92729, '\p{^Script=bamum}', "");
Expect(1, 92729, '\P{Script=bamum}', "");
Expect(0, 92729, '\P{^Script=bamum}', "");
Expect(1, 92728, '\p{Script=	-Bamum}', "");
Expect(0, 92728, '\p{^Script=	-Bamum}', "");
Expect(0, 92728, '\P{Script=	-Bamum}', "");
Expect(1, 92728, '\P{^Script=	-Bamum}', "");
Expect(0, 92729, '\p{Script=	-Bamum}', "");
Expect(1, 92729, '\p{^Script=	-Bamum}', "");
Expect(1, 92729, '\P{Script=	-Bamum}', "");
Expect(0, 92729, '\P{^Script=	-Bamum}', "");
Error('\p{Sc=:=  Bamu}');
Error('\P{Sc=:=  Bamu}');
Expect(1, 92728, '\p{Sc=bamu}', "");
Expect(0, 92728, '\p{^Sc=bamu}', "");
Expect(0, 92728, '\P{Sc=bamu}', "");
Expect(1, 92728, '\P{^Sc=bamu}', "");
Expect(0, 92729, '\p{Sc=bamu}', "");
Expect(1, 92729, '\p{^Sc=bamu}', "");
Expect(1, 92729, '\P{Sc=bamu}', "");
Expect(0, 92729, '\P{^Sc=bamu}', "");
Expect(1, 92728, '\p{Sc= Bamu}', "");
Expect(0, 92728, '\p{^Sc= Bamu}', "");
Expect(0, 92728, '\P{Sc= Bamu}', "");
Expect(1, 92728, '\P{^Sc= Bamu}', "");
Expect(0, 92729, '\p{Sc= Bamu}', "");
Expect(1, 92729, '\p{^Sc= Bamu}', "");
Expect(1, 92729, '\P{Sc= Bamu}', "");
Expect(0, 92729, '\P{^Sc= Bamu}', "");
Error('\p{Is_Script:	bamum:=}');
Error('\P{Is_Script:	bamum:=}');
Expect(1, 92728, '\p{Is_Script=bamum}', "");
Expect(0, 92728, '\p{^Is_Script=bamum}', "");
Expect(0, 92728, '\P{Is_Script=bamum}', "");
Expect(1, 92728, '\P{^Is_Script=bamum}', "");
Expect(0, 92729, '\p{Is_Script=bamum}', "");
Expect(1, 92729, '\p{^Is_Script=bamum}', "");
Expect(1, 92729, '\P{Is_Script=bamum}', "");
Expect(0, 92729, '\P{^Is_Script=bamum}', "");
Expect(1, 92728, '\p{Is_Script:_ Bamum}', "");
Expect(0, 92728, '\p{^Is_Script:_ Bamum}', "");
Expect(0, 92728, '\P{Is_Script:_ Bamum}', "");
Expect(1, 92728, '\P{^Is_Script:_ Bamum}', "");
Expect(0, 92729, '\p{Is_Script:_ Bamum}', "");
Expect(1, 92729, '\p{^Is_Script:_ Bamum}', "");
Expect(1, 92729, '\P{Is_Script:_ Bamum}', "");
Expect(0, 92729, '\P{^Is_Script:_ Bamum}', "");
Error('\p{Is_Sc=- bamu/a/}');
Error('\P{Is_Sc=- bamu/a/}');
Expect(1, 92728, '\p{Is_Sc=bamu}', "");
Expect(0, 92728, '\p{^Is_Sc=bamu}', "");
Expect(0, 92728, '\P{Is_Sc=bamu}', "");
Expect(1, 92728, '\P{^Is_Sc=bamu}', "");
Expect(0, 92729, '\p{Is_Sc=bamu}', "");
Expect(1, 92729, '\p{^Is_Sc=bamu}', "");
Expect(1, 92729, '\P{Is_Sc=bamu}', "");
Expect(0, 92729, '\P{^Is_Sc=bamu}', "");
Expect(1, 92728, '\p{Is_Sc=-BAMU}', "");
Expect(0, 92728, '\p{^Is_Sc=-BAMU}', "");
Expect(0, 92728, '\P{Is_Sc=-BAMU}', "");
Expect(1, 92728, '\P{^Is_Sc=-BAMU}', "");
Expect(0, 92729, '\p{Is_Sc=-BAMU}', "");
Expect(1, 92729, '\p{^Is_Sc=-BAMU}', "");
Expect(1, 92729, '\P{Is_Sc=-BAMU}', "");
Expect(0, 92729, '\P{^Is_Sc=-BAMU}', "");
Error('\p{Script=-:=Batak}');
Error('\P{Script=-:=Batak}');
Expect(1, 7167, '\p{Script=batak}', "");
Expect(0, 7167, '\p{^Script=batak}', "");
Expect(0, 7167, '\P{Script=batak}', "");
Expect(1, 7167, '\P{^Script=batak}', "");
Expect(0, 7168, '\p{Script=batak}', "");
Expect(1, 7168, '\p{^Script=batak}', "");
Expect(1, 7168, '\P{Script=batak}', "");
Expect(0, 7168, '\P{^Script=batak}', "");
Expect(1, 7167, '\p{Script=-	Batak}', "");
Expect(0, 7167, '\p{^Script=-	Batak}', "");
Expect(0, 7167, '\P{Script=-	Batak}', "");
Expect(1, 7167, '\P{^Script=-	Batak}', "");
Expect(0, 7168, '\p{Script=-	Batak}', "");
Expect(1, 7168, '\p{^Script=-	Batak}', "");
Expect(1, 7168, '\P{Script=-	Batak}', "");
Expect(0, 7168, '\P{^Script=-	Batak}', "");
Error('\p{Sc=	 batk:=}');
Error('\P{Sc=	 batk:=}');
Expect(1, 7167, '\p{Sc=batk}', "");
Expect(0, 7167, '\p{^Sc=batk}', "");
Expect(0, 7167, '\P{Sc=batk}', "");
Expect(1, 7167, '\P{^Sc=batk}', "");
Expect(0, 7168, '\p{Sc=batk}', "");
Expect(1, 7168, '\p{^Sc=batk}', "");
Expect(1, 7168, '\P{Sc=batk}', "");
Expect(0, 7168, '\P{^Sc=batk}', "");
Expect(1, 7167, '\p{Sc=--Batk}', "");
Expect(0, 7167, '\p{^Sc=--Batk}', "");
Expect(0, 7167, '\P{Sc=--Batk}', "");
Expect(1, 7167, '\P{^Sc=--Batk}', "");
Expect(0, 7168, '\p{Sc=--Batk}', "");
Expect(1, 7168, '\p{^Sc=--Batk}', "");
Expect(1, 7168, '\P{Sc=--Batk}', "");
Expect(0, 7168, '\P{^Sc=--Batk}', "");
Error('\p{Is_Script: /a/- BATAK}');
Error('\P{Is_Script: /a/- BATAK}');
Expect(1, 7167, '\p{Is_Script=batak}', "");
Expect(0, 7167, '\p{^Is_Script=batak}', "");
Expect(0, 7167, '\P{Is_Script=batak}', "");
Expect(1, 7167, '\P{^Is_Script=batak}', "");
Expect(0, 7168, '\p{Is_Script=batak}', "");
Expect(1, 7168, '\p{^Is_Script=batak}', "");
Expect(1, 7168, '\P{Is_Script=batak}', "");
Expect(0, 7168, '\P{^Is_Script=batak}', "");
Expect(1, 7167, '\p{Is_Script= Batak}', "");
Expect(0, 7167, '\p{^Is_Script= Batak}', "");
Expect(0, 7167, '\P{Is_Script= Batak}', "");
Expect(1, 7167, '\P{^Is_Script= Batak}', "");
Expect(0, 7168, '\p{Is_Script= Batak}', "");
Expect(1, 7168, '\p{^Is_Script= Batak}', "");
Expect(1, 7168, '\P{Is_Script= Batak}', "");
Expect(0, 7168, '\P{^Is_Script= Batak}', "");
Error('\p{Is_Sc=	:=Batk}');
Error('\P{Is_Sc=	:=Batk}');
Expect(1, 7167, '\p{Is_Sc=batk}', "");
Expect(0, 7167, '\p{^Is_Sc=batk}', "");
Expect(0, 7167, '\P{Is_Sc=batk}', "");
Expect(1, 7167, '\P{^Is_Sc=batk}', "");
Expect(0, 7168, '\p{Is_Sc=batk}', "");
Expect(1, 7168, '\p{^Is_Sc=batk}', "");
Expect(1, 7168, '\P{Is_Sc=batk}', "");
Expect(0, 7168, '\P{^Is_Sc=batk}', "");
Expect(1, 7167, '\p{Is_Sc=-	BATK}', "");
Expect(0, 7167, '\p{^Is_Sc=-	BATK}', "");
Expect(0, 7167, '\P{Is_Sc=-	BATK}', "");
Expect(1, 7167, '\P{^Is_Sc=-	BATK}', "");
Expect(0, 7168, '\p{Is_Sc=-	BATK}', "");
Expect(1, 7168, '\p{^Is_Sc=-	BATK}', "");
Expect(1, 7168, '\P{Is_Sc=-	BATK}', "");
Expect(0, 7168, '\P{^Is_Sc=-	BATK}', "");
Error('\p{Script=-Bengali:=}');
Error('\P{Script=-Bengali:=}');
Expect(1, 2555, '\p{Script:bengali}', "");
Expect(0, 2555, '\p{^Script:bengali}', "");
Expect(0, 2555, '\P{Script:bengali}', "");
Expect(1, 2555, '\P{^Script:bengali}', "");
Expect(0, 2556, '\p{Script:bengali}', "");
Expect(1, 2556, '\p{^Script:bengali}', "");
Expect(1, 2556, '\P{Script:bengali}', "");
Expect(0, 2556, '\P{^Script:bengali}', "");
Expect(1, 2555, '\p{Script=_	bengali}', "");
Expect(0, 2555, '\p{^Script=_	bengali}', "");
Expect(0, 2555, '\P{Script=_	bengali}', "");
Expect(1, 2555, '\P{^Script=_	bengali}', "");
Expect(0, 2556, '\p{Script=_	bengali}', "");
Expect(1, 2556, '\p{^Script=_	bengali}', "");
Expect(1, 2556, '\P{Script=_	bengali}', "");
Expect(0, 2556, '\P{^Script=_	bengali}', "");
Error('\p{Sc=	_beng:=}');
Error('\P{Sc=	_beng:=}');
Expect(1, 2555, '\p{Sc=beng}', "");
Expect(0, 2555, '\p{^Sc=beng}', "");
Expect(0, 2555, '\P{Sc=beng}', "");
Expect(1, 2555, '\P{^Sc=beng}', "");
Expect(0, 2556, '\p{Sc=beng}', "");
Expect(1, 2556, '\p{^Sc=beng}', "");
Expect(1, 2556, '\P{Sc=beng}', "");
Expect(0, 2556, '\P{^Sc=beng}', "");
Expect(1, 2555, '\p{Sc= Beng}', "");
Expect(0, 2555, '\p{^Sc= Beng}', "");
Expect(0, 2555, '\P{Sc= Beng}', "");
Expect(1, 2555, '\P{^Sc= Beng}', "");
Expect(0, 2556, '\p{Sc= Beng}', "");
Expect(1, 2556, '\p{^Sc= Beng}', "");
Expect(1, 2556, '\P{Sc= Beng}', "");
Expect(0, 2556, '\P{^Sc= Beng}', "");
Error('\p{Is_Script=:=_Bengali}');
Error('\P{Is_Script=:=_Bengali}');
Expect(1, 2555, '\p{Is_Script=bengali}', "");
Expect(0, 2555, '\p{^Is_Script=bengali}', "");
Expect(0, 2555, '\P{Is_Script=bengali}', "");
Expect(1, 2555, '\P{^Is_Script=bengali}', "");
Expect(0, 2556, '\p{Is_Script=bengali}', "");
Expect(1, 2556, '\p{^Is_Script=bengali}', "");
Expect(1, 2556, '\P{Is_Script=bengali}', "");
Expect(0, 2556, '\P{^Is_Script=bengali}', "");
Expect(1, 2555, '\p{Is_Script=-Bengali}', "");
Expect(0, 2555, '\p{^Is_Script=-Bengali}', "");
Expect(0, 2555, '\P{Is_Script=-Bengali}', "");
Expect(1, 2555, '\P{^Is_Script=-Bengali}', "");
Expect(0, 2556, '\p{Is_Script=-Bengali}', "");
Expect(1, 2556, '\p{^Is_Script=-Bengali}', "");
Expect(1, 2556, '\P{Is_Script=-Bengali}', "");
Expect(0, 2556, '\P{^Is_Script=-Bengali}', "");
Error('\p{Is_Sc:   /a/_-Beng}');
Error('\P{Is_Sc:   /a/_-Beng}');
Expect(1, 2555, '\p{Is_Sc=beng}', "");
Expect(0, 2555, '\p{^Is_Sc=beng}', "");
Expect(0, 2555, '\P{Is_Sc=beng}', "");
Expect(1, 2555, '\P{^Is_Sc=beng}', "");
Expect(0, 2556, '\p{Is_Sc=beng}', "");
Expect(1, 2556, '\p{^Is_Sc=beng}', "");
Expect(1, 2556, '\P{Is_Sc=beng}', "");
Expect(0, 2556, '\P{^Is_Sc=beng}', "");
Expect(1, 2555, '\p{Is_Sc=	_Beng}', "");
Expect(0, 2555, '\p{^Is_Sc=	_Beng}', "");
Expect(0, 2555, '\P{Is_Sc=	_Beng}', "");
Expect(1, 2555, '\P{^Is_Sc=	_Beng}', "");
Expect(0, 2556, '\p{Is_Sc=	_Beng}', "");
Expect(1, 2556, '\p{^Is_Sc=	_Beng}', "");
Expect(1, 2556, '\P{Is_Sc=	_Beng}', "");
Expect(0, 2556, '\P{^Is_Sc=	_Beng}', "");
Error('\p{Script=_:=BOPOMOFO}');
Error('\P{Script=_:=BOPOMOFO}');
Expect(1, 12730, '\p{Script=bopomofo}', "");
Expect(0, 12730, '\p{^Script=bopomofo}', "");
Expect(0, 12730, '\P{Script=bopomofo}', "");
Expect(1, 12730, '\P{^Script=bopomofo}', "");
Expect(0, 12731, '\p{Script=bopomofo}', "");
Expect(1, 12731, '\p{^Script=bopomofo}', "");
Expect(1, 12731, '\P{Script=bopomofo}', "");
Expect(0, 12731, '\P{^Script=bopomofo}', "");
Expect(1, 12730, '\p{Script:   __Bopomofo}', "");
Expect(0, 12730, '\p{^Script:   __Bopomofo}', "");
Expect(0, 12730, '\P{Script:   __Bopomofo}', "");
Expect(1, 12730, '\P{^Script:   __Bopomofo}', "");
Expect(0, 12731, '\p{Script:   __Bopomofo}', "");
Expect(1, 12731, '\p{^Script:   __Bopomofo}', "");
Expect(1, 12731, '\P{Script:   __Bopomofo}', "");
Expect(0, 12731, '\P{^Script:   __Bopomofo}', "");
Error('\p{Sc= -Bopo:=}');
Error('\P{Sc= -Bopo:=}');
Expect(1, 12730, '\p{Sc=bopo}', "");
Expect(0, 12730, '\p{^Sc=bopo}', "");
Expect(0, 12730, '\P{Sc=bopo}', "");
Expect(1, 12730, '\P{^Sc=bopo}', "");
Expect(0, 12731, '\p{Sc=bopo}', "");
Expect(1, 12731, '\p{^Sc=bopo}', "");
Expect(1, 12731, '\P{Sc=bopo}', "");
Expect(0, 12731, '\P{^Sc=bopo}', "");
Expect(1, 12730, '\p{Sc=_Bopo}', "");
Expect(0, 12730, '\p{^Sc=_Bopo}', "");
Expect(0, 12730, '\P{Sc=_Bopo}', "");
Expect(1, 12730, '\P{^Sc=_Bopo}', "");
Expect(0, 12731, '\p{Sc=_Bopo}', "");
Expect(1, 12731, '\p{^Sc=_Bopo}', "");
Expect(1, 12731, '\P{Sc=_Bopo}', "");
Expect(0, 12731, '\P{^Sc=_Bopo}', "");
Error('\p{Is_Script=-bopomofo/a/}');
Error('\P{Is_Script=-bopomofo/a/}');
Expect(1, 12730, '\p{Is_Script=bopomofo}', "");
Expect(0, 12730, '\p{^Is_Script=bopomofo}', "");
Expect(0, 12730, '\P{Is_Script=bopomofo}', "");
Expect(1, 12730, '\P{^Is_Script=bopomofo}', "");
Expect(0, 12731, '\p{Is_Script=bopomofo}', "");
Expect(1, 12731, '\p{^Is_Script=bopomofo}', "");
Expect(1, 12731, '\P{Is_Script=bopomofo}', "");
Expect(0, 12731, '\P{^Is_Script=bopomofo}', "");
Expect(1, 12730, '\p{Is_Script=	 BOPOMOFO}', "");
Expect(0, 12730, '\p{^Is_Script=	 BOPOMOFO}', "");
Expect(0, 12730, '\P{Is_Script=	 BOPOMOFO}', "");
Expect(1, 12730, '\P{^Is_Script=	 BOPOMOFO}', "");
Expect(0, 12731, '\p{Is_Script=	 BOPOMOFO}', "");
Expect(1, 12731, '\p{^Is_Script=	 BOPOMOFO}', "");
Expect(1, 12731, '\P{Is_Script=	 BOPOMOFO}', "");
Expect(0, 12731, '\P{^Is_Script=	 BOPOMOFO}', "");
Error('\p{Is_Sc=/a/Bopo}');
Error('\P{Is_Sc=/a/Bopo}');
Expect(1, 12730, '\p{Is_Sc=bopo}', "");
Expect(0, 12730, '\p{^Is_Sc=bopo}', "");
Expect(0, 12730, '\P{Is_Sc=bopo}', "");
Expect(1, 12730, '\P{^Is_Sc=bopo}', "");
Expect(0, 12731, '\p{Is_Sc=bopo}', "");
Expect(1, 12731, '\p{^Is_Sc=bopo}', "");
Expect(1, 12731, '\P{Is_Sc=bopo}', "");
Expect(0, 12731, '\P{^Is_Sc=bopo}', "");
Expect(1, 12730, '\p{Is_Sc=_Bopo}', "");
Expect(0, 12730, '\p{^Is_Sc=_Bopo}', "");
Expect(0, 12730, '\P{Is_Sc=_Bopo}', "");
Expect(1, 12730, '\P{^Is_Sc=_Bopo}', "");
Expect(0, 12731, '\p{Is_Sc=_Bopo}', "");
Expect(1, 12731, '\p{^Is_Sc=_Bopo}', "");
Expect(1, 12731, '\P{Is_Sc=_Bopo}', "");
Expect(0, 12731, '\P{^Is_Sc=_Bopo}', "");
Error('\p{Script=	/a/BRAHMI}');
Error('\P{Script=	/a/BRAHMI}');
Expect(1, 69743, '\p{Script=brahmi}', "");
Expect(0, 69743, '\p{^Script=brahmi}', "");
Expect(0, 69743, '\P{Script=brahmi}', "");
Expect(1, 69743, '\P{^Script=brahmi}', "");
Expect(0, 69744, '\p{Script=brahmi}', "");
Expect(1, 69744, '\p{^Script=brahmi}', "");
Expect(1, 69744, '\P{Script=brahmi}', "");
Expect(0, 69744, '\P{^Script=brahmi}', "");
Expect(1, 69743, '\p{Script= 	brahmi}', "");
Expect(0, 69743, '\p{^Script= 	brahmi}', "");
Expect(0, 69743, '\P{Script= 	brahmi}', "");
Expect(1, 69743, '\P{^Script= 	brahmi}', "");
Expect(0, 69744, '\p{Script= 	brahmi}', "");
Expect(1, 69744, '\p{^Script= 	brahmi}', "");
Expect(1, 69744, '\P{Script= 	brahmi}', "");
Expect(0, 69744, '\P{^Script= 	brahmi}', "");
Error('\p{Sc=/a/	Brah}');
Error('\P{Sc=/a/	Brah}');
Expect(1, 69743, '\p{Sc=brah}', "");
Expect(0, 69743, '\p{^Sc=brah}', "");
Expect(0, 69743, '\P{Sc=brah}', "");
Expect(1, 69743, '\P{^Sc=brah}', "");
Expect(0, 69744, '\p{Sc=brah}', "");
Expect(1, 69744, '\p{^Sc=brah}', "");
Expect(1, 69744, '\P{Sc=brah}', "");
Expect(0, 69744, '\P{^Sc=brah}', "");
Expect(1, 69743, '\p{Sc=  Brah}', "");
Expect(0, 69743, '\p{^Sc=  Brah}', "");
Expect(0, 69743, '\P{Sc=  Brah}', "");
Expect(1, 69743, '\P{^Sc=  Brah}', "");
Expect(0, 69744, '\p{Sc=  Brah}', "");
Expect(1, 69744, '\p{^Sc=  Brah}', "");
Expect(1, 69744, '\P{Sc=  Brah}', "");
Expect(0, 69744, '\P{^Sc=  Brah}', "");
Error('\p{Is_Script=	:=Brahmi}');
Error('\P{Is_Script=	:=Brahmi}');
Expect(1, 69743, '\p{Is_Script=brahmi}', "");
Expect(0, 69743, '\p{^Is_Script=brahmi}', "");
Expect(0, 69743, '\P{Is_Script=brahmi}', "");
Expect(1, 69743, '\P{^Is_Script=brahmi}', "");
Expect(0, 69744, '\p{Is_Script=brahmi}', "");
Expect(1, 69744, '\p{^Is_Script=brahmi}', "");
Expect(1, 69744, '\P{Is_Script=brahmi}', "");
Expect(0, 69744, '\P{^Is_Script=brahmi}', "");
Expect(1, 69743, '\p{Is_Script=	-BRAHMI}', "");
Expect(0, 69743, '\p{^Is_Script=	-BRAHMI}', "");
Expect(0, 69743, '\P{Is_Script=	-BRAHMI}', "");
Expect(1, 69743, '\P{^Is_Script=	-BRAHMI}', "");
Expect(0, 69744, '\p{Is_Script=	-BRAHMI}', "");
Expect(1, 69744, '\p{^Is_Script=	-BRAHMI}', "");
Expect(1, 69744, '\P{Is_Script=	-BRAHMI}', "");
Expect(0, 69744, '\P{^Is_Script=	-BRAHMI}', "");
Error('\p{Is_Sc=/a/Brah}');
Error('\P{Is_Sc=/a/Brah}');
Expect(1, 69743, '\p{Is_Sc=brah}', "");
Expect(0, 69743, '\p{^Is_Sc=brah}', "");
Expect(0, 69743, '\P{Is_Sc=brah}', "");
Expect(1, 69743, '\P{^Is_Sc=brah}', "");
Expect(0, 69744, '\p{Is_Sc=brah}', "");
Expect(1, 69744, '\p{^Is_Sc=brah}', "");
Expect(1, 69744, '\P{Is_Sc=brah}', "");
Expect(0, 69744, '\P{^Is_Sc=brah}', "");
Expect(1, 69743, '\p{Is_Sc= Brah}', "");
Expect(0, 69743, '\p{^Is_Sc= Brah}', "");
Expect(0, 69743, '\P{Is_Sc= Brah}', "");
Expect(1, 69743, '\P{^Is_Sc= Brah}', "");
Expect(0, 69744, '\p{Is_Sc= Brah}', "");
Expect(1, 69744, '\p{^Is_Sc= Brah}', "");
Expect(1, 69744, '\P{Is_Sc= Brah}', "");
Expect(0, 69744, '\P{^Is_Sc= Brah}', "");
Error('\p{Script=_/a/BRAILLE}');
Error('\P{Script=_/a/BRAILLE}');
Expect(1, 10495, '\p{Script=braille}', "");
Expect(0, 10495, '\p{^Script=braille}', "");
Expect(0, 10495, '\P{Script=braille}', "");
Expect(1, 10495, '\P{^Script=braille}', "");
Expect(0, 10496, '\p{Script=braille}', "");
Expect(1, 10496, '\p{^Script=braille}', "");
Expect(1, 10496, '\P{Script=braille}', "");
Expect(0, 10496, '\P{^Script=braille}', "");
Expect(1, 10495, '\p{Script=	 Braille}', "");
Expect(0, 10495, '\p{^Script=	 Braille}', "");
Expect(0, 10495, '\P{Script=	 Braille}', "");
Expect(1, 10495, '\P{^Script=	 Braille}', "");
Expect(0, 10496, '\p{Script=	 Braille}', "");
Expect(1, 10496, '\p{^Script=	 Braille}', "");
Expect(1, 10496, '\P{Script=	 Braille}', "");
Expect(0, 10496, '\P{^Script=	 Braille}', "");
Error('\p{Sc=-/a/Brai}');
Error('\P{Sc=-/a/Brai}');
Expect(1, 10495, '\p{Sc=brai}', "");
Expect(0, 10495, '\p{^Sc=brai}', "");
Expect(0, 10495, '\P{Sc=brai}', "");
Expect(1, 10495, '\P{^Sc=brai}', "");
Expect(0, 10496, '\p{Sc=brai}', "");
Expect(1, 10496, '\p{^Sc=brai}', "");
Expect(1, 10496, '\P{Sc=brai}', "");
Expect(0, 10496, '\P{^Sc=brai}', "");
Expect(1, 10495, '\p{Sc=_brai}', "");
Expect(0, 10495, '\p{^Sc=_brai}', "");
Expect(0, 10495, '\P{Sc=_brai}', "");
Expect(1, 10495, '\P{^Sc=_brai}', "");
Expect(0, 10496, '\p{Sc=_brai}', "");
Expect(1, 10496, '\p{^Sc=_brai}', "");
Expect(1, 10496, '\P{Sc=_brai}', "");
Expect(0, 10496, '\P{^Sc=_brai}', "");
Error('\p{Is_Script=-Braille:=}');
Error('\P{Is_Script=-Braille:=}');
Expect(1, 10495, '\p{Is_Script:braille}', "");
Expect(0, 10495, '\p{^Is_Script:braille}', "");
Expect(0, 10495, '\P{Is_Script:braille}', "");
Expect(1, 10495, '\P{^Is_Script:braille}', "");
Expect(0, 10496, '\p{Is_Script:braille}', "");
Expect(1, 10496, '\p{^Is_Script:braille}', "");
Expect(1, 10496, '\P{Is_Script:braille}', "");
Expect(0, 10496, '\P{^Is_Script:braille}', "");
Expect(1, 10495, '\p{Is_Script:   _-Braille}', "");
Expect(0, 10495, '\p{^Is_Script:   _-Braille}', "");
Expect(0, 10495, '\P{Is_Script:   _-Braille}', "");
Expect(1, 10495, '\P{^Is_Script:   _-Braille}', "");
Expect(0, 10496, '\p{Is_Script:   _-Braille}', "");
Expect(1, 10496, '\p{^Is_Script:   _-Braille}', "");
Expect(1, 10496, '\P{Is_Script:   _-Braille}', "");
Expect(0, 10496, '\P{^Is_Script:   _-Braille}', "");
Error('\p{Is_Sc=:=Brai}');
Error('\P{Is_Sc=:=Brai}');
Expect(1, 10495, '\p{Is_Sc=brai}', "");
Expect(0, 10495, '\p{^Is_Sc=brai}', "");
Expect(0, 10495, '\P{Is_Sc=brai}', "");
Expect(1, 10495, '\P{^Is_Sc=brai}', "");
Expect(0, 10496, '\p{Is_Sc=brai}', "");
Expect(1, 10496, '\p{^Is_Sc=brai}', "");
Expect(1, 10496, '\P{Is_Sc=brai}', "");
Expect(0, 10496, '\P{^Is_Sc=brai}', "");
Expect(1, 10495, '\p{Is_Sc= Brai}', "");
Expect(0, 10495, '\p{^Is_Sc= Brai}', "");
Expect(0, 10495, '\P{Is_Sc= Brai}', "");
Expect(1, 10495, '\P{^Is_Sc= Brai}', "");
Expect(0, 10496, '\p{Is_Sc= Brai}', "");
Expect(1, 10496, '\p{^Is_Sc= Brai}', "");
Expect(1, 10496, '\P{Is_Sc= Brai}', "");
Expect(0, 10496, '\P{^Is_Sc= Brai}', "");
Error('\p{Script:   		BUGINESE:=}');
Error('\P{Script:   		BUGINESE:=}');
Expect(1, 6687, '\p{Script=buginese}', "");
Expect(0, 6687, '\p{^Script=buginese}', "");
Expect(0, 6687, '\P{Script=buginese}', "");
Expect(1, 6687, '\P{^Script=buginese}', "");
Expect(0, 6688, '\p{Script=buginese}', "");
Expect(1, 6688, '\p{^Script=buginese}', "");
Expect(1, 6688, '\P{Script=buginese}', "");
Expect(0, 6688, '\P{^Script=buginese}', "");
Expect(1, 6687, '\p{Script=_ Buginese}', "");
Expect(0, 6687, '\p{^Script=_ Buginese}', "");
Expect(0, 6687, '\P{Script=_ Buginese}', "");
Expect(1, 6687, '\P{^Script=_ Buginese}', "");
Expect(0, 6688, '\p{Script=_ Buginese}', "");
Expect(1, 6688, '\p{^Script=_ Buginese}', "");
Expect(1, 6688, '\P{Script=_ Buginese}', "");
Expect(0, 6688, '\P{^Script=_ Buginese}', "");
Error('\p{Sc=	:=Bugi}');
Error('\P{Sc=	:=Bugi}');
Expect(1, 6687, '\p{Sc: bugi}', "");
Expect(0, 6687, '\p{^Sc: bugi}', "");
Expect(0, 6687, '\P{Sc: bugi}', "");
Expect(1, 6687, '\P{^Sc: bugi}', "");
Expect(0, 6688, '\p{Sc: bugi}', "");
Expect(1, 6688, '\p{^Sc: bugi}', "");
Expect(1, 6688, '\P{Sc: bugi}', "");
Expect(0, 6688, '\P{^Sc: bugi}', "");
Expect(1, 6687, '\p{Sc:	Bugi}', "");
Expect(0, 6687, '\p{^Sc:	Bugi}', "");
Expect(0, 6687, '\P{Sc:	Bugi}', "");
Expect(1, 6687, '\P{^Sc:	Bugi}', "");
Expect(0, 6688, '\p{Sc:	Bugi}', "");
Expect(1, 6688, '\p{^Sc:	Bugi}', "");
Expect(1, 6688, '\P{Sc:	Bugi}', "");
Expect(0, 6688, '\P{^Sc:	Bugi}', "");
Error('\p{Is_Script= :=buginese}');
Error('\P{Is_Script= :=buginese}');
Expect(1, 6687, '\p{Is_Script=buginese}', "");
Expect(0, 6687, '\p{^Is_Script=buginese}', "");
Expect(0, 6687, '\P{Is_Script=buginese}', "");
Expect(1, 6687, '\P{^Is_Script=buginese}', "");
Expect(0, 6688, '\p{Is_Script=buginese}', "");
Expect(1, 6688, '\p{^Is_Script=buginese}', "");
Expect(1, 6688, '\P{Is_Script=buginese}', "");
Expect(0, 6688, '\P{^Is_Script=buginese}', "");
Expect(1, 6687, '\p{Is_Script= 	buginese}', "");
Expect(0, 6687, '\p{^Is_Script= 	buginese}', "");
Expect(0, 6687, '\P{Is_Script= 	buginese}', "");
Expect(1, 6687, '\P{^Is_Script= 	buginese}', "");
Expect(0, 6688, '\p{Is_Script= 	buginese}', "");
Expect(1, 6688, '\p{^Is_Script= 	buginese}', "");
Expect(1, 6688, '\P{Is_Script= 	buginese}', "");
Expect(0, 6688, '\P{^Is_Script= 	buginese}', "");
Error('\p{Is_Sc=/a/ bugi}');
Error('\P{Is_Sc=/a/ bugi}');
Expect(1, 6687, '\p{Is_Sc: bugi}', "");
Expect(0, 6687, '\p{^Is_Sc: bugi}', "");
Expect(0, 6687, '\P{Is_Sc: bugi}', "");
Expect(1, 6687, '\P{^Is_Sc: bugi}', "");
Expect(0, 6688, '\p{Is_Sc: bugi}', "");
Expect(1, 6688, '\p{^Is_Sc: bugi}', "");
Expect(1, 6688, '\P{Is_Sc: bugi}', "");
Expect(0, 6688, '\P{^Is_Sc: bugi}', "");
Expect(1, 6687, '\p{Is_Sc=-	BUGI}', "");
Expect(0, 6687, '\p{^Is_Sc=-	BUGI}', "");
Expect(0, 6687, '\P{Is_Sc=-	BUGI}', "");
Expect(1, 6687, '\P{^Is_Sc=-	BUGI}', "");
Expect(0, 6688, '\p{Is_Sc=-	BUGI}', "");
Expect(1, 6688, '\p{^Is_Sc=-	BUGI}', "");
Expect(1, 6688, '\P{Is_Sc=-	BUGI}', "");
Expect(0, 6688, '\P{^Is_Sc=-	BUGI}', "");
Error('\p{Script=	-buhid/a/}');
Error('\P{Script=	-buhid/a/}');
Expect(1, 5971, '\p{Script=buhid}', "");
Expect(0, 5971, '\p{^Script=buhid}', "");
Expect(0, 5971, '\P{Script=buhid}', "");
Expect(1, 5971, '\P{^Script=buhid}', "");
Expect(0, 5972, '\p{Script=buhid}', "");
Expect(1, 5972, '\p{^Script=buhid}', "");
Expect(1, 5972, '\P{Script=buhid}', "");
Expect(0, 5972, '\P{^Script=buhid}', "");
Expect(1, 5971, '\p{Script=	BUHID}', "");
Expect(0, 5971, '\p{^Script=	BUHID}', "");
Expect(0, 5971, '\P{Script=	BUHID}', "");
Expect(1, 5971, '\P{^Script=	BUHID}', "");
Expect(0, 5972, '\p{Script=	BUHID}', "");
Expect(1, 5972, '\p{^Script=	BUHID}', "");
Expect(1, 5972, '\P{Script=	BUHID}', "");
Expect(0, 5972, '\P{^Script=	BUHID}', "");
Error('\p{Sc:   -	BUHD/a/}');
Error('\P{Sc:   -	BUHD/a/}');
Expect(1, 5971, '\p{Sc=buhd}', "");
Expect(0, 5971, '\p{^Sc=buhd}', "");
Expect(0, 5971, '\P{Sc=buhd}', "");
Expect(1, 5971, '\P{^Sc=buhd}', "");
Expect(0, 5972, '\p{Sc=buhd}', "");
Expect(1, 5972, '\p{^Sc=buhd}', "");
Expect(1, 5972, '\P{Sc=buhd}', "");
Expect(0, 5972, '\P{^Sc=buhd}', "");
Expect(1, 5971, '\p{Sc=		Buhd}', "");
Expect(0, 5971, '\p{^Sc=		Buhd}', "");
Expect(0, 5971, '\P{Sc=		Buhd}', "");
Expect(1, 5971, '\P{^Sc=		Buhd}', "");
Expect(0, 5972, '\p{Sc=		Buhd}', "");
Expect(1, 5972, '\p{^Sc=		Buhd}', "");
Expect(1, 5972, '\P{Sc=		Buhd}', "");
Expect(0, 5972, '\P{^Sc=		Buhd}', "");
Error('\p{Is_Script=:= _buhid}');
Error('\P{Is_Script=:= _buhid}');
Expect(1, 5971, '\p{Is_Script=buhid}', "");
Expect(0, 5971, '\p{^Is_Script=buhid}', "");
Expect(0, 5971, '\P{Is_Script=buhid}', "");
Expect(1, 5971, '\P{^Is_Script=buhid}', "");
Expect(0, 5972, '\p{Is_Script=buhid}', "");
Expect(1, 5972, '\p{^Is_Script=buhid}', "");
Expect(1, 5972, '\P{Is_Script=buhid}', "");
Expect(0, 5972, '\P{^Is_Script=buhid}', "");
Expect(1, 5971, '\p{Is_Script= -Buhid}', "");
Expect(0, 5971, '\p{^Is_Script= -Buhid}', "");
Expect(0, 5971, '\P{Is_Script= -Buhid}', "");
Expect(1, 5971, '\P{^Is_Script= -Buhid}', "");
Expect(0, 5972, '\p{Is_Script= -Buhid}', "");
Expect(1, 5972, '\p{^Is_Script= -Buhid}', "");
Expect(1, 5972, '\P{Is_Script= -Buhid}', "");
Expect(0, 5972, '\P{^Is_Script= -Buhid}', "");
Error('\p{Is_Sc=:=_ Buhd}');
Error('\P{Is_Sc=:=_ Buhd}');
Expect(1, 5971, '\p{Is_Sc=buhd}', "");
Expect(0, 5971, '\p{^Is_Sc=buhd}', "");
Expect(0, 5971, '\P{Is_Sc=buhd}', "");
Expect(1, 5971, '\P{^Is_Sc=buhd}', "");
Expect(0, 5972, '\p{Is_Sc=buhd}', "");
Expect(1, 5972, '\p{^Is_Sc=buhd}', "");
Expect(1, 5972, '\P{Is_Sc=buhd}', "");
Expect(0, 5972, '\P{^Is_Sc=buhd}', "");
Expect(1, 5971, '\p{Is_Sc=	BUHD}', "");
Expect(0, 5971, '\p{^Is_Sc=	BUHD}', "");
Expect(0, 5971, '\P{Is_Sc=	BUHD}', "");
Expect(1, 5971, '\P{^Is_Sc=	BUHD}', "");
Expect(0, 5972, '\p{Is_Sc=	BUHD}', "");
Expect(1, 5972, '\p{^Is_Sc=	BUHD}', "");
Expect(1, 5972, '\P{Is_Sc=	BUHD}', "");
Expect(0, 5972, '\P{^Is_Sc=	BUHD}', "");
Error('\p{Script=/a/	_CHAKMA}');
Error('\P{Script=/a/	_CHAKMA}');
Expect(1, 69955, '\p{Script=chakma}', "");
Expect(0, 69955, '\p{^Script=chakma}', "");
Expect(0, 69955, '\P{Script=chakma}', "");
Expect(1, 69955, '\P{^Script=chakma}', "");
Expect(0, 69956, '\p{Script=chakma}', "");
Expect(1, 69956, '\p{^Script=chakma}', "");
Expect(1, 69956, '\P{Script=chakma}', "");
Expect(0, 69956, '\P{^Script=chakma}', "");
Expect(1, 69955, '\p{Script=- Chakma}', "");
Expect(0, 69955, '\p{^Script=- Chakma}', "");
Expect(0, 69955, '\P{Script=- Chakma}', "");
Expect(1, 69955, '\P{^Script=- Chakma}', "");
Expect(0, 69956, '\p{Script=- Chakma}', "");
Expect(1, 69956, '\p{^Script=- Chakma}', "");
Expect(1, 69956, '\P{Script=- Chakma}', "");
Expect(0, 69956, '\P{^Script=- Chakma}', "");
Error('\p{Sc=:=	Cakm}');
Error('\P{Sc=:=	Cakm}');
Expect(1, 69955, '\p{Sc=cakm}', "");
Expect(0, 69955, '\p{^Sc=cakm}', "");
Expect(0, 69955, '\P{Sc=cakm}', "");
Expect(1, 69955, '\P{^Sc=cakm}', "");
Expect(0, 69956, '\p{Sc=cakm}', "");
Expect(1, 69956, '\p{^Sc=cakm}', "");
Expect(1, 69956, '\P{Sc=cakm}', "");
Expect(0, 69956, '\P{^Sc=cakm}', "");
Expect(1, 69955, '\p{Sc=	-Cakm}', "");
Expect(0, 69955, '\p{^Sc=	-Cakm}', "");
Expect(0, 69955, '\P{Sc=	-Cakm}', "");
Expect(1, 69955, '\P{^Sc=	-Cakm}', "");
Expect(0, 69956, '\p{Sc=	-Cakm}', "");
Expect(1, 69956, '\p{^Sc=	-Cakm}', "");
Expect(1, 69956, '\P{Sc=	-Cakm}', "");
Expect(0, 69956, '\P{^Sc=	-Cakm}', "");
Error('\p{Is_Script=:=_CHAKMA}');
Error('\P{Is_Script=:=_CHAKMA}');
Expect(1, 69955, '\p{Is_Script=chakma}', "");
Expect(0, 69955, '\p{^Is_Script=chakma}', "");
Expect(0, 69955, '\P{Is_Script=chakma}', "");
Expect(1, 69955, '\P{^Is_Script=chakma}', "");
Expect(0, 69956, '\p{Is_Script=chakma}', "");
Expect(1, 69956, '\p{^Is_Script=chakma}', "");
Expect(1, 69956, '\P{Is_Script=chakma}', "");
Expect(0, 69956, '\P{^Is_Script=chakma}', "");
Expect(1, 69955, '\p{Is_Script=_-Chakma}', "");
Expect(0, 69955, '\p{^Is_Script=_-Chakma}', "");
Expect(0, 69955, '\P{Is_Script=_-Chakma}', "");
Expect(1, 69955, '\P{^Is_Script=_-Chakma}', "");
Expect(0, 69956, '\p{Is_Script=_-Chakma}', "");
Expect(1, 69956, '\p{^Is_Script=_-Chakma}', "");
Expect(1, 69956, '\P{Is_Script=_-Chakma}', "");
Expect(0, 69956, '\P{^Is_Script=_-Chakma}', "");
Error('\p{Is_Sc=	Cakm:=}');
Error('\P{Is_Sc=	Cakm:=}');
Expect(1, 69955, '\p{Is_Sc=cakm}', "");
Expect(0, 69955, '\p{^Is_Sc=cakm}', "");
Expect(0, 69955, '\P{Is_Sc=cakm}', "");
Expect(1, 69955, '\P{^Is_Sc=cakm}', "");
Expect(0, 69956, '\p{Is_Sc=cakm}', "");
Expect(1, 69956, '\p{^Is_Sc=cakm}', "");
Expect(1, 69956, '\P{Is_Sc=cakm}', "");
Expect(0, 69956, '\P{^Is_Sc=cakm}', "");
Expect(1, 69955, '\p{Is_Sc=  CAKM}', "");
Expect(0, 69955, '\p{^Is_Sc=  CAKM}', "");
Expect(0, 69955, '\P{Is_Sc=  CAKM}', "");
Expect(1, 69955, '\P{^Is_Sc=  CAKM}', "");
Expect(0, 69956, '\p{Is_Sc=  CAKM}', "");
Expect(1, 69956, '\p{^Is_Sc=  CAKM}', "");
Expect(1, 69956, '\P{Is_Sc=  CAKM}', "");
Expect(0, 69956, '\P{^Is_Sc=  CAKM}', "");
Error('\p{Script=_/a/CANADIAN_aboriginal}');
Error('\P{Script=_/a/CANADIAN_aboriginal}');
Expect(1, 6389, '\p{Script:   canadianaboriginal}', "");
Expect(0, 6389, '\p{^Script:   canadianaboriginal}', "");
Expect(0, 6389, '\P{Script:   canadianaboriginal}', "");
Expect(1, 6389, '\P{^Script:   canadianaboriginal}', "");
Expect(0, 6390, '\p{Script:   canadianaboriginal}', "");
Expect(1, 6390, '\p{^Script:   canadianaboriginal}', "");
Expect(1, 6390, '\P{Script:   canadianaboriginal}', "");
Expect(0, 6390, '\P{^Script:   canadianaboriginal}', "");
Expect(1, 6389, '\p{Script=_	canadian_ABORIGINAL}', "");
Expect(0, 6389, '\p{^Script=_	canadian_ABORIGINAL}', "");
Expect(0, 6389, '\P{Script=_	canadian_ABORIGINAL}', "");
Expect(1, 6389, '\P{^Script=_	canadian_ABORIGINAL}', "");
Expect(0, 6390, '\p{Script=_	canadian_ABORIGINAL}', "");
Expect(1, 6390, '\p{^Script=_	canadian_ABORIGINAL}', "");
Expect(1, 6390, '\P{Script=_	canadian_ABORIGINAL}', "");
Expect(0, 6390, '\P{^Script=_	canadian_ABORIGINAL}', "");
Error('\p{Sc=/a/_cans}');
Error('\P{Sc=/a/_cans}');
Expect(1, 6389, '\p{Sc=cans}', "");
Expect(0, 6389, '\p{^Sc=cans}', "");
Expect(0, 6389, '\P{Sc=cans}', "");
Expect(1, 6389, '\P{^Sc=cans}', "");
Expect(0, 6390, '\p{Sc=cans}', "");
Expect(1, 6390, '\p{^Sc=cans}', "");
Expect(1, 6390, '\P{Sc=cans}', "");
Expect(0, 6390, '\P{^Sc=cans}', "");
Expect(1, 6389, '\p{Sc=_-CANS}', "");
Expect(0, 6389, '\p{^Sc=_-CANS}', "");
Expect(0, 6389, '\P{Sc=_-CANS}', "");
Expect(1, 6389, '\P{^Sc=_-CANS}', "");
Expect(0, 6390, '\p{Sc=_-CANS}', "");
Expect(1, 6390, '\p{^Sc=_-CANS}', "");
Expect(1, 6390, '\P{Sc=_-CANS}', "");
Expect(0, 6390, '\P{^Sc=_-CANS}', "");
Error('\p{Is_Script:   :=	 Canadian_aboriginal}');
Error('\P{Is_Script:   :=	 Canadian_aboriginal}');
Expect(1, 6389, '\p{Is_Script=canadianaboriginal}', "");
Expect(0, 6389, '\p{^Is_Script=canadianaboriginal}', "");
Expect(0, 6389, '\P{Is_Script=canadianaboriginal}', "");
Expect(1, 6389, '\P{^Is_Script=canadianaboriginal}', "");
Expect(0, 6390, '\p{Is_Script=canadianaboriginal}', "");
Expect(1, 6390, '\p{^Is_Script=canadianaboriginal}', "");
Expect(1, 6390, '\P{Is_Script=canadianaboriginal}', "");
Expect(0, 6390, '\P{^Is_Script=canadianaboriginal}', "");
Expect(1, 6389, '\p{Is_Script=canadian_ABORIGINAL}', "");
Expect(0, 6389, '\p{^Is_Script=canadian_ABORIGINAL}', "");
Expect(0, 6389, '\P{Is_Script=canadian_ABORIGINAL}', "");
Expect(1, 6389, '\P{^Is_Script=canadian_ABORIGINAL}', "");
Expect(0, 6390, '\p{Is_Script=canadian_ABORIGINAL}', "");
Expect(1, 6390, '\p{^Is_Script=canadian_ABORIGINAL}', "");
Expect(1, 6390, '\P{Is_Script=canadian_ABORIGINAL}', "");
Expect(0, 6390, '\P{^Is_Script=canadian_ABORIGINAL}', "");
Error('\p{Is_Sc= /a/CANS}');
Error('\P{Is_Sc= /a/CANS}');
Expect(1, 6389, '\p{Is_Sc=cans}', "");
Expect(0, 6389, '\p{^Is_Sc=cans}', "");
Expect(0, 6389, '\P{Is_Sc=cans}', "");
Expect(1, 6389, '\P{^Is_Sc=cans}', "");
Expect(0, 6390, '\p{Is_Sc=cans}', "");
Expect(1, 6390, '\p{^Is_Sc=cans}', "");
Expect(1, 6390, '\P{Is_Sc=cans}', "");
Expect(0, 6390, '\P{^Is_Sc=cans}', "");
Expect(1, 6389, '\p{Is_Sc= 	Cans}', "");
Expect(0, 6389, '\p{^Is_Sc= 	Cans}', "");
Expect(0, 6389, '\P{Is_Sc= 	Cans}', "");
Expect(1, 6389, '\P{^Is_Sc= 	Cans}', "");
Expect(0, 6390, '\p{Is_Sc= 	Cans}', "");
Expect(1, 6390, '\p{^Is_Sc= 	Cans}', "");
Expect(1, 6390, '\P{Is_Sc= 	Cans}', "");
Expect(0, 6390, '\P{^Is_Sc= 	Cans}', "");
Error('\p{Script=:=	_Carian}');
Error('\P{Script=:=	_Carian}');
Expect(1, 66256, '\p{Script=carian}', "");
Expect(0, 66256, '\p{^Script=carian}', "");
Expect(0, 66256, '\P{Script=carian}', "");
Expect(1, 66256, '\P{^Script=carian}', "");
Expect(0, 66257, '\p{Script=carian}', "");
Expect(1, 66257, '\p{^Script=carian}', "");
Expect(1, 66257, '\P{Script=carian}', "");
Expect(0, 66257, '\P{^Script=carian}', "");
Expect(1, 66256, '\p{Script=	_carian}', "");
Expect(0, 66256, '\p{^Script=	_carian}', "");
Expect(0, 66256, '\P{Script=	_carian}', "");
Expect(1, 66256, '\P{^Script=	_carian}', "");
Expect(0, 66257, '\p{Script=	_carian}', "");
Expect(1, 66257, '\p{^Script=	_carian}', "");
Expect(1, 66257, '\P{Script=	_carian}', "");
Expect(0, 66257, '\P{^Script=	_carian}', "");
Error('\p{Sc=	 Cari/a/}');
Error('\P{Sc=	 Cari/a/}');
Expect(1, 66256, '\p{Sc=cari}', "");
Expect(0, 66256, '\p{^Sc=cari}', "");
Expect(0, 66256, '\P{Sc=cari}', "");
Expect(1, 66256, '\P{^Sc=cari}', "");
Expect(0, 66257, '\p{Sc=cari}', "");
Expect(1, 66257, '\p{^Sc=cari}', "");
Expect(1, 66257, '\P{Sc=cari}', "");
Expect(0, 66257, '\P{^Sc=cari}', "");
Expect(1, 66256, '\p{Sc=- Cari}', "");
Expect(0, 66256, '\p{^Sc=- Cari}', "");
Expect(0, 66256, '\P{Sc=- Cari}', "");
Expect(1, 66256, '\P{^Sc=- Cari}', "");
Expect(0, 66257, '\p{Sc=- Cari}', "");
Expect(1, 66257, '\p{^Sc=- Cari}', "");
Expect(1, 66257, '\P{Sc=- Cari}', "");
Expect(0, 66257, '\P{^Sc=- Cari}', "");
Error('\p{Is_Script=_carian:=}');
Error('\P{Is_Script=_carian:=}');
Expect(1, 66256, '\p{Is_Script=carian}', "");
Expect(0, 66256, '\p{^Is_Script=carian}', "");
Expect(0, 66256, '\P{Is_Script=carian}', "");
Expect(1, 66256, '\P{^Is_Script=carian}', "");
Expect(0, 66257, '\p{Is_Script=carian}', "");
Expect(1, 66257, '\p{^Is_Script=carian}', "");
Expect(1, 66257, '\P{Is_Script=carian}', "");
Expect(0, 66257, '\P{^Is_Script=carian}', "");
Expect(1, 66256, '\p{Is_Script:-	Carian}', "");
Expect(0, 66256, '\p{^Is_Script:-	Carian}', "");
Expect(0, 66256, '\P{Is_Script:-	Carian}', "");
Expect(1, 66256, '\P{^Is_Script:-	Carian}', "");
Expect(0, 66257, '\p{Is_Script:-	Carian}', "");
Expect(1, 66257, '\p{^Is_Script:-	Carian}', "");
Expect(1, 66257, '\P{Is_Script:-	Carian}', "");
Expect(0, 66257, '\P{^Is_Script:-	Carian}', "");
Error('\p{Is_Sc:  /a/Cari}');
Error('\P{Is_Sc:  /a/Cari}');
Expect(1, 66256, '\p{Is_Sc=cari}', "");
Expect(0, 66256, '\p{^Is_Sc=cari}', "");
Expect(0, 66256, '\P{Is_Sc=cari}', "");
Expect(1, 66256, '\P{^Is_Sc=cari}', "");
Expect(0, 66257, '\p{Is_Sc=cari}', "");
Expect(1, 66257, '\p{^Is_Sc=cari}', "");
Expect(1, 66257, '\P{Is_Sc=cari}', "");
Expect(0, 66257, '\P{^Is_Sc=cari}', "");
Expect(1, 66256, '\p{Is_Sc= Cari}', "");
Expect(0, 66256, '\p{^Is_Sc= Cari}', "");
Expect(0, 66256, '\P{Is_Sc= Cari}', "");
Expect(1, 66256, '\P{^Is_Sc= Cari}', "");
Expect(0, 66257, '\p{Is_Sc= Cari}', "");
Expect(1, 66257, '\p{^Is_Sc= Cari}', "");
Expect(1, 66257, '\P{Is_Sc= Cari}', "");
Expect(0, 66257, '\P{^Is_Sc= Cari}', "");
Error('\p{Script=- CHAM:=}');
Error('\P{Script=- CHAM:=}');
Expect(1, 43615, '\p{Script:   cham}', "");
Expect(0, 43615, '\p{^Script:   cham}', "");
Expect(0, 43615, '\P{Script:   cham}', "");
Expect(1, 43615, '\P{^Script:   cham}', "");
Expect(0, 43616, '\p{Script:   cham}', "");
Expect(1, 43616, '\p{^Script:   cham}', "");
Expect(1, 43616, '\P{Script:   cham}', "");
Expect(0, 43616, '\P{^Script:   cham}', "");
Expect(1, 43615, '\p{Script= -cham}', "");
Expect(0, 43615, '\p{^Script= -cham}', "");
Expect(0, 43615, '\P{Script= -cham}', "");
Expect(1, 43615, '\P{^Script= -cham}', "");
Expect(0, 43616, '\p{Script= -cham}', "");
Expect(1, 43616, '\p{^Script= -cham}', "");
Expect(1, 43616, '\P{Script= -cham}', "");
Expect(0, 43616, '\P{^Script= -cham}', "");
Error('\p{Sc=__Cham/a/}');
Error('\P{Sc=__Cham/a/}');
Expect(1, 43615, '\p{Sc=cham}', "");
Expect(0, 43615, '\p{^Sc=cham}', "");
Expect(0, 43615, '\P{Sc=cham}', "");
Expect(1, 43615, '\P{^Sc=cham}', "");
Expect(0, 43616, '\p{Sc=cham}', "");
Expect(1, 43616, '\p{^Sc=cham}', "");
Expect(1, 43616, '\P{Sc=cham}', "");
Expect(0, 43616, '\P{^Sc=cham}', "");
Expect(1, 43615, '\p{Sc=-CHAM}', "");
Expect(0, 43615, '\p{^Sc=-CHAM}', "");
Expect(0, 43615, '\P{Sc=-CHAM}', "");
Expect(1, 43615, '\P{^Sc=-CHAM}', "");
Expect(0, 43616, '\p{Sc=-CHAM}', "");
Expect(1, 43616, '\p{^Sc=-CHAM}', "");
Expect(1, 43616, '\P{Sc=-CHAM}', "");
Expect(0, 43616, '\P{^Sc=-CHAM}', "");
Error('\p{Is_Script= /a/Cham}');
Error('\P{Is_Script= /a/Cham}');
Expect(1, 43615, '\p{Is_Script=cham}', "");
Expect(0, 43615, '\p{^Is_Script=cham}', "");
Expect(0, 43615, '\P{Is_Script=cham}', "");
Expect(1, 43615, '\P{^Is_Script=cham}', "");
Expect(0, 43616, '\p{Is_Script=cham}', "");
Expect(1, 43616, '\p{^Is_Script=cham}', "");
Expect(1, 43616, '\P{Is_Script=cham}', "");
Expect(0, 43616, '\P{^Is_Script=cham}', "");
Expect(1, 43615, '\p{Is_Script=-_Cham}', "");
Expect(0, 43615, '\p{^Is_Script=-_Cham}', "");
Expect(0, 43615, '\P{Is_Script=-_Cham}', "");
Expect(1, 43615, '\P{^Is_Script=-_Cham}', "");
Expect(0, 43616, '\p{Is_Script=-_Cham}', "");
Expect(1, 43616, '\p{^Is_Script=-_Cham}', "");
Expect(1, 43616, '\P{Is_Script=-_Cham}', "");
Expect(0, 43616, '\P{^Is_Script=-_Cham}', "");
Error('\p{Is_Sc: -/a/Cham}');
Error('\P{Is_Sc: -/a/Cham}');
Expect(1, 43615, '\p{Is_Sc=cham}', "");
Expect(0, 43615, '\p{^Is_Sc=cham}', "");
Expect(0, 43615, '\P{Is_Sc=cham}', "");
Expect(1, 43615, '\P{^Is_Sc=cham}', "");
Expect(0, 43616, '\p{Is_Sc=cham}', "");
Expect(1, 43616, '\p{^Is_Sc=cham}', "");
Expect(1, 43616, '\P{Is_Sc=cham}', "");
Expect(0, 43616, '\P{^Is_Sc=cham}', "");
Expect(1, 43615, '\p{Is_Sc:  -Cham}', "");
Expect(0, 43615, '\p{^Is_Sc:  -Cham}', "");
Expect(0, 43615, '\P{Is_Sc:  -Cham}', "");
Expect(1, 43615, '\P{^Is_Sc:  -Cham}', "");
Expect(0, 43616, '\p{Is_Sc:  -Cham}', "");
Expect(1, 43616, '\p{^Is_Sc:  -Cham}', "");
Expect(1, 43616, '\P{Is_Sc:  -Cham}', "");
Expect(0, 43616, '\P{^Is_Sc:  -Cham}', "");
Error('\p{Script:	/a/	CHEROKEE}');
Error('\P{Script:	/a/	CHEROKEE}');
Expect(1, 5108, '\p{Script: cherokee}', "");
Expect(0, 5108, '\p{^Script: cherokee}', "");
Expect(0, 5108, '\P{Script: cherokee}', "");
Expect(1, 5108, '\P{^Script: cherokee}', "");
Expect(0, 5109, '\p{Script: cherokee}', "");
Expect(1, 5109, '\p{^Script: cherokee}', "");
Expect(1, 5109, '\P{Script: cherokee}', "");
Expect(0, 5109, '\P{^Script: cherokee}', "");
Expect(1, 5108, '\p{Script=--CHEROKEE}', "");
Expect(0, 5108, '\p{^Script=--CHEROKEE}', "");
Expect(0, 5108, '\P{Script=--CHEROKEE}', "");
Expect(1, 5108, '\P{^Script=--CHEROKEE}', "");
Expect(0, 5109, '\p{Script=--CHEROKEE}', "");
Expect(1, 5109, '\p{^Script=--CHEROKEE}', "");
Expect(1, 5109, '\P{Script=--CHEROKEE}', "");
Expect(0, 5109, '\P{^Script=--CHEROKEE}', "");
Error('\p{Sc=_:=cher}');
Error('\P{Sc=_:=cher}');
Expect(1, 5108, '\p{Sc=cher}', "");
Expect(0, 5108, '\p{^Sc=cher}', "");
Expect(0, 5108, '\P{Sc=cher}', "");
Expect(1, 5108, '\P{^Sc=cher}', "");
Expect(0, 5109, '\p{Sc=cher}', "");
Expect(1, 5109, '\p{^Sc=cher}', "");
Expect(1, 5109, '\P{Sc=cher}', "");
Expect(0, 5109, '\P{^Sc=cher}', "");
Expect(1, 5108, '\p{Sc= _cher}', "");
Expect(0, 5108, '\p{^Sc= _cher}', "");
Expect(0, 5108, '\P{Sc= _cher}', "");
Expect(1, 5108, '\P{^Sc= _cher}', "");
Expect(0, 5109, '\p{Sc= _cher}', "");
Expect(1, 5109, '\p{^Sc= _cher}', "");
Expect(1, 5109, '\P{Sc= _cher}', "");
Expect(0, 5109, '\P{^Sc= _cher}', "");
Error('\p{Is_Script=		Cherokee:=}');
Error('\P{Is_Script=		Cherokee:=}');
Expect(1, 5108, '\p{Is_Script=cherokee}', "");
Expect(0, 5108, '\p{^Is_Script=cherokee}', "");
Expect(0, 5108, '\P{Is_Script=cherokee}', "");
Expect(1, 5108, '\P{^Is_Script=cherokee}', "");
Expect(0, 5109, '\p{Is_Script=cherokee}', "");
Expect(1, 5109, '\p{^Is_Script=cherokee}', "");
Expect(1, 5109, '\P{Is_Script=cherokee}', "");
Expect(0, 5109, '\P{^Is_Script=cherokee}', "");
Expect(1, 5108, '\p{Is_Script=__cherokee}', "");
Expect(0, 5108, '\p{^Is_Script=__cherokee}', "");
Expect(0, 5108, '\P{Is_Script=__cherokee}', "");
Expect(1, 5108, '\P{^Is_Script=__cherokee}', "");
Expect(0, 5109, '\p{Is_Script=__cherokee}', "");
Expect(1, 5109, '\p{^Is_Script=__cherokee}', "");
Expect(1, 5109, '\P{Is_Script=__cherokee}', "");
Expect(0, 5109, '\P{^Is_Script=__cherokee}', "");
Error('\p{Is_Sc=  CHER/a/}');
Error('\P{Is_Sc=  CHER/a/}');
Expect(1, 5108, '\p{Is_Sc=cher}', "");
Expect(0, 5108, '\p{^Is_Sc=cher}', "");
Expect(0, 5108, '\P{Is_Sc=cher}', "");
Expect(1, 5108, '\P{^Is_Sc=cher}', "");
Expect(0, 5109, '\p{Is_Sc=cher}', "");
Expect(1, 5109, '\p{^Is_Sc=cher}', "");
Expect(1, 5109, '\P{Is_Sc=cher}', "");
Expect(0, 5109, '\P{^Is_Sc=cher}', "");
Expect(1, 5108, '\p{Is_Sc= Cher}', "");
Expect(0, 5108, '\p{^Is_Sc= Cher}', "");
Expect(0, 5108, '\P{Is_Sc= Cher}', "");
Expect(1, 5108, '\P{^Is_Sc= Cher}', "");
Expect(0, 5109, '\p{Is_Sc= Cher}', "");
Expect(1, 5109, '\p{^Is_Sc= Cher}', "");
Expect(1, 5109, '\P{Is_Sc= Cher}', "");
Expect(0, 5109, '\P{^Is_Sc= Cher}', "");
Error('\p{Script= Coptic/a/}');
Error('\P{Script= Coptic/a/}');
Expect(1, 11519, '\p{Script=coptic}', "");
Expect(0, 11519, '\p{^Script=coptic}', "");
Expect(0, 11519, '\P{Script=coptic}', "");
Expect(1, 11519, '\P{^Script=coptic}', "");
Expect(0, 11520, '\p{Script=coptic}', "");
Expect(1, 11520, '\p{^Script=coptic}', "");
Expect(1, 11520, '\P{Script=coptic}', "");
Expect(0, 11520, '\P{^Script=coptic}', "");
Expect(1, 11519, '\p{Script=Coptic}', "");
Expect(0, 11519, '\p{^Script=Coptic}', "");
Expect(0, 11519, '\P{Script=Coptic}', "");
Expect(1, 11519, '\P{^Script=Coptic}', "");
Expect(0, 11520, '\p{Script=Coptic}', "");
Expect(1, 11520, '\p{^Script=Coptic}', "");
Expect(1, 11520, '\P{Script=Coptic}', "");
Expect(0, 11520, '\P{^Script=Coptic}', "");
Error('\p{Sc=:= copt}');
Error('\P{Sc=:= copt}');
Expect(1, 11519, '\p{Sc=copt}', "");
Expect(0, 11519, '\p{^Sc=copt}', "");
Expect(0, 11519, '\P{Sc=copt}', "");
Expect(1, 11519, '\P{^Sc=copt}', "");
Expect(0, 11520, '\p{Sc=copt}', "");
Expect(1, 11520, '\p{^Sc=copt}', "");
Expect(1, 11520, '\P{Sc=copt}', "");
Expect(0, 11520, '\P{^Sc=copt}', "");
Expect(1, 11519, '\p{Sc=-	Copt}', "");
Expect(0, 11519, '\p{^Sc=-	Copt}', "");
Expect(0, 11519, '\P{Sc=-	Copt}', "");
Expect(1, 11519, '\P{^Sc=-	Copt}', "");
Expect(0, 11520, '\p{Sc=-	Copt}', "");
Expect(1, 11520, '\p{^Sc=-	Copt}', "");
Expect(1, 11520, '\P{Sc=-	Copt}', "");
Expect(0, 11520, '\P{^Sc=-	Copt}', "");
Error('\p{Is_Script=		qaac/a/}');
Error('\P{Is_Script=		qaac/a/}');
Expect(1, 11519, '\p{Is_Script=qaac}', "");
Expect(0, 11519, '\p{^Is_Script=qaac}', "");
Expect(0, 11519, '\P{Is_Script=qaac}', "");
Expect(1, 11519, '\P{^Is_Script=qaac}', "");
Expect(0, 11520, '\p{Is_Script=qaac}', "");
Expect(1, 11520, '\p{^Is_Script=qaac}', "");
Expect(1, 11520, '\P{Is_Script=qaac}', "");
Expect(0, 11520, '\P{^Is_Script=qaac}', "");
Expect(1, 11519, '\p{Is_Script=	Qaac}', "");
Expect(0, 11519, '\p{^Is_Script=	Qaac}', "");
Expect(0, 11519, '\P{Is_Script=	Qaac}', "");
Expect(1, 11519, '\P{^Is_Script=	Qaac}', "");
Expect(0, 11520, '\p{Is_Script=	Qaac}', "");
Expect(1, 11520, '\p{^Is_Script=	Qaac}', "");
Expect(1, 11520, '\P{Is_Script=	Qaac}', "");
Expect(0, 11520, '\P{^Is_Script=	Qaac}', "");
Error('\p{Is_Sc=/a/ COPTIC}');
Error('\P{Is_Sc=/a/ COPTIC}');
Expect(1, 11519, '\p{Is_Sc=coptic}', "");
Expect(0, 11519, '\p{^Is_Sc=coptic}', "");
Expect(0, 11519, '\P{Is_Sc=coptic}', "");
Expect(1, 11519, '\P{^Is_Sc=coptic}', "");
Expect(0, 11520, '\p{Is_Sc=coptic}', "");
Expect(1, 11520, '\p{^Is_Sc=coptic}', "");
Expect(1, 11520, '\P{Is_Sc=coptic}', "");
Expect(0, 11520, '\P{^Is_Sc=coptic}', "");
Expect(1, 11519, '\p{Is_Sc=_COPTIC}', "");
Expect(0, 11519, '\p{^Is_Sc=_COPTIC}', "");
Expect(0, 11519, '\P{Is_Sc=_COPTIC}', "");
Expect(1, 11519, '\P{^Is_Sc=_COPTIC}', "");
Expect(0, 11520, '\p{Is_Sc=_COPTIC}', "");
Expect(1, 11520, '\p{^Is_Sc=_COPTIC}', "");
Expect(1, 11520, '\P{Is_Sc=_COPTIC}', "");
Expect(0, 11520, '\P{^Is_Sc=_COPTIC}', "");
Error('\p{Script=_-Cypriot/a/}');
Error('\P{Script=_-Cypriot/a/}');
Expect(1, 67647, '\p{Script=cypriot}', "");
Expect(0, 67647, '\p{^Script=cypriot}', "");
Expect(0, 67647, '\P{Script=cypriot}', "");
Expect(1, 67647, '\P{^Script=cypriot}', "");
Expect(0, 67648, '\p{Script=cypriot}', "");
Expect(1, 67648, '\p{^Script=cypriot}', "");
Expect(1, 67648, '\P{Script=cypriot}', "");
Expect(0, 67648, '\P{^Script=cypriot}', "");
Expect(1, 67647, '\p{Script=-Cypriot}', "");
Expect(0, 67647, '\p{^Script=-Cypriot}', "");
Expect(0, 67647, '\P{Script=-Cypriot}', "");
Expect(1, 67647, '\P{^Script=-Cypriot}', "");
Expect(0, 67648, '\p{Script=-Cypriot}', "");
Expect(1, 67648, '\p{^Script=-Cypriot}', "");
Expect(1, 67648, '\P{Script=-Cypriot}', "");
Expect(0, 67648, '\P{^Script=-Cypriot}', "");
Error('\p{Sc=/a/-Cprt}');
Error('\P{Sc=/a/-Cprt}');
Expect(1, 67647, '\p{Sc=cprt}', "");
Expect(0, 67647, '\p{^Sc=cprt}', "");
Expect(0, 67647, '\P{Sc=cprt}', "");
Expect(1, 67647, '\P{^Sc=cprt}', "");
Expect(0, 67648, '\p{Sc=cprt}', "");
Expect(1, 67648, '\p{^Sc=cprt}', "");
Expect(1, 67648, '\P{Sc=cprt}', "");
Expect(0, 67648, '\P{^Sc=cprt}', "");
Expect(1, 67647, '\p{Sc:  Cprt}', "");
Expect(0, 67647, '\p{^Sc:  Cprt}', "");
Expect(0, 67647, '\P{Sc:  Cprt}', "");
Expect(1, 67647, '\P{^Sc:  Cprt}', "");
Expect(0, 67648, '\p{Sc:  Cprt}', "");
Expect(1, 67648, '\p{^Sc:  Cprt}', "");
Expect(1, 67648, '\P{Sc:  Cprt}', "");
Expect(0, 67648, '\P{^Sc:  Cprt}', "");
Error('\p{Is_Script:   /a/	_Cypriot}');
Error('\P{Is_Script:   /a/	_Cypriot}');
Expect(1, 67647, '\p{Is_Script=cypriot}', "");
Expect(0, 67647, '\p{^Is_Script=cypriot}', "");
Expect(0, 67647, '\P{Is_Script=cypriot}', "");
Expect(1, 67647, '\P{^Is_Script=cypriot}', "");
Expect(0, 67648, '\p{Is_Script=cypriot}', "");
Expect(1, 67648, '\p{^Is_Script=cypriot}', "");
Expect(1, 67648, '\P{Is_Script=cypriot}', "");
Expect(0, 67648, '\P{^Is_Script=cypriot}', "");
Expect(1, 67647, '\p{Is_Script= _Cypriot}', "");
Expect(0, 67647, '\p{^Is_Script= _Cypriot}', "");
Expect(0, 67647, '\P{Is_Script= _Cypriot}', "");
Expect(1, 67647, '\P{^Is_Script= _Cypriot}', "");
Expect(0, 67648, '\p{Is_Script= _Cypriot}', "");
Expect(1, 67648, '\p{^Is_Script= _Cypriot}', "");
Expect(1, 67648, '\P{Is_Script= _Cypriot}', "");
Expect(0, 67648, '\P{^Is_Script= _Cypriot}', "");
Error('\p{Is_Sc=_/a/Cprt}');
Error('\P{Is_Sc=_/a/Cprt}');
Expect(1, 67647, '\p{Is_Sc=cprt}', "");
Expect(0, 67647, '\p{^Is_Sc=cprt}', "");
Expect(0, 67647, '\P{Is_Sc=cprt}', "");
Expect(1, 67647, '\P{^Is_Sc=cprt}', "");
Expect(0, 67648, '\p{Is_Sc=cprt}', "");
Expect(1, 67648, '\p{^Is_Sc=cprt}', "");
Expect(1, 67648, '\P{Is_Sc=cprt}', "");
Expect(0, 67648, '\P{^Is_Sc=cprt}', "");
Expect(1, 67647, '\p{Is_Sc=_-Cprt}', "");
Expect(0, 67647, '\p{^Is_Sc=_-Cprt}', "");
Expect(0, 67647, '\P{Is_Sc=_-Cprt}', "");
Expect(1, 67647, '\P{^Is_Sc=_-Cprt}', "");
Expect(0, 67648, '\p{Is_Sc=_-Cprt}', "");
Expect(1, 67648, '\p{^Is_Sc=_-Cprt}', "");
Expect(1, 67648, '\P{Is_Sc=_-Cprt}', "");
Expect(0, 67648, '\P{^Is_Sc=_-Cprt}', "");
Error('\p{Script=	:=cyrillic}');
Error('\P{Script=	:=cyrillic}');
Expect(1, 42655, '\p{Script=cyrillic}', "");
Expect(0, 42655, '\p{^Script=cyrillic}', "");
Expect(0, 42655, '\P{Script=cyrillic}', "");
Expect(1, 42655, '\P{^Script=cyrillic}', "");
Expect(0, 42656, '\p{Script=cyrillic}', "");
Expect(1, 42656, '\p{^Script=cyrillic}', "");
Expect(1, 42656, '\P{Script=cyrillic}', "");
Expect(0, 42656, '\P{^Script=cyrillic}', "");
Expect(1, 42655, '\p{Script= Cyrillic}', "");
Expect(0, 42655, '\p{^Script= Cyrillic}', "");
Expect(0, 42655, '\P{Script= Cyrillic}', "");
Expect(1, 42655, '\P{^Script= Cyrillic}', "");
Expect(0, 42656, '\p{Script= Cyrillic}', "");
Expect(1, 42656, '\p{^Script= Cyrillic}', "");
Expect(1, 42656, '\P{Script= Cyrillic}', "");
Expect(0, 42656, '\P{^Script= Cyrillic}', "");
Error('\p{Sc=_	Cyrl/a/}');
Error('\P{Sc=_	Cyrl/a/}');
Expect(1, 42655, '\p{Sc=cyrl}', "");
Expect(0, 42655, '\p{^Sc=cyrl}', "");
Expect(0, 42655, '\P{Sc=cyrl}', "");
Expect(1, 42655, '\P{^Sc=cyrl}', "");
Expect(0, 42656, '\p{Sc=cyrl}', "");
Expect(1, 42656, '\p{^Sc=cyrl}', "");
Expect(1, 42656, '\P{Sc=cyrl}', "");
Expect(0, 42656, '\P{^Sc=cyrl}', "");
Expect(1, 42655, '\p{Sc=- cyrl}', "");
Expect(0, 42655, '\p{^Sc=- cyrl}', "");
Expect(0, 42655, '\P{Sc=- cyrl}', "");
Expect(1, 42655, '\P{^Sc=- cyrl}', "");
Expect(0, 42656, '\p{Sc=- cyrl}', "");
Expect(1, 42656, '\p{^Sc=- cyrl}', "");
Expect(1, 42656, '\P{Sc=- cyrl}', "");
Expect(0, 42656, '\P{^Sc=- cyrl}', "");
Error('\p{Is_Script=__Cyrillic/a/}');
Error('\P{Is_Script=__Cyrillic/a/}');
Expect(1, 42655, '\p{Is_Script=cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script=cyrillic}', "");
Expect(0, 42655, '\P{Is_Script=cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script=cyrillic}', "");
Expect(0, 42656, '\p{Is_Script=cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script=cyrillic}', "");
Expect(1, 42656, '\P{Is_Script=cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script=cyrillic}', "");
Expect(1, 42655, '\p{Is_Script:_Cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script:_Cyrillic}', "");
Expect(0, 42655, '\P{Is_Script:_Cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script:_Cyrillic}', "");
Expect(0, 42656, '\p{Is_Script:_Cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script:_Cyrillic}', "");
Expect(1, 42656, '\P{Is_Script:_Cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script:_Cyrillic}', "");
Error('\p{Is_Sc=- cyrl:=}');
Error('\P{Is_Sc=- cyrl:=}');
Expect(1, 42655, '\p{Is_Sc:   cyrl}', "");
Expect(0, 42655, '\p{^Is_Sc:   cyrl}', "");
Expect(0, 42655, '\P{Is_Sc:   cyrl}', "");
Expect(1, 42655, '\P{^Is_Sc:   cyrl}', "");
Expect(0, 42656, '\p{Is_Sc:   cyrl}', "");
Expect(1, 42656, '\p{^Is_Sc:   cyrl}', "");
Expect(1, 42656, '\P{Is_Sc:   cyrl}', "");
Expect(0, 42656, '\P{^Is_Sc:   cyrl}', "");
Expect(1, 42655, '\p{Is_Sc=--CYRL}', "");
Expect(0, 42655, '\p{^Is_Sc=--CYRL}', "");
Expect(0, 42655, '\P{Is_Sc=--CYRL}', "");
Expect(1, 42655, '\P{^Is_Sc=--CYRL}', "");
Expect(0, 42656, '\p{Is_Sc=--CYRL}', "");
Expect(1, 42656, '\p{^Is_Sc=--CYRL}', "");
Expect(1, 42656, '\P{Is_Sc=--CYRL}', "");
Expect(0, 42656, '\P{^Is_Sc=--CYRL}', "");
Error('\p{Script=/a/	-devanagari}');
Error('\P{Script=/a/	-devanagari}');
Expect(1, 43259, '\p{Script=devanagari}', "");
Expect(0, 43259, '\p{^Script=devanagari}', "");
Expect(0, 43259, '\P{Script=devanagari}', "");
Expect(1, 43259, '\P{^Script=devanagari}', "");
Expect(0, 43260, '\p{Script=devanagari}', "");
Expect(1, 43260, '\p{^Script=devanagari}', "");
Expect(1, 43260, '\P{Script=devanagari}', "");
Expect(0, 43260, '\P{^Script=devanagari}', "");
Expect(1, 43259, '\p{Script= _DEVANAGARI}', "");
Expect(0, 43259, '\p{^Script= _DEVANAGARI}', "");
Expect(0, 43259, '\P{Script= _DEVANAGARI}', "");
Expect(1, 43259, '\P{^Script= _DEVANAGARI}', "");
Expect(0, 43260, '\p{Script= _DEVANAGARI}', "");
Expect(1, 43260, '\p{^Script= _DEVANAGARI}', "");
Expect(1, 43260, '\P{Script= _DEVANAGARI}', "");
Expect(0, 43260, '\P{^Script= _DEVANAGARI}', "");
Error('\p{Sc:   /a/  DEVA}');
Error('\P{Sc:   /a/  DEVA}');
Expect(1, 43259, '\p{Sc=deva}', "");
Expect(0, 43259, '\p{^Sc=deva}', "");
Expect(0, 43259, '\P{Sc=deva}', "");
Expect(1, 43259, '\P{^Sc=deva}', "");
Expect(0, 43260, '\p{Sc=deva}', "");
Expect(1, 43260, '\p{^Sc=deva}', "");
Expect(1, 43260, '\P{Sc=deva}', "");
Expect(0, 43260, '\P{^Sc=deva}', "");
Expect(1, 43259, '\p{Sc= Deva}', "");
Expect(0, 43259, '\p{^Sc= Deva}', "");
Expect(0, 43259, '\P{Sc= Deva}', "");
Expect(1, 43259, '\P{^Sc= Deva}', "");
Expect(0, 43260, '\p{Sc= Deva}', "");
Expect(1, 43260, '\p{^Sc= Deva}', "");
Expect(1, 43260, '\P{Sc= Deva}', "");
Expect(0, 43260, '\P{^Sc= Deva}', "");
Error('\p{Is_Script:    Devanagari/a/}');
Error('\P{Is_Script:    Devanagari/a/}');
Expect(1, 43259, '\p{Is_Script=devanagari}', "");
Expect(0, 43259, '\p{^Is_Script=devanagari}', "");
Expect(0, 43259, '\P{Is_Script=devanagari}', "");
Expect(1, 43259, '\P{^Is_Script=devanagari}', "");
Expect(0, 43260, '\p{Is_Script=devanagari}', "");
Expect(1, 43260, '\p{^Is_Script=devanagari}', "");
Expect(1, 43260, '\P{Is_Script=devanagari}', "");
Expect(0, 43260, '\P{^Is_Script=devanagari}', "");
Expect(1, 43259, '\p{Is_Script=--devanagari}', "");
Expect(0, 43259, '\p{^Is_Script=--devanagari}', "");
Expect(0, 43259, '\P{Is_Script=--devanagari}', "");
Expect(1, 43259, '\P{^Is_Script=--devanagari}', "");
Expect(0, 43260, '\p{Is_Script=--devanagari}', "");
Expect(1, 43260, '\p{^Is_Script=--devanagari}', "");
Expect(1, 43260, '\P{Is_Script=--devanagari}', "");
Expect(0, 43260, '\P{^Is_Script=--devanagari}', "");
Error('\p{Is_Sc=/a/		DEVA}');
Error('\P{Is_Sc=/a/		DEVA}');
Expect(1, 43259, '\p{Is_Sc=deva}', "");
Expect(0, 43259, '\p{^Is_Sc=deva}', "");
Expect(0, 43259, '\P{Is_Sc=deva}', "");
Expect(1, 43259, '\P{^Is_Sc=deva}', "");
Expect(0, 43260, '\p{Is_Sc=deva}', "");
Expect(1, 43260, '\p{^Is_Sc=deva}', "");
Expect(1, 43260, '\P{Is_Sc=deva}', "");
Expect(0, 43260, '\P{^Is_Sc=deva}', "");
Expect(1, 43259, '\p{Is_Sc=	 DEVA}', "");
Expect(0, 43259, '\p{^Is_Sc=	 DEVA}', "");
Expect(0, 43259, '\P{Is_Sc=	 DEVA}', "");
Expect(1, 43259, '\P{^Is_Sc=	 DEVA}', "");
Expect(0, 43260, '\p{Is_Sc=	 DEVA}', "");
Expect(1, 43260, '\p{^Is_Sc=	 DEVA}', "");
Expect(1, 43260, '\P{Is_Sc=	 DEVA}', "");
Expect(0, 43260, '\P{^Is_Sc=	 DEVA}', "");
Error('\p{Script=  Deseret:=}');
Error('\P{Script=  Deseret:=}');
Expect(1, 66639, '\p{Script=deseret}', "");
Expect(0, 66639, '\p{^Script=deseret}', "");
Expect(0, 66639, '\P{Script=deseret}', "");
Expect(1, 66639, '\P{^Script=deseret}', "");
Expect(0, 66640, '\p{Script=deseret}', "");
Expect(1, 66640, '\p{^Script=deseret}', "");
Expect(1, 66640, '\P{Script=deseret}', "");
Expect(0, 66640, '\P{^Script=deseret}', "");
Expect(1, 66639, '\p{Script= 	Deseret}', "");
Expect(0, 66639, '\p{^Script= 	Deseret}', "");
Expect(0, 66639, '\P{Script= 	Deseret}', "");
Expect(1, 66639, '\P{^Script= 	Deseret}', "");
Expect(0, 66640, '\p{Script= 	Deseret}', "");
Expect(1, 66640, '\p{^Script= 	Deseret}', "");
Expect(1, 66640, '\P{Script= 	Deseret}', "");
Expect(0, 66640, '\P{^Script= 	Deseret}', "");
Error('\p{Sc=_Dsrt:=}');
Error('\P{Sc=_Dsrt:=}');
Expect(1, 66639, '\p{Sc=dsrt}', "");
Expect(0, 66639, '\p{^Sc=dsrt}', "");
Expect(0, 66639, '\P{Sc=dsrt}', "");
Expect(1, 66639, '\P{^Sc=dsrt}', "");
Expect(0, 66640, '\p{Sc=dsrt}', "");
Expect(1, 66640, '\p{^Sc=dsrt}', "");
Expect(1, 66640, '\P{Sc=dsrt}', "");
Expect(0, 66640, '\P{^Sc=dsrt}', "");
Expect(1, 66639, '\p{Sc=_-DSRT}', "");
Expect(0, 66639, '\p{^Sc=_-DSRT}', "");
Expect(0, 66639, '\P{Sc=_-DSRT}', "");
Expect(1, 66639, '\P{^Sc=_-DSRT}', "");
Expect(0, 66640, '\p{Sc=_-DSRT}', "");
Expect(1, 66640, '\p{^Sc=_-DSRT}', "");
Expect(1, 66640, '\P{Sc=_-DSRT}', "");
Expect(0, 66640, '\P{^Sc=_-DSRT}', "");
Error('\p{Is_Script=/a/-	deseret}');
Error('\P{Is_Script=/a/-	deseret}');
Expect(1, 66639, '\p{Is_Script=deseret}', "");
Expect(0, 66639, '\p{^Is_Script=deseret}', "");
Expect(0, 66639, '\P{Is_Script=deseret}', "");
Expect(1, 66639, '\P{^Is_Script=deseret}', "");
Expect(0, 66640, '\p{Is_Script=deseret}', "");
Expect(1, 66640, '\p{^Is_Script=deseret}', "");
Expect(1, 66640, '\P{Is_Script=deseret}', "");
Expect(0, 66640, '\P{^Is_Script=deseret}', "");
Expect(1, 66639, '\p{Is_Script= 	deseret}', "");
Expect(0, 66639, '\p{^Is_Script= 	deseret}', "");
Expect(0, 66639, '\P{Is_Script= 	deseret}', "");
Expect(1, 66639, '\P{^Is_Script= 	deseret}', "");
Expect(0, 66640, '\p{Is_Script= 	deseret}', "");
Expect(1, 66640, '\p{^Is_Script= 	deseret}', "");
Expect(1, 66640, '\P{Is_Script= 	deseret}', "");
Expect(0, 66640, '\P{^Is_Script= 	deseret}', "");
Error('\p{Is_Sc=	:=Dsrt}');
Error('\P{Is_Sc=	:=Dsrt}');
Expect(1, 66639, '\p{Is_Sc=dsrt}', "");
Expect(0, 66639, '\p{^Is_Sc=dsrt}', "");
Expect(0, 66639, '\P{Is_Sc=dsrt}', "");
Expect(1, 66639, '\P{^Is_Sc=dsrt}', "");
Expect(0, 66640, '\p{Is_Sc=dsrt}', "");
Expect(1, 66640, '\p{^Is_Sc=dsrt}', "");
Expect(1, 66640, '\P{Is_Sc=dsrt}', "");
Expect(0, 66640, '\P{^Is_Sc=dsrt}', "");
Expect(1, 66639, '\p{Is_Sc: - Dsrt}', "");
Expect(0, 66639, '\p{^Is_Sc: - Dsrt}', "");
Expect(0, 66639, '\P{Is_Sc: - Dsrt}', "");
Expect(1, 66639, '\P{^Is_Sc: - Dsrt}', "");
Expect(0, 66640, '\p{Is_Sc: - Dsrt}', "");
Expect(1, 66640, '\p{^Is_Sc: - Dsrt}', "");
Expect(1, 66640, '\P{Is_Sc: - Dsrt}', "");
Expect(0, 66640, '\P{^Is_Sc: - Dsrt}', "");
Error('\p{Script=-:=egyptian_Hieroglyphs}');
Error('\P{Script=-:=egyptian_Hieroglyphs}');
Expect(1, 78894, '\p{Script=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Script=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Script=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Script=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Script=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Script=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Script=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Script=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78894, '\p{^Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78894, '\P{Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78894, '\P{^Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\p{Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\p{^Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(1, 78895, '\P{Script=_EGYPTIAN_Hieroglyphs}', "");
Expect(0, 78895, '\P{^Script=_EGYPTIAN_Hieroglyphs}', "");
Error('\p{Sc= :=Egyp}');
Error('\P{Sc= :=Egyp}');
Expect(1, 78894, '\p{Sc=egyp}', "");
Expect(0, 78894, '\p{^Sc=egyp}', "");
Expect(0, 78894, '\P{Sc=egyp}', "");
Expect(1, 78894, '\P{^Sc=egyp}', "");
Expect(0, 78895, '\p{Sc=egyp}', "");
Expect(1, 78895, '\p{^Sc=egyp}', "");
Expect(1, 78895, '\P{Sc=egyp}', "");
Expect(0, 78895, '\P{^Sc=egyp}', "");
Expect(1, 78894, '\p{Sc=  Egyp}', "");
Expect(0, 78894, '\p{^Sc=  Egyp}', "");
Expect(0, 78894, '\P{Sc=  Egyp}', "");
Expect(1, 78894, '\P{^Sc=  Egyp}', "");
Expect(0, 78895, '\p{Sc=  Egyp}', "");
Expect(1, 78895, '\p{^Sc=  Egyp}', "");
Expect(1, 78895, '\P{Sc=  Egyp}', "");
Expect(0, 78895, '\P{^Sc=  Egyp}', "");
Error('\p{Is_Script=:= -EGYPTIAN_HIEROGLYPHS}');
Error('\P{Is_Script=:= -EGYPTIAN_HIEROGLYPHS}');
Expect(1, 78894, '\p{Is_Script=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Is_Script=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Is_Script=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Is_Script=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Is_Script=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Is_Script=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Is_Script=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Is_Script=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(0, 78894, '\p{^Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(0, 78894, '\P{Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(1, 78894, '\P{^Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\p{Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\p{^Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(1, 78895, '\P{Is_Script=		Egyptian_Hieroglyphs}', "");
Expect(0, 78895, '\P{^Is_Script=		Egyptian_Hieroglyphs}', "");
Error('\p{Is_Sc: 	:=Egyp}');
Error('\P{Is_Sc: 	:=Egyp}');
Expect(1, 78894, '\p{Is_Sc=egyp}', "");
Expect(0, 78894, '\p{^Is_Sc=egyp}', "");
Expect(0, 78894, '\P{Is_Sc=egyp}', "");
Expect(1, 78894, '\P{^Is_Sc=egyp}', "");
Expect(0, 78895, '\p{Is_Sc=egyp}', "");
Expect(1, 78895, '\p{^Is_Sc=egyp}', "");
Expect(1, 78895, '\P{Is_Sc=egyp}', "");
Expect(0, 78895, '\P{^Is_Sc=egyp}', "");
Expect(1, 78894, '\p{Is_Sc= Egyp}', "");
Expect(0, 78894, '\p{^Is_Sc= Egyp}', "");
Expect(0, 78894, '\P{Is_Sc= Egyp}', "");
Expect(1, 78894, '\P{^Is_Sc= Egyp}', "");
Expect(0, 78895, '\p{Is_Sc= Egyp}', "");
Expect(1, 78895, '\p{^Is_Sc= Egyp}', "");
Expect(1, 78895, '\P{Is_Sc= Egyp}', "");
Expect(0, 78895, '\P{^Is_Sc= Egyp}', "");
Error('\p{Script=/a/Ethiopic}');
Error('\P{Script=/a/Ethiopic}');
Expect(1, 43822, '\p{Script=ethiopic}', "");
Expect(0, 43822, '\p{^Script=ethiopic}', "");
Expect(0, 43822, '\P{Script=ethiopic}', "");
Expect(1, 43822, '\P{^Script=ethiopic}', "");
Expect(0, 43823, '\p{Script=ethiopic}', "");
Expect(1, 43823, '\p{^Script=ethiopic}', "");
Expect(1, 43823, '\P{Script=ethiopic}', "");
Expect(0, 43823, '\P{^Script=ethiopic}', "");
Expect(1, 43822, '\p{Script= 	Ethiopic}', "");
Expect(0, 43822, '\p{^Script= 	Ethiopic}', "");
Expect(0, 43822, '\P{Script= 	Ethiopic}', "");
Expect(1, 43822, '\P{^Script= 	Ethiopic}', "");
Expect(0, 43823, '\p{Script= 	Ethiopic}', "");
Expect(1, 43823, '\p{^Script= 	Ethiopic}', "");
Expect(1, 43823, '\P{Script= 	Ethiopic}', "");
Expect(0, 43823, '\P{^Script= 	Ethiopic}', "");
Error('\p{Sc=_ Ethi:=}');
Error('\P{Sc=_ Ethi:=}');
Expect(1, 43822, '\p{Sc=ethi}', "");
Expect(0, 43822, '\p{^Sc=ethi}', "");
Expect(0, 43822, '\P{Sc=ethi}', "");
Expect(1, 43822, '\P{^Sc=ethi}', "");
Expect(0, 43823, '\p{Sc=ethi}', "");
Expect(1, 43823, '\p{^Sc=ethi}', "");
Expect(1, 43823, '\P{Sc=ethi}', "");
Expect(0, 43823, '\P{^Sc=ethi}', "");
Expect(1, 43822, '\p{Sc=__Ethi}', "");
Expect(0, 43822, '\p{^Sc=__Ethi}', "");
Expect(0, 43822, '\P{Sc=__Ethi}', "");
Expect(1, 43822, '\P{^Sc=__Ethi}', "");
Expect(0, 43823, '\p{Sc=__Ethi}', "");
Expect(1, 43823, '\p{^Sc=__Ethi}', "");
Expect(1, 43823, '\P{Sc=__Ethi}', "");
Expect(0, 43823, '\P{^Sc=__Ethi}', "");
Error('\p{Is_Script=--ethiopic:=}');
Error('\P{Is_Script=--ethiopic:=}');
Expect(1, 43822, '\p{Is_Script=ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script=ethiopic}', "");
Expect(0, 43822, '\P{Is_Script=ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script=ethiopic}', "");
Expect(0, 43823, '\p{Is_Script=ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script=ethiopic}', "");
Expect(1, 43823, '\P{Is_Script=ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script=ethiopic}', "");
Expect(1, 43822, '\p{Is_Script=--Ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script=--Ethiopic}', "");
Expect(0, 43822, '\P{Is_Script=--Ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script=--Ethiopic}', "");
Expect(0, 43823, '\p{Is_Script=--Ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script=--Ethiopic}', "");
Expect(1, 43823, '\P{Is_Script=--Ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script=--Ethiopic}', "");
Error('\p{Is_Sc=:=	 ethi}');
Error('\P{Is_Sc=:=	 ethi}');
Expect(1, 43822, '\p{Is_Sc=ethi}', "");
Expect(0, 43822, '\p{^Is_Sc=ethi}', "");
Expect(0, 43822, '\P{Is_Sc=ethi}', "");
Expect(1, 43822, '\P{^Is_Sc=ethi}', "");
Expect(0, 43823, '\p{Is_Sc=ethi}', "");
Expect(1, 43823, '\p{^Is_Sc=ethi}', "");
Expect(1, 43823, '\P{Is_Sc=ethi}', "");
Expect(0, 43823, '\P{^Is_Sc=ethi}', "");
Expect(1, 43822, '\p{Is_Sc:  _ethi}', "");
Expect(0, 43822, '\p{^Is_Sc:  _ethi}', "");
Expect(0, 43822, '\P{Is_Sc:  _ethi}', "");
Expect(1, 43822, '\P{^Is_Sc:  _ethi}', "");
Expect(0, 43823, '\p{Is_Sc:  _ethi}', "");
Expect(1, 43823, '\p{^Is_Sc:  _ethi}', "");
Expect(1, 43823, '\P{Is_Sc:  _ethi}', "");
Expect(0, 43823, '\P{^Is_Sc:  _ethi}', "");
Error('\p{Script=_:=georgian}');
Error('\P{Script=_:=georgian}');
Expect(1, 11565, '\p{Script=georgian}', "");
Expect(0, 11565, '\p{^Script=georgian}', "");
Expect(0, 11565, '\P{Script=georgian}', "");
Expect(1, 11565, '\P{^Script=georgian}', "");
Expect(0, 11566, '\p{Script=georgian}', "");
Expect(1, 11566, '\p{^Script=georgian}', "");
Expect(1, 11566, '\P{Script=georgian}', "");
Expect(0, 11566, '\P{^Script=georgian}', "");
Expect(1, 11565, '\p{Script=	 georgian}', "");
Expect(0, 11565, '\p{^Script=	 georgian}', "");
Expect(0, 11565, '\P{Script=	 georgian}', "");
Expect(1, 11565, '\P{^Script=	 georgian}', "");
Expect(0, 11566, '\p{Script=	 georgian}', "");
Expect(1, 11566, '\p{^Script=	 georgian}', "");
Expect(1, 11566, '\P{Script=	 georgian}', "");
Expect(0, 11566, '\P{^Script=	 georgian}', "");
Error('\p{Sc:   /a/-geor}');
Error('\P{Sc:   /a/-geor}');
Expect(1, 11565, '\p{Sc=geor}', "");
Expect(0, 11565, '\p{^Sc=geor}', "");
Expect(0, 11565, '\P{Sc=geor}', "");
Expect(1, 11565, '\P{^Sc=geor}', "");
Expect(0, 11566, '\p{Sc=geor}', "");
Expect(1, 11566, '\p{^Sc=geor}', "");
Expect(1, 11566, '\P{Sc=geor}', "");
Expect(0, 11566, '\P{^Sc=geor}', "");
Expect(1, 11565, '\p{Sc=_-Geor}', "");
Expect(0, 11565, '\p{^Sc=_-Geor}', "");
Expect(0, 11565, '\P{Sc=_-Geor}', "");
Expect(1, 11565, '\P{^Sc=_-Geor}', "");
Expect(0, 11566, '\p{Sc=_-Geor}', "");
Expect(1, 11566, '\p{^Sc=_-Geor}', "");
Expect(1, 11566, '\P{Sc=_-Geor}', "");
Expect(0, 11566, '\P{^Sc=_-Geor}', "");
Error('\p{Is_Script=-/a/GEORGIAN}');
Error('\P{Is_Script=-/a/GEORGIAN}');
Expect(1, 11565, '\p{Is_Script=georgian}', "");
Expect(0, 11565, '\p{^Is_Script=georgian}', "");
Expect(0, 11565, '\P{Is_Script=georgian}', "");
Expect(1, 11565, '\P{^Is_Script=georgian}', "");
Expect(0, 11566, '\p{Is_Script=georgian}', "");
Expect(1, 11566, '\p{^Is_Script=georgian}', "");
Expect(1, 11566, '\P{Is_Script=georgian}', "");
Expect(0, 11566, '\P{^Is_Script=georgian}', "");
Expect(1, 11565, '\p{Is_Script: Georgian}', "");
Expect(0, 11565, '\p{^Is_Script: Georgian}', "");
Expect(0, 11565, '\P{Is_Script: Georgian}', "");
Expect(1, 11565, '\P{^Is_Script: Georgian}', "");
Expect(0, 11566, '\p{Is_Script: Georgian}', "");
Expect(1, 11566, '\p{^Is_Script: Georgian}', "");
Expect(1, 11566, '\P{Is_Script: Georgian}', "");
Expect(0, 11566, '\P{^Is_Script: Georgian}', "");
Error('\p{Is_Sc=GEOR:=}');
Error('\P{Is_Sc=GEOR:=}');
Expect(1, 11565, '\p{Is_Sc=geor}', "");
Expect(0, 11565, '\p{^Is_Sc=geor}', "");
Expect(0, 11565, '\P{Is_Sc=geor}', "");
Expect(1, 11565, '\P{^Is_Sc=geor}', "");
Expect(0, 11566, '\p{Is_Sc=geor}', "");
Expect(1, 11566, '\p{^Is_Sc=geor}', "");
Expect(1, 11566, '\P{Is_Sc=geor}', "");
Expect(0, 11566, '\P{^Is_Sc=geor}', "");
Expect(1, 11565, '\p{Is_Sc=_	Geor}', "");
Expect(0, 11565, '\p{^Is_Sc=_	Geor}', "");
Expect(0, 11565, '\P{Is_Sc=_	Geor}', "");
Expect(1, 11565, '\P{^Is_Sc=_	Geor}', "");
Expect(0, 11566, '\p{Is_Sc=_	Geor}', "");
Expect(1, 11566, '\p{^Is_Sc=_	Geor}', "");
Expect(1, 11566, '\P{Is_Sc=_	Geor}', "");
Expect(0, 11566, '\P{^Is_Sc=_	Geor}', "");
Error('\p{Script:/a/-Glagolitic}');
Error('\P{Script:/a/-Glagolitic}');
Expect(1, 11358, '\p{Script=glagolitic}', "");
Expect(0, 11358, '\p{^Script=glagolitic}', "");
Expect(0, 11358, '\P{Script=glagolitic}', "");
Expect(1, 11358, '\P{^Script=glagolitic}', "");
Expect(0, 11359, '\p{Script=glagolitic}', "");
Expect(1, 11359, '\p{^Script=glagolitic}', "");
Expect(1, 11359, '\P{Script=glagolitic}', "");
Expect(0, 11359, '\P{^Script=glagolitic}', "");
Expect(1, 11358, '\p{Script=_	Glagolitic}', "");
Expect(0, 11358, '\p{^Script=_	Glagolitic}', "");
Expect(0, 11358, '\P{Script=_	Glagolitic}', "");
Expect(1, 11358, '\P{^Script=_	Glagolitic}', "");
Expect(0, 11359, '\p{Script=_	Glagolitic}', "");
Expect(1, 11359, '\p{^Script=_	Glagolitic}', "");
Expect(1, 11359, '\P{Script=_	Glagolitic}', "");
Expect(0, 11359, '\P{^Script=_	Glagolitic}', "");
Error('\p{Sc=_/a/Glag}');
Error('\P{Sc=_/a/Glag}');
Expect(1, 11358, '\p{Sc=glag}', "");
Expect(0, 11358, '\p{^Sc=glag}', "");
Expect(0, 11358, '\P{Sc=glag}', "");
Expect(1, 11358, '\P{^Sc=glag}', "");
Expect(0, 11359, '\p{Sc=glag}', "");
Expect(1, 11359, '\p{^Sc=glag}', "");
Expect(1, 11359, '\P{Sc=glag}', "");
Expect(0, 11359, '\P{^Sc=glag}', "");
Expect(1, 11358, '\p{Sc= _GLAG}', "");
Expect(0, 11358, '\p{^Sc= _GLAG}', "");
Expect(0, 11358, '\P{Sc= _GLAG}', "");
Expect(1, 11358, '\P{^Sc= _GLAG}', "");
Expect(0, 11359, '\p{Sc= _GLAG}', "");
Expect(1, 11359, '\p{^Sc= _GLAG}', "");
Expect(1, 11359, '\P{Sc= _GLAG}', "");
Expect(0, 11359, '\P{^Sc= _GLAG}', "");
Error('\p{Is_Script=:=	-Glagolitic}');
Error('\P{Is_Script=:=	-Glagolitic}');
Expect(1, 11358, '\p{Is_Script=glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script=glagolitic}', "");
Expect(0, 11358, '\P{Is_Script=glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script=glagolitic}', "");
Expect(0, 11359, '\p{Is_Script=glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script=glagolitic}', "");
Expect(1, 11359, '\P{Is_Script=glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script=glagolitic}', "");
Expect(1, 11358, '\p{Is_Script=	 Glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script=	 Glagolitic}', "");
Expect(0, 11358, '\P{Is_Script=	 Glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script=	 Glagolitic}', "");
Expect(0, 11359, '\p{Is_Script=	 Glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script=	 Glagolitic}', "");
Expect(1, 11359, '\P{Is_Script=	 Glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script=	 Glagolitic}', "");
Error('\p{Is_Sc=:=_-glag}');
Error('\P{Is_Sc=:=_-glag}');
Expect(1, 11358, '\p{Is_Sc=glag}', "");
Expect(0, 11358, '\p{^Is_Sc=glag}', "");
Expect(0, 11358, '\P{Is_Sc=glag}', "");
Expect(1, 11358, '\P{^Is_Sc=glag}', "");
Expect(0, 11359, '\p{Is_Sc=glag}', "");
Expect(1, 11359, '\p{^Is_Sc=glag}', "");
Expect(1, 11359, '\P{Is_Sc=glag}', "");
Expect(0, 11359, '\P{^Is_Sc=glag}', "");
Expect(1, 11358, '\p{Is_Sc=-Glag}', "");
Expect(0, 11358, '\p{^Is_Sc=-Glag}', "");
Expect(0, 11358, '\P{Is_Sc=-Glag}', "");
Expect(1, 11358, '\P{^Is_Sc=-Glag}', "");
Expect(0, 11359, '\p{Is_Sc=-Glag}', "");
Expect(1, 11359, '\p{^Is_Sc=-Glag}', "");
Expect(1, 11359, '\P{Is_Sc=-Glag}', "");
Expect(0, 11359, '\P{^Is_Sc=-Glag}', "");
Error('\p{Script=:=- Gothic}');
Error('\P{Script=:=- Gothic}');
Expect(1, 66378, '\p{Script=gothic}', "");
Expect(0, 66378, '\p{^Script=gothic}', "");
Expect(0, 66378, '\P{Script=gothic}', "");
Expect(1, 66378, '\P{^Script=gothic}', "");
Expect(0, 66379, '\p{Script=gothic}', "");
Expect(1, 66379, '\p{^Script=gothic}', "");
Expect(1, 66379, '\P{Script=gothic}', "");
Expect(0, 66379, '\P{^Script=gothic}', "");
Expect(1, 66378, '\p{Script=_-GOTHIC}', "");
Expect(0, 66378, '\p{^Script=_-GOTHIC}', "");
Expect(0, 66378, '\P{Script=_-GOTHIC}', "");
Expect(1, 66378, '\P{^Script=_-GOTHIC}', "");
Expect(0, 66379, '\p{Script=_-GOTHIC}', "");
Expect(1, 66379, '\p{^Script=_-GOTHIC}', "");
Expect(1, 66379, '\P{Script=_-GOTHIC}', "");
Expect(0, 66379, '\P{^Script=_-GOTHIC}', "");
Error('\p{Sc=	-goth:=}');
Error('\P{Sc=	-goth:=}');
Expect(1, 66378, '\p{Sc:   goth}', "");
Expect(0, 66378, '\p{^Sc:   goth}', "");
Expect(0, 66378, '\P{Sc:   goth}', "");
Expect(1, 66378, '\P{^Sc:   goth}', "");
Expect(0, 66379, '\p{Sc:   goth}', "");
Expect(1, 66379, '\p{^Sc:   goth}', "");
Expect(1, 66379, '\P{Sc:   goth}', "");
Expect(0, 66379, '\P{^Sc:   goth}', "");
Expect(1, 66378, '\p{Sc=-goth}', "");
Expect(0, 66378, '\p{^Sc=-goth}', "");
Expect(0, 66378, '\P{Sc=-goth}', "");
Expect(1, 66378, '\P{^Sc=-goth}', "");
Expect(0, 66379, '\p{Sc=-goth}', "");
Expect(1, 66379, '\p{^Sc=-goth}', "");
Expect(1, 66379, '\P{Sc=-goth}', "");
Expect(0, 66379, '\P{^Sc=-goth}', "");
Error('\p{Is_Script=gothic:=}');
Error('\P{Is_Script=gothic:=}');
Expect(1, 66378, '\p{Is_Script=gothic}', "");
Expect(0, 66378, '\p{^Is_Script=gothic}', "");
Expect(0, 66378, '\P{Is_Script=gothic}', "");
Expect(1, 66378, '\P{^Is_Script=gothic}', "");
Expect(0, 66379, '\p{Is_Script=gothic}', "");
Expect(1, 66379, '\p{^Is_Script=gothic}', "");
Expect(1, 66379, '\P{Is_Script=gothic}', "");
Expect(0, 66379, '\P{^Is_Script=gothic}', "");
Expect(1, 66378, '\p{Is_Script=-GOTHIC}', "");
Expect(0, 66378, '\p{^Is_Script=-GOTHIC}', "");
Expect(0, 66378, '\P{Is_Script=-GOTHIC}', "");
Expect(1, 66378, '\P{^Is_Script=-GOTHIC}', "");
Expect(0, 66379, '\p{Is_Script=-GOTHIC}', "");
Expect(1, 66379, '\p{^Is_Script=-GOTHIC}', "");
Expect(1, 66379, '\P{Is_Script=-GOTHIC}', "");
Expect(0, 66379, '\P{^Is_Script=-GOTHIC}', "");
Error('\p{Is_Sc=_/a/GOTH}');
Error('\P{Is_Sc=_/a/GOTH}');
Expect(1, 66378, '\p{Is_Sc=goth}', "");
Expect(0, 66378, '\p{^Is_Sc=goth}', "");
Expect(0, 66378, '\P{Is_Sc=goth}', "");
Expect(1, 66378, '\P{^Is_Sc=goth}', "");
Expect(0, 66379, '\p{Is_Sc=goth}', "");
Expect(1, 66379, '\p{^Is_Sc=goth}', "");
Expect(1, 66379, '\P{Is_Sc=goth}', "");
Expect(0, 66379, '\P{^Is_Sc=goth}', "");
Expect(1, 66378, '\p{Is_Sc=	_Goth}', "");
Expect(0, 66378, '\p{^Is_Sc=	_Goth}', "");
Expect(0, 66378, '\P{Is_Sc=	_Goth}', "");
Expect(1, 66378, '\P{^Is_Sc=	_Goth}', "");
Expect(0, 66379, '\p{Is_Sc=	_Goth}', "");
Expect(1, 66379, '\p{^Is_Sc=	_Goth}', "");
Expect(1, 66379, '\P{Is_Sc=	_Goth}', "");
Expect(0, 66379, '\P{^Is_Sc=	_Goth}', "");
Error('\p{Script=/a/ Greek}');
Error('\P{Script=/a/ Greek}');
Expect(1, 119365, '\p{Script=greek}', "");
Expect(0, 119365, '\p{^Script=greek}', "");
Expect(0, 119365, '\P{Script=greek}', "");
Expect(1, 119365, '\P{^Script=greek}', "");
Expect(0, 119366, '\p{Script=greek}', "");
Expect(1, 119366, '\p{^Script=greek}', "");
Expect(1, 119366, '\P{Script=greek}', "");
Expect(0, 119366, '\P{^Script=greek}', "");
Expect(1, 119365, '\p{Script=_	GREEK}', "");
Expect(0, 119365, '\p{^Script=_	GREEK}', "");
Expect(0, 119365, '\P{Script=_	GREEK}', "");
Expect(1, 119365, '\P{^Script=_	GREEK}', "");
Expect(0, 119366, '\p{Script=_	GREEK}', "");
Expect(1, 119366, '\p{^Script=_	GREEK}', "");
Expect(1, 119366, '\P{Script=_	GREEK}', "");
Expect(0, 119366, '\P{^Script=_	GREEK}', "");
Error('\p{Sc=-/a/Grek}');
Error('\P{Sc=-/a/Grek}');
Expect(1, 119365, '\p{Sc: grek}', "");
Expect(0, 119365, '\p{^Sc: grek}', "");
Expect(0, 119365, '\P{Sc: grek}', "");
Expect(1, 119365, '\P{^Sc: grek}', "");
Expect(0, 119366, '\p{Sc: grek}', "");
Expect(1, 119366, '\p{^Sc: grek}', "");
Expect(1, 119366, '\P{Sc: grek}', "");
Expect(0, 119366, '\P{^Sc: grek}', "");
Expect(1, 119365, '\p{Sc=_GREK}', "");
Expect(0, 119365, '\p{^Sc=_GREK}', "");
Expect(0, 119365, '\P{Sc=_GREK}', "");
Expect(1, 119365, '\P{^Sc=_GREK}', "");
Expect(0, 119366, '\p{Sc=_GREK}', "");
Expect(1, 119366, '\p{^Sc=_GREK}', "");
Expect(1, 119366, '\P{Sc=_GREK}', "");
Expect(0, 119366, '\P{^Sc=_GREK}', "");
Error('\p{Is_Script:    :=Greek}');
Error('\P{Is_Script:    :=Greek}');
Expect(1, 119365, '\p{Is_Script=greek}', "");
Expect(0, 119365, '\p{^Is_Script=greek}', "");
Expect(0, 119365, '\P{Is_Script=greek}', "");
Expect(1, 119365, '\P{^Is_Script=greek}', "");
Expect(0, 119366, '\p{Is_Script=greek}', "");
Expect(1, 119366, '\p{^Is_Script=greek}', "");
Expect(1, 119366, '\P{Is_Script=greek}', "");
Expect(0, 119366, '\P{^Is_Script=greek}', "");
Expect(1, 119365, '\p{Is_Script= _GREEK}', "");
Expect(0, 119365, '\p{^Is_Script= _GREEK}', "");
Expect(0, 119365, '\P{Is_Script= _GREEK}', "");
Expect(1, 119365, '\P{^Is_Script= _GREEK}', "");
Expect(0, 119366, '\p{Is_Script= _GREEK}', "");
Expect(1, 119366, '\p{^Is_Script= _GREEK}', "");
Expect(1, 119366, '\P{Is_Script= _GREEK}', "");
Expect(0, 119366, '\P{^Is_Script= _GREEK}', "");
Error('\p{Is_Sc=GREK/a/}');
Error('\P{Is_Sc=GREK/a/}');
Expect(1, 119365, '\p{Is_Sc=grek}', "");
Expect(0, 119365, '\p{^Is_Sc=grek}', "");
Expect(0, 119365, '\P{Is_Sc=grek}', "");
Expect(1, 119365, '\P{^Is_Sc=grek}', "");
Expect(0, 119366, '\p{Is_Sc=grek}', "");
Expect(1, 119366, '\p{^Is_Sc=grek}', "");
Expect(1, 119366, '\P{Is_Sc=grek}', "");
Expect(0, 119366, '\P{^Is_Sc=grek}', "");
Expect(1, 119365, '\p{Is_Sc=- Grek}', "");
Expect(0, 119365, '\p{^Is_Sc=- Grek}', "");
Expect(0, 119365, '\P{Is_Sc=- Grek}', "");
Expect(1, 119365, '\P{^Is_Sc=- Grek}', "");
Expect(0, 119366, '\p{Is_Sc=- Grek}', "");
Expect(1, 119366, '\p{^Is_Sc=- Grek}', "");
Expect(1, 119366, '\P{Is_Sc=- Grek}', "");
Expect(0, 119366, '\P{^Is_Sc=- Grek}', "");
Error('\p{Script=:=	-Gujarati}');
Error('\P{Script=:=	-Gujarati}');
Expect(1, 2801, '\p{Script=gujarati}', "");
Expect(0, 2801, '\p{^Script=gujarati}', "");
Expect(0, 2801, '\P{Script=gujarati}', "");
Expect(1, 2801, '\P{^Script=gujarati}', "");
Expect(0, 2802, '\p{Script=gujarati}', "");
Expect(1, 2802, '\p{^Script=gujarati}', "");
Expect(1, 2802, '\P{Script=gujarati}', "");
Expect(0, 2802, '\P{^Script=gujarati}', "");
Expect(1, 2801, '\p{Script=	-Gujarati}', "");
Expect(0, 2801, '\p{^Script=	-Gujarati}', "");
Expect(0, 2801, '\P{Script=	-Gujarati}', "");
Expect(1, 2801, '\P{^Script=	-Gujarati}', "");
Expect(0, 2802, '\p{Script=	-Gujarati}', "");
Expect(1, 2802, '\p{^Script=	-Gujarati}', "");
Expect(1, 2802, '\P{Script=	-Gujarati}', "");
Expect(0, 2802, '\P{^Script=	-Gujarati}', "");
Error('\p{Sc=	:=Gujr}');
Error('\P{Sc=	:=Gujr}');
Expect(1, 2801, '\p{Sc=gujr}', "");
Expect(0, 2801, '\p{^Sc=gujr}', "");
Expect(0, 2801, '\P{Sc=gujr}', "");
Expect(1, 2801, '\P{^Sc=gujr}', "");
Expect(0, 2802, '\p{Sc=gujr}', "");
Expect(1, 2802, '\p{^Sc=gujr}', "");
Expect(1, 2802, '\P{Sc=gujr}', "");
Expect(0, 2802, '\P{^Sc=gujr}', "");
Expect(1, 2801, '\p{Sc=	-GUJR}', "");
Expect(0, 2801, '\p{^Sc=	-GUJR}', "");
Expect(0, 2801, '\P{Sc=	-GUJR}', "");
Expect(1, 2801, '\P{^Sc=	-GUJR}', "");
Expect(0, 2802, '\p{Sc=	-GUJR}', "");
Expect(1, 2802, '\p{^Sc=	-GUJR}', "");
Expect(1, 2802, '\P{Sc=	-GUJR}', "");
Expect(0, 2802, '\P{^Sc=	-GUJR}', "");
Error('\p{Is_Script=  GUJARATI/a/}');
Error('\P{Is_Script=  GUJARATI/a/}');
Expect(1, 2801, '\p{Is_Script=gujarati}', "");
Expect(0, 2801, '\p{^Is_Script=gujarati}', "");
Expect(0, 2801, '\P{Is_Script=gujarati}', "");
Expect(1, 2801, '\P{^Is_Script=gujarati}', "");
Expect(0, 2802, '\p{Is_Script=gujarati}', "");
Expect(1, 2802, '\p{^Is_Script=gujarati}', "");
Expect(1, 2802, '\P{Is_Script=gujarati}', "");
Expect(0, 2802, '\P{^Is_Script=gujarati}', "");
Error('\p{Is_Sc:  _Gujr:=}');
Error('\P{Is_Sc:  _Gujr:=}');
Expect(1, 2801, '\p{Is_Sc=gujr}', "");
Expect(0, 2801, '\p{^Is_Sc=gujr}', "");
Expect(0, 2801, '\P{Is_Sc=gujr}', "");
Expect(1, 2801, '\P{^Is_Sc=gujr}', "");
Expect(0, 2802, '\p{Is_Sc=gujr}', "");
Expect(1, 2802, '\p{^Is_Sc=gujr}', "");
Expect(1, 2802, '\P{Is_Sc=gujr}', "");
Expect(0, 2802, '\P{^Is_Sc=gujr}', "");
Expect(1, 2801, '\p{Is_Sc=-_gujr}', "");
Expect(0, 2801, '\p{^Is_Sc=-_gujr}', "");
Expect(0, 2801, '\P{Is_Sc=-_gujr}', "");
Expect(1, 2801, '\P{^Is_Sc=-_gujr}', "");
Expect(0, 2802, '\p{Is_Sc=-_gujr}', "");
Expect(1, 2802, '\p{^Is_Sc=-_gujr}', "");
Expect(1, 2802, '\P{Is_Sc=-_gujr}', "");
Expect(0, 2802, '\P{^Is_Sc=-_gujr}', "");
Error('\p{Script=/a/_GURMUKHI}');
Error('\P{Script=/a/_GURMUKHI}');
Expect(1, 2677, '\p{Script=gurmukhi}', "");
Expect(0, 2677, '\p{^Script=gurmukhi}', "");
Expect(0, 2677, '\P{Script=gurmukhi}', "");
Expect(1, 2677, '\P{^Script=gurmukhi}', "");
Expect(0, 2678, '\p{Script=gurmukhi}', "");
Expect(1, 2678, '\p{^Script=gurmukhi}', "");
Expect(1, 2678, '\P{Script=gurmukhi}', "");
Expect(0, 2678, '\P{^Script=gurmukhi}', "");
Expect(1, 2677, '\p{Script=__Gurmukhi}', "");
Expect(0, 2677, '\p{^Script=__Gurmukhi}', "");
Expect(0, 2677, '\P{Script=__Gurmukhi}', "");
Expect(1, 2677, '\P{^Script=__Gurmukhi}', "");
Expect(0, 2678, '\p{Script=__Gurmukhi}', "");
Expect(1, 2678, '\p{^Script=__Gurmukhi}', "");
Expect(1, 2678, '\P{Script=__Gurmukhi}', "");
Expect(0, 2678, '\P{^Script=__Gurmukhi}', "");
Error('\p{Sc=	:=Guru}');
Error('\P{Sc=	:=Guru}');
Expect(1, 2677, '\p{Sc=guru}', "");
Expect(0, 2677, '\p{^Sc=guru}', "");
Expect(0, 2677, '\P{Sc=guru}', "");
Expect(1, 2677, '\P{^Sc=guru}', "");
Expect(0, 2678, '\p{Sc=guru}', "");
Expect(1, 2678, '\p{^Sc=guru}', "");
Expect(1, 2678, '\P{Sc=guru}', "");
Expect(0, 2678, '\P{^Sc=guru}', "");
Expect(1, 2677, '\p{Sc=-guru}', "");
Expect(0, 2677, '\p{^Sc=-guru}', "");
Expect(0, 2677, '\P{Sc=-guru}', "");
Expect(1, 2677, '\P{^Sc=-guru}', "");
Expect(0, 2678, '\p{Sc=-guru}', "");
Expect(1, 2678, '\p{^Sc=-guru}', "");
Expect(1, 2678, '\P{Sc=-guru}', "");
Expect(0, 2678, '\P{^Sc=-guru}', "");
Error('\p{Is_Script:	_-GURMUKHI/a/}');
Error('\P{Is_Script:	_-GURMUKHI/a/}');
Expect(1, 2677, '\p{Is_Script=gurmukhi}', "");
Expect(0, 2677, '\p{^Is_Script=gurmukhi}', "");
Expect(0, 2677, '\P{Is_Script=gurmukhi}', "");
Expect(1, 2677, '\P{^Is_Script=gurmukhi}', "");
Expect(0, 2678, '\p{Is_Script=gurmukhi}', "");
Expect(1, 2678, '\p{^Is_Script=gurmukhi}', "");
Expect(1, 2678, '\P{Is_Script=gurmukhi}', "");
Expect(0, 2678, '\P{^Is_Script=gurmukhi}', "");
Expect(1, 2677, '\p{Is_Script= 	gurmukhi}', "");
Expect(0, 2677, '\p{^Is_Script= 	gurmukhi}', "");
Expect(0, 2677, '\P{Is_Script= 	gurmukhi}', "");
Expect(1, 2677, '\P{^Is_Script= 	gurmukhi}', "");
Expect(0, 2678, '\p{Is_Script= 	gurmukhi}', "");
Expect(1, 2678, '\p{^Is_Script= 	gurmukhi}', "");
Expect(1, 2678, '\P{Is_Script= 	gurmukhi}', "");
Expect(0, 2678, '\P{^Is_Script= 	gurmukhi}', "");
Error('\p{Is_Sc=_/a/Guru}');
Error('\P{Is_Sc=_/a/Guru}');
Expect(1, 2677, '\p{Is_Sc=guru}', "");
Expect(0, 2677, '\p{^Is_Sc=guru}', "");
Expect(0, 2677, '\P{Is_Sc=guru}', "");
Expect(1, 2677, '\P{^Is_Sc=guru}', "");
Expect(0, 2678, '\p{Is_Sc=guru}', "");
Expect(1, 2678, '\p{^Is_Sc=guru}', "");
Expect(1, 2678, '\P{Is_Sc=guru}', "");
Expect(0, 2678, '\P{^Is_Sc=guru}', "");
Expect(1, 2677, '\p{Is_Sc=	guru}', "");
Expect(0, 2677, '\p{^Is_Sc=	guru}', "");
Expect(0, 2677, '\P{Is_Sc=	guru}', "");
Expect(1, 2677, '\P{^Is_Sc=	guru}', "");
Expect(0, 2678, '\p{Is_Sc=	guru}', "");
Expect(1, 2678, '\p{^Is_Sc=	guru}', "");
Expect(1, 2678, '\P{Is_Sc=	guru}', "");
Expect(0, 2678, '\P{^Is_Sc=	guru}', "");
Error('\p{Script=--HANGUL:=}');
Error('\P{Script=--HANGUL:=}');
Expect(1, 65500, '\p{Script=hangul}', "");
Expect(0, 65500, '\p{^Script=hangul}', "");
Expect(0, 65500, '\P{Script=hangul}', "");
Expect(1, 65500, '\P{^Script=hangul}', "");
Expect(0, 65501, '\p{Script=hangul}', "");
Expect(1, 65501, '\p{^Script=hangul}', "");
Expect(1, 65501, '\P{Script=hangul}', "");
Expect(0, 65501, '\P{^Script=hangul}', "");
Expect(1, 65500, '\p{Script=Hangul}', "");
Expect(0, 65500, '\p{^Script=Hangul}', "");
Expect(0, 65500, '\P{Script=Hangul}', "");
Expect(1, 65500, '\P{^Script=Hangul}', "");
Expect(0, 65501, '\p{Script=Hangul}', "");
Expect(1, 65501, '\p{^Script=Hangul}', "");
Expect(1, 65501, '\P{Script=Hangul}', "");
Expect(0, 65501, '\P{^Script=Hangul}', "");
Error('\p{Sc=:=-	Hang}');
Error('\P{Sc=:=-	Hang}');
Expect(1, 65500, '\p{Sc:	hang}', "");
Expect(0, 65500, '\p{^Sc:	hang}', "");
Expect(0, 65500, '\P{Sc:	hang}', "");
Expect(1, 65500, '\P{^Sc:	hang}', "");
Expect(0, 65501, '\p{Sc:	hang}', "");
Expect(1, 65501, '\p{^Sc:	hang}', "");
Expect(1, 65501, '\P{Sc:	hang}', "");
Expect(0, 65501, '\P{^Sc:	hang}', "");
Expect(1, 65500, '\p{Sc:    	HANG}', "");
Expect(0, 65500, '\p{^Sc:    	HANG}', "");
Expect(0, 65500, '\P{Sc:    	HANG}', "");
Expect(1, 65500, '\P{^Sc:    	HANG}', "");
Expect(0, 65501, '\p{Sc:    	HANG}', "");
Expect(1, 65501, '\p{^Sc:    	HANG}', "");
Expect(1, 65501, '\P{Sc:    	HANG}', "");
Expect(0, 65501, '\P{^Sc:    	HANG}', "");
Error('\p{Is_Script=	Hangul/a/}');
Error('\P{Is_Script=	Hangul/a/}');
Expect(1, 65500, '\p{Is_Script=hangul}', "");
Expect(0, 65500, '\p{^Is_Script=hangul}', "");
Expect(0, 65500, '\P{Is_Script=hangul}', "");
Expect(1, 65500, '\P{^Is_Script=hangul}', "");
Expect(0, 65501, '\p{Is_Script=hangul}', "");
Expect(1, 65501, '\p{^Is_Script=hangul}', "");
Expect(1, 65501, '\P{Is_Script=hangul}', "");
Expect(0, 65501, '\P{^Is_Script=hangul}', "");
Expect(1, 65500, '\p{Is_Script=	_Hangul}', "");
Expect(0, 65500, '\p{^Is_Script=	_Hangul}', "");
Expect(0, 65500, '\P{Is_Script=	_Hangul}', "");
Expect(1, 65500, '\P{^Is_Script=	_Hangul}', "");
Expect(0, 65501, '\p{Is_Script=	_Hangul}', "");
Expect(1, 65501, '\p{^Is_Script=	_Hangul}', "");
Expect(1, 65501, '\P{Is_Script=	_Hangul}', "");
Expect(0, 65501, '\P{^Is_Script=	_Hangul}', "");
Error('\p{Is_Sc=	/a/Hang}');
Error('\P{Is_Sc=	/a/Hang}');
Expect(1, 65500, '\p{Is_Sc=hang}', "");
Expect(0, 65500, '\p{^Is_Sc=hang}', "");
Expect(0, 65500, '\P{Is_Sc=hang}', "");
Expect(1, 65500, '\P{^Is_Sc=hang}', "");
Expect(0, 65501, '\p{Is_Sc=hang}', "");
Expect(1, 65501, '\p{^Is_Sc=hang}', "");
Expect(1, 65501, '\P{Is_Sc=hang}', "");
Expect(0, 65501, '\P{^Is_Sc=hang}', "");
Expect(1, 65500, '\p{Is_Sc=  Hang}', "");
Expect(0, 65500, '\p{^Is_Sc=  Hang}', "");
Expect(0, 65500, '\P{Is_Sc=  Hang}', "");
Expect(1, 65500, '\P{^Is_Sc=  Hang}', "");
Expect(0, 65501, '\p{Is_Sc=  Hang}', "");
Expect(1, 65501, '\p{^Is_Sc=  Hang}', "");
Expect(1, 65501, '\P{Is_Sc=  Hang}', "");
Expect(0, 65501, '\P{^Is_Sc=  Hang}', "");
Error('\p{Script=/a/	_han}');
Error('\P{Script=/a/	_han}');
Expect(1, 195101, '\p{Script=han}', "");
Expect(0, 195101, '\p{^Script=han}', "");
Expect(0, 195101, '\P{Script=han}', "");
Expect(1, 195101, '\P{^Script=han}', "");
Expect(0, 195102, '\p{Script=han}', "");
Expect(1, 195102, '\p{^Script=han}', "");
Expect(1, 195102, '\P{Script=han}', "");
Expect(0, 195102, '\P{^Script=han}', "");
Expect(1, 195101, '\p{Script= -Han}', "");
Expect(0, 195101, '\p{^Script= -Han}', "");
Expect(0, 195101, '\P{Script= -Han}', "");
Expect(1, 195101, '\P{^Script= -Han}', "");
Expect(0, 195102, '\p{Script= -Han}', "");
Expect(1, 195102, '\p{^Script= -Han}', "");
Expect(1, 195102, '\P{Script= -Han}', "");
Expect(0, 195102, '\P{^Script= -Han}', "");
Error('\p{Sc=_/a/HANI}');
Error('\P{Sc=_/a/HANI}');
Expect(1, 195101, '\p{Sc=hani}', "");
Expect(0, 195101, '\p{^Sc=hani}', "");
Expect(0, 195101, '\P{Sc=hani}', "");
Expect(1, 195101, '\P{^Sc=hani}', "");
Expect(0, 195102, '\p{Sc=hani}', "");
Expect(1, 195102, '\p{^Sc=hani}', "");
Expect(1, 195102, '\P{Sc=hani}', "");
Expect(0, 195102, '\P{^Sc=hani}', "");
Expect(1, 195101, '\p{Sc= -hani}', "");
Expect(0, 195101, '\p{^Sc= -hani}', "");
Expect(0, 195101, '\P{Sc= -hani}', "");
Expect(1, 195101, '\P{^Sc= -hani}', "");
Expect(0, 195102, '\p{Sc= -hani}', "");
Expect(1, 195102, '\p{^Sc= -hani}', "");
Expect(1, 195102, '\P{Sc= -hani}', "");
Expect(0, 195102, '\P{^Sc= -hani}', "");
Error('\p{Is_Script=	:=Han}');
Error('\P{Is_Script=	:=Han}');
Expect(1, 195101, '\p{Is_Script=han}', "");
Expect(0, 195101, '\p{^Is_Script=han}', "");
Expect(0, 195101, '\P{Is_Script=han}', "");
Expect(1, 195101, '\P{^Is_Script=han}', "");
Expect(0, 195102, '\p{Is_Script=han}', "");
Expect(1, 195102, '\p{^Is_Script=han}', "");
Expect(1, 195102, '\P{Is_Script=han}', "");
Expect(0, 195102, '\P{^Is_Script=han}', "");
Expect(1, 195101, '\p{Is_Script=	 han}', "");
Expect(0, 195101, '\p{^Is_Script=	 han}', "");
Expect(0, 195101, '\P{Is_Script=	 han}', "");
Expect(1, 195101, '\P{^Is_Script=	 han}', "");
Expect(0, 195102, '\p{Is_Script=	 han}', "");
Expect(1, 195102, '\p{^Is_Script=	 han}', "");
Expect(1, 195102, '\P{Is_Script=	 han}', "");
Expect(0, 195102, '\P{^Is_Script=	 han}', "");
Error('\p{Is_Sc=-:=hani}');
Error('\P{Is_Sc=-:=hani}');
Expect(1, 195101, '\p{Is_Sc=hani}', "");
Expect(0, 195101, '\p{^Is_Sc=hani}', "");
Expect(0, 195101, '\P{Is_Sc=hani}', "");
Expect(1, 195101, '\P{^Is_Sc=hani}', "");
Expect(0, 195102, '\p{Is_Sc=hani}', "");
Expect(1, 195102, '\p{^Is_Sc=hani}', "");
Expect(1, 195102, '\P{Is_Sc=hani}', "");
Expect(0, 195102, '\P{^Is_Sc=hani}', "");
Expect(1, 195101, '\p{Is_Sc= Hani}', "");
Expect(0, 195101, '\p{^Is_Sc= Hani}', "");
Expect(0, 195101, '\P{Is_Sc= Hani}', "");
Expect(1, 195101, '\P{^Is_Sc= Hani}', "");
Expect(0, 195102, '\p{Is_Sc= Hani}', "");
Expect(1, 195102, '\p{^Is_Sc= Hani}', "");
Expect(1, 195102, '\P{Is_Sc= Hani}', "");
Expect(0, 195102, '\P{^Is_Sc= Hani}', "");
Error('\p{Script=-HANUNOO/a/}');
Error('\P{Script=-HANUNOO/a/}');
Expect(1, 5940, '\p{Script=hanunoo}', "");
Expect(0, 5940, '\p{^Script=hanunoo}', "");
Expect(0, 5940, '\P{Script=hanunoo}', "");
Expect(1, 5940, '\P{^Script=hanunoo}', "");
Expect(0, 5941, '\p{Script=hanunoo}', "");
Expect(1, 5941, '\p{^Script=hanunoo}', "");
Expect(1, 5941, '\P{Script=hanunoo}', "");
Expect(0, 5941, '\P{^Script=hanunoo}', "");
Expect(1, 5940, '\p{Script= hanunoo}', "");
Expect(0, 5940, '\p{^Script= hanunoo}', "");
Expect(0, 5940, '\P{Script= hanunoo}', "");
Expect(1, 5940, '\P{^Script= hanunoo}', "");
Expect(0, 5941, '\p{Script= hanunoo}', "");
Expect(1, 5941, '\p{^Script= hanunoo}', "");
Expect(1, 5941, '\P{Script= hanunoo}', "");
Expect(0, 5941, '\P{^Script= hanunoo}', "");
Error('\p{Sc=:=__Hano}');
Error('\P{Sc=:=__Hano}');
Expect(1, 5940, '\p{Sc=hano}', "");
Expect(0, 5940, '\p{^Sc=hano}', "");
Expect(0, 5940, '\P{Sc=hano}', "");
Expect(1, 5940, '\P{^Sc=hano}', "");
Expect(0, 5941, '\p{Sc=hano}', "");
Expect(1, 5941, '\p{^Sc=hano}', "");
Expect(1, 5941, '\P{Sc=hano}', "");
Expect(0, 5941, '\P{^Sc=hano}', "");
Expect(1, 5940, '\p{Sc=_-Hano}', "");
Expect(0, 5940, '\p{^Sc=_-Hano}', "");
Expect(0, 5940, '\P{Sc=_-Hano}', "");
Expect(1, 5940, '\P{^Sc=_-Hano}', "");
Expect(0, 5941, '\p{Sc=_-Hano}', "");
Expect(1, 5941, '\p{^Sc=_-Hano}', "");
Expect(1, 5941, '\P{Sc=_-Hano}', "");
Expect(0, 5941, '\P{^Sc=_-Hano}', "");
Error('\p{Is_Script=-/a/Hanunoo}');
Error('\P{Is_Script=-/a/Hanunoo}');
Expect(1, 5940, '\p{Is_Script=hanunoo}', "");
Expect(0, 5940, '\p{^Is_Script=hanunoo}', "");
Expect(0, 5940, '\P{Is_Script=hanunoo}', "");
Expect(1, 5940, '\P{^Is_Script=hanunoo}', "");
Expect(0, 5941, '\p{Is_Script=hanunoo}', "");
Expect(1, 5941, '\p{^Is_Script=hanunoo}', "");
Expect(1, 5941, '\P{Is_Script=hanunoo}', "");
Expect(0, 5941, '\P{^Is_Script=hanunoo}', "");
Expect(1, 5940, '\p{Is_Script=-HANUNOO}', "");
Expect(0, 5940, '\p{^Is_Script=-HANUNOO}', "");
Expect(0, 5940, '\P{Is_Script=-HANUNOO}', "");
Expect(1, 5940, '\P{^Is_Script=-HANUNOO}', "");
Expect(0, 5941, '\p{Is_Script=-HANUNOO}', "");
Expect(1, 5941, '\p{^Is_Script=-HANUNOO}', "");
Expect(1, 5941, '\P{Is_Script=-HANUNOO}', "");
Expect(0, 5941, '\P{^Is_Script=-HANUNOO}', "");
Error('\p{Is_Sc=- Hano:=}');
Error('\P{Is_Sc=- Hano:=}');
Expect(1, 5940, '\p{Is_Sc:hano}', "");
Expect(0, 5940, '\p{^Is_Sc:hano}', "");
Expect(0, 5940, '\P{Is_Sc:hano}', "");
Expect(1, 5940, '\P{^Is_Sc:hano}', "");
Expect(0, 5941, '\p{Is_Sc:hano}', "");
Expect(1, 5941, '\p{^Is_Sc:hano}', "");
Expect(1, 5941, '\P{Is_Sc:hano}', "");
Expect(0, 5941, '\P{^Is_Sc:hano}', "");
Expect(1, 5940, '\p{Is_Sc=__hano}', "");
Expect(0, 5940, '\p{^Is_Sc=__hano}', "");
Expect(0, 5940, '\P{Is_Sc=__hano}', "");
Expect(1, 5940, '\P{^Is_Sc=__hano}', "");
Expect(0, 5941, '\p{Is_Sc=__hano}', "");
Expect(1, 5941, '\p{^Is_Sc=__hano}', "");
Expect(1, 5941, '\P{Is_Sc=__hano}', "");
Expect(0, 5941, '\P{^Is_Sc=__hano}', "");
Error('\p{Script=/a/_	hebrew}');
Error('\P{Script=/a/_	hebrew}');
Expect(1, 64335, '\p{Script=hebrew}', "");
Expect(0, 64335, '\p{^Script=hebrew}', "");
Expect(0, 64335, '\P{Script=hebrew}', "");
Expect(1, 64335, '\P{^Script=hebrew}', "");
Expect(0, 64336, '\p{Script=hebrew}', "");
Expect(1, 64336, '\p{^Script=hebrew}', "");
Expect(1, 64336, '\P{Script=hebrew}', "");
Expect(0, 64336, '\P{^Script=hebrew}', "");
Expect(1, 64335, '\p{Script=  Hebrew}', "");
Expect(0, 64335, '\p{^Script=  Hebrew}', "");
Expect(0, 64335, '\P{Script=  Hebrew}', "");
Expect(1, 64335, '\P{^Script=  Hebrew}', "");
Expect(0, 64336, '\p{Script=  Hebrew}', "");
Expect(1, 64336, '\p{^Script=  Hebrew}', "");
Expect(1, 64336, '\P{Script=  Hebrew}', "");
Expect(0, 64336, '\P{^Script=  Hebrew}', "");
Error('\p{Sc=/a/-_HEBR}');
Error('\P{Sc=/a/-_HEBR}');
Expect(1, 64335, '\p{Sc=hebr}', "");
Expect(0, 64335, '\p{^Sc=hebr}', "");
Expect(0, 64335, '\P{Sc=hebr}', "");
Expect(1, 64335, '\P{^Sc=hebr}', "");
Expect(0, 64336, '\p{Sc=hebr}', "");
Expect(1, 64336, '\p{^Sc=hebr}', "");
Expect(1, 64336, '\P{Sc=hebr}', "");
Expect(0, 64336, '\P{^Sc=hebr}', "");
Expect(1, 64335, '\p{Sc= Hebr}', "");
Expect(0, 64335, '\p{^Sc= Hebr}', "");
Expect(0, 64335, '\P{Sc= Hebr}', "");
Expect(1, 64335, '\P{^Sc= Hebr}', "");
Expect(0, 64336, '\p{Sc= Hebr}', "");
Expect(1, 64336, '\p{^Sc= Hebr}', "");
Expect(1, 64336, '\P{Sc= Hebr}', "");
Expect(0, 64336, '\P{^Sc= Hebr}', "");
Error('\p{Is_Script=:=_HEBREW}');
Error('\P{Is_Script=:=_HEBREW}');
Expect(1, 64335, '\p{Is_Script=hebrew}', "");
Expect(0, 64335, '\p{^Is_Script=hebrew}', "");
Expect(0, 64335, '\P{Is_Script=hebrew}', "");
Expect(1, 64335, '\P{^Is_Script=hebrew}', "");
Expect(0, 64336, '\p{Is_Script=hebrew}', "");
Expect(1, 64336, '\p{^Is_Script=hebrew}', "");
Expect(1, 64336, '\P{Is_Script=hebrew}', "");
Expect(0, 64336, '\P{^Is_Script=hebrew}', "");
Expect(1, 64335, '\p{Is_Script=_ Hebrew}', "");
Expect(0, 64335, '\p{^Is_Script=_ Hebrew}', "");
Expect(0, 64335, '\P{Is_Script=_ Hebrew}', "");
Expect(1, 64335, '\P{^Is_Script=_ Hebrew}', "");
Expect(0, 64336, '\p{Is_Script=_ Hebrew}', "");
Expect(1, 64336, '\p{^Is_Script=_ Hebrew}', "");
Expect(1, 64336, '\P{Is_Script=_ Hebrew}', "");
Expect(0, 64336, '\P{^Is_Script=_ Hebrew}', "");
Error('\p{Is_Sc=/a/_hebr}');
Error('\P{Is_Sc=/a/_hebr}');
Expect(1, 64335, '\p{Is_Sc=hebr}', "");
Expect(0, 64335, '\p{^Is_Sc=hebr}', "");
Expect(0, 64335, '\P{Is_Sc=hebr}', "");
Expect(1, 64335, '\P{^Is_Sc=hebr}', "");
Expect(0, 64336, '\p{Is_Sc=hebr}', "");
Expect(1, 64336, '\p{^Is_Sc=hebr}', "");
Expect(1, 64336, '\P{Is_Sc=hebr}', "");
Expect(0, 64336, '\P{^Is_Sc=hebr}', "");
Expect(1, 64335, '\p{Is_Sc=_ hebr}', "");
Expect(0, 64335, '\p{^Is_Sc=_ hebr}', "");
Expect(0, 64335, '\P{Is_Sc=_ hebr}', "");
Expect(1, 64335, '\P{^Is_Sc=_ hebr}', "");
Expect(0, 64336, '\p{Is_Sc=_ hebr}', "");
Expect(1, 64336, '\p{^Is_Sc=_ hebr}', "");
Expect(1, 64336, '\P{Is_Sc=_ hebr}', "");
Expect(0, 64336, '\P{^Is_Sc=_ hebr}', "");
Error('\p{Script=- Hiragana:=}');
Error('\P{Script=- Hiragana:=}');
Expect(1, 127488, '\p{Script=hiragana}', "");
Expect(0, 127488, '\p{^Script=hiragana}', "");
Expect(0, 127488, '\P{Script=hiragana}', "");
Expect(1, 127488, '\P{^Script=hiragana}', "");
Expect(0, 127489, '\p{Script=hiragana}', "");
Expect(1, 127489, '\p{^Script=hiragana}', "");
Expect(1, 127489, '\P{Script=hiragana}', "");
Expect(0, 127489, '\P{^Script=hiragana}', "");
Expect(1, 127488, '\p{Script=	 Hiragana}', "");
Expect(0, 127488, '\p{^Script=	 Hiragana}', "");
Expect(0, 127488, '\P{Script=	 Hiragana}', "");
Expect(1, 127488, '\P{^Script=	 Hiragana}', "");
Expect(0, 127489, '\p{Script=	 Hiragana}', "");
Expect(1, 127489, '\p{^Script=	 Hiragana}', "");
Expect(1, 127489, '\P{Script=	 Hiragana}', "");
Expect(0, 127489, '\P{^Script=	 Hiragana}', "");
Error('\p{Sc=/a/_-HIRA}');
Error('\P{Sc=/a/_-HIRA}');
Expect(1, 127488, '\p{Sc=hira}', "");
Expect(0, 127488, '\p{^Sc=hira}', "");
Expect(0, 127488, '\P{Sc=hira}', "");
Expect(1, 127488, '\P{^Sc=hira}', "");
Expect(0, 127489, '\p{Sc=hira}', "");
Expect(1, 127489, '\p{^Sc=hira}', "");
Expect(1, 127489, '\P{Sc=hira}', "");
Expect(0, 127489, '\P{^Sc=hira}', "");
Expect(1, 127488, '\p{Sc=_-Hira}', "");
Expect(0, 127488, '\p{^Sc=_-Hira}', "");
Expect(0, 127488, '\P{Sc=_-Hira}', "");
Expect(1, 127488, '\P{^Sc=_-Hira}', "");
Expect(0, 127489, '\p{Sc=_-Hira}', "");
Expect(1, 127489, '\p{^Sc=_-Hira}', "");
Expect(1, 127489, '\P{Sc=_-Hira}', "");
Expect(0, 127489, '\P{^Sc=_-Hira}', "");
Error('\p{Is_Script=-HIRAGANA/a/}');
Error('\P{Is_Script=-HIRAGANA/a/}');
Expect(1, 127488, '\p{Is_Script=hiragana}', "");
Expect(0, 127488, '\p{^Is_Script=hiragana}', "");
Expect(0, 127488, '\P{Is_Script=hiragana}', "");
Expect(1, 127488, '\P{^Is_Script=hiragana}', "");
Expect(0, 127489, '\p{Is_Script=hiragana}', "");
Expect(1, 127489, '\p{^Is_Script=hiragana}', "");
Expect(1, 127489, '\P{Is_Script=hiragana}', "");
Expect(0, 127489, '\P{^Is_Script=hiragana}', "");
Expect(1, 127488, '\p{Is_Script=HIRAGANA}', "");
Expect(0, 127488, '\p{^Is_Script=HIRAGANA}', "");
Expect(0, 127488, '\P{Is_Script=HIRAGANA}', "");
Expect(1, 127488, '\P{^Is_Script=HIRAGANA}', "");
Expect(0, 127489, '\p{Is_Script=HIRAGANA}', "");
Expect(1, 127489, '\p{^Is_Script=HIRAGANA}', "");
Expect(1, 127489, '\P{Is_Script=HIRAGANA}', "");
Expect(0, 127489, '\P{^Is_Script=HIRAGANA}', "");
Error('\p{Is_Sc=/a/Hira}');
Error('\P{Is_Sc=/a/Hira}');
Expect(1, 127488, '\p{Is_Sc:   hira}', "");
Expect(0, 127488, '\p{^Is_Sc:   hira}', "");
Expect(0, 127488, '\P{Is_Sc:   hira}', "");
Expect(1, 127488, '\P{^Is_Sc:   hira}', "");
Expect(0, 127489, '\p{Is_Sc:   hira}', "");
Expect(1, 127489, '\p{^Is_Sc:   hira}', "");
Expect(1, 127489, '\P{Is_Sc:   hira}', "");
Expect(0, 127489, '\P{^Is_Sc:   hira}', "");
Expect(1, 127488, '\p{Is_Sc=	 HIRA}', "");
Expect(0, 127488, '\p{^Is_Sc=	 HIRA}', "");
Expect(0, 127488, '\P{Is_Sc=	 HIRA}', "");
Expect(1, 127488, '\P{^Is_Sc=	 HIRA}', "");
Expect(0, 127489, '\p{Is_Sc=	 HIRA}', "");
Expect(1, 127489, '\p{^Is_Sc=	 HIRA}', "");
Expect(1, 127489, '\P{Is_Sc=	 HIRA}', "");
Expect(0, 127489, '\P{^Is_Sc=	 HIRA}', "");
Error('\p{Script=Katakana_Or_Hiragana}');
Error('\P{Script=Katakana_Or_Hiragana}');
Error('\p{Sc=Hrkt}');
Error('\P{Sc=Hrkt}');
Error('\p{Is_Script=Katakana_Or_Hiragana}');
Error('\P{Is_Script=Katakana_Or_Hiragana}');
Error('\p{Is_Sc=Hrkt}');
Error('\P{Is_Sc=Hrkt}');
Error('\p{Script=Old_ITALIC:=}');
Error('\P{Script=Old_ITALIC:=}');
Expect(1, 66339, '\p{Script=olditalic}', "");
Expect(0, 66339, '\p{^Script=olditalic}', "");
Expect(0, 66339, '\P{Script=olditalic}', "");
Expect(1, 66339, '\P{^Script=olditalic}', "");
Expect(0, 66340, '\p{Script=olditalic}', "");
Expect(1, 66340, '\p{^Script=olditalic}', "");
Expect(1, 66340, '\P{Script=olditalic}', "");
Expect(0, 66340, '\P{^Script=olditalic}', "");
Expect(1, 66339, '\p{Script=__Old_ITALIC}', "");
Expect(0, 66339, '\p{^Script=__Old_ITALIC}', "");
Expect(0, 66339, '\P{Script=__Old_ITALIC}', "");
Expect(1, 66339, '\P{^Script=__Old_ITALIC}', "");
Expect(0, 66340, '\p{Script=__Old_ITALIC}', "");
Expect(1, 66340, '\p{^Script=__Old_ITALIC}', "");
Expect(1, 66340, '\P{Script=__Old_ITALIC}', "");
Expect(0, 66340, '\P{^Script=__Old_ITALIC}', "");
Error('\p{Sc:_-Ital:=}');
Error('\P{Sc:_-Ital:=}');
Expect(1, 66339, '\p{Sc=ital}', "");
Expect(0, 66339, '\p{^Sc=ital}', "");
Expect(0, 66339, '\P{Sc=ital}', "");
Expect(1, 66339, '\P{^Sc=ital}', "");
Expect(0, 66340, '\p{Sc=ital}', "");
Expect(1, 66340, '\p{^Sc=ital}', "");
Expect(1, 66340, '\P{Sc=ital}', "");
Expect(0, 66340, '\P{^Sc=ital}', "");
Expect(1, 66339, '\p{Sc=__ITAL}', "");
Expect(0, 66339, '\p{^Sc=__ITAL}', "");
Expect(0, 66339, '\P{Sc=__ITAL}', "");
Expect(1, 66339, '\P{^Sc=__ITAL}', "");
Expect(0, 66340, '\p{Sc=__ITAL}', "");
Expect(1, 66340, '\p{^Sc=__ITAL}', "");
Expect(1, 66340, '\P{Sc=__ITAL}', "");
Expect(0, 66340, '\P{^Sc=__ITAL}', "");
Error('\p{Is_Script:/a/__old_ITALIC}');
Error('\P{Is_Script:/a/__old_ITALIC}');
Expect(1, 66339, '\p{Is_Script=olditalic}', "");
Expect(0, 66339, '\p{^Is_Script=olditalic}', "");
Expect(0, 66339, '\P{Is_Script=olditalic}', "");
Expect(1, 66339, '\P{^Is_Script=olditalic}', "");
Expect(0, 66340, '\p{Is_Script=olditalic}', "");
Expect(1, 66340, '\p{^Is_Script=olditalic}', "");
Expect(1, 66340, '\P{Is_Script=olditalic}', "");
Expect(0, 66340, '\P{^Is_Script=olditalic}', "");
Expect(1, 66339, '\p{Is_Script=-OLD_Italic}', "");
Expect(0, 66339, '\p{^Is_Script=-OLD_Italic}', "");
Expect(0, 66339, '\P{Is_Script=-OLD_Italic}', "");
Expect(1, 66339, '\P{^Is_Script=-OLD_Italic}', "");
Expect(0, 66340, '\p{Is_Script=-OLD_Italic}', "");
Expect(1, 66340, '\p{^Is_Script=-OLD_Italic}', "");
Expect(1, 66340, '\P{Is_Script=-OLD_Italic}', "");
Expect(0, 66340, '\P{^Is_Script=-OLD_Italic}', "");
Error('\p{Is_Sc=/a/ _Ital}');
Error('\P{Is_Sc=/a/ _Ital}');
Expect(1, 66339, '\p{Is_Sc=ital}', "");
Expect(0, 66339, '\p{^Is_Sc=ital}', "");
Expect(0, 66339, '\P{Is_Sc=ital}', "");
Expect(1, 66339, '\P{^Is_Sc=ital}', "");
Expect(0, 66340, '\p{Is_Sc=ital}', "");
Expect(1, 66340, '\p{^Is_Sc=ital}', "");
Expect(1, 66340, '\P{Is_Sc=ital}', "");
Expect(0, 66340, '\P{^Is_Sc=ital}', "");
Expect(1, 66339, '\p{Is_Sc=-ITAL}', "");
Expect(0, 66339, '\p{^Is_Sc=-ITAL}', "");
Expect(0, 66339, '\P{Is_Sc=-ITAL}', "");
Expect(1, 66339, '\P{^Is_Sc=-ITAL}', "");
Expect(0, 66340, '\p{Is_Sc=-ITAL}', "");
Expect(1, 66340, '\p{^Is_Sc=-ITAL}', "");
Expect(1, 66340, '\P{Is_Sc=-ITAL}', "");
Expect(0, 66340, '\P{^Is_Sc=-ITAL}', "");
Error('\p{Script=_/a/JAVANESE}');
Error('\P{Script=_/a/JAVANESE}');
Expect(1, 43487, '\p{Script=javanese}', "");
Expect(0, 43487, '\p{^Script=javanese}', "");
Expect(0, 43487, '\P{Script=javanese}', "");
Expect(1, 43487, '\P{^Script=javanese}', "");
Expect(0, 43488, '\p{Script=javanese}', "");
Expect(1, 43488, '\p{^Script=javanese}', "");
Expect(1, 43488, '\P{Script=javanese}', "");
Expect(0, 43488, '\P{^Script=javanese}', "");
Expect(1, 43487, '\p{Script= _JAVANESE}', "");
Expect(0, 43487, '\p{^Script= _JAVANESE}', "");
Expect(0, 43487, '\P{Script= _JAVANESE}', "");
Expect(1, 43487, '\P{^Script= _JAVANESE}', "");
Expect(0, 43488, '\p{Script= _JAVANESE}', "");
Expect(1, 43488, '\p{^Script= _JAVANESE}', "");
Expect(1, 43488, '\P{Script= _JAVANESE}', "");
Expect(0, 43488, '\P{^Script= _JAVANESE}', "");
Error('\p{Sc=_:=java}');
Error('\P{Sc=_:=java}');
Expect(1, 43487, '\p{Sc:	java}', "");
Expect(0, 43487, '\p{^Sc:	java}', "");
Expect(0, 43487, '\P{Sc:	java}', "");
Expect(1, 43487, '\P{^Sc:	java}', "");
Expect(0, 43488, '\p{Sc:	java}', "");
Expect(1, 43488, '\p{^Sc:	java}', "");
Expect(1, 43488, '\P{Sc:	java}', "");
Expect(0, 43488, '\P{^Sc:	java}', "");
Expect(1, 43487, '\p{Sc=_	java}', "");
Expect(0, 43487, '\p{^Sc=_	java}', "");
Expect(0, 43487, '\P{Sc=_	java}', "");
Expect(1, 43487, '\P{^Sc=_	java}', "");
Expect(0, 43488, '\p{Sc=_	java}', "");
Expect(1, 43488, '\p{^Sc=_	java}', "");
Expect(1, 43488, '\P{Sc=_	java}', "");
Expect(0, 43488, '\P{^Sc=_	java}', "");
Error('\p{Is_Script=  Javanese/a/}');
Error('\P{Is_Script=  Javanese/a/}');
Expect(1, 43487, '\p{Is_Script=javanese}', "");
Expect(0, 43487, '\p{^Is_Script=javanese}', "");
Expect(0, 43487, '\P{Is_Script=javanese}', "");
Expect(1, 43487, '\P{^Is_Script=javanese}', "");
Expect(0, 43488, '\p{Is_Script=javanese}', "");
Expect(1, 43488, '\p{^Is_Script=javanese}', "");
Expect(1, 43488, '\P{Is_Script=javanese}', "");
Expect(0, 43488, '\P{^Is_Script=javanese}', "");
Expect(1, 43487, '\p{Is_Script: -Javanese}', "");
Expect(0, 43487, '\p{^Is_Script: -Javanese}', "");
Expect(0, 43487, '\P{Is_Script: -Javanese}', "");
Expect(1, 43487, '\P{^Is_Script: -Javanese}', "");
Expect(0, 43488, '\p{Is_Script: -Javanese}', "");
Expect(1, 43488, '\p{^Is_Script: -Javanese}', "");
Expect(1, 43488, '\P{Is_Script: -Javanese}', "");
Expect(0, 43488, '\P{^Is_Script: -Javanese}', "");
Error('\p{Is_Sc=	/a/java}');
Error('\P{Is_Sc=	/a/java}');
Expect(1, 43487, '\p{Is_Sc=java}', "");
Expect(0, 43487, '\p{^Is_Sc=java}', "");
Expect(0, 43487, '\P{Is_Sc=java}', "");
Expect(1, 43487, '\P{^Is_Sc=java}', "");
Expect(0, 43488, '\p{Is_Sc=java}', "");
Expect(1, 43488, '\p{^Is_Sc=java}', "");
Expect(1, 43488, '\P{Is_Sc=java}', "");
Expect(0, 43488, '\P{^Is_Sc=java}', "");
Expect(1, 43487, '\p{Is_Sc=		java}', "");
Expect(0, 43487, '\p{^Is_Sc=		java}', "");
Expect(0, 43487, '\P{Is_Sc=		java}', "");
Expect(1, 43487, '\P{^Is_Sc=		java}', "");
Expect(0, 43488, '\p{Is_Sc=		java}', "");
Expect(1, 43488, '\p{^Is_Sc=		java}', "");
Expect(1, 43488, '\P{Is_Sc=		java}', "");
Expect(0, 43488, '\P{^Is_Sc=		java}', "");
Error('\p{Script=	 Kayah_Li/a/}');
Error('\P{Script=	 Kayah_Li/a/}');
Expect(1, 43311, '\p{Script=kayahli}', "");
Expect(0, 43311, '\p{^Script=kayahli}', "");
Expect(0, 43311, '\P{Script=kayahli}', "");
Expect(1, 43311, '\P{^Script=kayahli}', "");
Expect(0, 43312, '\p{Script=kayahli}', "");
Expect(1, 43312, '\p{^Script=kayahli}', "");
Expect(1, 43312, '\P{Script=kayahli}', "");
Expect(0, 43312, '\P{^Script=kayahli}', "");
Expect(1, 43311, '\p{Script=_-KAYAH_Li}', "");
Expect(0, 43311, '\p{^Script=_-KAYAH_Li}', "");
Expect(0, 43311, '\P{Script=_-KAYAH_Li}', "");
Expect(1, 43311, '\P{^Script=_-KAYAH_Li}', "");
Expect(0, 43312, '\p{Script=_-KAYAH_Li}', "");
Expect(1, 43312, '\p{^Script=_-KAYAH_Li}', "");
Expect(1, 43312, '\P{Script=_-KAYAH_Li}', "");
Expect(0, 43312, '\P{^Script=_-KAYAH_Li}', "");
Error('\p{Sc= :=Kali}');
Error('\P{Sc= :=Kali}');
Expect(1, 43311, '\p{Sc=kali}', "");
Expect(0, 43311, '\p{^Sc=kali}', "");
Expect(0, 43311, '\P{Sc=kali}', "");
Expect(1, 43311, '\P{^Sc=kali}', "");
Expect(0, 43312, '\p{Sc=kali}', "");
Expect(1, 43312, '\p{^Sc=kali}', "");
Expect(1, 43312, '\P{Sc=kali}', "");
Expect(0, 43312, '\P{^Sc=kali}', "");
Expect(1, 43311, '\p{Sc=-_kali}', "");
Expect(0, 43311, '\p{^Sc=-_kali}', "");
Expect(0, 43311, '\P{Sc=-_kali}', "");
Expect(1, 43311, '\P{^Sc=-_kali}', "");
Expect(0, 43312, '\p{Sc=-_kali}', "");
Expect(1, 43312, '\p{^Sc=-_kali}', "");
Expect(1, 43312, '\P{Sc=-_kali}', "");
Expect(0, 43312, '\P{^Sc=-_kali}', "");
Error('\p{Is_Script:-_KAYAH_LI:=}');
Error('\P{Is_Script:-_KAYAH_LI:=}');
Expect(1, 43311, '\p{Is_Script=kayahli}', "");
Expect(0, 43311, '\p{^Is_Script=kayahli}', "");
Expect(0, 43311, '\P{Is_Script=kayahli}', "");
Expect(1, 43311, '\P{^Is_Script=kayahli}', "");
Expect(0, 43312, '\p{Is_Script=kayahli}', "");
Expect(1, 43312, '\p{^Is_Script=kayahli}', "");
Expect(1, 43312, '\P{Is_Script=kayahli}', "");
Expect(0, 43312, '\P{^Is_Script=kayahli}', "");
Expect(1, 43311, '\p{Is_Script=-_Kayah_Li}', "");
Expect(0, 43311, '\p{^Is_Script=-_Kayah_Li}', "");
Expect(0, 43311, '\P{Is_Script=-_Kayah_Li}', "");
Expect(1, 43311, '\P{^Is_Script=-_Kayah_Li}', "");
Expect(0, 43312, '\p{Is_Script=-_Kayah_Li}', "");
Expect(1, 43312, '\p{^Is_Script=-_Kayah_Li}', "");
Expect(1, 43312, '\P{Is_Script=-_Kayah_Li}', "");
Expect(0, 43312, '\P{^Is_Script=-_Kayah_Li}', "");
Error('\p{Is_Sc=:=_ KALI}');
Error('\P{Is_Sc=:=_ KALI}');
Expect(1, 43311, '\p{Is_Sc=kali}', "");
Expect(0, 43311, '\p{^Is_Sc=kali}', "");
Expect(0, 43311, '\P{Is_Sc=kali}', "");
Expect(1, 43311, '\P{^Is_Sc=kali}', "");
Expect(0, 43312, '\p{Is_Sc=kali}', "");
Expect(1, 43312, '\p{^Is_Sc=kali}', "");
Expect(1, 43312, '\P{Is_Sc=kali}', "");
Expect(0, 43312, '\P{^Is_Sc=kali}', "");
Expect(1, 43311, '\p{Is_Sc=_Kali}', "");
Expect(0, 43311, '\p{^Is_Sc=_Kali}', "");
Expect(0, 43311, '\P{Is_Sc=_Kali}', "");
Expect(1, 43311, '\P{^Is_Sc=_Kali}', "");
Expect(0, 43312, '\p{Is_Sc=_Kali}', "");
Expect(1, 43312, '\p{^Is_Sc=_Kali}', "");
Expect(1, 43312, '\P{Is_Sc=_Kali}', "");
Expect(0, 43312, '\P{^Is_Sc=_Kali}', "");
Error('\p{Script=-:=katakana}');
Error('\P{Script=-:=katakana}');
Expect(1, 110592, '\p{Script=katakana}', "");
Expect(0, 110592, '\p{^Script=katakana}', "");
Expect(0, 110592, '\P{Script=katakana}', "");
Expect(1, 110592, '\P{^Script=katakana}', "");
Expect(0, 110593, '\p{Script=katakana}', "");
Expect(1, 110593, '\p{^Script=katakana}', "");
Expect(1, 110593, '\P{Script=katakana}', "");
Expect(0, 110593, '\P{^Script=katakana}', "");
Expect(1, 110592, '\p{Script= katakana}', "");
Expect(0, 110592, '\p{^Script= katakana}', "");
Expect(0, 110592, '\P{Script= katakana}', "");
Expect(1, 110592, '\P{^Script= katakana}', "");
Expect(0, 110593, '\p{Script= katakana}', "");
Expect(1, 110593, '\p{^Script= katakana}', "");
Expect(1, 110593, '\P{Script= katakana}', "");
Expect(0, 110593, '\P{^Script= katakana}', "");
Error('\p{Sc=/a/-KANA}');
Error('\P{Sc=/a/-KANA}');
Expect(1, 110592, '\p{Sc=kana}', "");
Expect(0, 110592, '\p{^Sc=kana}', "");
Expect(0, 110592, '\P{Sc=kana}', "");
Expect(1, 110592, '\P{^Sc=kana}', "");
Expect(0, 110593, '\p{Sc=kana}', "");
Expect(1, 110593, '\p{^Sc=kana}', "");
Expect(1, 110593, '\P{Sc=kana}', "");
Expect(0, 110593, '\P{^Sc=kana}', "");
Expect(1, 110592, '\p{Sc=-kana}', "");
Expect(0, 110592, '\p{^Sc=-kana}', "");
Expect(0, 110592, '\P{Sc=-kana}', "");
Expect(1, 110592, '\P{^Sc=-kana}', "");
Expect(0, 110593, '\p{Sc=-kana}', "");
Expect(1, 110593, '\p{^Sc=-kana}', "");
Expect(1, 110593, '\P{Sc=-kana}', "");
Expect(0, 110593, '\P{^Sc=-kana}', "");
Error('\p{Is_Script=:=	Katakana}');
Error('\P{Is_Script=:=	Katakana}');
Expect(1, 110592, '\p{Is_Script:   katakana}', "");
Expect(0, 110592, '\p{^Is_Script:   katakana}', "");
Expect(0, 110592, '\P{Is_Script:   katakana}', "");
Expect(1, 110592, '\P{^Is_Script:   katakana}', "");
Expect(0, 110593, '\p{Is_Script:   katakana}', "");
Expect(1, 110593, '\p{^Is_Script:   katakana}', "");
Expect(1, 110593, '\P{Is_Script:   katakana}', "");
Expect(0, 110593, '\P{^Is_Script:   katakana}', "");
Expect(1, 110592, '\p{Is_Script=-KATAKANA}', "");
Expect(0, 110592, '\p{^Is_Script=-KATAKANA}', "");
Expect(0, 110592, '\P{Is_Script=-KATAKANA}', "");
Expect(1, 110592, '\P{^Is_Script=-KATAKANA}', "");
Expect(0, 110593, '\p{Is_Script=-KATAKANA}', "");
Expect(1, 110593, '\p{^Is_Script=-KATAKANA}', "");
Expect(1, 110593, '\P{Is_Script=-KATAKANA}', "");
Expect(0, 110593, '\P{^Is_Script=-KATAKANA}', "");
Error('\p{Is_Sc=_ KANA/a/}');
Error('\P{Is_Sc=_ KANA/a/}');
Expect(1, 110592, '\p{Is_Sc=kana}', "");
Expect(0, 110592, '\p{^Is_Sc=kana}', "");
Expect(0, 110592, '\P{Is_Sc=kana}', "");
Expect(1, 110592, '\P{^Is_Sc=kana}', "");
Expect(0, 110593, '\p{Is_Sc=kana}', "");
Expect(1, 110593, '\p{^Is_Sc=kana}', "");
Expect(1, 110593, '\P{Is_Sc=kana}', "");
Expect(0, 110593, '\P{^Is_Sc=kana}', "");
Expect(1, 110592, '\p{Is_Sc= 	KANA}', "");
Expect(0, 110592, '\p{^Is_Sc= 	KANA}', "");
Expect(0, 110592, '\P{Is_Sc= 	KANA}', "");
Expect(1, 110592, '\P{^Is_Sc= 	KANA}', "");
Expect(0, 110593, '\p{Is_Sc= 	KANA}', "");
Expect(1, 110593, '\p{^Is_Sc= 	KANA}', "");
Expect(1, 110593, '\P{Is_Sc= 	KANA}', "");
Expect(0, 110593, '\P{^Is_Sc= 	KANA}', "");
Error('\p{Script=_/a/KHAROSHTHI}');
Error('\P{Script=_/a/KHAROSHTHI}');
Expect(1, 68184, '\p{Script=kharoshthi}', "");
Expect(0, 68184, '\p{^Script=kharoshthi}', "");
Expect(0, 68184, '\P{Script=kharoshthi}', "");
Expect(1, 68184, '\P{^Script=kharoshthi}', "");
Expect(0, 68185, '\p{Script=kharoshthi}', "");
Expect(1, 68185, '\p{^Script=kharoshthi}', "");
Expect(1, 68185, '\P{Script=kharoshthi}', "");
Expect(0, 68185, '\P{^Script=kharoshthi}', "");
Expect(1, 68184, '\p{Script=_kharoshthi}', "");
Expect(0, 68184, '\p{^Script=_kharoshthi}', "");
Expect(0, 68184, '\P{Script=_kharoshthi}', "");
Expect(1, 68184, '\P{^Script=_kharoshthi}', "");
Expect(0, 68185, '\p{Script=_kharoshthi}', "");
Expect(1, 68185, '\p{^Script=_kharoshthi}', "");
Expect(1, 68185, '\P{Script=_kharoshthi}', "");
Expect(0, 68185, '\P{^Script=_kharoshthi}', "");
Error('\p{Sc:   /a/ Khar}');
Error('\P{Sc:   /a/ Khar}');
Expect(1, 68184, '\p{Sc=khar}', "");
Expect(0, 68184, '\p{^Sc=khar}', "");
Expect(0, 68184, '\P{Sc=khar}', "");
Expect(1, 68184, '\P{^Sc=khar}', "");
Expect(0, 68185, '\p{Sc=khar}', "");
Expect(1, 68185, '\p{^Sc=khar}', "");
Expect(1, 68185, '\P{Sc=khar}', "");
Expect(0, 68185, '\P{^Sc=khar}', "");
Expect(1, 68184, '\p{Sc=	 KHAR}', "");
Expect(0, 68184, '\p{^Sc=	 KHAR}', "");
Expect(0, 68184, '\P{Sc=	 KHAR}', "");
Expect(1, 68184, '\P{^Sc=	 KHAR}', "");
Expect(0, 68185, '\p{Sc=	 KHAR}', "");
Expect(1, 68185, '\p{^Sc=	 KHAR}', "");
Expect(1, 68185, '\P{Sc=	 KHAR}', "");
Expect(0, 68185, '\P{^Sc=	 KHAR}', "");
Error('\p{Is_Script=/a/--Kharoshthi}');
Error('\P{Is_Script=/a/--Kharoshthi}');
Expect(1, 68184, '\p{Is_Script=kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script=kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script=kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script=kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script=kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script=kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script=kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script=kharoshthi}', "");
Expect(1, 68184, '\p{Is_Script= -Kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script= -Kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script= -Kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script= -Kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script= -Kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script= -Kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script= -Kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script= -Kharoshthi}', "");
Error('\p{Is_Sc=/a/ _Khar}');
Error('\P{Is_Sc=/a/ _Khar}');
Expect(1, 68184, '\p{Is_Sc=khar}', "");
Expect(0, 68184, '\p{^Is_Sc=khar}', "");
Expect(0, 68184, '\P{Is_Sc=khar}', "");
Expect(1, 68184, '\P{^Is_Sc=khar}', "");
Expect(0, 68185, '\p{Is_Sc=khar}', "");
Expect(1, 68185, '\p{^Is_Sc=khar}', "");
Expect(1, 68185, '\P{Is_Sc=khar}', "");
Expect(0, 68185, '\P{^Is_Sc=khar}', "");
Expect(1, 68184, '\p{Is_Sc= _KHAR}', "");
Expect(0, 68184, '\p{^Is_Sc= _KHAR}', "");
Expect(0, 68184, '\P{Is_Sc= _KHAR}', "");
Expect(1, 68184, '\P{^Is_Sc= _KHAR}', "");
Expect(0, 68185, '\p{Is_Sc= _KHAR}', "");
Expect(1, 68185, '\p{^Is_Sc= _KHAR}', "");
Expect(1, 68185, '\P{Is_Sc= _KHAR}', "");
Expect(0, 68185, '\P{^Is_Sc= _KHAR}', "");
Error('\p{Script=_:=khmer}');
Error('\P{Script=_:=khmer}');
Expect(1, 6655, '\p{Script=khmer}', "");
Expect(0, 6655, '\p{^Script=khmer}', "");
Expect(0, 6655, '\P{Script=khmer}', "");
Expect(1, 6655, '\P{^Script=khmer}', "");
Expect(0, 6656, '\p{Script=khmer}', "");
Expect(1, 6656, '\p{^Script=khmer}', "");
Expect(1, 6656, '\P{Script=khmer}', "");
Expect(0, 6656, '\P{^Script=khmer}', "");
Expect(1, 6655, '\p{Script= _Khmer}', "");
Expect(0, 6655, '\p{^Script= _Khmer}', "");
Expect(0, 6655, '\P{Script= _Khmer}', "");
Expect(1, 6655, '\P{^Script= _Khmer}', "");
Expect(0, 6656, '\p{Script= _Khmer}', "");
Expect(1, 6656, '\p{^Script= _Khmer}', "");
Expect(1, 6656, '\P{Script= _Khmer}', "");
Expect(0, 6656, '\P{^Script= _Khmer}', "");
Error('\p{Sc=	/a/khmr}');
Error('\P{Sc=	/a/khmr}');
Expect(1, 6655, '\p{Sc:khmr}', "");
Expect(0, 6655, '\p{^Sc:khmr}', "");
Expect(0, 6655, '\P{Sc:khmr}', "");
Expect(1, 6655, '\P{^Sc:khmr}', "");
Expect(0, 6656, '\p{Sc:khmr}', "");
Expect(1, 6656, '\p{^Sc:khmr}', "");
Expect(1, 6656, '\P{Sc:khmr}', "");
Expect(0, 6656, '\P{^Sc:khmr}', "");
Expect(1, 6655, '\p{Sc=_ khmr}', "");
Expect(0, 6655, '\p{^Sc=_ khmr}', "");
Expect(0, 6655, '\P{Sc=_ khmr}', "");
Expect(1, 6655, '\P{^Sc=_ khmr}', "");
Expect(0, 6656, '\p{Sc=_ khmr}', "");
Expect(1, 6656, '\p{^Sc=_ khmr}', "");
Expect(1, 6656, '\P{Sc=_ khmr}', "");
Expect(0, 6656, '\P{^Sc=_ khmr}', "");
Error('\p{Is_Script=/a/Khmer}');
Error('\P{Is_Script=/a/Khmer}');
Expect(1, 6655, '\p{Is_Script: khmer}', "");
Expect(0, 6655, '\p{^Is_Script: khmer}', "");
Expect(0, 6655, '\P{Is_Script: khmer}', "");
Expect(1, 6655, '\P{^Is_Script: khmer}', "");
Expect(0, 6656, '\p{Is_Script: khmer}', "");
Expect(1, 6656, '\p{^Is_Script: khmer}', "");
Expect(1, 6656, '\P{Is_Script: khmer}', "");
Expect(0, 6656, '\P{^Is_Script: khmer}', "");
Expect(1, 6655, '\p{Is_Script=-	khmer}', "");
Expect(0, 6655, '\p{^Is_Script=-	khmer}', "");
Expect(0, 6655, '\P{Is_Script=-	khmer}', "");
Expect(1, 6655, '\P{^Is_Script=-	khmer}', "");
Expect(0, 6656, '\p{Is_Script=-	khmer}', "");
Expect(1, 6656, '\p{^Is_Script=-	khmer}', "");
Expect(1, 6656, '\P{Is_Script=-	khmer}', "");
Expect(0, 6656, '\P{^Is_Script=-	khmer}', "");
Error('\p{Is_Sc::=- KHMR}');
Error('\P{Is_Sc::=- KHMR}');
Expect(1, 6655, '\p{Is_Sc=khmr}', "");
Expect(0, 6655, '\p{^Is_Sc=khmr}', "");
Expect(0, 6655, '\P{Is_Sc=khmr}', "");
Expect(1, 6655, '\P{^Is_Sc=khmr}', "");
Expect(0, 6656, '\p{Is_Sc=khmr}', "");
Expect(1, 6656, '\p{^Is_Sc=khmr}', "");
Expect(1, 6656, '\P{Is_Sc=khmr}', "");
Expect(0, 6656, '\P{^Is_Sc=khmr}', "");
Expect(1, 6655, '\p{Is_Sc=--Khmr}', "");
Expect(0, 6655, '\p{^Is_Sc=--Khmr}', "");
Expect(0, 6655, '\P{Is_Sc=--Khmr}', "");
Expect(1, 6655, '\P{^Is_Sc=--Khmr}', "");
Expect(0, 6656, '\p{Is_Sc=--Khmr}', "");
Expect(1, 6656, '\p{^Is_Sc=--Khmr}', "");
Expect(1, 6656, '\P{Is_Sc=--Khmr}', "");
Expect(0, 6656, '\P{^Is_Sc=--Khmr}', "");
Error('\p{Script=/a/Kannada}');
Error('\P{Script=/a/Kannada}');
Expect(1, 3314, '\p{Script=kannada}', "");
Expect(0, 3314, '\p{^Script=kannada}', "");
Expect(0, 3314, '\P{Script=kannada}', "");
Expect(1, 3314, '\P{^Script=kannada}', "");
Expect(0, 3315, '\p{Script=kannada}', "");
Expect(1, 3315, '\p{^Script=kannada}', "");
Expect(1, 3315, '\P{Script=kannada}', "");
Expect(0, 3315, '\P{^Script=kannada}', "");
Expect(1, 3314, '\p{Script=-_KANNADA}', "");
Expect(0, 3314, '\p{^Script=-_KANNADA}', "");
Expect(0, 3314, '\P{Script=-_KANNADA}', "");
Expect(1, 3314, '\P{^Script=-_KANNADA}', "");
Expect(0, 3315, '\p{Script=-_KANNADA}', "");
Expect(1, 3315, '\p{^Script=-_KANNADA}', "");
Expect(1, 3315, '\P{Script=-_KANNADA}', "");
Expect(0, 3315, '\P{^Script=-_KANNADA}', "");
Error('\p{Sc=	 Knda/a/}');
Error('\P{Sc=	 Knda/a/}');
Expect(1, 3314, '\p{Sc=knda}', "");
Expect(0, 3314, '\p{^Sc=knda}', "");
Expect(0, 3314, '\P{Sc=knda}', "");
Expect(1, 3314, '\P{^Sc=knda}', "");
Expect(0, 3315, '\p{Sc=knda}', "");
Expect(1, 3315, '\p{^Sc=knda}', "");
Expect(1, 3315, '\P{Sc=knda}', "");
Expect(0, 3315, '\P{^Sc=knda}', "");
Expect(1, 3314, '\p{Sc=	KNDA}', "");
Expect(0, 3314, '\p{^Sc=	KNDA}', "");
Expect(0, 3314, '\P{Sc=	KNDA}', "");
Expect(1, 3314, '\P{^Sc=	KNDA}', "");
Expect(0, 3315, '\p{Sc=	KNDA}', "");
Expect(1, 3315, '\p{^Sc=	KNDA}', "");
Expect(1, 3315, '\P{Sc=	KNDA}', "");
Expect(0, 3315, '\P{^Sc=	KNDA}', "");
Error('\p{Is_Script=/a/  Kannada}');
Error('\P{Is_Script=/a/  Kannada}');
Expect(1, 3314, '\p{Is_Script=kannada}', "");
Expect(0, 3314, '\p{^Is_Script=kannada}', "");
Expect(0, 3314, '\P{Is_Script=kannada}', "");
Expect(1, 3314, '\P{^Is_Script=kannada}', "");
Expect(0, 3315, '\p{Is_Script=kannada}', "");
Expect(1, 3315, '\p{^Is_Script=kannada}', "");
Expect(1, 3315, '\P{Is_Script=kannada}', "");
Expect(0, 3315, '\P{^Is_Script=kannada}', "");
Expect(1, 3314, '\p{Is_Script:	Kannada}', "");
Expect(0, 3314, '\p{^Is_Script:	Kannada}', "");
Expect(0, 3314, '\P{Is_Script:	Kannada}', "");
Expect(1, 3314, '\P{^Is_Script:	Kannada}', "");
Expect(0, 3315, '\p{Is_Script:	Kannada}', "");
Expect(1, 3315, '\p{^Is_Script:	Kannada}', "");
Expect(1, 3315, '\P{Is_Script:	Kannada}', "");
Expect(0, 3315, '\P{^Is_Script:	Kannada}', "");
Error('\p{Is_Sc=-Knda:=}');
Error('\P{Is_Sc=-Knda:=}');
Expect(1, 3314, '\p{Is_Sc: knda}', "");
Expect(0, 3314, '\p{^Is_Sc: knda}', "");
Expect(0, 3314, '\P{Is_Sc: knda}', "");
Expect(1, 3314, '\P{^Is_Sc: knda}', "");
Expect(0, 3315, '\p{Is_Sc: knda}', "");
Expect(1, 3315, '\p{^Is_Sc: knda}', "");
Expect(1, 3315, '\P{Is_Sc: knda}', "");
Expect(0, 3315, '\P{^Is_Sc: knda}', "");
Expect(1, 3314, '\p{Is_Sc=_KNDA}', "");
Expect(0, 3314, '\p{^Is_Sc=_KNDA}', "");
Expect(0, 3314, '\P{Is_Sc=_KNDA}', "");
Expect(1, 3314, '\P{^Is_Sc=_KNDA}', "");
Expect(0, 3315, '\p{Is_Sc=_KNDA}', "");
Expect(1, 3315, '\p{^Is_Sc=_KNDA}', "");
Expect(1, 3315, '\P{Is_Sc=_KNDA}', "");
Expect(0, 3315, '\P{^Is_Sc=_KNDA}', "");
Error('\p{Script=_/a/kaithi}');
Error('\P{Script=_/a/kaithi}');
Expect(1, 69825, '\p{Script=kaithi}', "");
Expect(0, 69825, '\p{^Script=kaithi}', "");
Expect(0, 69825, '\P{Script=kaithi}', "");
Expect(1, 69825, '\P{^Script=kaithi}', "");
Expect(0, 69826, '\p{Script=kaithi}', "");
Expect(1, 69826, '\p{^Script=kaithi}', "");
Expect(1, 69826, '\P{Script=kaithi}', "");
Expect(0, 69826, '\P{^Script=kaithi}', "");
Expect(1, 69825, '\p{Script=		KAITHI}', "");
Expect(0, 69825, '\p{^Script=		KAITHI}', "");
Expect(0, 69825, '\P{Script=		KAITHI}', "");
Expect(1, 69825, '\P{^Script=		KAITHI}', "");
Expect(0, 69826, '\p{Script=		KAITHI}', "");
Expect(1, 69826, '\p{^Script=		KAITHI}', "");
Expect(1, 69826, '\P{Script=		KAITHI}', "");
Expect(0, 69826, '\P{^Script=		KAITHI}', "");
Error('\p{Sc=-_KTHI/a/}');
Error('\P{Sc=-_KTHI/a/}');
Expect(1, 69825, '\p{Sc=kthi}', "");
Expect(0, 69825, '\p{^Sc=kthi}', "");
Expect(0, 69825, '\P{Sc=kthi}', "");
Expect(1, 69825, '\P{^Sc=kthi}', "");
Expect(0, 69826, '\p{Sc=kthi}', "");
Expect(1, 69826, '\p{^Sc=kthi}', "");
Expect(1, 69826, '\P{Sc=kthi}', "");
Expect(0, 69826, '\P{^Sc=kthi}', "");
Expect(1, 69825, '\p{Sc:   -_Kthi}', "");
Expect(0, 69825, '\p{^Sc:   -_Kthi}', "");
Expect(0, 69825, '\P{Sc:   -_Kthi}', "");
Expect(1, 69825, '\P{^Sc:   -_Kthi}', "");
Expect(0, 69826, '\p{Sc:   -_Kthi}', "");
Expect(1, 69826, '\p{^Sc:   -_Kthi}', "");
Expect(1, 69826, '\P{Sc:   -_Kthi}', "");
Expect(0, 69826, '\P{^Sc:   -_Kthi}', "");
Error('\p{Is_Script=- Kaithi/a/}');
Error('\P{Is_Script=- Kaithi/a/}');
Expect(1, 69825, '\p{Is_Script=kaithi}', "");
Expect(0, 69825, '\p{^Is_Script=kaithi}', "");
Expect(0, 69825, '\P{Is_Script=kaithi}', "");
Expect(1, 69825, '\P{^Is_Script=kaithi}', "");
Expect(0, 69826, '\p{Is_Script=kaithi}', "");
Expect(1, 69826, '\p{^Is_Script=kaithi}', "");
Expect(1, 69826, '\P{Is_Script=kaithi}', "");
Expect(0, 69826, '\P{^Is_Script=kaithi}', "");
Expect(1, 69825, '\p{Is_Script=  Kaithi}', "");
Expect(0, 69825, '\p{^Is_Script=  Kaithi}', "");
Expect(0, 69825, '\P{Is_Script=  Kaithi}', "");
Expect(1, 69825, '\P{^Is_Script=  Kaithi}', "");
Expect(0, 69826, '\p{Is_Script=  Kaithi}', "");
Expect(1, 69826, '\p{^Is_Script=  Kaithi}', "");
Expect(1, 69826, '\P{Is_Script=  Kaithi}', "");
Expect(0, 69826, '\P{^Is_Script=  Kaithi}', "");
Error('\p{Is_Sc=/a/_ kthi}');
Error('\P{Is_Sc=/a/_ kthi}');
Expect(1, 69825, '\p{Is_Sc:kthi}', "");
Expect(0, 69825, '\p{^Is_Sc:kthi}', "");
Expect(0, 69825, '\P{Is_Sc:kthi}', "");
Expect(1, 69825, '\P{^Is_Sc:kthi}', "");
Expect(0, 69826, '\p{Is_Sc:kthi}', "");
Expect(1, 69826, '\p{^Is_Sc:kthi}', "");
Expect(1, 69826, '\P{Is_Sc:kthi}', "");
Expect(0, 69826, '\P{^Is_Sc:kthi}', "");
Expect(1, 69825, '\p{Is_Sc=  Kthi}', "");
Expect(0, 69825, '\p{^Is_Sc=  Kthi}', "");
Expect(0, 69825, '\P{Is_Sc=  Kthi}', "");
Expect(1, 69825, '\P{^Is_Sc=  Kthi}', "");
Expect(0, 69826, '\p{Is_Sc=  Kthi}', "");
Expect(1, 69826, '\p{^Is_Sc=  Kthi}', "");
Expect(1, 69826, '\P{Is_Sc=  Kthi}', "");
Expect(0, 69826, '\P{^Is_Sc=  Kthi}', "");
Error('\p{Script:		-tai_Tham/a/}');
Error('\P{Script:		-tai_Tham/a/}');
Expect(1, 6829, '\p{Script=taitham}', "");
Expect(0, 6829, '\p{^Script=taitham}', "");
Expect(0, 6829, '\P{Script=taitham}', "");
Expect(1, 6829, '\P{^Script=taitham}', "");
Expect(0, 6830, '\p{Script=taitham}', "");
Expect(1, 6830, '\p{^Script=taitham}', "");
Expect(1, 6830, '\P{Script=taitham}', "");
Expect(0, 6830, '\P{^Script=taitham}', "");
Expect(1, 6829, '\p{Script=- Tai_THAM}', "");
Expect(0, 6829, '\p{^Script=- Tai_THAM}', "");
Expect(0, 6829, '\P{Script=- Tai_THAM}', "");
Expect(1, 6829, '\P{^Script=- Tai_THAM}', "");
Expect(0, 6830, '\p{Script=- Tai_THAM}', "");
Expect(1, 6830, '\p{^Script=- Tai_THAM}', "");
Expect(1, 6830, '\P{Script=- Tai_THAM}', "");
Expect(0, 6830, '\P{^Script=- Tai_THAM}', "");
Error('\p{Sc=-	Lana/a/}');
Error('\P{Sc=-	Lana/a/}');
Expect(1, 6829, '\p{Sc=lana}', "");
Expect(0, 6829, '\p{^Sc=lana}', "");
Expect(0, 6829, '\P{Sc=lana}', "");
Expect(1, 6829, '\P{^Sc=lana}', "");
Expect(0, 6830, '\p{Sc=lana}', "");
Expect(1, 6830, '\p{^Sc=lana}', "");
Expect(1, 6830, '\P{Sc=lana}', "");
Expect(0, 6830, '\P{^Sc=lana}', "");
Expect(1, 6829, '\p{Sc=	_Lana}', "");
Expect(0, 6829, '\p{^Sc=	_Lana}', "");
Expect(0, 6829, '\P{Sc=	_Lana}', "");
Expect(1, 6829, '\P{^Sc=	_Lana}', "");
Expect(0, 6830, '\p{Sc=	_Lana}', "");
Expect(1, 6830, '\p{^Sc=	_Lana}', "");
Expect(1, 6830, '\P{Sc=	_Lana}', "");
Expect(0, 6830, '\P{^Sc=	_Lana}', "");
Error('\p{Is_Script=/a/__tai_Tham}');
Error('\P{Is_Script=/a/__tai_Tham}');
Expect(1, 6829, '\p{Is_Script=taitham}', "");
Expect(0, 6829, '\p{^Is_Script=taitham}', "");
Expect(0, 6829, '\P{Is_Script=taitham}', "");
Expect(1, 6829, '\P{^Is_Script=taitham}', "");
Expect(0, 6830, '\p{Is_Script=taitham}', "");
Expect(1, 6830, '\p{^Is_Script=taitham}', "");
Expect(1, 6830, '\P{Is_Script=taitham}', "");
Expect(0, 6830, '\P{^Is_Script=taitham}', "");
Expect(1, 6829, '\p{Is_Script=	 Tai_THAM}', "");
Expect(0, 6829, '\p{^Is_Script=	 Tai_THAM}', "");
Expect(0, 6829, '\P{Is_Script=	 Tai_THAM}', "");
Expect(1, 6829, '\P{^Is_Script=	 Tai_THAM}', "");
Expect(0, 6830, '\p{Is_Script=	 Tai_THAM}', "");
Expect(1, 6830, '\p{^Is_Script=	 Tai_THAM}', "");
Expect(1, 6830, '\P{Is_Script=	 Tai_THAM}', "");
Expect(0, 6830, '\P{^Is_Script=	 Tai_THAM}', "");
Error('\p{Is_Sc=:=_lana}');
Error('\P{Is_Sc=:=_lana}');
Expect(1, 6829, '\p{Is_Sc=lana}', "");
Expect(0, 6829, '\p{^Is_Sc=lana}', "");
Expect(0, 6829, '\P{Is_Sc=lana}', "");
Expect(1, 6829, '\P{^Is_Sc=lana}', "");
Expect(0, 6830, '\p{Is_Sc=lana}', "");
Expect(1, 6830, '\p{^Is_Sc=lana}', "");
Expect(1, 6830, '\P{Is_Sc=lana}', "");
Expect(0, 6830, '\P{^Is_Sc=lana}', "");
Expect(1, 6829, '\p{Is_Sc= 	Lana}', "");
Expect(0, 6829, '\p{^Is_Sc= 	Lana}', "");
Expect(0, 6829, '\P{Is_Sc= 	Lana}', "");
Expect(1, 6829, '\P{^Is_Sc= 	Lana}', "");
Expect(0, 6830, '\p{Is_Sc= 	Lana}', "");
Expect(1, 6830, '\p{^Is_Sc= 	Lana}', "");
Expect(1, 6830, '\P{Is_Sc= 	Lana}', "");
Expect(0, 6830, '\P{^Is_Sc= 	Lana}', "");
Error('\p{Script=-lao:=}');
Error('\P{Script=-lao:=}');
Expect(1, 3807, '\p{Script=lao}', "");
Expect(0, 3807, '\p{^Script=lao}', "");
Expect(0, 3807, '\P{Script=lao}', "");
Expect(1, 3807, '\P{^Script=lao}', "");
Expect(0, 3808, '\p{Script=lao}', "");
Expect(1, 3808, '\p{^Script=lao}', "");
Expect(1, 3808, '\P{Script=lao}', "");
Expect(0, 3808, '\P{^Script=lao}', "");
Expect(1, 3807, '\p{Script= lao}', "");
Expect(0, 3807, '\p{^Script= lao}', "");
Expect(0, 3807, '\P{Script= lao}', "");
Expect(1, 3807, '\P{^Script= lao}', "");
Expect(0, 3808, '\p{Script= lao}', "");
Expect(1, 3808, '\p{^Script= lao}', "");
Expect(1, 3808, '\P{Script= lao}', "");
Expect(0, 3808, '\P{^Script= lao}', "");
Error('\p{Sc=  Laoo:=}');
Error('\P{Sc=  Laoo:=}');
Expect(1, 3807, '\p{Sc=laoo}', "");
Expect(0, 3807, '\p{^Sc=laoo}', "");
Expect(0, 3807, '\P{Sc=laoo}', "");
Expect(1, 3807, '\P{^Sc=laoo}', "");
Expect(0, 3808, '\p{Sc=laoo}', "");
Expect(1, 3808, '\p{^Sc=laoo}', "");
Expect(1, 3808, '\P{Sc=laoo}', "");
Expect(0, 3808, '\P{^Sc=laoo}', "");
Expect(1, 3807, '\p{Sc=	 laoo}', "");
Expect(0, 3807, '\p{^Sc=	 laoo}', "");
Expect(0, 3807, '\P{Sc=	 laoo}', "");
Expect(1, 3807, '\P{^Sc=	 laoo}', "");
Expect(0, 3808, '\p{Sc=	 laoo}', "");
Expect(1, 3808, '\p{^Sc=	 laoo}', "");
Expect(1, 3808, '\P{Sc=	 laoo}', "");
Expect(0, 3808, '\P{^Sc=	 laoo}', "");
Error('\p{Is_Script=:= Lao}');
Error('\P{Is_Script=:= Lao}');
Expect(1, 3807, '\p{Is_Script=lao}', "");
Expect(0, 3807, '\p{^Is_Script=lao}', "");
Expect(0, 3807, '\P{Is_Script=lao}', "");
Expect(1, 3807, '\P{^Is_Script=lao}', "");
Expect(0, 3808, '\p{Is_Script=lao}', "");
Expect(1, 3808, '\p{^Is_Script=lao}', "");
Expect(1, 3808, '\P{Is_Script=lao}', "");
Expect(0, 3808, '\P{^Is_Script=lao}', "");
Expect(1, 3807, '\p{Is_Script=_-Lao}', "");
Expect(0, 3807, '\p{^Is_Script=_-Lao}', "");
Expect(0, 3807, '\P{Is_Script=_-Lao}', "");
Expect(1, 3807, '\P{^Is_Script=_-Lao}', "");
Expect(0, 3808, '\p{Is_Script=_-Lao}', "");
Expect(1, 3808, '\p{^Is_Script=_-Lao}', "");
Expect(1, 3808, '\P{Is_Script=_-Lao}', "");
Expect(0, 3808, '\P{^Is_Script=_-Lao}', "");
Error('\p{Is_Sc=:=_-LAOO}');
Error('\P{Is_Sc=:=_-LAOO}');
Expect(1, 3807, '\p{Is_Sc=laoo}', "");
Expect(0, 3807, '\p{^Is_Sc=laoo}', "");
Expect(0, 3807, '\P{Is_Sc=laoo}', "");
Expect(1, 3807, '\P{^Is_Sc=laoo}', "");
Expect(0, 3808, '\p{Is_Sc=laoo}', "");
Expect(1, 3808, '\p{^Is_Sc=laoo}', "");
Expect(1, 3808, '\P{Is_Sc=laoo}', "");
Expect(0, 3808, '\P{^Is_Sc=laoo}', "");
Expect(1, 3807, '\p{Is_Sc= -Laoo}', "");
Expect(0, 3807, '\p{^Is_Sc= -Laoo}', "");
Expect(0, 3807, '\P{Is_Sc= -Laoo}', "");
Expect(1, 3807, '\P{^Is_Sc= -Laoo}', "");
Expect(0, 3808, '\p{Is_Sc= -Laoo}', "");
Expect(1, 3808, '\p{^Is_Sc= -Laoo}', "");
Expect(1, 3808, '\P{Is_Sc= -Laoo}', "");
Expect(0, 3808, '\P{^Is_Sc= -Laoo}', "");
Error('\p{Script=-latin/a/}');
Error('\P{Script=-latin/a/}');
Expect(1, 65370, '\p{Script=latin}', "");
Expect(0, 65370, '\p{^Script=latin}', "");
Expect(0, 65370, '\P{Script=latin}', "");
Expect(1, 65370, '\P{^Script=latin}', "");
Expect(0, 65371, '\p{Script=latin}', "");
Expect(1, 65371, '\p{^Script=latin}', "");
Expect(1, 65371, '\P{Script=latin}', "");
Expect(0, 65371, '\P{^Script=latin}', "");
Expect(1, 65370, '\p{Script=_	LATIN}', "");
Expect(0, 65370, '\p{^Script=_	LATIN}', "");
Expect(0, 65370, '\P{Script=_	LATIN}', "");
Expect(1, 65370, '\P{^Script=_	LATIN}', "");
Expect(0, 65371, '\p{Script=_	LATIN}', "");
Expect(1, 65371, '\p{^Script=_	LATIN}', "");
Expect(1, 65371, '\P{Script=_	LATIN}', "");
Expect(0, 65371, '\P{^Script=_	LATIN}', "");
Error('\p{Sc=_/a/LATN}');
Error('\P{Sc=_/a/LATN}');
Expect(1, 65370, '\p{Sc=latn}', "");
Expect(0, 65370, '\p{^Sc=latn}', "");
Expect(0, 65370, '\P{Sc=latn}', "");
Expect(1, 65370, '\P{^Sc=latn}', "");
Expect(0, 65371, '\p{Sc=latn}', "");
Expect(1, 65371, '\p{^Sc=latn}', "");
Expect(1, 65371, '\P{Sc=latn}', "");
Expect(0, 65371, '\P{^Sc=latn}', "");
Expect(1, 65370, '\p{Sc= Latn}', "");
Expect(0, 65370, '\p{^Sc= Latn}', "");
Expect(0, 65370, '\P{Sc= Latn}', "");
Expect(1, 65370, '\P{^Sc= Latn}', "");
Expect(0, 65371, '\p{Sc= Latn}', "");
Expect(1, 65371, '\p{^Sc= Latn}', "");
Expect(1, 65371, '\P{Sc= Latn}', "");
Expect(0, 65371, '\P{^Sc= Latn}', "");
Error('\p{Is_Script=_:=LATIN}');
Error('\P{Is_Script=_:=LATIN}');
Expect(1, 65370, '\p{Is_Script:latin}', "");
Expect(0, 65370, '\p{^Is_Script:latin}', "");
Expect(0, 65370, '\P{Is_Script:latin}', "");
Expect(1, 65370, '\P{^Is_Script:latin}', "");
Expect(0, 65371, '\p{Is_Script:latin}', "");
Expect(1, 65371, '\p{^Is_Script:latin}', "");
Expect(1, 65371, '\P{Is_Script:latin}', "");
Expect(0, 65371, '\P{^Is_Script:latin}', "");
Expect(1, 65370, '\p{Is_Script:    -LATIN}', "");
Expect(0, 65370, '\p{^Is_Script:    -LATIN}', "");
Expect(0, 65370, '\P{Is_Script:    -LATIN}', "");
Expect(1, 65370, '\P{^Is_Script:    -LATIN}', "");
Expect(0, 65371, '\p{Is_Script:    -LATIN}', "");
Expect(1, 65371, '\p{^Is_Script:    -LATIN}', "");
Expect(1, 65371, '\P{Is_Script:    -LATIN}', "");
Expect(0, 65371, '\P{^Is_Script:    -LATIN}', "");
Error('\p{Is_Sc= :=Latn}');
Error('\P{Is_Sc= :=Latn}');
Expect(1, 65370, '\p{Is_Sc=latn}', "");
Expect(0, 65370, '\p{^Is_Sc=latn}', "");
Expect(0, 65370, '\P{Is_Sc=latn}', "");
Expect(1, 65370, '\P{^Is_Sc=latn}', "");
Expect(0, 65371, '\p{Is_Sc=latn}', "");
Expect(1, 65371, '\p{^Is_Sc=latn}', "");
Expect(1, 65371, '\P{Is_Sc=latn}', "");
Expect(0, 65371, '\P{^Is_Sc=latn}', "");
Expect(1, 65370, '\p{Is_Sc=-_latn}', "");
Expect(0, 65370, '\p{^Is_Sc=-_latn}', "");
Expect(0, 65370, '\P{Is_Sc=-_latn}', "");
Expect(1, 65370, '\P{^Is_Sc=-_latn}', "");
Expect(0, 65371, '\p{Is_Sc=-_latn}', "");
Expect(1, 65371, '\p{^Is_Sc=-_latn}', "");
Expect(1, 65371, '\P{Is_Sc=-_latn}', "");
Expect(0, 65371, '\P{^Is_Sc=-_latn}', "");
Error('\p{Script=:= LEPCHA}');
Error('\P{Script=:= LEPCHA}');
Expect(1, 7247, '\p{Script=lepcha}', "");
Expect(0, 7247, '\p{^Script=lepcha}', "");
Expect(0, 7247, '\P{Script=lepcha}', "");
Expect(1, 7247, '\P{^Script=lepcha}', "");
Expect(0, 7248, '\p{Script=lepcha}', "");
Expect(1, 7248, '\p{^Script=lepcha}', "");
Expect(1, 7248, '\P{Script=lepcha}', "");
Expect(0, 7248, '\P{^Script=lepcha}', "");
Expect(1, 7247, '\p{Script=- Lepcha}', "");
Expect(0, 7247, '\p{^Script=- Lepcha}', "");
Expect(0, 7247, '\P{Script=- Lepcha}', "");
Expect(1, 7247, '\P{^Script=- Lepcha}', "");
Expect(0, 7248, '\p{Script=- Lepcha}', "");
Expect(1, 7248, '\p{^Script=- Lepcha}', "");
Expect(1, 7248, '\P{Script=- Lepcha}', "");
Expect(0, 7248, '\P{^Script=- Lepcha}', "");
Error('\p{Sc=_/a/LEPC}');
Error('\P{Sc=_/a/LEPC}');
Expect(1, 7247, '\p{Sc=lepc}', "");
Expect(0, 7247, '\p{^Sc=lepc}', "");
Expect(0, 7247, '\P{Sc=lepc}', "");
Expect(1, 7247, '\P{^Sc=lepc}', "");
Expect(0, 7248, '\p{Sc=lepc}', "");
Expect(1, 7248, '\p{^Sc=lepc}', "");
Expect(1, 7248, '\P{Sc=lepc}', "");
Expect(0, 7248, '\P{^Sc=lepc}', "");
Expect(1, 7247, '\p{Sc= 	Lepc}', "");
Expect(0, 7247, '\p{^Sc= 	Lepc}', "");
Expect(0, 7247, '\P{Sc= 	Lepc}', "");
Expect(1, 7247, '\P{^Sc= 	Lepc}', "");
Expect(0, 7248, '\p{Sc= 	Lepc}', "");
Expect(1, 7248, '\p{^Sc= 	Lepc}', "");
Expect(1, 7248, '\P{Sc= 	Lepc}', "");
Expect(0, 7248, '\P{^Sc= 	Lepc}', "");
Error('\p{Is_Script:   :=	_Lepcha}');
Error('\P{Is_Script:   :=	_Lepcha}');
Expect(1, 7247, '\p{Is_Script=lepcha}', "");
Expect(0, 7247, '\p{^Is_Script=lepcha}', "");
Expect(0, 7247, '\P{Is_Script=lepcha}', "");
Expect(1, 7247, '\P{^Is_Script=lepcha}', "");
Expect(0, 7248, '\p{Is_Script=lepcha}', "");
Expect(1, 7248, '\p{^Is_Script=lepcha}', "");
Expect(1, 7248, '\P{Is_Script=lepcha}', "");
Expect(0, 7248, '\P{^Is_Script=lepcha}', "");
Expect(1, 7247, '\p{Is_Script=-	Lepcha}', "");
Expect(0, 7247, '\p{^Is_Script=-	Lepcha}', "");
Expect(0, 7247, '\P{Is_Script=-	Lepcha}', "");
Expect(1, 7247, '\P{^Is_Script=-	Lepcha}', "");
Expect(0, 7248, '\p{Is_Script=-	Lepcha}', "");
Expect(1, 7248, '\p{^Is_Script=-	Lepcha}', "");
Expect(1, 7248, '\P{Is_Script=-	Lepcha}', "");
Expect(0, 7248, '\P{^Is_Script=-	Lepcha}', "");
Error('\p{Is_Sc=/a/LEPC}');
Error('\P{Is_Sc=/a/LEPC}');
Expect(1, 7247, '\p{Is_Sc=lepc}', "");
Expect(0, 7247, '\p{^Is_Sc=lepc}', "");
Expect(0, 7247, '\P{Is_Sc=lepc}', "");
Expect(1, 7247, '\P{^Is_Sc=lepc}', "");
Expect(0, 7248, '\p{Is_Sc=lepc}', "");
Expect(1, 7248, '\p{^Is_Sc=lepc}', "");
Expect(1, 7248, '\P{Is_Sc=lepc}', "");
Expect(0, 7248, '\P{^Is_Sc=lepc}', "");
Expect(1, 7247, '\p{Is_Sc= -lepc}', "");
Expect(0, 7247, '\p{^Is_Sc= -lepc}', "");
Expect(0, 7247, '\P{Is_Sc= -lepc}', "");
Expect(1, 7247, '\P{^Is_Sc= -lepc}', "");
Expect(0, 7248, '\p{Is_Sc= -lepc}', "");
Expect(1, 7248, '\p{^Is_Sc= -lepc}', "");
Expect(1, 7248, '\P{Is_Sc= -lepc}', "");
Expect(0, 7248, '\P{^Is_Sc= -lepc}', "");
Error('\p{Script=-limbu:=}');
Error('\P{Script=-limbu:=}');
Expect(1, 6479, '\p{Script:limbu}', "");
Expect(0, 6479, '\p{^Script:limbu}', "");
Expect(0, 6479, '\P{Script:limbu}', "");
Expect(1, 6479, '\P{^Script:limbu}', "");
Expect(0, 6480, '\p{Script:limbu}', "");
Expect(1, 6480, '\p{^Script:limbu}', "");
Expect(1, 6480, '\P{Script:limbu}', "");
Expect(0, 6480, '\P{^Script:limbu}', "");
Expect(1, 6479, '\p{Script: -Limbu}', "");
Expect(0, 6479, '\p{^Script: -Limbu}', "");
Expect(0, 6479, '\P{Script: -Limbu}', "");
Expect(1, 6479, '\P{^Script: -Limbu}', "");
Expect(0, 6480, '\p{Script: -Limbu}', "");
Expect(1, 6480, '\p{^Script: -Limbu}', "");
Expect(1, 6480, '\P{Script: -Limbu}', "");
Expect(0, 6480, '\P{^Script: -Limbu}', "");
Error('\p{Sc=	/a/Limb}');
Error('\P{Sc=	/a/Limb}');
Expect(1, 6479, '\p{Sc=limb}', "");
Expect(0, 6479, '\p{^Sc=limb}', "");
Expect(0, 6479, '\P{Sc=limb}', "");
Expect(1, 6479, '\P{^Sc=limb}', "");
Expect(0, 6480, '\p{Sc=limb}', "");
Expect(1, 6480, '\p{^Sc=limb}', "");
Expect(1, 6480, '\P{Sc=limb}', "");
Expect(0, 6480, '\P{^Sc=limb}', "");
Expect(1, 6479, '\p{Sc= _Limb}', "");
Expect(0, 6479, '\p{^Sc= _Limb}', "");
Expect(0, 6479, '\P{Sc= _Limb}', "");
Expect(1, 6479, '\P{^Sc= _Limb}', "");
Expect(0, 6480, '\p{Sc= _Limb}', "");
Expect(1, 6480, '\p{^Sc= _Limb}', "");
Expect(1, 6480, '\P{Sc= _Limb}', "");
Expect(0, 6480, '\P{^Sc= _Limb}', "");
Error('\p{Is_Script=/a/-Limbu}');
Error('\P{Is_Script=/a/-Limbu}');
Expect(1, 6479, '\p{Is_Script=limbu}', "");
Expect(0, 6479, '\p{^Is_Script=limbu}', "");
Expect(0, 6479, '\P{Is_Script=limbu}', "");
Expect(1, 6479, '\P{^Is_Script=limbu}', "");
Expect(0, 6480, '\p{Is_Script=limbu}', "");
Expect(1, 6480, '\p{^Is_Script=limbu}', "");
Expect(1, 6480, '\P{Is_Script=limbu}', "");
Expect(0, 6480, '\P{^Is_Script=limbu}', "");
Expect(1, 6479, '\p{Is_Script=	_Limbu}', "");
Expect(0, 6479, '\p{^Is_Script=	_Limbu}', "");
Expect(0, 6479, '\P{Is_Script=	_Limbu}', "");
Expect(1, 6479, '\P{^Is_Script=	_Limbu}', "");
Expect(0, 6480, '\p{Is_Script=	_Limbu}', "");
Expect(1, 6480, '\p{^Is_Script=	_Limbu}', "");
Expect(1, 6480, '\P{Is_Script=	_Limbu}', "");
Expect(0, 6480, '\P{^Is_Script=	_Limbu}', "");
Error('\p{Is_Sc=:=_LIMB}');
Error('\P{Is_Sc=:=_LIMB}');
Expect(1, 6479, '\p{Is_Sc=limb}', "");
Expect(0, 6479, '\p{^Is_Sc=limb}', "");
Expect(0, 6479, '\P{Is_Sc=limb}', "");
Expect(1, 6479, '\P{^Is_Sc=limb}', "");
Expect(0, 6480, '\p{Is_Sc=limb}', "");
Expect(1, 6480, '\p{^Is_Sc=limb}', "");
Expect(1, 6480, '\P{Is_Sc=limb}', "");
Expect(0, 6480, '\P{^Is_Sc=limb}', "");
Expect(1, 6479, '\p{Is_Sc=__LIMB}', "");
Expect(0, 6479, '\p{^Is_Sc=__LIMB}', "");
Expect(0, 6479, '\P{Is_Sc=__LIMB}', "");
Expect(1, 6479, '\P{^Is_Sc=__LIMB}', "");
Expect(0, 6480, '\p{Is_Sc=__LIMB}', "");
Expect(1, 6480, '\p{^Is_Sc=__LIMB}', "");
Expect(1, 6480, '\P{Is_Sc=__LIMB}', "");
Expect(0, 6480, '\P{^Is_Sc=__LIMB}', "");
Error('\p{Script=/a/ LINEAR_B}');
Error('\P{Script=/a/ LINEAR_B}');
Expect(1, 65786, '\p{Script=linearb}', "");
Expect(0, 65786, '\p{^Script=linearb}', "");
Expect(0, 65786, '\P{Script=linearb}', "");
Expect(1, 65786, '\P{^Script=linearb}', "");
Expect(0, 65787, '\p{Script=linearb}', "");
Expect(1, 65787, '\p{^Script=linearb}', "");
Expect(1, 65787, '\P{Script=linearb}', "");
Expect(0, 65787, '\P{^Script=linearb}', "");
Expect(1, 65786, '\p{Script= 	Linear_B}', "");
Expect(0, 65786, '\p{^Script= 	Linear_B}', "");
Expect(0, 65786, '\P{Script= 	Linear_B}', "");
Expect(1, 65786, '\P{^Script= 	Linear_B}', "");
Expect(0, 65787, '\p{Script= 	Linear_B}', "");
Expect(1, 65787, '\p{^Script= 	Linear_B}', "");
Expect(1, 65787, '\P{Script= 	Linear_B}', "");
Expect(0, 65787, '\P{^Script= 	Linear_B}', "");
Error('\p{Sc=/a/-Linb}');
Error('\P{Sc=/a/-Linb}');
Expect(1, 65786, '\p{Sc=linb}', "");
Expect(0, 65786, '\p{^Sc=linb}', "");
Expect(0, 65786, '\P{Sc=linb}', "");
Expect(1, 65786, '\P{^Sc=linb}', "");
Expect(0, 65787, '\p{Sc=linb}', "");
Expect(1, 65787, '\p{^Sc=linb}', "");
Expect(1, 65787, '\P{Sc=linb}', "");
Expect(0, 65787, '\P{^Sc=linb}', "");
Expect(1, 65786, '\p{Sc=	LINB}', "");
Expect(0, 65786, '\p{^Sc=	LINB}', "");
Expect(0, 65786, '\P{Sc=	LINB}', "");
Expect(1, 65786, '\P{^Sc=	LINB}', "");
Expect(0, 65787, '\p{Sc=	LINB}', "");
Expect(1, 65787, '\p{^Sc=	LINB}', "");
Expect(1, 65787, '\P{Sc=	LINB}', "");
Expect(0, 65787, '\P{^Sc=	LINB}', "");
Error('\p{Is_Script: -	Linear_b/a/}');
Error('\P{Is_Script: -	Linear_b/a/}');
Expect(1, 65786, '\p{Is_Script=linearb}', "");
Expect(0, 65786, '\p{^Is_Script=linearb}', "");
Expect(0, 65786, '\P{Is_Script=linearb}', "");
Expect(1, 65786, '\P{^Is_Script=linearb}', "");
Expect(0, 65787, '\p{Is_Script=linearb}', "");
Expect(1, 65787, '\p{^Is_Script=linearb}', "");
Expect(1, 65787, '\P{Is_Script=linearb}', "");
Expect(0, 65787, '\P{^Is_Script=linearb}', "");
Expect(1, 65786, '\p{Is_Script=_-Linear_B}', "");
Expect(0, 65786, '\p{^Is_Script=_-Linear_B}', "");
Expect(0, 65786, '\P{Is_Script=_-Linear_B}', "");
Expect(1, 65786, '\P{^Is_Script=_-Linear_B}', "");
Expect(0, 65787, '\p{Is_Script=_-Linear_B}', "");
Expect(1, 65787, '\p{^Is_Script=_-Linear_B}', "");
Expect(1, 65787, '\P{Is_Script=_-Linear_B}', "");
Expect(0, 65787, '\P{^Is_Script=_-Linear_B}', "");
Error('\p{Is_Sc=	-Linb/a/}');
Error('\P{Is_Sc=	-Linb/a/}');
Expect(1, 65786, '\p{Is_Sc:linb}', "");
Expect(0, 65786, '\p{^Is_Sc:linb}', "");
Expect(0, 65786, '\P{Is_Sc:linb}', "");
Expect(1, 65786, '\P{^Is_Sc:linb}', "");
Expect(0, 65787, '\p{Is_Sc:linb}', "");
Expect(1, 65787, '\p{^Is_Sc:linb}', "");
Expect(1, 65787, '\P{Is_Sc:linb}', "");
Expect(0, 65787, '\P{^Is_Sc:linb}', "");
Expect(1, 65786, '\p{Is_Sc=	Linb}', "");
Expect(0, 65786, '\p{^Is_Sc=	Linb}', "");
Expect(0, 65786, '\P{Is_Sc=	Linb}', "");
Expect(1, 65786, '\P{^Is_Sc=	Linb}', "");
Expect(0, 65787, '\p{Is_Sc=	Linb}', "");
Expect(1, 65787, '\p{^Is_Sc=	Linb}', "");
Expect(1, 65787, '\P{Is_Sc=	Linb}', "");
Expect(0, 65787, '\P{^Is_Sc=	Linb}', "");
Error('\p{Script=:=__Lisu}');
Error('\P{Script=:=__Lisu}');
Expect(1, 42239, '\p{Script=lisu}', "");
Expect(0, 42239, '\p{^Script=lisu}', "");
Expect(0, 42239, '\P{Script=lisu}', "");
Expect(1, 42239, '\P{^Script=lisu}', "");
Expect(0, 42240, '\p{Script=lisu}', "");
Expect(1, 42240, '\p{^Script=lisu}', "");
Expect(1, 42240, '\P{Script=lisu}', "");
Expect(0, 42240, '\P{^Script=lisu}', "");
Expect(1, 42239, '\p{Script=_	Lisu}', "");
Expect(0, 42239, '\p{^Script=_	Lisu}', "");
Expect(0, 42239, '\P{Script=_	Lisu}', "");
Expect(1, 42239, '\P{^Script=_	Lisu}', "");
Expect(0, 42240, '\p{Script=_	Lisu}', "");
Expect(1, 42240, '\p{^Script=_	Lisu}', "");
Expect(1, 42240, '\P{Script=_	Lisu}', "");
Expect(0, 42240, '\P{^Script=_	Lisu}', "");
Error('\p{Sc: Lisu:=}');
Error('\P{Sc: Lisu:=}');
Expect(1, 42239, '\p{Sc=lisu}', "");
Expect(0, 42239, '\p{^Sc=lisu}', "");
Expect(0, 42239, '\P{Sc=lisu}', "");
Expect(1, 42239, '\P{^Sc=lisu}', "");
Expect(0, 42240, '\p{Sc=lisu}', "");
Expect(1, 42240, '\p{^Sc=lisu}', "");
Expect(1, 42240, '\P{Sc=lisu}', "");
Expect(0, 42240, '\P{^Sc=lisu}', "");
Expect(1, 42239, '\p{Sc=	 Lisu}', "");
Expect(0, 42239, '\p{^Sc=	 Lisu}', "");
Expect(0, 42239, '\P{Sc=	 Lisu}', "");
Expect(1, 42239, '\P{^Sc=	 Lisu}', "");
Expect(0, 42240, '\p{Sc=	 Lisu}', "");
Expect(1, 42240, '\p{^Sc=	 Lisu}', "");
Expect(1, 42240, '\P{Sc=	 Lisu}', "");
Expect(0, 42240, '\P{^Sc=	 Lisu}', "");
Error('\p{Is_Script:   -lisu/a/}');
Error('\P{Is_Script:   -lisu/a/}');
Expect(1, 42239, '\p{Is_Script=lisu}', "");
Expect(0, 42239, '\p{^Is_Script=lisu}', "");
Expect(0, 42239, '\P{Is_Script=lisu}', "");
Expect(1, 42239, '\P{^Is_Script=lisu}', "");
Expect(0, 42240, '\p{Is_Script=lisu}', "");
Expect(1, 42240, '\p{^Is_Script=lisu}', "");
Expect(1, 42240, '\P{Is_Script=lisu}', "");
Expect(0, 42240, '\P{^Is_Script=lisu}', "");
Expect(1, 42239, '\p{Is_Script=-	Lisu}', "");
Expect(0, 42239, '\p{^Is_Script=-	Lisu}', "");
Expect(0, 42239, '\P{Is_Script=-	Lisu}', "");
Expect(1, 42239, '\P{^Is_Script=-	Lisu}', "");
Expect(0, 42240, '\p{Is_Script=-	Lisu}', "");
Expect(1, 42240, '\p{^Is_Script=-	Lisu}', "");
Expect(1, 42240, '\P{Is_Script=-	Lisu}', "");
Expect(0, 42240, '\P{^Is_Script=-	Lisu}', "");
Error('\p{Is_Sc=/a/__lisu}');
Error('\P{Is_Sc=/a/__lisu}');
Expect(1, 42239, '\p{Is_Sc:	lisu}', "");
Expect(0, 42239, '\p{^Is_Sc:	lisu}', "");
Expect(0, 42239, '\P{Is_Sc:	lisu}', "");
Expect(1, 42239, '\P{^Is_Sc:	lisu}', "");
Expect(0, 42240, '\p{Is_Sc:	lisu}', "");
Expect(1, 42240, '\p{^Is_Sc:	lisu}', "");
Expect(1, 42240, '\P{Is_Sc:	lisu}', "");
Expect(0, 42240, '\P{^Is_Sc:	lisu}', "");
Expect(1, 42239, '\p{Is_Sc=-_LISU}', "");
Expect(0, 42239, '\p{^Is_Sc=-_LISU}', "");
Expect(0, 42239, '\P{Is_Sc=-_LISU}', "");
Expect(1, 42239, '\P{^Is_Sc=-_LISU}', "");
Expect(0, 42240, '\p{Is_Sc=-_LISU}', "");
Expect(1, 42240, '\p{^Is_Sc=-_LISU}', "");
Expect(1, 42240, '\P{Is_Sc=-_LISU}', "");
Expect(0, 42240, '\P{^Is_Sc=-_LISU}', "");
Error('\p{Script=_:=Lycian}');
Error('\P{Script=_:=Lycian}');
Expect(1, 66204, '\p{Script=lycian}', "");
Expect(0, 66204, '\p{^Script=lycian}', "");
Expect(0, 66204, '\P{Script=lycian}', "");
Expect(1, 66204, '\P{^Script=lycian}', "");
Expect(0, 66205, '\p{Script=lycian}', "");
Expect(1, 66205, '\p{^Script=lycian}', "");
Expect(1, 66205, '\P{Script=lycian}', "");
Expect(0, 66205, '\P{^Script=lycian}', "");
Expect(1, 66204, '\p{Script=	Lycian}', "");
Expect(0, 66204, '\p{^Script=	Lycian}', "");
Expect(0, 66204, '\P{Script=	Lycian}', "");
Expect(1, 66204, '\P{^Script=	Lycian}', "");
Expect(0, 66205, '\p{Script=	Lycian}', "");
Expect(1, 66205, '\p{^Script=	Lycian}', "");
Expect(1, 66205, '\P{Script=	Lycian}', "");
Expect(0, 66205, '\P{^Script=	Lycian}', "");
Error('\p{Sc=:=__Lyci}');
Error('\P{Sc=:=__Lyci}');
Expect(1, 66204, '\p{Sc: lyci}', "");
Expect(0, 66204, '\p{^Sc: lyci}', "");
Expect(0, 66204, '\P{Sc: lyci}', "");
Expect(1, 66204, '\P{^Sc: lyci}', "");
Expect(0, 66205, '\p{Sc: lyci}', "");
Expect(1, 66205, '\p{^Sc: lyci}', "");
Expect(1, 66205, '\P{Sc: lyci}', "");
Expect(0, 66205, '\P{^Sc: lyci}', "");
Expect(1, 66204, '\p{Sc= 	Lyci}', "");
Expect(0, 66204, '\p{^Sc= 	Lyci}', "");
Expect(0, 66204, '\P{Sc= 	Lyci}', "");
Expect(1, 66204, '\P{^Sc= 	Lyci}', "");
Expect(0, 66205, '\p{Sc= 	Lyci}', "");
Expect(1, 66205, '\p{^Sc= 	Lyci}', "");
Expect(1, 66205, '\P{Sc= 	Lyci}', "");
Expect(0, 66205, '\P{^Sc= 	Lyci}', "");
Error('\p{Is_Script=_/a/Lycian}');
Error('\P{Is_Script=_/a/Lycian}');
Expect(1, 66204, '\p{Is_Script=lycian}', "");
Expect(0, 66204, '\p{^Is_Script=lycian}', "");
Expect(0, 66204, '\P{Is_Script=lycian}', "");
Expect(1, 66204, '\P{^Is_Script=lycian}', "");
Expect(0, 66205, '\p{Is_Script=lycian}', "");
Expect(1, 66205, '\p{^Is_Script=lycian}', "");
Expect(1, 66205, '\P{Is_Script=lycian}', "");
Expect(0, 66205, '\P{^Is_Script=lycian}', "");
Expect(1, 66204, '\p{Is_Script=-_lycian}', "");
Expect(0, 66204, '\p{^Is_Script=-_lycian}', "");
Expect(0, 66204, '\P{Is_Script=-_lycian}', "");
Expect(1, 66204, '\P{^Is_Script=-_lycian}', "");
Expect(0, 66205, '\p{Is_Script=-_lycian}', "");
Expect(1, 66205, '\p{^Is_Script=-_lycian}', "");
Expect(1, 66205, '\P{Is_Script=-_lycian}', "");
Expect(0, 66205, '\P{^Is_Script=-_lycian}', "");
Error('\p{Is_Sc=_LYCI/a/}');
Error('\P{Is_Sc=_LYCI/a/}');
Expect(1, 66204, '\p{Is_Sc=lyci}', "");
Expect(0, 66204, '\p{^Is_Sc=lyci}', "");
Expect(0, 66204, '\P{Is_Sc=lyci}', "");
Expect(1, 66204, '\P{^Is_Sc=lyci}', "");
Expect(0, 66205, '\p{Is_Sc=lyci}', "");
Expect(1, 66205, '\p{^Is_Sc=lyci}', "");
Expect(1, 66205, '\P{Is_Sc=lyci}', "");
Expect(0, 66205, '\P{^Is_Sc=lyci}', "");
Expect(1, 66204, '\p{Is_Sc=-Lyci}', "");
Expect(0, 66204, '\p{^Is_Sc=-Lyci}', "");
Expect(0, 66204, '\P{Is_Sc=-Lyci}', "");
Expect(1, 66204, '\P{^Is_Sc=-Lyci}', "");
Expect(0, 66205, '\p{Is_Sc=-Lyci}', "");
Expect(1, 66205, '\p{^Is_Sc=-Lyci}', "");
Expect(1, 66205, '\P{Is_Sc=-Lyci}', "");
Expect(0, 66205, '\P{^Is_Sc=-Lyci}', "");
Error('\p{Script=  lydian/a/}');
Error('\P{Script=  lydian/a/}');
Expect(1, 67903, '\p{Script=lydian}', "");
Expect(0, 67903, '\p{^Script=lydian}', "");
Expect(0, 67903, '\P{Script=lydian}', "");
Expect(1, 67903, '\P{^Script=lydian}', "");
Expect(0, 67904, '\p{Script=lydian}', "");
Expect(1, 67904, '\p{^Script=lydian}', "");
Expect(1, 67904, '\P{Script=lydian}', "");
Expect(0, 67904, '\P{^Script=lydian}', "");
Expect(1, 67903, '\p{Script:   _	Lydian}', "");
Expect(0, 67903, '\p{^Script:   _	Lydian}', "");
Expect(0, 67903, '\P{Script:   _	Lydian}', "");
Expect(1, 67903, '\P{^Script:   _	Lydian}', "");
Expect(0, 67904, '\p{Script:   _	Lydian}', "");
Expect(1, 67904, '\p{^Script:   _	Lydian}', "");
Expect(1, 67904, '\P{Script:   _	Lydian}', "");
Expect(0, 67904, '\P{^Script:   _	Lydian}', "");
Error('\p{Sc=:=Lydi}');
Error('\P{Sc=:=Lydi}');
Expect(1, 67903, '\p{Sc:   lydi}', "");
Expect(0, 67903, '\p{^Sc:   lydi}', "");
Expect(0, 67903, '\P{Sc:   lydi}', "");
Expect(1, 67903, '\P{^Sc:   lydi}', "");
Expect(0, 67904, '\p{Sc:   lydi}', "");
Expect(1, 67904, '\p{^Sc:   lydi}', "");
Expect(1, 67904, '\P{Sc:   lydi}', "");
Expect(0, 67904, '\P{^Sc:   lydi}', "");
Expect(1, 67903, '\p{Sc= Lydi}', "");
Expect(0, 67903, '\p{^Sc= Lydi}', "");
Expect(0, 67903, '\P{Sc= Lydi}', "");
Expect(1, 67903, '\P{^Sc= Lydi}', "");
Expect(0, 67904, '\p{Sc= Lydi}', "");
Expect(1, 67904, '\p{^Sc= Lydi}', "");
Expect(1, 67904, '\P{Sc= Lydi}', "");
Expect(0, 67904, '\P{^Sc= Lydi}', "");
Error('\p{Is_Script=	:=Lydian}');
Error('\P{Is_Script=	:=Lydian}');
Expect(1, 67903, '\p{Is_Script=lydian}', "");
Expect(0, 67903, '\p{^Is_Script=lydian}', "");
Expect(0, 67903, '\P{Is_Script=lydian}', "");
Expect(1, 67903, '\P{^Is_Script=lydian}', "");
Expect(0, 67904, '\p{Is_Script=lydian}', "");
Expect(1, 67904, '\p{^Is_Script=lydian}', "");
Expect(1, 67904, '\P{Is_Script=lydian}', "");
Expect(0, 67904, '\P{^Is_Script=lydian}', "");
Expect(1, 67903, '\p{Is_Script=--LYDIAN}', "");
Expect(0, 67903, '\p{^Is_Script=--LYDIAN}', "");
Expect(0, 67903, '\P{Is_Script=--LYDIAN}', "");
Expect(1, 67903, '\P{^Is_Script=--LYDIAN}', "");
Expect(0, 67904, '\p{Is_Script=--LYDIAN}', "");
Expect(1, 67904, '\p{^Is_Script=--LYDIAN}', "");
Expect(1, 67904, '\P{Is_Script=--LYDIAN}', "");
Expect(0, 67904, '\P{^Is_Script=--LYDIAN}', "");
Error('\p{Is_Sc=-/a/lydi}');
Error('\P{Is_Sc=-/a/lydi}');
Expect(1, 67903, '\p{Is_Sc=lydi}', "");
Expect(0, 67903, '\p{^Is_Sc=lydi}', "");
Expect(0, 67903, '\P{Is_Sc=lydi}', "");
Expect(1, 67903, '\P{^Is_Sc=lydi}', "");
Expect(0, 67904, '\p{Is_Sc=lydi}', "");
Expect(1, 67904, '\p{^Is_Sc=lydi}', "");
Expect(1, 67904, '\P{Is_Sc=lydi}', "");
Expect(0, 67904, '\P{^Is_Sc=lydi}', "");
Expect(1, 67903, '\p{Is_Sc=	lydi}', "");
Expect(0, 67903, '\p{^Is_Sc=	lydi}', "");
Expect(0, 67903, '\P{Is_Sc=	lydi}', "");
Expect(1, 67903, '\P{^Is_Sc=	lydi}', "");
Expect(0, 67904, '\p{Is_Sc=	lydi}', "");
Expect(1, 67904, '\p{^Is_Sc=	lydi}', "");
Expect(1, 67904, '\P{Is_Sc=	lydi}', "");
Expect(0, 67904, '\P{^Is_Sc=	lydi}', "");
Error('\p{Script:  /a/mandaic}');
Error('\P{Script:  /a/mandaic}');
Expect(1, 2142, '\p{Script:mandaic}', "");
Expect(0, 2142, '\p{^Script:mandaic}', "");
Expect(0, 2142, '\P{Script:mandaic}', "");
Expect(1, 2142, '\P{^Script:mandaic}', "");
Expect(0, 2143, '\p{Script:mandaic}', "");
Expect(1, 2143, '\p{^Script:mandaic}', "");
Expect(1, 2143, '\P{Script:mandaic}', "");
Expect(0, 2143, '\P{^Script:mandaic}', "");
Expect(1, 2142, '\p{Script=-Mandaic}', "");
Expect(0, 2142, '\p{^Script=-Mandaic}', "");
Expect(0, 2142, '\P{Script=-Mandaic}', "");
Expect(1, 2142, '\P{^Script=-Mandaic}', "");
Expect(0, 2143, '\p{Script=-Mandaic}', "");
Expect(1, 2143, '\p{^Script=-Mandaic}', "");
Expect(1, 2143, '\P{Script=-Mandaic}', "");
Expect(0, 2143, '\P{^Script=-Mandaic}', "");
Error('\p{Sc=	/a/MAND}');
Error('\P{Sc=	/a/MAND}');
Expect(1, 2142, '\p{Sc=mand}', "");
Expect(0, 2142, '\p{^Sc=mand}', "");
Expect(0, 2142, '\P{Sc=mand}', "");
Expect(1, 2142, '\P{^Sc=mand}', "");
Expect(0, 2143, '\p{Sc=mand}', "");
Expect(1, 2143, '\p{^Sc=mand}', "");
Expect(1, 2143, '\P{Sc=mand}', "");
Expect(0, 2143, '\P{^Sc=mand}', "");
Expect(1, 2142, '\p{Sc=_-Mand}', "");
Expect(0, 2142, '\p{^Sc=_-Mand}', "");
Expect(0, 2142, '\P{Sc=_-Mand}', "");
Expect(1, 2142, '\P{^Sc=_-Mand}', "");
Expect(0, 2143, '\p{Sc=_-Mand}', "");
Expect(1, 2143, '\p{^Sc=_-Mand}', "");
Expect(1, 2143, '\P{Sc=_-Mand}', "");
Expect(0, 2143, '\P{^Sc=_-Mand}', "");
Error('\p{Is_Script=_-Mandaic:=}');
Error('\P{Is_Script=_-Mandaic:=}');
Expect(1, 2142, '\p{Is_Script=mandaic}', "");
Expect(0, 2142, '\p{^Is_Script=mandaic}', "");
Expect(0, 2142, '\P{Is_Script=mandaic}', "");
Expect(1, 2142, '\P{^Is_Script=mandaic}', "");
Expect(0, 2143, '\p{Is_Script=mandaic}', "");
Expect(1, 2143, '\p{^Is_Script=mandaic}', "");
Expect(1, 2143, '\P{Is_Script=mandaic}', "");
Expect(0, 2143, '\P{^Is_Script=mandaic}', "");
Expect(1, 2142, '\p{Is_Script=--mandaic}', "");
Expect(0, 2142, '\p{^Is_Script=--mandaic}', "");
Expect(0, 2142, '\P{Is_Script=--mandaic}', "");
Expect(1, 2142, '\P{^Is_Script=--mandaic}', "");
Expect(0, 2143, '\p{Is_Script=--mandaic}', "");
Expect(1, 2143, '\p{^Is_Script=--mandaic}', "");
Expect(1, 2143, '\P{Is_Script=--mandaic}', "");
Expect(0, 2143, '\P{^Is_Script=--mandaic}', "");
Error('\p{Is_Sc=_ Mand:=}');
Error('\P{Is_Sc=_ Mand:=}');
Expect(1, 2142, '\p{Is_Sc=mand}', "");
Expect(0, 2142, '\p{^Is_Sc=mand}', "");
Expect(0, 2142, '\P{Is_Sc=mand}', "");
Expect(1, 2142, '\P{^Is_Sc=mand}', "");
Expect(0, 2143, '\p{Is_Sc=mand}', "");
Expect(1, 2143, '\p{^Is_Sc=mand}', "");
Expect(1, 2143, '\P{Is_Sc=mand}', "");
Expect(0, 2143, '\P{^Is_Sc=mand}', "");
Expect(1, 2142, '\p{Is_Sc:	_mand}', "");
Expect(0, 2142, '\p{^Is_Sc:	_mand}', "");
Expect(0, 2142, '\P{Is_Sc:	_mand}', "");
Expect(1, 2142, '\P{^Is_Sc:	_mand}', "");
Expect(0, 2143, '\p{Is_Sc:	_mand}', "");
Expect(1, 2143, '\p{^Is_Sc:	_mand}', "");
Expect(1, 2143, '\P{Is_Sc:	_mand}', "");
Expect(0, 2143, '\P{^Is_Sc:	_mand}', "");
Error('\p{Script=/a/meroitic_Cursive}');
Error('\P{Script=/a/meroitic_Cursive}');
Expect(1, 68031, '\p{Script=meroiticcursive}', "");
Expect(0, 68031, '\p{^Script=meroiticcursive}', "");
Expect(0, 68031, '\P{Script=meroiticcursive}', "");
Expect(1, 68031, '\P{^Script=meroiticcursive}', "");
Expect(0, 68032, '\p{Script=meroiticcursive}', "");
Expect(1, 68032, '\p{^Script=meroiticcursive}', "");
Expect(1, 68032, '\P{Script=meroiticcursive}', "");
Expect(0, 68032, '\P{^Script=meroiticcursive}', "");
Expect(1, 68031, '\p{Script:	meroitic_Cursive}', "");
Expect(0, 68031, '\p{^Script:	meroitic_Cursive}', "");
Expect(0, 68031, '\P{Script:	meroitic_Cursive}', "");
Expect(1, 68031, '\P{^Script:	meroitic_Cursive}', "");
Expect(0, 68032, '\p{Script:	meroitic_Cursive}', "");
Expect(1, 68032, '\p{^Script:	meroitic_Cursive}', "");
Expect(1, 68032, '\P{Script:	meroitic_Cursive}', "");
Expect(0, 68032, '\P{^Script:	meroitic_Cursive}', "");
Error('\p{Sc: /a/-_MERC}');
Error('\P{Sc: /a/-_MERC}');
Expect(1, 68031, '\p{Sc=merc}', "");
Expect(0, 68031, '\p{^Sc=merc}', "");
Expect(0, 68031, '\P{Sc=merc}', "");
Expect(1, 68031, '\P{^Sc=merc}', "");
Expect(0, 68032, '\p{Sc=merc}', "");
Expect(1, 68032, '\p{^Sc=merc}', "");
Expect(1, 68032, '\P{Sc=merc}', "");
Expect(0, 68032, '\P{^Sc=merc}', "");
Expect(1, 68031, '\p{Sc=- Merc}', "");
Expect(0, 68031, '\p{^Sc=- Merc}', "");
Expect(0, 68031, '\P{Sc=- Merc}', "");
Expect(1, 68031, '\P{^Sc=- Merc}', "");
Expect(0, 68032, '\p{Sc=- Merc}', "");
Expect(1, 68032, '\p{^Sc=- Merc}', "");
Expect(1, 68032, '\P{Sc=- Merc}', "");
Expect(0, 68032, '\P{^Sc=- Merc}', "");
Error('\p{Is_Script=:= Meroitic_CURSIVE}');
Error('\P{Is_Script=:= Meroitic_CURSIVE}');
Expect(1, 68031, '\p{Is_Script=meroiticcursive}', "");
Expect(0, 68031, '\p{^Is_Script=meroiticcursive}', "");
Expect(0, 68031, '\P{Is_Script=meroiticcursive}', "");
Expect(1, 68031, '\P{^Is_Script=meroiticcursive}', "");
Expect(0, 68032, '\p{Is_Script=meroiticcursive}', "");
Expect(1, 68032, '\p{^Is_Script=meroiticcursive}', "");
Expect(1, 68032, '\P{Is_Script=meroiticcursive}', "");
Expect(0, 68032, '\P{^Is_Script=meroiticcursive}', "");
Expect(1, 68031, '\p{Is_Script=-Meroitic_Cursive}', "");
Expect(0, 68031, '\p{^Is_Script=-Meroitic_Cursive}', "");
Expect(0, 68031, '\P{Is_Script=-Meroitic_Cursive}', "");
Expect(1, 68031, '\P{^Is_Script=-Meroitic_Cursive}', "");
Expect(0, 68032, '\p{Is_Script=-Meroitic_Cursive}', "");
Expect(1, 68032, '\p{^Is_Script=-Meroitic_Cursive}', "");
Expect(1, 68032, '\P{Is_Script=-Meroitic_Cursive}', "");
Expect(0, 68032, '\P{^Is_Script=-Meroitic_Cursive}', "");
Error('\p{Is_Sc=/a/-	MERC}');
Error('\P{Is_Sc=/a/-	MERC}');
Expect(1, 68031, '\p{Is_Sc=merc}', "");
Expect(0, 68031, '\p{^Is_Sc=merc}', "");
Expect(0, 68031, '\P{Is_Sc=merc}', "");
Expect(1, 68031, '\P{^Is_Sc=merc}', "");
Expect(0, 68032, '\p{Is_Sc=merc}', "");
Expect(1, 68032, '\p{^Is_Sc=merc}', "");
Expect(1, 68032, '\P{Is_Sc=merc}', "");
Expect(0, 68032, '\P{^Is_Sc=merc}', "");
Expect(1, 68031, '\p{Is_Sc=_ merc}', "");
Expect(0, 68031, '\p{^Is_Sc=_ merc}', "");
Expect(0, 68031, '\P{Is_Sc=_ merc}', "");
Expect(1, 68031, '\P{^Is_Sc=_ merc}', "");
Expect(0, 68032, '\p{Is_Sc=_ merc}', "");
Expect(1, 68032, '\p{^Is_Sc=_ merc}', "");
Expect(1, 68032, '\P{Is_Sc=_ merc}', "");
Expect(0, 68032, '\P{^Is_Sc=_ merc}', "");
Error('\p{Script=	meroitic_Hieroglyphs/a/}');
Error('\P{Script=	meroitic_Hieroglyphs/a/}');
Expect(1, 67999, '\p{Script: meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Script: meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Script: meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Script: meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Script: meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Script: meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Script: meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Script: meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Script=		meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Script=		meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Script=		meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Script=		meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Script=		meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Script=		meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Script=		meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Script=		meroitic_Hieroglyphs}', "");
Error('\p{Sc:   _ Mero:=}');
Error('\P{Sc:   _ Mero:=}');
Expect(1, 67999, '\p{Sc=mero}', "");
Expect(0, 67999, '\p{^Sc=mero}', "");
Expect(0, 67999, '\P{Sc=mero}', "");
Expect(1, 67999, '\P{^Sc=mero}', "");
Expect(0, 68000, '\p{Sc=mero}', "");
Expect(1, 68000, '\p{^Sc=mero}', "");
Expect(1, 68000, '\P{Sc=mero}', "");
Expect(0, 68000, '\P{^Sc=mero}', "");
Expect(1, 67999, '\p{Sc= mero}', "");
Expect(0, 67999, '\p{^Sc= mero}', "");
Expect(0, 67999, '\P{Sc= mero}', "");
Expect(1, 67999, '\P{^Sc= mero}', "");
Expect(0, 68000, '\p{Sc= mero}', "");
Expect(1, 68000, '\p{^Sc= mero}', "");
Expect(1, 68000, '\P{Sc= mero}', "");
Expect(0, 68000, '\P{^Sc= mero}', "");
Error('\p{Is_Script=_:=Meroitic_Hieroglyphs}');
Error('\P{Is_Script=_:=Meroitic_Hieroglyphs}');
Expect(1, 67999, '\p{Is_Script=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Script=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Script=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Script=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Script=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Script=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Script=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Script=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Script=__meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Script=__meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Is_Script=__meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Script=__meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Is_Script=__meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Script=__meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Is_Script=__meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Script=__meroitic_Hieroglyphs}', "");
Error('\p{Is_Sc=_:=Mero}');
Error('\P{Is_Sc=_:=Mero}');
Expect(1, 67999, '\p{Is_Sc=mero}', "");
Expect(0, 67999, '\p{^Is_Sc=mero}', "");
Expect(0, 67999, '\P{Is_Sc=mero}', "");
Expect(1, 67999, '\P{^Is_Sc=mero}', "");
Expect(0, 68000, '\p{Is_Sc=mero}', "");
Expect(1, 68000, '\p{^Is_Sc=mero}', "");
Expect(1, 68000, '\P{Is_Sc=mero}', "");
Expect(0, 68000, '\P{^Is_Sc=mero}', "");
Expect(1, 67999, '\p{Is_Sc=_ mero}', "");
Expect(0, 67999, '\p{^Is_Sc=_ mero}', "");
Expect(0, 67999, '\P{Is_Sc=_ mero}', "");
Expect(1, 67999, '\P{^Is_Sc=_ mero}', "");
Expect(0, 68000, '\p{Is_Sc=_ mero}', "");
Expect(1, 68000, '\p{^Is_Sc=_ mero}', "");
Expect(1, 68000, '\P{Is_Sc=_ mero}', "");
Expect(0, 68000, '\P{^Is_Sc=_ mero}', "");
Error('\p{Script=-:=MALAYALAM}');
Error('\P{Script=-:=MALAYALAM}');
Expect(1, 3455, '\p{Script=malayalam}', "");
Expect(0, 3455, '\p{^Script=malayalam}', "");
Expect(0, 3455, '\P{Script=malayalam}', "");
Expect(1, 3455, '\P{^Script=malayalam}', "");
Expect(0, 3456, '\p{Script=malayalam}', "");
Expect(1, 3456, '\p{^Script=malayalam}', "");
Expect(1, 3456, '\P{Script=malayalam}', "");
Expect(0, 3456, '\P{^Script=malayalam}', "");
Expect(1, 3455, '\p{Script=-	Malayalam}', "");
Expect(0, 3455, '\p{^Script=-	Malayalam}', "");
Expect(0, 3455, '\P{Script=-	Malayalam}', "");
Expect(1, 3455, '\P{^Script=-	Malayalam}', "");
Expect(0, 3456, '\p{Script=-	Malayalam}', "");
Expect(1, 3456, '\p{^Script=-	Malayalam}', "");
Expect(1, 3456, '\P{Script=-	Malayalam}', "");
Expect(0, 3456, '\P{^Script=-	Malayalam}', "");
Error('\p{Sc:	:=	_mlym}');
Error('\P{Sc:	:=	_mlym}');
Expect(1, 3455, '\p{Sc=mlym}', "");
Expect(0, 3455, '\p{^Sc=mlym}', "");
Expect(0, 3455, '\P{Sc=mlym}', "");
Expect(1, 3455, '\P{^Sc=mlym}', "");
Expect(0, 3456, '\p{Sc=mlym}', "");
Expect(1, 3456, '\p{^Sc=mlym}', "");
Expect(1, 3456, '\P{Sc=mlym}', "");
Expect(0, 3456, '\P{^Sc=mlym}', "");
Expect(1, 3455, '\p{Sc=MLYM}', "");
Expect(0, 3455, '\p{^Sc=MLYM}', "");
Expect(0, 3455, '\P{Sc=MLYM}', "");
Expect(1, 3455, '\P{^Sc=MLYM}', "");
Expect(0, 3456, '\p{Sc=MLYM}', "");
Expect(1, 3456, '\p{^Sc=MLYM}', "");
Expect(1, 3456, '\P{Sc=MLYM}', "");
Expect(0, 3456, '\P{^Sc=MLYM}', "");
Error('\p{Is_Script=:=Malayalam}');
Error('\P{Is_Script=:=Malayalam}');
Expect(1, 3455, '\p{Is_Script=malayalam}', "");
Expect(0, 3455, '\p{^Is_Script=malayalam}', "");
Expect(0, 3455, '\P{Is_Script=malayalam}', "");
Expect(1, 3455, '\P{^Is_Script=malayalam}', "");
Expect(0, 3456, '\p{Is_Script=malayalam}', "");
Expect(1, 3456, '\p{^Is_Script=malayalam}', "");
Expect(1, 3456, '\P{Is_Script=malayalam}', "");
Expect(0, 3456, '\P{^Is_Script=malayalam}', "");
Expect(1, 3455, '\p{Is_Script=-MALAYALAM}', "");
Expect(0, 3455, '\p{^Is_Script=-MALAYALAM}', "");
Expect(0, 3455, '\P{Is_Script=-MALAYALAM}', "");
Expect(1, 3455, '\P{^Is_Script=-MALAYALAM}', "");
Expect(0, 3456, '\p{Is_Script=-MALAYALAM}', "");
Expect(1, 3456, '\p{^Is_Script=-MALAYALAM}', "");
Expect(1, 3456, '\P{Is_Script=-MALAYALAM}', "");
Expect(0, 3456, '\P{^Is_Script=-MALAYALAM}', "");
Error('\p{Is_Sc=:=Mlym}');
Error('\P{Is_Sc=:=Mlym}');
Expect(1, 3455, '\p{Is_Sc=mlym}', "");
Expect(0, 3455, '\p{^Is_Sc=mlym}', "");
Expect(0, 3455, '\P{Is_Sc=mlym}', "");
Expect(1, 3455, '\P{^Is_Sc=mlym}', "");
Expect(0, 3456, '\p{Is_Sc=mlym}', "");
Expect(1, 3456, '\p{^Is_Sc=mlym}', "");
Expect(1, 3456, '\P{Is_Sc=mlym}', "");
Expect(0, 3456, '\P{^Is_Sc=mlym}', "");
Expect(1, 3455, '\p{Is_Sc=--mlym}', "");
Expect(0, 3455, '\p{^Is_Sc=--mlym}', "");
Expect(0, 3455, '\P{Is_Sc=--mlym}', "");
Expect(1, 3455, '\P{^Is_Sc=--mlym}', "");
Expect(0, 3456, '\p{Is_Sc=--mlym}', "");
Expect(1, 3456, '\p{^Is_Sc=--mlym}', "");
Expect(1, 3456, '\P{Is_Sc=--mlym}', "");
Expect(0, 3456, '\P{^Is_Sc=--mlym}', "");
Error('\p{Script=/a/- Mongolian}');
Error('\P{Script=/a/- Mongolian}');
Expect(1, 6314, '\p{Script=mongolian}', "");
Expect(0, 6314, '\p{^Script=mongolian}', "");
Expect(0, 6314, '\P{Script=mongolian}', "");
Expect(1, 6314, '\P{^Script=mongolian}', "");
Expect(0, 6315, '\p{Script=mongolian}', "");
Expect(1, 6315, '\p{^Script=mongolian}', "");
Expect(1, 6315, '\P{Script=mongolian}', "");
Expect(0, 6315, '\P{^Script=mongolian}', "");
Expect(1, 6314, '\p{Script:	  Mongolian}', "");
Expect(0, 6314, '\p{^Script:	  Mongolian}', "");
Expect(0, 6314, '\P{Script:	  Mongolian}', "");
Expect(1, 6314, '\P{^Script:	  Mongolian}', "");
Expect(0, 6315, '\p{Script:	  Mongolian}', "");
Expect(1, 6315, '\p{^Script:	  Mongolian}', "");
Expect(1, 6315, '\P{Script:	  Mongolian}', "");
Expect(0, 6315, '\P{^Script:	  Mongolian}', "");
Error('\p{Sc=_mong/a/}');
Error('\P{Sc=_mong/a/}');
Expect(1, 6314, '\p{Sc=mong}', "");
Expect(0, 6314, '\p{^Sc=mong}', "");
Expect(0, 6314, '\P{Sc=mong}', "");
Expect(1, 6314, '\P{^Sc=mong}', "");
Expect(0, 6315, '\p{Sc=mong}', "");
Expect(1, 6315, '\p{^Sc=mong}', "");
Expect(1, 6315, '\P{Sc=mong}', "");
Expect(0, 6315, '\P{^Sc=mong}', "");
Expect(1, 6314, '\p{Sc=_ Mong}', "");
Expect(0, 6314, '\p{^Sc=_ Mong}', "");
Expect(0, 6314, '\P{Sc=_ Mong}', "");
Expect(1, 6314, '\P{^Sc=_ Mong}', "");
Expect(0, 6315, '\p{Sc=_ Mong}', "");
Expect(1, 6315, '\p{^Sc=_ Mong}', "");
Expect(1, 6315, '\P{Sc=_ Mong}', "");
Expect(0, 6315, '\P{^Sc=_ Mong}', "");
Error('\p{Is_Script=mongolian/a/}');
Error('\P{Is_Script=mongolian/a/}');
Expect(1, 6314, '\p{Is_Script=mongolian}', "");
Expect(0, 6314, '\p{^Is_Script=mongolian}', "");
Expect(0, 6314, '\P{Is_Script=mongolian}', "");
Expect(1, 6314, '\P{^Is_Script=mongolian}', "");
Expect(0, 6315, '\p{Is_Script=mongolian}', "");
Expect(1, 6315, '\p{^Is_Script=mongolian}', "");
Expect(1, 6315, '\P{Is_Script=mongolian}', "");
Expect(0, 6315, '\P{^Is_Script=mongolian}', "");
Expect(1, 6314, '\p{Is_Script=-Mongolian}', "");
Expect(0, 6314, '\p{^Is_Script=-Mongolian}', "");
Expect(0, 6314, '\P{Is_Script=-Mongolian}', "");
Expect(1, 6314, '\P{^Is_Script=-Mongolian}', "");
Expect(0, 6315, '\p{Is_Script=-Mongolian}', "");
Expect(1, 6315, '\p{^Is_Script=-Mongolian}', "");
Expect(1, 6315, '\P{Is_Script=-Mongolian}', "");
Expect(0, 6315, '\P{^Is_Script=-Mongolian}', "");
Error('\p{Is_Sc=-Mong/a/}');
Error('\P{Is_Sc=-Mong/a/}');
Expect(1, 6314, '\p{Is_Sc:   mong}', "");
Expect(0, 6314, '\p{^Is_Sc:   mong}', "");
Expect(0, 6314, '\P{Is_Sc:   mong}', "");
Expect(1, 6314, '\P{^Is_Sc:   mong}', "");
Expect(0, 6315, '\p{Is_Sc:   mong}', "");
Expect(1, 6315, '\p{^Is_Sc:   mong}', "");
Expect(1, 6315, '\P{Is_Sc:   mong}', "");
Expect(0, 6315, '\P{^Is_Sc:   mong}', "");
Expect(1, 6314, '\p{Is_Sc= _Mong}', "");
Expect(0, 6314, '\p{^Is_Sc= _Mong}', "");
Expect(0, 6314, '\P{Is_Sc= _Mong}', "");
Expect(1, 6314, '\P{^Is_Sc= _Mong}', "");
Expect(0, 6315, '\p{Is_Sc= _Mong}', "");
Expect(1, 6315, '\p{^Is_Sc= _Mong}', "");
Expect(1, 6315, '\P{Is_Sc= _Mong}', "");
Expect(0, 6315, '\P{^Is_Sc= _Mong}', "");
Error('\p{Script=__Meetei_mayek/a/}');
Error('\P{Script=__Meetei_mayek/a/}');
Expect(1, 44025, '\p{Script=meeteimayek}', "");
Expect(0, 44025, '\p{^Script=meeteimayek}', "");
Expect(0, 44025, '\P{Script=meeteimayek}', "");
Expect(1, 44025, '\P{^Script=meeteimayek}', "");
Expect(0, 44026, '\p{Script=meeteimayek}', "");
Expect(1, 44026, '\p{^Script=meeteimayek}', "");
Expect(1, 44026, '\P{Script=meeteimayek}', "");
Expect(0, 44026, '\P{^Script=meeteimayek}', "");
Expect(1, 44025, '\p{Script= Meetei_MAYEK}', "");
Expect(0, 44025, '\p{^Script= Meetei_MAYEK}', "");
Expect(0, 44025, '\P{Script= Meetei_MAYEK}', "");
Expect(1, 44025, '\P{^Script= Meetei_MAYEK}', "");
Expect(0, 44026, '\p{Script= Meetei_MAYEK}', "");
Expect(1, 44026, '\p{^Script= Meetei_MAYEK}', "");
Expect(1, 44026, '\P{Script= Meetei_MAYEK}', "");
Expect(0, 44026, '\P{^Script= Meetei_MAYEK}', "");
Error('\p{Sc=-	MTEI:=}');
Error('\P{Sc=-	MTEI:=}');
Expect(1, 44025, '\p{Sc=mtei}', "");
Expect(0, 44025, '\p{^Sc=mtei}', "");
Expect(0, 44025, '\P{Sc=mtei}', "");
Expect(1, 44025, '\P{^Sc=mtei}', "");
Expect(0, 44026, '\p{Sc=mtei}', "");
Expect(1, 44026, '\p{^Sc=mtei}', "");
Expect(1, 44026, '\P{Sc=mtei}', "");
Expect(0, 44026, '\P{^Sc=mtei}', "");
Expect(1, 44025, '\p{Sc=- mtei}', "");
Expect(0, 44025, '\p{^Sc=- mtei}', "");
Expect(0, 44025, '\P{Sc=- mtei}', "");
Expect(1, 44025, '\P{^Sc=- mtei}', "");
Expect(0, 44026, '\p{Sc=- mtei}', "");
Expect(1, 44026, '\p{^Sc=- mtei}', "");
Expect(1, 44026, '\P{Sc=- mtei}', "");
Expect(0, 44026, '\P{^Sc=- mtei}', "");
Error('\p{Is_Script=:= -MEETEI_Mayek}');
Error('\P{Is_Script=:= -MEETEI_Mayek}');
Expect(1, 44025, '\p{Is_Script=meeteimayek}', "");
Expect(0, 44025, '\p{^Is_Script=meeteimayek}', "");
Expect(0, 44025, '\P{Is_Script=meeteimayek}', "");
Expect(1, 44025, '\P{^Is_Script=meeteimayek}', "");
Expect(0, 44026, '\p{Is_Script=meeteimayek}', "");
Expect(1, 44026, '\p{^Is_Script=meeteimayek}', "");
Expect(1, 44026, '\P{Is_Script=meeteimayek}', "");
Expect(0, 44026, '\P{^Is_Script=meeteimayek}', "");
Expect(1, 44025, '\p{Is_Script=--Meetei_mayek}', "");
Expect(0, 44025, '\p{^Is_Script=--Meetei_mayek}', "");
Expect(0, 44025, '\P{Is_Script=--Meetei_mayek}', "");
Expect(1, 44025, '\P{^Is_Script=--Meetei_mayek}', "");
Expect(0, 44026, '\p{Is_Script=--Meetei_mayek}', "");
Expect(1, 44026, '\p{^Is_Script=--Meetei_mayek}', "");
Expect(1, 44026, '\P{Is_Script=--Meetei_mayek}', "");
Expect(0, 44026, '\P{^Is_Script=--Meetei_mayek}', "");
Error('\p{Is_Sc=/a/_	Mtei}');
Error('\P{Is_Sc=/a/_	Mtei}');
Expect(1, 44025, '\p{Is_Sc=mtei}', "");
Expect(0, 44025, '\p{^Is_Sc=mtei}', "");
Expect(0, 44025, '\P{Is_Sc=mtei}', "");
Expect(1, 44025, '\P{^Is_Sc=mtei}', "");
Expect(0, 44026, '\p{Is_Sc=mtei}', "");
Expect(1, 44026, '\p{^Is_Sc=mtei}', "");
Expect(1, 44026, '\P{Is_Sc=mtei}', "");
Expect(0, 44026, '\P{^Is_Sc=mtei}', "");
Expect(1, 44025, '\p{Is_Sc= Mtei}', "");
Expect(0, 44025, '\p{^Is_Sc= Mtei}', "");
Expect(0, 44025, '\P{Is_Sc= Mtei}', "");
Expect(1, 44025, '\P{^Is_Sc= Mtei}', "");
Expect(0, 44026, '\p{Is_Sc= Mtei}', "");
Expect(1, 44026, '\p{^Is_Sc= Mtei}', "");
Expect(1, 44026, '\P{Is_Sc= Mtei}', "");
Expect(0, 44026, '\P{^Is_Sc= Mtei}', "");
Error('\p{Script=:=	 MYANMAR}');
Error('\P{Script=:=	 MYANMAR}');
Expect(1, 43643, '\p{Script=myanmar}', "");
Expect(0, 43643, '\p{^Script=myanmar}', "");
Expect(0, 43643, '\P{Script=myanmar}', "");
Expect(1, 43643, '\P{^Script=myanmar}', "");
Expect(0, 43644, '\p{Script=myanmar}', "");
Expect(1, 43644, '\p{^Script=myanmar}', "");
Expect(1, 43644, '\P{Script=myanmar}', "");
Expect(0, 43644, '\P{^Script=myanmar}', "");
Expect(1, 43643, '\p{Script=		MYANMAR}', "");
Expect(0, 43643, '\p{^Script=		MYANMAR}', "");
Expect(0, 43643, '\P{Script=		MYANMAR}', "");
Expect(1, 43643, '\P{^Script=		MYANMAR}', "");
Expect(0, 43644, '\p{Script=		MYANMAR}', "");
Expect(1, 43644, '\p{^Script=		MYANMAR}', "");
Expect(1, 43644, '\P{Script=		MYANMAR}', "");
Expect(0, 43644, '\P{^Script=		MYANMAR}', "");
Error('\p{Sc:	/a/mymr}');
Error('\P{Sc:	/a/mymr}');
Expect(1, 43643, '\p{Sc=mymr}', "");
Expect(0, 43643, '\p{^Sc=mymr}', "");
Expect(0, 43643, '\P{Sc=mymr}', "");
Expect(1, 43643, '\P{^Sc=mymr}', "");
Expect(0, 43644, '\p{Sc=mymr}', "");
Expect(1, 43644, '\p{^Sc=mymr}', "");
Expect(1, 43644, '\P{Sc=mymr}', "");
Expect(0, 43644, '\P{^Sc=mymr}', "");
Expect(1, 43643, '\p{Sc=_Mymr}', "");
Expect(0, 43643, '\p{^Sc=_Mymr}', "");
Expect(0, 43643, '\P{Sc=_Mymr}', "");
Expect(1, 43643, '\P{^Sc=_Mymr}', "");
Expect(0, 43644, '\p{Sc=_Mymr}', "");
Expect(1, 43644, '\p{^Sc=_Mymr}', "");
Expect(1, 43644, '\P{Sc=_Mymr}', "");
Expect(0, 43644, '\P{^Sc=_Mymr}', "");
Error('\p{Is_Script=/a/	-Myanmar}');
Error('\P{Is_Script=/a/	-Myanmar}');
Expect(1, 43643, '\p{Is_Script=myanmar}', "");
Expect(0, 43643, '\p{^Is_Script=myanmar}', "");
Expect(0, 43643, '\P{Is_Script=myanmar}', "");
Expect(1, 43643, '\P{^Is_Script=myanmar}', "");
Expect(0, 43644, '\p{Is_Script=myanmar}', "");
Expect(1, 43644, '\p{^Is_Script=myanmar}', "");
Expect(1, 43644, '\P{Is_Script=myanmar}', "");
Expect(0, 43644, '\P{^Is_Script=myanmar}', "");
Expect(1, 43643, '\p{Is_Script=- Myanmar}', "");
Expect(0, 43643, '\p{^Is_Script=- Myanmar}', "");
Expect(0, 43643, '\P{Is_Script=- Myanmar}', "");
Expect(1, 43643, '\P{^Is_Script=- Myanmar}', "");
Expect(0, 43644, '\p{Is_Script=- Myanmar}', "");
Expect(1, 43644, '\p{^Is_Script=- Myanmar}', "");
Expect(1, 43644, '\P{Is_Script=- Myanmar}', "");
Expect(0, 43644, '\P{^Is_Script=- Myanmar}', "");
Error('\p{Is_Sc=/a/-_MYMR}');
Error('\P{Is_Sc=/a/-_MYMR}');
Expect(1, 43643, '\p{Is_Sc=mymr}', "");
Expect(0, 43643, '\p{^Is_Sc=mymr}', "");
Expect(0, 43643, '\P{Is_Sc=mymr}', "");
Expect(1, 43643, '\P{^Is_Sc=mymr}', "");
Expect(0, 43644, '\p{Is_Sc=mymr}', "");
Expect(1, 43644, '\p{^Is_Sc=mymr}', "");
Expect(1, 43644, '\P{Is_Sc=mymr}', "");
Expect(0, 43644, '\P{^Is_Sc=mymr}', "");
Expect(1, 43643, '\p{Is_Sc=-Mymr}', "");
Expect(0, 43643, '\p{^Is_Sc=-Mymr}', "");
Expect(0, 43643, '\P{Is_Sc=-Mymr}', "");
Expect(1, 43643, '\P{^Is_Sc=-Mymr}', "");
Expect(0, 43644, '\p{Is_Sc=-Mymr}', "");
Expect(1, 43644, '\p{^Is_Sc=-Mymr}', "");
Expect(1, 43644, '\P{Is_Sc=-Mymr}', "");
Expect(0, 43644, '\P{^Is_Sc=-Mymr}', "");
Error('\p{Script=:=-NKO}');
Error('\P{Script=:=-NKO}');
Expect(1, 2042, '\p{Script=nko}', "");
Expect(0, 2042, '\p{^Script=nko}', "");
Expect(0, 2042, '\P{Script=nko}', "");
Expect(1, 2042, '\P{^Script=nko}', "");
Expect(0, 2043, '\p{Script=nko}', "");
Expect(1, 2043, '\p{^Script=nko}', "");
Expect(1, 2043, '\P{Script=nko}', "");
Expect(0, 2043, '\P{^Script=nko}', "");
Expect(1, 2042, '\p{Script:	NKO}', "");
Expect(0, 2042, '\p{^Script:	NKO}', "");
Expect(0, 2042, '\P{Script:	NKO}', "");
Expect(1, 2042, '\P{^Script:	NKO}', "");
Expect(0, 2043, '\p{Script:	NKO}', "");
Expect(1, 2043, '\p{^Script:	NKO}', "");
Expect(1, 2043, '\P{Script:	NKO}', "");
Expect(0, 2043, '\P{^Script:	NKO}', "");
Error('\p{Sc=/a/Nkoo}');
Error('\P{Sc=/a/Nkoo}');
Expect(1, 2042, '\p{Sc=nkoo}', "");
Expect(0, 2042, '\p{^Sc=nkoo}', "");
Expect(0, 2042, '\P{Sc=nkoo}', "");
Expect(1, 2042, '\P{^Sc=nkoo}', "");
Expect(0, 2043, '\p{Sc=nkoo}', "");
Expect(1, 2043, '\p{^Sc=nkoo}', "");
Expect(1, 2043, '\P{Sc=nkoo}', "");
Expect(0, 2043, '\P{^Sc=nkoo}', "");
Expect(1, 2042, '\p{Sc= Nkoo}', "");
Expect(0, 2042, '\p{^Sc= Nkoo}', "");
Expect(0, 2042, '\P{Sc= Nkoo}', "");
Expect(1, 2042, '\P{^Sc= Nkoo}', "");
Expect(0, 2043, '\p{Sc= Nkoo}', "");
Expect(1, 2043, '\p{^Sc= Nkoo}', "");
Expect(1, 2043, '\P{Sc= Nkoo}', "");
Expect(0, 2043, '\P{^Sc= Nkoo}', "");
Error('\p{Is_Script=-:=Nko}');
Error('\P{Is_Script=-:=Nko}');
Expect(1, 2042, '\p{Is_Script:	nko}', "");
Expect(0, 2042, '\p{^Is_Script:	nko}', "");
Expect(0, 2042, '\P{Is_Script:	nko}', "");
Expect(1, 2042, '\P{^Is_Script:	nko}', "");
Expect(0, 2043, '\p{Is_Script:	nko}', "");
Expect(1, 2043, '\p{^Is_Script:	nko}', "");
Expect(1, 2043, '\P{Is_Script:	nko}', "");
Expect(0, 2043, '\P{^Is_Script:	nko}', "");
Expect(1, 2042, '\p{Is_Script=-_NKO}', "");
Expect(0, 2042, '\p{^Is_Script=-_NKO}', "");
Expect(0, 2042, '\P{Is_Script=-_NKO}', "");
Expect(1, 2042, '\P{^Is_Script=-_NKO}', "");
Expect(0, 2043, '\p{Is_Script=-_NKO}', "");
Expect(1, 2043, '\p{^Is_Script=-_NKO}', "");
Expect(1, 2043, '\P{Is_Script=-_NKO}', "");
Expect(0, 2043, '\P{^Is_Script=-_NKO}', "");
Error('\p{Is_Sc=/a/-_Nkoo}');
Error('\P{Is_Sc=/a/-_Nkoo}');
Expect(1, 2042, '\p{Is_Sc=nkoo}', "");
Expect(0, 2042, '\p{^Is_Sc=nkoo}', "");
Expect(0, 2042, '\P{Is_Sc=nkoo}', "");
Expect(1, 2042, '\P{^Is_Sc=nkoo}', "");
Expect(0, 2043, '\p{Is_Sc=nkoo}', "");
Expect(1, 2043, '\p{^Is_Sc=nkoo}', "");
Expect(1, 2043, '\P{Is_Sc=nkoo}', "");
Expect(0, 2043, '\P{^Is_Sc=nkoo}', "");
Expect(1, 2042, '\p{Is_Sc= 	NKOO}', "");
Expect(0, 2042, '\p{^Is_Sc= 	NKOO}', "");
Expect(0, 2042, '\P{Is_Sc= 	NKOO}', "");
Expect(1, 2042, '\P{^Is_Sc= 	NKOO}', "");
Expect(0, 2043, '\p{Is_Sc= 	NKOO}', "");
Expect(1, 2043, '\p{^Is_Sc= 	NKOO}', "");
Expect(1, 2043, '\P{Is_Sc= 	NKOO}', "");
Expect(0, 2043, '\P{^Is_Sc= 	NKOO}', "");
Error('\p{Script=/a/ -Ogham}');
Error('\P{Script=/a/ -Ogham}');
Expect(1, 5788, '\p{Script=ogham}', "");
Expect(0, 5788, '\p{^Script=ogham}', "");
Expect(0, 5788, '\P{Script=ogham}', "");
Expect(1, 5788, '\P{^Script=ogham}', "");
Expect(0, 5789, '\p{Script=ogham}', "");
Expect(1, 5789, '\p{^Script=ogham}', "");
Expect(1, 5789, '\P{Script=ogham}', "");
Expect(0, 5789, '\P{^Script=ogham}', "");
Expect(1, 5788, '\p{Script=  Ogham}', "");
Expect(0, 5788, '\p{^Script=  Ogham}', "");
Expect(0, 5788, '\P{Script=  Ogham}', "");
Expect(1, 5788, '\P{^Script=  Ogham}', "");
Expect(0, 5789, '\p{Script=  Ogham}', "");
Expect(1, 5789, '\p{^Script=  Ogham}', "");
Expect(1, 5789, '\P{Script=  Ogham}', "");
Expect(0, 5789, '\P{^Script=  Ogham}', "");
Error('\p{Sc=__OGAM/a/}');
Error('\P{Sc=__OGAM/a/}');
Expect(1, 5788, '\p{Sc=ogam}', "");
Expect(0, 5788, '\p{^Sc=ogam}', "");
Expect(0, 5788, '\P{Sc=ogam}', "");
Expect(1, 5788, '\P{^Sc=ogam}', "");
Expect(0, 5789, '\p{Sc=ogam}', "");
Expect(1, 5789, '\p{^Sc=ogam}', "");
Expect(1, 5789, '\P{Sc=ogam}', "");
Expect(0, 5789, '\P{^Sc=ogam}', "");
Expect(1, 5788, '\p{Sc=- OGAM}', "");
Expect(0, 5788, '\p{^Sc=- OGAM}', "");
Expect(0, 5788, '\P{Sc=- OGAM}', "");
Expect(1, 5788, '\P{^Sc=- OGAM}', "");
Expect(0, 5789, '\p{Sc=- OGAM}', "");
Expect(1, 5789, '\p{^Sc=- OGAM}', "");
Expect(1, 5789, '\P{Sc=- OGAM}', "");
Expect(0, 5789, '\P{^Sc=- OGAM}', "");
Error('\p{Is_Script=-OGHAM/a/}');
Error('\P{Is_Script=-OGHAM/a/}');
Expect(1, 5788, '\p{Is_Script=ogham}', "");
Expect(0, 5788, '\p{^Is_Script=ogham}', "");
Expect(0, 5788, '\P{Is_Script=ogham}', "");
Expect(1, 5788, '\P{^Is_Script=ogham}', "");
Expect(0, 5789, '\p{Is_Script=ogham}', "");
Expect(1, 5789, '\p{^Is_Script=ogham}', "");
Expect(1, 5789, '\P{Is_Script=ogham}', "");
Expect(0, 5789, '\P{^Is_Script=ogham}', "");
Expect(1, 5788, '\p{Is_Script=-OGHAM}', "");
Expect(0, 5788, '\p{^Is_Script=-OGHAM}', "");
Expect(0, 5788, '\P{Is_Script=-OGHAM}', "");
Expect(1, 5788, '\P{^Is_Script=-OGHAM}', "");
Expect(0, 5789, '\p{Is_Script=-OGHAM}', "");
Expect(1, 5789, '\p{^Is_Script=-OGHAM}', "");
Expect(1, 5789, '\P{Is_Script=-OGHAM}', "");
Expect(0, 5789, '\P{^Is_Script=-OGHAM}', "");
Error('\p{Is_Sc=_Ogam/a/}');
Error('\P{Is_Sc=_Ogam/a/}');
Expect(1, 5788, '\p{Is_Sc=ogam}', "");
Expect(0, 5788, '\p{^Is_Sc=ogam}', "");
Expect(0, 5788, '\P{Is_Sc=ogam}', "");
Expect(1, 5788, '\P{^Is_Sc=ogam}', "");
Expect(0, 5789, '\p{Is_Sc=ogam}', "");
Expect(1, 5789, '\p{^Is_Sc=ogam}', "");
Expect(1, 5789, '\P{Is_Sc=ogam}', "");
Expect(0, 5789, '\P{^Is_Sc=ogam}', "");
Expect(1, 5788, '\p{Is_Sc= _Ogam}', "");
Expect(0, 5788, '\p{^Is_Sc= _Ogam}', "");
Expect(0, 5788, '\P{Is_Sc= _Ogam}', "");
Expect(1, 5788, '\P{^Is_Sc= _Ogam}', "");
Expect(0, 5789, '\p{Is_Sc= _Ogam}', "");
Expect(1, 5789, '\p{^Is_Sc= _Ogam}', "");
Expect(1, 5789, '\P{Is_Sc= _Ogam}', "");
Expect(0, 5789, '\P{^Is_Sc= _Ogam}', "");
Error('\p{Script=_:=ol_Chiki}');
Error('\P{Script=_:=ol_Chiki}');
Expect(1, 7295, '\p{Script=olchiki}', "");
Expect(0, 7295, '\p{^Script=olchiki}', "");
Expect(0, 7295, '\P{Script=olchiki}', "");
Expect(1, 7295, '\P{^Script=olchiki}', "");
Expect(0, 7296, '\p{Script=olchiki}', "");
Expect(1, 7296, '\p{^Script=olchiki}', "");
Expect(1, 7296, '\P{Script=olchiki}', "");
Expect(0, 7296, '\P{^Script=olchiki}', "");
Expect(1, 7295, '\p{Script=	OL_Chiki}', "");
Expect(0, 7295, '\p{^Script=	OL_Chiki}', "");
Expect(0, 7295, '\P{Script=	OL_Chiki}', "");
Expect(1, 7295, '\P{^Script=	OL_Chiki}', "");
Expect(0, 7296, '\p{Script=	OL_Chiki}', "");
Expect(1, 7296, '\p{^Script=	OL_Chiki}', "");
Expect(1, 7296, '\P{Script=	OL_Chiki}', "");
Expect(0, 7296, '\P{^Script=	OL_Chiki}', "");
Error('\p{Sc=-:=Olck}');
Error('\P{Sc=-:=Olck}');
Expect(1, 7295, '\p{Sc=olck}', "");
Expect(0, 7295, '\p{^Sc=olck}', "");
Expect(0, 7295, '\P{Sc=olck}', "");
Expect(1, 7295, '\P{^Sc=olck}', "");
Expect(0, 7296, '\p{Sc=olck}', "");
Expect(1, 7296, '\p{^Sc=olck}', "");
Expect(1, 7296, '\P{Sc=olck}', "");
Expect(0, 7296, '\P{^Sc=olck}', "");
Expect(1, 7295, '\p{Sc=		OLCK}', "");
Expect(0, 7295, '\p{^Sc=		OLCK}', "");
Expect(0, 7295, '\P{Sc=		OLCK}', "");
Expect(1, 7295, '\P{^Sc=		OLCK}', "");
Expect(0, 7296, '\p{Sc=		OLCK}', "");
Expect(1, 7296, '\p{^Sc=		OLCK}', "");
Expect(1, 7296, '\P{Sc=		OLCK}', "");
Expect(0, 7296, '\P{^Sc=		OLCK}', "");
Error('\p{Is_Script=_OL_CHIKI/a/}');
Error('\P{Is_Script=_OL_CHIKI/a/}');
Expect(1, 7295, '\p{Is_Script=olchiki}', "");
Expect(0, 7295, '\p{^Is_Script=olchiki}', "");
Expect(0, 7295, '\P{Is_Script=olchiki}', "");
Expect(1, 7295, '\P{^Is_Script=olchiki}', "");
Expect(0, 7296, '\p{Is_Script=olchiki}', "");
Expect(1, 7296, '\p{^Is_Script=olchiki}', "");
Expect(1, 7296, '\P{Is_Script=olchiki}', "");
Expect(0, 7296, '\P{^Is_Script=olchiki}', "");
Expect(1, 7295, '\p{Is_Script=	ol_Chiki}', "");
Expect(0, 7295, '\p{^Is_Script=	ol_Chiki}', "");
Expect(0, 7295, '\P{Is_Script=	ol_Chiki}', "");
Expect(1, 7295, '\P{^Is_Script=	ol_Chiki}', "");
Expect(0, 7296, '\p{Is_Script=	ol_Chiki}', "");
Expect(1, 7296, '\p{^Is_Script=	ol_Chiki}', "");
Expect(1, 7296, '\P{Is_Script=	ol_Chiki}', "");
Expect(0, 7296, '\P{^Is_Script=	ol_Chiki}', "");
Error('\p{Is_Sc=:=-Olck}');
Error('\P{Is_Sc=:=-Olck}');
Expect(1, 7295, '\p{Is_Sc=olck}', "");
Expect(0, 7295, '\p{^Is_Sc=olck}', "");
Expect(0, 7295, '\P{Is_Sc=olck}', "");
Expect(1, 7295, '\P{^Is_Sc=olck}', "");
Expect(0, 7296, '\p{Is_Sc=olck}', "");
Expect(1, 7296, '\p{^Is_Sc=olck}', "");
Expect(1, 7296, '\P{Is_Sc=olck}', "");
Expect(0, 7296, '\P{^Is_Sc=olck}', "");
Expect(1, 7295, '\p{Is_Sc=_OLCK}', "");
Expect(0, 7295, '\p{^Is_Sc=_OLCK}', "");
Expect(0, 7295, '\P{Is_Sc=_OLCK}', "");
Expect(1, 7295, '\P{^Is_Sc=_OLCK}', "");
Expect(0, 7296, '\p{Is_Sc=_OLCK}', "");
Expect(1, 7296, '\p{^Is_Sc=_OLCK}', "");
Expect(1, 7296, '\P{Is_Sc=_OLCK}', "");
Expect(0, 7296, '\P{^Is_Sc=_OLCK}', "");
Error('\p{Script=/a/Old_Turkic}');
Error('\P{Script=/a/Old_Turkic}');
Expect(1, 68680, '\p{Script=oldturkic}', "");
Expect(0, 68680, '\p{^Script=oldturkic}', "");
Expect(0, 68680, '\P{Script=oldturkic}', "");
Expect(1, 68680, '\P{^Script=oldturkic}', "");
Expect(0, 68681, '\p{Script=oldturkic}', "");
Expect(1, 68681, '\p{^Script=oldturkic}', "");
Expect(1, 68681, '\P{Script=oldturkic}', "");
Expect(0, 68681, '\P{^Script=oldturkic}', "");
Expect(1, 68680, '\p{Script=	Old_TURKIC}', "");
Expect(0, 68680, '\p{^Script=	Old_TURKIC}', "");
Expect(0, 68680, '\P{Script=	Old_TURKIC}', "");
Expect(1, 68680, '\P{^Script=	Old_TURKIC}', "");
Expect(0, 68681, '\p{Script=	Old_TURKIC}', "");
Expect(1, 68681, '\p{^Script=	Old_TURKIC}', "");
Expect(1, 68681, '\P{Script=	Old_TURKIC}', "");
Expect(0, 68681, '\P{^Script=	Old_TURKIC}', "");
Error('\p{Sc= _Orkh/a/}');
Error('\P{Sc= _Orkh/a/}');
Expect(1, 68680, '\p{Sc: orkh}', "");
Expect(0, 68680, '\p{^Sc: orkh}', "");
Expect(0, 68680, '\P{Sc: orkh}', "");
Expect(1, 68680, '\P{^Sc: orkh}', "");
Expect(0, 68681, '\p{Sc: orkh}', "");
Expect(1, 68681, '\p{^Sc: orkh}', "");
Expect(1, 68681, '\P{Sc: orkh}', "");
Expect(0, 68681, '\P{^Sc: orkh}', "");
Expect(1, 68680, '\p{Sc=__Orkh}', "");
Expect(0, 68680, '\p{^Sc=__Orkh}', "");
Expect(0, 68680, '\P{Sc=__Orkh}', "");
Expect(1, 68680, '\P{^Sc=__Orkh}', "");
Expect(0, 68681, '\p{Sc=__Orkh}', "");
Expect(1, 68681, '\p{^Sc=__Orkh}', "");
Expect(1, 68681, '\P{Sc=__Orkh}', "");
Expect(0, 68681, '\P{^Sc=__Orkh}', "");
Error('\p{Is_Script=-/a/Old_Turkic}');
Error('\P{Is_Script=-/a/Old_Turkic}');
Expect(1, 68680, '\p{Is_Script=oldturkic}', "");
Expect(0, 68680, '\p{^Is_Script=oldturkic}', "");
Expect(0, 68680, '\P{Is_Script=oldturkic}', "");
Expect(1, 68680, '\P{^Is_Script=oldturkic}', "");
Expect(0, 68681, '\p{Is_Script=oldturkic}', "");
Expect(1, 68681, '\p{^Is_Script=oldturkic}', "");
Expect(1, 68681, '\P{Is_Script=oldturkic}', "");
Expect(0, 68681, '\P{^Is_Script=oldturkic}', "");
Expect(1, 68680, '\p{Is_Script=  old_Turkic}', "");
Expect(0, 68680, '\p{^Is_Script=  old_Turkic}', "");
Expect(0, 68680, '\P{Is_Script=  old_Turkic}', "");
Expect(1, 68680, '\P{^Is_Script=  old_Turkic}', "");
Expect(0, 68681, '\p{Is_Script=  old_Turkic}', "");
Expect(1, 68681, '\p{^Is_Script=  old_Turkic}', "");
Expect(1, 68681, '\P{Is_Script=  old_Turkic}', "");
Expect(0, 68681, '\P{^Is_Script=  old_Turkic}', "");
Error('\p{Is_Sc=_/a/ORKH}');
Error('\P{Is_Sc=_/a/ORKH}');
Expect(1, 68680, '\p{Is_Sc:	orkh}', "");
Expect(0, 68680, '\p{^Is_Sc:	orkh}', "");
Expect(0, 68680, '\P{Is_Sc:	orkh}', "");
Expect(1, 68680, '\P{^Is_Sc:	orkh}', "");
Expect(0, 68681, '\p{Is_Sc:	orkh}', "");
Expect(1, 68681, '\p{^Is_Sc:	orkh}', "");
Expect(1, 68681, '\P{Is_Sc:	orkh}', "");
Expect(0, 68681, '\P{^Is_Sc:	orkh}', "");
Expect(1, 68680, '\p{Is_Sc=-	orkh}', "");
Expect(0, 68680, '\p{^Is_Sc=-	orkh}', "");
Expect(0, 68680, '\P{Is_Sc=-	orkh}', "");
Expect(1, 68680, '\P{^Is_Sc=-	orkh}', "");
Expect(0, 68681, '\p{Is_Sc=-	orkh}', "");
Expect(1, 68681, '\p{^Is_Sc=-	orkh}', "");
Expect(1, 68681, '\P{Is_Sc=-	orkh}', "");
Expect(0, 68681, '\P{^Is_Sc=-	orkh}', "");
Error('\p{Script=-:=Oriya}');
Error('\P{Script=-:=Oriya}');
Expect(1, 2935, '\p{Script=oriya}', "");
Expect(0, 2935, '\p{^Script=oriya}', "");
Expect(0, 2935, '\P{Script=oriya}', "");
Expect(1, 2935, '\P{^Script=oriya}', "");
Expect(0, 2936, '\p{Script=oriya}', "");
Expect(1, 2936, '\p{^Script=oriya}', "");
Expect(1, 2936, '\P{Script=oriya}', "");
Expect(0, 2936, '\P{^Script=oriya}', "");
Expect(1, 2935, '\p{Script:  _oriya}', "");
Expect(0, 2935, '\p{^Script:  _oriya}', "");
Expect(0, 2935, '\P{Script:  _oriya}', "");
Expect(1, 2935, '\P{^Script:  _oriya}', "");
Expect(0, 2936, '\p{Script:  _oriya}', "");
Expect(1, 2936, '\p{^Script:  _oriya}', "");
Expect(1, 2936, '\P{Script:  _oriya}', "");
Expect(0, 2936, '\P{^Script:  _oriya}', "");
Error('\p{Sc=_:=Orya}');
Error('\P{Sc=_:=Orya}');
Expect(1, 2935, '\p{Sc=orya}', "");
Expect(0, 2935, '\p{^Sc=orya}', "");
Expect(0, 2935, '\P{Sc=orya}', "");
Expect(1, 2935, '\P{^Sc=orya}', "");
Expect(0, 2936, '\p{Sc=orya}', "");
Expect(1, 2936, '\p{^Sc=orya}', "");
Expect(1, 2936, '\P{Sc=orya}', "");
Expect(0, 2936, '\P{^Sc=orya}', "");
Expect(1, 2935, '\p{Sc=	_orya}', "");
Expect(0, 2935, '\p{^Sc=	_orya}', "");
Expect(0, 2935, '\P{Sc=	_orya}', "");
Expect(1, 2935, '\P{^Sc=	_orya}', "");
Expect(0, 2936, '\p{Sc=	_orya}', "");
Expect(1, 2936, '\p{^Sc=	_orya}', "");
Expect(1, 2936, '\P{Sc=	_orya}', "");
Expect(0, 2936, '\P{^Sc=	_orya}', "");
Error('\p{Is_Script= :=Oriya}');
Error('\P{Is_Script= :=Oriya}');
Expect(1, 2935, '\p{Is_Script=oriya}', "");
Expect(0, 2935, '\p{^Is_Script=oriya}', "");
Expect(0, 2935, '\P{Is_Script=oriya}', "");
Expect(1, 2935, '\P{^Is_Script=oriya}', "");
Expect(0, 2936, '\p{Is_Script=oriya}', "");
Expect(1, 2936, '\p{^Is_Script=oriya}', "");
Expect(1, 2936, '\P{Is_Script=oriya}', "");
Expect(0, 2936, '\P{^Is_Script=oriya}', "");
Expect(1, 2935, '\p{Is_Script=-	Oriya}', "");
Expect(0, 2935, '\p{^Is_Script=-	Oriya}', "");
Expect(0, 2935, '\P{Is_Script=-	Oriya}', "");
Expect(1, 2935, '\P{^Is_Script=-	Oriya}', "");
Expect(0, 2936, '\p{Is_Script=-	Oriya}', "");
Expect(1, 2936, '\p{^Is_Script=-	Oriya}', "");
Expect(1, 2936, '\P{Is_Script=-	Oriya}', "");
Expect(0, 2936, '\P{^Is_Script=-	Oriya}', "");
Error('\p{Is_Sc:	:=	ORYA}');
Error('\P{Is_Sc:	:=	ORYA}');
Expect(1, 2935, '\p{Is_Sc=orya}', "");
Expect(0, 2935, '\p{^Is_Sc=orya}', "");
Expect(0, 2935, '\P{Is_Sc=orya}', "");
Expect(1, 2935, '\P{^Is_Sc=orya}', "");
Expect(0, 2936, '\p{Is_Sc=orya}', "");
Expect(1, 2936, '\p{^Is_Sc=orya}', "");
Expect(1, 2936, '\P{Is_Sc=orya}', "");
Expect(0, 2936, '\P{^Is_Sc=orya}', "");
Expect(1, 2935, '\p{Is_Sc= ORYA}', "");
Expect(0, 2935, '\p{^Is_Sc= ORYA}', "");
Expect(0, 2935, '\P{Is_Sc= ORYA}', "");
Expect(1, 2935, '\P{^Is_Sc= ORYA}', "");
Expect(0, 2936, '\p{Is_Sc= ORYA}', "");
Expect(1, 2936, '\p{^Is_Sc= ORYA}', "");
Expect(1, 2936, '\P{Is_Sc= ORYA}', "");
Expect(0, 2936, '\P{^Is_Sc= ORYA}', "");
Error('\p{Script=:= OSMANYA}');
Error('\P{Script=:= OSMANYA}');
Expect(1, 66729, '\p{Script=osmanya}', "");
Expect(0, 66729, '\p{^Script=osmanya}', "");
Expect(0, 66729, '\P{Script=osmanya}', "");
Expect(1, 66729, '\P{^Script=osmanya}', "");
Expect(0, 66730, '\p{Script=osmanya}', "");
Expect(1, 66730, '\p{^Script=osmanya}', "");
Expect(1, 66730, '\P{Script=osmanya}', "");
Expect(0, 66730, '\P{^Script=osmanya}', "");
Expect(1, 66729, '\p{Script=_	Osmanya}', "");
Expect(0, 66729, '\p{^Script=_	Osmanya}', "");
Expect(0, 66729, '\P{Script=_	Osmanya}', "");
Expect(1, 66729, '\P{^Script=_	Osmanya}', "");
Expect(0, 66730, '\p{Script=_	Osmanya}', "");
Expect(1, 66730, '\p{^Script=_	Osmanya}', "");
Expect(1, 66730, '\P{Script=_	Osmanya}', "");
Expect(0, 66730, '\P{^Script=_	Osmanya}', "");
Error('\p{Sc=/a/  Osma}');
Error('\P{Sc=/a/  Osma}');
Expect(1, 66729, '\p{Sc=osma}', "");
Expect(0, 66729, '\p{^Sc=osma}', "");
Expect(0, 66729, '\P{Sc=osma}', "");
Expect(1, 66729, '\P{^Sc=osma}', "");
Expect(0, 66730, '\p{Sc=osma}', "");
Expect(1, 66730, '\p{^Sc=osma}', "");
Expect(1, 66730, '\P{Sc=osma}', "");
Expect(0, 66730, '\P{^Sc=osma}', "");
Expect(1, 66729, '\p{Sc=-Osma}', "");
Expect(0, 66729, '\p{^Sc=-Osma}', "");
Expect(0, 66729, '\P{Sc=-Osma}', "");
Expect(1, 66729, '\P{^Sc=-Osma}', "");
Expect(0, 66730, '\p{Sc=-Osma}', "");
Expect(1, 66730, '\p{^Sc=-Osma}', "");
Expect(1, 66730, '\P{Sc=-Osma}', "");
Expect(0, 66730, '\P{^Sc=-Osma}', "");
Error('\p{Is_Script=/a/-OSMANYA}');
Error('\P{Is_Script=/a/-OSMANYA}');
Expect(1, 66729, '\p{Is_Script:   osmanya}', "");
Expect(0, 66729, '\p{^Is_Script:   osmanya}', "");
Expect(0, 66729, '\P{Is_Script:   osmanya}', "");
Expect(1, 66729, '\P{^Is_Script:   osmanya}', "");
Expect(0, 66730, '\p{Is_Script:   osmanya}', "");
Expect(1, 66730, '\p{^Is_Script:   osmanya}', "");
Expect(1, 66730, '\P{Is_Script:   osmanya}', "");
Expect(0, 66730, '\P{^Is_Script:   osmanya}', "");
Expect(1, 66729, '\p{Is_Script=_-OSMANYA}', "");
Expect(0, 66729, '\p{^Is_Script=_-OSMANYA}', "");
Expect(0, 66729, '\P{Is_Script=_-OSMANYA}', "");
Expect(1, 66729, '\P{^Is_Script=_-OSMANYA}', "");
Expect(0, 66730, '\p{Is_Script=_-OSMANYA}', "");
Expect(1, 66730, '\p{^Is_Script=_-OSMANYA}', "");
Expect(1, 66730, '\P{Is_Script=_-OSMANYA}', "");
Expect(0, 66730, '\P{^Is_Script=_-OSMANYA}', "");
Error('\p{Is_Sc=/a/ 	Osma}');
Error('\P{Is_Sc=/a/ 	Osma}');
Expect(1, 66729, '\p{Is_Sc=osma}', "");
Expect(0, 66729, '\p{^Is_Sc=osma}', "");
Expect(0, 66729, '\P{Is_Sc=osma}', "");
Expect(1, 66729, '\P{^Is_Sc=osma}', "");
Expect(0, 66730, '\p{Is_Sc=osma}', "");
Expect(1, 66730, '\p{^Is_Sc=osma}', "");
Expect(1, 66730, '\P{Is_Sc=osma}', "");
Expect(0, 66730, '\P{^Is_Sc=osma}', "");
Expect(1, 66729, '\p{Is_Sc=__osma}', "");
Expect(0, 66729, '\p{^Is_Sc=__osma}', "");
Expect(0, 66729, '\P{Is_Sc=__osma}', "");
Expect(1, 66729, '\P{^Is_Sc=__osma}', "");
Expect(0, 66730, '\p{Is_Sc=__osma}', "");
Expect(1, 66730, '\p{^Is_Sc=__osma}', "");
Expect(1, 66730, '\P{Is_Sc=__osma}', "");
Expect(0, 66730, '\P{^Is_Sc=__osma}', "");
Error('\p{Script=:=PHAGS_PA}');
Error('\P{Script=:=PHAGS_PA}');
Expect(1, 43127, '\p{Script=phagspa}', "");
Expect(0, 43127, '\p{^Script=phagspa}', "");
Expect(0, 43127, '\P{Script=phagspa}', "");
Expect(1, 43127, '\P{^Script=phagspa}', "");
Expect(0, 43128, '\p{Script=phagspa}', "");
Expect(1, 43128, '\p{^Script=phagspa}', "");
Expect(1, 43128, '\P{Script=phagspa}', "");
Expect(0, 43128, '\P{^Script=phagspa}', "");
Expect(1, 43127, '\p{Script= PHAGS_pa}', "");
Expect(0, 43127, '\p{^Script= PHAGS_pa}', "");
Expect(0, 43127, '\P{Script= PHAGS_pa}', "");
Expect(1, 43127, '\P{^Script= PHAGS_pa}', "");
Expect(0, 43128, '\p{Script= PHAGS_pa}', "");
Expect(1, 43128, '\p{^Script= PHAGS_pa}', "");
Expect(1, 43128, '\P{Script= PHAGS_pa}', "");
Expect(0, 43128, '\P{^Script= PHAGS_pa}', "");
Error('\p{Sc=:= _Phag}');
Error('\P{Sc=:= _Phag}');
Expect(1, 43127, '\p{Sc=phag}', "");
Expect(0, 43127, '\p{^Sc=phag}', "");
Expect(0, 43127, '\P{Sc=phag}', "");
Expect(1, 43127, '\P{^Sc=phag}', "");
Expect(0, 43128, '\p{Sc=phag}', "");
Expect(1, 43128, '\p{^Sc=phag}', "");
Expect(1, 43128, '\P{Sc=phag}', "");
Expect(0, 43128, '\P{^Sc=phag}', "");
Expect(1, 43127, '\p{Sc:_-phag}', "");
Expect(0, 43127, '\p{^Sc:_-phag}', "");
Expect(0, 43127, '\P{Sc:_-phag}', "");
Expect(1, 43127, '\P{^Sc:_-phag}', "");
Expect(0, 43128, '\p{Sc:_-phag}', "");
Expect(1, 43128, '\p{^Sc:_-phag}', "");
Expect(1, 43128, '\P{Sc:_-phag}', "");
Expect(0, 43128, '\P{^Sc:_-phag}', "");
Error('\p{Is_Script=/a/_-PHAGS_PA}');
Error('\P{Is_Script=/a/_-PHAGS_PA}');
Expect(1, 43127, '\p{Is_Script=phagspa}', "");
Expect(0, 43127, '\p{^Is_Script=phagspa}', "");
Expect(0, 43127, '\P{Is_Script=phagspa}', "");
Expect(1, 43127, '\P{^Is_Script=phagspa}', "");
Expect(0, 43128, '\p{Is_Script=phagspa}', "");
Expect(1, 43128, '\p{^Is_Script=phagspa}', "");
Expect(1, 43128, '\P{Is_Script=phagspa}', "");
Expect(0, 43128, '\P{^Is_Script=phagspa}', "");
Expect(1, 43127, '\p{Is_Script=  PHAGS_Pa}', "");
Expect(0, 43127, '\p{^Is_Script=  PHAGS_Pa}', "");
Expect(0, 43127, '\P{Is_Script=  PHAGS_Pa}', "");
Expect(1, 43127, '\P{^Is_Script=  PHAGS_Pa}', "");
Expect(0, 43128, '\p{Is_Script=  PHAGS_Pa}', "");
Expect(1, 43128, '\p{^Is_Script=  PHAGS_Pa}', "");
Expect(1, 43128, '\P{Is_Script=  PHAGS_Pa}', "");
Expect(0, 43128, '\P{^Is_Script=  PHAGS_Pa}', "");
Error('\p{Is_Sc:   :=__phag}');
Error('\P{Is_Sc:   :=__phag}');
Expect(1, 43127, '\p{Is_Sc=phag}', "");
Expect(0, 43127, '\p{^Is_Sc=phag}', "");
Expect(0, 43127, '\P{Is_Sc=phag}', "");
Expect(1, 43127, '\P{^Is_Sc=phag}', "");
Expect(0, 43128, '\p{Is_Sc=phag}', "");
Expect(1, 43128, '\p{^Is_Sc=phag}', "");
Expect(1, 43128, '\P{Is_Sc=phag}', "");
Expect(0, 43128, '\P{^Is_Sc=phag}', "");
Expect(1, 43127, '\p{Is_Sc=	-Phag}', "");
Expect(0, 43127, '\p{^Is_Sc=	-Phag}', "");
Expect(0, 43127, '\P{Is_Sc=	-Phag}', "");
Expect(1, 43127, '\P{^Is_Sc=	-Phag}', "");
Expect(0, 43128, '\p{Is_Sc=	-Phag}', "");
Expect(1, 43128, '\p{^Is_Sc=	-Phag}', "");
Expect(1, 43128, '\P{Is_Sc=	-Phag}', "");
Expect(0, 43128, '\P{^Is_Sc=	-Phag}', "");
Error('\p{Script=:=	Inscriptional_PAHLAVI}');
Error('\P{Script=:=	Inscriptional_PAHLAVI}');
Expect(1, 68479, '\p{Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Script=	Inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\p{^Script=	Inscriptional_PAHLAVI}', "");
Expect(0, 68479, '\P{Script=	Inscriptional_PAHLAVI}', "");
Expect(1, 68479, '\P{^Script=	Inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\p{Script=	Inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\p{^Script=	Inscriptional_PAHLAVI}', "");
Expect(1, 68480, '\P{Script=	Inscriptional_PAHLAVI}', "");
Expect(0, 68480, '\P{^Script=	Inscriptional_PAHLAVI}', "");
Error('\p{Sc=/a/-Phli}');
Error('\P{Sc=/a/-Phli}');
Expect(1, 68479, '\p{Sc:	phli}', "");
Expect(0, 68479, '\p{^Sc:	phli}', "");
Expect(0, 68479, '\P{Sc:	phli}', "");
Expect(1, 68479, '\P{^Sc:	phli}', "");
Expect(0, 68480, '\p{Sc:	phli}', "");
Expect(1, 68480, '\p{^Sc:	phli}', "");
Expect(1, 68480, '\P{Sc:	phli}', "");
Expect(0, 68480, '\P{^Sc:	phli}', "");
Expect(1, 68479, '\p{Sc=_Phli}', "");
Expect(0, 68479, '\p{^Sc=_Phli}', "");
Expect(0, 68479, '\P{Sc=_Phli}', "");
Expect(1, 68479, '\P{^Sc=_Phli}', "");
Expect(0, 68480, '\p{Sc=_Phli}', "");
Expect(1, 68480, '\p{^Sc=_Phli}', "");
Expect(1, 68480, '\P{Sc=_Phli}', "");
Expect(0, 68480, '\P{^Sc=_Phli}', "");
Error('\p{Is_Script=_/a/Inscriptional_pahlavi}');
Error('\P{Is_Script=_/a/Inscriptional_pahlavi}');
Expect(1, 68479, '\p{Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Script=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Script=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Script:		Inscriptional_pahlavi}', "");
Expect(0, 68479, '\p{^Is_Script:		Inscriptional_pahlavi}', "");
Expect(0, 68479, '\P{Is_Script:		Inscriptional_pahlavi}', "");
Expect(1, 68479, '\P{^Is_Script:		Inscriptional_pahlavi}', "");
Expect(0, 68480, '\p{Is_Script:		Inscriptional_pahlavi}', "");
Expect(1, 68480, '\p{^Is_Script:		Inscriptional_pahlavi}', "");
Expect(1, 68480, '\P{Is_Script:		Inscriptional_pahlavi}', "");
Expect(0, 68480, '\P{^Is_Script:		Inscriptional_pahlavi}', "");
Error('\p{Is_Sc: _:=phli}');
Error('\P{Is_Sc: _:=phli}');
Expect(1, 68479, '\p{Is_Sc=phli}', "");
Expect(0, 68479, '\p{^Is_Sc=phli}', "");
Expect(0, 68479, '\P{Is_Sc=phli}', "");
Expect(1, 68479, '\P{^Is_Sc=phli}', "");
Expect(0, 68480, '\p{Is_Sc=phli}', "");
Expect(1, 68480, '\p{^Is_Sc=phli}', "");
Expect(1, 68480, '\P{Is_Sc=phli}', "");
Expect(0, 68480, '\P{^Is_Sc=phli}', "");
Expect(1, 68479, '\p{Is_Sc=-	Phli}', "");
Expect(0, 68479, '\p{^Is_Sc=-	Phli}', "");
Expect(0, 68479, '\P{Is_Sc=-	Phli}', "");
Expect(1, 68479, '\P{^Is_Sc=-	Phli}', "");
Expect(0, 68480, '\p{Is_Sc=-	Phli}', "");
Expect(1, 68480, '\p{^Is_Sc=-	Phli}', "");
Expect(1, 68480, '\P{Is_Sc=-	Phli}', "");
Expect(0, 68480, '\P{^Is_Sc=-	Phli}', "");
Error('\p{Script=-/a/Phoenician}');
Error('\P{Script=-/a/Phoenician}');
Expect(1, 67871, '\p{Script=phoenician}', "");
Expect(0, 67871, '\p{^Script=phoenician}', "");
Expect(0, 67871, '\P{Script=phoenician}', "");
Expect(1, 67871, '\P{^Script=phoenician}', "");
Expect(0, 67872, '\p{Script=phoenician}', "");
Expect(1, 67872, '\p{^Script=phoenician}', "");
Expect(1, 67872, '\P{Script=phoenician}', "");
Expect(0, 67872, '\P{^Script=phoenician}', "");
Expect(1, 67871, '\p{Script=_ Phoenician}', "");
Expect(0, 67871, '\p{^Script=_ Phoenician}', "");
Expect(0, 67871, '\P{Script=_ Phoenician}', "");
Expect(1, 67871, '\P{^Script=_ Phoenician}', "");
Expect(0, 67872, '\p{Script=_ Phoenician}', "");
Expect(1, 67872, '\p{^Script=_ Phoenician}', "");
Expect(1, 67872, '\P{Script=_ Phoenician}', "");
Expect(0, 67872, '\P{^Script=_ Phoenician}', "");
Error('\p{Sc=/a/-	phnx}');
Error('\P{Sc=/a/-	phnx}');
Expect(1, 67871, '\p{Sc=phnx}', "");
Expect(0, 67871, '\p{^Sc=phnx}', "");
Expect(0, 67871, '\P{Sc=phnx}', "");
Expect(1, 67871, '\P{^Sc=phnx}', "");
Expect(0, 67872, '\p{Sc=phnx}', "");
Expect(1, 67872, '\p{^Sc=phnx}', "");
Expect(1, 67872, '\P{Sc=phnx}', "");
Expect(0, 67872, '\P{^Sc=phnx}', "");
Expect(1, 67871, '\p{Sc= 	Phnx}', "");
Expect(0, 67871, '\p{^Sc= 	Phnx}', "");
Expect(0, 67871, '\P{Sc= 	Phnx}', "");
Expect(1, 67871, '\P{^Sc= 	Phnx}', "");
Expect(0, 67872, '\p{Sc= 	Phnx}', "");
Expect(1, 67872, '\p{^Sc= 	Phnx}', "");
Expect(1, 67872, '\P{Sc= 	Phnx}', "");
Expect(0, 67872, '\P{^Sc= 	Phnx}', "");
Error('\p{Is_Script=:=	Phoenician}');
Error('\P{Is_Script=:=	Phoenician}');
Expect(1, 67871, '\p{Is_Script=phoenician}', "");
Expect(0, 67871, '\p{^Is_Script=phoenician}', "");
Expect(0, 67871, '\P{Is_Script=phoenician}', "");
Expect(1, 67871, '\P{^Is_Script=phoenician}', "");
Expect(0, 67872, '\p{Is_Script=phoenician}', "");
Expect(1, 67872, '\p{^Is_Script=phoenician}', "");
Expect(1, 67872, '\P{Is_Script=phoenician}', "");
Expect(0, 67872, '\P{^Is_Script=phoenician}', "");
Expect(1, 67871, '\p{Is_Script= -Phoenician}', "");
Expect(0, 67871, '\p{^Is_Script= -Phoenician}', "");
Expect(0, 67871, '\P{Is_Script= -Phoenician}', "");
Expect(1, 67871, '\P{^Is_Script= -Phoenician}', "");
Expect(0, 67872, '\p{Is_Script= -Phoenician}', "");
Expect(1, 67872, '\p{^Is_Script= -Phoenician}', "");
Expect(1, 67872, '\P{Is_Script= -Phoenician}', "");
Expect(0, 67872, '\P{^Is_Script= -Phoenician}', "");
Error('\p{Is_Sc=- phnx/a/}');
Error('\P{Is_Sc=- phnx/a/}');
Expect(1, 67871, '\p{Is_Sc=phnx}', "");
Expect(0, 67871, '\p{^Is_Sc=phnx}', "");
Expect(0, 67871, '\P{Is_Sc=phnx}', "");
Expect(1, 67871, '\P{^Is_Sc=phnx}', "");
Expect(0, 67872, '\p{Is_Sc=phnx}', "");
Expect(1, 67872, '\p{^Is_Sc=phnx}', "");
Expect(1, 67872, '\P{Is_Sc=phnx}', "");
Expect(0, 67872, '\P{^Is_Sc=phnx}', "");
Expect(1, 67871, '\p{Is_Sc=-_phnx}', "");
Expect(0, 67871, '\p{^Is_Sc=-_phnx}', "");
Expect(0, 67871, '\P{Is_Sc=-_phnx}', "");
Expect(1, 67871, '\P{^Is_Sc=-_phnx}', "");
Expect(0, 67872, '\p{Is_Sc=-_phnx}', "");
Expect(1, 67872, '\p{^Is_Sc=-_phnx}', "");
Expect(1, 67872, '\P{Is_Sc=-_phnx}', "");
Expect(0, 67872, '\P{^Is_Sc=-_phnx}', "");
Error('\p{Script=	 Miao/a/}');
Error('\P{Script=	 Miao/a/}');
Expect(1, 94111, '\p{Script=miao}', "");
Expect(0, 94111, '\p{^Script=miao}', "");
Expect(0, 94111, '\P{Script=miao}', "");
Expect(1, 94111, '\P{^Script=miao}', "");
Expect(0, 94112, '\p{Script=miao}', "");
Expect(1, 94112, '\p{^Script=miao}', "");
Expect(1, 94112, '\P{Script=miao}', "");
Expect(0, 94112, '\P{^Script=miao}', "");
Expect(1, 94111, '\p{Script=	Miao}', "");
Expect(0, 94111, '\p{^Script=	Miao}', "");
Expect(0, 94111, '\P{Script=	Miao}', "");
Expect(1, 94111, '\P{^Script=	Miao}', "");
Expect(0, 94112, '\p{Script=	Miao}', "");
Expect(1, 94112, '\p{^Script=	Miao}', "");
Expect(1, 94112, '\P{Script=	Miao}', "");
Expect(0, 94112, '\P{^Script=	Miao}', "");
Error('\p{Sc=:=Plrd}');
Error('\P{Sc=:=Plrd}');
Expect(1, 94111, '\p{Sc=plrd}', "");
Expect(0, 94111, '\p{^Sc=plrd}', "");
Expect(0, 94111, '\P{Sc=plrd}', "");
Expect(1, 94111, '\P{^Sc=plrd}', "");
Expect(0, 94112, '\p{Sc=plrd}', "");
Expect(1, 94112, '\p{^Sc=plrd}', "");
Expect(1, 94112, '\P{Sc=plrd}', "");
Expect(0, 94112, '\P{^Sc=plrd}', "");
Expect(1, 94111, '\p{Sc=_Plrd}', "");
Expect(0, 94111, '\p{^Sc=_Plrd}', "");
Expect(0, 94111, '\P{Sc=_Plrd}', "");
Expect(1, 94111, '\P{^Sc=_Plrd}', "");
Expect(0, 94112, '\p{Sc=_Plrd}', "");
Expect(1, 94112, '\p{^Sc=_Plrd}', "");
Expect(1, 94112, '\P{Sc=_Plrd}', "");
Expect(0, 94112, '\P{^Sc=_Plrd}', "");
Error('\p{Is_Script=-Miao/a/}');
Error('\P{Is_Script=-Miao/a/}');
Expect(1, 94111, '\p{Is_Script=miao}', "");
Expect(0, 94111, '\p{^Is_Script=miao}', "");
Expect(0, 94111, '\P{Is_Script=miao}', "");
Expect(1, 94111, '\P{^Is_Script=miao}', "");
Expect(0, 94112, '\p{Is_Script=miao}', "");
Expect(1, 94112, '\p{^Is_Script=miao}', "");
Expect(1, 94112, '\P{Is_Script=miao}', "");
Expect(0, 94112, '\P{^Is_Script=miao}', "");
Expect(1, 94111, '\p{Is_Script= -MIAO}', "");
Expect(0, 94111, '\p{^Is_Script= -MIAO}', "");
Expect(0, 94111, '\P{Is_Script= -MIAO}', "");
Expect(1, 94111, '\P{^Is_Script= -MIAO}', "");
Expect(0, 94112, '\p{Is_Script= -MIAO}', "");
Expect(1, 94112, '\p{^Is_Script= -MIAO}', "");
Expect(1, 94112, '\P{Is_Script= -MIAO}', "");
Expect(0, 94112, '\P{^Is_Script= -MIAO}', "");
Error('\p{Is_Sc=/a/PLRD}');
Error('\P{Is_Sc=/a/PLRD}');
Expect(1, 94111, '\p{Is_Sc=plrd}', "");
Expect(0, 94111, '\p{^Is_Sc=plrd}', "");
Expect(0, 94111, '\P{Is_Sc=plrd}', "");
Expect(1, 94111, '\P{^Is_Sc=plrd}', "");
Expect(0, 94112, '\p{Is_Sc=plrd}', "");
Expect(1, 94112, '\p{^Is_Sc=plrd}', "");
Expect(1, 94112, '\P{Is_Sc=plrd}', "");
Expect(0, 94112, '\P{^Is_Sc=plrd}', "");
Expect(1, 94111, '\p{Is_Sc=-	plrd}', "");
Expect(0, 94111, '\p{^Is_Sc=-	plrd}', "");
Expect(0, 94111, '\P{Is_Sc=-	plrd}', "");
Expect(1, 94111, '\P{^Is_Sc=-	plrd}', "");
Expect(0, 94112, '\p{Is_Sc=-	plrd}', "");
Expect(1, 94112, '\p{^Is_Sc=-	plrd}', "");
Expect(1, 94112, '\P{Is_Sc=-	plrd}', "");
Expect(0, 94112, '\P{^Is_Sc=-	plrd}', "");
Error('\p{Script=:=_ inscriptional_Parthian}');
Error('\P{Script=:=_ inscriptional_Parthian}');
Expect(1, 68447, '\p{Script=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Script=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Script=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Script=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Script=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Script=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Script=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Script=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Script=	 Inscriptional_parthian}', "");
Expect(0, 68447, '\p{^Script=	 Inscriptional_parthian}', "");
Expect(0, 68447, '\P{Script=	 Inscriptional_parthian}', "");
Expect(1, 68447, '\P{^Script=	 Inscriptional_parthian}', "");
Expect(0, 68448, '\p{Script=	 Inscriptional_parthian}', "");
Expect(1, 68448, '\p{^Script=	 Inscriptional_parthian}', "");
Expect(1, 68448, '\P{Script=	 Inscriptional_parthian}', "");
Expect(0, 68448, '\P{^Script=	 Inscriptional_parthian}', "");
Error('\p{Sc:-:=Prti}');
Error('\P{Sc:-:=Prti}');
Expect(1, 68447, '\p{Sc=prti}', "");
Expect(0, 68447, '\p{^Sc=prti}', "");
Expect(0, 68447, '\P{Sc=prti}', "");
Expect(1, 68447, '\P{^Sc=prti}', "");
Expect(0, 68448, '\p{Sc=prti}', "");
Expect(1, 68448, '\p{^Sc=prti}', "");
Expect(1, 68448, '\P{Sc=prti}', "");
Expect(0, 68448, '\P{^Sc=prti}', "");
Expect(1, 68447, '\p{Sc=-PRTI}', "");
Expect(0, 68447, '\p{^Sc=-PRTI}', "");
Expect(0, 68447, '\P{Sc=-PRTI}', "");
Expect(1, 68447, '\P{^Sc=-PRTI}', "");
Expect(0, 68448, '\p{Sc=-PRTI}', "");
Expect(1, 68448, '\p{^Sc=-PRTI}', "");
Expect(1, 68448, '\P{Sc=-PRTI}', "");
Expect(0, 68448, '\P{^Sc=-PRTI}', "");
Error('\p{Is_Script:   :=-inscriptional_parthian}');
Error('\P{Is_Script:   :=-inscriptional_parthian}');
Expect(1, 68447, '\p{Is_Script=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Script=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Script=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Script=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Script=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Script=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Script=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Script=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\p{^Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68447, '\P{Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(1, 68447, '\P{^Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\p{Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\p{^Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(1, 68448, '\P{Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Expect(0, 68448, '\P{^Is_Script=	 INSCRIPTIONAL_Parthian}', "");
Error('\p{Is_Sc:    :=Prti}');
Error('\P{Is_Sc:    :=Prti}');
Expect(1, 68447, '\p{Is_Sc=prti}', "");
Expect(0, 68447, '\p{^Is_Sc=prti}', "");
Expect(0, 68447, '\P{Is_Sc=prti}', "");
Expect(1, 68447, '\P{^Is_Sc=prti}', "");
Expect(0, 68448, '\p{Is_Sc=prti}', "");
Expect(1, 68448, '\p{^Is_Sc=prti}', "");
Expect(1, 68448, '\P{Is_Sc=prti}', "");
Expect(0, 68448, '\P{^Is_Sc=prti}', "");
Expect(1, 68447, '\p{Is_Sc=PRTI}', "");
Expect(0, 68447, '\p{^Is_Sc=PRTI}', "");
Expect(0, 68447, '\P{Is_Sc=PRTI}', "");
Expect(1, 68447, '\P{^Is_Sc=PRTI}', "");
Expect(0, 68448, '\p{Is_Sc=PRTI}', "");
Expect(1, 68448, '\p{^Is_Sc=PRTI}', "");
Expect(1, 68448, '\P{Is_Sc=PRTI}', "");
Expect(0, 68448, '\P{^Is_Sc=PRTI}', "");
Error('\p{Script=/a/_Rejang}');
Error('\P{Script=/a/_Rejang}');
Expect(1, 43359, '\p{Script=rejang}', "");
Expect(0, 43359, '\p{^Script=rejang}', "");
Expect(0, 43359, '\P{Script=rejang}', "");
Expect(1, 43359, '\P{^Script=rejang}', "");
Expect(0, 43360, '\p{Script=rejang}', "");
Expect(1, 43360, '\p{^Script=rejang}', "");
Expect(1, 43360, '\P{Script=rejang}', "");
Expect(0, 43360, '\P{^Script=rejang}', "");
Expect(1, 43359, '\p{Script=	_Rejang}', "");
Expect(0, 43359, '\p{^Script=	_Rejang}', "");
Expect(0, 43359, '\P{Script=	_Rejang}', "");
Expect(1, 43359, '\P{^Script=	_Rejang}', "");
Expect(0, 43360, '\p{Script=	_Rejang}', "");
Expect(1, 43360, '\p{^Script=	_Rejang}', "");
Expect(1, 43360, '\P{Script=	_Rejang}', "");
Expect(0, 43360, '\P{^Script=	_Rejang}', "");
Error('\p{Sc=	/a/Rjng}');
Error('\P{Sc=	/a/Rjng}');
Expect(1, 43359, '\p{Sc:   rjng}', "");
Expect(0, 43359, '\p{^Sc:   rjng}', "");
Expect(0, 43359, '\P{Sc:   rjng}', "");
Expect(1, 43359, '\P{^Sc:   rjng}', "");
Expect(0, 43360, '\p{Sc:   rjng}', "");
Expect(1, 43360, '\p{^Sc:   rjng}', "");
Expect(1, 43360, '\P{Sc:   rjng}', "");
Expect(0, 43360, '\P{^Sc:   rjng}', "");
Expect(1, 43359, '\p{Sc=	 rjng}', "");
Expect(0, 43359, '\p{^Sc=	 rjng}', "");
Expect(0, 43359, '\P{Sc=	 rjng}', "");
Expect(1, 43359, '\P{^Sc=	 rjng}', "");
Expect(0, 43360, '\p{Sc=	 rjng}', "");
Expect(1, 43360, '\p{^Sc=	 rjng}', "");
Expect(1, 43360, '\P{Sc=	 rjng}', "");
Expect(0, 43360, '\P{^Sc=	 rjng}', "");
Error('\p{Is_Script:	-REJANG:=}');
Error('\P{Is_Script:	-REJANG:=}');
Expect(1, 43359, '\p{Is_Script=rejang}', "");
Expect(0, 43359, '\p{^Is_Script=rejang}', "");
Expect(0, 43359, '\P{Is_Script=rejang}', "");
Expect(1, 43359, '\P{^Is_Script=rejang}', "");
Expect(0, 43360, '\p{Is_Script=rejang}', "");
Expect(1, 43360, '\p{^Is_Script=rejang}', "");
Expect(1, 43360, '\P{Is_Script=rejang}', "");
Expect(0, 43360, '\P{^Is_Script=rejang}', "");
Expect(1, 43359, '\p{Is_Script=_Rejang}', "");
Expect(0, 43359, '\p{^Is_Script=_Rejang}', "");
Expect(0, 43359, '\P{Is_Script=_Rejang}', "");
Expect(1, 43359, '\P{^Is_Script=_Rejang}', "");
Expect(0, 43360, '\p{Is_Script=_Rejang}', "");
Expect(1, 43360, '\p{^Is_Script=_Rejang}', "");
Expect(1, 43360, '\P{Is_Script=_Rejang}', "");
Expect(0, 43360, '\P{^Is_Script=_Rejang}', "");
Error('\p{Is_Sc= RJNG/a/}');
Error('\P{Is_Sc= RJNG/a/}');
Expect(1, 43359, '\p{Is_Sc=rjng}', "");
Expect(0, 43359, '\p{^Is_Sc=rjng}', "");
Expect(0, 43359, '\P{Is_Sc=rjng}', "");
Expect(1, 43359, '\P{^Is_Sc=rjng}', "");
Expect(0, 43360, '\p{Is_Sc=rjng}', "");
Expect(1, 43360, '\p{^Is_Sc=rjng}', "");
Expect(1, 43360, '\P{Is_Sc=rjng}', "");
Expect(0, 43360, '\P{^Is_Sc=rjng}', "");
Expect(1, 43359, '\p{Is_Sc=_RJNG}', "");
Expect(0, 43359, '\p{^Is_Sc=_RJNG}', "");
Expect(0, 43359, '\P{Is_Sc=_RJNG}', "");
Expect(1, 43359, '\P{^Is_Sc=_RJNG}', "");
Expect(0, 43360, '\p{Is_Sc=_RJNG}', "");
Expect(1, 43360, '\p{^Is_Sc=_RJNG}', "");
Expect(1, 43360, '\P{Is_Sc=_RJNG}', "");
Expect(0, 43360, '\P{^Is_Sc=_RJNG}', "");
Error('\p{Script=	:=runic}');
Error('\P{Script=	:=runic}');
Expect(1, 5872, '\p{Script=runic}', "");
Expect(0, 5872, '\p{^Script=runic}', "");
Expect(0, 5872, '\P{Script=runic}', "");
Expect(1, 5872, '\P{^Script=runic}', "");
Expect(0, 5873, '\p{Script=runic}', "");
Expect(1, 5873, '\p{^Script=runic}', "");
Expect(1, 5873, '\P{Script=runic}', "");
Expect(0, 5873, '\P{^Script=runic}', "");
Expect(1, 5872, '\p{Script=-Runic}', "");
Expect(0, 5872, '\p{^Script=-Runic}', "");
Expect(0, 5872, '\P{Script=-Runic}', "");
Expect(1, 5872, '\P{^Script=-Runic}', "");
Expect(0, 5873, '\p{Script=-Runic}', "");
Expect(1, 5873, '\p{^Script=-Runic}', "");
Expect(1, 5873, '\P{Script=-Runic}', "");
Expect(0, 5873, '\P{^Script=-Runic}', "");
Error('\p{Sc=:=	-Runr}');
Error('\P{Sc=:=	-Runr}');
Expect(1, 5872, '\p{Sc=runr}', "");
Expect(0, 5872, '\p{^Sc=runr}', "");
Expect(0, 5872, '\P{Sc=runr}', "");
Expect(1, 5872, '\P{^Sc=runr}', "");
Expect(0, 5873, '\p{Sc=runr}', "");
Expect(1, 5873, '\p{^Sc=runr}', "");
Expect(1, 5873, '\P{Sc=runr}', "");
Expect(0, 5873, '\P{^Sc=runr}', "");
Expect(1, 5872, '\p{Sc=_ Runr}', "");
Expect(0, 5872, '\p{^Sc=_ Runr}', "");
Expect(0, 5872, '\P{Sc=_ Runr}', "");
Expect(1, 5872, '\P{^Sc=_ Runr}', "");
Expect(0, 5873, '\p{Sc=_ Runr}', "");
Expect(1, 5873, '\p{^Sc=_ Runr}', "");
Expect(1, 5873, '\P{Sc=_ Runr}', "");
Expect(0, 5873, '\P{^Sc=_ Runr}', "");
Error('\p{Is_Script=_-runic/a/}');
Error('\P{Is_Script=_-runic/a/}');
Expect(1, 5872, '\p{Is_Script=runic}', "");
Expect(0, 5872, '\p{^Is_Script=runic}', "");
Expect(0, 5872, '\P{Is_Script=runic}', "");
Expect(1, 5872, '\P{^Is_Script=runic}', "");
Expect(0, 5873, '\p{Is_Script=runic}', "");
Expect(1, 5873, '\p{^Is_Script=runic}', "");
Expect(1, 5873, '\P{Is_Script=runic}', "");
Expect(0, 5873, '\P{^Is_Script=runic}', "");
Expect(1, 5872, '\p{Is_Script= _RUNIC}', "");
Expect(0, 5872, '\p{^Is_Script= _RUNIC}', "");
Expect(0, 5872, '\P{Is_Script= _RUNIC}', "");
Expect(1, 5872, '\P{^Is_Script= _RUNIC}', "");
Expect(0, 5873, '\p{Is_Script= _RUNIC}', "");
Expect(1, 5873, '\p{^Is_Script= _RUNIC}', "");
Expect(1, 5873, '\P{Is_Script= _RUNIC}', "");
Expect(0, 5873, '\P{^Is_Script= _RUNIC}', "");
Error('\p{Is_Sc=_/a/Runr}');
Error('\P{Is_Sc=_/a/Runr}');
Expect(1, 5872, '\p{Is_Sc: runr}', "");
Expect(0, 5872, '\p{^Is_Sc: runr}', "");
Expect(0, 5872, '\P{Is_Sc: runr}', "");
Expect(1, 5872, '\P{^Is_Sc: runr}', "");
Expect(0, 5873, '\p{Is_Sc: runr}', "");
Expect(1, 5873, '\p{^Is_Sc: runr}', "");
Expect(1, 5873, '\P{Is_Sc: runr}', "");
Expect(0, 5873, '\P{^Is_Sc: runr}', "");
Expect(1, 5872, '\p{Is_Sc= RUNR}', "");
Expect(0, 5872, '\p{^Is_Sc= RUNR}', "");
Expect(0, 5872, '\P{Is_Sc= RUNR}', "");
Expect(1, 5872, '\P{^Is_Sc= RUNR}', "");
Expect(0, 5873, '\p{Is_Sc= RUNR}', "");
Expect(1, 5873, '\p{^Is_Sc= RUNR}', "");
Expect(1, 5873, '\P{Is_Sc= RUNR}', "");
Expect(0, 5873, '\P{^Is_Sc= RUNR}', "");
Error('\p{Script=	/a/Samaritan}');
Error('\P{Script=	/a/Samaritan}');
Expect(1, 2110, '\p{Script=samaritan}', "");
Expect(0, 2110, '\p{^Script=samaritan}', "");
Expect(0, 2110, '\P{Script=samaritan}', "");
Expect(1, 2110, '\P{^Script=samaritan}', "");
Expect(0, 2111, '\p{Script=samaritan}', "");
Expect(1, 2111, '\p{^Script=samaritan}', "");
Expect(1, 2111, '\P{Script=samaritan}', "");
Expect(0, 2111, '\P{^Script=samaritan}', "");
Expect(1, 2110, '\p{Script=-	Samaritan}', "");
Expect(0, 2110, '\p{^Script=-	Samaritan}', "");
Expect(0, 2110, '\P{Script=-	Samaritan}', "");
Expect(1, 2110, '\P{^Script=-	Samaritan}', "");
Expect(0, 2111, '\p{Script=-	Samaritan}', "");
Expect(1, 2111, '\p{^Script=-	Samaritan}', "");
Expect(1, 2111, '\P{Script=-	Samaritan}', "");
Expect(0, 2111, '\P{^Script=-	Samaritan}', "");
Error('\p{Sc=_:=samr}');
Error('\P{Sc=_:=samr}');
Expect(1, 2110, '\p{Sc=samr}', "");
Expect(0, 2110, '\p{^Sc=samr}', "");
Expect(0, 2110, '\P{Sc=samr}', "");
Expect(1, 2110, '\P{^Sc=samr}', "");
Expect(0, 2111, '\p{Sc=samr}', "");
Expect(1, 2111, '\p{^Sc=samr}', "");
Expect(1, 2111, '\P{Sc=samr}', "");
Expect(0, 2111, '\P{^Sc=samr}', "");
Expect(1, 2110, '\p{Sc=__SAMR}', "");
Expect(0, 2110, '\p{^Sc=__SAMR}', "");
Expect(0, 2110, '\P{Sc=__SAMR}', "");
Expect(1, 2110, '\P{^Sc=__SAMR}', "");
Expect(0, 2111, '\p{Sc=__SAMR}', "");
Expect(1, 2111, '\p{^Sc=__SAMR}', "");
Expect(1, 2111, '\P{Sc=__SAMR}', "");
Expect(0, 2111, '\P{^Sc=__SAMR}', "");
Error('\p{Is_Script=-/a/Samaritan}');
Error('\P{Is_Script=-/a/Samaritan}');
Expect(1, 2110, '\p{Is_Script:samaritan}', "");
Expect(0, 2110, '\p{^Is_Script:samaritan}', "");
Expect(0, 2110, '\P{Is_Script:samaritan}', "");
Expect(1, 2110, '\P{^Is_Script:samaritan}', "");
Expect(0, 2111, '\p{Is_Script:samaritan}', "");
Expect(1, 2111, '\p{^Is_Script:samaritan}', "");
Expect(1, 2111, '\P{Is_Script:samaritan}', "");
Expect(0, 2111, '\P{^Is_Script:samaritan}', "");
Error('\p{Is_Sc= Samr:=}');
Error('\P{Is_Sc= Samr:=}');
Expect(1, 2110, '\p{Is_Sc=samr}', "");
Expect(0, 2110, '\p{^Is_Sc=samr}', "");
Expect(0, 2110, '\P{Is_Sc=samr}', "");
Expect(1, 2110, '\P{^Is_Sc=samr}', "");
Expect(0, 2111, '\p{Is_Sc=samr}', "");
Expect(1, 2111, '\p{^Is_Sc=samr}', "");
Expect(1, 2111, '\P{Is_Sc=samr}', "");
Expect(0, 2111, '\P{^Is_Sc=samr}', "");
Expect(1, 2110, '\p{Is_Sc:--samr}', "");
Expect(0, 2110, '\p{^Is_Sc:--samr}', "");
Expect(0, 2110, '\P{Is_Sc:--samr}', "");
Expect(1, 2110, '\P{^Is_Sc:--samr}', "");
Expect(0, 2111, '\p{Is_Sc:--samr}', "");
Expect(1, 2111, '\p{^Is_Sc:--samr}', "");
Expect(1, 2111, '\P{Is_Sc:--samr}', "");
Expect(0, 2111, '\P{^Is_Sc:--samr}', "");
Error('\p{Script=- old_SOUTH_arabian:=}');
Error('\P{Script=- old_SOUTH_arabian:=}');
Expect(1, 68223, '\p{Script=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Script=oldsoutharabian}', "");
Expect(0, 68223, '\P{Script=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Script=oldsoutharabian}', "");
Expect(0, 68224, '\p{Script=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Script=oldsoutharabian}', "");
Expect(1, 68224, '\P{Script=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Script=oldsoutharabian}', "");
Expect(1, 68223, '\p{Script=_-Old_South_Arabian}', "");
Expect(0, 68223, '\p{^Script=_-Old_South_Arabian}', "");
Expect(0, 68223, '\P{Script=_-Old_South_Arabian}', "");
Expect(1, 68223, '\P{^Script=_-Old_South_Arabian}', "");
Expect(0, 68224, '\p{Script=_-Old_South_Arabian}', "");
Expect(1, 68224, '\p{^Script=_-Old_South_Arabian}', "");
Expect(1, 68224, '\P{Script=_-Old_South_Arabian}', "");
Expect(0, 68224, '\P{^Script=_-Old_South_Arabian}', "");
Error('\p{Sc=_/a/sarb}');
Error('\P{Sc=_/a/sarb}');
Expect(1, 68223, '\p{Sc=sarb}', "");
Expect(0, 68223, '\p{^Sc=sarb}', "");
Expect(0, 68223, '\P{Sc=sarb}', "");
Expect(1, 68223, '\P{^Sc=sarb}', "");
Expect(0, 68224, '\p{Sc=sarb}', "");
Expect(1, 68224, '\p{^Sc=sarb}', "");
Expect(1, 68224, '\P{Sc=sarb}', "");
Expect(0, 68224, '\P{^Sc=sarb}', "");
Expect(1, 68223, '\p{Sc=Sarb}', "");
Expect(0, 68223, '\p{^Sc=Sarb}', "");
Expect(0, 68223, '\P{Sc=Sarb}', "");
Expect(1, 68223, '\P{^Sc=Sarb}', "");
Expect(0, 68224, '\p{Sc=Sarb}', "");
Expect(1, 68224, '\p{^Sc=Sarb}', "");
Expect(1, 68224, '\P{Sc=Sarb}', "");
Expect(0, 68224, '\P{^Sc=Sarb}', "");
Error('\p{Is_Script=/a/ old_South_ARABIAN}');
Error('\P{Is_Script=/a/ old_South_ARABIAN}');
Expect(1, 68223, '\p{Is_Script=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Script=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Script=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Script=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Script=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Script=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Script=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Script=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Script=--OLD_South_Arabian}', "");
Expect(0, 68223, '\p{^Is_Script=--OLD_South_Arabian}', "");
Expect(0, 68223, '\P{Is_Script=--OLD_South_Arabian}', "");
Expect(1, 68223, '\P{^Is_Script=--OLD_South_Arabian}', "");
Expect(0, 68224, '\p{Is_Script=--OLD_South_Arabian}', "");
Expect(1, 68224, '\p{^Is_Script=--OLD_South_Arabian}', "");
Expect(1, 68224, '\P{Is_Script=--OLD_South_Arabian}', "");
Expect(0, 68224, '\P{^Is_Script=--OLD_South_Arabian}', "");
Error('\p{Is_Sc= /a/Sarb}');
Error('\P{Is_Sc= /a/Sarb}');
Expect(1, 68223, '\p{Is_Sc=sarb}', "");
Expect(0, 68223, '\p{^Is_Sc=sarb}', "");
Expect(0, 68223, '\P{Is_Sc=sarb}', "");
Expect(1, 68223, '\P{^Is_Sc=sarb}', "");
Expect(0, 68224, '\p{Is_Sc=sarb}', "");
Expect(1, 68224, '\p{^Is_Sc=sarb}', "");
Expect(1, 68224, '\P{Is_Sc=sarb}', "");
Expect(0, 68224, '\P{^Is_Sc=sarb}', "");
Expect(1, 68223, '\p{Is_Sc= -sarb}', "");
Expect(0, 68223, '\p{^Is_Sc= -sarb}', "");
Expect(0, 68223, '\P{Is_Sc= -sarb}', "");
Expect(1, 68223, '\P{^Is_Sc= -sarb}', "");
Expect(0, 68224, '\p{Is_Sc= -sarb}', "");
Expect(1, 68224, '\p{^Is_Sc= -sarb}', "");
Expect(1, 68224, '\P{Is_Sc= -sarb}', "");
Expect(0, 68224, '\P{^Is_Sc= -sarb}', "");
Error('\p{Script=:= -SAURASHTRA}');
Error('\P{Script=:= -SAURASHTRA}');
Expect(1, 43225, '\p{Script=saurashtra}', "");
Expect(0, 43225, '\p{^Script=saurashtra}', "");
Expect(0, 43225, '\P{Script=saurashtra}', "");
Expect(1, 43225, '\P{^Script=saurashtra}', "");
Expect(0, 43226, '\p{Script=saurashtra}', "");
Expect(1, 43226, '\p{^Script=saurashtra}', "");
Expect(1, 43226, '\P{Script=saurashtra}', "");
Expect(0, 43226, '\P{^Script=saurashtra}', "");
Expect(1, 43225, '\p{Script=__SAURASHTRA}', "");
Expect(0, 43225, '\p{^Script=__SAURASHTRA}', "");
Expect(0, 43225, '\P{Script=__SAURASHTRA}', "");
Expect(1, 43225, '\P{^Script=__SAURASHTRA}', "");
Expect(0, 43226, '\p{Script=__SAURASHTRA}', "");
Expect(1, 43226, '\p{^Script=__SAURASHTRA}', "");
Expect(1, 43226, '\P{Script=__SAURASHTRA}', "");
Expect(0, 43226, '\P{^Script=__SAURASHTRA}', "");
Error('\p{Sc= :=Saur}');
Error('\P{Sc= :=Saur}');
Expect(1, 43225, '\p{Sc=saur}', "");
Expect(0, 43225, '\p{^Sc=saur}', "");
Expect(0, 43225, '\P{Sc=saur}', "");
Expect(1, 43225, '\P{^Sc=saur}', "");
Expect(0, 43226, '\p{Sc=saur}', "");
Expect(1, 43226, '\p{^Sc=saur}', "");
Expect(1, 43226, '\P{Sc=saur}', "");
Expect(0, 43226, '\P{^Sc=saur}', "");
Expect(1, 43225, '\p{Sc=	SAUR}', "");
Expect(0, 43225, '\p{^Sc=	SAUR}', "");
Expect(0, 43225, '\P{Sc=	SAUR}', "");
Expect(1, 43225, '\P{^Sc=	SAUR}', "");
Expect(0, 43226, '\p{Sc=	SAUR}', "");
Expect(1, 43226, '\p{^Sc=	SAUR}', "");
Expect(1, 43226, '\P{Sc=	SAUR}', "");
Expect(0, 43226, '\P{^Sc=	SAUR}', "");
Error('\p{Is_Script=	_Saurashtra/a/}');
Error('\P{Is_Script=	_Saurashtra/a/}');
Expect(1, 43225, '\p{Is_Script=saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script=saurashtra}', "");
Expect(0, 43225, '\P{Is_Script=saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script=saurashtra}', "");
Expect(0, 43226, '\p{Is_Script=saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script=saurashtra}', "");
Expect(1, 43226, '\P{Is_Script=saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script=saurashtra}', "");
Expect(1, 43225, '\p{Is_Script=	-Saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script=	-Saurashtra}', "");
Expect(0, 43225, '\P{Is_Script=	-Saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script=	-Saurashtra}', "");
Expect(0, 43226, '\p{Is_Script=	-Saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script=	-Saurashtra}', "");
Expect(1, 43226, '\P{Is_Script=	-Saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script=	-Saurashtra}', "");
Error('\p{Is_Sc=/a/ 	Saur}');
Error('\P{Is_Sc=/a/ 	Saur}');
Expect(1, 43225, '\p{Is_Sc=saur}', "");
Expect(0, 43225, '\p{^Is_Sc=saur}', "");
Expect(0, 43225, '\P{Is_Sc=saur}', "");
Expect(1, 43225, '\P{^Is_Sc=saur}', "");
Expect(0, 43226, '\p{Is_Sc=saur}', "");
Expect(1, 43226, '\p{^Is_Sc=saur}', "");
Expect(1, 43226, '\P{Is_Sc=saur}', "");
Expect(0, 43226, '\P{^Is_Sc=saur}', "");
Expect(1, 43225, '\p{Is_Sc=	Saur}', "");
Expect(0, 43225, '\p{^Is_Sc=	Saur}', "");
Expect(0, 43225, '\P{Is_Sc=	Saur}', "");
Expect(1, 43225, '\P{^Is_Sc=	Saur}', "");
Expect(0, 43226, '\p{Is_Sc=	Saur}', "");
Expect(1, 43226, '\p{^Is_Sc=	Saur}', "");
Expect(1, 43226, '\P{Is_Sc=	Saur}', "");
Expect(0, 43226, '\P{^Is_Sc=	Saur}', "");
Error('\p{Script=	:=Shavian}');
Error('\P{Script=	:=Shavian}');
Expect(1, 66687, '\p{Script=shavian}', "");
Expect(0, 66687, '\p{^Script=shavian}', "");
Expect(0, 66687, '\P{Script=shavian}', "");
Expect(1, 66687, '\P{^Script=shavian}', "");
Expect(0, 66688, '\p{Script=shavian}', "");
Expect(1, 66688, '\p{^Script=shavian}', "");
Expect(1, 66688, '\P{Script=shavian}', "");
Expect(0, 66688, '\P{^Script=shavian}', "");
Expect(1, 66687, '\p{Script=--shavian}', "");
Expect(0, 66687, '\p{^Script=--shavian}', "");
Expect(0, 66687, '\P{Script=--shavian}', "");
Expect(1, 66687, '\P{^Script=--shavian}', "");
Expect(0, 66688, '\p{Script=--shavian}', "");
Expect(1, 66688, '\p{^Script=--shavian}', "");
Expect(1, 66688, '\P{Script=--shavian}', "");
Expect(0, 66688, '\P{^Script=--shavian}', "");
Error('\p{Sc=/a/_-shaw}');
Error('\P{Sc=/a/_-shaw}');
Expect(1, 66687, '\p{Sc:shaw}', "");
Expect(0, 66687, '\p{^Sc:shaw}', "");
Expect(0, 66687, '\P{Sc:shaw}', "");
Expect(1, 66687, '\P{^Sc:shaw}', "");
Expect(0, 66688, '\p{Sc:shaw}', "");
Expect(1, 66688, '\p{^Sc:shaw}', "");
Expect(1, 66688, '\P{Sc:shaw}', "");
Expect(0, 66688, '\P{^Sc:shaw}', "");
Expect(1, 66687, '\p{Sc:   - shaw}', "");
Expect(0, 66687, '\p{^Sc:   - shaw}', "");
Expect(0, 66687, '\P{Sc:   - shaw}', "");
Expect(1, 66687, '\P{^Sc:   - shaw}', "");
Expect(0, 66688, '\p{Sc:   - shaw}', "");
Expect(1, 66688, '\p{^Sc:   - shaw}', "");
Expect(1, 66688, '\P{Sc:   - shaw}', "");
Expect(0, 66688, '\P{^Sc:   - shaw}', "");
Error('\p{Is_Script=	/a/SHAVIAN}');
Error('\P{Is_Script=	/a/SHAVIAN}');
Expect(1, 66687, '\p{Is_Script=shavian}', "");
Expect(0, 66687, '\p{^Is_Script=shavian}', "");
Expect(0, 66687, '\P{Is_Script=shavian}', "");
Expect(1, 66687, '\P{^Is_Script=shavian}', "");
Expect(0, 66688, '\p{Is_Script=shavian}', "");
Expect(1, 66688, '\p{^Is_Script=shavian}', "");
Expect(1, 66688, '\P{Is_Script=shavian}', "");
Expect(0, 66688, '\P{^Is_Script=shavian}', "");
Expect(1, 66687, '\p{Is_Script=__Shavian}', "");
Expect(0, 66687, '\p{^Is_Script=__Shavian}', "");
Expect(0, 66687, '\P{Is_Script=__Shavian}', "");
Expect(1, 66687, '\P{^Is_Script=__Shavian}', "");
Expect(0, 66688, '\p{Is_Script=__Shavian}', "");
Expect(1, 66688, '\p{^Is_Script=__Shavian}', "");
Expect(1, 66688, '\P{Is_Script=__Shavian}', "");
Expect(0, 66688, '\P{^Is_Script=__Shavian}', "");
Error('\p{Is_Sc=	:=Shaw}');
Error('\P{Is_Sc=	:=Shaw}');
Expect(1, 66687, '\p{Is_Sc=shaw}', "");
Expect(0, 66687, '\p{^Is_Sc=shaw}', "");
Expect(0, 66687, '\P{Is_Sc=shaw}', "");
Expect(1, 66687, '\P{^Is_Sc=shaw}', "");
Expect(0, 66688, '\p{Is_Sc=shaw}', "");
Expect(1, 66688, '\p{^Is_Sc=shaw}', "");
Expect(1, 66688, '\P{Is_Sc=shaw}', "");
Expect(0, 66688, '\P{^Is_Sc=shaw}', "");
Expect(1, 66687, '\p{Is_Sc=__shaw}', "");
Expect(0, 66687, '\p{^Is_Sc=__shaw}', "");
Expect(0, 66687, '\P{Is_Sc=__shaw}', "");
Expect(1, 66687, '\P{^Is_Sc=__shaw}', "");
Expect(0, 66688, '\p{Is_Sc=__shaw}', "");
Expect(1, 66688, '\p{^Is_Sc=__shaw}', "");
Expect(1, 66688, '\P{Is_Sc=__shaw}', "");
Expect(0, 66688, '\P{^Is_Sc=__shaw}', "");
Error('\p{Script=:=Sharada}');
Error('\P{Script=:=Sharada}');
Expect(1, 70105, '\p{Script=sharada}', "");
Expect(0, 70105, '\p{^Script=sharada}', "");
Expect(0, 70105, '\P{Script=sharada}', "");
Expect(1, 70105, '\P{^Script=sharada}', "");
Expect(0, 70106, '\p{Script=sharada}', "");
Expect(1, 70106, '\p{^Script=sharada}', "");
Expect(1, 70106, '\P{Script=sharada}', "");
Expect(0, 70106, '\P{^Script=sharada}', "");
Expect(1, 70105, '\p{Script=_sharada}', "");
Expect(0, 70105, '\p{^Script=_sharada}', "");
Expect(0, 70105, '\P{Script=_sharada}', "");
Expect(1, 70105, '\P{^Script=_sharada}', "");
Expect(0, 70106, '\p{Script=_sharada}', "");
Expect(1, 70106, '\p{^Script=_sharada}', "");
Expect(1, 70106, '\P{Script=_sharada}', "");
Expect(0, 70106, '\P{^Script=_sharada}', "");
Error('\p{Sc=:=__shrd}');
Error('\P{Sc=:=__shrd}');
Expect(1, 70105, '\p{Sc: shrd}', "");
Expect(0, 70105, '\p{^Sc: shrd}', "");
Expect(0, 70105, '\P{Sc: shrd}', "");
Expect(1, 70105, '\P{^Sc: shrd}', "");
Expect(0, 70106, '\p{Sc: shrd}', "");
Expect(1, 70106, '\p{^Sc: shrd}', "");
Expect(1, 70106, '\P{Sc: shrd}', "");
Expect(0, 70106, '\P{^Sc: shrd}', "");
Expect(1, 70105, '\p{Sc=--Shrd}', "");
Expect(0, 70105, '\p{^Sc=--Shrd}', "");
Expect(0, 70105, '\P{Sc=--Shrd}', "");
Expect(1, 70105, '\P{^Sc=--Shrd}', "");
Expect(0, 70106, '\p{Sc=--Shrd}', "");
Expect(1, 70106, '\p{^Sc=--Shrd}', "");
Expect(1, 70106, '\P{Sc=--Shrd}', "");
Expect(0, 70106, '\P{^Sc=--Shrd}', "");
Error('\p{Is_Script=/a/ 	Sharada}');
Error('\P{Is_Script=/a/ 	Sharada}');
Expect(1, 70105, '\p{Is_Script=sharada}', "");
Expect(0, 70105, '\p{^Is_Script=sharada}', "");
Expect(0, 70105, '\P{Is_Script=sharada}', "");
Expect(1, 70105, '\P{^Is_Script=sharada}', "");
Expect(0, 70106, '\p{Is_Script=sharada}', "");
Expect(1, 70106, '\p{^Is_Script=sharada}', "");
Expect(1, 70106, '\P{Is_Script=sharada}', "");
Expect(0, 70106, '\P{^Is_Script=sharada}', "");
Expect(1, 70105, '\p{Is_Script=SHARADA}', "");
Expect(0, 70105, '\p{^Is_Script=SHARADA}', "");
Expect(0, 70105, '\P{Is_Script=SHARADA}', "");
Expect(1, 70105, '\P{^Is_Script=SHARADA}', "");
Expect(0, 70106, '\p{Is_Script=SHARADA}', "");
Expect(1, 70106, '\p{^Is_Script=SHARADA}', "");
Expect(1, 70106, '\P{Is_Script=SHARADA}', "");
Expect(0, 70106, '\P{^Is_Script=SHARADA}', "");
Error('\p{Is_Sc=_:=SHRD}');
Error('\P{Is_Sc=_:=SHRD}');
Expect(1, 70105, '\p{Is_Sc=shrd}', "");
Expect(0, 70105, '\p{^Is_Sc=shrd}', "");
Expect(0, 70105, '\P{Is_Sc=shrd}', "");
Expect(1, 70105, '\P{^Is_Sc=shrd}', "");
Expect(0, 70106, '\p{Is_Sc=shrd}', "");
Expect(1, 70106, '\p{^Is_Sc=shrd}', "");
Expect(1, 70106, '\P{Is_Sc=shrd}', "");
Expect(0, 70106, '\P{^Is_Sc=shrd}', "");
Expect(1, 70105, '\p{Is_Sc:   _	Shrd}', "");
Expect(0, 70105, '\p{^Is_Sc:   _	Shrd}', "");
Expect(0, 70105, '\P{Is_Sc:   _	Shrd}', "");
Expect(1, 70105, '\P{^Is_Sc:   _	Shrd}', "");
Expect(0, 70106, '\p{Is_Sc:   _	Shrd}', "");
Expect(1, 70106, '\p{^Is_Sc:   _	Shrd}', "");
Expect(1, 70106, '\P{Is_Sc:   _	Shrd}', "");
Expect(0, 70106, '\P{^Is_Sc:   _	Shrd}', "");
Error('\p{Script=:=_	Sinhala}');
Error('\P{Script=:=_	Sinhala}');
Expect(1, 3572, '\p{Script:	sinhala}', "");
Expect(0, 3572, '\p{^Script:	sinhala}', "");
Expect(0, 3572, '\P{Script:	sinhala}', "");
Expect(1, 3572, '\P{^Script:	sinhala}', "");
Expect(0, 3573, '\p{Script:	sinhala}', "");
Expect(1, 3573, '\p{^Script:	sinhala}', "");
Expect(1, 3573, '\P{Script:	sinhala}', "");
Expect(0, 3573, '\P{^Script:	sinhala}', "");
Expect(1, 3572, '\p{Script:   SINHALA}', "");
Expect(0, 3572, '\p{^Script:   SINHALA}', "");
Expect(0, 3572, '\P{Script:   SINHALA}', "");
Expect(1, 3572, '\P{^Script:   SINHALA}', "");
Expect(0, 3573, '\p{Script:   SINHALA}', "");
Expect(1, 3573, '\p{^Script:   SINHALA}', "");
Expect(1, 3573, '\P{Script:   SINHALA}', "");
Expect(0, 3573, '\P{^Script:   SINHALA}', "");
Error('\p{Sc=:=Sinh}');
Error('\P{Sc=:=Sinh}');
Expect(1, 3572, '\p{Sc=sinh}', "");
Expect(0, 3572, '\p{^Sc=sinh}', "");
Expect(0, 3572, '\P{Sc=sinh}', "");
Expect(1, 3572, '\P{^Sc=sinh}', "");
Expect(0, 3573, '\p{Sc=sinh}', "");
Expect(1, 3573, '\p{^Sc=sinh}', "");
Expect(1, 3573, '\P{Sc=sinh}', "");
Expect(0, 3573, '\P{^Sc=sinh}', "");
Expect(1, 3572, '\p{Sc=_SINH}', "");
Expect(0, 3572, '\p{^Sc=_SINH}', "");
Expect(0, 3572, '\P{Sc=_SINH}', "");
Expect(1, 3572, '\P{^Sc=_SINH}', "");
Expect(0, 3573, '\p{Sc=_SINH}', "");
Expect(1, 3573, '\p{^Sc=_SINH}', "");
Expect(1, 3573, '\P{Sc=_SINH}', "");
Expect(0, 3573, '\P{^Sc=_SINH}', "");
Error('\p{Is_Script=-/a/sinhala}');
Error('\P{Is_Script=-/a/sinhala}');
Expect(1, 3572, '\p{Is_Script=sinhala}', "");
Expect(0, 3572, '\p{^Is_Script=sinhala}', "");
Expect(0, 3572, '\P{Is_Script=sinhala}', "");
Expect(1, 3572, '\P{^Is_Script=sinhala}', "");
Expect(0, 3573, '\p{Is_Script=sinhala}', "");
Expect(1, 3573, '\p{^Is_Script=sinhala}', "");
Expect(1, 3573, '\P{Is_Script=sinhala}', "");
Expect(0, 3573, '\P{^Is_Script=sinhala}', "");
Expect(1, 3572, '\p{Is_Script=_sinhala}', "");
Expect(0, 3572, '\p{^Is_Script=_sinhala}', "");
Expect(0, 3572, '\P{Is_Script=_sinhala}', "");
Expect(1, 3572, '\P{^Is_Script=_sinhala}', "");
Expect(0, 3573, '\p{Is_Script=_sinhala}', "");
Expect(1, 3573, '\p{^Is_Script=_sinhala}', "");
Expect(1, 3573, '\P{Is_Script=_sinhala}', "");
Expect(0, 3573, '\P{^Is_Script=_sinhala}', "");
Error('\p{Is_Sc:-	SINH/a/}');
Error('\P{Is_Sc:-	SINH/a/}');
Expect(1, 3572, '\p{Is_Sc=sinh}', "");
Expect(0, 3572, '\p{^Is_Sc=sinh}', "");
Expect(0, 3572, '\P{Is_Sc=sinh}', "");
Expect(1, 3572, '\P{^Is_Sc=sinh}', "");
Expect(0, 3573, '\p{Is_Sc=sinh}', "");
Expect(1, 3573, '\p{^Is_Sc=sinh}', "");
Expect(1, 3573, '\P{Is_Sc=sinh}', "");
Expect(0, 3573, '\P{^Is_Sc=sinh}', "");
Expect(1, 3572, '\p{Is_Sc=--Sinh}', "");
Expect(0, 3572, '\p{^Is_Sc=--Sinh}', "");
Expect(0, 3572, '\P{Is_Sc=--Sinh}', "");
Expect(1, 3572, '\P{^Is_Sc=--Sinh}', "");
Expect(0, 3573, '\p{Is_Sc=--Sinh}', "");
Expect(1, 3573, '\p{^Is_Sc=--Sinh}', "");
Expect(1, 3573, '\P{Is_Sc=--Sinh}', "");
Expect(0, 3573, '\P{^Is_Sc=--Sinh}', "");
Error('\p{Script=/a/ 	sora_sompeng}');
Error('\P{Script=/a/ 	sora_sompeng}');
Expect(1, 69881, '\p{Script:   sorasompeng}', "");
Expect(0, 69881, '\p{^Script:   sorasompeng}', "");
Expect(0, 69881, '\P{Script:   sorasompeng}', "");
Expect(1, 69881, '\P{^Script:   sorasompeng}', "");
Expect(0, 69882, '\p{Script:   sorasompeng}', "");
Expect(1, 69882, '\p{^Script:   sorasompeng}', "");
Expect(1, 69882, '\P{Script:   sorasompeng}', "");
Expect(0, 69882, '\P{^Script:   sorasompeng}', "");
Expect(1, 69881, '\p{Script=	 Sora_sompeng}', "");
Expect(0, 69881, '\p{^Script=	 Sora_sompeng}', "");
Expect(0, 69881, '\P{Script=	 Sora_sompeng}', "");
Expect(1, 69881, '\P{^Script=	 Sora_sompeng}', "");
Expect(0, 69882, '\p{Script=	 Sora_sompeng}', "");
Expect(1, 69882, '\p{^Script=	 Sora_sompeng}', "");
Expect(1, 69882, '\P{Script=	 Sora_sompeng}', "");
Expect(0, 69882, '\P{^Script=	 Sora_sompeng}', "");
Error('\p{Sc=-Sora:=}');
Error('\P{Sc=-Sora:=}');
Expect(1, 69881, '\p{Sc=sora}', "");
Expect(0, 69881, '\p{^Sc=sora}', "");
Expect(0, 69881, '\P{Sc=sora}', "");
Expect(1, 69881, '\P{^Sc=sora}', "");
Expect(0, 69882, '\p{Sc=sora}', "");
Expect(1, 69882, '\p{^Sc=sora}', "");
Expect(1, 69882, '\P{Sc=sora}', "");
Expect(0, 69882, '\P{^Sc=sora}', "");
Expect(1, 69881, '\p{Sc= Sora}', "");
Expect(0, 69881, '\p{^Sc= Sora}', "");
Expect(0, 69881, '\P{Sc= Sora}', "");
Expect(1, 69881, '\P{^Sc= Sora}', "");
Expect(0, 69882, '\p{Sc= Sora}', "");
Expect(1, 69882, '\p{^Sc= Sora}', "");
Expect(1, 69882, '\P{Sc= Sora}', "");
Expect(0, 69882, '\P{^Sc= Sora}', "");
Error('\p{Is_Script=/a/_ Sora_sompeng}');
Error('\P{Is_Script=/a/_ Sora_sompeng}');
Expect(1, 69881, '\p{Is_Script=sorasompeng}', "");
Expect(0, 69881, '\p{^Is_Script=sorasompeng}', "");
Expect(0, 69881, '\P{Is_Script=sorasompeng}', "");
Expect(1, 69881, '\P{^Is_Script=sorasompeng}', "");
Expect(0, 69882, '\p{Is_Script=sorasompeng}', "");
Expect(1, 69882, '\p{^Is_Script=sorasompeng}', "");
Expect(1, 69882, '\P{Is_Script=sorasompeng}', "");
Expect(0, 69882, '\P{^Is_Script=sorasompeng}', "");
Expect(1, 69881, '\p{Is_Script=-Sora_Sompeng}', "");
Expect(0, 69881, '\p{^Is_Script=-Sora_Sompeng}', "");
Expect(0, 69881, '\P{Is_Script=-Sora_Sompeng}', "");
Expect(1, 69881, '\P{^Is_Script=-Sora_Sompeng}', "");
Expect(0, 69882, '\p{Is_Script=-Sora_Sompeng}', "");
Expect(1, 69882, '\p{^Is_Script=-Sora_Sompeng}', "");
Expect(1, 69882, '\P{Is_Script=-Sora_Sompeng}', "");
Expect(0, 69882, '\P{^Is_Script=-Sora_Sompeng}', "");
Error('\p{Is_Sc=:=		sora}');
Error('\P{Is_Sc=:=		sora}');
Expect(1, 69881, '\p{Is_Sc=sora}', "");
Expect(0, 69881, '\p{^Is_Sc=sora}', "");
Expect(0, 69881, '\P{Is_Sc=sora}', "");
Expect(1, 69881, '\P{^Is_Sc=sora}', "");
Expect(0, 69882, '\p{Is_Sc=sora}', "");
Expect(1, 69882, '\p{^Is_Sc=sora}', "");
Expect(1, 69882, '\P{Is_Sc=sora}', "");
Expect(0, 69882, '\P{^Is_Sc=sora}', "");
Expect(1, 69881, '\p{Is_Sc=-Sora}', "");
Expect(0, 69881, '\p{^Is_Sc=-Sora}', "");
Expect(0, 69881, '\P{Is_Sc=-Sora}', "");
Expect(1, 69881, '\P{^Is_Sc=-Sora}', "");
Expect(0, 69882, '\p{Is_Sc=-Sora}', "");
Expect(1, 69882, '\p{^Is_Sc=-Sora}', "");
Expect(1, 69882, '\P{Is_Sc=-Sora}', "");
Expect(0, 69882, '\P{^Is_Sc=-Sora}', "");
Error('\p{Script=:=_	Sundanese}');
Error('\P{Script=:=_	Sundanese}');
Expect(1, 7367, '\p{Script=sundanese}', "");
Expect(0, 7367, '\p{^Script=sundanese}', "");
Expect(0, 7367, '\P{Script=sundanese}', "");
Expect(1, 7367, '\P{^Script=sundanese}', "");
Expect(0, 7368, '\p{Script=sundanese}', "");
Expect(1, 7368, '\p{^Script=sundanese}', "");
Expect(1, 7368, '\P{Script=sundanese}', "");
Expect(0, 7368, '\P{^Script=sundanese}', "");
Expect(1, 7367, '\p{Script= Sundanese}', "");
Expect(0, 7367, '\p{^Script= Sundanese}', "");
Expect(0, 7367, '\P{Script= Sundanese}', "");
Expect(1, 7367, '\P{^Script= Sundanese}', "");
Expect(0, 7368, '\p{Script= Sundanese}', "");
Expect(1, 7368, '\p{^Script= Sundanese}', "");
Expect(1, 7368, '\P{Script= Sundanese}', "");
Expect(0, 7368, '\P{^Script= Sundanese}', "");
Error('\p{Sc=/a/		SUND}');
Error('\P{Sc=/a/		SUND}');
Expect(1, 7367, '\p{Sc=sund}', "");
Expect(0, 7367, '\p{^Sc=sund}', "");
Expect(0, 7367, '\P{Sc=sund}', "");
Expect(1, 7367, '\P{^Sc=sund}', "");
Expect(0, 7368, '\p{Sc=sund}', "");
Expect(1, 7368, '\p{^Sc=sund}', "");
Expect(1, 7368, '\P{Sc=sund}', "");
Expect(0, 7368, '\P{^Sc=sund}', "");
Expect(1, 7367, '\p{Sc:	  Sund}', "");
Expect(0, 7367, '\p{^Sc:	  Sund}', "");
Expect(0, 7367, '\P{Sc:	  Sund}', "");
Expect(1, 7367, '\P{^Sc:	  Sund}', "");
Expect(0, 7368, '\p{Sc:	  Sund}', "");
Expect(1, 7368, '\p{^Sc:	  Sund}', "");
Expect(1, 7368, '\P{Sc:	  Sund}', "");
Expect(0, 7368, '\P{^Sc:	  Sund}', "");
Error('\p{Is_Script:	/a/  SUNDANESE}');
Error('\P{Is_Script:	/a/  SUNDANESE}');
Expect(1, 7367, '\p{Is_Script=sundanese}', "");
Expect(0, 7367, '\p{^Is_Script=sundanese}', "");
Expect(0, 7367, '\P{Is_Script=sundanese}', "");
Expect(1, 7367, '\P{^Is_Script=sundanese}', "");
Expect(0, 7368, '\p{Is_Script=sundanese}', "");
Expect(1, 7368, '\p{^Is_Script=sundanese}', "");
Expect(1, 7368, '\P{Is_Script=sundanese}', "");
Expect(0, 7368, '\P{^Is_Script=sundanese}', "");
Expect(1, 7367, '\p{Is_Script=-SUNDANESE}', "");
Expect(0, 7367, '\p{^Is_Script=-SUNDANESE}', "");
Expect(0, 7367, '\P{Is_Script=-SUNDANESE}', "");
Expect(1, 7367, '\P{^Is_Script=-SUNDANESE}', "");
Expect(0, 7368, '\p{Is_Script=-SUNDANESE}', "");
Expect(1, 7368, '\p{^Is_Script=-SUNDANESE}', "");
Expect(1, 7368, '\P{Is_Script=-SUNDANESE}', "");
Expect(0, 7368, '\P{^Is_Script=-SUNDANESE}', "");
Error('\p{Is_Sc= :=sund}');
Error('\P{Is_Sc= :=sund}');
Expect(1, 7367, '\p{Is_Sc=sund}', "");
Expect(0, 7367, '\p{^Is_Sc=sund}', "");
Expect(0, 7367, '\P{Is_Sc=sund}', "");
Expect(1, 7367, '\P{^Is_Sc=sund}', "");
Expect(0, 7368, '\p{Is_Sc=sund}', "");
Expect(1, 7368, '\p{^Is_Sc=sund}', "");
Expect(1, 7368, '\P{Is_Sc=sund}', "");
Expect(0, 7368, '\P{^Is_Sc=sund}', "");
Expect(1, 7367, '\p{Is_Sc= _Sund}', "");
Expect(0, 7367, '\p{^Is_Sc= _Sund}', "");
Expect(0, 7367, '\P{Is_Sc= _Sund}', "");
Expect(1, 7367, '\P{^Is_Sc= _Sund}', "");
Expect(0, 7368, '\p{Is_Sc= _Sund}', "");
Expect(1, 7368, '\p{^Is_Sc= _Sund}', "");
Expect(1, 7368, '\P{Is_Sc= _Sund}', "");
Expect(0, 7368, '\P{^Is_Sc= _Sund}', "");
Error('\p{Script=/a/- SYLOTI_Nagri}');
Error('\P{Script=/a/- SYLOTI_Nagri}');
Expect(1, 43051, '\p{Script=sylotinagri}', "");
Expect(0, 43051, '\p{^Script=sylotinagri}', "");
Expect(0, 43051, '\P{Script=sylotinagri}', "");
Expect(1, 43051, '\P{^Script=sylotinagri}', "");
Expect(0, 43052, '\p{Script=sylotinagri}', "");
Expect(1, 43052, '\p{^Script=sylotinagri}', "");
Expect(1, 43052, '\P{Script=sylotinagri}', "");
Expect(0, 43052, '\P{^Script=sylotinagri}', "");
Expect(1, 43051, '\p{Script=-	Syloti_NAGRI}', "");
Expect(0, 43051, '\p{^Script=-	Syloti_NAGRI}', "");
Expect(0, 43051, '\P{Script=-	Syloti_NAGRI}', "");
Expect(1, 43051, '\P{^Script=-	Syloti_NAGRI}', "");
Expect(0, 43052, '\p{Script=-	Syloti_NAGRI}', "");
Expect(1, 43052, '\p{^Script=-	Syloti_NAGRI}', "");
Expect(1, 43052, '\P{Script=-	Syloti_NAGRI}', "");
Expect(0, 43052, '\P{^Script=-	Syloti_NAGRI}', "");
Error('\p{Sc=/a/  Sylo}');
Error('\P{Sc=/a/  Sylo}');
Expect(1, 43051, '\p{Sc=sylo}', "");
Expect(0, 43051, '\p{^Sc=sylo}', "");
Expect(0, 43051, '\P{Sc=sylo}', "");
Expect(1, 43051, '\P{^Sc=sylo}', "");
Expect(0, 43052, '\p{Sc=sylo}', "");
Expect(1, 43052, '\p{^Sc=sylo}', "");
Expect(1, 43052, '\P{Sc=sylo}', "");
Expect(0, 43052, '\P{^Sc=sylo}', "");
Expect(1, 43051, '\p{Sc=  Sylo}', "");
Expect(0, 43051, '\p{^Sc=  Sylo}', "");
Expect(0, 43051, '\P{Sc=  Sylo}', "");
Expect(1, 43051, '\P{^Sc=  Sylo}', "");
Expect(0, 43052, '\p{Sc=  Sylo}', "");
Expect(1, 43052, '\p{^Sc=  Sylo}', "");
Expect(1, 43052, '\P{Sc=  Sylo}', "");
Expect(0, 43052, '\P{^Sc=  Sylo}', "");
Error('\p{Is_Script=/a/  Syloti_NAGRI}');
Error('\P{Is_Script=/a/  Syloti_NAGRI}');
Expect(1, 43051, '\p{Is_Script: sylotinagri}', "");
Expect(0, 43051, '\p{^Is_Script: sylotinagri}', "");
Expect(0, 43051, '\P{Is_Script: sylotinagri}', "");
Expect(1, 43051, '\P{^Is_Script: sylotinagri}', "");
Expect(0, 43052, '\p{Is_Script: sylotinagri}', "");
Expect(1, 43052, '\p{^Is_Script: sylotinagri}', "");
Expect(1, 43052, '\P{Is_Script: sylotinagri}', "");
Expect(0, 43052, '\P{^Is_Script: sylotinagri}', "");
Expect(1, 43051, '\p{Is_Script=		Syloti_NAGRI}', "");
Expect(0, 43051, '\p{^Is_Script=		Syloti_NAGRI}', "");
Expect(0, 43051, '\P{Is_Script=		Syloti_NAGRI}', "");
Expect(1, 43051, '\P{^Is_Script=		Syloti_NAGRI}', "");
Expect(0, 43052, '\p{Is_Script=		Syloti_NAGRI}', "");
Expect(1, 43052, '\p{^Is_Script=		Syloti_NAGRI}', "");
Expect(1, 43052, '\P{Is_Script=		Syloti_NAGRI}', "");
Expect(0, 43052, '\P{^Is_Script=		Syloti_NAGRI}', "");
Error('\p{Is_Sc=-/a/Sylo}');
Error('\P{Is_Sc=-/a/Sylo}');
Expect(1, 43051, '\p{Is_Sc=sylo}', "");
Expect(0, 43051, '\p{^Is_Sc=sylo}', "");
Expect(0, 43051, '\P{Is_Sc=sylo}', "");
Expect(1, 43051, '\P{^Is_Sc=sylo}', "");
Expect(0, 43052, '\p{Is_Sc=sylo}', "");
Expect(1, 43052, '\p{^Is_Sc=sylo}', "");
Expect(1, 43052, '\P{Is_Sc=sylo}', "");
Expect(0, 43052, '\P{^Is_Sc=sylo}', "");
Expect(1, 43051, '\p{Is_Sc: -Sylo}', "");
Expect(0, 43051, '\p{^Is_Sc: -Sylo}', "");
Expect(0, 43051, '\P{Is_Sc: -Sylo}', "");
Expect(1, 43051, '\P{^Is_Sc: -Sylo}', "");
Expect(0, 43052, '\p{Is_Sc: -Sylo}', "");
Expect(1, 43052, '\p{^Is_Sc: -Sylo}', "");
Expect(1, 43052, '\P{Is_Sc: -Sylo}', "");
Expect(0, 43052, '\P{^Is_Sc: -Sylo}', "");
Error('\p{Script=/a/	Syriac}');
Error('\P{Script=/a/	Syriac}');
Expect(1, 1871, '\p{Script=syriac}', "");
Expect(0, 1871, '\p{^Script=syriac}', "");
Expect(0, 1871, '\P{Script=syriac}', "");
Expect(1, 1871, '\P{^Script=syriac}', "");
Expect(0, 1872, '\p{Script=syriac}', "");
Expect(1, 1872, '\p{^Script=syriac}', "");
Expect(1, 1872, '\P{Script=syriac}', "");
Expect(0, 1872, '\P{^Script=syriac}', "");
Expect(1, 1871, '\p{Script=-_syriac}', "");
Expect(0, 1871, '\p{^Script=-_syriac}', "");
Expect(0, 1871, '\P{Script=-_syriac}', "");
Expect(1, 1871, '\P{^Script=-_syriac}', "");
Expect(0, 1872, '\p{Script=-_syriac}', "");
Expect(1, 1872, '\p{^Script=-_syriac}', "");
Expect(1, 1872, '\P{Script=-_syriac}', "");
Expect(0, 1872, '\P{^Script=-_syriac}', "");
Error('\p{Sc=/a/-syrc}');
Error('\P{Sc=/a/-syrc}');
Expect(1, 1871, '\p{Sc=syrc}', "");
Expect(0, 1871, '\p{^Sc=syrc}', "");
Expect(0, 1871, '\P{Sc=syrc}', "");
Expect(1, 1871, '\P{^Sc=syrc}', "");
Expect(0, 1872, '\p{Sc=syrc}', "");
Expect(1, 1872, '\p{^Sc=syrc}', "");
Expect(1, 1872, '\P{Sc=syrc}', "");
Expect(0, 1872, '\P{^Sc=syrc}', "");
Expect(1, 1871, '\p{Sc=	-Syrc}', "");
Expect(0, 1871, '\p{^Sc=	-Syrc}', "");
Expect(0, 1871, '\P{Sc=	-Syrc}', "");
Expect(1, 1871, '\P{^Sc=	-Syrc}', "");
Expect(0, 1872, '\p{Sc=	-Syrc}', "");
Expect(1, 1872, '\p{^Sc=	-Syrc}', "");
Expect(1, 1872, '\P{Sc=	-Syrc}', "");
Expect(0, 1872, '\P{^Sc=	-Syrc}', "");
Error('\p{Is_Script=:= SYRIAC}');
Error('\P{Is_Script=:= SYRIAC}');
Expect(1, 1871, '\p{Is_Script=syriac}', "");
Expect(0, 1871, '\p{^Is_Script=syriac}', "");
Expect(0, 1871, '\P{Is_Script=syriac}', "");
Expect(1, 1871, '\P{^Is_Script=syriac}', "");
Expect(0, 1872, '\p{Is_Script=syriac}', "");
Expect(1, 1872, '\p{^Is_Script=syriac}', "");
Expect(1, 1872, '\P{Is_Script=syriac}', "");
Expect(0, 1872, '\P{^Is_Script=syriac}', "");
Expect(1, 1871, '\p{Is_Script=	SYRIAC}', "");
Expect(0, 1871, '\p{^Is_Script=	SYRIAC}', "");
Expect(0, 1871, '\P{Is_Script=	SYRIAC}', "");
Expect(1, 1871, '\P{^Is_Script=	SYRIAC}', "");
Expect(0, 1872, '\p{Is_Script=	SYRIAC}', "");
Expect(1, 1872, '\p{^Is_Script=	SYRIAC}', "");
Expect(1, 1872, '\P{Is_Script=	SYRIAC}', "");
Expect(0, 1872, '\P{^Is_Script=	SYRIAC}', "");
Error('\p{Is_Sc=:=SYRC}');
Error('\P{Is_Sc=:=SYRC}');
Expect(1, 1871, '\p{Is_Sc=syrc}', "");
Expect(0, 1871, '\p{^Is_Sc=syrc}', "");
Expect(0, 1871, '\P{Is_Sc=syrc}', "");
Expect(1, 1871, '\P{^Is_Sc=syrc}', "");
Expect(0, 1872, '\p{Is_Sc=syrc}', "");
Expect(1, 1872, '\p{^Is_Sc=syrc}', "");
Expect(1, 1872, '\P{Is_Sc=syrc}', "");
Expect(0, 1872, '\P{^Is_Sc=syrc}', "");
Error('\p{Script=/a/TAGBANWA}');
Error('\P{Script=/a/TAGBANWA}');
Expect(1, 6003, '\p{Script: tagbanwa}', "");
Expect(0, 6003, '\p{^Script: tagbanwa}', "");
Expect(0, 6003, '\P{Script: tagbanwa}', "");
Expect(1, 6003, '\P{^Script: tagbanwa}', "");
Expect(0, 6004, '\p{Script: tagbanwa}', "");
Expect(1, 6004, '\p{^Script: tagbanwa}', "");
Expect(1, 6004, '\P{Script: tagbanwa}', "");
Expect(0, 6004, '\P{^Script: tagbanwa}', "");
Expect(1, 6003, '\p{Script=	 tagbanwa}', "");
Expect(0, 6003, '\p{^Script=	 tagbanwa}', "");
Expect(0, 6003, '\P{Script=	 tagbanwa}', "");
Expect(1, 6003, '\P{^Script=	 tagbanwa}', "");
Expect(0, 6004, '\p{Script=	 tagbanwa}', "");
Expect(1, 6004, '\p{^Script=	 tagbanwa}', "");
Expect(1, 6004, '\P{Script=	 tagbanwa}', "");
Expect(0, 6004, '\P{^Script=	 tagbanwa}', "");
Error('\p{Sc=	tagb/a/}');
Error('\P{Sc=	tagb/a/}');
Expect(1, 6003, '\p{Sc=tagb}', "");
Expect(0, 6003, '\p{^Sc=tagb}', "");
Expect(0, 6003, '\P{Sc=tagb}', "");
Expect(1, 6003, '\P{^Sc=tagb}', "");
Expect(0, 6004, '\p{Sc=tagb}', "");
Expect(1, 6004, '\p{^Sc=tagb}', "");
Expect(1, 6004, '\P{Sc=tagb}', "");
Expect(0, 6004, '\P{^Sc=tagb}', "");
Expect(1, 6003, '\p{Sc= tagb}', "");
Expect(0, 6003, '\p{^Sc= tagb}', "");
Expect(0, 6003, '\P{Sc= tagb}', "");
Expect(1, 6003, '\P{^Sc= tagb}', "");
Expect(0, 6004, '\p{Sc= tagb}', "");
Expect(1, 6004, '\p{^Sc= tagb}', "");
Expect(1, 6004, '\P{Sc= tagb}', "");
Expect(0, 6004, '\P{^Sc= tagb}', "");
Error('\p{Is_Script=:=	Tagbanwa}');
Error('\P{Is_Script=:=	Tagbanwa}');
Expect(1, 6003, '\p{Is_Script:	tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script:	tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script:	tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script:	tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script:	tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script:	tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script:	tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script:	tagbanwa}', "");
Expect(1, 6003, '\p{Is_Script=	-Tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script=	-Tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script=	-Tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script=	-Tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script=	-Tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script=	-Tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script=	-Tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script=	-Tagbanwa}', "");
Error('\p{Is_Sc=_	TAGB:=}');
Error('\P{Is_Sc=_	TAGB:=}');
Expect(1, 6003, '\p{Is_Sc=tagb}', "");
Expect(0, 6003, '\p{^Is_Sc=tagb}', "");
Expect(0, 6003, '\P{Is_Sc=tagb}', "");
Expect(1, 6003, '\P{^Is_Sc=tagb}', "");
Expect(0, 6004, '\p{Is_Sc=tagb}', "");
Expect(1, 6004, '\p{^Is_Sc=tagb}', "");
Expect(1, 6004, '\P{Is_Sc=tagb}', "");
Expect(0, 6004, '\P{^Is_Sc=tagb}', "");
Expect(1, 6003, '\p{Is_Sc=- Tagb}', "");
Expect(0, 6003, '\p{^Is_Sc=- Tagb}', "");
Expect(0, 6003, '\P{Is_Sc=- Tagb}', "");
Expect(1, 6003, '\P{^Is_Sc=- Tagb}', "");
Expect(0, 6004, '\p{Is_Sc=- Tagb}', "");
Expect(1, 6004, '\p{^Is_Sc=- Tagb}', "");
Expect(1, 6004, '\P{Is_Sc=- Tagb}', "");
Expect(0, 6004, '\P{^Is_Sc=- Tagb}', "");
Error('\p{Script=:=Takri}');
Error('\P{Script=:=Takri}');
Expect(1, 71369, '\p{Script=takri}', "");
Expect(0, 71369, '\p{^Script=takri}', "");
Expect(0, 71369, '\P{Script=takri}', "");
Expect(1, 71369, '\P{^Script=takri}', "");
Expect(0, 71370, '\p{Script=takri}', "");
Expect(1, 71370, '\p{^Script=takri}', "");
Expect(1, 71370, '\P{Script=takri}', "");
Expect(0, 71370, '\P{^Script=takri}', "");
Expect(1, 71369, '\p{Script=	_Takri}', "");
Expect(0, 71369, '\p{^Script=	_Takri}', "");
Expect(0, 71369, '\P{Script=	_Takri}', "");
Expect(1, 71369, '\P{^Script=	_Takri}', "");
Expect(0, 71370, '\p{Script=	_Takri}', "");
Expect(1, 71370, '\p{^Script=	_Takri}', "");
Expect(1, 71370, '\P{Script=	_Takri}', "");
Expect(0, 71370, '\P{^Script=	_Takri}', "");
Error('\p{Sc=/a/	-TAKR}');
Error('\P{Sc=/a/	-TAKR}');
Expect(1, 71369, '\p{Sc=takr}', "");
Expect(0, 71369, '\p{^Sc=takr}', "");
Expect(0, 71369, '\P{Sc=takr}', "");
Expect(1, 71369, '\P{^Sc=takr}', "");
Expect(0, 71370, '\p{Sc=takr}', "");
Expect(1, 71370, '\p{^Sc=takr}', "");
Expect(1, 71370, '\P{Sc=takr}', "");
Expect(0, 71370, '\P{^Sc=takr}', "");
Error('\p{Is_Script=:=Takri}');
Error('\P{Is_Script=:=Takri}');
Expect(1, 71369, '\p{Is_Script=takri}', "");
Expect(0, 71369, '\p{^Is_Script=takri}', "");
Expect(0, 71369, '\P{Is_Script=takri}', "");
Expect(1, 71369, '\P{^Is_Script=takri}', "");
Expect(0, 71370, '\p{Is_Script=takri}', "");
Expect(1, 71370, '\p{^Is_Script=takri}', "");
Expect(1, 71370, '\P{Is_Script=takri}', "");
Expect(0, 71370, '\P{^Is_Script=takri}', "");
Expect(1, 71369, '\p{Is_Script= Takri}', "");
Expect(0, 71369, '\p{^Is_Script= Takri}', "");
Expect(0, 71369, '\P{Is_Script= Takri}', "");
Expect(1, 71369, '\P{^Is_Script= Takri}', "");
Expect(0, 71370, '\p{Is_Script= Takri}', "");
Expect(1, 71370, '\p{^Is_Script= Takri}', "");
Expect(1, 71370, '\P{Is_Script= Takri}', "");
Expect(0, 71370, '\P{^Is_Script= Takri}', "");
Error('\p{Is_Sc=	/a/takr}');
Error('\P{Is_Sc=	/a/takr}');
Expect(1, 71369, '\p{Is_Sc=takr}', "");
Expect(0, 71369, '\p{^Is_Sc=takr}', "");
Expect(0, 71369, '\P{Is_Sc=takr}', "");
Expect(1, 71369, '\P{^Is_Sc=takr}', "");
Expect(0, 71370, '\p{Is_Sc=takr}', "");
Expect(1, 71370, '\p{^Is_Sc=takr}', "");
Expect(1, 71370, '\P{Is_Sc=takr}', "");
Expect(0, 71370, '\P{^Is_Sc=takr}', "");
Expect(1, 71369, '\p{Is_Sc=_-TAKR}', "");
Expect(0, 71369, '\p{^Is_Sc=_-TAKR}', "");
Expect(0, 71369, '\P{Is_Sc=_-TAKR}', "");
Expect(1, 71369, '\P{^Is_Sc=_-TAKR}', "");
Expect(0, 71370, '\p{Is_Sc=_-TAKR}', "");
Expect(1, 71370, '\p{^Is_Sc=_-TAKR}', "");
Expect(1, 71370, '\P{Is_Sc=_-TAKR}', "");
Expect(0, 71370, '\P{^Is_Sc=_-TAKR}', "");
Error('\p{Script: /a/Tai_Le}');
Error('\P{Script: /a/Tai_Le}');
Expect(1, 6516, '\p{Script=taile}', "");
Expect(0, 6516, '\p{^Script=taile}', "");
Expect(0, 6516, '\P{Script=taile}', "");
Expect(1, 6516, '\P{^Script=taile}', "");
Expect(0, 6517, '\p{Script=taile}', "");
Expect(1, 6517, '\p{^Script=taile}', "");
Expect(1, 6517, '\P{Script=taile}', "");
Expect(0, 6517, '\P{^Script=taile}', "");
Expect(1, 6516, '\p{Script=	_Tai_Le}', "");
Expect(0, 6516, '\p{^Script=	_Tai_Le}', "");
Expect(0, 6516, '\P{Script=	_Tai_Le}', "");
Expect(1, 6516, '\P{^Script=	_Tai_Le}', "");
Expect(0, 6517, '\p{Script=	_Tai_Le}', "");
Expect(1, 6517, '\p{^Script=	_Tai_Le}', "");
Expect(1, 6517, '\P{Script=	_Tai_Le}', "");
Expect(0, 6517, '\P{^Script=	_Tai_Le}', "");
Error('\p{Sc=	Tale:=}');
Error('\P{Sc=	Tale:=}');
Expect(1, 6516, '\p{Sc=tale}', "");
Expect(0, 6516, '\p{^Sc=tale}', "");
Expect(0, 6516, '\P{Sc=tale}', "");
Expect(1, 6516, '\P{^Sc=tale}', "");
Expect(0, 6517, '\p{Sc=tale}', "");
Expect(1, 6517, '\p{^Sc=tale}', "");
Expect(1, 6517, '\P{Sc=tale}', "");
Expect(0, 6517, '\P{^Sc=tale}', "");
Expect(1, 6516, '\p{Sc:		Tale}', "");
Expect(0, 6516, '\p{^Sc:		Tale}', "");
Expect(0, 6516, '\P{Sc:		Tale}', "");
Expect(1, 6516, '\P{^Sc:		Tale}', "");
Expect(0, 6517, '\p{Sc:		Tale}', "");
Expect(1, 6517, '\p{^Sc:		Tale}', "");
Expect(1, 6517, '\P{Sc:		Tale}', "");
Expect(0, 6517, '\P{^Sc:		Tale}', "");
Error('\p{Is_Script=	 tai_Le/a/}');
Error('\P{Is_Script=	 tai_Le/a/}');
Expect(1, 6516, '\p{Is_Script=taile}', "");
Expect(0, 6516, '\p{^Is_Script=taile}', "");
Expect(0, 6516, '\P{Is_Script=taile}', "");
Expect(1, 6516, '\P{^Is_Script=taile}', "");
Expect(0, 6517, '\p{Is_Script=taile}', "");
Expect(1, 6517, '\p{^Is_Script=taile}', "");
Expect(1, 6517, '\P{Is_Script=taile}', "");
Expect(0, 6517, '\P{^Is_Script=taile}', "");
Expect(1, 6516, '\p{Is_Script=--Tai_LE}', "");
Expect(0, 6516, '\p{^Is_Script=--Tai_LE}', "");
Expect(0, 6516, '\P{Is_Script=--Tai_LE}', "");
Expect(1, 6516, '\P{^Is_Script=--Tai_LE}', "");
Expect(0, 6517, '\p{Is_Script=--Tai_LE}', "");
Expect(1, 6517, '\p{^Is_Script=--Tai_LE}', "");
Expect(1, 6517, '\P{Is_Script=--Tai_LE}', "");
Expect(0, 6517, '\P{^Is_Script=--Tai_LE}', "");
Error('\p{Is_Sc=/a/_	Tale}');
Error('\P{Is_Sc=/a/_	Tale}');
Expect(1, 6516, '\p{Is_Sc=tale}', "");
Expect(0, 6516, '\p{^Is_Sc=tale}', "");
Expect(0, 6516, '\P{Is_Sc=tale}', "");
Expect(1, 6516, '\P{^Is_Sc=tale}', "");
Expect(0, 6517, '\p{Is_Sc=tale}', "");
Expect(1, 6517, '\p{^Is_Sc=tale}', "");
Expect(1, 6517, '\P{Is_Sc=tale}', "");
Expect(0, 6517, '\P{^Is_Sc=tale}', "");
Expect(1, 6516, '\p{Is_Sc=__Tale}', "");
Expect(0, 6516, '\p{^Is_Sc=__Tale}', "");
Expect(0, 6516, '\P{Is_Sc=__Tale}', "");
Expect(1, 6516, '\P{^Is_Sc=__Tale}', "");
Expect(0, 6517, '\p{Is_Sc=__Tale}', "");
Expect(1, 6517, '\p{^Is_Sc=__Tale}', "");
Expect(1, 6517, '\P{Is_Sc=__Tale}', "");
Expect(0, 6517, '\P{^Is_Sc=__Tale}', "");
Error('\p{Script=:=NEW_Tai_lue}');
Error('\P{Script=:=NEW_Tai_lue}');
Expect(1, 6623, '\p{Script=newtailue}', "");
Expect(0, 6623, '\p{^Script=newtailue}', "");
Expect(0, 6623, '\P{Script=newtailue}', "");
Expect(1, 6623, '\P{^Script=newtailue}', "");
Expect(0, 6624, '\p{Script=newtailue}', "");
Expect(1, 6624, '\p{^Script=newtailue}', "");
Expect(1, 6624, '\P{Script=newtailue}', "");
Expect(0, 6624, '\P{^Script=newtailue}', "");
Expect(1, 6623, '\p{Script= new_Tai_Lue}', "");
Expect(0, 6623, '\p{^Script= new_Tai_Lue}', "");
Expect(0, 6623, '\P{Script= new_Tai_Lue}', "");
Expect(1, 6623, '\P{^Script= new_Tai_Lue}', "");
Expect(0, 6624, '\p{Script= new_Tai_Lue}', "");
Expect(1, 6624, '\p{^Script= new_Tai_Lue}', "");
Expect(1, 6624, '\P{Script= new_Tai_Lue}', "");
Expect(0, 6624, '\P{^Script= new_Tai_Lue}', "");
Error('\p{Sc=-/a/TALU}');
Error('\P{Sc=-/a/TALU}');
Expect(1, 6623, '\p{Sc=talu}', "");
Expect(0, 6623, '\p{^Sc=talu}', "");
Expect(0, 6623, '\P{Sc=talu}', "");
Expect(1, 6623, '\P{^Sc=talu}', "");
Expect(0, 6624, '\p{Sc=talu}', "");
Expect(1, 6624, '\p{^Sc=talu}', "");
Expect(1, 6624, '\P{Sc=talu}', "");
Expect(0, 6624, '\P{^Sc=talu}', "");
Expect(1, 6623, '\p{Sc=_talu}', "");
Expect(0, 6623, '\p{^Sc=_talu}', "");
Expect(0, 6623, '\P{Sc=_talu}', "");
Expect(1, 6623, '\P{^Sc=_talu}', "");
Expect(0, 6624, '\p{Sc=_talu}', "");
Expect(1, 6624, '\p{^Sc=_talu}', "");
Expect(1, 6624, '\P{Sc=_talu}', "");
Expect(0, 6624, '\P{^Sc=_talu}', "");
Error('\p{Is_Script=-	NEW_Tai_Lue:=}');
Error('\P{Is_Script=-	NEW_Tai_Lue:=}');
Expect(1, 6623, '\p{Is_Script=newtailue}', "");
Expect(0, 6623, '\p{^Is_Script=newtailue}', "");
Expect(0, 6623, '\P{Is_Script=newtailue}', "");
Expect(1, 6623, '\P{^Is_Script=newtailue}', "");
Expect(0, 6624, '\p{Is_Script=newtailue}', "");
Expect(1, 6624, '\p{^Is_Script=newtailue}', "");
Expect(1, 6624, '\P{Is_Script=newtailue}', "");
Expect(0, 6624, '\P{^Is_Script=newtailue}', "");
Expect(1, 6623, '\p{Is_Script=_-New_TAI_Lue}', "");
Expect(0, 6623, '\p{^Is_Script=_-New_TAI_Lue}', "");
Expect(0, 6623, '\P{Is_Script=_-New_TAI_Lue}', "");
Expect(1, 6623, '\P{^Is_Script=_-New_TAI_Lue}', "");
Expect(0, 6624, '\p{Is_Script=_-New_TAI_Lue}', "");
Expect(1, 6624, '\p{^Is_Script=_-New_TAI_Lue}', "");
Expect(1, 6624, '\P{Is_Script=_-New_TAI_Lue}', "");
Expect(0, 6624, '\P{^Is_Script=_-New_TAI_Lue}', "");
Error('\p{Is_Sc=  TALU:=}');
Error('\P{Is_Sc=  TALU:=}');
Expect(1, 6623, '\p{Is_Sc=talu}', "");
Expect(0, 6623, '\p{^Is_Sc=talu}', "");
Expect(0, 6623, '\P{Is_Sc=talu}', "");
Expect(1, 6623, '\P{^Is_Sc=talu}', "");
Expect(0, 6624, '\p{Is_Sc=talu}', "");
Expect(1, 6624, '\p{^Is_Sc=talu}', "");
Expect(1, 6624, '\P{Is_Sc=talu}', "");
Expect(0, 6624, '\P{^Is_Sc=talu}', "");
Expect(1, 6623, '\p{Is_Sc=  Talu}', "");
Expect(0, 6623, '\p{^Is_Sc=  Talu}', "");
Expect(0, 6623, '\P{Is_Sc=  Talu}', "");
Expect(1, 6623, '\P{^Is_Sc=  Talu}', "");
Expect(0, 6624, '\p{Is_Sc=  Talu}', "");
Expect(1, 6624, '\p{^Is_Sc=  Talu}', "");
Expect(1, 6624, '\P{Is_Sc=  Talu}', "");
Expect(0, 6624, '\P{^Is_Sc=  Talu}', "");
Error('\p{Script=_Tamil/a/}');
Error('\P{Script=_Tamil/a/}');
Expect(1, 3066, '\p{Script=tamil}', "");
Expect(0, 3066, '\p{^Script=tamil}', "");
Expect(0, 3066, '\P{Script=tamil}', "");
Expect(1, 3066, '\P{^Script=tamil}', "");
Expect(0, 3067, '\p{Script=tamil}', "");
Expect(1, 3067, '\p{^Script=tamil}', "");
Expect(1, 3067, '\P{Script=tamil}', "");
Expect(0, 3067, '\P{^Script=tamil}', "");
Expect(1, 3066, '\p{Script= Tamil}', "");
Expect(0, 3066, '\p{^Script= Tamil}', "");
Expect(0, 3066, '\P{Script= Tamil}', "");
Expect(1, 3066, '\P{^Script= Tamil}', "");
Expect(0, 3067, '\p{Script= Tamil}', "");
Expect(1, 3067, '\p{^Script= Tamil}', "");
Expect(1, 3067, '\P{Script= Tamil}', "");
Expect(0, 3067, '\P{^Script= Tamil}', "");
Error('\p{Sc=-Taml:=}');
Error('\P{Sc=-Taml:=}');
Expect(1, 3066, '\p{Sc=taml}', "");
Expect(0, 3066, '\p{^Sc=taml}', "");
Expect(0, 3066, '\P{Sc=taml}', "");
Expect(1, 3066, '\P{^Sc=taml}', "");
Expect(0, 3067, '\p{Sc=taml}', "");
Expect(1, 3067, '\p{^Sc=taml}', "");
Expect(1, 3067, '\P{Sc=taml}', "");
Expect(0, 3067, '\P{^Sc=taml}', "");
Expect(1, 3066, '\p{Sc= Taml}', "");
Expect(0, 3066, '\p{^Sc= Taml}', "");
Expect(0, 3066, '\P{Sc= Taml}', "");
Expect(1, 3066, '\P{^Sc= Taml}', "");
Expect(0, 3067, '\p{Sc= Taml}', "");
Expect(1, 3067, '\p{^Sc= Taml}', "");
Expect(1, 3067, '\P{Sc= Taml}', "");
Expect(0, 3067, '\P{^Sc= Taml}', "");
Error('\p{Is_Script:   -Tamil:=}');
Error('\P{Is_Script:   -Tamil:=}');
Expect(1, 3066, '\p{Is_Script: tamil}', "");
Expect(0, 3066, '\p{^Is_Script: tamil}', "");
Expect(0, 3066, '\P{Is_Script: tamil}', "");
Expect(1, 3066, '\P{^Is_Script: tamil}', "");
Expect(0, 3067, '\p{Is_Script: tamil}', "");
Expect(1, 3067, '\p{^Is_Script: tamil}', "");
Expect(1, 3067, '\P{Is_Script: tamil}', "");
Expect(0, 3067, '\P{^Is_Script: tamil}', "");
Expect(1, 3066, '\p{Is_Script=_-TAMIL}', "");
Expect(0, 3066, '\p{^Is_Script=_-TAMIL}', "");
Expect(0, 3066, '\P{Is_Script=_-TAMIL}', "");
Expect(1, 3066, '\P{^Is_Script=_-TAMIL}', "");
Expect(0, 3067, '\p{Is_Script=_-TAMIL}', "");
Expect(1, 3067, '\p{^Is_Script=_-TAMIL}', "");
Expect(1, 3067, '\P{Is_Script=_-TAMIL}', "");
Expect(0, 3067, '\P{^Is_Script=_-TAMIL}', "");
Error('\p{Is_Sc= :=Taml}');
Error('\P{Is_Sc= :=Taml}');
Expect(1, 3066, '\p{Is_Sc=taml}', "");
Expect(0, 3066, '\p{^Is_Sc=taml}', "");
Expect(0, 3066, '\P{Is_Sc=taml}', "");
Expect(1, 3066, '\P{^Is_Sc=taml}', "");
Expect(0, 3067, '\p{Is_Sc=taml}', "");
Expect(1, 3067, '\p{^Is_Sc=taml}', "");
Expect(1, 3067, '\P{Is_Sc=taml}', "");
Expect(0, 3067, '\P{^Is_Sc=taml}', "");
Expect(1, 3066, '\p{Is_Sc=--TAML}', "");
Expect(0, 3066, '\p{^Is_Sc=--TAML}', "");
Expect(0, 3066, '\P{Is_Sc=--TAML}', "");
Expect(1, 3066, '\P{^Is_Sc=--TAML}', "");
Expect(0, 3067, '\p{Is_Sc=--TAML}', "");
Expect(1, 3067, '\p{^Is_Sc=--TAML}', "");
Expect(1, 3067, '\P{Is_Sc=--TAML}', "");
Expect(0, 3067, '\P{^Is_Sc=--TAML}', "");
Error('\p{Script=/a/ 	Tai_Viet}');
Error('\P{Script=/a/ 	Tai_Viet}');
Expect(1, 43743, '\p{Script: taiviet}', "");
Expect(0, 43743, '\p{^Script: taiviet}', "");
Expect(0, 43743, '\P{Script: taiviet}', "");
Expect(1, 43743, '\P{^Script: taiviet}', "");
Expect(0, 43744, '\p{Script: taiviet}', "");
Expect(1, 43744, '\p{^Script: taiviet}', "");
Expect(1, 43744, '\P{Script: taiviet}', "");
Expect(0, 43744, '\P{^Script: taiviet}', "");
Expect(1, 43743, '\p{Script=-_TAI_viet}', "");
Expect(0, 43743, '\p{^Script=-_TAI_viet}', "");
Expect(0, 43743, '\P{Script=-_TAI_viet}', "");
Expect(1, 43743, '\P{^Script=-_TAI_viet}', "");
Expect(0, 43744, '\p{Script=-_TAI_viet}', "");
Expect(1, 43744, '\p{^Script=-_TAI_viet}', "");
Expect(1, 43744, '\P{Script=-_TAI_viet}', "");
Expect(0, 43744, '\P{^Script=-_TAI_viet}', "");
Error('\p{Sc=/a/--Tavt}');
Error('\P{Sc=/a/--Tavt}');
Expect(1, 43743, '\p{Sc=tavt}', "");
Expect(0, 43743, '\p{^Sc=tavt}', "");
Expect(0, 43743, '\P{Sc=tavt}', "");
Expect(1, 43743, '\P{^Sc=tavt}', "");
Expect(0, 43744, '\p{Sc=tavt}', "");
Expect(1, 43744, '\p{^Sc=tavt}', "");
Expect(1, 43744, '\P{Sc=tavt}', "");
Expect(0, 43744, '\P{^Sc=tavt}', "");
Expect(1, 43743, '\p{Sc=_Tavt}', "");
Expect(0, 43743, '\p{^Sc=_Tavt}', "");
Expect(0, 43743, '\P{Sc=_Tavt}', "");
Expect(1, 43743, '\P{^Sc=_Tavt}', "");
Expect(0, 43744, '\p{Sc=_Tavt}', "");
Expect(1, 43744, '\p{^Sc=_Tavt}', "");
Expect(1, 43744, '\P{Sc=_Tavt}', "");
Expect(0, 43744, '\P{^Sc=_Tavt}', "");
Error('\p{Is_Script=  Tai_viet:=}');
Error('\P{Is_Script=  Tai_viet:=}');
Expect(1, 43743, '\p{Is_Script=taiviet}', "");
Expect(0, 43743, '\p{^Is_Script=taiviet}', "");
Expect(0, 43743, '\P{Is_Script=taiviet}', "");
Expect(1, 43743, '\P{^Is_Script=taiviet}', "");
Expect(0, 43744, '\p{Is_Script=taiviet}', "");
Expect(1, 43744, '\p{^Is_Script=taiviet}', "");
Expect(1, 43744, '\P{Is_Script=taiviet}', "");
Expect(0, 43744, '\P{^Is_Script=taiviet}', "");
Expect(1, 43743, '\p{Is_Script=	 Tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Script=	 Tai_Viet}', "");
Expect(0, 43743, '\P{Is_Script=	 Tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Script=	 Tai_Viet}', "");
Expect(0, 43744, '\p{Is_Script=	 Tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Script=	 Tai_Viet}', "");
Expect(1, 43744, '\P{Is_Script=	 Tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Script=	 Tai_Viet}', "");
Error('\p{Is_Sc: := _tavt}');
Error('\P{Is_Sc: := _tavt}');
Expect(1, 43743, '\p{Is_Sc=tavt}', "");
Expect(0, 43743, '\p{^Is_Sc=tavt}', "");
Expect(0, 43743, '\P{Is_Sc=tavt}', "");
Expect(1, 43743, '\P{^Is_Sc=tavt}', "");
Expect(0, 43744, '\p{Is_Sc=tavt}', "");
Expect(1, 43744, '\p{^Is_Sc=tavt}', "");
Expect(1, 43744, '\P{Is_Sc=tavt}', "");
Expect(0, 43744, '\P{^Is_Sc=tavt}', "");
Expect(1, 43743, '\p{Is_Sc= tavt}', "");
Expect(0, 43743, '\p{^Is_Sc= tavt}', "");
Expect(0, 43743, '\P{Is_Sc= tavt}', "");
Expect(1, 43743, '\P{^Is_Sc= tavt}', "");
Expect(0, 43744, '\p{Is_Sc= tavt}', "");
Expect(1, 43744, '\p{^Is_Sc= tavt}', "");
Expect(1, 43744, '\P{Is_Sc= tavt}', "");
Expect(0, 43744, '\P{^Is_Sc= tavt}', "");
Error('\p{Script=-:=telugu}');
Error('\P{Script=-:=telugu}');
Expect(1, 3199, '\p{Script=telugu}', "");
Expect(0, 3199, '\p{^Script=telugu}', "");
Expect(0, 3199, '\P{Script=telugu}', "");
Expect(1, 3199, '\P{^Script=telugu}', "");
Expect(0, 3200, '\p{Script=telugu}', "");
Expect(1, 3200, '\p{^Script=telugu}', "");
Expect(1, 3200, '\P{Script=telugu}', "");
Expect(0, 3200, '\P{^Script=telugu}', "");
Expect(1, 3199, '\p{Script:   Telugu}', "");
Expect(0, 3199, '\p{^Script:   Telugu}', "");
Expect(0, 3199, '\P{Script:   Telugu}', "");
Expect(1, 3199, '\P{^Script:   Telugu}', "");
Expect(0, 3200, '\p{Script:   Telugu}', "");
Expect(1, 3200, '\p{^Script:   Telugu}', "");
Expect(1, 3200, '\P{Script:   Telugu}', "");
Expect(0, 3200, '\P{^Script:   Telugu}', "");
Error('\p{Sc= Telu:=}');
Error('\P{Sc= Telu:=}');
Expect(1, 3199, '\p{Sc=telu}', "");
Expect(0, 3199, '\p{^Sc=telu}', "");
Expect(0, 3199, '\P{Sc=telu}', "");
Expect(1, 3199, '\P{^Sc=telu}', "");
Expect(0, 3200, '\p{Sc=telu}', "");
Expect(1, 3200, '\p{^Sc=telu}', "");
Expect(1, 3200, '\P{Sc=telu}', "");
Expect(0, 3200, '\P{^Sc=telu}', "");
Expect(1, 3199, '\p{Sc=_telu}', "");
Expect(0, 3199, '\p{^Sc=_telu}', "");
Expect(0, 3199, '\P{Sc=_telu}', "");
Expect(1, 3199, '\P{^Sc=_telu}', "");
Expect(0, 3200, '\p{Sc=_telu}', "");
Expect(1, 3200, '\p{^Sc=_telu}', "");
Expect(1, 3200, '\P{Sc=_telu}', "");
Expect(0, 3200, '\P{^Sc=_telu}', "");
Error('\p{Is_Script: _-Telugu/a/}');
Error('\P{Is_Script: _-Telugu/a/}');
Expect(1, 3199, '\p{Is_Script=telugu}', "");
Expect(0, 3199, '\p{^Is_Script=telugu}', "");
Expect(0, 3199, '\P{Is_Script=telugu}', "");
Expect(1, 3199, '\P{^Is_Script=telugu}', "");
Expect(0, 3200, '\p{Is_Script=telugu}', "");
Expect(1, 3200, '\p{^Is_Script=telugu}', "");
Expect(1, 3200, '\P{Is_Script=telugu}', "");
Expect(0, 3200, '\P{^Is_Script=telugu}', "");
Expect(1, 3199, '\p{Is_Script=  telugu}', "");
Expect(0, 3199, '\p{^Is_Script=  telugu}', "");
Expect(0, 3199, '\P{Is_Script=  telugu}', "");
Expect(1, 3199, '\P{^Is_Script=  telugu}', "");
Expect(0, 3200, '\p{Is_Script=  telugu}', "");
Expect(1, 3200, '\p{^Is_Script=  telugu}', "");
Expect(1, 3200, '\P{Is_Script=  telugu}', "");
Expect(0, 3200, '\P{^Is_Script=  telugu}', "");
Error('\p{Is_Sc=-_telu/a/}');
Error('\P{Is_Sc=-_telu/a/}');
Expect(1, 3199, '\p{Is_Sc=telu}', "");
Expect(0, 3199, '\p{^Is_Sc=telu}', "");
Expect(0, 3199, '\P{Is_Sc=telu}', "");
Expect(1, 3199, '\P{^Is_Sc=telu}', "");
Expect(0, 3200, '\p{Is_Sc=telu}', "");
Expect(1, 3200, '\p{^Is_Sc=telu}', "");
Expect(1, 3200, '\P{Is_Sc=telu}', "");
Expect(0, 3200, '\P{^Is_Sc=telu}', "");
Expect(1, 3199, '\p{Is_Sc=	-telu}', "");
Expect(0, 3199, '\p{^Is_Sc=	-telu}', "");
Expect(0, 3199, '\P{Is_Sc=	-telu}', "");
Expect(1, 3199, '\P{^Is_Sc=	-telu}', "");
Expect(0, 3200, '\p{Is_Sc=	-telu}', "");
Expect(1, 3200, '\p{^Is_Sc=	-telu}', "");
Expect(1, 3200, '\P{Is_Sc=	-telu}', "");
Expect(0, 3200, '\P{^Is_Sc=	-telu}', "");
Error('\p{Script=-Tifinagh/a/}');
Error('\P{Script=-Tifinagh/a/}');
Expect(1, 11647, '\p{Script=tifinagh}', "");
Expect(0, 11647, '\p{^Script=tifinagh}', "");
Expect(0, 11647, '\P{Script=tifinagh}', "");
Expect(1, 11647, '\P{^Script=tifinagh}', "");
Expect(0, 11648, '\p{Script=tifinagh}', "");
Expect(1, 11648, '\p{^Script=tifinagh}', "");
Expect(1, 11648, '\P{Script=tifinagh}', "");
Expect(0, 11648, '\P{^Script=tifinagh}', "");
Expect(1, 11647, '\p{Script=	 Tifinagh}', "");
Expect(0, 11647, '\p{^Script=	 Tifinagh}', "");
Expect(0, 11647, '\P{Script=	 Tifinagh}', "");
Expect(1, 11647, '\P{^Script=	 Tifinagh}', "");
Expect(0, 11648, '\p{Script=	 Tifinagh}', "");
Expect(1, 11648, '\p{^Script=	 Tifinagh}', "");
Expect(1, 11648, '\P{Script=	 Tifinagh}', "");
Expect(0, 11648, '\P{^Script=	 Tifinagh}', "");
Error('\p{Sc=:=Tfng}');
Error('\P{Sc=:=Tfng}');
Expect(1, 11647, '\p{Sc=tfng}', "");
Expect(0, 11647, '\p{^Sc=tfng}', "");
Expect(0, 11647, '\P{Sc=tfng}', "");
Expect(1, 11647, '\P{^Sc=tfng}', "");
Expect(0, 11648, '\p{Sc=tfng}', "");
Expect(1, 11648, '\p{^Sc=tfng}', "");
Expect(1, 11648, '\P{Sc=tfng}', "");
Expect(0, 11648, '\P{^Sc=tfng}', "");
Expect(1, 11647, '\p{Sc=	_TFNG}', "");
Expect(0, 11647, '\p{^Sc=	_TFNG}', "");
Expect(0, 11647, '\P{Sc=	_TFNG}', "");
Expect(1, 11647, '\P{^Sc=	_TFNG}', "");
Expect(0, 11648, '\p{Sc=	_TFNG}', "");
Expect(1, 11648, '\p{^Sc=	_TFNG}', "");
Expect(1, 11648, '\P{Sc=	_TFNG}', "");
Expect(0, 11648, '\P{^Sc=	_TFNG}', "");
Error('\p{Is_Script::= Tifinagh}');
Error('\P{Is_Script::= Tifinagh}');
Expect(1, 11647, '\p{Is_Script=tifinagh}', "");
Expect(0, 11647, '\p{^Is_Script=tifinagh}', "");
Expect(0, 11647, '\P{Is_Script=tifinagh}', "");
Expect(1, 11647, '\P{^Is_Script=tifinagh}', "");
Expect(0, 11648, '\p{Is_Script=tifinagh}', "");
Expect(1, 11648, '\p{^Is_Script=tifinagh}', "");
Expect(1, 11648, '\P{Is_Script=tifinagh}', "");
Expect(0, 11648, '\P{^Is_Script=tifinagh}', "");
Expect(1, 11647, '\p{Is_Script:   	-Tifinagh}', "");
Expect(0, 11647, '\p{^Is_Script:   	-Tifinagh}', "");
Expect(0, 11647, '\P{Is_Script:   	-Tifinagh}', "");
Expect(1, 11647, '\P{^Is_Script:   	-Tifinagh}', "");
Expect(0, 11648, '\p{Is_Script:   	-Tifinagh}', "");
Expect(1, 11648, '\p{^Is_Script:   	-Tifinagh}', "");
Expect(1, 11648, '\P{Is_Script:   	-Tifinagh}', "");
Expect(0, 11648, '\P{^Is_Script:   	-Tifinagh}', "");
Error('\p{Is_Sc=--Tfng/a/}');
Error('\P{Is_Sc=--Tfng/a/}');
Expect(1, 11647, '\p{Is_Sc=tfng}', "");
Expect(0, 11647, '\p{^Is_Sc=tfng}', "");
Expect(0, 11647, '\P{Is_Sc=tfng}', "");
Expect(1, 11647, '\P{^Is_Sc=tfng}', "");
Expect(0, 11648, '\p{Is_Sc=tfng}', "");
Expect(1, 11648, '\p{^Is_Sc=tfng}', "");
Expect(1, 11648, '\P{Is_Sc=tfng}', "");
Expect(0, 11648, '\P{^Is_Sc=tfng}', "");
Expect(1, 11647, '\p{Is_Sc=  Tfng}', "");
Expect(0, 11647, '\p{^Is_Sc=  Tfng}', "");
Expect(0, 11647, '\P{Is_Sc=  Tfng}', "");
Expect(1, 11647, '\P{^Is_Sc=  Tfng}', "");
Expect(0, 11648, '\p{Is_Sc=  Tfng}', "");
Expect(1, 11648, '\p{^Is_Sc=  Tfng}', "");
Expect(1, 11648, '\P{Is_Sc=  Tfng}', "");
Expect(0, 11648, '\P{^Is_Sc=  Tfng}', "");
Error('\p{Script= TAGALOG:=}');
Error('\P{Script= TAGALOG:=}');
Expect(1, 5908, '\p{Script=tagalog}', "");
Expect(0, 5908, '\p{^Script=tagalog}', "");
Expect(0, 5908, '\P{Script=tagalog}', "");
Expect(1, 5908, '\P{^Script=tagalog}', "");
Expect(0, 5909, '\p{Script=tagalog}', "");
Expect(1, 5909, '\p{^Script=tagalog}', "");
Expect(1, 5909, '\P{Script=tagalog}', "");
Expect(0, 5909, '\P{^Script=tagalog}', "");
Expect(1, 5908, '\p{Script=_-Tagalog}', "");
Expect(0, 5908, '\p{^Script=_-Tagalog}', "");
Expect(0, 5908, '\P{Script=_-Tagalog}', "");
Expect(1, 5908, '\P{^Script=_-Tagalog}', "");
Expect(0, 5909, '\p{Script=_-Tagalog}', "");
Expect(1, 5909, '\p{^Script=_-Tagalog}', "");
Expect(1, 5909, '\P{Script=_-Tagalog}', "");
Expect(0, 5909, '\P{^Script=_-Tagalog}', "");
Error('\p{Sc= tglg/a/}');
Error('\P{Sc= tglg/a/}');
Expect(1, 5908, '\p{Sc=tglg}', "");
Expect(0, 5908, '\p{^Sc=tglg}', "");
Expect(0, 5908, '\P{Sc=tglg}', "");
Expect(1, 5908, '\P{^Sc=tglg}', "");
Expect(0, 5909, '\p{Sc=tglg}', "");
Expect(1, 5909, '\p{^Sc=tglg}', "");
Expect(1, 5909, '\P{Sc=tglg}', "");
Expect(0, 5909, '\P{^Sc=tglg}', "");
Expect(1, 5908, '\p{Sc=_	Tglg}', "");
Expect(0, 5908, '\p{^Sc=_	Tglg}', "");
Expect(0, 5908, '\P{Sc=_	Tglg}', "");
Expect(1, 5908, '\P{^Sc=_	Tglg}', "");
Expect(0, 5909, '\p{Sc=_	Tglg}', "");
Expect(1, 5909, '\p{^Sc=_	Tglg}', "");
Expect(1, 5909, '\P{Sc=_	Tglg}', "");
Expect(0, 5909, '\P{^Sc=_	Tglg}', "");
Error('\p{Is_Script= Tagalog:=}');
Error('\P{Is_Script= Tagalog:=}');
Expect(1, 5908, '\p{Is_Script=tagalog}', "");
Expect(0, 5908, '\p{^Is_Script=tagalog}', "");
Expect(0, 5908, '\P{Is_Script=tagalog}', "");
Expect(1, 5908, '\P{^Is_Script=tagalog}', "");
Expect(0, 5909, '\p{Is_Script=tagalog}', "");
Expect(1, 5909, '\p{^Is_Script=tagalog}', "");
Expect(1, 5909, '\P{Is_Script=tagalog}', "");
Expect(0, 5909, '\P{^Is_Script=tagalog}', "");
Expect(1, 5908, '\p{Is_Script=	_tagalog}', "");
Expect(0, 5908, '\p{^Is_Script=	_tagalog}', "");
Expect(0, 5908, '\P{Is_Script=	_tagalog}', "");
Expect(1, 5908, '\P{^Is_Script=	_tagalog}', "");
Expect(0, 5909, '\p{Is_Script=	_tagalog}', "");
Expect(1, 5909, '\p{^Is_Script=	_tagalog}', "");
Expect(1, 5909, '\P{Is_Script=	_tagalog}', "");
Expect(0, 5909, '\P{^Is_Script=	_tagalog}', "");
Error('\p{Is_Sc=/a/_Tglg}');
Error('\P{Is_Sc=/a/_Tglg}');
Expect(1, 5908, '\p{Is_Sc=tglg}', "");
Expect(0, 5908, '\p{^Is_Sc=tglg}', "");
Expect(0, 5908, '\P{Is_Sc=tglg}', "");
Expect(1, 5908, '\P{^Is_Sc=tglg}', "");
Expect(0, 5909, '\p{Is_Sc=tglg}', "");
Expect(1, 5909, '\p{^Is_Sc=tglg}', "");
Expect(1, 5909, '\P{Is_Sc=tglg}', "");
Expect(0, 5909, '\P{^Is_Sc=tglg}', "");
Expect(1, 5908, '\p{Is_Sc=_tglg}', "");
Expect(0, 5908, '\p{^Is_Sc=_tglg}', "");
Expect(0, 5908, '\P{Is_Sc=_tglg}', "");
Expect(1, 5908, '\P{^Is_Sc=_tglg}', "");
Expect(0, 5909, '\p{Is_Sc=_tglg}', "");
Expect(1, 5909, '\p{^Is_Sc=_tglg}', "");
Expect(1, 5909, '\P{Is_Sc=_tglg}', "");
Expect(0, 5909, '\P{^Is_Sc=_tglg}', "");
Error('\p{Script=	THAANA/a/}');
Error('\P{Script=	THAANA/a/}');
Expect(1, 1969, '\p{Script=thaana}', "");
Expect(0, 1969, '\p{^Script=thaana}', "");
Expect(0, 1969, '\P{Script=thaana}', "");
Expect(1, 1969, '\P{^Script=thaana}', "");
Expect(0, 1970, '\p{Script=thaana}', "");
Expect(1, 1970, '\p{^Script=thaana}', "");
Expect(1, 1970, '\P{Script=thaana}', "");
Expect(0, 1970, '\P{^Script=thaana}', "");
Expect(1, 1969, '\p{Script=	Thaana}', "");
Expect(0, 1969, '\p{^Script=	Thaana}', "");
Expect(0, 1969, '\P{Script=	Thaana}', "");
Expect(1, 1969, '\P{^Script=	Thaana}', "");
Expect(0, 1970, '\p{Script=	Thaana}', "");
Expect(1, 1970, '\p{^Script=	Thaana}', "");
Expect(1, 1970, '\P{Script=	Thaana}', "");
Expect(0, 1970, '\P{^Script=	Thaana}', "");
Error('\p{Sc=_:=Thaa}');
Error('\P{Sc=_:=Thaa}');
Expect(1, 1969, '\p{Sc=thaa}', "");
Expect(0, 1969, '\p{^Sc=thaa}', "");
Expect(0, 1969, '\P{Sc=thaa}', "");
Expect(1, 1969, '\P{^Sc=thaa}', "");
Expect(0, 1970, '\p{Sc=thaa}', "");
Expect(1, 1970, '\p{^Sc=thaa}', "");
Expect(1, 1970, '\P{Sc=thaa}', "");
Expect(0, 1970, '\P{^Sc=thaa}', "");
Expect(1, 1969, '\p{Sc= thaa}', "");
Expect(0, 1969, '\p{^Sc= thaa}', "");
Expect(0, 1969, '\P{Sc= thaa}', "");
Expect(1, 1969, '\P{^Sc= thaa}', "");
Expect(0, 1970, '\p{Sc= thaa}', "");
Expect(1, 1970, '\p{^Sc= thaa}', "");
Expect(1, 1970, '\P{Sc= thaa}', "");
Expect(0, 1970, '\P{^Sc= thaa}', "");
Error('\p{Is_Script=/a/THAANA}');
Error('\P{Is_Script=/a/THAANA}');
Expect(1, 1969, '\p{Is_Script:	thaana}', "");
Expect(0, 1969, '\p{^Is_Script:	thaana}', "");
Expect(0, 1969, '\P{Is_Script:	thaana}', "");
Expect(1, 1969, '\P{^Is_Script:	thaana}', "");
Expect(0, 1970, '\p{Is_Script:	thaana}', "");
Expect(1, 1970, '\p{^Is_Script:	thaana}', "");
Expect(1, 1970, '\P{Is_Script:	thaana}', "");
Expect(0, 1970, '\P{^Is_Script:	thaana}', "");
Expect(1, 1969, '\p{Is_Script=	 THAANA}', "");
Expect(0, 1969, '\p{^Is_Script=	 THAANA}', "");
Expect(0, 1969, '\P{Is_Script=	 THAANA}', "");
Expect(1, 1969, '\P{^Is_Script=	 THAANA}', "");
Expect(0, 1970, '\p{Is_Script=	 THAANA}', "");
Expect(1, 1970, '\p{^Is_Script=	 THAANA}', "");
Expect(1, 1970, '\P{Is_Script=	 THAANA}', "");
Expect(0, 1970, '\P{^Is_Script=	 THAANA}', "");
Error('\p{Is_Sc=	/a/Thaa}');
Error('\P{Is_Sc=	/a/Thaa}');
Expect(1, 1969, '\p{Is_Sc=thaa}', "");
Expect(0, 1969, '\p{^Is_Sc=thaa}', "");
Expect(0, 1969, '\P{Is_Sc=thaa}', "");
Expect(1, 1969, '\P{^Is_Sc=thaa}', "");
Expect(0, 1970, '\p{Is_Sc=thaa}', "");
Expect(1, 1970, '\p{^Is_Sc=thaa}', "");
Expect(1, 1970, '\P{Is_Sc=thaa}', "");
Expect(0, 1970, '\P{^Is_Sc=thaa}', "");
Expect(1, 1969, '\p{Is_Sc=	thaa}', "");
Expect(0, 1969, '\p{^Is_Sc=	thaa}', "");
Expect(0, 1969, '\P{Is_Sc=	thaa}', "");
Expect(1, 1969, '\P{^Is_Sc=	thaa}', "");
Expect(0, 1970, '\p{Is_Sc=	thaa}', "");
Expect(1, 1970, '\p{^Is_Sc=	thaa}', "");
Expect(1, 1970, '\P{Is_Sc=	thaa}', "");
Expect(0, 1970, '\P{^Is_Sc=	thaa}', "");
Error('\p{Script=_-Thai:=}');
Error('\P{Script=_-Thai:=}');
Expect(1, 3675, '\p{Script=thai}', "");
Expect(0, 3675, '\p{^Script=thai}', "");
Expect(0, 3675, '\P{Script=thai}', "");
Expect(1, 3675, '\P{^Script=thai}', "");
Expect(0, 3676, '\p{Script=thai}', "");
Expect(1, 3676, '\p{^Script=thai}', "");
Expect(1, 3676, '\P{Script=thai}', "");
Expect(0, 3676, '\P{^Script=thai}', "");
Expect(1, 3675, '\p{Script: _	Thai}', "");
Expect(0, 3675, '\p{^Script: _	Thai}', "");
Expect(0, 3675, '\P{Script: _	Thai}', "");
Expect(1, 3675, '\P{^Script: _	Thai}', "");
Expect(0, 3676, '\p{Script: _	Thai}', "");
Expect(1, 3676, '\p{^Script: _	Thai}', "");
Expect(1, 3676, '\P{Script: _	Thai}', "");
Expect(0, 3676, '\P{^Script: _	Thai}', "");
Error('\p{Sc=:=- THAI}');
Error('\P{Sc=:=- THAI}');
Expect(1, 3675, '\p{Sc=thai}', "");
Expect(0, 3675, '\p{^Sc=thai}', "");
Expect(0, 3675, '\P{Sc=thai}', "");
Expect(1, 3675, '\P{^Sc=thai}', "");
Expect(0, 3676, '\p{Sc=thai}', "");
Expect(1, 3676, '\p{^Sc=thai}', "");
Expect(1, 3676, '\P{Sc=thai}', "");
Expect(0, 3676, '\P{^Sc=thai}', "");
Expect(1, 3675, '\p{Sc=-	Thai}', "");
Expect(0, 3675, '\p{^Sc=-	Thai}', "");
Expect(0, 3675, '\P{Sc=-	Thai}', "");
Expect(1, 3675, '\P{^Sc=-	Thai}', "");
Expect(0, 3676, '\p{Sc=-	Thai}', "");
Expect(1, 3676, '\p{^Sc=-	Thai}', "");
Expect(1, 3676, '\P{Sc=-	Thai}', "");
Expect(0, 3676, '\P{^Sc=-	Thai}', "");
Error('\p{Is_Script= :=THAI}');
Error('\P{Is_Script= :=THAI}');
Expect(1, 3675, '\p{Is_Script=thai}', "");
Expect(0, 3675, '\p{^Is_Script=thai}', "");
Expect(0, 3675, '\P{Is_Script=thai}', "");
Expect(1, 3675, '\P{^Is_Script=thai}', "");
Expect(0, 3676, '\p{Is_Script=thai}', "");
Expect(1, 3676, '\p{^Is_Script=thai}', "");
Expect(1, 3676, '\P{Is_Script=thai}', "");
Expect(0, 3676, '\P{^Is_Script=thai}', "");
Expect(1, 3675, '\p{Is_Script=- Thai}', "");
Expect(0, 3675, '\p{^Is_Script=- Thai}', "");
Expect(0, 3675, '\P{Is_Script=- Thai}', "");
Expect(1, 3675, '\P{^Is_Script=- Thai}', "");
Expect(0, 3676, '\p{Is_Script=- Thai}', "");
Expect(1, 3676, '\p{^Is_Script=- Thai}', "");
Expect(1, 3676, '\P{Is_Script=- Thai}', "");
Expect(0, 3676, '\P{^Is_Script=- Thai}', "");
Error('\p{Is_Sc=	:=Thai}');
Error('\P{Is_Sc=	:=Thai}');
Expect(1, 3675, '\p{Is_Sc=thai}', "");
Expect(0, 3675, '\p{^Is_Sc=thai}', "");
Expect(0, 3675, '\P{Is_Sc=thai}', "");
Expect(1, 3675, '\P{^Is_Sc=thai}', "");
Expect(0, 3676, '\p{Is_Sc=thai}', "");
Expect(1, 3676, '\p{^Is_Sc=thai}', "");
Expect(1, 3676, '\P{Is_Sc=thai}', "");
Expect(0, 3676, '\P{^Is_Sc=thai}', "");
Expect(1, 3675, '\p{Is_Sc=_ Thai}', "");
Expect(0, 3675, '\p{^Is_Sc=_ Thai}', "");
Expect(0, 3675, '\P{Is_Sc=_ Thai}', "");
Expect(1, 3675, '\P{^Is_Sc=_ Thai}', "");
Expect(0, 3676, '\p{Is_Sc=_ Thai}', "");
Expect(1, 3676, '\p{^Is_Sc=_ Thai}', "");
Expect(1, 3676, '\P{Is_Sc=_ Thai}', "");
Expect(0, 3676, '\P{^Is_Sc=_ Thai}', "");
Error('\p{Script=:=--TIBETAN}');
Error('\P{Script=:=--TIBETAN}');
Expect(1, 4058, '\p{Script=tibetan}', "");
Expect(0, 4058, '\p{^Script=tibetan}', "");
Expect(0, 4058, '\P{Script=tibetan}', "");
Expect(1, 4058, '\P{^Script=tibetan}', "");
Expect(0, 4059, '\p{Script=tibetan}', "");
Expect(1, 4059, '\p{^Script=tibetan}', "");
Expect(1, 4059, '\P{Script=tibetan}', "");
Expect(0, 4059, '\P{^Script=tibetan}', "");
Expect(1, 4058, '\p{Script=-TIBETAN}', "");
Expect(0, 4058, '\p{^Script=-TIBETAN}', "");
Expect(0, 4058, '\P{Script=-TIBETAN}', "");
Expect(1, 4058, '\P{^Script=-TIBETAN}', "");
Expect(0, 4059, '\p{Script=-TIBETAN}', "");
Expect(1, 4059, '\p{^Script=-TIBETAN}', "");
Expect(1, 4059, '\P{Script=-TIBETAN}', "");
Expect(0, 4059, '\P{^Script=-TIBETAN}', "");
Error('\p{Sc=:=Tibt}');
Error('\P{Sc=:=Tibt}');
Expect(1, 4058, '\p{Sc: tibt}', "");
Expect(0, 4058, '\p{^Sc: tibt}', "");
Expect(0, 4058, '\P{Sc: tibt}', "");
Expect(1, 4058, '\P{^Sc: tibt}', "");
Expect(0, 4059, '\p{Sc: tibt}', "");
Expect(1, 4059, '\p{^Sc: tibt}', "");
Expect(1, 4059, '\P{Sc: tibt}', "");
Expect(0, 4059, '\P{^Sc: tibt}', "");
Expect(1, 4058, '\p{Sc=-_Tibt}', "");
Expect(0, 4058, '\p{^Sc=-_Tibt}', "");
Expect(0, 4058, '\P{Sc=-_Tibt}', "");
Expect(1, 4058, '\P{^Sc=-_Tibt}', "");
Expect(0, 4059, '\p{Sc=-_Tibt}', "");
Expect(1, 4059, '\p{^Sc=-_Tibt}', "");
Expect(1, 4059, '\P{Sc=-_Tibt}', "");
Expect(0, 4059, '\P{^Sc=-_Tibt}', "");
Error('\p{Is_Script=	-Tibetan:=}');
Error('\P{Is_Script=	-Tibetan:=}');
Expect(1, 4058, '\p{Is_Script=tibetan}', "");
Expect(0, 4058, '\p{^Is_Script=tibetan}', "");
Expect(0, 4058, '\P{Is_Script=tibetan}', "");
Expect(1, 4058, '\P{^Is_Script=tibetan}', "");
Expect(0, 4059, '\p{Is_Script=tibetan}', "");
Expect(1, 4059, '\p{^Is_Script=tibetan}', "");
Expect(1, 4059, '\P{Is_Script=tibetan}', "");
Expect(0, 4059, '\P{^Is_Script=tibetan}', "");
Expect(1, 4058, '\p{Is_Script= -Tibetan}', "");
Expect(0, 4058, '\p{^Is_Script= -Tibetan}', "");
Expect(0, 4058, '\P{Is_Script= -Tibetan}', "");
Expect(1, 4058, '\P{^Is_Script= -Tibetan}', "");
Expect(0, 4059, '\p{Is_Script= -Tibetan}', "");
Expect(1, 4059, '\p{^Is_Script= -Tibetan}', "");
Expect(1, 4059, '\P{Is_Script= -Tibetan}', "");
Expect(0, 4059, '\P{^Is_Script= -Tibetan}', "");
Error('\p{Is_Sc= Tibt/a/}');
Error('\P{Is_Sc= Tibt/a/}');
Expect(1, 4058, '\p{Is_Sc=tibt}', "");
Expect(0, 4058, '\p{^Is_Sc=tibt}', "");
Expect(0, 4058, '\P{Is_Sc=tibt}', "");
Expect(1, 4058, '\P{^Is_Sc=tibt}', "");
Expect(0, 4059, '\p{Is_Sc=tibt}', "");
Expect(1, 4059, '\p{^Is_Sc=tibt}', "");
Expect(1, 4059, '\P{Is_Sc=tibt}', "");
Expect(0, 4059, '\P{^Is_Sc=tibt}', "");
Expect(1, 4058, '\p{Is_Sc=	tibt}', "");
Expect(0, 4058, '\p{^Is_Sc=	tibt}', "");
Expect(0, 4058, '\P{Is_Sc=	tibt}', "");
Expect(1, 4058, '\P{^Is_Sc=	tibt}', "");
Expect(0, 4059, '\p{Is_Sc=	tibt}', "");
Expect(1, 4059, '\p{^Is_Sc=	tibt}', "");
Expect(1, 4059, '\P{Is_Sc=	tibt}', "");
Expect(0, 4059, '\P{^Is_Sc=	tibt}', "");
Error('\p{Script=-/a/Ugaritic}');
Error('\P{Script=-/a/Ugaritic}');
Expect(1, 66463, '\p{Script=ugaritic}', "");
Expect(0, 66463, '\p{^Script=ugaritic}', "");
Expect(0, 66463, '\P{Script=ugaritic}', "");
Expect(1, 66463, '\P{^Script=ugaritic}', "");
Expect(0, 66464, '\p{Script=ugaritic}', "");
Expect(1, 66464, '\p{^Script=ugaritic}', "");
Expect(1, 66464, '\P{Script=ugaritic}', "");
Expect(0, 66464, '\P{^Script=ugaritic}', "");
Expect(1, 66463, '\p{Script:	-UGARITIC}', "");
Expect(0, 66463, '\p{^Script:	-UGARITIC}', "");
Expect(0, 66463, '\P{Script:	-UGARITIC}', "");
Expect(1, 66463, '\P{^Script:	-UGARITIC}', "");
Expect(0, 66464, '\p{Script:	-UGARITIC}', "");
Expect(1, 66464, '\p{^Script:	-UGARITIC}', "");
Expect(1, 66464, '\P{Script:	-UGARITIC}', "");
Expect(0, 66464, '\P{^Script:	-UGARITIC}', "");
Error('\p{Sc= _ugar/a/}');
Error('\P{Sc= _ugar/a/}');
Expect(1, 66463, '\p{Sc=ugar}', "");
Expect(0, 66463, '\p{^Sc=ugar}', "");
Expect(0, 66463, '\P{Sc=ugar}', "");
Expect(1, 66463, '\P{^Sc=ugar}', "");
Expect(0, 66464, '\p{Sc=ugar}', "");
Expect(1, 66464, '\p{^Sc=ugar}', "");
Expect(1, 66464, '\P{Sc=ugar}', "");
Expect(0, 66464, '\P{^Sc=ugar}', "");
Expect(1, 66463, '\p{Sc= UGAR}', "");
Expect(0, 66463, '\p{^Sc= UGAR}', "");
Expect(0, 66463, '\P{Sc= UGAR}', "");
Expect(1, 66463, '\P{^Sc= UGAR}', "");
Expect(0, 66464, '\p{Sc= UGAR}', "");
Expect(1, 66464, '\p{^Sc= UGAR}', "");
Expect(1, 66464, '\P{Sc= UGAR}', "");
Expect(0, 66464, '\P{^Sc= UGAR}', "");
Error('\p{Is_Script:_ Ugaritic:=}');
Error('\P{Is_Script:_ Ugaritic:=}');
Expect(1, 66463, '\p{Is_Script=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script=ugaritic}', "");
Expect(0, 66463, '\P{Is_Script=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script=ugaritic}', "");
Expect(0, 66464, '\p{Is_Script=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script=ugaritic}', "");
Expect(1, 66464, '\P{Is_Script=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script=ugaritic}', "");
Expect(1, 66463, '\p{Is_Script:_Ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script:_Ugaritic}', "");
Expect(0, 66463, '\P{Is_Script:_Ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script:_Ugaritic}', "");
Expect(0, 66464, '\p{Is_Script:_Ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script:_Ugaritic}', "");
Expect(1, 66464, '\P{Is_Script:_Ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script:_Ugaritic}', "");
Error('\p{Is_Sc=/a/	 Ugar}');
Error('\P{Is_Sc=/a/	 Ugar}');
Expect(1, 66463, '\p{Is_Sc=ugar}', "");
Expect(0, 66463, '\p{^Is_Sc=ugar}', "");
Expect(0, 66463, '\P{Is_Sc=ugar}', "");
Expect(1, 66463, '\P{^Is_Sc=ugar}', "");
Expect(0, 66464, '\p{Is_Sc=ugar}', "");
Expect(1, 66464, '\p{^Is_Sc=ugar}', "");
Expect(1, 66464, '\P{Is_Sc=ugar}', "");
Expect(0, 66464, '\P{^Is_Sc=ugar}', "");
Expect(1, 66463, '\p{Is_Sc=_-Ugar}', "");
Expect(0, 66463, '\p{^Is_Sc=_-Ugar}', "");
Expect(0, 66463, '\P{Is_Sc=_-Ugar}', "");
Expect(1, 66463, '\P{^Is_Sc=_-Ugar}', "");
Expect(0, 66464, '\p{Is_Sc=_-Ugar}', "");
Expect(1, 66464, '\p{^Is_Sc=_-Ugar}', "");
Expect(1, 66464, '\P{Is_Sc=_-Ugar}', "");
Expect(0, 66464, '\P{^Is_Sc=_-Ugar}', "");
Error('\p{Script= VAI:=}');
Error('\P{Script= VAI:=}');
Expect(1, 42539, '\p{Script=vai}', "");
Expect(0, 42539, '\p{^Script=vai}', "");
Expect(0, 42539, '\P{Script=vai}', "");
Expect(1, 42539, '\P{^Script=vai}', "");
Expect(0, 42540, '\p{Script=vai}', "");
Expect(1, 42540, '\p{^Script=vai}', "");
Expect(1, 42540, '\P{Script=vai}', "");
Expect(0, 42540, '\P{^Script=vai}', "");
Error('\p{Sc= /a/Vaii}');
Error('\P{Sc= /a/Vaii}');
Expect(1, 42539, '\p{Sc=vaii}', "");
Expect(0, 42539, '\p{^Sc=vaii}', "");
Expect(0, 42539, '\P{Sc=vaii}', "");
Expect(1, 42539, '\P{^Sc=vaii}', "");
Expect(0, 42540, '\p{Sc=vaii}', "");
Expect(1, 42540, '\p{^Sc=vaii}', "");
Expect(1, 42540, '\P{Sc=vaii}', "");
Expect(0, 42540, '\P{^Sc=vaii}', "");
Expect(1, 42539, '\p{Sc=-VAII}', "");
Expect(0, 42539, '\p{^Sc=-VAII}', "");
Expect(0, 42539, '\P{Sc=-VAII}', "");
Expect(1, 42539, '\P{^Sc=-VAII}', "");
Expect(0, 42540, '\p{Sc=-VAII}', "");
Expect(1, 42540, '\p{^Sc=-VAII}', "");
Expect(1, 42540, '\P{Sc=-VAII}', "");
Expect(0, 42540, '\P{^Sc=-VAII}', "");
Error('\p{Is_Script:		/a/Vai}');
Error('\P{Is_Script:		/a/Vai}');
Expect(1, 42539, '\p{Is_Script=vai}', "");
Expect(0, 42539, '\p{^Is_Script=vai}', "");
Expect(0, 42539, '\P{Is_Script=vai}', "");
Expect(1, 42539, '\P{^Is_Script=vai}', "");
Expect(0, 42540, '\p{Is_Script=vai}', "");
Expect(1, 42540, '\p{^Is_Script=vai}', "");
Expect(1, 42540, '\P{Is_Script=vai}', "");
Expect(0, 42540, '\P{^Is_Script=vai}', "");
Expect(1, 42539, '\p{Is_Script=_ Vai}', "");
Expect(0, 42539, '\p{^Is_Script=_ Vai}', "");
Expect(0, 42539, '\P{Is_Script=_ Vai}', "");
Expect(1, 42539, '\P{^Is_Script=_ Vai}', "");
Expect(0, 42540, '\p{Is_Script=_ Vai}', "");
Expect(1, 42540, '\p{^Is_Script=_ Vai}', "");
Expect(1, 42540, '\P{Is_Script=_ Vai}', "");
Expect(0, 42540, '\P{^Is_Script=_ Vai}', "");
Error('\p{Is_Sc= _VAII:=}');
Error('\P{Is_Sc= _VAII:=}');
Expect(1, 42539, '\p{Is_Sc=vaii}', "");
Expect(0, 42539, '\p{^Is_Sc=vaii}', "");
Expect(0, 42539, '\P{Is_Sc=vaii}', "");
Expect(1, 42539, '\P{^Is_Sc=vaii}', "");
Expect(0, 42540, '\p{Is_Sc=vaii}', "");
Expect(1, 42540, '\p{^Is_Sc=vaii}', "");
Expect(1, 42540, '\P{Is_Sc=vaii}', "");
Expect(0, 42540, '\P{^Is_Sc=vaii}', "");
Expect(1, 42539, '\p{Is_Sc= -vaii}', "");
Expect(0, 42539, '\p{^Is_Sc= -vaii}', "");
Expect(0, 42539, '\P{Is_Sc= -vaii}', "");
Expect(1, 42539, '\P{^Is_Sc= -vaii}', "");
Expect(0, 42540, '\p{Is_Sc= -vaii}', "");
Expect(1, 42540, '\p{^Is_Sc= -vaii}', "");
Expect(1, 42540, '\P{Is_Sc= -vaii}', "");
Expect(0, 42540, '\P{^Is_Sc= -vaii}', "");
Error('\p{Script:   _	Old_Persian:=}');
Error('\P{Script:   _	Old_Persian:=}');
Expect(1, 66517, '\p{Script=oldpersian}', "");
Expect(0, 66517, '\p{^Script=oldpersian}', "");
Expect(0, 66517, '\P{Script=oldpersian}', "");
Expect(1, 66517, '\P{^Script=oldpersian}', "");
Expect(0, 66518, '\p{Script=oldpersian}', "");
Expect(1, 66518, '\p{^Script=oldpersian}', "");
Expect(1, 66518, '\P{Script=oldpersian}', "");
Expect(0, 66518, '\P{^Script=oldpersian}', "");
Expect(1, 66517, '\p{Script=_Old_persian}', "");
Expect(0, 66517, '\p{^Script=_Old_persian}', "");
Expect(0, 66517, '\P{Script=_Old_persian}', "");
Expect(1, 66517, '\P{^Script=_Old_persian}', "");
Expect(0, 66518, '\p{Script=_Old_persian}', "");
Expect(1, 66518, '\p{^Script=_Old_persian}', "");
Expect(1, 66518, '\P{Script=_Old_persian}', "");
Expect(0, 66518, '\P{^Script=_Old_persian}', "");
Error('\p{Sc=/a/_Xpeo}');
Error('\P{Sc=/a/_Xpeo}');
Expect(1, 66517, '\p{Sc:	xpeo}', "");
Expect(0, 66517, '\p{^Sc:	xpeo}', "");
Expect(0, 66517, '\P{Sc:	xpeo}', "");
Expect(1, 66517, '\P{^Sc:	xpeo}', "");
Expect(0, 66518, '\p{Sc:	xpeo}', "");
Expect(1, 66518, '\p{^Sc:	xpeo}', "");
Expect(1, 66518, '\P{Sc:	xpeo}', "");
Expect(0, 66518, '\P{^Sc:	xpeo}', "");
Expect(1, 66517, '\p{Sc=	 XPEO}', "");
Expect(0, 66517, '\p{^Sc=	 XPEO}', "");
Expect(0, 66517, '\P{Sc=	 XPEO}', "");
Expect(1, 66517, '\P{^Sc=	 XPEO}', "");
Expect(0, 66518, '\p{Sc=	 XPEO}', "");
Expect(1, 66518, '\p{^Sc=	 XPEO}', "");
Expect(1, 66518, '\P{Sc=	 XPEO}', "");
Expect(0, 66518, '\P{^Sc=	 XPEO}', "");
Error('\p{Is_Script=:=__old_persian}');
Error('\P{Is_Script=:=__old_persian}');
Expect(1, 66517, '\p{Is_Script=oldpersian}', "");
Expect(0, 66517, '\p{^Is_Script=oldpersian}', "");
Expect(0, 66517, '\P{Is_Script=oldpersian}', "");
Expect(1, 66517, '\P{^Is_Script=oldpersian}', "");
Expect(0, 66518, '\p{Is_Script=oldpersian}', "");
Expect(1, 66518, '\p{^Is_Script=oldpersian}', "");
Expect(1, 66518, '\P{Is_Script=oldpersian}', "");
Expect(0, 66518, '\P{^Is_Script=oldpersian}', "");
Expect(1, 66517, '\p{Is_Script=	-OLD_persian}', "");
Expect(0, 66517, '\p{^Is_Script=	-OLD_persian}', "");
Expect(0, 66517, '\P{Is_Script=	-OLD_persian}', "");
Expect(1, 66517, '\P{^Is_Script=	-OLD_persian}', "");
Expect(0, 66518, '\p{Is_Script=	-OLD_persian}', "");
Expect(1, 66518, '\p{^Is_Script=	-OLD_persian}', "");
Expect(1, 66518, '\P{Is_Script=	-OLD_persian}', "");
Expect(0, 66518, '\P{^Is_Script=	-OLD_persian}', "");
Error('\p{Is_Sc=/a/-_xpeo}');
Error('\P{Is_Sc=/a/-_xpeo}');
Expect(1, 66517, '\p{Is_Sc=xpeo}', "");
Expect(0, 66517, '\p{^Is_Sc=xpeo}', "");
Expect(0, 66517, '\P{Is_Sc=xpeo}', "");
Expect(1, 66517, '\P{^Is_Sc=xpeo}', "");
Expect(0, 66518, '\p{Is_Sc=xpeo}', "");
Expect(1, 66518, '\p{^Is_Sc=xpeo}', "");
Expect(1, 66518, '\P{Is_Sc=xpeo}', "");
Expect(0, 66518, '\P{^Is_Sc=xpeo}', "");
Expect(1, 66517, '\p{Is_Sc=-_Xpeo}', "");
Expect(0, 66517, '\p{^Is_Sc=-_Xpeo}', "");
Expect(0, 66517, '\P{Is_Sc=-_Xpeo}', "");
Expect(1, 66517, '\P{^Is_Sc=-_Xpeo}', "");
Expect(0, 66518, '\p{Is_Sc=-_Xpeo}', "");
Expect(1, 66518, '\p{^Is_Sc=-_Xpeo}', "");
Expect(1, 66518, '\P{Is_Sc=-_Xpeo}', "");
Expect(0, 66518, '\P{^Is_Sc=-_Xpeo}', "");
Error('\p{Script=:=CUNEIFORM}');
Error('\P{Script=:=CUNEIFORM}');
Expect(1, 74867, '\p{Script=cuneiform}', "");
Expect(0, 74867, '\p{^Script=cuneiform}', "");
Expect(0, 74867, '\P{Script=cuneiform}', "");
Expect(1, 74867, '\P{^Script=cuneiform}', "");
Expect(0, 74868, '\p{Script=cuneiform}', "");
Expect(1, 74868, '\p{^Script=cuneiform}', "");
Expect(1, 74868, '\P{Script=cuneiform}', "");
Expect(0, 74868, '\P{^Script=cuneiform}', "");
Expect(1, 74867, '\p{Script=	cuneiform}', "");
Expect(0, 74867, '\p{^Script=	cuneiform}', "");
Expect(0, 74867, '\P{Script=	cuneiform}', "");
Expect(1, 74867, '\P{^Script=	cuneiform}', "");
Expect(0, 74868, '\p{Script=	cuneiform}', "");
Expect(1, 74868, '\p{^Script=	cuneiform}', "");
Expect(1, 74868, '\P{Script=	cuneiform}', "");
Expect(0, 74868, '\P{^Script=	cuneiform}', "");
Error('\p{Sc=:=xsux}');
Error('\P{Sc=:=xsux}');
Expect(1, 74867, '\p{Sc=xsux}', "");
Expect(0, 74867, '\p{^Sc=xsux}', "");
Expect(0, 74867, '\P{Sc=xsux}', "");
Expect(1, 74867, '\P{^Sc=xsux}', "");
Expect(0, 74868, '\p{Sc=xsux}', "");
Expect(1, 74868, '\p{^Sc=xsux}', "");
Expect(1, 74868, '\P{Sc=xsux}', "");
Expect(0, 74868, '\P{^Sc=xsux}', "");
Expect(1, 74867, '\p{Sc=	XSUX}', "");
Expect(0, 74867, '\p{^Sc=	XSUX}', "");
Expect(0, 74867, '\P{Sc=	XSUX}', "");
Expect(1, 74867, '\P{^Sc=	XSUX}', "");
Expect(0, 74868, '\p{Sc=	XSUX}', "");
Expect(1, 74868, '\p{^Sc=	XSUX}', "");
Expect(1, 74868, '\P{Sc=	XSUX}', "");
Expect(0, 74868, '\P{^Sc=	XSUX}', "");
Error('\p{Is_Script=		cuneiform:=}');
Error('\P{Is_Script=		cuneiform:=}');
Expect(1, 74867, '\p{Is_Script=cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script=cuneiform}', "");
Expect(0, 74867, '\P{Is_Script=cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script=cuneiform}', "");
Expect(0, 74868, '\p{Is_Script=cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script=cuneiform}', "");
Expect(1, 74868, '\P{Is_Script=cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script=cuneiform}', "");
Expect(1, 74867, '\p{Is_Script= _Cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script= _Cuneiform}', "");
Expect(0, 74867, '\P{Is_Script= _Cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script= _Cuneiform}', "");
Expect(0, 74868, '\p{Is_Script= _Cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script= _Cuneiform}', "");
Expect(1, 74868, '\P{Is_Script= _Cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script= _Cuneiform}', "");
Error('\p{Is_Sc=	-XSUX:=}');
Error('\P{Is_Sc=	-XSUX:=}');
Expect(1, 74867, '\p{Is_Sc=xsux}', "");
Expect(0, 74867, '\p{^Is_Sc=xsux}', "");
Expect(0, 74867, '\P{Is_Sc=xsux}', "");
Expect(1, 74867, '\P{^Is_Sc=xsux}', "");
Expect(0, 74868, '\p{Is_Sc=xsux}', "");
Expect(1, 74868, '\p{^Is_Sc=xsux}', "");
Expect(1, 74868, '\P{Is_Sc=xsux}', "");
Expect(0, 74868, '\P{^Is_Sc=xsux}', "");
Expect(1, 74867, '\p{Is_Sc: -xsux}', "");
Expect(0, 74867, '\p{^Is_Sc: -xsux}', "");
Expect(0, 74867, '\P{Is_Sc: -xsux}', "");
Expect(1, 74867, '\P{^Is_Sc: -xsux}', "");
Expect(0, 74868, '\p{Is_Sc: -xsux}', "");
Expect(1, 74868, '\p{^Is_Sc: -xsux}', "");
Expect(1, 74868, '\P{Is_Sc: -xsux}', "");
Expect(0, 74868, '\P{^Is_Sc: -xsux}', "");
Error('\p{Script=	Yi/a/}');
Error('\P{Script=	Yi/a/}');
Expect(1, 42182, '\p{Script=yi}', "");
Expect(0, 42182, '\p{^Script=yi}', "");
Expect(0, 42182, '\P{Script=yi}', "");
Expect(1, 42182, '\P{^Script=yi}', "");
Expect(0, 42183, '\p{Script=yi}', "");
Expect(1, 42183, '\p{^Script=yi}', "");
Expect(1, 42183, '\P{Script=yi}', "");
Expect(0, 42183, '\P{^Script=yi}', "");
Expect(1, 42182, '\p{Script=Yi}', "");
Expect(0, 42182, '\p{^Script=Yi}', "");
Expect(0, 42182, '\P{Script=Yi}', "");
Expect(1, 42182, '\P{^Script=Yi}', "");
Expect(0, 42183, '\p{Script=Yi}', "");
Expect(1, 42183, '\p{^Script=Yi}', "");
Expect(1, 42183, '\P{Script=Yi}', "");
Expect(0, 42183, '\P{^Script=Yi}', "");
Error('\p{Sc=/a/	 YIII}');
Error('\P{Sc=/a/	 YIII}');
Expect(1, 42182, '\p{Sc=yiii}', "");
Expect(0, 42182, '\p{^Sc=yiii}', "");
Expect(0, 42182, '\P{Sc=yiii}', "");
Expect(1, 42182, '\P{^Sc=yiii}', "");
Expect(0, 42183, '\p{Sc=yiii}', "");
Expect(1, 42183, '\p{^Sc=yiii}', "");
Expect(1, 42183, '\P{Sc=yiii}', "");
Expect(0, 42183, '\P{^Sc=yiii}', "");
Expect(1, 42182, '\p{Sc=	Yiii}', "");
Expect(0, 42182, '\p{^Sc=	Yiii}', "");
Expect(0, 42182, '\P{Sc=	Yiii}', "");
Expect(1, 42182, '\P{^Sc=	Yiii}', "");
Expect(0, 42183, '\p{Sc=	Yiii}', "");
Expect(1, 42183, '\p{^Sc=	Yiii}', "");
Expect(1, 42183, '\P{Sc=	Yiii}', "");
Expect(0, 42183, '\P{^Sc=	Yiii}', "");
Error('\p{Is_Script= /a/Yi}');
Error('\P{Is_Script= /a/Yi}');
Expect(1, 42182, '\p{Is_Script=yi}', "");
Expect(0, 42182, '\p{^Is_Script=yi}', "");
Expect(0, 42182, '\P{Is_Script=yi}', "");
Expect(1, 42182, '\P{^Is_Script=yi}', "");
Expect(0, 42183, '\p{Is_Script=yi}', "");
Expect(1, 42183, '\p{^Is_Script=yi}', "");
Expect(1, 42183, '\P{Is_Script=yi}', "");
Expect(0, 42183, '\P{^Is_Script=yi}', "");
Expect(1, 42182, '\p{Is_Script=	Yi}', "");
Expect(0, 42182, '\p{^Is_Script=	Yi}', "");
Expect(0, 42182, '\P{Is_Script=	Yi}', "");
Expect(1, 42182, '\P{^Is_Script=	Yi}', "");
Expect(0, 42183, '\p{Is_Script=	Yi}', "");
Expect(1, 42183, '\p{^Is_Script=	Yi}', "");
Expect(1, 42183, '\P{Is_Script=	Yi}', "");
Expect(0, 42183, '\P{^Is_Script=	Yi}', "");
Error('\p{Is_Sc=	/a/YIII}');
Error('\P{Is_Sc=	/a/YIII}');
Expect(1, 42182, '\p{Is_Sc=yiii}', "");
Expect(0, 42182, '\p{^Is_Sc=yiii}', "");
Expect(0, 42182, '\P{Is_Sc=yiii}', "");
Expect(1, 42182, '\P{^Is_Sc=yiii}', "");
Expect(0, 42183, '\p{Is_Sc=yiii}', "");
Expect(1, 42183, '\p{^Is_Sc=yiii}', "");
Expect(1, 42183, '\P{Is_Sc=yiii}', "");
Expect(0, 42183, '\P{^Is_Sc=yiii}', "");
Expect(1, 42182, '\p{Is_Sc=  yiii}', "");
Expect(0, 42182, '\p{^Is_Sc=  yiii}', "");
Expect(0, 42182, '\P{Is_Sc=  yiii}', "");
Expect(1, 42182, '\P{^Is_Sc=  yiii}', "");
Expect(0, 42183, '\p{Is_Sc=  yiii}', "");
Expect(1, 42183, '\p{^Is_Sc=  yiii}', "");
Expect(1, 42183, '\P{Is_Sc=  yiii}', "");
Expect(0, 42183, '\P{^Is_Sc=  yiii}', "");
Error('\p{Script=/a/ _Inherited}');
Error('\P{Script=/a/ _Inherited}');
Expect(1, 917999, '\p{Script:   inherited}', "");
Expect(0, 917999, '\p{^Script:   inherited}', "");
Expect(0, 917999, '\P{Script:   inherited}', "");
Expect(1, 917999, '\P{^Script:   inherited}', "");
Expect(0, 918000, '\p{Script:   inherited}', "");
Expect(1, 918000, '\p{^Script:   inherited}', "");
Expect(1, 918000, '\P{Script:   inherited}', "");
Expect(0, 918000, '\P{^Script:   inherited}', "");
Expect(1, 917999, '\p{Script=	INHERITED}', "");
Expect(0, 917999, '\p{^Script=	INHERITED}', "");
Expect(0, 917999, '\P{Script=	INHERITED}', "");
Expect(1, 917999, '\P{^Script=	INHERITED}', "");
Expect(0, 918000, '\p{Script=	INHERITED}', "");
Expect(1, 918000, '\p{^Script=	INHERITED}', "");
Expect(1, 918000, '\P{Script=	INHERITED}', "");
Expect(0, 918000, '\P{^Script=	INHERITED}', "");
Error('\p{Sc:			ZINH/a/}');
Error('\P{Sc:			ZINH/a/}');
Expect(1, 917999, '\p{Sc=zinh}', "");
Expect(0, 917999, '\p{^Sc=zinh}', "");
Expect(0, 917999, '\P{Sc=zinh}', "");
Expect(1, 917999, '\P{^Sc=zinh}', "");
Expect(0, 918000, '\p{Sc=zinh}', "");
Expect(1, 918000, '\p{^Sc=zinh}', "");
Expect(1, 918000, '\P{Sc=zinh}', "");
Expect(0, 918000, '\P{^Sc=zinh}', "");
Expect(1, 917999, '\p{Sc=	Zinh}', "");
Expect(0, 917999, '\p{^Sc=	Zinh}', "");
Expect(0, 917999, '\P{Sc=	Zinh}', "");
Expect(1, 917999, '\P{^Sc=	Zinh}', "");
Expect(0, 918000, '\p{Sc=	Zinh}', "");
Expect(1, 918000, '\p{^Sc=	Zinh}', "");
Expect(1, 918000, '\P{Sc=	Zinh}', "");
Expect(0, 918000, '\P{^Sc=	Zinh}', "");
Error('\p{Is_Script=:= _Qaai}');
Error('\P{Is_Script=:= _Qaai}');
Expect(1, 917999, '\p{Is_Script=qaai}', "");
Expect(0, 917999, '\p{^Is_Script=qaai}', "");
Expect(0, 917999, '\P{Is_Script=qaai}', "");
Expect(1, 917999, '\P{^Is_Script=qaai}', "");
Expect(0, 918000, '\p{Is_Script=qaai}', "");
Expect(1, 918000, '\p{^Is_Script=qaai}', "");
Expect(1, 918000, '\P{Is_Script=qaai}', "");
Expect(0, 918000, '\P{^Is_Script=qaai}', "");
Expect(1, 917999, '\p{Is_Script=-Qaai}', "");
Expect(0, 917999, '\p{^Is_Script=-Qaai}', "");
Expect(0, 917999, '\P{Is_Script=-Qaai}', "");
Expect(1, 917999, '\P{^Is_Script=-Qaai}', "");
Expect(0, 918000, '\p{Is_Script=-Qaai}', "");
Expect(1, 918000, '\p{^Is_Script=-Qaai}', "");
Expect(1, 918000, '\P{Is_Script=-Qaai}', "");
Expect(0, 918000, '\P{^Is_Script=-Qaai}', "");
Error('\p{Is_Sc=-/a/INHERITED}');
Error('\P{Is_Sc=-/a/INHERITED}');
Expect(1, 917999, '\p{Is_Sc=inherited}', "");
Expect(0, 917999, '\p{^Is_Sc=inherited}', "");
Expect(0, 917999, '\P{Is_Sc=inherited}', "");
Expect(1, 917999, '\P{^Is_Sc=inherited}', "");
Expect(0, 918000, '\p{Is_Sc=inherited}', "");
Expect(1, 918000, '\p{^Is_Sc=inherited}', "");
Expect(1, 918000, '\P{Is_Sc=inherited}', "");
Expect(0, 918000, '\P{^Is_Sc=inherited}', "");
Expect(1, 917999, '\p{Is_Sc=  INHERITED}', "");
Expect(0, 917999, '\p{^Is_Sc=  INHERITED}', "");
Expect(0, 917999, '\P{Is_Sc=  INHERITED}', "");
Expect(1, 917999, '\P{^Is_Sc=  INHERITED}', "");
Expect(0, 918000, '\p{Is_Sc=  INHERITED}', "");
Expect(1, 918000, '\p{^Is_Sc=  INHERITED}', "");
Expect(1, 918000, '\P{Is_Sc=  INHERITED}', "");
Expect(0, 918000, '\P{^Is_Sc=  INHERITED}', "");
Error('\p{Script:	:= _Common}');
Error('\P{Script:	:= _Common}');
Expect(1, 917631, '\p{Script=common}', "");
Expect(0, 917631, '\p{^Script=common}', "");
Expect(0, 917631, '\P{Script=common}', "");
Expect(1, 917631, '\P{^Script=common}', "");
Expect(0, 917632, '\p{Script=common}', "");
Expect(1, 917632, '\p{^Script=common}', "");
Expect(1, 917632, '\P{Script=common}', "");
Expect(0, 917632, '\P{^Script=common}', "");
Expect(1, 917631, '\p{Script=COMMON}', "");
Expect(0, 917631, '\p{^Script=COMMON}', "");
Expect(0, 917631, '\P{Script=COMMON}', "");
Expect(1, 917631, '\P{^Script=COMMON}', "");
Expect(0, 917632, '\p{Script=COMMON}', "");
Expect(1, 917632, '\p{^Script=COMMON}', "");
Expect(1, 917632, '\P{Script=COMMON}', "");
Expect(0, 917632, '\P{^Script=COMMON}', "");
Error('\p{Sc=/a/Zyyy}');
Error('\P{Sc=/a/Zyyy}');
Expect(1, 917631, '\p{Sc=zyyy}', "");
Expect(0, 917631, '\p{^Sc=zyyy}', "");
Expect(0, 917631, '\P{Sc=zyyy}', "");
Expect(1, 917631, '\P{^Sc=zyyy}', "");
Expect(0, 917632, '\p{Sc=zyyy}', "");
Expect(1, 917632, '\p{^Sc=zyyy}', "");
Expect(1, 917632, '\P{Sc=zyyy}', "");
Expect(0, 917632, '\P{^Sc=zyyy}', "");
Expect(1, 917631, '\p{Sc=- Zyyy}', "");
Expect(0, 917631, '\p{^Sc=- Zyyy}', "");
Expect(0, 917631, '\P{Sc=- Zyyy}', "");
Expect(1, 917631, '\P{^Sc=- Zyyy}', "");
Expect(0, 917632, '\p{Sc=- Zyyy}', "");
Expect(1, 917632, '\p{^Sc=- Zyyy}', "");
Expect(1, 917632, '\P{Sc=- Zyyy}', "");
Expect(0, 917632, '\P{^Sc=- Zyyy}', "");
Error('\p{Is_Script: -:=Common}');
Error('\P{Is_Script: -:=Common}');
Expect(1, 917631, '\p{Is_Script=common}', "");
Expect(0, 917631, '\p{^Is_Script=common}', "");
Expect(0, 917631, '\P{Is_Script=common}', "");
Expect(1, 917631, '\P{^Is_Script=common}', "");
Expect(0, 917632, '\p{Is_Script=common}', "");
Expect(1, 917632, '\p{^Is_Script=common}', "");
Expect(1, 917632, '\P{Is_Script=common}', "");
Expect(0, 917632, '\P{^Is_Script=common}', "");
Expect(1, 917631, '\p{Is_Script=-Common}', "");
Expect(0, 917631, '\p{^Is_Script=-Common}', "");
Expect(0, 917631, '\P{Is_Script=-Common}', "");
Expect(1, 917631, '\P{^Is_Script=-Common}', "");
Expect(0, 917632, '\p{Is_Script=-Common}', "");
Expect(1, 917632, '\p{^Is_Script=-Common}', "");
Expect(1, 917632, '\P{Is_Script=-Common}', "");
Expect(0, 917632, '\P{^Is_Script=-Common}', "");
Error('\p{Is_Sc=:= Zyyy}');
Error('\P{Is_Sc=:= Zyyy}');
Expect(1, 917631, '\p{Is_Sc=zyyy}', "");
Expect(0, 917631, '\p{^Is_Sc=zyyy}', "");
Expect(0, 917631, '\P{Is_Sc=zyyy}', "");
Expect(1, 917631, '\P{^Is_Sc=zyyy}', "");
Expect(0, 917632, '\p{Is_Sc=zyyy}', "");
Expect(1, 917632, '\p{^Is_Sc=zyyy}', "");
Expect(1, 917632, '\P{Is_Sc=zyyy}', "");
Expect(0, 917632, '\P{^Is_Sc=zyyy}', "");
Expect(1, 917631, '\p{Is_Sc=--Zyyy}', "");
Expect(0, 917631, '\p{^Is_Sc=--Zyyy}', "");
Expect(0, 917631, '\P{Is_Sc=--Zyyy}', "");
Expect(1, 917631, '\P{^Is_Sc=--Zyyy}', "");
Expect(0, 917632, '\p{Is_Sc=--Zyyy}', "");
Expect(1, 917632, '\p{^Is_Sc=--Zyyy}', "");
Expect(1, 917632, '\P{Is_Sc=--Zyyy}', "");
Expect(0, 917632, '\P{^Is_Sc=--Zyyy}', "");
Error('\p{Script=	UNKNOWN:=}');
Error('\P{Script=	UNKNOWN:=}');
Expect(1, 918000, '\p{Script=unknown}', "");
Expect(0, 918000, '\p{^Script=unknown}', "");
Expect(0, 918000, '\P{Script=unknown}', "");
Expect(1, 918000, '\P{^Script=unknown}', "");
Expect(0, 917999, '\p{Script=unknown}', "");
Expect(1, 917999, '\p{^Script=unknown}', "");
Expect(1, 917999, '\P{Script=unknown}', "");
Expect(0, 917999, '\P{^Script=unknown}', "");
Expect(1, 918000, '\p{Script= Unknown}', "");
Expect(0, 918000, '\p{^Script= Unknown}', "");
Expect(0, 918000, '\P{Script= Unknown}', "");
Expect(1, 918000, '\P{^Script= Unknown}', "");
Expect(0, 917999, '\p{Script= Unknown}', "");
Expect(1, 917999, '\p{^Script= Unknown}', "");
Expect(1, 917999, '\P{Script= Unknown}', "");
Expect(0, 917999, '\P{^Script= Unknown}', "");
Error('\p{Sc=	Zzzz/a/}');
Error('\P{Sc=	Zzzz/a/}');
Expect(1, 918000, '\p{Sc=zzzz}', "");
Expect(0, 918000, '\p{^Sc=zzzz}', "");
Expect(0, 918000, '\P{Sc=zzzz}', "");
Expect(1, 918000, '\P{^Sc=zzzz}', "");
Expect(0, 917999, '\p{Sc=zzzz}', "");
Expect(1, 917999, '\p{^Sc=zzzz}', "");
Expect(1, 917999, '\P{Sc=zzzz}', "");
Expect(0, 917999, '\P{^Sc=zzzz}', "");
Expect(1, 918000, '\p{Sc=		zzzz}', "");
Expect(0, 918000, '\p{^Sc=		zzzz}', "");
Expect(0, 918000, '\P{Sc=		zzzz}', "");
Expect(1, 918000, '\P{^Sc=		zzzz}', "");
Expect(0, 917999, '\p{Sc=		zzzz}', "");
Expect(1, 917999, '\p{^Sc=		zzzz}', "");
Expect(1, 917999, '\P{Sc=		zzzz}', "");
Expect(0, 917999, '\P{^Sc=		zzzz}', "");
Error('\p{Is_Script= Unknown:=}');
Error('\P{Is_Script= Unknown:=}');
Expect(1, 918000, '\p{Is_Script=unknown}', "");
Expect(0, 918000, '\p{^Is_Script=unknown}', "");
Expect(0, 918000, '\P{Is_Script=unknown}', "");
Expect(1, 918000, '\P{^Is_Script=unknown}', "");
Expect(0, 917999, '\p{Is_Script=unknown}', "");
Expect(1, 917999, '\p{^Is_Script=unknown}', "");
Expect(1, 917999, '\P{Is_Script=unknown}', "");
Expect(0, 917999, '\P{^Is_Script=unknown}', "");
Expect(1, 918000, '\p{Is_Script=	-unknown}', "");
Expect(0, 918000, '\p{^Is_Script=	-unknown}', "");
Expect(0, 918000, '\P{Is_Script=	-unknown}', "");
Expect(1, 918000, '\P{^Is_Script=	-unknown}', "");
Expect(0, 917999, '\p{Is_Script=	-unknown}', "");
Expect(1, 917999, '\p{^Is_Script=	-unknown}', "");
Expect(1, 917999, '\P{Is_Script=	-unknown}', "");
Expect(0, 917999, '\P{^Is_Script=	-unknown}', "");
Error('\p{Is_Sc= :=Zzzz}');
Error('\P{Is_Sc= :=Zzzz}');
Expect(1, 918000, '\p{Is_Sc=zzzz}', "");
Expect(0, 918000, '\p{^Is_Sc=zzzz}', "");
Expect(0, 918000, '\P{Is_Sc=zzzz}', "");
Expect(1, 918000, '\P{^Is_Sc=zzzz}', "");
Expect(0, 917999, '\p{Is_Sc=zzzz}', "");
Expect(1, 917999, '\p{^Is_Sc=zzzz}', "");
Expect(1, 917999, '\P{Is_Sc=zzzz}', "");
Expect(0, 917999, '\P{^Is_Sc=zzzz}', "");
Expect(1, 918000, '\p{Is_Sc=	 ZZZZ}', "");
Expect(0, 918000, '\p{^Is_Sc=	 ZZZZ}', "");
Expect(0, 918000, '\P{Is_Sc=	 ZZZZ}', "");
Expect(1, 918000, '\P{^Is_Sc=	 ZZZZ}', "");
Expect(0, 917999, '\p{Is_Sc=	 ZZZZ}', "");
Expect(1, 917999, '\p{^Is_Sc=	 ZZZZ}', "");
Expect(1, 917999, '\P{Is_Sc=	 ZZZZ}', "");
Expect(0, 917999, '\P{^Is_Sc=	 ZZZZ}', "");
Error('\p{Script_Extensions=--Arabic:=}');
Error('\P{Script_Extensions=--Arabic:=}');
Expect(1, 126705, '\p{Script_Extensions=arabic}', "");
Expect(0, 126705, '\p{^Script_Extensions=arabic}', "");
Expect(0, 126705, '\P{Script_Extensions=arabic}', "");
Expect(1, 126705, '\P{^Script_Extensions=arabic}', "");
Expect(0, 126706, '\p{Script_Extensions=arabic}', "");
Expect(1, 126706, '\p{^Script_Extensions=arabic}', "");
Expect(1, 126706, '\P{Script_Extensions=arabic}', "");
Expect(0, 126706, '\P{^Script_Extensions=arabic}', "");
Expect(1, 126705, '\p{Script_Extensions:_-ARABIC}', "");
Expect(0, 126705, '\p{^Script_Extensions:_-ARABIC}', "");
Expect(0, 126705, '\P{Script_Extensions:_-ARABIC}', "");
Expect(1, 126705, '\P{^Script_Extensions:_-ARABIC}', "");
Expect(0, 126706, '\p{Script_Extensions:_-ARABIC}', "");
Expect(1, 126706, '\p{^Script_Extensions:_-ARABIC}', "");
Expect(1, 126706, '\P{Script_Extensions:_-ARABIC}', "");
Expect(0, 126706, '\P{^Script_Extensions:_-ARABIC}', "");
Error('\p{Scx=-_arab:=}');
Error('\P{Scx=-_arab:=}');
Expect(1, 126705, '\p{Scx=arab}', "");
Expect(0, 126705, '\p{^Scx=arab}', "");
Expect(0, 126705, '\P{Scx=arab}', "");
Expect(1, 126705, '\P{^Scx=arab}', "");
Expect(0, 126706, '\p{Scx=arab}', "");
Expect(1, 126706, '\p{^Scx=arab}', "");
Expect(1, 126706, '\P{Scx=arab}', "");
Expect(0, 126706, '\P{^Scx=arab}', "");
Expect(1, 126705, '\p{Scx=	ARAB}', "");
Expect(0, 126705, '\p{^Scx=	ARAB}', "");
Expect(0, 126705, '\P{Scx=	ARAB}', "");
Expect(1, 126705, '\P{^Scx=	ARAB}', "");
Expect(0, 126706, '\p{Scx=	ARAB}', "");
Expect(1, 126706, '\p{^Scx=	ARAB}', "");
Expect(1, 126706, '\P{Scx=	ARAB}', "");
Expect(0, 126706, '\P{^Scx=	ARAB}', "");
Error('\p{Is_Script_Extensions=	-Arabic/a/}');
Error('\P{Is_Script_Extensions=	-Arabic/a/}');
Expect(1, 126705, '\p{Is_Script_Extensions=arabic}', "");
Expect(0, 126705, '\p{^Is_Script_Extensions=arabic}', "");
Expect(0, 126705, '\P{Is_Script_Extensions=arabic}', "");
Expect(1, 126705, '\P{^Is_Script_Extensions=arabic}', "");
Expect(0, 126706, '\p{Is_Script_Extensions=arabic}', "");
Expect(1, 126706, '\p{^Is_Script_Extensions=arabic}', "");
Expect(1, 126706, '\P{Is_Script_Extensions=arabic}', "");
Expect(0, 126706, '\P{^Is_Script_Extensions=arabic}', "");
Expect(1, 126705, '\p{Is_Script_Extensions=	 arabic}', "");
Expect(0, 126705, '\p{^Is_Script_Extensions=	 arabic}', "");
Expect(0, 126705, '\P{Is_Script_Extensions=	 arabic}', "");
Expect(1, 126705, '\P{^Is_Script_Extensions=	 arabic}', "");
Expect(0, 126706, '\p{Is_Script_Extensions=	 arabic}', "");
Expect(1, 126706, '\p{^Is_Script_Extensions=	 arabic}', "");
Expect(1, 126706, '\P{Is_Script_Extensions=	 arabic}', "");
Expect(0, 126706, '\P{^Is_Script_Extensions=	 arabic}', "");
Error('\p{Is_Scx= 	arab:=}');
Error('\P{Is_Scx= 	arab:=}');
Expect(1, 126705, '\p{Is_Scx=arab}', "");
Expect(0, 126705, '\p{^Is_Scx=arab}', "");
Expect(0, 126705, '\P{Is_Scx=arab}', "");
Expect(1, 126705, '\P{^Is_Scx=arab}', "");
Expect(0, 126706, '\p{Is_Scx=arab}', "");
Expect(1, 126706, '\p{^Is_Scx=arab}', "");
Expect(1, 126706, '\P{Is_Scx=arab}', "");
Expect(0, 126706, '\P{^Is_Scx=arab}', "");
Expect(1, 126705, '\p{Is_Scx=  Arab}', "");
Expect(0, 126705, '\p{^Is_Scx=  Arab}', "");
Expect(0, 126705, '\P{Is_Scx=  Arab}', "");
Expect(1, 126705, '\P{^Is_Scx=  Arab}', "");
Expect(0, 126706, '\p{Is_Scx=  Arab}', "");
Expect(1, 126706, '\p{^Is_Scx=  Arab}', "");
Expect(1, 126706, '\P{Is_Scx=  Arab}', "");
Expect(0, 126706, '\P{^Is_Scx=  Arab}', "");
Error('\p{Script_Extensions=:=-imperial_Aramaic}');
Error('\P{Script_Extensions=:=-imperial_Aramaic}');
Expect(1, 67679, '\p{Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\p{^Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\P{Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\P{^Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\p{Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\p{^Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\P{Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\P{^Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\p{Script_Extensions: -Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Script_Extensions: -Imperial_Aramaic}', "");
Expect(0, 67679, '\P{Script_Extensions: -Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Script_Extensions: -Imperial_Aramaic}', "");
Expect(0, 67680, '\p{Script_Extensions: -Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Script_Extensions: -Imperial_Aramaic}', "");
Expect(1, 67680, '\P{Script_Extensions: -Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Script_Extensions: -Imperial_Aramaic}', "");
Error('\p{Scx=:=	 Armi}');
Error('\P{Scx=:=	 Armi}');
Expect(1, 67679, '\p{Scx=armi}', "");
Expect(0, 67679, '\p{^Scx=armi}', "");
Expect(0, 67679, '\P{Scx=armi}', "");
Expect(1, 67679, '\P{^Scx=armi}', "");
Expect(0, 67680, '\p{Scx=armi}', "");
Expect(1, 67680, '\p{^Scx=armi}', "");
Expect(1, 67680, '\P{Scx=armi}', "");
Expect(0, 67680, '\P{^Scx=armi}', "");
Expect(1, 67679, '\p{Scx= 	armi}', "");
Expect(0, 67679, '\p{^Scx= 	armi}', "");
Expect(0, 67679, '\P{Scx= 	armi}', "");
Expect(1, 67679, '\P{^Scx= 	armi}', "");
Expect(0, 67680, '\p{Scx= 	armi}', "");
Expect(1, 67680, '\p{^Scx= 	armi}', "");
Expect(1, 67680, '\P{Scx= 	armi}', "");
Expect(0, 67680, '\P{^Scx= 	armi}', "");
Error('\p{Is_Script_Extensions=:=_-IMPERIAL_Aramaic}');
Error('\P{Is_Script_Extensions=:=_-IMPERIAL_Aramaic}');
Expect(1, 67679, '\p{Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\p{^Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67679, '\P{Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\P{^Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\p{Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\p{^Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67680, '\P{Is_Script_Extensions=imperialaramaic}', "");
Expect(0, 67680, '\P{^Is_Script_Extensions=imperialaramaic}', "");
Expect(1, 67679, '\p{Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(0, 67679, '\p{^Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(0, 67679, '\P{Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(1, 67679, '\P{^Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(0, 67680, '\p{Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(1, 67680, '\p{^Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(1, 67680, '\P{Is_Script_Extensions= 	Imperial_Aramaic}', "");
Expect(0, 67680, '\P{^Is_Script_Extensions= 	Imperial_Aramaic}', "");
Error('\p{Is_Scx=	Armi/a/}');
Error('\P{Is_Scx=	Armi/a/}');
Expect(1, 67679, '\p{Is_Scx=armi}', "");
Expect(0, 67679, '\p{^Is_Scx=armi}', "");
Expect(0, 67679, '\P{Is_Scx=armi}', "");
Expect(1, 67679, '\P{^Is_Scx=armi}', "");
Expect(0, 67680, '\p{Is_Scx=armi}', "");
Expect(1, 67680, '\p{^Is_Scx=armi}', "");
Expect(1, 67680, '\P{Is_Scx=armi}', "");
Expect(0, 67680, '\P{^Is_Scx=armi}', "");
Expect(1, 67679, '\p{Is_Scx=- Armi}', "");
Expect(0, 67679, '\p{^Is_Scx=- Armi}', "");
Expect(0, 67679, '\P{Is_Scx=- Armi}', "");
Expect(1, 67679, '\P{^Is_Scx=- Armi}', "");
Expect(0, 67680, '\p{Is_Scx=- Armi}', "");
Expect(1, 67680, '\p{^Is_Scx=- Armi}', "");
Expect(1, 67680, '\P{Is_Scx=- Armi}', "");
Expect(0, 67680, '\P{^Is_Scx=- Armi}', "");
Error('\p{Script_Extensions=	:=armenian}');
Error('\P{Script_Extensions=	:=armenian}');
Expect(1, 64279, '\p{Script_Extensions=armenian}', "");
Expect(0, 64279, '\p{^Script_Extensions=armenian}', "");
Expect(0, 64279, '\P{Script_Extensions=armenian}', "");
Expect(1, 64279, '\P{^Script_Extensions=armenian}', "");
Expect(0, 64280, '\p{Script_Extensions=armenian}', "");
Expect(1, 64280, '\p{^Script_Extensions=armenian}', "");
Expect(1, 64280, '\P{Script_Extensions=armenian}', "");
Expect(0, 64280, '\P{^Script_Extensions=armenian}', "");
Expect(1, 64279, '\p{Script_Extensions=	-Armenian}', "");
Expect(0, 64279, '\p{^Script_Extensions=	-Armenian}', "");
Expect(0, 64279, '\P{Script_Extensions=	-Armenian}', "");
Expect(1, 64279, '\P{^Script_Extensions=	-Armenian}', "");
Expect(0, 64280, '\p{Script_Extensions=	-Armenian}', "");
Expect(1, 64280, '\p{^Script_Extensions=	-Armenian}', "");
Expect(1, 64280, '\P{Script_Extensions=	-Armenian}', "");
Expect(0, 64280, '\P{^Script_Extensions=	-Armenian}', "");
Error('\p{Scx=	_ARMN:=}');
Error('\P{Scx=	_ARMN:=}');
Expect(1, 64279, '\p{Scx=armn}', "");
Expect(0, 64279, '\p{^Scx=armn}', "");
Expect(0, 64279, '\P{Scx=armn}', "");
Expect(1, 64279, '\P{^Scx=armn}', "");
Expect(0, 64280, '\p{Scx=armn}', "");
Expect(1, 64280, '\p{^Scx=armn}', "");
Expect(1, 64280, '\P{Scx=armn}', "");
Expect(0, 64280, '\P{^Scx=armn}', "");
Expect(1, 64279, '\p{Scx=	Armn}', "");
Expect(0, 64279, '\p{^Scx=	Armn}', "");
Expect(0, 64279, '\P{Scx=	Armn}', "");
Expect(1, 64279, '\P{^Scx=	Armn}', "");
Expect(0, 64280, '\p{Scx=	Armn}', "");
Expect(1, 64280, '\p{^Scx=	Armn}', "");
Expect(1, 64280, '\P{Scx=	Armn}', "");
Expect(0, 64280, '\P{^Scx=	Armn}', "");
Error('\p{Is_Script_Extensions=:=_ Armenian}');
Error('\P{Is_Script_Extensions=:=_ Armenian}');
Expect(1, 64279, '\p{Is_Script_Extensions=armenian}', "");
Expect(0, 64279, '\p{^Is_Script_Extensions=armenian}', "");
Expect(0, 64279, '\P{Is_Script_Extensions=armenian}', "");
Expect(1, 64279, '\P{^Is_Script_Extensions=armenian}', "");
Expect(0, 64280, '\p{Is_Script_Extensions=armenian}', "");
Expect(1, 64280, '\p{^Is_Script_Extensions=armenian}', "");
Expect(1, 64280, '\P{Is_Script_Extensions=armenian}', "");
Expect(0, 64280, '\P{^Is_Script_Extensions=armenian}', "");
Expect(1, 64279, '\p{Is_Script_Extensions=- Armenian}', "");
Expect(0, 64279, '\p{^Is_Script_Extensions=- Armenian}', "");
Expect(0, 64279, '\P{Is_Script_Extensions=- Armenian}', "");
Expect(1, 64279, '\P{^Is_Script_Extensions=- Armenian}', "");
Expect(0, 64280, '\p{Is_Script_Extensions=- Armenian}', "");
Expect(1, 64280, '\p{^Is_Script_Extensions=- Armenian}', "");
Expect(1, 64280, '\P{Is_Script_Extensions=- Armenian}', "");
Expect(0, 64280, '\P{^Is_Script_Extensions=- Armenian}', "");
Error('\p{Is_Scx=/a/	-Armn}');
Error('\P{Is_Scx=/a/	-Armn}');
Expect(1, 64279, '\p{Is_Scx=armn}', "");
Expect(0, 64279, '\p{^Is_Scx=armn}', "");
Expect(0, 64279, '\P{Is_Scx=armn}', "");
Expect(1, 64279, '\P{^Is_Scx=armn}', "");
Expect(0, 64280, '\p{Is_Scx=armn}', "");
Expect(1, 64280, '\p{^Is_Scx=armn}', "");
Expect(1, 64280, '\P{Is_Scx=armn}', "");
Expect(0, 64280, '\P{^Is_Scx=armn}', "");
Expect(1, 64279, '\p{Is_Scx=  Armn}', "");
Expect(0, 64279, '\p{^Is_Scx=  Armn}', "");
Expect(0, 64279, '\P{Is_Scx=  Armn}', "");
Expect(1, 64279, '\P{^Is_Scx=  Armn}', "");
Expect(0, 64280, '\p{Is_Scx=  Armn}', "");
Expect(1, 64280, '\p{^Is_Scx=  Armn}', "");
Expect(1, 64280, '\P{Is_Scx=  Armn}', "");
Expect(0, 64280, '\P{^Is_Scx=  Armn}', "");
Error('\p{Script_Extensions:		Avestan/a/}');
Error('\P{Script_Extensions:		Avestan/a/}');
Expect(1, 68415, '\p{Script_Extensions=avestan}', "");
Expect(0, 68415, '\p{^Script_Extensions=avestan}', "");
Expect(0, 68415, '\P{Script_Extensions=avestan}', "");
Expect(1, 68415, '\P{^Script_Extensions=avestan}', "");
Expect(0, 68416, '\p{Script_Extensions=avestan}', "");
Expect(1, 68416, '\p{^Script_Extensions=avestan}', "");
Expect(1, 68416, '\P{Script_Extensions=avestan}', "");
Expect(0, 68416, '\P{^Script_Extensions=avestan}', "");
Expect(1, 68415, '\p{Script_Extensions=_AVESTAN}', "");
Expect(0, 68415, '\p{^Script_Extensions=_AVESTAN}', "");
Expect(0, 68415, '\P{Script_Extensions=_AVESTAN}', "");
Expect(1, 68415, '\P{^Script_Extensions=_AVESTAN}', "");
Expect(0, 68416, '\p{Script_Extensions=_AVESTAN}', "");
Expect(1, 68416, '\p{^Script_Extensions=_AVESTAN}', "");
Expect(1, 68416, '\P{Script_Extensions=_AVESTAN}', "");
Expect(0, 68416, '\P{^Script_Extensions=_AVESTAN}', "");
Error('\p{Scx=_/a/avst}');
Error('\P{Scx=_/a/avst}');
Expect(1, 68415, '\p{Scx: avst}', "");
Expect(0, 68415, '\p{^Scx: avst}', "");
Expect(0, 68415, '\P{Scx: avst}', "");
Expect(1, 68415, '\P{^Scx: avst}', "");
Expect(0, 68416, '\p{Scx: avst}', "");
Expect(1, 68416, '\p{^Scx: avst}', "");
Expect(1, 68416, '\P{Scx: avst}', "");
Expect(0, 68416, '\P{^Scx: avst}', "");
Expect(1, 68415, '\p{Scx=_-Avst}', "");
Expect(0, 68415, '\p{^Scx=_-Avst}', "");
Expect(0, 68415, '\P{Scx=_-Avst}', "");
Expect(1, 68415, '\P{^Scx=_-Avst}', "");
Expect(0, 68416, '\p{Scx=_-Avst}', "");
Expect(1, 68416, '\p{^Scx=_-Avst}', "");
Expect(1, 68416, '\P{Scx=_-Avst}', "");
Expect(0, 68416, '\P{^Scx=_-Avst}', "");
Error('\p{Is_Script_Extensions=  AVESTAN:=}');
Error('\P{Is_Script_Extensions=  AVESTAN:=}');
Expect(1, 68415, '\p{Is_Script_Extensions=avestan}', "");
Expect(0, 68415, '\p{^Is_Script_Extensions=avestan}', "");
Expect(0, 68415, '\P{Is_Script_Extensions=avestan}', "");
Expect(1, 68415, '\P{^Is_Script_Extensions=avestan}', "");
Expect(0, 68416, '\p{Is_Script_Extensions=avestan}', "");
Expect(1, 68416, '\p{^Is_Script_Extensions=avestan}', "");
Expect(1, 68416, '\P{Is_Script_Extensions=avestan}', "");
Expect(0, 68416, '\P{^Is_Script_Extensions=avestan}', "");
Expect(1, 68415, '\p{Is_Script_Extensions=	Avestan}', "");
Expect(0, 68415, '\p{^Is_Script_Extensions=	Avestan}', "");
Expect(0, 68415, '\P{Is_Script_Extensions=	Avestan}', "");
Expect(1, 68415, '\P{^Is_Script_Extensions=	Avestan}', "");
Expect(0, 68416, '\p{Is_Script_Extensions=	Avestan}', "");
Expect(1, 68416, '\p{^Is_Script_Extensions=	Avestan}', "");
Expect(1, 68416, '\P{Is_Script_Extensions=	Avestan}', "");
Expect(0, 68416, '\P{^Is_Script_Extensions=	Avestan}', "");
Error('\p{Is_Scx=:=	Avst}');
Error('\P{Is_Scx=:=	Avst}');
Expect(1, 68415, '\p{Is_Scx=avst}', "");
Expect(0, 68415, '\p{^Is_Scx=avst}', "");
Expect(0, 68415, '\P{Is_Scx=avst}', "");
Expect(1, 68415, '\P{^Is_Scx=avst}', "");
Expect(0, 68416, '\p{Is_Scx=avst}', "");
Expect(1, 68416, '\p{^Is_Scx=avst}', "");
Expect(1, 68416, '\P{Is_Scx=avst}', "");
Expect(0, 68416, '\P{^Is_Scx=avst}', "");
Expect(1, 68415, '\p{Is_Scx=	_Avst}', "");
Expect(0, 68415, '\p{^Is_Scx=	_Avst}', "");
Expect(0, 68415, '\P{Is_Scx=	_Avst}', "");
Expect(1, 68415, '\P{^Is_Scx=	_Avst}', "");
Expect(0, 68416, '\p{Is_Scx=	_Avst}', "");
Expect(1, 68416, '\p{^Is_Scx=	_Avst}', "");
Expect(1, 68416, '\P{Is_Scx=	_Avst}', "");
Expect(0, 68416, '\P{^Is_Scx=	_Avst}', "");
Error('\p{Script_Extensions= _Balinese/a/}');
Error('\P{Script_Extensions= _Balinese/a/}');
Expect(1, 7036, '\p{Script_Extensions=balinese}', "");
Expect(0, 7036, '\p{^Script_Extensions=balinese}', "");
Expect(0, 7036, '\P{Script_Extensions=balinese}', "");
Expect(1, 7036, '\P{^Script_Extensions=balinese}', "");
Expect(0, 7037, '\p{Script_Extensions=balinese}', "");
Expect(1, 7037, '\p{^Script_Extensions=balinese}', "");
Expect(1, 7037, '\P{Script_Extensions=balinese}', "");
Expect(0, 7037, '\P{^Script_Extensions=balinese}', "");
Expect(1, 7036, '\p{Script_Extensions=Balinese}', "");
Expect(0, 7036, '\p{^Script_Extensions=Balinese}', "");
Expect(0, 7036, '\P{Script_Extensions=Balinese}', "");
Expect(1, 7036, '\P{^Script_Extensions=Balinese}', "");
Expect(0, 7037, '\p{Script_Extensions=Balinese}', "");
Expect(1, 7037, '\p{^Script_Extensions=Balinese}', "");
Expect(1, 7037, '\P{Script_Extensions=Balinese}', "");
Expect(0, 7037, '\P{^Script_Extensions=Balinese}', "");
Error('\p{Scx: := bali}');
Error('\P{Scx: := bali}');
Expect(1, 7036, '\p{Scx=bali}', "");
Expect(0, 7036, '\p{^Scx=bali}', "");
Expect(0, 7036, '\P{Scx=bali}', "");
Expect(1, 7036, '\P{^Scx=bali}', "");
Expect(0, 7037, '\p{Scx=bali}', "");
Expect(1, 7037, '\p{^Scx=bali}', "");
Expect(1, 7037, '\P{Scx=bali}', "");
Expect(0, 7037, '\P{^Scx=bali}', "");
Expect(1, 7036, '\p{Scx=__BALI}', "");
Expect(0, 7036, '\p{^Scx=__BALI}', "");
Expect(0, 7036, '\P{Scx=__BALI}', "");
Expect(1, 7036, '\P{^Scx=__BALI}', "");
Expect(0, 7037, '\p{Scx=__BALI}', "");
Expect(1, 7037, '\p{^Scx=__BALI}', "");
Expect(1, 7037, '\P{Scx=__BALI}', "");
Expect(0, 7037, '\P{^Scx=__BALI}', "");
Error('\p{Is_Script_Extensions=	BALINESE/a/}');
Error('\P{Is_Script_Extensions=	BALINESE/a/}');
Expect(1, 7036, '\p{Is_Script_Extensions=balinese}', "");
Expect(0, 7036, '\p{^Is_Script_Extensions=balinese}', "");
Expect(0, 7036, '\P{Is_Script_Extensions=balinese}', "");
Expect(1, 7036, '\P{^Is_Script_Extensions=balinese}', "");
Expect(0, 7037, '\p{Is_Script_Extensions=balinese}', "");
Expect(1, 7037, '\p{^Is_Script_Extensions=balinese}', "");
Expect(1, 7037, '\P{Is_Script_Extensions=balinese}', "");
Expect(0, 7037, '\P{^Is_Script_Extensions=balinese}', "");
Expect(1, 7036, '\p{Is_Script_Extensions=	 Balinese}', "");
Expect(0, 7036, '\p{^Is_Script_Extensions=	 Balinese}', "");
Expect(0, 7036, '\P{Is_Script_Extensions=	 Balinese}', "");
Expect(1, 7036, '\P{^Is_Script_Extensions=	 Balinese}', "");
Expect(0, 7037, '\p{Is_Script_Extensions=	 Balinese}', "");
Expect(1, 7037, '\p{^Is_Script_Extensions=	 Balinese}', "");
Expect(1, 7037, '\P{Is_Script_Extensions=	 Balinese}', "");
Expect(0, 7037, '\P{^Is_Script_Extensions=	 Balinese}', "");
Error('\p{Is_Scx=:=Bali}');
Error('\P{Is_Scx=:=Bali}');
Expect(1, 7036, '\p{Is_Scx=bali}', "");
Expect(0, 7036, '\p{^Is_Scx=bali}', "");
Expect(0, 7036, '\P{Is_Scx=bali}', "");
Expect(1, 7036, '\P{^Is_Scx=bali}', "");
Expect(0, 7037, '\p{Is_Scx=bali}', "");
Expect(1, 7037, '\p{^Is_Scx=bali}', "");
Expect(1, 7037, '\P{Is_Scx=bali}', "");
Expect(0, 7037, '\P{^Is_Scx=bali}', "");
Expect(1, 7036, '\p{Is_Scx=	-BALI}', "");
Expect(0, 7036, '\p{^Is_Scx=	-BALI}', "");
Expect(0, 7036, '\P{Is_Scx=	-BALI}', "");
Expect(1, 7036, '\P{^Is_Scx=	-BALI}', "");
Expect(0, 7037, '\p{Is_Scx=	-BALI}', "");
Expect(1, 7037, '\p{^Is_Scx=	-BALI}', "");
Expect(1, 7037, '\P{Is_Scx=	-BALI}', "");
Expect(0, 7037, '\P{^Is_Scx=	-BALI}', "");
Error('\p{Script_Extensions=:=	_Bamum}');
Error('\P{Script_Extensions=:=	_Bamum}');
Expect(1, 92728, '\p{Script_Extensions=bamum}', "");
Expect(0, 92728, '\p{^Script_Extensions=bamum}', "");
Expect(0, 92728, '\P{Script_Extensions=bamum}', "");
Expect(1, 92728, '\P{^Script_Extensions=bamum}', "");
Expect(0, 92729, '\p{Script_Extensions=bamum}', "");
Expect(1, 92729, '\p{^Script_Extensions=bamum}', "");
Expect(1, 92729, '\P{Script_Extensions=bamum}', "");
Expect(0, 92729, '\P{^Script_Extensions=bamum}', "");
Expect(1, 92728, '\p{Script_Extensions:	-BAMUM}', "");
Expect(0, 92728, '\p{^Script_Extensions:	-BAMUM}', "");
Expect(0, 92728, '\P{Script_Extensions:	-BAMUM}', "");
Expect(1, 92728, '\P{^Script_Extensions:	-BAMUM}', "");
Expect(0, 92729, '\p{Script_Extensions:	-BAMUM}', "");
Expect(1, 92729, '\p{^Script_Extensions:	-BAMUM}', "");
Expect(1, 92729, '\P{Script_Extensions:	-BAMUM}', "");
Expect(0, 92729, '\P{^Script_Extensions:	-BAMUM}', "");
Error('\p{Scx=/a/ 	bamu}');
Error('\P{Scx=/a/ 	bamu}');
Expect(1, 92728, '\p{Scx:bamu}', "");
Expect(0, 92728, '\p{^Scx:bamu}', "");
Expect(0, 92728, '\P{Scx:bamu}', "");
Expect(1, 92728, '\P{^Scx:bamu}', "");
Expect(0, 92729, '\p{Scx:bamu}', "");
Expect(1, 92729, '\p{^Scx:bamu}', "");
Expect(1, 92729, '\P{Scx:bamu}', "");
Expect(0, 92729, '\P{^Scx:bamu}', "");
Expect(1, 92728, '\p{Scx=_-bamu}', "");
Expect(0, 92728, '\p{^Scx=_-bamu}', "");
Expect(0, 92728, '\P{Scx=_-bamu}', "");
Expect(1, 92728, '\P{^Scx=_-bamu}', "");
Expect(0, 92729, '\p{Scx=_-bamu}', "");
Expect(1, 92729, '\p{^Scx=_-bamu}', "");
Expect(1, 92729, '\P{Scx=_-bamu}', "");
Expect(0, 92729, '\P{^Scx=_-bamu}', "");
Error('\p{Is_Script_Extensions=_bamum:=}');
Error('\P{Is_Script_Extensions=_bamum:=}');
Expect(1, 92728, '\p{Is_Script_Extensions:   bamum}', "");
Expect(0, 92728, '\p{^Is_Script_Extensions:   bamum}', "");
Expect(0, 92728, '\P{Is_Script_Extensions:   bamum}', "");
Expect(1, 92728, '\P{^Is_Script_Extensions:   bamum}', "");
Expect(0, 92729, '\p{Is_Script_Extensions:   bamum}', "");
Expect(1, 92729, '\p{^Is_Script_Extensions:   bamum}', "");
Expect(1, 92729, '\P{Is_Script_Extensions:   bamum}', "");
Expect(0, 92729, '\P{^Is_Script_Extensions:   bamum}', "");
Expect(1, 92728, '\p{Is_Script_Extensions: 	_BAMUM}', "");
Expect(0, 92728, '\p{^Is_Script_Extensions: 	_BAMUM}', "");
Expect(0, 92728, '\P{Is_Script_Extensions: 	_BAMUM}', "");
Expect(1, 92728, '\P{^Is_Script_Extensions: 	_BAMUM}', "");
Expect(0, 92729, '\p{Is_Script_Extensions: 	_BAMUM}', "");
Expect(1, 92729, '\p{^Is_Script_Extensions: 	_BAMUM}', "");
Expect(1, 92729, '\P{Is_Script_Extensions: 	_BAMUM}', "");
Expect(0, 92729, '\P{^Is_Script_Extensions: 	_BAMUM}', "");
Error('\p{Is_Scx=_:=BAMU}');
Error('\P{Is_Scx=_:=BAMU}');
Expect(1, 92728, '\p{Is_Scx=bamu}', "");
Expect(0, 92728, '\p{^Is_Scx=bamu}', "");
Expect(0, 92728, '\P{Is_Scx=bamu}', "");
Expect(1, 92728, '\P{^Is_Scx=bamu}', "");
Expect(0, 92729, '\p{Is_Scx=bamu}', "");
Expect(1, 92729, '\p{^Is_Scx=bamu}', "");
Expect(1, 92729, '\P{Is_Scx=bamu}', "");
Expect(0, 92729, '\P{^Is_Scx=bamu}', "");
Expect(1, 92728, '\p{Is_Scx=-	BAMU}', "");
Expect(0, 92728, '\p{^Is_Scx=-	BAMU}', "");
Expect(0, 92728, '\P{Is_Scx=-	BAMU}', "");
Expect(1, 92728, '\P{^Is_Scx=-	BAMU}', "");
Expect(0, 92729, '\p{Is_Scx=-	BAMU}', "");
Expect(1, 92729, '\p{^Is_Scx=-	BAMU}', "");
Expect(1, 92729, '\P{Is_Scx=-	BAMU}', "");
Expect(0, 92729, '\P{^Is_Scx=-	BAMU}', "");
Error('\p{Script_Extensions= :=batak}');
Error('\P{Script_Extensions= :=batak}');
Expect(1, 7167, '\p{Script_Extensions:batak}', "");
Expect(0, 7167, '\p{^Script_Extensions:batak}', "");
Expect(0, 7167, '\P{Script_Extensions:batak}', "");
Expect(1, 7167, '\P{^Script_Extensions:batak}', "");
Expect(0, 7168, '\p{Script_Extensions:batak}', "");
Expect(1, 7168, '\p{^Script_Extensions:batak}', "");
Expect(1, 7168, '\P{Script_Extensions:batak}', "");
Expect(0, 7168, '\P{^Script_Extensions:batak}', "");
Expect(1, 7167, '\p{Script_Extensions=	BATAK}', "");
Expect(0, 7167, '\p{^Script_Extensions=	BATAK}', "");
Expect(0, 7167, '\P{Script_Extensions=	BATAK}', "");
Expect(1, 7167, '\P{^Script_Extensions=	BATAK}', "");
Expect(0, 7168, '\p{Script_Extensions=	BATAK}', "");
Expect(1, 7168, '\p{^Script_Extensions=	BATAK}', "");
Expect(1, 7168, '\P{Script_Extensions=	BATAK}', "");
Expect(0, 7168, '\P{^Script_Extensions=	BATAK}', "");
Error('\p{Scx=-:=Batk}');
Error('\P{Scx=-:=Batk}');
Expect(1, 7167, '\p{Scx:   batk}', "");
Expect(0, 7167, '\p{^Scx:   batk}', "");
Expect(0, 7167, '\P{Scx:   batk}', "");
Expect(1, 7167, '\P{^Scx:   batk}', "");
Expect(0, 7168, '\p{Scx:   batk}', "");
Expect(1, 7168, '\p{^Scx:   batk}', "");
Expect(1, 7168, '\P{Scx:   batk}', "");
Expect(0, 7168, '\P{^Scx:   batk}', "");
Expect(1, 7167, '\p{Scx: __batk}', "");
Expect(0, 7167, '\p{^Scx: __batk}', "");
Expect(0, 7167, '\P{Scx: __batk}', "");
Expect(1, 7167, '\P{^Scx: __batk}', "");
Expect(0, 7168, '\p{Scx: __batk}', "");
Expect(1, 7168, '\p{^Scx: __batk}', "");
Expect(1, 7168, '\P{Scx: __batk}', "");
Expect(0, 7168, '\P{^Scx: __batk}', "");
Error('\p{Is_Script_Extensions=:=batak}');
Error('\P{Is_Script_Extensions=:=batak}');
Expect(1, 7167, '\p{Is_Script_Extensions=batak}', "");
Expect(0, 7167, '\p{^Is_Script_Extensions=batak}', "");
Expect(0, 7167, '\P{Is_Script_Extensions=batak}', "");
Expect(1, 7167, '\P{^Is_Script_Extensions=batak}', "");
Expect(0, 7168, '\p{Is_Script_Extensions=batak}', "");
Expect(1, 7168, '\p{^Is_Script_Extensions=batak}', "");
Expect(1, 7168, '\P{Is_Script_Extensions=batak}', "");
Expect(0, 7168, '\P{^Is_Script_Extensions=batak}', "");
Expect(1, 7167, '\p{Is_Script_Extensions=-_Batak}', "");
Expect(0, 7167, '\p{^Is_Script_Extensions=-_Batak}', "");
Expect(0, 7167, '\P{Is_Script_Extensions=-_Batak}', "");
Expect(1, 7167, '\P{^Is_Script_Extensions=-_Batak}', "");
Expect(0, 7168, '\p{Is_Script_Extensions=-_Batak}', "");
Expect(1, 7168, '\p{^Is_Script_Extensions=-_Batak}', "");
Expect(1, 7168, '\P{Is_Script_Extensions=-_Batak}', "");
Expect(0, 7168, '\P{^Is_Script_Extensions=-_Batak}', "");
Error('\p{Is_Scx=:= -Batk}');
Error('\P{Is_Scx=:= -Batk}');
Expect(1, 7167, '\p{Is_Scx: batk}', "");
Expect(0, 7167, '\p{^Is_Scx: batk}', "");
Expect(0, 7167, '\P{Is_Scx: batk}', "");
Expect(1, 7167, '\P{^Is_Scx: batk}', "");
Expect(0, 7168, '\p{Is_Scx: batk}', "");
Expect(1, 7168, '\p{^Is_Scx: batk}', "");
Expect(1, 7168, '\P{Is_Scx: batk}', "");
Expect(0, 7168, '\P{^Is_Scx: batk}', "");
Expect(1, 7167, '\p{Is_Scx=_-batk}', "");
Expect(0, 7167, '\p{^Is_Scx=_-batk}', "");
Expect(0, 7167, '\P{Is_Scx=_-batk}', "");
Expect(1, 7167, '\P{^Is_Scx=_-batk}', "");
Expect(0, 7168, '\p{Is_Scx=_-batk}', "");
Expect(1, 7168, '\p{^Is_Scx=_-batk}', "");
Expect(1, 7168, '\P{Is_Scx=_-batk}', "");
Expect(0, 7168, '\P{^Is_Scx=_-batk}', "");
Error('\p{Script_Extensions=		BENGALI:=}');
Error('\P{Script_Extensions=		BENGALI:=}');
Expect(1, 2555, '\p{Script_Extensions=bengali}', "");
Expect(0, 2555, '\p{^Script_Extensions=bengali}', "");
Expect(0, 2555, '\P{Script_Extensions=bengali}', "");
Expect(1, 2555, '\P{^Script_Extensions=bengali}', "");
Expect(0, 2556, '\p{Script_Extensions=bengali}', "");
Expect(1, 2556, '\p{^Script_Extensions=bengali}', "");
Expect(1, 2556, '\P{Script_Extensions=bengali}', "");
Expect(0, 2556, '\P{^Script_Extensions=bengali}', "");
Expect(1, 2555, '\p{Script_Extensions=	Bengali}', "");
Expect(0, 2555, '\p{^Script_Extensions=	Bengali}', "");
Expect(0, 2555, '\P{Script_Extensions=	Bengali}', "");
Expect(1, 2555, '\P{^Script_Extensions=	Bengali}', "");
Expect(0, 2556, '\p{Script_Extensions=	Bengali}', "");
Expect(1, 2556, '\p{^Script_Extensions=	Bengali}', "");
Expect(1, 2556, '\P{Script_Extensions=	Bengali}', "");
Expect(0, 2556, '\P{^Script_Extensions=	Bengali}', "");
Error('\p{Scx: /a/beng}');
Error('\P{Scx: /a/beng}');
Expect(1, 2555, '\p{Scx=beng}', "");
Expect(0, 2555, '\p{^Scx=beng}', "");
Expect(0, 2555, '\P{Scx=beng}', "");
Expect(1, 2555, '\P{^Scx=beng}', "");
Expect(0, 2556, '\p{Scx=beng}', "");
Expect(1, 2556, '\p{^Scx=beng}', "");
Expect(1, 2556, '\P{Scx=beng}', "");
Expect(0, 2556, '\P{^Scx=beng}', "");
Expect(1, 2555, '\p{Scx=		Beng}', "");
Expect(0, 2555, '\p{^Scx=		Beng}', "");
Expect(0, 2555, '\P{Scx=		Beng}', "");
Expect(1, 2555, '\P{^Scx=		Beng}', "");
Expect(0, 2556, '\p{Scx=		Beng}', "");
Expect(1, 2556, '\p{^Scx=		Beng}', "");
Expect(1, 2556, '\P{Scx=		Beng}', "");
Expect(0, 2556, '\P{^Scx=		Beng}', "");
Error('\p{Is_Script_Extensions=/a/_-BENGALI}');
Error('\P{Is_Script_Extensions=/a/_-BENGALI}');
Expect(1, 2555, '\p{Is_Script_Extensions=bengali}', "");
Expect(0, 2555, '\p{^Is_Script_Extensions=bengali}', "");
Expect(0, 2555, '\P{Is_Script_Extensions=bengali}', "");
Expect(1, 2555, '\P{^Is_Script_Extensions=bengali}', "");
Expect(0, 2556, '\p{Is_Script_Extensions=bengali}', "");
Expect(1, 2556, '\p{^Is_Script_Extensions=bengali}', "");
Expect(1, 2556, '\P{Is_Script_Extensions=bengali}', "");
Expect(0, 2556, '\P{^Is_Script_Extensions=bengali}', "");
Expect(1, 2555, '\p{Is_Script_Extensions=	bengali}', "");
Expect(0, 2555, '\p{^Is_Script_Extensions=	bengali}', "");
Expect(0, 2555, '\P{Is_Script_Extensions=	bengali}', "");
Expect(1, 2555, '\P{^Is_Script_Extensions=	bengali}', "");
Expect(0, 2556, '\p{Is_Script_Extensions=	bengali}', "");
Expect(1, 2556, '\p{^Is_Script_Extensions=	bengali}', "");
Expect(1, 2556, '\P{Is_Script_Extensions=	bengali}', "");
Expect(0, 2556, '\P{^Is_Script_Extensions=	bengali}', "");
Error('\p{Is_Scx= -BENG:=}');
Error('\P{Is_Scx= -BENG:=}');
Expect(1, 2555, '\p{Is_Scx=beng}', "");
Expect(0, 2555, '\p{^Is_Scx=beng}', "");
Expect(0, 2555, '\P{Is_Scx=beng}', "");
Expect(1, 2555, '\P{^Is_Scx=beng}', "");
Expect(0, 2556, '\p{Is_Scx=beng}', "");
Expect(1, 2556, '\p{^Is_Scx=beng}', "");
Expect(1, 2556, '\P{Is_Scx=beng}', "");
Expect(0, 2556, '\P{^Is_Scx=beng}', "");
Expect(1, 2555, '\p{Is_Scx=_beng}', "");
Expect(0, 2555, '\p{^Is_Scx=_beng}', "");
Expect(0, 2555, '\P{Is_Scx=_beng}', "");
Expect(1, 2555, '\P{^Is_Scx=_beng}', "");
Expect(0, 2556, '\p{Is_Scx=_beng}', "");
Expect(1, 2556, '\p{^Is_Scx=_beng}', "");
Expect(1, 2556, '\P{Is_Scx=_beng}', "");
Expect(0, 2556, '\P{^Is_Scx=_beng}', "");
Error('\p{Script_Extensions=:=-_BOPOMOFO}');
Error('\P{Script_Extensions=:=-_BOPOMOFO}');
Expect(1, 65381, '\p{Script_Extensions=bopomofo}', "");
Expect(0, 65381, '\p{^Script_Extensions=bopomofo}', "");
Expect(0, 65381, '\P{Script_Extensions=bopomofo}', "");
Expect(1, 65381, '\P{^Script_Extensions=bopomofo}', "");
Expect(0, 65382, '\p{Script_Extensions=bopomofo}', "");
Expect(1, 65382, '\p{^Script_Extensions=bopomofo}', "");
Expect(1, 65382, '\P{Script_Extensions=bopomofo}', "");
Expect(0, 65382, '\P{^Script_Extensions=bopomofo}', "");
Expect(1, 65381, '\p{Script_Extensions= bopomofo}', "");
Expect(0, 65381, '\p{^Script_Extensions= bopomofo}', "");
Expect(0, 65381, '\P{Script_Extensions= bopomofo}', "");
Expect(1, 65381, '\P{^Script_Extensions= bopomofo}', "");
Expect(0, 65382, '\p{Script_Extensions= bopomofo}', "");
Expect(1, 65382, '\p{^Script_Extensions= bopomofo}', "");
Expect(1, 65382, '\P{Script_Extensions= bopomofo}', "");
Expect(0, 65382, '\P{^Script_Extensions= bopomofo}', "");
Error('\p{Scx= :=BOPO}');
Error('\P{Scx= :=BOPO}');
Expect(1, 65381, '\p{Scx=bopo}', "");
Expect(0, 65381, '\p{^Scx=bopo}', "");
Expect(0, 65381, '\P{Scx=bopo}', "");
Expect(1, 65381, '\P{^Scx=bopo}', "");
Expect(0, 65382, '\p{Scx=bopo}', "");
Expect(1, 65382, '\p{^Scx=bopo}', "");
Expect(1, 65382, '\P{Scx=bopo}', "");
Expect(0, 65382, '\P{^Scx=bopo}', "");
Expect(1, 65381, '\p{Scx=_ Bopo}', "");
Expect(0, 65381, '\p{^Scx=_ Bopo}', "");
Expect(0, 65381, '\P{Scx=_ Bopo}', "");
Expect(1, 65381, '\P{^Scx=_ Bopo}', "");
Expect(0, 65382, '\p{Scx=_ Bopo}', "");
Expect(1, 65382, '\p{^Scx=_ Bopo}', "");
Expect(1, 65382, '\P{Scx=_ Bopo}', "");
Expect(0, 65382, '\P{^Scx=_ Bopo}', "");
Error('\p{Is_Script_Extensions=-Bopomofo/a/}');
Error('\P{Is_Script_Extensions=-Bopomofo/a/}');
Expect(1, 65381, '\p{Is_Script_Extensions=bopomofo}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=bopomofo}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=bopomofo}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=bopomofo}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=bopomofo}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=bopomofo}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=bopomofo}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=bopomofo}', "");
Expect(1, 65381, '\p{Is_Script_Extensions=	-Bopomofo}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=	-Bopomofo}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=	-Bopomofo}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=	-Bopomofo}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=	-Bopomofo}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=	-Bopomofo}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=	-Bopomofo}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=	-Bopomofo}', "");
Error('\p{Is_Scx=/a/	 BOPO}');
Error('\P{Is_Scx=/a/	 BOPO}');
Expect(1, 65381, '\p{Is_Scx=bopo}', "");
Expect(0, 65381, '\p{^Is_Scx=bopo}', "");
Expect(0, 65381, '\P{Is_Scx=bopo}', "");
Expect(1, 65381, '\P{^Is_Scx=bopo}', "");
Expect(0, 65382, '\p{Is_Scx=bopo}', "");
Expect(1, 65382, '\p{^Is_Scx=bopo}', "");
Expect(1, 65382, '\P{Is_Scx=bopo}', "");
Expect(0, 65382, '\P{^Is_Scx=bopo}', "");
Error('\p{Script_Extensions=_ Brahmi/a/}');
Error('\P{Script_Extensions=_ Brahmi/a/}');
Expect(1, 69743, '\p{Script_Extensions=brahmi}', "");
Expect(0, 69743, '\p{^Script_Extensions=brahmi}', "");
Expect(0, 69743, '\P{Script_Extensions=brahmi}', "");
Expect(1, 69743, '\P{^Script_Extensions=brahmi}', "");
Expect(0, 69744, '\p{Script_Extensions=brahmi}', "");
Expect(1, 69744, '\p{^Script_Extensions=brahmi}', "");
Expect(1, 69744, '\P{Script_Extensions=brahmi}', "");
Expect(0, 69744, '\P{^Script_Extensions=brahmi}', "");
Expect(1, 69743, '\p{Script_Extensions:		_Brahmi}', "");
Expect(0, 69743, '\p{^Script_Extensions:		_Brahmi}', "");
Expect(0, 69743, '\P{Script_Extensions:		_Brahmi}', "");
Expect(1, 69743, '\P{^Script_Extensions:		_Brahmi}', "");
Expect(0, 69744, '\p{Script_Extensions:		_Brahmi}', "");
Expect(1, 69744, '\p{^Script_Extensions:		_Brahmi}', "");
Expect(1, 69744, '\P{Script_Extensions:		_Brahmi}', "");
Expect(0, 69744, '\P{^Script_Extensions:		_Brahmi}', "");
Error('\p{Scx=	_Brah:=}');
Error('\P{Scx=	_Brah:=}');
Expect(1, 69743, '\p{Scx=brah}', "");
Expect(0, 69743, '\p{^Scx=brah}', "");
Expect(0, 69743, '\P{Scx=brah}', "");
Expect(1, 69743, '\P{^Scx=brah}', "");
Expect(0, 69744, '\p{Scx=brah}', "");
Expect(1, 69744, '\p{^Scx=brah}', "");
Expect(1, 69744, '\P{Scx=brah}', "");
Expect(0, 69744, '\P{^Scx=brah}', "");
Expect(1, 69743, '\p{Scx=-	Brah}', "");
Expect(0, 69743, '\p{^Scx=-	Brah}', "");
Expect(0, 69743, '\P{Scx=-	Brah}', "");
Expect(1, 69743, '\P{^Scx=-	Brah}', "");
Expect(0, 69744, '\p{Scx=-	Brah}', "");
Expect(1, 69744, '\p{^Scx=-	Brah}', "");
Expect(1, 69744, '\P{Scx=-	Brah}', "");
Expect(0, 69744, '\P{^Scx=-	Brah}', "");
Error('\p{Is_Script_Extensions=:= -Brahmi}');
Error('\P{Is_Script_Extensions=:= -Brahmi}');
Expect(1, 69743, '\p{Is_Script_Extensions=brahmi}', "");
Expect(0, 69743, '\p{^Is_Script_Extensions=brahmi}', "");
Expect(0, 69743, '\P{Is_Script_Extensions=brahmi}', "");
Expect(1, 69743, '\P{^Is_Script_Extensions=brahmi}', "");
Expect(0, 69744, '\p{Is_Script_Extensions=brahmi}', "");
Expect(1, 69744, '\p{^Is_Script_Extensions=brahmi}', "");
Expect(1, 69744, '\P{Is_Script_Extensions=brahmi}', "");
Expect(0, 69744, '\P{^Is_Script_Extensions=brahmi}', "");
Expect(1, 69743, '\p{Is_Script_Extensions=-	Brahmi}', "");
Expect(0, 69743, '\p{^Is_Script_Extensions=-	Brahmi}', "");
Expect(0, 69743, '\P{Is_Script_Extensions=-	Brahmi}', "");
Expect(1, 69743, '\P{^Is_Script_Extensions=-	Brahmi}', "");
Expect(0, 69744, '\p{Is_Script_Extensions=-	Brahmi}', "");
Expect(1, 69744, '\p{^Is_Script_Extensions=-	Brahmi}', "");
Expect(1, 69744, '\P{Is_Script_Extensions=-	Brahmi}', "");
Expect(0, 69744, '\P{^Is_Script_Extensions=-	Brahmi}', "");
Error('\p{Is_Scx=/a/BRAH}');
Error('\P{Is_Scx=/a/BRAH}');
Expect(1, 69743, '\p{Is_Scx=brah}', "");
Expect(0, 69743, '\p{^Is_Scx=brah}', "");
Expect(0, 69743, '\P{Is_Scx=brah}', "");
Expect(1, 69743, '\P{^Is_Scx=brah}', "");
Expect(0, 69744, '\p{Is_Scx=brah}', "");
Expect(1, 69744, '\p{^Is_Scx=brah}', "");
Expect(1, 69744, '\P{Is_Scx=brah}', "");
Expect(0, 69744, '\P{^Is_Scx=brah}', "");
Expect(1, 69743, '\p{Is_Scx=	 Brah}', "");
Expect(0, 69743, '\p{^Is_Scx=	 Brah}', "");
Expect(0, 69743, '\P{Is_Scx=	 Brah}', "");
Expect(1, 69743, '\P{^Is_Scx=	 Brah}', "");
Expect(0, 69744, '\p{Is_Scx=	 Brah}', "");
Expect(1, 69744, '\p{^Is_Scx=	 Brah}', "");
Expect(1, 69744, '\P{Is_Scx=	 Brah}', "");
Expect(0, 69744, '\P{^Is_Scx=	 Brah}', "");
Error('\p{Script_Extensions=:=Braille}');
Error('\P{Script_Extensions=:=Braille}');
Expect(1, 10495, '\p{Script_Extensions=braille}', "");
Expect(0, 10495, '\p{^Script_Extensions=braille}', "");
Expect(0, 10495, '\P{Script_Extensions=braille}', "");
Expect(1, 10495, '\P{^Script_Extensions=braille}', "");
Expect(0, 10496, '\p{Script_Extensions=braille}', "");
Expect(1, 10496, '\p{^Script_Extensions=braille}', "");
Expect(1, 10496, '\P{Script_Extensions=braille}', "");
Expect(0, 10496, '\P{^Script_Extensions=braille}', "");
Expect(1, 10495, '\p{Script_Extensions= _braille}', "");
Expect(0, 10495, '\p{^Script_Extensions= _braille}', "");
Expect(0, 10495, '\P{Script_Extensions= _braille}', "");
Expect(1, 10495, '\P{^Script_Extensions= _braille}', "");
Expect(0, 10496, '\p{Script_Extensions= _braille}', "");
Expect(1, 10496, '\p{^Script_Extensions= _braille}', "");
Expect(1, 10496, '\P{Script_Extensions= _braille}', "");
Expect(0, 10496, '\P{^Script_Extensions= _braille}', "");
Error('\p{Scx=:=BRAI}');
Error('\P{Scx=:=BRAI}');
Expect(1, 10495, '\p{Scx=brai}', "");
Expect(0, 10495, '\p{^Scx=brai}', "");
Expect(0, 10495, '\P{Scx=brai}', "");
Expect(1, 10495, '\P{^Scx=brai}', "");
Expect(0, 10496, '\p{Scx=brai}', "");
Expect(1, 10496, '\p{^Scx=brai}', "");
Expect(1, 10496, '\P{Scx=brai}', "");
Expect(0, 10496, '\P{^Scx=brai}', "");
Expect(1, 10495, '\p{Scx=- Brai}', "");
Expect(0, 10495, '\p{^Scx=- Brai}', "");
Expect(0, 10495, '\P{Scx=- Brai}', "");
Expect(1, 10495, '\P{^Scx=- Brai}', "");
Expect(0, 10496, '\p{Scx=- Brai}', "");
Expect(1, 10496, '\p{^Scx=- Brai}', "");
Expect(1, 10496, '\P{Scx=- Brai}', "");
Expect(0, 10496, '\P{^Scx=- Brai}', "");
Error('\p{Is_Script_Extensions: :=Braille}');
Error('\P{Is_Script_Extensions: :=Braille}');
Expect(1, 10495, '\p{Is_Script_Extensions=braille}', "");
Expect(0, 10495, '\p{^Is_Script_Extensions=braille}', "");
Expect(0, 10495, '\P{Is_Script_Extensions=braille}', "");
Expect(1, 10495, '\P{^Is_Script_Extensions=braille}', "");
Expect(0, 10496, '\p{Is_Script_Extensions=braille}', "");
Expect(1, 10496, '\p{^Is_Script_Extensions=braille}', "");
Expect(1, 10496, '\P{Is_Script_Extensions=braille}', "");
Expect(0, 10496, '\P{^Is_Script_Extensions=braille}', "");
Expect(1, 10495, '\p{Is_Script_Extensions=	 braille}', "");
Expect(0, 10495, '\p{^Is_Script_Extensions=	 braille}', "");
Expect(0, 10495, '\P{Is_Script_Extensions=	 braille}', "");
Expect(1, 10495, '\P{^Is_Script_Extensions=	 braille}', "");
Expect(0, 10496, '\p{Is_Script_Extensions=	 braille}', "");
Expect(1, 10496, '\p{^Is_Script_Extensions=	 braille}', "");
Expect(1, 10496, '\P{Is_Script_Extensions=	 braille}', "");
Expect(0, 10496, '\P{^Is_Script_Extensions=	 braille}', "");
Error('\p{Is_Scx=  BRAI/a/}');
Error('\P{Is_Scx=  BRAI/a/}');
Expect(1, 10495, '\p{Is_Scx:	brai}', "");
Expect(0, 10495, '\p{^Is_Scx:	brai}', "");
Expect(0, 10495, '\P{Is_Scx:	brai}', "");
Expect(1, 10495, '\P{^Is_Scx:	brai}', "");
Expect(0, 10496, '\p{Is_Scx:	brai}', "");
Expect(1, 10496, '\p{^Is_Scx:	brai}', "");
Expect(1, 10496, '\P{Is_Scx:	brai}', "");
Expect(0, 10496, '\P{^Is_Scx:	brai}', "");
Expect(1, 10495, '\p{Is_Scx:	  Brai}', "");
Expect(0, 10495, '\p{^Is_Scx:	  Brai}', "");
Expect(0, 10495, '\P{Is_Scx:	  Brai}', "");
Expect(1, 10495, '\P{^Is_Scx:	  Brai}', "");
Expect(0, 10496, '\p{Is_Scx:	  Brai}', "");
Expect(1, 10496, '\p{^Is_Scx:	  Brai}', "");
Expect(1, 10496, '\P{Is_Scx:	  Brai}', "");
Expect(0, 10496, '\P{^Is_Scx:	  Brai}', "");
Error('\p{Script_Extensions:    _buginese/a/}');
Error('\P{Script_Extensions:    _buginese/a/}');
Expect(1, 6687, '\p{Script_Extensions=buginese}', "");
Expect(0, 6687, '\p{^Script_Extensions=buginese}', "");
Expect(0, 6687, '\P{Script_Extensions=buginese}', "");
Expect(1, 6687, '\P{^Script_Extensions=buginese}', "");
Expect(0, 6688, '\p{Script_Extensions=buginese}', "");
Expect(1, 6688, '\p{^Script_Extensions=buginese}', "");
Expect(1, 6688, '\P{Script_Extensions=buginese}', "");
Expect(0, 6688, '\P{^Script_Extensions=buginese}', "");
Expect(1, 6687, '\p{Script_Extensions=-Buginese}', "");
Expect(0, 6687, '\p{^Script_Extensions=-Buginese}', "");
Expect(0, 6687, '\P{Script_Extensions=-Buginese}', "");
Expect(1, 6687, '\P{^Script_Extensions=-Buginese}', "");
Expect(0, 6688, '\p{Script_Extensions=-Buginese}', "");
Expect(1, 6688, '\p{^Script_Extensions=-Buginese}', "");
Expect(1, 6688, '\P{Script_Extensions=-Buginese}', "");
Expect(0, 6688, '\P{^Script_Extensions=-Buginese}', "");
Error('\p{Scx= _BUGI:=}');
Error('\P{Scx= _BUGI:=}');
Expect(1, 6687, '\p{Scx=bugi}', "");
Expect(0, 6687, '\p{^Scx=bugi}', "");
Expect(0, 6687, '\P{Scx=bugi}', "");
Expect(1, 6687, '\P{^Scx=bugi}', "");
Expect(0, 6688, '\p{Scx=bugi}', "");
Expect(1, 6688, '\p{^Scx=bugi}', "");
Expect(1, 6688, '\P{Scx=bugi}', "");
Expect(0, 6688, '\P{^Scx=bugi}', "");
Expect(1, 6687, '\p{Scx:   	BUGI}', "");
Expect(0, 6687, '\p{^Scx:   	BUGI}', "");
Expect(0, 6687, '\P{Scx:   	BUGI}', "");
Expect(1, 6687, '\P{^Scx:   	BUGI}', "");
Expect(0, 6688, '\p{Scx:   	BUGI}', "");
Expect(1, 6688, '\p{^Scx:   	BUGI}', "");
Expect(1, 6688, '\P{Scx:   	BUGI}', "");
Expect(0, 6688, '\P{^Scx:   	BUGI}', "");
Error('\p{Is_Script_Extensions=/a/- buginese}');
Error('\P{Is_Script_Extensions=/a/- buginese}');
Expect(1, 6687, '\p{Is_Script_Extensions=buginese}', "");
Expect(0, 6687, '\p{^Is_Script_Extensions=buginese}', "");
Expect(0, 6687, '\P{Is_Script_Extensions=buginese}', "");
Expect(1, 6687, '\P{^Is_Script_Extensions=buginese}', "");
Expect(0, 6688, '\p{Is_Script_Extensions=buginese}', "");
Expect(1, 6688, '\p{^Is_Script_Extensions=buginese}', "");
Expect(1, 6688, '\P{Is_Script_Extensions=buginese}', "");
Expect(0, 6688, '\P{^Is_Script_Extensions=buginese}', "");
Expect(1, 6687, '\p{Is_Script_Extensions=_ Buginese}', "");
Expect(0, 6687, '\p{^Is_Script_Extensions=_ Buginese}', "");
Expect(0, 6687, '\P{Is_Script_Extensions=_ Buginese}', "");
Expect(1, 6687, '\P{^Is_Script_Extensions=_ Buginese}', "");
Expect(0, 6688, '\p{Is_Script_Extensions=_ Buginese}', "");
Expect(1, 6688, '\p{^Is_Script_Extensions=_ Buginese}', "");
Expect(1, 6688, '\P{Is_Script_Extensions=_ Buginese}', "");
Expect(0, 6688, '\P{^Is_Script_Extensions=_ Buginese}', "");
Error('\p{Is_Scx= bugi/a/}');
Error('\P{Is_Scx= bugi/a/}');
Expect(1, 6687, '\p{Is_Scx=bugi}', "");
Expect(0, 6687, '\p{^Is_Scx=bugi}', "");
Expect(0, 6687, '\P{Is_Scx=bugi}', "");
Expect(1, 6687, '\P{^Is_Scx=bugi}', "");
Expect(0, 6688, '\p{Is_Scx=bugi}', "");
Expect(1, 6688, '\p{^Is_Scx=bugi}', "");
Expect(1, 6688, '\P{Is_Scx=bugi}', "");
Expect(0, 6688, '\P{^Is_Scx=bugi}', "");
Expect(1, 6687, '\p{Is_Scx= -bugi}', "");
Expect(0, 6687, '\p{^Is_Scx= -bugi}', "");
Expect(0, 6687, '\P{Is_Scx= -bugi}', "");
Expect(1, 6687, '\P{^Is_Scx= -bugi}', "");
Expect(0, 6688, '\p{Is_Scx= -bugi}', "");
Expect(1, 6688, '\p{^Is_Scx= -bugi}', "");
Expect(1, 6688, '\P{Is_Scx= -bugi}', "");
Expect(0, 6688, '\P{^Is_Scx= -bugi}', "");
Error('\p{Script_Extensions=_	buhid/a/}');
Error('\P{Script_Extensions=_	buhid/a/}');
Expect(1, 5971, '\p{Script_Extensions=buhid}', "");
Expect(0, 5971, '\p{^Script_Extensions=buhid}', "");
Expect(0, 5971, '\P{Script_Extensions=buhid}', "");
Expect(1, 5971, '\P{^Script_Extensions=buhid}', "");
Expect(0, 5972, '\p{Script_Extensions=buhid}', "");
Expect(1, 5972, '\p{^Script_Extensions=buhid}', "");
Expect(1, 5972, '\P{Script_Extensions=buhid}', "");
Expect(0, 5972, '\P{^Script_Extensions=buhid}', "");
Expect(1, 5971, '\p{Script_Extensions=-_buhid}', "");
Expect(0, 5971, '\p{^Script_Extensions=-_buhid}', "");
Expect(0, 5971, '\P{Script_Extensions=-_buhid}', "");
Expect(1, 5971, '\P{^Script_Extensions=-_buhid}', "");
Expect(0, 5972, '\p{Script_Extensions=-_buhid}', "");
Expect(1, 5972, '\p{^Script_Extensions=-_buhid}', "");
Expect(1, 5972, '\P{Script_Extensions=-_buhid}', "");
Expect(0, 5972, '\P{^Script_Extensions=-_buhid}', "");
Error('\p{Scx=BUHD/a/}');
Error('\P{Scx=BUHD/a/}');
Expect(1, 5971, '\p{Scx=buhd}', "");
Expect(0, 5971, '\p{^Scx=buhd}', "");
Expect(0, 5971, '\P{Scx=buhd}', "");
Expect(1, 5971, '\P{^Scx=buhd}', "");
Expect(0, 5972, '\p{Scx=buhd}', "");
Expect(1, 5972, '\p{^Scx=buhd}', "");
Expect(1, 5972, '\P{Scx=buhd}', "");
Expect(0, 5972, '\P{^Scx=buhd}', "");
Expect(1, 5971, '\p{Scx: _	Buhd}', "");
Expect(0, 5971, '\p{^Scx: _	Buhd}', "");
Expect(0, 5971, '\P{Scx: _	Buhd}', "");
Expect(1, 5971, '\P{^Scx: _	Buhd}', "");
Expect(0, 5972, '\p{Scx: _	Buhd}', "");
Expect(1, 5972, '\p{^Scx: _	Buhd}', "");
Expect(1, 5972, '\P{Scx: _	Buhd}', "");
Expect(0, 5972, '\P{^Scx: _	Buhd}', "");
Error('\p{Is_Script_Extensions=	-BUHID/a/}');
Error('\P{Is_Script_Extensions=	-BUHID/a/}');
Expect(1, 5971, '\p{Is_Script_Extensions=buhid}', "");
Expect(0, 5971, '\p{^Is_Script_Extensions=buhid}', "");
Expect(0, 5971, '\P{Is_Script_Extensions=buhid}', "");
Expect(1, 5971, '\P{^Is_Script_Extensions=buhid}', "");
Expect(0, 5972, '\p{Is_Script_Extensions=buhid}', "");
Expect(1, 5972, '\p{^Is_Script_Extensions=buhid}', "");
Expect(1, 5972, '\P{Is_Script_Extensions=buhid}', "");
Expect(0, 5972, '\P{^Is_Script_Extensions=buhid}', "");
Expect(1, 5971, '\p{Is_Script_Extensions=	-Buhid}', "");
Expect(0, 5971, '\p{^Is_Script_Extensions=	-Buhid}', "");
Expect(0, 5971, '\P{Is_Script_Extensions=	-Buhid}', "");
Expect(1, 5971, '\P{^Is_Script_Extensions=	-Buhid}', "");
Expect(0, 5972, '\p{Is_Script_Extensions=	-Buhid}', "");
Expect(1, 5972, '\p{^Is_Script_Extensions=	-Buhid}', "");
Expect(1, 5972, '\P{Is_Script_Extensions=	-Buhid}', "");
Expect(0, 5972, '\P{^Is_Script_Extensions=	-Buhid}', "");
Error('\p{Is_Scx=/a/BUHD}');
Error('\P{Is_Scx=/a/BUHD}');
Expect(1, 5971, '\p{Is_Scx=buhd}', "");
Expect(0, 5971, '\p{^Is_Scx=buhd}', "");
Expect(0, 5971, '\P{Is_Scx=buhd}', "");
Expect(1, 5971, '\P{^Is_Scx=buhd}', "");
Expect(0, 5972, '\p{Is_Scx=buhd}', "");
Expect(1, 5972, '\p{^Is_Scx=buhd}', "");
Expect(1, 5972, '\P{Is_Scx=buhd}', "");
Expect(0, 5972, '\P{^Is_Scx=buhd}', "");
Expect(1, 5971, '\p{Is_Scx=	BUHD}', "");
Expect(0, 5971, '\p{^Is_Scx=	BUHD}', "");
Expect(0, 5971, '\P{Is_Scx=	BUHD}', "");
Expect(1, 5971, '\P{^Is_Scx=	BUHD}', "");
Expect(0, 5972, '\p{Is_Scx=	BUHD}', "");
Expect(1, 5972, '\p{^Is_Scx=	BUHD}', "");
Expect(1, 5972, '\P{Is_Scx=	BUHD}', "");
Expect(0, 5972, '\P{^Is_Scx=	BUHD}', "");
Error('\p{Script_Extensions=_/a/Chakma}');
Error('\P{Script_Extensions=_/a/Chakma}');
Expect(1, 69955, '\p{Script_Extensions=chakma}', "");
Expect(0, 69955, '\p{^Script_Extensions=chakma}', "");
Expect(0, 69955, '\P{Script_Extensions=chakma}', "");
Expect(1, 69955, '\P{^Script_Extensions=chakma}', "");
Expect(0, 69956, '\p{Script_Extensions=chakma}', "");
Expect(1, 69956, '\p{^Script_Extensions=chakma}', "");
Expect(1, 69956, '\P{Script_Extensions=chakma}', "");
Expect(0, 69956, '\P{^Script_Extensions=chakma}', "");
Expect(1, 69955, '\p{Script_Extensions=	-CHAKMA}', "");
Expect(0, 69955, '\p{^Script_Extensions=	-CHAKMA}', "");
Expect(0, 69955, '\P{Script_Extensions=	-CHAKMA}', "");
Expect(1, 69955, '\P{^Script_Extensions=	-CHAKMA}', "");
Expect(0, 69956, '\p{Script_Extensions=	-CHAKMA}', "");
Expect(1, 69956, '\p{^Script_Extensions=	-CHAKMA}', "");
Expect(1, 69956, '\P{Script_Extensions=	-CHAKMA}', "");
Expect(0, 69956, '\P{^Script_Extensions=	-CHAKMA}', "");
Error('\p{Scx=:= cakm}');
Error('\P{Scx=:= cakm}');
Expect(1, 69955, '\p{Scx=cakm}', "");
Expect(0, 69955, '\p{^Scx=cakm}', "");
Expect(0, 69955, '\P{Scx=cakm}', "");
Expect(1, 69955, '\P{^Scx=cakm}', "");
Expect(0, 69956, '\p{Scx=cakm}', "");
Expect(1, 69956, '\p{^Scx=cakm}', "");
Expect(1, 69956, '\P{Scx=cakm}', "");
Expect(0, 69956, '\P{^Scx=cakm}', "");
Expect(1, 69955, '\p{Scx=	-cakm}', "");
Expect(0, 69955, '\p{^Scx=	-cakm}', "");
Expect(0, 69955, '\P{Scx=	-cakm}', "");
Expect(1, 69955, '\P{^Scx=	-cakm}', "");
Expect(0, 69956, '\p{Scx=	-cakm}', "");
Expect(1, 69956, '\p{^Scx=	-cakm}', "");
Expect(1, 69956, '\P{Scx=	-cakm}', "");
Expect(0, 69956, '\P{^Scx=	-cakm}', "");
Error('\p{Is_Script_Extensions= :=chakma}');
Error('\P{Is_Script_Extensions= :=chakma}');
Expect(1, 69955, '\p{Is_Script_Extensions=chakma}', "");
Expect(0, 69955, '\p{^Is_Script_Extensions=chakma}', "");
Expect(0, 69955, '\P{Is_Script_Extensions=chakma}', "");
Expect(1, 69955, '\P{^Is_Script_Extensions=chakma}', "");
Expect(0, 69956, '\p{Is_Script_Extensions=chakma}', "");
Expect(1, 69956, '\p{^Is_Script_Extensions=chakma}', "");
Expect(1, 69956, '\P{Is_Script_Extensions=chakma}', "");
Expect(0, 69956, '\P{^Is_Script_Extensions=chakma}', "");
Expect(1, 69955, '\p{Is_Script_Extensions=-	CHAKMA}', "");
Expect(0, 69955, '\p{^Is_Script_Extensions=-	CHAKMA}', "");
Expect(0, 69955, '\P{Is_Script_Extensions=-	CHAKMA}', "");
Expect(1, 69955, '\P{^Is_Script_Extensions=-	CHAKMA}', "");
Expect(0, 69956, '\p{Is_Script_Extensions=-	CHAKMA}', "");
Expect(1, 69956, '\p{^Is_Script_Extensions=-	CHAKMA}', "");
Expect(1, 69956, '\P{Is_Script_Extensions=-	CHAKMA}', "");
Expect(0, 69956, '\P{^Is_Script_Extensions=-	CHAKMA}', "");
Error('\p{Is_Scx=:=_ CAKM}');
Error('\P{Is_Scx=:=_ CAKM}');
Expect(1, 69955, '\p{Is_Scx=cakm}', "");
Expect(0, 69955, '\p{^Is_Scx=cakm}', "");
Expect(0, 69955, '\P{Is_Scx=cakm}', "");
Expect(1, 69955, '\P{^Is_Scx=cakm}', "");
Expect(0, 69956, '\p{Is_Scx=cakm}', "");
Expect(1, 69956, '\p{^Is_Scx=cakm}', "");
Expect(1, 69956, '\P{Is_Scx=cakm}', "");
Expect(0, 69956, '\P{^Is_Scx=cakm}', "");
Expect(1, 69955, '\p{Is_Scx=-	CAKM}', "");
Expect(0, 69955, '\p{^Is_Scx=-	CAKM}', "");
Expect(0, 69955, '\P{Is_Scx=-	CAKM}', "");
Expect(1, 69955, '\P{^Is_Scx=-	CAKM}', "");
Expect(0, 69956, '\p{Is_Scx=-	CAKM}', "");
Expect(1, 69956, '\p{^Is_Scx=-	CAKM}', "");
Expect(1, 69956, '\P{Is_Scx=-	CAKM}', "");
Expect(0, 69956, '\P{^Is_Scx=-	CAKM}', "");
Error('\p{Script_Extensions=  canadian_aboriginal/a/}');
Error('\P{Script_Extensions=  canadian_aboriginal/a/}');
Expect(1, 6389, '\p{Script_Extensions=canadianaboriginal}', "");
Expect(0, 6389, '\p{^Script_Extensions=canadianaboriginal}', "");
Expect(0, 6389, '\P{Script_Extensions=canadianaboriginal}', "");
Expect(1, 6389, '\P{^Script_Extensions=canadianaboriginal}', "");
Expect(0, 6390, '\p{Script_Extensions=canadianaboriginal}', "");
Expect(1, 6390, '\p{^Script_Extensions=canadianaboriginal}', "");
Expect(1, 6390, '\P{Script_Extensions=canadianaboriginal}', "");
Expect(0, 6390, '\P{^Script_Extensions=canadianaboriginal}', "");
Expect(1, 6389, '\p{Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(0, 6389, '\p{^Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(0, 6389, '\P{Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(1, 6389, '\P{^Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(0, 6390, '\p{Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(1, 6390, '\p{^Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(1, 6390, '\P{Script_Extensions=	 Canadian_ABORIGINAL}', "");
Expect(0, 6390, '\P{^Script_Extensions=	 Canadian_ABORIGINAL}', "");
Error('\p{Scx=/a/_	Cans}');
Error('\P{Scx=/a/_	Cans}');
Expect(1, 6389, '\p{Scx=cans}', "");
Expect(0, 6389, '\p{^Scx=cans}', "");
Expect(0, 6389, '\P{Scx=cans}', "");
Expect(1, 6389, '\P{^Scx=cans}', "");
Expect(0, 6390, '\p{Scx=cans}', "");
Expect(1, 6390, '\p{^Scx=cans}', "");
Expect(1, 6390, '\P{Scx=cans}', "");
Expect(0, 6390, '\P{^Scx=cans}', "");
Expect(1, 6389, '\p{Scx= _CANS}', "");
Expect(0, 6389, '\p{^Scx= _CANS}', "");
Expect(0, 6389, '\P{Scx= _CANS}', "");
Expect(1, 6389, '\P{^Scx= _CANS}', "");
Expect(0, 6390, '\p{Scx= _CANS}', "");
Expect(1, 6390, '\p{^Scx= _CANS}', "");
Expect(1, 6390, '\P{Scx= _CANS}', "");
Expect(0, 6390, '\P{^Scx= _CANS}', "");
Error('\p{Is_Script_Extensions=/a/Canadian_Aboriginal}');
Error('\P{Is_Script_Extensions=/a/Canadian_Aboriginal}');
Expect(1, 6389, '\p{Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6389, '\p{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6389, '\P{Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6389, '\P{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6390, '\p{Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6390, '\p{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6390, '\P{Is_Script_Extensions=canadianaboriginal}', "");
Expect(0, 6390, '\P{^Is_Script_Extensions=canadianaboriginal}', "");
Expect(1, 6389, '\p{Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(0, 6389, '\p{^Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(0, 6389, '\P{Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(1, 6389, '\P{^Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(0, 6390, '\p{Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(1, 6390, '\p{^Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(1, 6390, '\P{Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Expect(0, 6390, '\P{^Is_Script_Extensions=--CANADIAN_Aboriginal}', "");
Error('\p{Is_Scx=:= -Cans}');
Error('\P{Is_Scx=:= -Cans}');
Expect(1, 6389, '\p{Is_Scx:	cans}', "");
Expect(0, 6389, '\p{^Is_Scx:	cans}', "");
Expect(0, 6389, '\P{Is_Scx:	cans}', "");
Expect(1, 6389, '\P{^Is_Scx:	cans}', "");
Expect(0, 6390, '\p{Is_Scx:	cans}', "");
Expect(1, 6390, '\p{^Is_Scx:	cans}', "");
Expect(1, 6390, '\P{Is_Scx:	cans}', "");
Expect(0, 6390, '\P{^Is_Scx:	cans}', "");
Expect(1, 6389, '\p{Is_Scx=_Cans}', "");
Expect(0, 6389, '\p{^Is_Scx=_Cans}', "");
Expect(0, 6389, '\P{Is_Scx=_Cans}', "");
Expect(1, 6389, '\P{^Is_Scx=_Cans}', "");
Expect(0, 6390, '\p{Is_Scx=_Cans}', "");
Expect(1, 6390, '\p{^Is_Scx=_Cans}', "");
Expect(1, 6390, '\P{Is_Scx=_Cans}', "");
Expect(0, 6390, '\P{^Is_Scx=_Cans}', "");
Error('\p{Script_Extensions=--Carian/a/}');
Error('\P{Script_Extensions=--Carian/a/}');
Expect(1, 66256, '\p{Script_Extensions=carian}', "");
Expect(0, 66256, '\p{^Script_Extensions=carian}', "");
Expect(0, 66256, '\P{Script_Extensions=carian}', "");
Expect(1, 66256, '\P{^Script_Extensions=carian}', "");
Expect(0, 66257, '\p{Script_Extensions=carian}', "");
Expect(1, 66257, '\p{^Script_Extensions=carian}', "");
Expect(1, 66257, '\P{Script_Extensions=carian}', "");
Expect(0, 66257, '\P{^Script_Extensions=carian}', "");
Expect(1, 66256, '\p{Script_Extensions= carian}', "");
Expect(0, 66256, '\p{^Script_Extensions= carian}', "");
Expect(0, 66256, '\P{Script_Extensions= carian}', "");
Expect(1, 66256, '\P{^Script_Extensions= carian}', "");
Expect(0, 66257, '\p{Script_Extensions= carian}', "");
Expect(1, 66257, '\p{^Script_Extensions= carian}', "");
Expect(1, 66257, '\P{Script_Extensions= carian}', "");
Expect(0, 66257, '\P{^Script_Extensions= carian}', "");
Error('\p{Scx=:= CARI}');
Error('\P{Scx=:= CARI}');
Expect(1, 66256, '\p{Scx=cari}', "");
Expect(0, 66256, '\p{^Scx=cari}', "");
Expect(0, 66256, '\P{Scx=cari}', "");
Expect(1, 66256, '\P{^Scx=cari}', "");
Expect(0, 66257, '\p{Scx=cari}', "");
Expect(1, 66257, '\p{^Scx=cari}', "");
Expect(1, 66257, '\P{Scx=cari}', "");
Expect(0, 66257, '\P{^Scx=cari}', "");
Expect(1, 66256, '\p{Scx= Cari}', "");
Expect(0, 66256, '\p{^Scx= Cari}', "");
Expect(0, 66256, '\P{Scx= Cari}', "");
Expect(1, 66256, '\P{^Scx= Cari}', "");
Expect(0, 66257, '\p{Scx= Cari}', "");
Expect(1, 66257, '\p{^Scx= Cari}', "");
Expect(1, 66257, '\P{Scx= Cari}', "");
Expect(0, 66257, '\P{^Scx= Cari}', "");
Error('\p{Is_Script_Extensions=	_Carian:=}');
Error('\P{Is_Script_Extensions=	_Carian:=}');
Expect(1, 66256, '\p{Is_Script_Extensions=carian}', "");
Expect(0, 66256, '\p{^Is_Script_Extensions=carian}', "");
Expect(0, 66256, '\P{Is_Script_Extensions=carian}', "");
Expect(1, 66256, '\P{^Is_Script_Extensions=carian}', "");
Expect(0, 66257, '\p{Is_Script_Extensions=carian}', "");
Expect(1, 66257, '\p{^Is_Script_Extensions=carian}', "");
Expect(1, 66257, '\P{Is_Script_Extensions=carian}', "");
Expect(0, 66257, '\P{^Is_Script_Extensions=carian}', "");
Expect(1, 66256, '\p{Is_Script_Extensions:	 _CARIAN}', "");
Expect(0, 66256, '\p{^Is_Script_Extensions:	 _CARIAN}', "");
Expect(0, 66256, '\P{Is_Script_Extensions:	 _CARIAN}', "");
Expect(1, 66256, '\P{^Is_Script_Extensions:	 _CARIAN}', "");
Expect(0, 66257, '\p{Is_Script_Extensions:	 _CARIAN}', "");
Expect(1, 66257, '\p{^Is_Script_Extensions:	 _CARIAN}', "");
Expect(1, 66257, '\P{Is_Script_Extensions:	 _CARIAN}', "");
Expect(0, 66257, '\P{^Is_Script_Extensions:	 _CARIAN}', "");
Error('\p{Is_Scx=-:=Cari}');
Error('\P{Is_Scx=-:=Cari}');
Expect(1, 66256, '\p{Is_Scx=cari}', "");
Expect(0, 66256, '\p{^Is_Scx=cari}', "");
Expect(0, 66256, '\P{Is_Scx=cari}', "");
Expect(1, 66256, '\P{^Is_Scx=cari}', "");
Expect(0, 66257, '\p{Is_Scx=cari}', "");
Expect(1, 66257, '\p{^Is_Scx=cari}', "");
Expect(1, 66257, '\P{Is_Scx=cari}', "");
Expect(0, 66257, '\P{^Is_Scx=cari}', "");
Expect(1, 66256, '\p{Is_Scx=-Cari}', "");
Expect(0, 66256, '\p{^Is_Scx=-Cari}', "");
Expect(0, 66256, '\P{Is_Scx=-Cari}', "");
Expect(1, 66256, '\P{^Is_Scx=-Cari}', "");
Expect(0, 66257, '\p{Is_Scx=-Cari}', "");
Expect(1, 66257, '\p{^Is_Scx=-Cari}', "");
Expect(1, 66257, '\P{Is_Scx=-Cari}', "");
Expect(0, 66257, '\P{^Is_Scx=-Cari}', "");
Error('\p{Script_Extensions=_/a/Cham}');
Error('\P{Script_Extensions=_/a/Cham}');
Expect(1, 43615, '\p{Script_Extensions=cham}', "");
Expect(0, 43615, '\p{^Script_Extensions=cham}', "");
Expect(0, 43615, '\P{Script_Extensions=cham}', "");
Expect(1, 43615, '\P{^Script_Extensions=cham}', "");
Expect(0, 43616, '\p{Script_Extensions=cham}', "");
Expect(1, 43616, '\p{^Script_Extensions=cham}', "");
Expect(1, 43616, '\P{Script_Extensions=cham}', "");
Expect(0, 43616, '\P{^Script_Extensions=cham}', "");
Expect(1, 43615, '\p{Script_Extensions= Cham}', "");
Expect(0, 43615, '\p{^Script_Extensions= Cham}', "");
Expect(0, 43615, '\P{Script_Extensions= Cham}', "");
Expect(1, 43615, '\P{^Script_Extensions= Cham}', "");
Expect(0, 43616, '\p{Script_Extensions= Cham}', "");
Expect(1, 43616, '\p{^Script_Extensions= Cham}', "");
Expect(1, 43616, '\P{Script_Extensions= Cham}', "");
Expect(0, 43616, '\P{^Script_Extensions= Cham}', "");
Error('\p{Scx=:= _Cham}');
Error('\P{Scx=:= _Cham}');
Expect(1, 43615, '\p{Scx=cham}', "");
Expect(0, 43615, '\p{^Scx=cham}', "");
Expect(0, 43615, '\P{Scx=cham}', "");
Expect(1, 43615, '\P{^Scx=cham}', "");
Expect(0, 43616, '\p{Scx=cham}', "");
Expect(1, 43616, '\p{^Scx=cham}', "");
Expect(1, 43616, '\P{Scx=cham}', "");
Expect(0, 43616, '\P{^Scx=cham}', "");
Expect(1, 43615, '\p{Scx=	Cham}', "");
Expect(0, 43615, '\p{^Scx=	Cham}', "");
Expect(0, 43615, '\P{Scx=	Cham}', "");
Expect(1, 43615, '\P{^Scx=	Cham}', "");
Expect(0, 43616, '\p{Scx=	Cham}', "");
Expect(1, 43616, '\p{^Scx=	Cham}', "");
Expect(1, 43616, '\P{Scx=	Cham}', "");
Expect(0, 43616, '\P{^Scx=	Cham}', "");
Error('\p{Is_Script_Extensions= :=cham}');
Error('\P{Is_Script_Extensions= :=cham}');
Expect(1, 43615, '\p{Is_Script_Extensions=cham}', "");
Expect(0, 43615, '\p{^Is_Script_Extensions=cham}', "");
Expect(0, 43615, '\P{Is_Script_Extensions=cham}', "");
Expect(1, 43615, '\P{^Is_Script_Extensions=cham}', "");
Expect(0, 43616, '\p{Is_Script_Extensions=cham}', "");
Expect(1, 43616, '\p{^Is_Script_Extensions=cham}', "");
Expect(1, 43616, '\P{Is_Script_Extensions=cham}', "");
Expect(0, 43616, '\P{^Is_Script_Extensions=cham}', "");
Expect(1, 43615, '\p{Is_Script_Extensions= 	cham}', "");
Expect(0, 43615, '\p{^Is_Script_Extensions= 	cham}', "");
Expect(0, 43615, '\P{Is_Script_Extensions= 	cham}', "");
Expect(1, 43615, '\P{^Is_Script_Extensions= 	cham}', "");
Expect(0, 43616, '\p{Is_Script_Extensions= 	cham}', "");
Expect(1, 43616, '\p{^Is_Script_Extensions= 	cham}', "");
Expect(1, 43616, '\P{Is_Script_Extensions= 	cham}', "");
Expect(0, 43616, '\P{^Is_Script_Extensions= 	cham}', "");
Error('\p{Is_Scx: :=	-Cham}');
Error('\P{Is_Scx: :=	-Cham}');
Expect(1, 43615, '\p{Is_Scx=cham}', "");
Expect(0, 43615, '\p{^Is_Scx=cham}', "");
Expect(0, 43615, '\P{Is_Scx=cham}', "");
Expect(1, 43615, '\P{^Is_Scx=cham}', "");
Expect(0, 43616, '\p{Is_Scx=cham}', "");
Expect(1, 43616, '\p{^Is_Scx=cham}', "");
Expect(1, 43616, '\P{Is_Scx=cham}', "");
Expect(0, 43616, '\P{^Is_Scx=cham}', "");
Expect(1, 43615, '\p{Is_Scx= Cham}', "");
Expect(0, 43615, '\p{^Is_Scx= Cham}', "");
Expect(0, 43615, '\P{Is_Scx= Cham}', "");
Expect(1, 43615, '\P{^Is_Scx= Cham}', "");
Expect(0, 43616, '\p{Is_Scx= Cham}', "");
Expect(1, 43616, '\p{^Is_Scx= Cham}', "");
Expect(1, 43616, '\P{Is_Scx= Cham}', "");
Expect(0, 43616, '\P{^Is_Scx= Cham}', "");
Error('\p{Script_Extensions=:=_ Cherokee}');
Error('\P{Script_Extensions=:=_ Cherokee}');
Expect(1, 5108, '\p{Script_Extensions:cherokee}', "");
Expect(0, 5108, '\p{^Script_Extensions:cherokee}', "");
Expect(0, 5108, '\P{Script_Extensions:cherokee}', "");
Expect(1, 5108, '\P{^Script_Extensions:cherokee}', "");
Expect(0, 5109, '\p{Script_Extensions:cherokee}', "");
Expect(1, 5109, '\p{^Script_Extensions:cherokee}', "");
Expect(1, 5109, '\P{Script_Extensions:cherokee}', "");
Expect(0, 5109, '\P{^Script_Extensions:cherokee}', "");
Expect(1, 5108, '\p{Script_Extensions=-	CHEROKEE}', "");
Expect(0, 5108, '\p{^Script_Extensions=-	CHEROKEE}', "");
Expect(0, 5108, '\P{Script_Extensions=-	CHEROKEE}', "");
Expect(1, 5108, '\P{^Script_Extensions=-	CHEROKEE}', "");
Expect(0, 5109, '\p{Script_Extensions=-	CHEROKEE}', "");
Expect(1, 5109, '\p{^Script_Extensions=-	CHEROKEE}', "");
Expect(1, 5109, '\P{Script_Extensions=-	CHEROKEE}', "");
Expect(0, 5109, '\P{^Script_Extensions=-	CHEROKEE}', "");
Error('\p{Scx=:=  Cher}');
Error('\P{Scx=:=  Cher}');
Expect(1, 5108, '\p{Scx=cher}', "");
Expect(0, 5108, '\p{^Scx=cher}', "");
Expect(0, 5108, '\P{Scx=cher}', "");
Expect(1, 5108, '\P{^Scx=cher}', "");
Expect(0, 5109, '\p{Scx=cher}', "");
Expect(1, 5109, '\p{^Scx=cher}', "");
Expect(1, 5109, '\P{Scx=cher}', "");
Expect(0, 5109, '\P{^Scx=cher}', "");
Expect(1, 5108, '\p{Scx=_-CHER}', "");
Expect(0, 5108, '\p{^Scx=_-CHER}', "");
Expect(0, 5108, '\P{Scx=_-CHER}', "");
Expect(1, 5108, '\P{^Scx=_-CHER}', "");
Expect(0, 5109, '\p{Scx=_-CHER}', "");
Expect(1, 5109, '\p{^Scx=_-CHER}', "");
Expect(1, 5109, '\P{Scx=_-CHER}', "");
Expect(0, 5109, '\P{^Scx=_-CHER}', "");
Error('\p{Is_Script_Extensions=/a/ _cherokee}');
Error('\P{Is_Script_Extensions=/a/ _cherokee}');
Expect(1, 5108, '\p{Is_Script_Extensions=cherokee}', "");
Expect(0, 5108, '\p{^Is_Script_Extensions=cherokee}', "");
Expect(0, 5108, '\P{Is_Script_Extensions=cherokee}', "");
Expect(1, 5108, '\P{^Is_Script_Extensions=cherokee}', "");
Expect(0, 5109, '\p{Is_Script_Extensions=cherokee}', "");
Expect(1, 5109, '\p{^Is_Script_Extensions=cherokee}', "");
Expect(1, 5109, '\P{Is_Script_Extensions=cherokee}', "");
Expect(0, 5109, '\P{^Is_Script_Extensions=cherokee}', "");
Expect(1, 5108, '\p{Is_Script_Extensions=_cherokee}', "");
Expect(0, 5108, '\p{^Is_Script_Extensions=_cherokee}', "");
Expect(0, 5108, '\P{Is_Script_Extensions=_cherokee}', "");
Expect(1, 5108, '\P{^Is_Script_Extensions=_cherokee}', "");
Expect(0, 5109, '\p{Is_Script_Extensions=_cherokee}', "");
Expect(1, 5109, '\p{^Is_Script_Extensions=_cherokee}', "");
Expect(1, 5109, '\P{Is_Script_Extensions=_cherokee}', "");
Expect(0, 5109, '\P{^Is_Script_Extensions=_cherokee}', "");
Error('\p{Is_Scx=/a/	Cher}');
Error('\P{Is_Scx=/a/	Cher}');
Expect(1, 5108, '\p{Is_Scx=cher}', "");
Expect(0, 5108, '\p{^Is_Scx=cher}', "");
Expect(0, 5108, '\P{Is_Scx=cher}', "");
Expect(1, 5108, '\P{^Is_Scx=cher}', "");
Expect(0, 5109, '\p{Is_Scx=cher}', "");
Expect(1, 5109, '\p{^Is_Scx=cher}', "");
Expect(1, 5109, '\P{Is_Scx=cher}', "");
Expect(0, 5109, '\P{^Is_Scx=cher}', "");
Expect(1, 5108, '\p{Is_Scx=_cher}', "");
Expect(0, 5108, '\p{^Is_Scx=_cher}', "");
Expect(0, 5108, '\P{Is_Scx=_cher}', "");
Expect(1, 5108, '\P{^Is_Scx=_cher}', "");
Expect(0, 5109, '\p{Is_Scx=_cher}', "");
Expect(1, 5109, '\p{^Is_Scx=_cher}', "");
Expect(1, 5109, '\P{Is_Scx=_cher}', "");
Expect(0, 5109, '\P{^Is_Scx=_cher}', "");
Error('\p{Script_Extensions= 	Coptic/a/}');
Error('\P{Script_Extensions= 	Coptic/a/}');
Expect(1, 11519, '\p{Script_Extensions:coptic}', "");
Expect(0, 11519, '\p{^Script_Extensions:coptic}', "");
Expect(0, 11519, '\P{Script_Extensions:coptic}', "");
Expect(1, 11519, '\P{^Script_Extensions:coptic}', "");
Expect(0, 11520, '\p{Script_Extensions:coptic}', "");
Expect(1, 11520, '\p{^Script_Extensions:coptic}', "");
Expect(1, 11520, '\P{Script_Extensions:coptic}', "");
Expect(0, 11520, '\P{^Script_Extensions:coptic}', "");
Expect(1, 11519, '\p{Script_Extensions=	COPTIC}', "");
Expect(0, 11519, '\p{^Script_Extensions=	COPTIC}', "");
Expect(0, 11519, '\P{Script_Extensions=	COPTIC}', "");
Expect(1, 11519, '\P{^Script_Extensions=	COPTIC}', "");
Expect(0, 11520, '\p{Script_Extensions=	COPTIC}', "");
Expect(1, 11520, '\p{^Script_Extensions=	COPTIC}', "");
Expect(1, 11520, '\P{Script_Extensions=	COPTIC}', "");
Expect(0, 11520, '\P{^Script_Extensions=	COPTIC}', "");
Error('\p{Scx=/a/-copt}');
Error('\P{Scx=/a/-copt}');
Expect(1, 11519, '\p{Scx=copt}', "");
Expect(0, 11519, '\p{^Scx=copt}', "");
Expect(0, 11519, '\P{Scx=copt}', "");
Expect(1, 11519, '\P{^Scx=copt}', "");
Expect(0, 11520, '\p{Scx=copt}', "");
Expect(1, 11520, '\p{^Scx=copt}', "");
Expect(1, 11520, '\P{Scx=copt}', "");
Expect(0, 11520, '\P{^Scx=copt}', "");
Expect(1, 11519, '\p{Scx= copt}', "");
Expect(0, 11519, '\p{^Scx= copt}', "");
Expect(0, 11519, '\P{Scx= copt}', "");
Expect(1, 11519, '\P{^Scx= copt}', "");
Expect(0, 11520, '\p{Scx= copt}', "");
Expect(1, 11520, '\p{^Scx= copt}', "");
Expect(1, 11520, '\P{Scx= copt}', "");
Expect(0, 11520, '\P{^Scx= copt}', "");
Error('\p{Is_Script_Extensions= qaac:=}');
Error('\P{Is_Script_Extensions= qaac:=}');
Expect(1, 11519, '\p{Is_Script_Extensions:qaac}', "");
Expect(0, 11519, '\p{^Is_Script_Extensions:qaac}', "");
Expect(0, 11519, '\P{Is_Script_Extensions:qaac}', "");
Expect(1, 11519, '\P{^Is_Script_Extensions:qaac}', "");
Expect(0, 11520, '\p{Is_Script_Extensions:qaac}', "");
Expect(1, 11520, '\p{^Is_Script_Extensions:qaac}', "");
Expect(1, 11520, '\P{Is_Script_Extensions:qaac}', "");
Expect(0, 11520, '\P{^Is_Script_Extensions:qaac}', "");
Expect(1, 11519, '\p{Is_Script_Extensions:	-Qaac}', "");
Expect(0, 11519, '\p{^Is_Script_Extensions:	-Qaac}', "");
Expect(0, 11519, '\P{Is_Script_Extensions:	-Qaac}', "");
Expect(1, 11519, '\P{^Is_Script_Extensions:	-Qaac}', "");
Expect(0, 11520, '\p{Is_Script_Extensions:	-Qaac}', "");
Expect(1, 11520, '\p{^Is_Script_Extensions:	-Qaac}', "");
Expect(1, 11520, '\P{Is_Script_Extensions:	-Qaac}', "");
Expect(0, 11520, '\P{^Is_Script_Extensions:	-Qaac}', "");
Error('\p{Is_Scx=_	Coptic/a/}');
Error('\P{Is_Scx=_	Coptic/a/}');
Expect(1, 11519, '\p{Is_Scx=coptic}', "");
Expect(0, 11519, '\p{^Is_Scx=coptic}', "");
Expect(0, 11519, '\P{Is_Scx=coptic}', "");
Expect(1, 11519, '\P{^Is_Scx=coptic}', "");
Expect(0, 11520, '\p{Is_Scx=coptic}', "");
Expect(1, 11520, '\p{^Is_Scx=coptic}', "");
Expect(1, 11520, '\P{Is_Scx=coptic}', "");
Expect(0, 11520, '\P{^Is_Scx=coptic}', "");
Expect(1, 11519, '\p{Is_Scx=_coptic}', "");
Expect(0, 11519, '\p{^Is_Scx=_coptic}', "");
Expect(0, 11519, '\P{Is_Scx=_coptic}', "");
Expect(1, 11519, '\P{^Is_Scx=_coptic}', "");
Expect(0, 11520, '\p{Is_Scx=_coptic}', "");
Expect(1, 11520, '\p{^Is_Scx=_coptic}', "");
Expect(1, 11520, '\P{Is_Scx=_coptic}', "");
Expect(0, 11520, '\P{^Is_Scx=_coptic}', "");
Error('\p{Script_Extensions:	 CYPRIOT/a/}');
Error('\P{Script_Extensions:	 CYPRIOT/a/}');
Expect(1, 67647, '\p{Script_Extensions=cypriot}', "");
Expect(0, 67647, '\p{^Script_Extensions=cypriot}', "");
Expect(0, 67647, '\P{Script_Extensions=cypriot}', "");
Expect(1, 67647, '\P{^Script_Extensions=cypriot}', "");
Expect(0, 67648, '\p{Script_Extensions=cypriot}', "");
Expect(1, 67648, '\p{^Script_Extensions=cypriot}', "");
Expect(1, 67648, '\P{Script_Extensions=cypriot}', "");
Expect(0, 67648, '\P{^Script_Extensions=cypriot}', "");
Expect(1, 67647, '\p{Script_Extensions= Cypriot}', "");
Expect(0, 67647, '\p{^Script_Extensions= Cypriot}', "");
Expect(0, 67647, '\P{Script_Extensions= Cypriot}', "");
Expect(1, 67647, '\P{^Script_Extensions= Cypriot}', "");
Expect(0, 67648, '\p{Script_Extensions= Cypriot}', "");
Expect(1, 67648, '\p{^Script_Extensions= Cypriot}', "");
Expect(1, 67648, '\P{Script_Extensions= Cypriot}', "");
Expect(0, 67648, '\P{^Script_Extensions= Cypriot}', "");
Error('\p{Scx:	:=CPRT}');
Error('\P{Scx:	:=CPRT}');
Expect(1, 67647, '\p{Scx=cprt}', "");
Expect(0, 67647, '\p{^Scx=cprt}', "");
Expect(0, 67647, '\P{Scx=cprt}', "");
Expect(1, 67647, '\P{^Scx=cprt}', "");
Expect(0, 67648, '\p{Scx=cprt}', "");
Expect(1, 67648, '\p{^Scx=cprt}', "");
Expect(1, 67648, '\P{Scx=cprt}', "");
Expect(0, 67648, '\P{^Scx=cprt}', "");
Expect(1, 67647, '\p{Scx=-cprt}', "");
Expect(0, 67647, '\p{^Scx=-cprt}', "");
Expect(0, 67647, '\P{Scx=-cprt}', "");
Expect(1, 67647, '\P{^Scx=-cprt}', "");
Expect(0, 67648, '\p{Scx=-cprt}', "");
Expect(1, 67648, '\p{^Scx=-cprt}', "");
Expect(1, 67648, '\P{Scx=-cprt}', "");
Expect(0, 67648, '\P{^Scx=-cprt}', "");
Error('\p{Is_Script_Extensions=:=		CYPRIOT}');
Error('\P{Is_Script_Extensions=:=		CYPRIOT}');
Expect(1, 67647, '\p{Is_Script_Extensions=cypriot}', "");
Expect(0, 67647, '\p{^Is_Script_Extensions=cypriot}', "");
Expect(0, 67647, '\P{Is_Script_Extensions=cypriot}', "");
Expect(1, 67647, '\P{^Is_Script_Extensions=cypriot}', "");
Expect(0, 67648, '\p{Is_Script_Extensions=cypriot}', "");
Expect(1, 67648, '\p{^Is_Script_Extensions=cypriot}', "");
Expect(1, 67648, '\P{Is_Script_Extensions=cypriot}', "");
Expect(0, 67648, '\P{^Is_Script_Extensions=cypriot}', "");
Expect(1, 67647, '\p{Is_Script_Extensions:		CYPRIOT}', "");
Expect(0, 67647, '\p{^Is_Script_Extensions:		CYPRIOT}', "");
Expect(0, 67647, '\P{Is_Script_Extensions:		CYPRIOT}', "");
Expect(1, 67647, '\P{^Is_Script_Extensions:		CYPRIOT}', "");
Expect(0, 67648, '\p{Is_Script_Extensions:		CYPRIOT}', "");
Expect(1, 67648, '\p{^Is_Script_Extensions:		CYPRIOT}', "");
Expect(1, 67648, '\P{Is_Script_Extensions:		CYPRIOT}', "");
Expect(0, 67648, '\P{^Is_Script_Extensions:		CYPRIOT}', "");
Error('\p{Is_Scx=-/a/CPRT}');
Error('\P{Is_Scx=-/a/CPRT}');
Expect(1, 67647, '\p{Is_Scx=cprt}', "");
Expect(0, 67647, '\p{^Is_Scx=cprt}', "");
Expect(0, 67647, '\P{Is_Scx=cprt}', "");
Expect(1, 67647, '\P{^Is_Scx=cprt}', "");
Expect(0, 67648, '\p{Is_Scx=cprt}', "");
Expect(1, 67648, '\p{^Is_Scx=cprt}', "");
Expect(1, 67648, '\P{Is_Scx=cprt}', "");
Expect(0, 67648, '\P{^Is_Scx=cprt}', "");
Expect(1, 67647, '\p{Is_Scx: _-CPRT}', "");
Expect(0, 67647, '\p{^Is_Scx: _-CPRT}', "");
Expect(0, 67647, '\P{Is_Scx: _-CPRT}', "");
Expect(1, 67647, '\P{^Is_Scx: _-CPRT}', "");
Expect(0, 67648, '\p{Is_Scx: _-CPRT}', "");
Expect(1, 67648, '\p{^Is_Scx: _-CPRT}', "");
Expect(1, 67648, '\P{Is_Scx: _-CPRT}', "");
Expect(0, 67648, '\P{^Is_Scx: _-CPRT}', "");
Error('\p{Script_Extensions=/a/cyrillic}');
Error('\P{Script_Extensions=/a/cyrillic}');
Expect(1, 42655, '\p{Script_Extensions=cyrillic}', "");
Expect(0, 42655, '\p{^Script_Extensions=cyrillic}', "");
Expect(0, 42655, '\P{Script_Extensions=cyrillic}', "");
Expect(1, 42655, '\P{^Script_Extensions=cyrillic}', "");
Expect(0, 42656, '\p{Script_Extensions=cyrillic}', "");
Expect(1, 42656, '\p{^Script_Extensions=cyrillic}', "");
Expect(1, 42656, '\P{Script_Extensions=cyrillic}', "");
Expect(0, 42656, '\P{^Script_Extensions=cyrillic}', "");
Expect(1, 42655, '\p{Script_Extensions=	 cyrillic}', "");
Expect(0, 42655, '\p{^Script_Extensions=	 cyrillic}', "");
Expect(0, 42655, '\P{Script_Extensions=	 cyrillic}', "");
Expect(1, 42655, '\P{^Script_Extensions=	 cyrillic}', "");
Expect(0, 42656, '\p{Script_Extensions=	 cyrillic}', "");
Expect(1, 42656, '\p{^Script_Extensions=	 cyrillic}', "");
Expect(1, 42656, '\P{Script_Extensions=	 cyrillic}', "");
Expect(0, 42656, '\P{^Script_Extensions=	 cyrillic}', "");
Error('\p{Scx=	:=CYRL}');
Error('\P{Scx=	:=CYRL}');
Expect(1, 42655, '\p{Scx=cyrl}', "");
Expect(0, 42655, '\p{^Scx=cyrl}', "");
Expect(0, 42655, '\P{Scx=cyrl}', "");
Expect(1, 42655, '\P{^Scx=cyrl}', "");
Expect(0, 42656, '\p{Scx=cyrl}', "");
Expect(1, 42656, '\p{^Scx=cyrl}', "");
Expect(1, 42656, '\P{Scx=cyrl}', "");
Expect(0, 42656, '\P{^Scx=cyrl}', "");
Expect(1, 42655, '\p{Scx= _Cyrl}', "");
Expect(0, 42655, '\p{^Scx= _Cyrl}', "");
Expect(0, 42655, '\P{Scx= _Cyrl}', "");
Expect(1, 42655, '\P{^Scx= _Cyrl}', "");
Expect(0, 42656, '\p{Scx= _Cyrl}', "");
Expect(1, 42656, '\p{^Scx= _Cyrl}', "");
Expect(1, 42656, '\P{Scx= _Cyrl}', "");
Expect(0, 42656, '\P{^Scx= _Cyrl}', "");
Error('\p{Is_Script_Extensions:/a/  cyrillic}');
Error('\P{Is_Script_Extensions:/a/  cyrillic}');
Expect(1, 42655, '\p{Is_Script_Extensions:cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script_Extensions:cyrillic}', "");
Expect(0, 42655, '\P{Is_Script_Extensions:cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script_Extensions:cyrillic}', "");
Expect(0, 42656, '\p{Is_Script_Extensions:cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script_Extensions:cyrillic}', "");
Expect(1, 42656, '\P{Is_Script_Extensions:cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script_Extensions:cyrillic}', "");
Expect(1, 42655, '\p{Is_Script_Extensions= cyrillic}', "");
Expect(0, 42655, '\p{^Is_Script_Extensions= cyrillic}', "");
Expect(0, 42655, '\P{Is_Script_Extensions= cyrillic}', "");
Expect(1, 42655, '\P{^Is_Script_Extensions= cyrillic}', "");
Expect(0, 42656, '\p{Is_Script_Extensions= cyrillic}', "");
Expect(1, 42656, '\p{^Is_Script_Extensions= cyrillic}', "");
Expect(1, 42656, '\P{Is_Script_Extensions= cyrillic}', "");
Expect(0, 42656, '\P{^Is_Script_Extensions= cyrillic}', "");
Error('\p{Is_Scx=/a/cyrl}');
Error('\P{Is_Scx=/a/cyrl}');
Expect(1, 42655, '\p{Is_Scx=cyrl}', "");
Expect(0, 42655, '\p{^Is_Scx=cyrl}', "");
Expect(0, 42655, '\P{Is_Scx=cyrl}', "");
Expect(1, 42655, '\P{^Is_Scx=cyrl}', "");
Expect(0, 42656, '\p{Is_Scx=cyrl}', "");
Expect(1, 42656, '\p{^Is_Scx=cyrl}', "");
Expect(1, 42656, '\P{Is_Scx=cyrl}', "");
Expect(0, 42656, '\P{^Is_Scx=cyrl}', "");
Expect(1, 42655, '\p{Is_Scx=_	cyrl}', "");
Expect(0, 42655, '\p{^Is_Scx=_	cyrl}', "");
Expect(0, 42655, '\P{Is_Scx=_	cyrl}', "");
Expect(1, 42655, '\P{^Is_Scx=_	cyrl}', "");
Expect(0, 42656, '\p{Is_Scx=_	cyrl}', "");
Expect(1, 42656, '\p{^Is_Scx=_	cyrl}', "");
Expect(1, 42656, '\P{Is_Scx=_	cyrl}', "");
Expect(0, 42656, '\P{^Is_Scx=_	cyrl}', "");
Error('\p{Script_Extensions=/a/-_DEVANAGARI}');
Error('\P{Script_Extensions=/a/-_DEVANAGARI}');
Expect(1, 43259, '\p{Script_Extensions=devanagari}', "");
Expect(0, 43259, '\p{^Script_Extensions=devanagari}', "");
Expect(0, 43259, '\P{Script_Extensions=devanagari}', "");
Expect(1, 43259, '\P{^Script_Extensions=devanagari}', "");
Expect(0, 43260, '\p{Script_Extensions=devanagari}', "");
Expect(1, 43260, '\p{^Script_Extensions=devanagari}', "");
Expect(1, 43260, '\P{Script_Extensions=devanagari}', "");
Expect(0, 43260, '\P{^Script_Extensions=devanagari}', "");
Expect(1, 43259, '\p{Script_Extensions=-_Devanagari}', "");
Expect(0, 43259, '\p{^Script_Extensions=-_Devanagari}', "");
Expect(0, 43259, '\P{Script_Extensions=-_Devanagari}', "");
Expect(1, 43259, '\P{^Script_Extensions=-_Devanagari}', "");
Expect(0, 43260, '\p{Script_Extensions=-_Devanagari}', "");
Expect(1, 43260, '\p{^Script_Extensions=-_Devanagari}', "");
Expect(1, 43260, '\P{Script_Extensions=-_Devanagari}', "");
Expect(0, 43260, '\P{^Script_Extensions=-_Devanagari}', "");
Error('\p{Scx= /a/Deva}');
Error('\P{Scx= /a/Deva}');
Expect(1, 43259, '\p{Scx=deva}', "");
Expect(0, 43259, '\p{^Scx=deva}', "");
Expect(0, 43259, '\P{Scx=deva}', "");
Expect(1, 43259, '\P{^Scx=deva}', "");
Expect(0, 43260, '\p{Scx=deva}', "");
Expect(1, 43260, '\p{^Scx=deva}', "");
Expect(1, 43260, '\P{Scx=deva}', "");
Expect(0, 43260, '\P{^Scx=deva}', "");
Expect(1, 43259, '\p{Scx:		-DEVA}', "");
Expect(0, 43259, '\p{^Scx:		-DEVA}', "");
Expect(0, 43259, '\P{Scx:		-DEVA}', "");
Expect(1, 43259, '\P{^Scx:		-DEVA}', "");
Expect(0, 43260, '\p{Scx:		-DEVA}', "");
Expect(1, 43260, '\p{^Scx:		-DEVA}', "");
Expect(1, 43260, '\P{Scx:		-DEVA}', "");
Expect(0, 43260, '\P{^Scx:		-DEVA}', "");
Error('\p{Is_Script_Extensions=:=- DEVANAGARI}');
Error('\P{Is_Script_Extensions=:=- DEVANAGARI}');
Expect(1, 43259, '\p{Is_Script_Extensions=devanagari}', "");
Expect(0, 43259, '\p{^Is_Script_Extensions=devanagari}', "");
Expect(0, 43259, '\P{Is_Script_Extensions=devanagari}', "");
Expect(1, 43259, '\P{^Is_Script_Extensions=devanagari}', "");
Expect(0, 43260, '\p{Is_Script_Extensions=devanagari}', "");
Expect(1, 43260, '\p{^Is_Script_Extensions=devanagari}', "");
Expect(1, 43260, '\P{Is_Script_Extensions=devanagari}', "");
Expect(0, 43260, '\P{^Is_Script_Extensions=devanagari}', "");
Expect(1, 43259, '\p{Is_Script_Extensions=-_Devanagari}', "");
Expect(0, 43259, '\p{^Is_Script_Extensions=-_Devanagari}', "");
Expect(0, 43259, '\P{Is_Script_Extensions=-_Devanagari}', "");
Expect(1, 43259, '\P{^Is_Script_Extensions=-_Devanagari}', "");
Expect(0, 43260, '\p{Is_Script_Extensions=-_Devanagari}', "");
Expect(1, 43260, '\p{^Is_Script_Extensions=-_Devanagari}', "");
Expect(1, 43260, '\P{Is_Script_Extensions=-_Devanagari}', "");
Expect(0, 43260, '\P{^Is_Script_Extensions=-_Devanagari}', "");
Error('\p{Is_Scx= 	Deva/a/}');
Error('\P{Is_Scx= 	Deva/a/}');
Expect(1, 43259, '\p{Is_Scx=deva}', "");
Expect(0, 43259, '\p{^Is_Scx=deva}', "");
Expect(0, 43259, '\P{Is_Scx=deva}', "");
Expect(1, 43259, '\P{^Is_Scx=deva}', "");
Expect(0, 43260, '\p{Is_Scx=deva}', "");
Expect(1, 43260, '\p{^Is_Scx=deva}', "");
Expect(1, 43260, '\P{Is_Scx=deva}', "");
Expect(0, 43260, '\P{^Is_Scx=deva}', "");
Expect(1, 43259, '\p{Is_Scx=--Deva}', "");
Expect(0, 43259, '\p{^Is_Scx=--Deva}', "");
Expect(0, 43259, '\P{Is_Scx=--Deva}', "");
Expect(1, 43259, '\P{^Is_Scx=--Deva}', "");
Expect(0, 43260, '\p{Is_Scx=--Deva}', "");
Expect(1, 43260, '\p{^Is_Scx=--Deva}', "");
Expect(1, 43260, '\P{Is_Scx=--Deva}', "");
Expect(0, 43260, '\P{^Is_Scx=--Deva}', "");
Error('\p{Script_Extensions= _Deseret/a/}');
Error('\P{Script_Extensions= _Deseret/a/}');
Expect(1, 66639, '\p{Script_Extensions=deseret}', "");
Expect(0, 66639, '\p{^Script_Extensions=deseret}', "");
Expect(0, 66639, '\P{Script_Extensions=deseret}', "");
Expect(1, 66639, '\P{^Script_Extensions=deseret}', "");
Expect(0, 66640, '\p{Script_Extensions=deseret}', "");
Expect(1, 66640, '\p{^Script_Extensions=deseret}', "");
Expect(1, 66640, '\P{Script_Extensions=deseret}', "");
Expect(0, 66640, '\P{^Script_Extensions=deseret}', "");
Expect(1, 66639, '\p{Script_Extensions=--Deseret}', "");
Expect(0, 66639, '\p{^Script_Extensions=--Deseret}', "");
Expect(0, 66639, '\P{Script_Extensions=--Deseret}', "");
Expect(1, 66639, '\P{^Script_Extensions=--Deseret}', "");
Expect(0, 66640, '\p{Script_Extensions=--Deseret}', "");
Expect(1, 66640, '\p{^Script_Extensions=--Deseret}', "");
Expect(1, 66640, '\P{Script_Extensions=--Deseret}', "");
Expect(0, 66640, '\P{^Script_Extensions=--Deseret}', "");
Error('\p{Scx=	 Dsrt/a/}');
Error('\P{Scx=	 Dsrt/a/}');
Expect(1, 66639, '\p{Scx=dsrt}', "");
Expect(0, 66639, '\p{^Scx=dsrt}', "");
Expect(0, 66639, '\P{Scx=dsrt}', "");
Expect(1, 66639, '\P{^Scx=dsrt}', "");
Expect(0, 66640, '\p{Scx=dsrt}', "");
Expect(1, 66640, '\p{^Scx=dsrt}', "");
Expect(1, 66640, '\P{Scx=dsrt}', "");
Expect(0, 66640, '\P{^Scx=dsrt}', "");
Expect(1, 66639, '\p{Scx=--dsrt}', "");
Expect(0, 66639, '\p{^Scx=--dsrt}', "");
Expect(0, 66639, '\P{Scx=--dsrt}', "");
Expect(1, 66639, '\P{^Scx=--dsrt}', "");
Expect(0, 66640, '\p{Scx=--dsrt}', "");
Expect(1, 66640, '\p{^Scx=--dsrt}', "");
Expect(1, 66640, '\P{Scx=--dsrt}', "");
Expect(0, 66640, '\P{^Scx=--dsrt}', "");
Error('\p{Is_Script_Extensions=-_DESERET/a/}');
Error('\P{Is_Script_Extensions=-_DESERET/a/}');
Expect(1, 66639, '\p{Is_Script_Extensions=deseret}', "");
Expect(0, 66639, '\p{^Is_Script_Extensions=deseret}', "");
Expect(0, 66639, '\P{Is_Script_Extensions=deseret}', "");
Expect(1, 66639, '\P{^Is_Script_Extensions=deseret}', "");
Expect(0, 66640, '\p{Is_Script_Extensions=deseret}', "");
Expect(1, 66640, '\p{^Is_Script_Extensions=deseret}', "");
Expect(1, 66640, '\P{Is_Script_Extensions=deseret}', "");
Expect(0, 66640, '\P{^Is_Script_Extensions=deseret}', "");
Expect(1, 66639, '\p{Is_Script_Extensions=- Deseret}', "");
Expect(0, 66639, '\p{^Is_Script_Extensions=- Deseret}', "");
Expect(0, 66639, '\P{Is_Script_Extensions=- Deseret}', "");
Expect(1, 66639, '\P{^Is_Script_Extensions=- Deseret}', "");
Expect(0, 66640, '\p{Is_Script_Extensions=- Deseret}', "");
Expect(1, 66640, '\p{^Is_Script_Extensions=- Deseret}', "");
Expect(1, 66640, '\P{Is_Script_Extensions=- Deseret}', "");
Expect(0, 66640, '\P{^Is_Script_Extensions=- Deseret}', "");
Error('\p{Is_Scx=_:=Dsrt}');
Error('\P{Is_Scx=_:=Dsrt}');
Expect(1, 66639, '\p{Is_Scx=dsrt}', "");
Expect(0, 66639, '\p{^Is_Scx=dsrt}', "");
Expect(0, 66639, '\P{Is_Scx=dsrt}', "");
Expect(1, 66639, '\P{^Is_Scx=dsrt}', "");
Expect(0, 66640, '\p{Is_Scx=dsrt}', "");
Expect(1, 66640, '\p{^Is_Scx=dsrt}', "");
Expect(1, 66640, '\P{Is_Scx=dsrt}', "");
Expect(0, 66640, '\P{^Is_Scx=dsrt}', "");
Expect(1, 66639, '\p{Is_Scx=_Dsrt}', "");
Expect(0, 66639, '\p{^Is_Scx=_Dsrt}', "");
Expect(0, 66639, '\P{Is_Scx=_Dsrt}', "");
Expect(1, 66639, '\P{^Is_Scx=_Dsrt}', "");
Expect(0, 66640, '\p{Is_Scx=_Dsrt}', "");
Expect(1, 66640, '\p{^Is_Scx=_Dsrt}', "");
Expect(1, 66640, '\P{Is_Scx=_Dsrt}', "");
Expect(0, 66640, '\P{^Is_Scx=_Dsrt}', "");
Error('\p{Script_Extensions:   :=_	Egyptian_HIEROGLYPHS}');
Error('\P{Script_Extensions:   :=_	Egyptian_HIEROGLYPHS}');
Expect(1, 78894, '\p{Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(0, 78894, '\p{^Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(0, 78894, '\P{Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(1, 78894, '\P{^Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(0, 78895, '\p{Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(1, 78895, '\p{^Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(1, 78895, '\P{Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Expect(0, 78895, '\P{^Script_Extensions=	EGYPTIAN_hieroglyphs}', "");
Error('\p{Scx= :=EGYP}');
Error('\P{Scx= :=EGYP}');
Expect(1, 78894, '\p{Scx=egyp}', "");
Expect(0, 78894, '\p{^Scx=egyp}', "");
Expect(0, 78894, '\P{Scx=egyp}', "");
Expect(1, 78894, '\P{^Scx=egyp}', "");
Expect(0, 78895, '\p{Scx=egyp}', "");
Expect(1, 78895, '\p{^Scx=egyp}', "");
Expect(1, 78895, '\P{Scx=egyp}', "");
Expect(0, 78895, '\P{^Scx=egyp}', "");
Expect(1, 78894, '\p{Scx=	_Egyp}', "");
Expect(0, 78894, '\p{^Scx=	_Egyp}', "");
Expect(0, 78894, '\P{Scx=	_Egyp}', "");
Expect(1, 78894, '\P{^Scx=	_Egyp}', "");
Expect(0, 78895, '\p{Scx=	_Egyp}', "");
Expect(1, 78895, '\p{^Scx=	_Egyp}', "");
Expect(1, 78895, '\P{Scx=	_Egyp}', "");
Expect(0, 78895, '\P{^Scx=	_Egyp}', "");
Error('\p{Is_Script_Extensions=:=_	egyptian_hieroglyphs}');
Error('\P{Is_Script_Extensions=:=_	egyptian_hieroglyphs}');
Expect(1, 78894, '\p{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\p{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78894, '\P{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\P{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\p{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\p{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78895, '\P{Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(0, 78895, '\P{^Is_Script_Extensions=egyptianhieroglyphs}', "");
Expect(1, 78894, '\p{Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(0, 78894, '\p{^Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(0, 78894, '\P{Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(1, 78894, '\P{^Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\p{Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(1, 78895, '\p{^Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(1, 78895, '\P{Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Expect(0, 78895, '\P{^Is_Script_Extensions=	_Egyptian_HIEROGLYPHS}', "");
Error('\p{Is_Scx=:=	-egyp}');
Error('\P{Is_Scx=:=	-egyp}');
Expect(1, 78894, '\p{Is_Scx=egyp}', "");
Expect(0, 78894, '\p{^Is_Scx=egyp}', "");
Expect(0, 78894, '\P{Is_Scx=egyp}', "");
Expect(1, 78894, '\P{^Is_Scx=egyp}', "");
Expect(0, 78895, '\p{Is_Scx=egyp}', "");
Expect(1, 78895, '\p{^Is_Scx=egyp}', "");
Expect(1, 78895, '\P{Is_Scx=egyp}', "");
Expect(0, 78895, '\P{^Is_Scx=egyp}', "");
Expect(1, 78894, '\p{Is_Scx=	Egyp}', "");
Expect(0, 78894, '\p{^Is_Scx=	Egyp}', "");
Expect(0, 78894, '\P{Is_Scx=	Egyp}', "");
Expect(1, 78894, '\P{^Is_Scx=	Egyp}', "");
Expect(0, 78895, '\p{Is_Scx=	Egyp}', "");
Expect(1, 78895, '\p{^Is_Scx=	Egyp}', "");
Expect(1, 78895, '\P{Is_Scx=	Egyp}', "");
Expect(0, 78895, '\P{^Is_Scx=	Egyp}', "");
Error('\p{Script_Extensions=/a/_ethiopic}');
Error('\P{Script_Extensions=/a/_ethiopic}');
Expect(1, 43822, '\p{Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\p{^Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\P{Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\P{^Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\p{Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\p{^Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\P{Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\P{^Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\p{Script_Extensions= -ETHIOPIC}', "");
Expect(0, 43822, '\p{^Script_Extensions= -ETHIOPIC}', "");
Expect(0, 43822, '\P{Script_Extensions= -ETHIOPIC}', "");
Expect(1, 43822, '\P{^Script_Extensions= -ETHIOPIC}', "");
Expect(0, 43823, '\p{Script_Extensions= -ETHIOPIC}', "");
Expect(1, 43823, '\p{^Script_Extensions= -ETHIOPIC}', "");
Expect(1, 43823, '\P{Script_Extensions= -ETHIOPIC}', "");
Expect(0, 43823, '\P{^Script_Extensions= -ETHIOPIC}', "");
Error('\p{Scx=:=_ethi}');
Error('\P{Scx=:=_ethi}');
Expect(1, 43822, '\p{Scx=ethi}', "");
Expect(0, 43822, '\p{^Scx=ethi}', "");
Expect(0, 43822, '\P{Scx=ethi}', "");
Expect(1, 43822, '\P{^Scx=ethi}', "");
Expect(0, 43823, '\p{Scx=ethi}', "");
Expect(1, 43823, '\p{^Scx=ethi}', "");
Expect(1, 43823, '\P{Scx=ethi}', "");
Expect(0, 43823, '\P{^Scx=ethi}', "");
Expect(1, 43822, '\p{Scx=	-ethi}', "");
Expect(0, 43822, '\p{^Scx=	-ethi}', "");
Expect(0, 43822, '\P{Scx=	-ethi}', "");
Expect(1, 43822, '\P{^Scx=	-ethi}', "");
Expect(0, 43823, '\p{Scx=	-ethi}', "");
Expect(1, 43823, '\p{^Scx=	-ethi}', "");
Expect(1, 43823, '\P{Scx=	-ethi}', "");
Expect(0, 43823, '\P{^Scx=	-ethi}', "");
Error('\p{Is_Script_Extensions=_:=Ethiopic}');
Error('\P{Is_Script_Extensions=_:=Ethiopic}');
Expect(1, 43822, '\p{Is_Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script_Extensions=ethiopic}', "");
Expect(0, 43822, '\P{Is_Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\p{Is_Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script_Extensions=ethiopic}', "");
Expect(1, 43823, '\P{Is_Script_Extensions=ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script_Extensions=ethiopic}', "");
Expect(1, 43822, '\p{Is_Script_Extensions=-_ethiopic}', "");
Expect(0, 43822, '\p{^Is_Script_Extensions=-_ethiopic}', "");
Expect(0, 43822, '\P{Is_Script_Extensions=-_ethiopic}', "");
Expect(1, 43822, '\P{^Is_Script_Extensions=-_ethiopic}', "");
Expect(0, 43823, '\p{Is_Script_Extensions=-_ethiopic}', "");
Expect(1, 43823, '\p{^Is_Script_Extensions=-_ethiopic}', "");
Expect(1, 43823, '\P{Is_Script_Extensions=-_ethiopic}', "");
Expect(0, 43823, '\P{^Is_Script_Extensions=-_ethiopic}', "");
Error('\p{Is_Scx= ethi:=}');
Error('\P{Is_Scx= ethi:=}');
Expect(1, 43822, '\p{Is_Scx=ethi}', "");
Expect(0, 43822, '\p{^Is_Scx=ethi}', "");
Expect(0, 43822, '\P{Is_Scx=ethi}', "");
Expect(1, 43822, '\P{^Is_Scx=ethi}', "");
Expect(0, 43823, '\p{Is_Scx=ethi}', "");
Expect(1, 43823, '\p{^Is_Scx=ethi}', "");
Expect(1, 43823, '\P{Is_Scx=ethi}', "");
Expect(0, 43823, '\P{^Is_Scx=ethi}', "");
Expect(1, 43822, '\p{Is_Scx: __ethi}', "");
Expect(0, 43822, '\p{^Is_Scx: __ethi}', "");
Expect(0, 43822, '\P{Is_Scx: __ethi}', "");
Expect(1, 43822, '\P{^Is_Scx: __ethi}', "");
Expect(0, 43823, '\p{Is_Scx: __ethi}', "");
Expect(1, 43823, '\p{^Is_Scx: __ethi}', "");
Expect(1, 43823, '\P{Is_Scx: __ethi}', "");
Expect(0, 43823, '\P{^Is_Scx: __ethi}', "");
Error('\p{Script_Extensions=	 GEORGIAN/a/}');
Error('\P{Script_Extensions=	 GEORGIAN/a/}');
Expect(1, 11565, '\p{Script_Extensions=georgian}', "");
Expect(0, 11565, '\p{^Script_Extensions=georgian}', "");
Expect(0, 11565, '\P{Script_Extensions=georgian}', "");
Expect(1, 11565, '\P{^Script_Extensions=georgian}', "");
Expect(0, 11566, '\p{Script_Extensions=georgian}', "");
Expect(1, 11566, '\p{^Script_Extensions=georgian}', "");
Expect(1, 11566, '\P{Script_Extensions=georgian}', "");
Expect(0, 11566, '\P{^Script_Extensions=georgian}', "");
Expect(1, 11565, '\p{Script_Extensions=-GEORGIAN}', "");
Expect(0, 11565, '\p{^Script_Extensions=-GEORGIAN}', "");
Expect(0, 11565, '\P{Script_Extensions=-GEORGIAN}', "");
Expect(1, 11565, '\P{^Script_Extensions=-GEORGIAN}', "");
Expect(0, 11566, '\p{Script_Extensions=-GEORGIAN}', "");
Expect(1, 11566, '\p{^Script_Extensions=-GEORGIAN}', "");
Expect(1, 11566, '\P{Script_Extensions=-GEORGIAN}', "");
Expect(0, 11566, '\P{^Script_Extensions=-GEORGIAN}', "");
Error('\p{Scx= 	Geor/a/}');
Error('\P{Scx= 	Geor/a/}');
Expect(1, 11565, '\p{Scx:	geor}', "");
Expect(0, 11565, '\p{^Scx:	geor}', "");
Expect(0, 11565, '\P{Scx:	geor}', "");
Expect(1, 11565, '\P{^Scx:	geor}', "");
Expect(0, 11566, '\p{Scx:	geor}', "");
Expect(1, 11566, '\p{^Scx:	geor}', "");
Expect(1, 11566, '\P{Scx:	geor}', "");
Expect(0, 11566, '\P{^Scx:	geor}', "");
Expect(1, 11565, '\p{Scx:	 -geor}', "");
Expect(0, 11565, '\p{^Scx:	 -geor}', "");
Expect(0, 11565, '\P{Scx:	 -geor}', "");
Expect(1, 11565, '\P{^Scx:	 -geor}', "");
Expect(0, 11566, '\p{Scx:	 -geor}', "");
Expect(1, 11566, '\p{^Scx:	 -geor}', "");
Expect(1, 11566, '\P{Scx:	 -geor}', "");
Expect(0, 11566, '\P{^Scx:	 -geor}', "");
Error('\p{Is_Script_Extensions=	:=Georgian}');
Error('\P{Is_Script_Extensions=	:=Georgian}');
Expect(1, 11565, '\p{Is_Script_Extensions=georgian}', "");
Expect(0, 11565, '\p{^Is_Script_Extensions=georgian}', "");
Expect(0, 11565, '\P{Is_Script_Extensions=georgian}', "");
Expect(1, 11565, '\P{^Is_Script_Extensions=georgian}', "");
Expect(0, 11566, '\p{Is_Script_Extensions=georgian}', "");
Expect(1, 11566, '\p{^Is_Script_Extensions=georgian}', "");
Expect(1, 11566, '\P{Is_Script_Extensions=georgian}', "");
Expect(0, 11566, '\P{^Is_Script_Extensions=georgian}', "");
Expect(1, 11565, '\p{Is_Script_Extensions=  Georgian}', "");
Expect(0, 11565, '\p{^Is_Script_Extensions=  Georgian}', "");
Expect(0, 11565, '\P{Is_Script_Extensions=  Georgian}', "");
Expect(1, 11565, '\P{^Is_Script_Extensions=  Georgian}', "");
Expect(0, 11566, '\p{Is_Script_Extensions=  Georgian}', "");
Expect(1, 11566, '\p{^Is_Script_Extensions=  Georgian}', "");
Expect(1, 11566, '\P{Is_Script_Extensions=  Georgian}', "");
Expect(0, 11566, '\P{^Is_Script_Extensions=  Georgian}', "");
Error('\p{Is_Scx=_-Geor/a/}');
Error('\P{Is_Scx=_-Geor/a/}');
Expect(1, 11565, '\p{Is_Scx=geor}', "");
Expect(0, 11565, '\p{^Is_Scx=geor}', "");
Expect(0, 11565, '\P{Is_Scx=geor}', "");
Expect(1, 11565, '\P{^Is_Scx=geor}', "");
Expect(0, 11566, '\p{Is_Scx=geor}', "");
Expect(1, 11566, '\p{^Is_Scx=geor}', "");
Expect(1, 11566, '\P{Is_Scx=geor}', "");
Expect(0, 11566, '\P{^Is_Scx=geor}', "");
Expect(1, 11565, '\p{Is_Scx=-Geor}', "");
Expect(0, 11565, '\p{^Is_Scx=-Geor}', "");
Expect(0, 11565, '\P{Is_Scx=-Geor}', "");
Expect(1, 11565, '\P{^Is_Scx=-Geor}', "");
Expect(0, 11566, '\p{Is_Scx=-Geor}', "");
Expect(1, 11566, '\p{^Is_Scx=-Geor}', "");
Expect(1, 11566, '\P{Is_Scx=-Geor}', "");
Expect(0, 11566, '\P{^Is_Scx=-Geor}', "");
Error('\p{Script_Extensions=	 Glagolitic/a/}');
Error('\P{Script_Extensions=	 Glagolitic/a/}');
Expect(1, 11358, '\p{Script_Extensions:	glagolitic}', "");
Expect(0, 11358, '\p{^Script_Extensions:	glagolitic}', "");
Expect(0, 11358, '\P{Script_Extensions:	glagolitic}', "");
Expect(1, 11358, '\P{^Script_Extensions:	glagolitic}', "");
Expect(0, 11359, '\p{Script_Extensions:	glagolitic}', "");
Expect(1, 11359, '\p{^Script_Extensions:	glagolitic}', "");
Expect(1, 11359, '\P{Script_Extensions:	glagolitic}', "");
Expect(0, 11359, '\P{^Script_Extensions:	glagolitic}', "");
Expect(1, 11358, '\p{Script_Extensions=_ Glagolitic}', "");
Expect(0, 11358, '\p{^Script_Extensions=_ Glagolitic}', "");
Expect(0, 11358, '\P{Script_Extensions=_ Glagolitic}', "");
Expect(1, 11358, '\P{^Script_Extensions=_ Glagolitic}', "");
Expect(0, 11359, '\p{Script_Extensions=_ Glagolitic}', "");
Expect(1, 11359, '\p{^Script_Extensions=_ Glagolitic}', "");
Expect(1, 11359, '\P{Script_Extensions=_ Glagolitic}', "");
Expect(0, 11359, '\P{^Script_Extensions=_ Glagolitic}', "");
Error('\p{Scx=:=glag}');
Error('\P{Scx=:=glag}');
Expect(1, 11358, '\p{Scx=glag}', "");
Expect(0, 11358, '\p{^Scx=glag}', "");
Expect(0, 11358, '\P{Scx=glag}', "");
Expect(1, 11358, '\P{^Scx=glag}', "");
Expect(0, 11359, '\p{Scx=glag}', "");
Expect(1, 11359, '\p{^Scx=glag}', "");
Expect(1, 11359, '\P{Scx=glag}', "");
Expect(0, 11359, '\P{^Scx=glag}', "");
Expect(1, 11358, '\p{Scx: --GLAG}', "");
Expect(0, 11358, '\p{^Scx: --GLAG}', "");
Expect(0, 11358, '\P{Scx: --GLAG}', "");
Expect(1, 11358, '\P{^Scx: --GLAG}', "");
Expect(0, 11359, '\p{Scx: --GLAG}', "");
Expect(1, 11359, '\p{^Scx: --GLAG}', "");
Expect(1, 11359, '\P{Scx: --GLAG}', "");
Expect(0, 11359, '\P{^Scx: --GLAG}', "");
Error('\p{Is_Script_Extensions=/a/ glagolitic}');
Error('\P{Is_Script_Extensions=/a/ glagolitic}');
Expect(1, 11358, '\p{Is_Script_Extensions=glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script_Extensions=glagolitic}', "");
Expect(0, 11358, '\P{Is_Script_Extensions=glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script_Extensions=glagolitic}', "");
Expect(0, 11359, '\p{Is_Script_Extensions=glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script_Extensions=glagolitic}', "");
Expect(1, 11359, '\P{Is_Script_Extensions=glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script_Extensions=glagolitic}', "");
Expect(1, 11358, '\p{Is_Script_Extensions=--Glagolitic}', "");
Expect(0, 11358, '\p{^Is_Script_Extensions=--Glagolitic}', "");
Expect(0, 11358, '\P{Is_Script_Extensions=--Glagolitic}', "");
Expect(1, 11358, '\P{^Is_Script_Extensions=--Glagolitic}', "");
Expect(0, 11359, '\p{Is_Script_Extensions=--Glagolitic}', "");
Expect(1, 11359, '\p{^Is_Script_Extensions=--Glagolitic}', "");
Expect(1, 11359, '\P{Is_Script_Extensions=--Glagolitic}', "");
Expect(0, 11359, '\P{^Is_Script_Extensions=--Glagolitic}', "");
Error('\p{Is_Scx=  Glag:=}');
Error('\P{Is_Scx=  Glag:=}');
Expect(1, 11358, '\p{Is_Scx=glag}', "");
Expect(0, 11358, '\p{^Is_Scx=glag}', "");
Expect(0, 11358, '\P{Is_Scx=glag}', "");
Expect(1, 11358, '\P{^Is_Scx=glag}', "");
Expect(0, 11359, '\p{Is_Scx=glag}', "");
Expect(1, 11359, '\p{^Is_Scx=glag}', "");
Expect(1, 11359, '\P{Is_Scx=glag}', "");
Expect(0, 11359, '\P{^Is_Scx=glag}', "");
Expect(1, 11358, '\p{Is_Scx=  Glag}', "");
Expect(0, 11358, '\p{^Is_Scx=  Glag}', "");
Expect(0, 11358, '\P{Is_Scx=  Glag}', "");
Expect(1, 11358, '\P{^Is_Scx=  Glag}', "");
Expect(0, 11359, '\p{Is_Scx=  Glag}', "");
Expect(1, 11359, '\p{^Is_Scx=  Glag}', "");
Expect(1, 11359, '\P{Is_Scx=  Glag}', "");
Expect(0, 11359, '\P{^Is_Scx=  Glag}', "");
Error('\p{Script_Extensions: -/a/gothic}');
Error('\P{Script_Extensions: -/a/gothic}');
Expect(1, 66378, '\p{Script_Extensions=gothic}', "");
Expect(0, 66378, '\p{^Script_Extensions=gothic}', "");
Expect(0, 66378, '\P{Script_Extensions=gothic}', "");
Expect(1, 66378, '\P{^Script_Extensions=gothic}', "");
Expect(0, 66379, '\p{Script_Extensions=gothic}', "");
Expect(1, 66379, '\p{^Script_Extensions=gothic}', "");
Expect(1, 66379, '\P{Script_Extensions=gothic}', "");
Expect(0, 66379, '\P{^Script_Extensions=gothic}', "");
Expect(1, 66378, '\p{Script_Extensions= gothic}', "");
Expect(0, 66378, '\p{^Script_Extensions= gothic}', "");
Expect(0, 66378, '\P{Script_Extensions= gothic}', "");
Expect(1, 66378, '\P{^Script_Extensions= gothic}', "");
Expect(0, 66379, '\p{Script_Extensions= gothic}', "");
Expect(1, 66379, '\p{^Script_Extensions= gothic}', "");
Expect(1, 66379, '\P{Script_Extensions= gothic}', "");
Expect(0, 66379, '\P{^Script_Extensions= gothic}', "");
Error('\p{Scx=-:=Goth}');
Error('\P{Scx=-:=Goth}');
Expect(1, 66378, '\p{Scx=goth}', "");
Expect(0, 66378, '\p{^Scx=goth}', "");
Expect(0, 66378, '\P{Scx=goth}', "");
Expect(1, 66378, '\P{^Scx=goth}', "");
Expect(0, 66379, '\p{Scx=goth}', "");
Expect(1, 66379, '\p{^Scx=goth}', "");
Expect(1, 66379, '\P{Scx=goth}', "");
Expect(0, 66379, '\P{^Scx=goth}', "");
Expect(1, 66378, '\p{Scx=- Goth}', "");
Expect(0, 66378, '\p{^Scx=- Goth}', "");
Expect(0, 66378, '\P{Scx=- Goth}', "");
Expect(1, 66378, '\P{^Scx=- Goth}', "");
Expect(0, 66379, '\p{Scx=- Goth}', "");
Expect(1, 66379, '\p{^Scx=- Goth}', "");
Expect(1, 66379, '\P{Scx=- Goth}', "");
Expect(0, 66379, '\P{^Scx=- Goth}', "");
Error('\p{Is_Script_Extensions= 	GOTHIC/a/}');
Error('\P{Is_Script_Extensions= 	GOTHIC/a/}');
Expect(1, 66378, '\p{Is_Script_Extensions=gothic}', "");
Expect(0, 66378, '\p{^Is_Script_Extensions=gothic}', "");
Expect(0, 66378, '\P{Is_Script_Extensions=gothic}', "");
Expect(1, 66378, '\P{^Is_Script_Extensions=gothic}', "");
Expect(0, 66379, '\p{Is_Script_Extensions=gothic}', "");
Expect(1, 66379, '\p{^Is_Script_Extensions=gothic}', "");
Expect(1, 66379, '\P{Is_Script_Extensions=gothic}', "");
Expect(0, 66379, '\P{^Is_Script_Extensions=gothic}', "");
Expect(1, 66378, '\p{Is_Script_Extensions= Gothic}', "");
Expect(0, 66378, '\p{^Is_Script_Extensions= Gothic}', "");
Expect(0, 66378, '\P{Is_Script_Extensions= Gothic}', "");
Expect(1, 66378, '\P{^Is_Script_Extensions= Gothic}', "");
Expect(0, 66379, '\p{Is_Script_Extensions= Gothic}', "");
Expect(1, 66379, '\p{^Is_Script_Extensions= Gothic}', "");
Expect(1, 66379, '\P{Is_Script_Extensions= Gothic}', "");
Expect(0, 66379, '\P{^Is_Script_Extensions= Gothic}', "");
Error('\p{Is_Scx=	-goth:=}');
Error('\P{Is_Scx=	-goth:=}');
Expect(1, 66378, '\p{Is_Scx=goth}', "");
Expect(0, 66378, '\p{^Is_Scx=goth}', "");
Expect(0, 66378, '\P{Is_Scx=goth}', "");
Expect(1, 66378, '\P{^Is_Scx=goth}', "");
Expect(0, 66379, '\p{Is_Scx=goth}', "");
Expect(1, 66379, '\p{^Is_Scx=goth}', "");
Expect(1, 66379, '\P{Is_Scx=goth}', "");
Expect(0, 66379, '\P{^Is_Scx=goth}', "");
Expect(1, 66378, '\p{Is_Scx=	Goth}', "");
Expect(0, 66378, '\p{^Is_Scx=	Goth}', "");
Expect(0, 66378, '\P{Is_Scx=	Goth}', "");
Expect(1, 66378, '\P{^Is_Scx=	Goth}', "");
Expect(0, 66379, '\p{Is_Scx=	Goth}', "");
Expect(1, 66379, '\p{^Is_Scx=	Goth}', "");
Expect(1, 66379, '\P{Is_Scx=	Goth}', "");
Expect(0, 66379, '\P{^Is_Scx=	Goth}', "");
Error('\p{Script_Extensions=-_Greek/a/}');
Error('\P{Script_Extensions=-_Greek/a/}');
Expect(1, 119365, '\p{Script_Extensions=greek}', "");
Expect(0, 119365, '\p{^Script_Extensions=greek}', "");
Expect(0, 119365, '\P{Script_Extensions=greek}', "");
Expect(1, 119365, '\P{^Script_Extensions=greek}', "");
Expect(0, 119366, '\p{Script_Extensions=greek}', "");
Expect(1, 119366, '\p{^Script_Extensions=greek}', "");
Expect(1, 119366, '\P{Script_Extensions=greek}', "");
Expect(0, 119366, '\P{^Script_Extensions=greek}', "");
Expect(1, 119365, '\p{Script_Extensions:-greek}', "");
Expect(0, 119365, '\p{^Script_Extensions:-greek}', "");
Expect(0, 119365, '\P{Script_Extensions:-greek}', "");
Expect(1, 119365, '\P{^Script_Extensions:-greek}', "");
Expect(0, 119366, '\p{Script_Extensions:-greek}', "");
Expect(1, 119366, '\p{^Script_Extensions:-greek}', "");
Expect(1, 119366, '\P{Script_Extensions:-greek}', "");
Expect(0, 119366, '\P{^Script_Extensions:-greek}', "");
Error('\p{Scx=:=		grek}');
Error('\P{Scx=:=		grek}');
Expect(1, 119365, '\p{Scx=grek}', "");
Expect(0, 119365, '\p{^Scx=grek}', "");
Expect(0, 119365, '\P{Scx=grek}', "");
Expect(1, 119365, '\P{^Scx=grek}', "");
Expect(0, 119366, '\p{Scx=grek}', "");
Expect(1, 119366, '\p{^Scx=grek}', "");
Expect(1, 119366, '\P{Scx=grek}', "");
Expect(0, 119366, '\P{^Scx=grek}', "");
Expect(1, 119365, '\p{Scx=_ Grek}', "");
Expect(0, 119365, '\p{^Scx=_ Grek}', "");
Expect(0, 119365, '\P{Scx=_ Grek}', "");
Expect(1, 119365, '\P{^Scx=_ Grek}', "");
Expect(0, 119366, '\p{Scx=_ Grek}', "");
Expect(1, 119366, '\p{^Scx=_ Grek}', "");
Expect(1, 119366, '\P{Scx=_ Grek}', "");
Expect(0, 119366, '\P{^Scx=_ Grek}', "");
Error('\p{Is_Script_Extensions:   /a/	-Greek}');
Error('\P{Is_Script_Extensions:   /a/	-Greek}');
Expect(1, 119365, '\p{Is_Script_Extensions:   greek}', "");
Expect(0, 119365, '\p{^Is_Script_Extensions:   greek}', "");
Expect(0, 119365, '\P{Is_Script_Extensions:   greek}', "");
Expect(1, 119365, '\P{^Is_Script_Extensions:   greek}', "");
Expect(0, 119366, '\p{Is_Script_Extensions:   greek}', "");
Expect(1, 119366, '\p{^Is_Script_Extensions:   greek}', "");
Expect(1, 119366, '\P{Is_Script_Extensions:   greek}', "");
Expect(0, 119366, '\P{^Is_Script_Extensions:   greek}', "");
Expect(1, 119365, '\p{Is_Script_Extensions=_ greek}', "");
Expect(0, 119365, '\p{^Is_Script_Extensions=_ greek}', "");
Expect(0, 119365, '\P{Is_Script_Extensions=_ greek}', "");
Expect(1, 119365, '\P{^Is_Script_Extensions=_ greek}', "");
Expect(0, 119366, '\p{Is_Script_Extensions=_ greek}', "");
Expect(1, 119366, '\p{^Is_Script_Extensions=_ greek}', "");
Expect(1, 119366, '\P{Is_Script_Extensions=_ greek}', "");
Expect(0, 119366, '\P{^Is_Script_Extensions=_ greek}', "");
Error('\p{Is_Scx= :=Grek}');
Error('\P{Is_Scx= :=Grek}');
Expect(1, 119365, '\p{Is_Scx:grek}', "");
Expect(0, 119365, '\p{^Is_Scx:grek}', "");
Expect(0, 119365, '\P{Is_Scx:grek}', "");
Expect(1, 119365, '\P{^Is_Scx:grek}', "");
Expect(0, 119366, '\p{Is_Scx:grek}', "");
Expect(1, 119366, '\p{^Is_Scx:grek}', "");
Expect(1, 119366, '\P{Is_Scx:grek}', "");
Expect(0, 119366, '\P{^Is_Scx:grek}', "");
Expect(1, 119365, '\p{Is_Scx=_	Grek}', "");
Expect(0, 119365, '\p{^Is_Scx=_	Grek}', "");
Expect(0, 119365, '\P{Is_Scx=_	Grek}', "");
Expect(1, 119365, '\P{^Is_Scx=_	Grek}', "");
Expect(0, 119366, '\p{Is_Scx=_	Grek}', "");
Expect(1, 119366, '\p{^Is_Scx=_	Grek}', "");
Expect(1, 119366, '\P{Is_Scx=_	Grek}', "");
Expect(0, 119366, '\P{^Is_Scx=_	Grek}', "");
Error('\p{Script_Extensions:	/a/	-Gujarati}');
Error('\P{Script_Extensions:	/a/	-Gujarati}');
Expect(1, 43065, '\p{Script_Extensions=gujarati}', "");
Expect(0, 43065, '\p{^Script_Extensions=gujarati}', "");
Expect(0, 43065, '\P{Script_Extensions=gujarati}', "");
Expect(1, 43065, '\P{^Script_Extensions=gujarati}', "");
Expect(0, 43066, '\p{Script_Extensions=gujarati}', "");
Expect(1, 43066, '\p{^Script_Extensions=gujarati}', "");
Expect(1, 43066, '\P{Script_Extensions=gujarati}', "");
Expect(0, 43066, '\P{^Script_Extensions=gujarati}', "");
Expect(1, 43065, '\p{Script_Extensions=__Gujarati}', "");
Expect(0, 43065, '\p{^Script_Extensions=__Gujarati}', "");
Expect(0, 43065, '\P{Script_Extensions=__Gujarati}', "");
Expect(1, 43065, '\P{^Script_Extensions=__Gujarati}', "");
Expect(0, 43066, '\p{Script_Extensions=__Gujarati}', "");
Expect(1, 43066, '\p{^Script_Extensions=__Gujarati}', "");
Expect(1, 43066, '\P{Script_Extensions=__Gujarati}', "");
Expect(0, 43066, '\P{^Script_Extensions=__Gujarati}', "");
Error('\p{Scx=:=	-gujr}');
Error('\P{Scx=:=	-gujr}');
Expect(1, 43065, '\p{Scx:gujr}', "");
Expect(0, 43065, '\p{^Scx:gujr}', "");
Expect(0, 43065, '\P{Scx:gujr}', "");
Expect(1, 43065, '\P{^Scx:gujr}', "");
Expect(0, 43066, '\p{Scx:gujr}', "");
Expect(1, 43066, '\p{^Scx:gujr}', "");
Expect(1, 43066, '\P{Scx:gujr}', "");
Expect(0, 43066, '\P{^Scx:gujr}', "");
Expect(1, 43065, '\p{Scx=-_GUJR}', "");
Expect(0, 43065, '\p{^Scx=-_GUJR}', "");
Expect(0, 43065, '\P{Scx=-_GUJR}', "");
Expect(1, 43065, '\P{^Scx=-_GUJR}', "");
Expect(0, 43066, '\p{Scx=-_GUJR}', "");
Expect(1, 43066, '\p{^Scx=-_GUJR}', "");
Expect(1, 43066, '\P{Scx=-_GUJR}', "");
Expect(0, 43066, '\P{^Scx=-_GUJR}', "");
Error('\p{Is_Script_Extensions:   :=-	gujarati}');
Error('\P{Is_Script_Extensions:   :=-	gujarati}');
Expect(1, 43065, '\p{Is_Script_Extensions=gujarati}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=gujarati}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=gujarati}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=gujarati}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=gujarati}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=gujarati}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=gujarati}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=gujarati}', "");
Expect(1, 43065, '\p{Is_Script_Extensions=_ GUJARATI}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=_ GUJARATI}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=_ GUJARATI}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=_ GUJARATI}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=_ GUJARATI}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=_ GUJARATI}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=_ GUJARATI}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=_ GUJARATI}', "");
Error('\p{Is_Scx=-Gujr:=}');
Error('\P{Is_Scx=-Gujr:=}');
Expect(1, 43065, '\p{Is_Scx=gujr}', "");
Expect(0, 43065, '\p{^Is_Scx=gujr}', "");
Expect(0, 43065, '\P{Is_Scx=gujr}', "");
Expect(1, 43065, '\P{^Is_Scx=gujr}', "");
Expect(0, 43066, '\p{Is_Scx=gujr}', "");
Expect(1, 43066, '\p{^Is_Scx=gujr}', "");
Expect(1, 43066, '\P{Is_Scx=gujr}', "");
Expect(0, 43066, '\P{^Is_Scx=gujr}', "");
Expect(1, 43065, '\p{Is_Scx=_	Gujr}', "");
Expect(0, 43065, '\p{^Is_Scx=_	Gujr}', "");
Expect(0, 43065, '\P{Is_Scx=_	Gujr}', "");
Expect(1, 43065, '\P{^Is_Scx=_	Gujr}', "");
Expect(0, 43066, '\p{Is_Scx=_	Gujr}', "");
Expect(1, 43066, '\p{^Is_Scx=_	Gujr}', "");
Expect(1, 43066, '\P{Is_Scx=_	Gujr}', "");
Expect(0, 43066, '\P{^Is_Scx=_	Gujr}', "");
Error('\p{Script_Extensions: /a/Gurmukhi}');
Error('\P{Script_Extensions: /a/Gurmukhi}');
Expect(1, 43065, '\p{Script_Extensions: gurmukhi}', "");
Expect(0, 43065, '\p{^Script_Extensions: gurmukhi}', "");
Expect(0, 43065, '\P{Script_Extensions: gurmukhi}', "");
Expect(1, 43065, '\P{^Script_Extensions: gurmukhi}', "");
Expect(0, 43066, '\p{Script_Extensions: gurmukhi}', "");
Expect(1, 43066, '\p{^Script_Extensions: gurmukhi}', "");
Expect(1, 43066, '\P{Script_Extensions: gurmukhi}', "");
Expect(0, 43066, '\P{^Script_Extensions: gurmukhi}', "");
Expect(1, 43065, '\p{Script_Extensions=  Gurmukhi}', "");
Expect(0, 43065, '\p{^Script_Extensions=  Gurmukhi}', "");
Expect(0, 43065, '\P{Script_Extensions=  Gurmukhi}', "");
Expect(1, 43065, '\P{^Script_Extensions=  Gurmukhi}', "");
Expect(0, 43066, '\p{Script_Extensions=  Gurmukhi}', "");
Expect(1, 43066, '\p{^Script_Extensions=  Gurmukhi}', "");
Expect(1, 43066, '\P{Script_Extensions=  Gurmukhi}', "");
Expect(0, 43066, '\P{^Script_Extensions=  Gurmukhi}', "");
Error('\p{Scx::=_	guru}');
Error('\P{Scx::=_	guru}');
Expect(1, 43065, '\p{Scx=guru}', "");
Expect(0, 43065, '\p{^Scx=guru}', "");
Expect(0, 43065, '\P{Scx=guru}', "");
Expect(1, 43065, '\P{^Scx=guru}', "");
Expect(0, 43066, '\p{Scx=guru}', "");
Expect(1, 43066, '\p{^Scx=guru}', "");
Expect(1, 43066, '\P{Scx=guru}', "");
Expect(0, 43066, '\P{^Scx=guru}', "");
Expect(1, 43065, '\p{Scx= 	Guru}', "");
Expect(0, 43065, '\p{^Scx= 	Guru}', "");
Expect(0, 43065, '\P{Scx= 	Guru}', "");
Expect(1, 43065, '\P{^Scx= 	Guru}', "");
Expect(0, 43066, '\p{Scx= 	Guru}', "");
Expect(1, 43066, '\p{^Scx= 	Guru}', "");
Expect(1, 43066, '\P{Scx= 	Guru}', "");
Expect(0, 43066, '\P{^Scx= 	Guru}', "");
Error('\p{Is_Script_Extensions=/a/ Gurmukhi}');
Error('\P{Is_Script_Extensions=/a/ Gurmukhi}');
Expect(1, 43065, '\p{Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=gurmukhi}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=gurmukhi}', "");
Expect(1, 43065, '\p{Is_Script_Extensions=_ gurmukhi}', "");
Expect(0, 43065, '\p{^Is_Script_Extensions=_ gurmukhi}', "");
Expect(0, 43065, '\P{Is_Script_Extensions=_ gurmukhi}', "");
Expect(1, 43065, '\P{^Is_Script_Extensions=_ gurmukhi}', "");
Expect(0, 43066, '\p{Is_Script_Extensions=_ gurmukhi}', "");
Expect(1, 43066, '\p{^Is_Script_Extensions=_ gurmukhi}', "");
Expect(1, 43066, '\P{Is_Script_Extensions=_ gurmukhi}', "");
Expect(0, 43066, '\P{^Is_Script_Extensions=_ gurmukhi}', "");
Error('\p{Is_Scx=:= 	Guru}');
Error('\P{Is_Scx=:= 	Guru}');
Expect(1, 43065, '\p{Is_Scx:   guru}', "");
Expect(0, 43065, '\p{^Is_Scx:   guru}', "");
Expect(0, 43065, '\P{Is_Scx:   guru}', "");
Expect(1, 43065, '\P{^Is_Scx:   guru}', "");
Expect(0, 43066, '\p{Is_Scx:   guru}', "");
Expect(1, 43066, '\p{^Is_Scx:   guru}', "");
Expect(1, 43066, '\P{Is_Scx:   guru}', "");
Expect(0, 43066, '\P{^Is_Scx:   guru}', "");
Expect(1, 43065, '\p{Is_Scx= _GURU}', "");
Expect(0, 43065, '\p{^Is_Scx= _GURU}', "");
Expect(0, 43065, '\P{Is_Scx= _GURU}', "");
Expect(1, 43065, '\P{^Is_Scx= _GURU}', "");
Expect(0, 43066, '\p{Is_Scx= _GURU}', "");
Expect(1, 43066, '\p{^Is_Scx= _GURU}', "");
Expect(1, 43066, '\P{Is_Scx= _GURU}', "");
Expect(0, 43066, '\P{^Is_Scx= _GURU}', "");
Error('\p{Script_Extensions=	hangul:=}');
Error('\P{Script_Extensions=	hangul:=}');
Expect(1, 65500, '\p{Script_Extensions=hangul}', "");
Expect(0, 65500, '\p{^Script_Extensions=hangul}', "");
Expect(0, 65500, '\P{Script_Extensions=hangul}', "");
Expect(1, 65500, '\P{^Script_Extensions=hangul}', "");
Expect(0, 65501, '\p{Script_Extensions=hangul}', "");
Expect(1, 65501, '\p{^Script_Extensions=hangul}', "");
Expect(1, 65501, '\P{Script_Extensions=hangul}', "");
Expect(0, 65501, '\P{^Script_Extensions=hangul}', "");
Expect(1, 65500, '\p{Script_Extensions=-_HANGUL}', "");
Expect(0, 65500, '\p{^Script_Extensions=-_HANGUL}', "");
Expect(0, 65500, '\P{Script_Extensions=-_HANGUL}', "");
Expect(1, 65500, '\P{^Script_Extensions=-_HANGUL}', "");
Expect(0, 65501, '\p{Script_Extensions=-_HANGUL}', "");
Expect(1, 65501, '\p{^Script_Extensions=-_HANGUL}', "");
Expect(1, 65501, '\P{Script_Extensions=-_HANGUL}', "");
Expect(0, 65501, '\P{^Script_Extensions=-_HANGUL}', "");
Error('\p{Scx=	/a/Hang}');
Error('\P{Scx=	/a/Hang}');
Expect(1, 65500, '\p{Scx=hang}', "");
Expect(0, 65500, '\p{^Scx=hang}', "");
Expect(0, 65500, '\P{Scx=hang}', "");
Expect(1, 65500, '\P{^Scx=hang}', "");
Expect(0, 65501, '\p{Scx=hang}', "");
Expect(1, 65501, '\p{^Scx=hang}', "");
Expect(1, 65501, '\P{Scx=hang}', "");
Expect(0, 65501, '\P{^Scx=hang}', "");
Expect(1, 65500, '\p{Scx=	 HANG}', "");
Expect(0, 65500, '\p{^Scx=	 HANG}', "");
Expect(0, 65500, '\P{Scx=	 HANG}', "");
Expect(1, 65500, '\P{^Scx=	 HANG}', "");
Expect(0, 65501, '\p{Scx=	 HANG}', "");
Expect(1, 65501, '\p{^Scx=	 HANG}', "");
Expect(1, 65501, '\P{Scx=	 HANG}', "");
Expect(0, 65501, '\P{^Scx=	 HANG}', "");
Error('\p{Is_Script_Extensions=:= -Hangul}');
Error('\P{Is_Script_Extensions=:= -Hangul}');
Expect(1, 65500, '\p{Is_Script_Extensions=hangul}', "");
Expect(0, 65500, '\p{^Is_Script_Extensions=hangul}', "");
Expect(0, 65500, '\P{Is_Script_Extensions=hangul}', "");
Expect(1, 65500, '\P{^Is_Script_Extensions=hangul}', "");
Expect(0, 65501, '\p{Is_Script_Extensions=hangul}', "");
Expect(1, 65501, '\p{^Is_Script_Extensions=hangul}', "");
Expect(1, 65501, '\P{Is_Script_Extensions=hangul}', "");
Expect(0, 65501, '\P{^Is_Script_Extensions=hangul}', "");
Expect(1, 65500, '\p{Is_Script_Extensions= HANGUL}', "");
Expect(0, 65500, '\p{^Is_Script_Extensions= HANGUL}', "");
Expect(0, 65500, '\P{Is_Script_Extensions= HANGUL}', "");
Expect(1, 65500, '\P{^Is_Script_Extensions= HANGUL}', "");
Expect(0, 65501, '\p{Is_Script_Extensions= HANGUL}', "");
Expect(1, 65501, '\p{^Is_Script_Extensions= HANGUL}', "");
Expect(1, 65501, '\P{Is_Script_Extensions= HANGUL}', "");
Expect(0, 65501, '\P{^Is_Script_Extensions= HANGUL}', "");
Error('\p{Is_Scx= hang/a/}');
Error('\P{Is_Scx= hang/a/}');
Expect(1, 65500, '\p{Is_Scx=hang}', "");
Expect(0, 65500, '\p{^Is_Scx=hang}', "");
Expect(0, 65500, '\P{Is_Scx=hang}', "");
Expect(1, 65500, '\P{^Is_Scx=hang}', "");
Expect(0, 65501, '\p{Is_Scx=hang}', "");
Expect(1, 65501, '\p{^Is_Scx=hang}', "");
Expect(1, 65501, '\P{Is_Scx=hang}', "");
Expect(0, 65501, '\P{^Is_Scx=hang}', "");
Expect(1, 65500, '\p{Is_Scx= 	HANG}', "");
Expect(0, 65500, '\p{^Is_Scx= 	HANG}', "");
Expect(0, 65500, '\P{Is_Scx= 	HANG}', "");
Expect(1, 65500, '\P{^Is_Scx= 	HANG}', "");
Expect(0, 65501, '\p{Is_Scx= 	HANG}', "");
Expect(1, 65501, '\p{^Is_Scx= 	HANG}', "");
Expect(1, 65501, '\P{Is_Scx= 	HANG}', "");
Expect(0, 65501, '\P{^Is_Scx= 	HANG}', "");
Error('\p{Script_Extensions=:=- Han}');
Error('\P{Script_Extensions=:=- Han}');
Expect(1, 195101, '\p{Script_Extensions=han}', "");
Expect(0, 195101, '\p{^Script_Extensions=han}', "");
Expect(0, 195101, '\P{Script_Extensions=han}', "");
Expect(1, 195101, '\P{^Script_Extensions=han}', "");
Expect(0, 195102, '\p{Script_Extensions=han}', "");
Expect(1, 195102, '\p{^Script_Extensions=han}', "");
Expect(1, 195102, '\P{Script_Extensions=han}', "");
Expect(0, 195102, '\P{^Script_Extensions=han}', "");
Expect(1, 195101, '\p{Script_Extensions=-_HAN}', "");
Expect(0, 195101, '\p{^Script_Extensions=-_HAN}', "");
Expect(0, 195101, '\P{Script_Extensions=-_HAN}', "");
Expect(1, 195101, '\P{^Script_Extensions=-_HAN}', "");
Expect(0, 195102, '\p{Script_Extensions=-_HAN}', "");
Expect(1, 195102, '\p{^Script_Extensions=-_HAN}', "");
Expect(1, 195102, '\P{Script_Extensions=-_HAN}', "");
Expect(0, 195102, '\P{^Script_Extensions=-_HAN}', "");
Error('\p{Scx=_	Hani/a/}');
Error('\P{Scx=_	Hani/a/}');
Expect(1, 195101, '\p{Scx=hani}', "");
Expect(0, 195101, '\p{^Scx=hani}', "");
Expect(0, 195101, '\P{Scx=hani}', "");
Expect(1, 195101, '\P{^Scx=hani}', "");
Expect(0, 195102, '\p{Scx=hani}', "");
Expect(1, 195102, '\p{^Scx=hani}', "");
Expect(1, 195102, '\P{Scx=hani}', "");
Expect(0, 195102, '\P{^Scx=hani}', "");
Expect(1, 195101, '\p{Scx= _Hani}', "");
Expect(0, 195101, '\p{^Scx= _Hani}', "");
Expect(0, 195101, '\P{Scx= _Hani}', "");
Expect(1, 195101, '\P{^Scx= _Hani}', "");
Expect(0, 195102, '\p{Scx= _Hani}', "");
Expect(1, 195102, '\p{^Scx= _Hani}', "");
Expect(1, 195102, '\P{Scx= _Hani}', "");
Expect(0, 195102, '\P{^Scx= _Hani}', "");
Error('\p{Is_Script_Extensions=-:=HAN}');
Error('\P{Is_Script_Extensions=-:=HAN}');
Expect(1, 195101, '\p{Is_Script_Extensions=han}', "");
Expect(0, 195101, '\p{^Is_Script_Extensions=han}', "");
Expect(0, 195101, '\P{Is_Script_Extensions=han}', "");
Expect(1, 195101, '\P{^Is_Script_Extensions=han}', "");
Expect(0, 195102, '\p{Is_Script_Extensions=han}', "");
Expect(1, 195102, '\p{^Is_Script_Extensions=han}', "");
Expect(1, 195102, '\P{Is_Script_Extensions=han}', "");
Expect(0, 195102, '\P{^Is_Script_Extensions=han}', "");
Expect(1, 195101, '\p{Is_Script_Extensions=--Han}', "");
Expect(0, 195101, '\p{^Is_Script_Extensions=--Han}', "");
Expect(0, 195101, '\P{Is_Script_Extensions=--Han}', "");
Expect(1, 195101, '\P{^Is_Script_Extensions=--Han}', "");
Expect(0, 195102, '\p{Is_Script_Extensions=--Han}', "");
Expect(1, 195102, '\p{^Is_Script_Extensions=--Han}', "");
Expect(1, 195102, '\P{Is_Script_Extensions=--Han}', "");
Expect(0, 195102, '\P{^Is_Script_Extensions=--Han}', "");
Error('\p{Is_Scx=:= _Hani}');
Error('\P{Is_Scx=:= _Hani}');
Expect(1, 195101, '\p{Is_Scx=hani}', "");
Expect(0, 195101, '\p{^Is_Scx=hani}', "");
Expect(0, 195101, '\P{Is_Scx=hani}', "");
Expect(1, 195101, '\P{^Is_Scx=hani}', "");
Expect(0, 195102, '\p{Is_Scx=hani}', "");
Expect(1, 195102, '\p{^Is_Scx=hani}', "");
Expect(1, 195102, '\P{Is_Scx=hani}', "");
Expect(0, 195102, '\P{^Is_Scx=hani}', "");
Expect(1, 195101, '\p{Is_Scx=-_HANI}', "");
Expect(0, 195101, '\p{^Is_Scx=-_HANI}', "");
Expect(0, 195101, '\P{Is_Scx=-_HANI}', "");
Expect(1, 195101, '\P{^Is_Scx=-_HANI}', "");
Expect(0, 195102, '\p{Is_Scx=-_HANI}', "");
Expect(1, 195102, '\p{^Is_Scx=-_HANI}', "");
Expect(1, 195102, '\P{Is_Scx=-_HANI}', "");
Expect(0, 195102, '\P{^Is_Scx=-_HANI}', "");
Error('\p{Script_Extensions=_:=Hanunoo}');
Error('\P{Script_Extensions=_:=Hanunoo}');
Expect(1, 5942, '\p{Script_Extensions=hanunoo}', "");
Expect(0, 5942, '\p{^Script_Extensions=hanunoo}', "");
Expect(0, 5942, '\P{Script_Extensions=hanunoo}', "");
Expect(1, 5942, '\P{^Script_Extensions=hanunoo}', "");
Expect(0, 5943, '\p{Script_Extensions=hanunoo}', "");
Expect(1, 5943, '\p{^Script_Extensions=hanunoo}', "");
Expect(1, 5943, '\P{Script_Extensions=hanunoo}', "");
Expect(0, 5943, '\P{^Script_Extensions=hanunoo}', "");
Expect(1, 5942, '\p{Script_Extensions=	-hanunoo}', "");
Expect(0, 5942, '\p{^Script_Extensions=	-hanunoo}', "");
Expect(0, 5942, '\P{Script_Extensions=	-hanunoo}', "");
Expect(1, 5942, '\P{^Script_Extensions=	-hanunoo}', "");
Expect(0, 5943, '\p{Script_Extensions=	-hanunoo}', "");
Expect(1, 5943, '\p{^Script_Extensions=	-hanunoo}', "");
Expect(1, 5943, '\P{Script_Extensions=	-hanunoo}', "");
Expect(0, 5943, '\P{^Script_Extensions=	-hanunoo}', "");
Error('\p{Scx= 	Hano:=}');
Error('\P{Scx= 	Hano:=}');
Expect(1, 5942, '\p{Scx: hano}', "");
Expect(0, 5942, '\p{^Scx: hano}', "");
Expect(0, 5942, '\P{Scx: hano}', "");
Expect(1, 5942, '\P{^Scx: hano}', "");
Expect(0, 5943, '\p{Scx: hano}', "");
Expect(1, 5943, '\p{^Scx: hano}', "");
Expect(1, 5943, '\P{Scx: hano}', "");
Expect(0, 5943, '\P{^Scx: hano}', "");
Expect(1, 5942, '\p{Scx=		Hano}', "");
Expect(0, 5942, '\p{^Scx=		Hano}', "");
Expect(0, 5942, '\P{Scx=		Hano}', "");
Expect(1, 5942, '\P{^Scx=		Hano}', "");
Expect(0, 5943, '\p{Scx=		Hano}', "");
Expect(1, 5943, '\p{^Scx=		Hano}', "");
Expect(1, 5943, '\P{Scx=		Hano}', "");
Expect(0, 5943, '\P{^Scx=		Hano}', "");
Error('\p{Is_Script_Extensions=:=-Hanunoo}');
Error('\P{Is_Script_Extensions=:=-Hanunoo}');
Expect(1, 5942, '\p{Is_Script_Extensions:hanunoo}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions:hanunoo}', "");
Expect(0, 5942, '\P{Is_Script_Extensions:hanunoo}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions:hanunoo}', "");
Expect(0, 5943, '\p{Is_Script_Extensions:hanunoo}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions:hanunoo}', "");
Expect(1, 5943, '\P{Is_Script_Extensions:hanunoo}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions:hanunoo}', "");
Expect(1, 5942, '\p{Is_Script_Extensions:   _-Hanunoo}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions:   _-Hanunoo}', "");
Expect(0, 5942, '\P{Is_Script_Extensions:   _-Hanunoo}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions:   _-Hanunoo}', "");
Expect(0, 5943, '\p{Is_Script_Extensions:   _-Hanunoo}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions:   _-Hanunoo}', "");
Expect(1, 5943, '\P{Is_Script_Extensions:   _-Hanunoo}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions:   _-Hanunoo}', "");
Error('\p{Is_Scx=_/a/Hano}');
Error('\P{Is_Scx=_/a/Hano}');
Expect(1, 5942, '\p{Is_Scx=hano}', "");
Expect(0, 5942, '\p{^Is_Scx=hano}', "");
Expect(0, 5942, '\P{Is_Scx=hano}', "");
Expect(1, 5942, '\P{^Is_Scx=hano}', "");
Expect(0, 5943, '\p{Is_Scx=hano}', "");
Expect(1, 5943, '\p{^Is_Scx=hano}', "");
Expect(1, 5943, '\P{Is_Scx=hano}', "");
Expect(0, 5943, '\P{^Is_Scx=hano}', "");
Expect(1, 5942, '\p{Is_Scx: Hano}', "");
Expect(0, 5942, '\p{^Is_Scx: Hano}', "");
Expect(0, 5942, '\P{Is_Scx: Hano}', "");
Expect(1, 5942, '\P{^Is_Scx: Hano}', "");
Expect(0, 5943, '\p{Is_Scx: Hano}', "");
Expect(1, 5943, '\p{^Is_Scx: Hano}', "");
Expect(1, 5943, '\P{Is_Scx: Hano}', "");
Expect(0, 5943, '\P{^Is_Scx: Hano}', "");
Error('\p{Script_Extensions= :=Hebrew}');
Error('\P{Script_Extensions= :=Hebrew}');
Expect(1, 64335, '\p{Script_Extensions=hebrew}', "");
Expect(0, 64335, '\p{^Script_Extensions=hebrew}', "");
Expect(0, 64335, '\P{Script_Extensions=hebrew}', "");
Expect(1, 64335, '\P{^Script_Extensions=hebrew}', "");
Expect(0, 64336, '\p{Script_Extensions=hebrew}', "");
Expect(1, 64336, '\p{^Script_Extensions=hebrew}', "");
Expect(1, 64336, '\P{Script_Extensions=hebrew}', "");
Expect(0, 64336, '\P{^Script_Extensions=hebrew}', "");
Expect(1, 64335, '\p{Script_Extensions=		Hebrew}', "");
Expect(0, 64335, '\p{^Script_Extensions=		Hebrew}', "");
Expect(0, 64335, '\P{Script_Extensions=		Hebrew}', "");
Expect(1, 64335, '\P{^Script_Extensions=		Hebrew}', "");
Expect(0, 64336, '\p{Script_Extensions=		Hebrew}', "");
Expect(1, 64336, '\p{^Script_Extensions=		Hebrew}', "");
Expect(1, 64336, '\P{Script_Extensions=		Hebrew}', "");
Expect(0, 64336, '\P{^Script_Extensions=		Hebrew}', "");
Error('\p{Scx= /a/hebr}');
Error('\P{Scx= /a/hebr}');
Expect(1, 64335, '\p{Scx: hebr}', "");
Expect(0, 64335, '\p{^Scx: hebr}', "");
Expect(0, 64335, '\P{Scx: hebr}', "");
Expect(1, 64335, '\P{^Scx: hebr}', "");
Expect(0, 64336, '\p{Scx: hebr}', "");
Expect(1, 64336, '\p{^Scx: hebr}', "");
Expect(1, 64336, '\P{Scx: hebr}', "");
Expect(0, 64336, '\P{^Scx: hebr}', "");
Expect(1, 64335, '\p{Scx= HEBR}', "");
Expect(0, 64335, '\p{^Scx= HEBR}', "");
Expect(0, 64335, '\P{Scx= HEBR}', "");
Expect(1, 64335, '\P{^Scx= HEBR}', "");
Expect(0, 64336, '\p{Scx= HEBR}', "");
Expect(1, 64336, '\p{^Scx= HEBR}', "");
Expect(1, 64336, '\P{Scx= HEBR}', "");
Expect(0, 64336, '\P{^Scx= HEBR}', "");
Error('\p{Is_Script_Extensions: 		Hebrew:=}');
Error('\P{Is_Script_Extensions: 		Hebrew:=}');
Expect(1, 64335, '\p{Is_Script_Extensions=hebrew}', "");
Expect(0, 64335, '\p{^Is_Script_Extensions=hebrew}', "");
Expect(0, 64335, '\P{Is_Script_Extensions=hebrew}', "");
Expect(1, 64335, '\P{^Is_Script_Extensions=hebrew}', "");
Expect(0, 64336, '\p{Is_Script_Extensions=hebrew}', "");
Expect(1, 64336, '\p{^Is_Script_Extensions=hebrew}', "");
Expect(1, 64336, '\P{Is_Script_Extensions=hebrew}', "");
Expect(0, 64336, '\P{^Is_Script_Extensions=hebrew}', "");
Expect(1, 64335, '\p{Is_Script_Extensions=	_Hebrew}', "");
Expect(0, 64335, '\p{^Is_Script_Extensions=	_Hebrew}', "");
Expect(0, 64335, '\P{Is_Script_Extensions=	_Hebrew}', "");
Expect(1, 64335, '\P{^Is_Script_Extensions=	_Hebrew}', "");
Expect(0, 64336, '\p{Is_Script_Extensions=	_Hebrew}', "");
Expect(1, 64336, '\p{^Is_Script_Extensions=	_Hebrew}', "");
Expect(1, 64336, '\P{Is_Script_Extensions=	_Hebrew}', "");
Expect(0, 64336, '\P{^Is_Script_Extensions=	_Hebrew}', "");
Error('\p{Is_Scx= -Hebr:=}');
Error('\P{Is_Scx= -Hebr:=}');
Expect(1, 64335, '\p{Is_Scx=hebr}', "");
Expect(0, 64335, '\p{^Is_Scx=hebr}', "");
Expect(0, 64335, '\P{Is_Scx=hebr}', "");
Expect(1, 64335, '\P{^Is_Scx=hebr}', "");
Expect(0, 64336, '\p{Is_Scx=hebr}', "");
Expect(1, 64336, '\p{^Is_Scx=hebr}', "");
Expect(1, 64336, '\P{Is_Scx=hebr}', "");
Expect(0, 64336, '\P{^Is_Scx=hebr}', "");
Expect(1, 64335, '\p{Is_Scx=_HEBR}', "");
Expect(0, 64335, '\p{^Is_Scx=_HEBR}', "");
Expect(0, 64335, '\P{Is_Scx=_HEBR}', "");
Expect(1, 64335, '\P{^Is_Scx=_HEBR}', "");
Expect(0, 64336, '\p{Is_Scx=_HEBR}', "");
Expect(1, 64336, '\p{^Is_Scx=_HEBR}', "");
Expect(1, 64336, '\P{Is_Scx=_HEBR}', "");
Expect(0, 64336, '\P{^Is_Scx=_HEBR}', "");
Error('\p{Script_Extensions=:=	 hiragana}');
Error('\P{Script_Extensions=:=	 hiragana}');
Expect(1, 127488, '\p{Script_Extensions=hiragana}', "");
Expect(0, 127488, '\p{^Script_Extensions=hiragana}', "");
Expect(0, 127488, '\P{Script_Extensions=hiragana}', "");
Expect(1, 127488, '\P{^Script_Extensions=hiragana}', "");
Expect(0, 127489, '\p{Script_Extensions=hiragana}', "");
Expect(1, 127489, '\p{^Script_Extensions=hiragana}', "");
Expect(1, 127489, '\P{Script_Extensions=hiragana}', "");
Expect(0, 127489, '\P{^Script_Extensions=hiragana}', "");
Expect(1, 127488, '\p{Script_Extensions= 	Hiragana}', "");
Expect(0, 127488, '\p{^Script_Extensions= 	Hiragana}', "");
Expect(0, 127488, '\P{Script_Extensions= 	Hiragana}', "");
Expect(1, 127488, '\P{^Script_Extensions= 	Hiragana}', "");
Expect(0, 127489, '\p{Script_Extensions= 	Hiragana}', "");
Expect(1, 127489, '\p{^Script_Extensions= 	Hiragana}', "");
Expect(1, 127489, '\P{Script_Extensions= 	Hiragana}', "");
Expect(0, 127489, '\P{^Script_Extensions= 	Hiragana}', "");
Error('\p{Scx=  hira/a/}');
Error('\P{Scx=  hira/a/}');
Expect(1, 127488, '\p{Scx=hira}', "");
Expect(0, 127488, '\p{^Scx=hira}', "");
Expect(0, 127488, '\P{Scx=hira}', "");
Expect(1, 127488, '\P{^Scx=hira}', "");
Expect(0, 127489, '\p{Scx=hira}', "");
Expect(1, 127489, '\p{^Scx=hira}', "");
Expect(1, 127489, '\P{Scx=hira}', "");
Expect(0, 127489, '\P{^Scx=hira}', "");
Expect(1, 127488, '\p{Scx=		HIRA}', "");
Expect(0, 127488, '\p{^Scx=		HIRA}', "");
Expect(0, 127488, '\P{Scx=		HIRA}', "");
Expect(1, 127488, '\P{^Scx=		HIRA}', "");
Expect(0, 127489, '\p{Scx=		HIRA}', "");
Expect(1, 127489, '\p{^Scx=		HIRA}', "");
Expect(1, 127489, '\P{Scx=		HIRA}', "");
Expect(0, 127489, '\P{^Scx=		HIRA}', "");
Error('\p{Is_Script_Extensions=_-HIRAGANA/a/}');
Error('\P{Is_Script_Extensions=_-HIRAGANA/a/}');
Expect(1, 127488, '\p{Is_Script_Extensions=hiragana}', "");
Expect(0, 127488, '\p{^Is_Script_Extensions=hiragana}', "");
Expect(0, 127488, '\P{Is_Script_Extensions=hiragana}', "");
Expect(1, 127488, '\P{^Is_Script_Extensions=hiragana}', "");
Expect(0, 127489, '\p{Is_Script_Extensions=hiragana}', "");
Expect(1, 127489, '\p{^Is_Script_Extensions=hiragana}', "");
Expect(1, 127489, '\P{Is_Script_Extensions=hiragana}', "");
Expect(0, 127489, '\P{^Is_Script_Extensions=hiragana}', "");
Expect(1, 127488, '\p{Is_Script_Extensions=-_Hiragana}', "");
Expect(0, 127488, '\p{^Is_Script_Extensions=-_Hiragana}', "");
Expect(0, 127488, '\P{Is_Script_Extensions=-_Hiragana}', "");
Expect(1, 127488, '\P{^Is_Script_Extensions=-_Hiragana}', "");
Expect(0, 127489, '\p{Is_Script_Extensions=-_Hiragana}', "");
Expect(1, 127489, '\p{^Is_Script_Extensions=-_Hiragana}', "");
Expect(1, 127489, '\P{Is_Script_Extensions=-_Hiragana}', "");
Expect(0, 127489, '\P{^Is_Script_Extensions=-_Hiragana}', "");
Error('\p{Is_Scx=-Hira:=}');
Error('\P{Is_Scx=-Hira:=}');
Expect(1, 127488, '\p{Is_Scx=hira}', "");
Expect(0, 127488, '\p{^Is_Scx=hira}', "");
Expect(0, 127488, '\P{Is_Scx=hira}', "");
Expect(1, 127488, '\P{^Is_Scx=hira}', "");
Expect(0, 127489, '\p{Is_Scx=hira}', "");
Expect(1, 127489, '\p{^Is_Scx=hira}', "");
Expect(1, 127489, '\P{Is_Scx=hira}', "");
Expect(0, 127489, '\P{^Is_Scx=hira}', "");
Expect(1, 127488, '\p{Is_Scx=--Hira}', "");
Expect(0, 127488, '\p{^Is_Scx=--Hira}', "");
Expect(0, 127488, '\P{Is_Scx=--Hira}', "");
Expect(1, 127488, '\P{^Is_Scx=--Hira}', "");
Expect(0, 127489, '\p{Is_Scx=--Hira}', "");
Expect(1, 127489, '\p{^Is_Scx=--Hira}', "");
Expect(1, 127489, '\P{Is_Scx=--Hira}', "");
Expect(0, 127489, '\P{^Is_Scx=--Hira}', "");
Error('\p{Script_Extensions:Katakana_Or_Hiragana}');
Error('\P{Script_Extensions:Katakana_Or_Hiragana}');
Error('\p{Scx=Hrkt}');
Error('\P{Scx=Hrkt}');
Error('\p{Is_Script_Extensions=Katakana_Or_Hiragana}');
Error('\P{Is_Script_Extensions=Katakana_Or_Hiragana}');
Error('\p{Is_Scx=Hrkt}');
Error('\P{Is_Scx=Hrkt}');
Error('\p{Script_Extensions=_/a/Old_Italic}');
Error('\P{Script_Extensions=_/a/Old_Italic}');
Expect(1, 66339, '\p{Script_Extensions=olditalic}', "");
Expect(0, 66339, '\p{^Script_Extensions=olditalic}', "");
Expect(0, 66339, '\P{Script_Extensions=olditalic}', "");
Expect(1, 66339, '\P{^Script_Extensions=olditalic}', "");
Expect(0, 66340, '\p{Script_Extensions=olditalic}', "");
Expect(1, 66340, '\p{^Script_Extensions=olditalic}', "");
Expect(1, 66340, '\P{Script_Extensions=olditalic}', "");
Expect(0, 66340, '\P{^Script_Extensions=olditalic}', "");
Expect(1, 66339, '\p{Script_Extensions=  Old_Italic}', "");
Expect(0, 66339, '\p{^Script_Extensions=  Old_Italic}', "");
Expect(0, 66339, '\P{Script_Extensions=  Old_Italic}', "");
Expect(1, 66339, '\P{^Script_Extensions=  Old_Italic}', "");
Expect(0, 66340, '\p{Script_Extensions=  Old_Italic}', "");
Expect(1, 66340, '\p{^Script_Extensions=  Old_Italic}', "");
Expect(1, 66340, '\P{Script_Extensions=  Old_Italic}', "");
Expect(0, 66340, '\P{^Script_Extensions=  Old_Italic}', "");
Error('\p{Scx=_ITAL/a/}');
Error('\P{Scx=_ITAL/a/}');
Expect(1, 66339, '\p{Scx:	ital}', "");
Expect(0, 66339, '\p{^Scx:	ital}', "");
Expect(0, 66339, '\P{Scx:	ital}', "");
Expect(1, 66339, '\P{^Scx:	ital}', "");
Expect(0, 66340, '\p{Scx:	ital}', "");
Expect(1, 66340, '\p{^Scx:	ital}', "");
Expect(1, 66340, '\P{Scx:	ital}', "");
Expect(0, 66340, '\P{^Scx:	ital}', "");
Expect(1, 66339, '\p{Scx=	_Ital}', "");
Expect(0, 66339, '\p{^Scx=	_Ital}', "");
Expect(0, 66339, '\P{Scx=	_Ital}', "");
Expect(1, 66339, '\P{^Scx=	_Ital}', "");
Expect(0, 66340, '\p{Scx=	_Ital}', "");
Expect(1, 66340, '\p{^Scx=	_Ital}', "");
Expect(1, 66340, '\P{Scx=	_Ital}', "");
Expect(0, 66340, '\P{^Scx=	_Ital}', "");
Error('\p{Is_Script_Extensions=_/a/OLD_italic}');
Error('\P{Is_Script_Extensions=_/a/OLD_italic}');
Expect(1, 66339, '\p{Is_Script_Extensions=olditalic}', "");
Expect(0, 66339, '\p{^Is_Script_Extensions=olditalic}', "");
Expect(0, 66339, '\P{Is_Script_Extensions=olditalic}', "");
Expect(1, 66339, '\P{^Is_Script_Extensions=olditalic}', "");
Expect(0, 66340, '\p{Is_Script_Extensions=olditalic}', "");
Expect(1, 66340, '\p{^Is_Script_Extensions=olditalic}', "");
Expect(1, 66340, '\P{Is_Script_Extensions=olditalic}', "");
Expect(0, 66340, '\P{^Is_Script_Extensions=olditalic}', "");
Expect(1, 66339, '\p{Is_Script_Extensions=	Old_ITALIC}', "");
Expect(0, 66339, '\p{^Is_Script_Extensions=	Old_ITALIC}', "");
Expect(0, 66339, '\P{Is_Script_Extensions=	Old_ITALIC}', "");
Expect(1, 66339, '\P{^Is_Script_Extensions=	Old_ITALIC}', "");
Expect(0, 66340, '\p{Is_Script_Extensions=	Old_ITALIC}', "");
Expect(1, 66340, '\p{^Is_Script_Extensions=	Old_ITALIC}', "");
Expect(1, 66340, '\P{Is_Script_Extensions=	Old_ITALIC}', "");
Expect(0, 66340, '\P{^Is_Script_Extensions=	Old_ITALIC}', "");
Error('\p{Is_Scx=_ital:=}');
Error('\P{Is_Scx=_ital:=}');
Expect(1, 66339, '\p{Is_Scx:   ital}', "");
Expect(0, 66339, '\p{^Is_Scx:   ital}', "");
Expect(0, 66339, '\P{Is_Scx:   ital}', "");
Expect(1, 66339, '\P{^Is_Scx:   ital}', "");
Expect(0, 66340, '\p{Is_Scx:   ital}', "");
Expect(1, 66340, '\p{^Is_Scx:   ital}', "");
Expect(1, 66340, '\P{Is_Scx:   ital}', "");
Expect(0, 66340, '\P{^Is_Scx:   ital}', "");
Expect(1, 66339, '\p{Is_Scx= ITAL}', "");
Expect(0, 66339, '\p{^Is_Scx= ITAL}', "");
Expect(0, 66339, '\P{Is_Scx= ITAL}', "");
Expect(1, 66339, '\P{^Is_Scx= ITAL}', "");
Expect(0, 66340, '\p{Is_Scx= ITAL}', "");
Expect(1, 66340, '\p{^Is_Scx= ITAL}', "");
Expect(1, 66340, '\P{Is_Scx= ITAL}', "");
Expect(0, 66340, '\P{^Is_Scx= ITAL}', "");
Error('\p{Script_Extensions:	:=JAVANESE}');
Error('\P{Script_Extensions:	:=JAVANESE}');
Expect(1, 43487, '\p{Script_Extensions=javanese}', "");
Expect(0, 43487, '\p{^Script_Extensions=javanese}', "");
Expect(0, 43487, '\P{Script_Extensions=javanese}', "");
Expect(1, 43487, '\P{^Script_Extensions=javanese}', "");
Expect(0, 43488, '\p{Script_Extensions=javanese}', "");
Expect(1, 43488, '\p{^Script_Extensions=javanese}', "");
Expect(1, 43488, '\P{Script_Extensions=javanese}', "");
Expect(0, 43488, '\P{^Script_Extensions=javanese}', "");
Expect(1, 43487, '\p{Script_Extensions:   _-Javanese}', "");
Expect(0, 43487, '\p{^Script_Extensions:   _-Javanese}', "");
Expect(0, 43487, '\P{Script_Extensions:   _-Javanese}', "");
Expect(1, 43487, '\P{^Script_Extensions:   _-Javanese}', "");
Expect(0, 43488, '\p{Script_Extensions:   _-Javanese}', "");
Expect(1, 43488, '\p{^Script_Extensions:   _-Javanese}', "");
Expect(1, 43488, '\P{Script_Extensions:   _-Javanese}', "");
Expect(0, 43488, '\P{^Script_Extensions:   _-Javanese}', "");
Error('\p{Scx:    /a/Java}');
Error('\P{Scx:    /a/Java}');
Expect(1, 43487, '\p{Scx=java}', "");
Expect(0, 43487, '\p{^Scx=java}', "");
Expect(0, 43487, '\P{Scx=java}', "");
Expect(1, 43487, '\P{^Scx=java}', "");
Expect(0, 43488, '\p{Scx=java}', "");
Expect(1, 43488, '\p{^Scx=java}', "");
Expect(1, 43488, '\P{Scx=java}', "");
Expect(0, 43488, '\P{^Scx=java}', "");
Expect(1, 43487, '\p{Scx=_-Java}', "");
Expect(0, 43487, '\p{^Scx=_-Java}', "");
Expect(0, 43487, '\P{Scx=_-Java}', "");
Expect(1, 43487, '\P{^Scx=_-Java}', "");
Expect(0, 43488, '\p{Scx=_-Java}', "");
Expect(1, 43488, '\p{^Scx=_-Java}', "");
Expect(1, 43488, '\P{Scx=_-Java}', "");
Expect(0, 43488, '\P{^Scx=_-Java}', "");
Error('\p{Is_Script_Extensions:   -Javanese/a/}');
Error('\P{Is_Script_Extensions:   -Javanese/a/}');
Expect(1, 43487, '\p{Is_Script_Extensions=javanese}', "");
Expect(0, 43487, '\p{^Is_Script_Extensions=javanese}', "");
Expect(0, 43487, '\P{Is_Script_Extensions=javanese}', "");
Expect(1, 43487, '\P{^Is_Script_Extensions=javanese}', "");
Expect(0, 43488, '\p{Is_Script_Extensions=javanese}', "");
Expect(1, 43488, '\p{^Is_Script_Extensions=javanese}', "");
Expect(1, 43488, '\P{Is_Script_Extensions=javanese}', "");
Expect(0, 43488, '\P{^Is_Script_Extensions=javanese}', "");
Expect(1, 43487, '\p{Is_Script_Extensions=__javanese}', "");
Expect(0, 43487, '\p{^Is_Script_Extensions=__javanese}', "");
Expect(0, 43487, '\P{Is_Script_Extensions=__javanese}', "");
Expect(1, 43487, '\P{^Is_Script_Extensions=__javanese}', "");
Expect(0, 43488, '\p{Is_Script_Extensions=__javanese}', "");
Expect(1, 43488, '\p{^Is_Script_Extensions=__javanese}', "");
Expect(1, 43488, '\P{Is_Script_Extensions=__javanese}', "");
Expect(0, 43488, '\P{^Is_Script_Extensions=__javanese}', "");
Error('\p{Is_Scx=_ Java:=}');
Error('\P{Is_Scx=_ Java:=}');
Expect(1, 43487, '\p{Is_Scx=java}', "");
Expect(0, 43487, '\p{^Is_Scx=java}', "");
Expect(0, 43487, '\P{Is_Scx=java}', "");
Expect(1, 43487, '\P{^Is_Scx=java}', "");
Expect(0, 43488, '\p{Is_Scx=java}', "");
Expect(1, 43488, '\p{^Is_Scx=java}', "");
Expect(1, 43488, '\P{Is_Scx=java}', "");
Expect(0, 43488, '\P{^Is_Scx=java}', "");
Expect(1, 43487, '\p{Is_Scx= _JAVA}', "");
Expect(0, 43487, '\p{^Is_Scx= _JAVA}', "");
Expect(0, 43487, '\P{Is_Scx= _JAVA}', "");
Expect(1, 43487, '\P{^Is_Scx= _JAVA}', "");
Expect(0, 43488, '\p{Is_Scx= _JAVA}', "");
Expect(1, 43488, '\p{^Is_Scx= _JAVA}', "");
Expect(1, 43488, '\P{Is_Scx= _JAVA}', "");
Expect(0, 43488, '\P{^Is_Scx= _JAVA}', "");
Error('\p{Script_Extensions=_ Kayah_Li/a/}');
Error('\P{Script_Extensions=_ Kayah_Li/a/}');
Expect(1, 43311, '\p{Script_Extensions=kayahli}', "");
Expect(0, 43311, '\p{^Script_Extensions=kayahli}', "");
Expect(0, 43311, '\P{Script_Extensions=kayahli}', "");
Expect(1, 43311, '\P{^Script_Extensions=kayahli}', "");
Expect(0, 43312, '\p{Script_Extensions=kayahli}', "");
Expect(1, 43312, '\p{^Script_Extensions=kayahli}', "");
Expect(1, 43312, '\P{Script_Extensions=kayahli}', "");
Expect(0, 43312, '\P{^Script_Extensions=kayahli}', "");
Expect(1, 43311, '\p{Script_Extensions=_-KAYAH_li}', "");
Expect(0, 43311, '\p{^Script_Extensions=_-KAYAH_li}', "");
Expect(0, 43311, '\P{Script_Extensions=_-KAYAH_li}', "");
Expect(1, 43311, '\P{^Script_Extensions=_-KAYAH_li}', "");
Expect(0, 43312, '\p{Script_Extensions=_-KAYAH_li}', "");
Expect(1, 43312, '\p{^Script_Extensions=_-KAYAH_li}', "");
Expect(1, 43312, '\P{Script_Extensions=_-KAYAH_li}', "");
Expect(0, 43312, '\P{^Script_Extensions=_-KAYAH_li}', "");
Error('\p{Scx=_:=KALI}');
Error('\P{Scx=_:=KALI}');
Expect(1, 43311, '\p{Scx=kali}', "");
Expect(0, 43311, '\p{^Scx=kali}', "");
Expect(0, 43311, '\P{Scx=kali}', "");
Expect(1, 43311, '\P{^Scx=kali}', "");
Expect(0, 43312, '\p{Scx=kali}', "");
Expect(1, 43312, '\p{^Scx=kali}', "");
Expect(1, 43312, '\P{Scx=kali}', "");
Expect(0, 43312, '\P{^Scx=kali}', "");
Expect(1, 43311, '\p{Scx= 	Kali}', "");
Expect(0, 43311, '\p{^Scx= 	Kali}', "");
Expect(0, 43311, '\P{Scx= 	Kali}', "");
Expect(1, 43311, '\P{^Scx= 	Kali}', "");
Expect(0, 43312, '\p{Scx= 	Kali}', "");
Expect(1, 43312, '\p{^Scx= 	Kali}', "");
Expect(1, 43312, '\P{Scx= 	Kali}', "");
Expect(0, 43312, '\P{^Scx= 	Kali}', "");
Error('\p{Is_Script_Extensions=/a/-KAYAH_Li}');
Error('\P{Is_Script_Extensions=/a/-KAYAH_Li}');
Expect(1, 43311, '\p{Is_Script_Extensions:kayahli}', "");
Expect(0, 43311, '\p{^Is_Script_Extensions:kayahli}', "");
Expect(0, 43311, '\P{Is_Script_Extensions:kayahli}', "");
Expect(1, 43311, '\P{^Is_Script_Extensions:kayahli}', "");
Expect(0, 43312, '\p{Is_Script_Extensions:kayahli}', "");
Expect(1, 43312, '\p{^Is_Script_Extensions:kayahli}', "");
Expect(1, 43312, '\P{Is_Script_Extensions:kayahli}', "");
Expect(0, 43312, '\P{^Is_Script_Extensions:kayahli}', "");
Expect(1, 43311, '\p{Is_Script_Extensions= -Kayah_li}', "");
Expect(0, 43311, '\p{^Is_Script_Extensions= -Kayah_li}', "");
Expect(0, 43311, '\P{Is_Script_Extensions= -Kayah_li}', "");
Expect(1, 43311, '\P{^Is_Script_Extensions= -Kayah_li}', "");
Expect(0, 43312, '\p{Is_Script_Extensions= -Kayah_li}', "");
Expect(1, 43312, '\p{^Is_Script_Extensions= -Kayah_li}', "");
Expect(1, 43312, '\P{Is_Script_Extensions= -Kayah_li}', "");
Expect(0, 43312, '\P{^Is_Script_Extensions= -Kayah_li}', "");
Error('\p{Is_Scx=_ Kali/a/}');
Error('\P{Is_Scx=_ Kali/a/}');
Expect(1, 43311, '\p{Is_Scx:   kali}', "");
Expect(0, 43311, '\p{^Is_Scx:   kali}', "");
Expect(0, 43311, '\P{Is_Scx:   kali}', "");
Expect(1, 43311, '\P{^Is_Scx:   kali}', "");
Expect(0, 43312, '\p{Is_Scx:   kali}', "");
Expect(1, 43312, '\p{^Is_Scx:   kali}', "");
Expect(1, 43312, '\P{Is_Scx:   kali}', "");
Expect(0, 43312, '\P{^Is_Scx:   kali}', "");
Expect(1, 43311, '\p{Is_Scx=-Kali}', "");
Expect(0, 43311, '\p{^Is_Scx=-Kali}', "");
Expect(0, 43311, '\P{Is_Scx=-Kali}', "");
Expect(1, 43311, '\P{^Is_Scx=-Kali}', "");
Expect(0, 43312, '\p{Is_Scx=-Kali}', "");
Expect(1, 43312, '\p{^Is_Scx=-Kali}', "");
Expect(1, 43312, '\P{Is_Scx=-Kali}', "");
Expect(0, 43312, '\P{^Is_Scx=-Kali}', "");
Error('\p{Script_Extensions=-:=Katakana}');
Error('\P{Script_Extensions=-:=Katakana}');
Expect(1, 110592, '\p{Script_Extensions=katakana}', "");
Expect(0, 110592, '\p{^Script_Extensions=katakana}', "");
Expect(0, 110592, '\P{Script_Extensions=katakana}', "");
Expect(1, 110592, '\P{^Script_Extensions=katakana}', "");
Expect(0, 110593, '\p{Script_Extensions=katakana}', "");
Expect(1, 110593, '\p{^Script_Extensions=katakana}', "");
Expect(1, 110593, '\P{Script_Extensions=katakana}', "");
Expect(0, 110593, '\P{^Script_Extensions=katakana}', "");
Expect(1, 110592, '\p{Script_Extensions:  Katakana}', "");
Expect(0, 110592, '\p{^Script_Extensions:  Katakana}', "");
Expect(0, 110592, '\P{Script_Extensions:  Katakana}', "");
Expect(1, 110592, '\P{^Script_Extensions:  Katakana}', "");
Expect(0, 110593, '\p{Script_Extensions:  Katakana}', "");
Expect(1, 110593, '\p{^Script_Extensions:  Katakana}', "");
Expect(1, 110593, '\P{Script_Extensions:  Katakana}', "");
Expect(0, 110593, '\P{^Script_Extensions:  Katakana}', "");
Error('\p{Scx=	/a/KANA}');
Error('\P{Scx=	/a/KANA}');
Expect(1, 110592, '\p{Scx:   kana}', "");
Expect(0, 110592, '\p{^Scx:   kana}', "");
Expect(0, 110592, '\P{Scx:   kana}', "");
Expect(1, 110592, '\P{^Scx:   kana}', "");
Expect(0, 110593, '\p{Scx:   kana}', "");
Expect(1, 110593, '\p{^Scx:   kana}', "");
Expect(1, 110593, '\P{Scx:   kana}', "");
Expect(0, 110593, '\P{^Scx:   kana}', "");
Expect(1, 110592, '\p{Scx= 	kana}', "");
Expect(0, 110592, '\p{^Scx= 	kana}', "");
Expect(0, 110592, '\P{Scx= 	kana}', "");
Expect(1, 110592, '\P{^Scx= 	kana}', "");
Expect(0, 110593, '\p{Scx= 	kana}', "");
Expect(1, 110593, '\p{^Scx= 	kana}', "");
Expect(1, 110593, '\P{Scx= 	kana}', "");
Expect(0, 110593, '\P{^Scx= 	kana}', "");
Error('\p{Is_Script_Extensions=:=__katakana}');
Error('\P{Is_Script_Extensions=:=__katakana}');
Expect(1, 110592, '\p{Is_Script_Extensions=katakana}', "");
Expect(0, 110592, '\p{^Is_Script_Extensions=katakana}', "");
Expect(0, 110592, '\P{Is_Script_Extensions=katakana}', "");
Expect(1, 110592, '\P{^Is_Script_Extensions=katakana}', "");
Expect(0, 110593, '\p{Is_Script_Extensions=katakana}', "");
Expect(1, 110593, '\p{^Is_Script_Extensions=katakana}', "");
Expect(1, 110593, '\P{Is_Script_Extensions=katakana}', "");
Expect(0, 110593, '\P{^Is_Script_Extensions=katakana}', "");
Expect(1, 110592, '\p{Is_Script_Extensions=_Katakana}', "");
Expect(0, 110592, '\p{^Is_Script_Extensions=_Katakana}', "");
Expect(0, 110592, '\P{Is_Script_Extensions=_Katakana}', "");
Expect(1, 110592, '\P{^Is_Script_Extensions=_Katakana}', "");
Expect(0, 110593, '\p{Is_Script_Extensions=_Katakana}', "");
Expect(1, 110593, '\p{^Is_Script_Extensions=_Katakana}', "");
Expect(1, 110593, '\P{Is_Script_Extensions=_Katakana}', "");
Expect(0, 110593, '\P{^Is_Script_Extensions=_Katakana}', "");
Error('\p{Is_Scx=_:=kana}');
Error('\P{Is_Scx=_:=kana}');
Expect(1, 110592, '\p{Is_Scx=kana}', "");
Expect(0, 110592, '\p{^Is_Scx=kana}', "");
Expect(0, 110592, '\P{Is_Scx=kana}', "");
Expect(1, 110592, '\P{^Is_Scx=kana}', "");
Expect(0, 110593, '\p{Is_Scx=kana}', "");
Expect(1, 110593, '\p{^Is_Scx=kana}', "");
Expect(1, 110593, '\P{Is_Scx=kana}', "");
Expect(0, 110593, '\P{^Is_Scx=kana}', "");
Expect(1, 110592, '\p{Is_Scx=	Kana}', "");
Expect(0, 110592, '\p{^Is_Scx=	Kana}', "");
Expect(0, 110592, '\P{Is_Scx=	Kana}', "");
Expect(1, 110592, '\P{^Is_Scx=	Kana}', "");
Expect(0, 110593, '\p{Is_Scx=	Kana}', "");
Expect(1, 110593, '\p{^Is_Scx=	Kana}', "");
Expect(1, 110593, '\P{Is_Scx=	Kana}', "");
Expect(0, 110593, '\P{^Is_Scx=	Kana}', "");
Error('\p{Script_Extensions=_:=Kharoshthi}');
Error('\P{Script_Extensions=_:=Kharoshthi}');
Expect(1, 68184, '\p{Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\p{^Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\P{Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\P{^Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\p{Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\p{^Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\P{Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\P{^Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\p{Script_Extensions=-kharoshthi}', "");
Expect(0, 68184, '\p{^Script_Extensions=-kharoshthi}', "");
Expect(0, 68184, '\P{Script_Extensions=-kharoshthi}', "");
Expect(1, 68184, '\P{^Script_Extensions=-kharoshthi}', "");
Expect(0, 68185, '\p{Script_Extensions=-kharoshthi}', "");
Expect(1, 68185, '\p{^Script_Extensions=-kharoshthi}', "");
Expect(1, 68185, '\P{Script_Extensions=-kharoshthi}', "");
Expect(0, 68185, '\P{^Script_Extensions=-kharoshthi}', "");
Error('\p{Scx=/a/  KHAR}');
Error('\P{Scx=/a/  KHAR}');
Expect(1, 68184, '\p{Scx=khar}', "");
Expect(0, 68184, '\p{^Scx=khar}', "");
Expect(0, 68184, '\P{Scx=khar}', "");
Expect(1, 68184, '\P{^Scx=khar}', "");
Expect(0, 68185, '\p{Scx=khar}', "");
Expect(1, 68185, '\p{^Scx=khar}', "");
Expect(1, 68185, '\P{Scx=khar}', "");
Expect(0, 68185, '\P{^Scx=khar}', "");
Expect(1, 68184, '\p{Scx=	Khar}', "");
Expect(0, 68184, '\p{^Scx=	Khar}', "");
Expect(0, 68184, '\P{Scx=	Khar}', "");
Expect(1, 68184, '\P{^Scx=	Khar}', "");
Expect(0, 68185, '\p{Scx=	Khar}', "");
Expect(1, 68185, '\p{^Scx=	Khar}', "");
Expect(1, 68185, '\P{Scx=	Khar}', "");
Expect(0, 68185, '\P{^Scx=	Khar}', "");
Error('\p{Is_Script_Extensions= /a/KHAROSHTHI}');
Error('\P{Is_Script_Extensions= /a/KHAROSHTHI}');
Expect(1, 68184, '\p{Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script_Extensions=kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script_Extensions=kharoshthi}', "");
Expect(1, 68184, '\p{Is_Script_Extensions=-Kharoshthi}', "");
Expect(0, 68184, '\p{^Is_Script_Extensions=-Kharoshthi}', "");
Expect(0, 68184, '\P{Is_Script_Extensions=-Kharoshthi}', "");
Expect(1, 68184, '\P{^Is_Script_Extensions=-Kharoshthi}', "");
Expect(0, 68185, '\p{Is_Script_Extensions=-Kharoshthi}', "");
Expect(1, 68185, '\p{^Is_Script_Extensions=-Kharoshthi}', "");
Expect(1, 68185, '\P{Is_Script_Extensions=-Kharoshthi}', "");
Expect(0, 68185, '\P{^Is_Script_Extensions=-Kharoshthi}', "");
Error('\p{Is_Scx=	khar:=}');
Error('\P{Is_Scx=	khar:=}');
Expect(1, 68184, '\p{Is_Scx=khar}', "");
Expect(0, 68184, '\p{^Is_Scx=khar}', "");
Expect(0, 68184, '\P{Is_Scx=khar}', "");
Expect(1, 68184, '\P{^Is_Scx=khar}', "");
Expect(0, 68185, '\p{Is_Scx=khar}', "");
Expect(1, 68185, '\p{^Is_Scx=khar}', "");
Expect(1, 68185, '\P{Is_Scx=khar}', "");
Expect(0, 68185, '\P{^Is_Scx=khar}', "");
Expect(1, 68184, '\p{Is_Scx=_Khar}', "");
Expect(0, 68184, '\p{^Is_Scx=_Khar}', "");
Expect(0, 68184, '\P{Is_Scx=_Khar}', "");
Expect(1, 68184, '\P{^Is_Scx=_Khar}', "");
Expect(0, 68185, '\p{Is_Scx=_Khar}', "");
Expect(1, 68185, '\p{^Is_Scx=_Khar}', "");
Expect(1, 68185, '\P{Is_Scx=_Khar}', "");
Expect(0, 68185, '\P{^Is_Scx=_Khar}', "");
Error('\p{Script_Extensions=		Khmer/a/}');
Error('\P{Script_Extensions=		Khmer/a/}');
Expect(1, 6655, '\p{Script_Extensions=khmer}', "");
Expect(0, 6655, '\p{^Script_Extensions=khmer}', "");
Expect(0, 6655, '\P{Script_Extensions=khmer}', "");
Expect(1, 6655, '\P{^Script_Extensions=khmer}', "");
Expect(0, 6656, '\p{Script_Extensions=khmer}', "");
Expect(1, 6656, '\p{^Script_Extensions=khmer}', "");
Expect(1, 6656, '\P{Script_Extensions=khmer}', "");
Expect(0, 6656, '\P{^Script_Extensions=khmer}', "");
Expect(1, 6655, '\p{Script_Extensions=_-Khmer}', "");
Expect(0, 6655, '\p{^Script_Extensions=_-Khmer}', "");
Expect(0, 6655, '\P{Script_Extensions=_-Khmer}', "");
Expect(1, 6655, '\P{^Script_Extensions=_-Khmer}', "");
Expect(0, 6656, '\p{Script_Extensions=_-Khmer}', "");
Expect(1, 6656, '\p{^Script_Extensions=_-Khmer}', "");
Expect(1, 6656, '\P{Script_Extensions=_-Khmer}', "");
Expect(0, 6656, '\P{^Script_Extensions=_-Khmer}', "");
Error('\p{Scx=_-Khmr:=}');
Error('\P{Scx=_-Khmr:=}');
Expect(1, 6655, '\p{Scx=khmr}', "");
Expect(0, 6655, '\p{^Scx=khmr}', "");
Expect(0, 6655, '\P{Scx=khmr}', "");
Expect(1, 6655, '\P{^Scx=khmr}', "");
Expect(0, 6656, '\p{Scx=khmr}', "");
Expect(1, 6656, '\p{^Scx=khmr}', "");
Expect(1, 6656, '\P{Scx=khmr}', "");
Expect(0, 6656, '\P{^Scx=khmr}', "");
Expect(1, 6655, '\p{Scx=-Khmr}', "");
Expect(0, 6655, '\p{^Scx=-Khmr}', "");
Expect(0, 6655, '\P{Scx=-Khmr}', "");
Expect(1, 6655, '\P{^Scx=-Khmr}', "");
Expect(0, 6656, '\p{Scx=-Khmr}', "");
Expect(1, 6656, '\p{^Scx=-Khmr}', "");
Expect(1, 6656, '\P{Scx=-Khmr}', "");
Expect(0, 6656, '\P{^Scx=-Khmr}', "");
Error('\p{Is_Script_Extensions: /a/-KHMER}');
Error('\P{Is_Script_Extensions: /a/-KHMER}');
Expect(1, 6655, '\p{Is_Script_Extensions=khmer}', "");
Expect(0, 6655, '\p{^Is_Script_Extensions=khmer}', "");
Expect(0, 6655, '\P{Is_Script_Extensions=khmer}', "");
Expect(1, 6655, '\P{^Is_Script_Extensions=khmer}', "");
Expect(0, 6656, '\p{Is_Script_Extensions=khmer}', "");
Expect(1, 6656, '\p{^Is_Script_Extensions=khmer}', "");
Expect(1, 6656, '\P{Is_Script_Extensions=khmer}', "");
Expect(0, 6656, '\P{^Is_Script_Extensions=khmer}', "");
Expect(1, 6655, '\p{Is_Script_Extensions=- Khmer}', "");
Expect(0, 6655, '\p{^Is_Script_Extensions=- Khmer}', "");
Expect(0, 6655, '\P{Is_Script_Extensions=- Khmer}', "");
Expect(1, 6655, '\P{^Is_Script_Extensions=- Khmer}', "");
Expect(0, 6656, '\p{Is_Script_Extensions=- Khmer}', "");
Expect(1, 6656, '\p{^Is_Script_Extensions=- Khmer}', "");
Expect(1, 6656, '\P{Is_Script_Extensions=- Khmer}', "");
Expect(0, 6656, '\P{^Is_Script_Extensions=- Khmer}', "");
Error('\p{Is_Scx=	-Khmr:=}');
Error('\P{Is_Scx=	-Khmr:=}');
Expect(1, 6655, '\p{Is_Scx=khmr}', "");
Expect(0, 6655, '\p{^Is_Scx=khmr}', "");
Expect(0, 6655, '\P{Is_Scx=khmr}', "");
Expect(1, 6655, '\P{^Is_Scx=khmr}', "");
Expect(0, 6656, '\p{Is_Scx=khmr}', "");
Expect(1, 6656, '\p{^Is_Scx=khmr}', "");
Expect(1, 6656, '\P{Is_Scx=khmr}', "");
Expect(0, 6656, '\P{^Is_Scx=khmr}', "");
Expect(1, 6655, '\p{Is_Scx=_-Khmr}', "");
Expect(0, 6655, '\p{^Is_Scx=_-Khmr}', "");
Expect(0, 6655, '\P{Is_Scx=_-Khmr}', "");
Expect(1, 6655, '\P{^Is_Scx=_-Khmr}', "");
Expect(0, 6656, '\p{Is_Scx=_-Khmr}', "");
Expect(1, 6656, '\p{^Is_Scx=_-Khmr}', "");
Expect(1, 6656, '\P{Is_Scx=_-Khmr}', "");
Expect(0, 6656, '\P{^Is_Scx=_-Khmr}', "");
Error('\p{Script_Extensions=:=	KANNADA}');
Error('\P{Script_Extensions=:=	KANNADA}');
Expect(1, 3314, '\p{Script_Extensions=kannada}', "");
Expect(0, 3314, '\p{^Script_Extensions=kannada}', "");
Expect(0, 3314, '\P{Script_Extensions=kannada}', "");
Expect(1, 3314, '\P{^Script_Extensions=kannada}', "");
Expect(0, 3315, '\p{Script_Extensions=kannada}', "");
Expect(1, 3315, '\p{^Script_Extensions=kannada}', "");
Expect(1, 3315, '\P{Script_Extensions=kannada}', "");
Expect(0, 3315, '\P{^Script_Extensions=kannada}', "");
Expect(1, 3314, '\p{Script_Extensions=__Kannada}', "");
Expect(0, 3314, '\p{^Script_Extensions=__Kannada}', "");
Expect(0, 3314, '\P{Script_Extensions=__Kannada}', "");
Expect(1, 3314, '\P{^Script_Extensions=__Kannada}', "");
Expect(0, 3315, '\p{Script_Extensions=__Kannada}', "");
Expect(1, 3315, '\p{^Script_Extensions=__Kannada}', "");
Expect(1, 3315, '\P{Script_Extensions=__Kannada}', "");
Expect(0, 3315, '\P{^Script_Extensions=__Kannada}', "");
Error('\p{Scx= :=Knda}');
Error('\P{Scx= :=Knda}');
Expect(1, 3314, '\p{Scx=knda}', "");
Expect(0, 3314, '\p{^Scx=knda}', "");
Expect(0, 3314, '\P{Scx=knda}', "");
Expect(1, 3314, '\P{^Scx=knda}', "");
Expect(0, 3315, '\p{Scx=knda}', "");
Expect(1, 3315, '\p{^Scx=knda}', "");
Expect(1, 3315, '\P{Scx=knda}', "");
Expect(0, 3315, '\P{^Scx=knda}', "");
Expect(1, 3314, '\p{Scx:		-Knda}', "");
Expect(0, 3314, '\p{^Scx:		-Knda}', "");
Expect(0, 3314, '\P{Scx:		-Knda}', "");
Expect(1, 3314, '\P{^Scx:		-Knda}', "");
Expect(0, 3315, '\p{Scx:		-Knda}', "");
Expect(1, 3315, '\p{^Scx:		-Knda}', "");
Expect(1, 3315, '\P{Scx:		-Knda}', "");
Expect(0, 3315, '\P{^Scx:		-Knda}', "");
Error('\p{Is_Script_Extensions:	/a/--Kannada}');
Error('\P{Is_Script_Extensions:	/a/--Kannada}');
Expect(1, 3314, '\p{Is_Script_Extensions=kannada}', "");
Expect(0, 3314, '\p{^Is_Script_Extensions=kannada}', "");
Expect(0, 3314, '\P{Is_Script_Extensions=kannada}', "");
Expect(1, 3314, '\P{^Is_Script_Extensions=kannada}', "");
Expect(0, 3315, '\p{Is_Script_Extensions=kannada}', "");
Expect(1, 3315, '\p{^Is_Script_Extensions=kannada}', "");
Expect(1, 3315, '\P{Is_Script_Extensions=kannada}', "");
Expect(0, 3315, '\P{^Is_Script_Extensions=kannada}', "");
Expect(1, 3314, '\p{Is_Script_Extensions=	kannada}', "");
Expect(0, 3314, '\p{^Is_Script_Extensions=	kannada}', "");
Expect(0, 3314, '\P{Is_Script_Extensions=	kannada}', "");
Expect(1, 3314, '\P{^Is_Script_Extensions=	kannada}', "");
Expect(0, 3315, '\p{Is_Script_Extensions=	kannada}', "");
Expect(1, 3315, '\p{^Is_Script_Extensions=	kannada}', "");
Expect(1, 3315, '\P{Is_Script_Extensions=	kannada}', "");
Expect(0, 3315, '\P{^Is_Script_Extensions=	kannada}', "");
Error('\p{Is_Scx=-_knda/a/}');
Error('\P{Is_Scx=-_knda/a/}');
Expect(1, 3314, '\p{Is_Scx=knda}', "");
Expect(0, 3314, '\p{^Is_Scx=knda}', "");
Expect(0, 3314, '\P{Is_Scx=knda}', "");
Expect(1, 3314, '\P{^Is_Scx=knda}', "");
Expect(0, 3315, '\p{Is_Scx=knda}', "");
Expect(1, 3315, '\p{^Is_Scx=knda}', "");
Expect(1, 3315, '\P{Is_Scx=knda}', "");
Expect(0, 3315, '\P{^Is_Scx=knda}', "");
Expect(1, 3314, '\p{Is_Scx=_	KNDA}', "");
Expect(0, 3314, '\p{^Is_Scx=_	KNDA}', "");
Expect(0, 3314, '\P{Is_Scx=_	KNDA}', "");
Expect(1, 3314, '\P{^Is_Scx=_	KNDA}', "");
Expect(0, 3315, '\p{Is_Scx=_	KNDA}', "");
Expect(1, 3315, '\p{^Is_Scx=_	KNDA}', "");
Expect(1, 3315, '\P{Is_Scx=_	KNDA}', "");
Expect(0, 3315, '\P{^Is_Scx=_	KNDA}', "");
Error('\p{Script_Extensions:	/a/- Kaithi}');
Error('\P{Script_Extensions:	/a/- Kaithi}');
Expect(1, 69825, '\p{Script_Extensions=kaithi}', "");
Expect(0, 69825, '\p{^Script_Extensions=kaithi}', "");
Expect(0, 69825, '\P{Script_Extensions=kaithi}', "");
Expect(1, 69825, '\P{^Script_Extensions=kaithi}', "");
Expect(0, 69826, '\p{Script_Extensions=kaithi}', "");
Expect(1, 69826, '\p{^Script_Extensions=kaithi}', "");
Expect(1, 69826, '\P{Script_Extensions=kaithi}', "");
Expect(0, 69826, '\P{^Script_Extensions=kaithi}', "");
Expect(1, 69825, '\p{Script_Extensions= 	kaithi}', "");
Expect(0, 69825, '\p{^Script_Extensions= 	kaithi}', "");
Expect(0, 69825, '\P{Script_Extensions= 	kaithi}', "");
Expect(1, 69825, '\P{^Script_Extensions= 	kaithi}', "");
Expect(0, 69826, '\p{Script_Extensions= 	kaithi}', "");
Expect(1, 69826, '\p{^Script_Extensions= 	kaithi}', "");
Expect(1, 69826, '\P{Script_Extensions= 	kaithi}', "");
Expect(0, 69826, '\P{^Script_Extensions= 	kaithi}', "");
Error('\p{Scx= 	KTHI:=}');
Error('\P{Scx= 	KTHI:=}');
Expect(1, 69825, '\p{Scx=kthi}', "");
Expect(0, 69825, '\p{^Scx=kthi}', "");
Expect(0, 69825, '\P{Scx=kthi}', "");
Expect(1, 69825, '\P{^Scx=kthi}', "");
Expect(0, 69826, '\p{Scx=kthi}', "");
Expect(1, 69826, '\p{^Scx=kthi}', "");
Expect(1, 69826, '\P{Scx=kthi}', "");
Expect(0, 69826, '\P{^Scx=kthi}', "");
Expect(1, 69825, '\p{Scx=	 Kthi}', "");
Expect(0, 69825, '\p{^Scx=	 Kthi}', "");
Expect(0, 69825, '\P{Scx=	 Kthi}', "");
Expect(1, 69825, '\P{^Scx=	 Kthi}', "");
Expect(0, 69826, '\p{Scx=	 Kthi}', "");
Expect(1, 69826, '\p{^Scx=	 Kthi}', "");
Expect(1, 69826, '\P{Scx=	 Kthi}', "");
Expect(0, 69826, '\P{^Scx=	 Kthi}', "");
Error('\p{Is_Script_Extensions=:=	kaithi}');
Error('\P{Is_Script_Extensions=:=	kaithi}');
Expect(1, 69825, '\p{Is_Script_Extensions:	kaithi}', "");
Expect(0, 69825, '\p{^Is_Script_Extensions:	kaithi}', "");
Expect(0, 69825, '\P{Is_Script_Extensions:	kaithi}', "");
Expect(1, 69825, '\P{^Is_Script_Extensions:	kaithi}', "");
Expect(0, 69826, '\p{Is_Script_Extensions:	kaithi}', "");
Expect(1, 69826, '\p{^Is_Script_Extensions:	kaithi}', "");
Expect(1, 69826, '\P{Is_Script_Extensions:	kaithi}', "");
Expect(0, 69826, '\P{^Is_Script_Extensions:	kaithi}', "");
Expect(1, 69825, '\p{Is_Script_Extensions=- Kaithi}', "");
Expect(0, 69825, '\p{^Is_Script_Extensions=- Kaithi}', "");
Expect(0, 69825, '\P{Is_Script_Extensions=- Kaithi}', "");
Expect(1, 69825, '\P{^Is_Script_Extensions=- Kaithi}', "");
Expect(0, 69826, '\p{Is_Script_Extensions=- Kaithi}', "");
Expect(1, 69826, '\p{^Is_Script_Extensions=- Kaithi}', "");
Expect(1, 69826, '\P{Is_Script_Extensions=- Kaithi}', "");
Expect(0, 69826, '\P{^Is_Script_Extensions=- Kaithi}', "");
Error('\p{Is_Scx=/a/	-Kthi}');
Error('\P{Is_Scx=/a/	-Kthi}');
Expect(1, 69825, '\p{Is_Scx=kthi}', "");
Expect(0, 69825, '\p{^Is_Scx=kthi}', "");
Expect(0, 69825, '\P{Is_Scx=kthi}', "");
Expect(1, 69825, '\P{^Is_Scx=kthi}', "");
Expect(0, 69826, '\p{Is_Scx=kthi}', "");
Expect(1, 69826, '\p{^Is_Scx=kthi}', "");
Expect(1, 69826, '\P{Is_Scx=kthi}', "");
Expect(0, 69826, '\P{^Is_Scx=kthi}', "");
Expect(1, 69825, '\p{Is_Scx=-	KTHI}', "");
Expect(0, 69825, '\p{^Is_Scx=-	KTHI}', "");
Expect(0, 69825, '\P{Is_Scx=-	KTHI}', "");
Expect(1, 69825, '\P{^Is_Scx=-	KTHI}', "");
Expect(0, 69826, '\p{Is_Scx=-	KTHI}', "");
Expect(1, 69826, '\p{^Is_Scx=-	KTHI}', "");
Expect(1, 69826, '\P{Is_Scx=-	KTHI}', "");
Expect(0, 69826, '\P{^Is_Scx=-	KTHI}', "");
Error('\p{Script_Extensions=/a/ Tai_Tham}');
Error('\P{Script_Extensions=/a/ Tai_Tham}');
Expect(1, 6829, '\p{Script_Extensions=taitham}', "");
Expect(0, 6829, '\p{^Script_Extensions=taitham}', "");
Expect(0, 6829, '\P{Script_Extensions=taitham}', "");
Expect(1, 6829, '\P{^Script_Extensions=taitham}', "");
Expect(0, 6830, '\p{Script_Extensions=taitham}', "");
Expect(1, 6830, '\p{^Script_Extensions=taitham}', "");
Expect(1, 6830, '\P{Script_Extensions=taitham}', "");
Expect(0, 6830, '\P{^Script_Extensions=taitham}', "");
Expect(1, 6829, '\p{Script_Extensions= 	Tai_Tham}', "");
Expect(0, 6829, '\p{^Script_Extensions= 	Tai_Tham}', "");
Expect(0, 6829, '\P{Script_Extensions= 	Tai_Tham}', "");
Expect(1, 6829, '\P{^Script_Extensions= 	Tai_Tham}', "");
Expect(0, 6830, '\p{Script_Extensions= 	Tai_Tham}', "");
Expect(1, 6830, '\p{^Script_Extensions= 	Tai_Tham}', "");
Expect(1, 6830, '\P{Script_Extensions= 	Tai_Tham}', "");
Expect(0, 6830, '\P{^Script_Extensions= 	Tai_Tham}', "");
Error('\p{Scx=_-LANA/a/}');
Error('\P{Scx=_-LANA/a/}');
Expect(1, 6829, '\p{Scx=lana}', "");
Expect(0, 6829, '\p{^Scx=lana}', "");
Expect(0, 6829, '\P{Scx=lana}', "");
Expect(1, 6829, '\P{^Scx=lana}', "");
Expect(0, 6830, '\p{Scx=lana}', "");
Expect(1, 6830, '\p{^Scx=lana}', "");
Expect(1, 6830, '\P{Scx=lana}', "");
Expect(0, 6830, '\P{^Scx=lana}', "");
Expect(1, 6829, '\p{Scx=		Lana}', "");
Expect(0, 6829, '\p{^Scx=		Lana}', "");
Expect(0, 6829, '\P{Scx=		Lana}', "");
Expect(1, 6829, '\P{^Scx=		Lana}', "");
Expect(0, 6830, '\p{Scx=		Lana}', "");
Expect(1, 6830, '\p{^Scx=		Lana}', "");
Expect(1, 6830, '\P{Scx=		Lana}', "");
Expect(0, 6830, '\P{^Scx=		Lana}', "");
Error('\p{Is_Script_Extensions=_/a/Tai_THAM}');
Error('\P{Is_Script_Extensions=_/a/Tai_THAM}');
Expect(1, 6829, '\p{Is_Script_Extensions=taitham}', "");
Expect(0, 6829, '\p{^Is_Script_Extensions=taitham}', "");
Expect(0, 6829, '\P{Is_Script_Extensions=taitham}', "");
Expect(1, 6829, '\P{^Is_Script_Extensions=taitham}', "");
Expect(0, 6830, '\p{Is_Script_Extensions=taitham}', "");
Expect(1, 6830, '\p{^Is_Script_Extensions=taitham}', "");
Expect(1, 6830, '\P{Is_Script_Extensions=taitham}', "");
Expect(0, 6830, '\P{^Is_Script_Extensions=taitham}', "");
Expect(1, 6829, '\p{Is_Script_Extensions=-_TAI_tham}', "");
Expect(0, 6829, '\p{^Is_Script_Extensions=-_TAI_tham}', "");
Expect(0, 6829, '\P{Is_Script_Extensions=-_TAI_tham}', "");
Expect(1, 6829, '\P{^Is_Script_Extensions=-_TAI_tham}', "");
Expect(0, 6830, '\p{Is_Script_Extensions=-_TAI_tham}', "");
Expect(1, 6830, '\p{^Is_Script_Extensions=-_TAI_tham}', "");
Expect(1, 6830, '\P{Is_Script_Extensions=-_TAI_tham}', "");
Expect(0, 6830, '\P{^Is_Script_Extensions=-_TAI_tham}', "");
Error('\p{Is_Scx=_:=lana}');
Error('\P{Is_Scx=_:=lana}');
Expect(1, 6829, '\p{Is_Scx=lana}', "");
Expect(0, 6829, '\p{^Is_Scx=lana}', "");
Expect(0, 6829, '\P{Is_Scx=lana}', "");
Expect(1, 6829, '\P{^Is_Scx=lana}', "");
Expect(0, 6830, '\p{Is_Scx=lana}', "");
Expect(1, 6830, '\p{^Is_Scx=lana}', "");
Expect(1, 6830, '\P{Is_Scx=lana}', "");
Expect(0, 6830, '\P{^Is_Scx=lana}', "");
Expect(1, 6829, '\p{Is_Scx=	-Lana}', "");
Expect(0, 6829, '\p{^Is_Scx=	-Lana}', "");
Expect(0, 6829, '\P{Is_Scx=	-Lana}', "");
Expect(1, 6829, '\P{^Is_Scx=	-Lana}', "");
Expect(0, 6830, '\p{Is_Scx=	-Lana}', "");
Expect(1, 6830, '\p{^Is_Scx=	-Lana}', "");
Expect(1, 6830, '\P{Is_Scx=	-Lana}', "");
Expect(0, 6830, '\P{^Is_Scx=	-Lana}', "");
Error('\p{Script_Extensions=-/a/Lao}');
Error('\P{Script_Extensions=-/a/Lao}');
Expect(1, 3807, '\p{Script_Extensions=lao}', "");
Expect(0, 3807, '\p{^Script_Extensions=lao}', "");
Expect(0, 3807, '\P{Script_Extensions=lao}', "");
Expect(1, 3807, '\P{^Script_Extensions=lao}', "");
Expect(0, 3808, '\p{Script_Extensions=lao}', "");
Expect(1, 3808, '\p{^Script_Extensions=lao}', "");
Expect(1, 3808, '\P{Script_Extensions=lao}', "");
Expect(0, 3808, '\P{^Script_Extensions=lao}', "");
Expect(1, 3807, '\p{Script_Extensions=-LAO}', "");
Expect(0, 3807, '\p{^Script_Extensions=-LAO}', "");
Expect(0, 3807, '\P{Script_Extensions=-LAO}', "");
Expect(1, 3807, '\P{^Script_Extensions=-LAO}', "");
Expect(0, 3808, '\p{Script_Extensions=-LAO}', "");
Expect(1, 3808, '\p{^Script_Extensions=-LAO}', "");
Expect(1, 3808, '\P{Script_Extensions=-LAO}', "");
Expect(0, 3808, '\P{^Script_Extensions=-LAO}', "");
Error('\p{Scx=_:=Laoo}');
Error('\P{Scx=_:=Laoo}');
Expect(1, 3807, '\p{Scx=laoo}', "");
Expect(0, 3807, '\p{^Scx=laoo}', "");
Expect(0, 3807, '\P{Scx=laoo}', "");
Expect(1, 3807, '\P{^Scx=laoo}', "");
Expect(0, 3808, '\p{Scx=laoo}', "");
Expect(1, 3808, '\p{^Scx=laoo}', "");
Expect(1, 3808, '\P{Scx=laoo}', "");
Expect(0, 3808, '\P{^Scx=laoo}', "");
Expect(1, 3807, '\p{Scx= 	laoo}', "");
Expect(0, 3807, '\p{^Scx= 	laoo}', "");
Expect(0, 3807, '\P{Scx= 	laoo}', "");
Expect(1, 3807, '\P{^Scx= 	laoo}', "");
Expect(0, 3808, '\p{Scx= 	laoo}', "");
Expect(1, 3808, '\p{^Scx= 	laoo}', "");
Expect(1, 3808, '\P{Scx= 	laoo}', "");
Expect(0, 3808, '\P{^Scx= 	laoo}', "");
Error('\p{Is_Script_Extensions=	Lao:=}');
Error('\P{Is_Script_Extensions=	Lao:=}');
Expect(1, 3807, '\p{Is_Script_Extensions: lao}', "");
Expect(0, 3807, '\p{^Is_Script_Extensions: lao}', "");
Expect(0, 3807, '\P{Is_Script_Extensions: lao}', "");
Expect(1, 3807, '\P{^Is_Script_Extensions: lao}', "");
Expect(0, 3808, '\p{Is_Script_Extensions: lao}', "");
Expect(1, 3808, '\p{^Is_Script_Extensions: lao}', "");
Expect(1, 3808, '\P{Is_Script_Extensions: lao}', "");
Expect(0, 3808, '\P{^Is_Script_Extensions: lao}', "");
Expect(1, 3807, '\p{Is_Script_Extensions= -Lao}', "");
Expect(0, 3807, '\p{^Is_Script_Extensions= -Lao}', "");
Expect(0, 3807, '\P{Is_Script_Extensions= -Lao}', "");
Expect(1, 3807, '\P{^Is_Script_Extensions= -Lao}', "");
Expect(0, 3808, '\p{Is_Script_Extensions= -Lao}', "");
Expect(1, 3808, '\p{^Is_Script_Extensions= -Lao}', "");
Expect(1, 3808, '\P{Is_Script_Extensions= -Lao}', "");
Expect(0, 3808, '\P{^Is_Script_Extensions= -Lao}', "");
Error('\p{Is_Scx=:=--LAOO}');
Error('\P{Is_Scx=:=--LAOO}');
Expect(1, 3807, '\p{Is_Scx=laoo}', "");
Expect(0, 3807, '\p{^Is_Scx=laoo}', "");
Expect(0, 3807, '\P{Is_Scx=laoo}', "");
Expect(1, 3807, '\P{^Is_Scx=laoo}', "");
Expect(0, 3808, '\p{Is_Scx=laoo}', "");
Expect(1, 3808, '\p{^Is_Scx=laoo}', "");
Expect(1, 3808, '\P{Is_Scx=laoo}', "");
Expect(0, 3808, '\P{^Is_Scx=laoo}', "");
Expect(1, 3807, '\p{Is_Scx=_ laoo}', "");
Expect(0, 3807, '\p{^Is_Scx=_ laoo}', "");
Expect(0, 3807, '\P{Is_Scx=_ laoo}', "");
Expect(1, 3807, '\P{^Is_Scx=_ laoo}', "");
Expect(0, 3808, '\p{Is_Scx=_ laoo}', "");
Expect(1, 3808, '\p{^Is_Scx=_ laoo}', "");
Expect(1, 3808, '\P{Is_Scx=_ laoo}', "");
Expect(0, 3808, '\P{^Is_Scx=_ laoo}', "");
Error('\p{Script_Extensions: /a/- latin}');
Error('\P{Script_Extensions: /a/- latin}');
Expect(1, 65370, '\p{Script_Extensions=latin}', "");
Expect(0, 65370, '\p{^Script_Extensions=latin}', "");
Expect(0, 65370, '\P{Script_Extensions=latin}', "");
Expect(1, 65370, '\P{^Script_Extensions=latin}', "");
Expect(0, 65371, '\p{Script_Extensions=latin}', "");
Expect(1, 65371, '\p{^Script_Extensions=latin}', "");
Expect(1, 65371, '\P{Script_Extensions=latin}', "");
Expect(0, 65371, '\P{^Script_Extensions=latin}', "");
Expect(1, 65370, '\p{Script_Extensions=_ LATIN}', "");
Expect(0, 65370, '\p{^Script_Extensions=_ LATIN}', "");
Expect(0, 65370, '\P{Script_Extensions=_ LATIN}', "");
Expect(1, 65370, '\P{^Script_Extensions=_ LATIN}', "");
Expect(0, 65371, '\p{Script_Extensions=_ LATIN}', "");
Expect(1, 65371, '\p{^Script_Extensions=_ LATIN}', "");
Expect(1, 65371, '\P{Script_Extensions=_ LATIN}', "");
Expect(0, 65371, '\P{^Script_Extensions=_ LATIN}', "");
Error('\p{Scx=	:=LATN}');
Error('\P{Scx=	:=LATN}');
Expect(1, 65370, '\p{Scx=latn}', "");
Expect(0, 65370, '\p{^Scx=latn}', "");
Expect(0, 65370, '\P{Scx=latn}', "");
Expect(1, 65370, '\P{^Scx=latn}', "");
Expect(0, 65371, '\p{Scx=latn}', "");
Expect(1, 65371, '\p{^Scx=latn}', "");
Expect(1, 65371, '\P{Scx=latn}', "");
Expect(0, 65371, '\P{^Scx=latn}', "");
Expect(1, 65370, '\p{Scx=	-LATN}', "");
Expect(0, 65370, '\p{^Scx=	-LATN}', "");
Expect(0, 65370, '\P{Scx=	-LATN}', "");
Expect(1, 65370, '\P{^Scx=	-LATN}', "");
Expect(0, 65371, '\p{Scx=	-LATN}', "");
Expect(1, 65371, '\p{^Scx=	-LATN}', "");
Expect(1, 65371, '\P{Scx=	-LATN}', "");
Expect(0, 65371, '\P{^Scx=	-LATN}', "");
Error('\p{Is_Script_Extensions::= 	Latin}');
Error('\P{Is_Script_Extensions::= 	Latin}');
Expect(1, 65370, '\p{Is_Script_Extensions=latin}', "");
Expect(0, 65370, '\p{^Is_Script_Extensions=latin}', "");
Expect(0, 65370, '\P{Is_Script_Extensions=latin}', "");
Expect(1, 65370, '\P{^Is_Script_Extensions=latin}', "");
Expect(0, 65371, '\p{Is_Script_Extensions=latin}', "");
Expect(1, 65371, '\p{^Is_Script_Extensions=latin}', "");
Expect(1, 65371, '\P{Is_Script_Extensions=latin}', "");
Expect(0, 65371, '\P{^Is_Script_Extensions=latin}', "");
Expect(1, 65370, '\p{Is_Script_Extensions=		Latin}', "");
Expect(0, 65370, '\p{^Is_Script_Extensions=		Latin}', "");
Expect(0, 65370, '\P{Is_Script_Extensions=		Latin}', "");
Expect(1, 65370, '\P{^Is_Script_Extensions=		Latin}', "");
Expect(0, 65371, '\p{Is_Script_Extensions=		Latin}', "");
Expect(1, 65371, '\p{^Is_Script_Extensions=		Latin}', "");
Expect(1, 65371, '\P{Is_Script_Extensions=		Latin}', "");
Expect(0, 65371, '\P{^Is_Script_Extensions=		Latin}', "");
Error('\p{Is_Scx:/a/	_Latn}');
Error('\P{Is_Scx:/a/	_Latn}');
Expect(1, 65370, '\p{Is_Scx:latn}', "");
Expect(0, 65370, '\p{^Is_Scx:latn}', "");
Expect(0, 65370, '\P{Is_Scx:latn}', "");
Expect(1, 65370, '\P{^Is_Scx:latn}', "");
Expect(0, 65371, '\p{Is_Scx:latn}', "");
Expect(1, 65371, '\p{^Is_Scx:latn}', "");
Expect(1, 65371, '\P{Is_Scx:latn}', "");
Expect(0, 65371, '\P{^Is_Scx:latn}', "");
Expect(1, 65370, '\p{Is_Scx=		Latn}', "");
Expect(0, 65370, '\p{^Is_Scx=		Latn}', "");
Expect(0, 65370, '\P{Is_Scx=		Latn}', "");
Expect(1, 65370, '\P{^Is_Scx=		Latn}', "");
Expect(0, 65371, '\p{Is_Scx=		Latn}', "");
Expect(1, 65371, '\p{^Is_Scx=		Latn}', "");
Expect(1, 65371, '\P{Is_Scx=		Latn}', "");
Expect(0, 65371, '\P{^Is_Scx=		Latn}', "");
Error('\p{Script_Extensions=_:=LEPCHA}');
Error('\P{Script_Extensions=_:=LEPCHA}');
Expect(1, 7247, '\p{Script_Extensions:	lepcha}', "");
Expect(0, 7247, '\p{^Script_Extensions:	lepcha}', "");
Expect(0, 7247, '\P{Script_Extensions:	lepcha}', "");
Expect(1, 7247, '\P{^Script_Extensions:	lepcha}', "");
Expect(0, 7248, '\p{Script_Extensions:	lepcha}', "");
Expect(1, 7248, '\p{^Script_Extensions:	lepcha}', "");
Expect(1, 7248, '\P{Script_Extensions:	lepcha}', "");
Expect(0, 7248, '\P{^Script_Extensions:	lepcha}', "");
Expect(1, 7247, '\p{Script_Extensions=_Lepcha}', "");
Expect(0, 7247, '\p{^Script_Extensions=_Lepcha}', "");
Expect(0, 7247, '\P{Script_Extensions=_Lepcha}', "");
Expect(1, 7247, '\P{^Script_Extensions=_Lepcha}', "");
Expect(0, 7248, '\p{Script_Extensions=_Lepcha}', "");
Expect(1, 7248, '\p{^Script_Extensions=_Lepcha}', "");
Expect(1, 7248, '\P{Script_Extensions=_Lepcha}', "");
Expect(0, 7248, '\P{^Script_Extensions=_Lepcha}', "");
Error('\p{Scx=:=_LEPC}');
Error('\P{Scx=:=_LEPC}');
Expect(1, 7247, '\p{Scx=lepc}', "");
Expect(0, 7247, '\p{^Scx=lepc}', "");
Expect(0, 7247, '\P{Scx=lepc}', "");
Expect(1, 7247, '\P{^Scx=lepc}', "");
Expect(0, 7248, '\p{Scx=lepc}', "");
Expect(1, 7248, '\p{^Scx=lepc}', "");
Expect(1, 7248, '\P{Scx=lepc}', "");
Expect(0, 7248, '\P{^Scx=lepc}', "");
Expect(1, 7247, '\p{Scx=- lepc}', "");
Expect(0, 7247, '\p{^Scx=- lepc}', "");
Expect(0, 7247, '\P{Scx=- lepc}', "");
Expect(1, 7247, '\P{^Scx=- lepc}', "");
Expect(0, 7248, '\p{Scx=- lepc}', "");
Expect(1, 7248, '\p{^Scx=- lepc}', "");
Expect(1, 7248, '\P{Scx=- lepc}', "");
Expect(0, 7248, '\P{^Scx=- lepc}', "");
Error('\p{Is_Script_Extensions=:=_Lepcha}');
Error('\P{Is_Script_Extensions=:=_Lepcha}');
Expect(1, 7247, '\p{Is_Script_Extensions=lepcha}', "");
Expect(0, 7247, '\p{^Is_Script_Extensions=lepcha}', "");
Expect(0, 7247, '\P{Is_Script_Extensions=lepcha}', "");
Expect(1, 7247, '\P{^Is_Script_Extensions=lepcha}', "");
Expect(0, 7248, '\p{Is_Script_Extensions=lepcha}', "");
Expect(1, 7248, '\p{^Is_Script_Extensions=lepcha}', "");
Expect(1, 7248, '\P{Is_Script_Extensions=lepcha}', "");
Expect(0, 7248, '\P{^Is_Script_Extensions=lepcha}', "");
Expect(1, 7247, '\p{Is_Script_Extensions= 	LEPCHA}', "");
Expect(0, 7247, '\p{^Is_Script_Extensions= 	LEPCHA}', "");
Expect(0, 7247, '\P{Is_Script_Extensions= 	LEPCHA}', "");
Expect(1, 7247, '\P{^Is_Script_Extensions= 	LEPCHA}', "");
Expect(0, 7248, '\p{Is_Script_Extensions= 	LEPCHA}', "");
Expect(1, 7248, '\p{^Is_Script_Extensions= 	LEPCHA}', "");
Expect(1, 7248, '\P{Is_Script_Extensions= 	LEPCHA}', "");
Expect(0, 7248, '\P{^Is_Script_Extensions= 	LEPCHA}', "");
Error('\p{Is_Scx=-:=Lepc}');
Error('\P{Is_Scx=-:=Lepc}');
Expect(1, 7247, '\p{Is_Scx=lepc}', "");
Expect(0, 7247, '\p{^Is_Scx=lepc}', "");
Expect(0, 7247, '\P{Is_Scx=lepc}', "");
Expect(1, 7247, '\P{^Is_Scx=lepc}', "");
Expect(0, 7248, '\p{Is_Scx=lepc}', "");
Expect(1, 7248, '\p{^Is_Scx=lepc}', "");
Expect(1, 7248, '\P{Is_Scx=lepc}', "");
Expect(0, 7248, '\P{^Is_Scx=lepc}', "");
Expect(1, 7247, '\p{Is_Scx=-Lepc}', "");
Expect(0, 7247, '\p{^Is_Scx=-Lepc}', "");
Expect(0, 7247, '\P{Is_Scx=-Lepc}', "");
Expect(1, 7247, '\P{^Is_Scx=-Lepc}', "");
Expect(0, 7248, '\p{Is_Scx=-Lepc}', "");
Expect(1, 7248, '\p{^Is_Scx=-Lepc}', "");
Expect(1, 7248, '\P{Is_Scx=-Lepc}', "");
Expect(0, 7248, '\P{^Is_Scx=-Lepc}', "");
Error('\p{Script_Extensions=-/a/Limbu}');
Error('\P{Script_Extensions=-/a/Limbu}');
Expect(1, 6479, '\p{Script_Extensions=limbu}', "");
Expect(0, 6479, '\p{^Script_Extensions=limbu}', "");
Expect(0, 6479, '\P{Script_Extensions=limbu}', "");
Expect(1, 6479, '\P{^Script_Extensions=limbu}', "");
Expect(0, 6480, '\p{Script_Extensions=limbu}', "");
Expect(1, 6480, '\p{^Script_Extensions=limbu}', "");
Expect(1, 6480, '\P{Script_Extensions=limbu}', "");
Expect(0, 6480, '\P{^Script_Extensions=limbu}', "");
Expect(1, 6479, '\p{Script_Extensions=-_Limbu}', "");
Expect(0, 6479, '\p{^Script_Extensions=-_Limbu}', "");
Expect(0, 6479, '\P{Script_Extensions=-_Limbu}', "");
Expect(1, 6479, '\P{^Script_Extensions=-_Limbu}', "");
Expect(0, 6480, '\p{Script_Extensions=-_Limbu}', "");
Expect(1, 6480, '\p{^Script_Extensions=-_Limbu}', "");
Expect(1, 6480, '\P{Script_Extensions=-_Limbu}', "");
Expect(0, 6480, '\P{^Script_Extensions=-_Limbu}', "");
Error('\p{Scx=/a/	LIMB}');
Error('\P{Scx=/a/	LIMB}');
Expect(1, 6479, '\p{Scx=limb}', "");
Expect(0, 6479, '\p{^Scx=limb}', "");
Expect(0, 6479, '\P{Scx=limb}', "");
Expect(1, 6479, '\P{^Scx=limb}', "");
Expect(0, 6480, '\p{Scx=limb}', "");
Expect(1, 6480, '\p{^Scx=limb}', "");
Expect(1, 6480, '\P{Scx=limb}', "");
Expect(0, 6480, '\P{^Scx=limb}', "");
Expect(1, 6479, '\p{Scx=--Limb}', "");
Expect(0, 6479, '\p{^Scx=--Limb}', "");
Expect(0, 6479, '\P{Scx=--Limb}', "");
Expect(1, 6479, '\P{^Scx=--Limb}', "");
Expect(0, 6480, '\p{Scx=--Limb}', "");
Expect(1, 6480, '\p{^Scx=--Limb}', "");
Expect(1, 6480, '\P{Scx=--Limb}', "");
Expect(0, 6480, '\P{^Scx=--Limb}', "");
Error('\p{Is_Script_Extensions=/a/ Limbu}');
Error('\P{Is_Script_Extensions=/a/ Limbu}');
Expect(1, 6479, '\p{Is_Script_Extensions=limbu}', "");
Expect(0, 6479, '\p{^Is_Script_Extensions=limbu}', "");
Expect(0, 6479, '\P{Is_Script_Extensions=limbu}', "");
Expect(1, 6479, '\P{^Is_Script_Extensions=limbu}', "");
Expect(0, 6480, '\p{Is_Script_Extensions=limbu}', "");
Expect(1, 6480, '\p{^Is_Script_Extensions=limbu}', "");
Expect(1, 6480, '\P{Is_Script_Extensions=limbu}', "");
Expect(0, 6480, '\P{^Is_Script_Extensions=limbu}', "");
Expect(1, 6479, '\p{Is_Script_Extensions= limbu}', "");
Expect(0, 6479, '\p{^Is_Script_Extensions= limbu}', "");
Expect(0, 6479, '\P{Is_Script_Extensions= limbu}', "");
Expect(1, 6479, '\P{^Is_Script_Extensions= limbu}', "");
Expect(0, 6480, '\p{Is_Script_Extensions= limbu}', "");
Expect(1, 6480, '\p{^Is_Script_Extensions= limbu}', "");
Expect(1, 6480, '\P{Is_Script_Extensions= limbu}', "");
Expect(0, 6480, '\P{^Is_Script_Extensions= limbu}', "");
Error('\p{Is_Scx=:=	_Limb}');
Error('\P{Is_Scx=:=	_Limb}');
Expect(1, 6479, '\p{Is_Scx=limb}', "");
Expect(0, 6479, '\p{^Is_Scx=limb}', "");
Expect(0, 6479, '\P{Is_Scx=limb}', "");
Expect(1, 6479, '\P{^Is_Scx=limb}', "");
Expect(0, 6480, '\p{Is_Scx=limb}', "");
Expect(1, 6480, '\p{^Is_Scx=limb}', "");
Expect(1, 6480, '\P{Is_Scx=limb}', "");
Expect(0, 6480, '\P{^Is_Scx=limb}', "");
Expect(1, 6479, '\p{Is_Scx=		limb}', "");
Expect(0, 6479, '\p{^Is_Scx=		limb}', "");
Expect(0, 6479, '\P{Is_Scx=		limb}', "");
Expect(1, 6479, '\P{^Is_Scx=		limb}', "");
Expect(0, 6480, '\p{Is_Scx=		limb}', "");
Expect(1, 6480, '\p{^Is_Scx=		limb}', "");
Expect(1, 6480, '\P{Is_Scx=		limb}', "");
Expect(0, 6480, '\P{^Is_Scx=		limb}', "");
Error('\p{Script_Extensions=/a/linear_b}');
Error('\P{Script_Extensions=/a/linear_b}');
Expect(1, 65855, '\p{Script_Extensions=linearb}', "");
Expect(0, 65855, '\p{^Script_Extensions=linearb}', "");
Expect(0, 65855, '\P{Script_Extensions=linearb}', "");
Expect(1, 65855, '\P{^Script_Extensions=linearb}', "");
Expect(0, 65856, '\p{Script_Extensions=linearb}', "");
Expect(1, 65856, '\p{^Script_Extensions=linearb}', "");
Expect(1, 65856, '\P{Script_Extensions=linearb}', "");
Expect(0, 65856, '\P{^Script_Extensions=linearb}', "");
Expect(1, 65855, '\p{Script_Extensions= _linear_B}', "");
Expect(0, 65855, '\p{^Script_Extensions= _linear_B}', "");
Expect(0, 65855, '\P{Script_Extensions= _linear_B}', "");
Expect(1, 65855, '\P{^Script_Extensions= _linear_B}', "");
Expect(0, 65856, '\p{Script_Extensions= _linear_B}', "");
Expect(1, 65856, '\p{^Script_Extensions= _linear_B}', "");
Expect(1, 65856, '\P{Script_Extensions= _linear_B}', "");
Expect(0, 65856, '\P{^Script_Extensions= _linear_B}', "");
Error('\p{Scx=:=		linb}');
Error('\P{Scx=:=		linb}');
Expect(1, 65855, '\p{Scx=linb}', "");
Expect(0, 65855, '\p{^Scx=linb}', "");
Expect(0, 65855, '\P{Scx=linb}', "");
Expect(1, 65855, '\P{^Scx=linb}', "");
Expect(0, 65856, '\p{Scx=linb}', "");
Expect(1, 65856, '\p{^Scx=linb}', "");
Expect(1, 65856, '\P{Scx=linb}', "");
Expect(0, 65856, '\P{^Scx=linb}', "");
Expect(1, 65855, '\p{Scx=	_LINB}', "");
Expect(0, 65855, '\p{^Scx=	_LINB}', "");
Expect(0, 65855, '\P{Scx=	_LINB}', "");
Expect(1, 65855, '\P{^Scx=	_LINB}', "");
Expect(0, 65856, '\p{Scx=	_LINB}', "");
Expect(1, 65856, '\p{^Scx=	_LINB}', "");
Expect(1, 65856, '\P{Scx=	_LINB}', "");
Expect(0, 65856, '\P{^Scx=	_LINB}', "");
Error('\p{Is_Script_Extensions=		LINEAR_B:=}');
Error('\P{Is_Script_Extensions=		LINEAR_B:=}');
Expect(1, 65855, '\p{Is_Script_Extensions:linearb}', "");
Expect(0, 65855, '\p{^Is_Script_Extensions:linearb}', "");
Expect(0, 65855, '\P{Is_Script_Extensions:linearb}', "");
Expect(1, 65855, '\P{^Is_Script_Extensions:linearb}', "");
Expect(0, 65856, '\p{Is_Script_Extensions:linearb}', "");
Expect(1, 65856, '\p{^Is_Script_Extensions:linearb}', "");
Expect(1, 65856, '\P{Is_Script_Extensions:linearb}', "");
Expect(0, 65856, '\P{^Is_Script_Extensions:linearb}', "");
Expect(1, 65855, '\p{Is_Script_Extensions=  linear_B}', "");
Expect(0, 65855, '\p{^Is_Script_Extensions=  linear_B}', "");
Expect(0, 65855, '\P{Is_Script_Extensions=  linear_B}', "");
Expect(1, 65855, '\P{^Is_Script_Extensions=  linear_B}', "");
Expect(0, 65856, '\p{Is_Script_Extensions=  linear_B}', "");
Expect(1, 65856, '\p{^Is_Script_Extensions=  linear_B}', "");
Expect(1, 65856, '\P{Is_Script_Extensions=  linear_B}', "");
Expect(0, 65856, '\P{^Is_Script_Extensions=  linear_B}', "");
Error('\p{Is_Scx=_	Linb:=}');
Error('\P{Is_Scx=_	Linb:=}');
Expect(1, 65855, '\p{Is_Scx=linb}', "");
Expect(0, 65855, '\p{^Is_Scx=linb}', "");
Expect(0, 65855, '\P{Is_Scx=linb}', "");
Expect(1, 65855, '\P{^Is_Scx=linb}', "");
Expect(0, 65856, '\p{Is_Scx=linb}', "");
Expect(1, 65856, '\p{^Is_Scx=linb}', "");
Expect(1, 65856, '\P{Is_Scx=linb}', "");
Expect(0, 65856, '\P{^Is_Scx=linb}', "");
Expect(1, 65855, '\p{Is_Scx=-Linb}', "");
Expect(0, 65855, '\p{^Is_Scx=-Linb}', "");
Expect(0, 65855, '\P{Is_Scx=-Linb}', "");
Expect(1, 65855, '\P{^Is_Scx=-Linb}', "");
Expect(0, 65856, '\p{Is_Scx=-Linb}', "");
Expect(1, 65856, '\p{^Is_Scx=-Linb}', "");
Expect(1, 65856, '\P{Is_Scx=-Linb}', "");
Expect(0, 65856, '\P{^Is_Scx=-Linb}', "");
Error('\p{Script_Extensions:	_:=LISU}');
Error('\P{Script_Extensions:	_:=LISU}');
Expect(1, 42239, '\p{Script_Extensions=lisu}', "");
Expect(0, 42239, '\p{^Script_Extensions=lisu}', "");
Expect(0, 42239, '\P{Script_Extensions=lisu}', "");
Expect(1, 42239, '\P{^Script_Extensions=lisu}', "");
Expect(0, 42240, '\p{Script_Extensions=lisu}', "");
Expect(1, 42240, '\p{^Script_Extensions=lisu}', "");
Expect(1, 42240, '\P{Script_Extensions=lisu}', "");
Expect(0, 42240, '\P{^Script_Extensions=lisu}', "");
Expect(1, 42239, '\p{Script_Extensions: 	_Lisu}', "");
Expect(0, 42239, '\p{^Script_Extensions: 	_Lisu}', "");
Expect(0, 42239, '\P{Script_Extensions: 	_Lisu}', "");
Expect(1, 42239, '\P{^Script_Extensions: 	_Lisu}', "");
Expect(0, 42240, '\p{Script_Extensions: 	_Lisu}', "");
Expect(1, 42240, '\p{^Script_Extensions: 	_Lisu}', "");
Expect(1, 42240, '\P{Script_Extensions: 	_Lisu}', "");
Expect(0, 42240, '\P{^Script_Extensions: 	_Lisu}', "");
Error('\p{Scx:	/a/_ Lisu}');
Error('\P{Scx:	/a/_ Lisu}');
Expect(1, 42239, '\p{Scx=lisu}', "");
Expect(0, 42239, '\p{^Scx=lisu}', "");
Expect(0, 42239, '\P{Scx=lisu}', "");
Expect(1, 42239, '\P{^Scx=lisu}', "");
Expect(0, 42240, '\p{Scx=lisu}', "");
Expect(1, 42240, '\p{^Scx=lisu}', "");
Expect(1, 42240, '\P{Scx=lisu}', "");
Expect(0, 42240, '\P{^Scx=lisu}', "");
Expect(1, 42239, '\p{Scx: 	-Lisu}', "");
Expect(0, 42239, '\p{^Scx: 	-Lisu}', "");
Expect(0, 42239, '\P{Scx: 	-Lisu}', "");
Expect(1, 42239, '\P{^Scx: 	-Lisu}', "");
Expect(0, 42240, '\p{Scx: 	-Lisu}', "");
Expect(1, 42240, '\p{^Scx: 	-Lisu}', "");
Expect(1, 42240, '\P{Scx: 	-Lisu}', "");
Expect(0, 42240, '\P{^Scx: 	-Lisu}', "");
Error('\p{Is_Script_Extensions=:=- LISU}');
Error('\P{Is_Script_Extensions=:=- LISU}');
Expect(1, 42239, '\p{Is_Script_Extensions=lisu}', "");
Expect(0, 42239, '\p{^Is_Script_Extensions=lisu}', "");
Expect(0, 42239, '\P{Is_Script_Extensions=lisu}', "");
Expect(1, 42239, '\P{^Is_Script_Extensions=lisu}', "");
Expect(0, 42240, '\p{Is_Script_Extensions=lisu}', "");
Expect(1, 42240, '\p{^Is_Script_Extensions=lisu}', "");
Expect(1, 42240, '\P{Is_Script_Extensions=lisu}', "");
Expect(0, 42240, '\P{^Is_Script_Extensions=lisu}', "");
Expect(1, 42239, '\p{Is_Script_Extensions=_-lisu}', "");
Expect(0, 42239, '\p{^Is_Script_Extensions=_-lisu}', "");
Expect(0, 42239, '\P{Is_Script_Extensions=_-lisu}', "");
Expect(1, 42239, '\P{^Is_Script_Extensions=_-lisu}', "");
Expect(0, 42240, '\p{Is_Script_Extensions=_-lisu}', "");
Expect(1, 42240, '\p{^Is_Script_Extensions=_-lisu}', "");
Expect(1, 42240, '\P{Is_Script_Extensions=_-lisu}', "");
Expect(0, 42240, '\P{^Is_Script_Extensions=_-lisu}', "");
Error('\p{Is_Scx= :=Lisu}');
Error('\P{Is_Scx= :=Lisu}');
Expect(1, 42239, '\p{Is_Scx=lisu}', "");
Expect(0, 42239, '\p{^Is_Scx=lisu}', "");
Expect(0, 42239, '\P{Is_Scx=lisu}', "");
Expect(1, 42239, '\P{^Is_Scx=lisu}', "");
Expect(0, 42240, '\p{Is_Scx=lisu}', "");
Expect(1, 42240, '\p{^Is_Scx=lisu}', "");
Expect(1, 42240, '\P{Is_Scx=lisu}', "");
Expect(0, 42240, '\P{^Is_Scx=lisu}', "");
Expect(1, 42239, '\p{Is_Scx=  lisu}', "");
Expect(0, 42239, '\p{^Is_Scx=  lisu}', "");
Expect(0, 42239, '\P{Is_Scx=  lisu}', "");
Expect(1, 42239, '\P{^Is_Scx=  lisu}', "");
Expect(0, 42240, '\p{Is_Scx=  lisu}', "");
Expect(1, 42240, '\p{^Is_Scx=  lisu}', "");
Expect(1, 42240, '\P{Is_Scx=  lisu}', "");
Expect(0, 42240, '\P{^Is_Scx=  lisu}', "");
Error('\p{Script_Extensions=	/a/Lycian}');
Error('\P{Script_Extensions=	/a/Lycian}');
Expect(1, 66204, '\p{Script_Extensions=lycian}', "");
Expect(0, 66204, '\p{^Script_Extensions=lycian}', "");
Expect(0, 66204, '\P{Script_Extensions=lycian}', "");
Expect(1, 66204, '\P{^Script_Extensions=lycian}', "");
Expect(0, 66205, '\p{Script_Extensions=lycian}', "");
Expect(1, 66205, '\p{^Script_Extensions=lycian}', "");
Expect(1, 66205, '\P{Script_Extensions=lycian}', "");
Expect(0, 66205, '\P{^Script_Extensions=lycian}', "");
Expect(1, 66204, '\p{Script_Extensions=_Lycian}', "");
Expect(0, 66204, '\p{^Script_Extensions=_Lycian}', "");
Expect(0, 66204, '\P{Script_Extensions=_Lycian}', "");
Expect(1, 66204, '\P{^Script_Extensions=_Lycian}', "");
Expect(0, 66205, '\p{Script_Extensions=_Lycian}', "");
Expect(1, 66205, '\p{^Script_Extensions=_Lycian}', "");
Expect(1, 66205, '\P{Script_Extensions=_Lycian}', "");
Expect(0, 66205, '\P{^Script_Extensions=_Lycian}', "");
Error('\p{Scx=	/a/lyci}');
Error('\P{Scx=	/a/lyci}');
Expect(1, 66204, '\p{Scx:	lyci}', "");
Expect(0, 66204, '\p{^Scx:	lyci}', "");
Expect(0, 66204, '\P{Scx:	lyci}', "");
Expect(1, 66204, '\P{^Scx:	lyci}', "");
Expect(0, 66205, '\p{Scx:	lyci}', "");
Expect(1, 66205, '\p{^Scx:	lyci}', "");
Expect(1, 66205, '\P{Scx:	lyci}', "");
Expect(0, 66205, '\P{^Scx:	lyci}', "");
Expect(1, 66204, '\p{Scx=LYCI}', "");
Expect(0, 66204, '\p{^Scx=LYCI}', "");
Expect(0, 66204, '\P{Scx=LYCI}', "");
Expect(1, 66204, '\P{^Scx=LYCI}', "");
Expect(0, 66205, '\p{Scx=LYCI}', "");
Expect(1, 66205, '\p{^Scx=LYCI}', "");
Expect(1, 66205, '\P{Scx=LYCI}', "");
Expect(0, 66205, '\P{^Scx=LYCI}', "");
Error('\p{Is_Script_Extensions=/a/Lycian}');
Error('\P{Is_Script_Extensions=/a/Lycian}');
Expect(1, 66204, '\p{Is_Script_Extensions=lycian}', "");
Expect(0, 66204, '\p{^Is_Script_Extensions=lycian}', "");
Expect(0, 66204, '\P{Is_Script_Extensions=lycian}', "");
Expect(1, 66204, '\P{^Is_Script_Extensions=lycian}', "");
Expect(0, 66205, '\p{Is_Script_Extensions=lycian}', "");
Expect(1, 66205, '\p{^Is_Script_Extensions=lycian}', "");
Expect(1, 66205, '\P{Is_Script_Extensions=lycian}', "");
Expect(0, 66205, '\P{^Is_Script_Extensions=lycian}', "");
Expect(1, 66204, '\p{Is_Script_Extensions= 	Lycian}', "");
Expect(0, 66204, '\p{^Is_Script_Extensions= 	Lycian}', "");
Expect(0, 66204, '\P{Is_Script_Extensions= 	Lycian}', "");
Expect(1, 66204, '\P{^Is_Script_Extensions= 	Lycian}', "");
Expect(0, 66205, '\p{Is_Script_Extensions= 	Lycian}', "");
Expect(1, 66205, '\p{^Is_Script_Extensions= 	Lycian}', "");
Expect(1, 66205, '\P{Is_Script_Extensions= 	Lycian}', "");
Expect(0, 66205, '\P{^Is_Script_Extensions= 	Lycian}', "");
Error('\p{Is_Scx:    	Lyci:=}');
Error('\P{Is_Scx:    	Lyci:=}');
Expect(1, 66204, '\p{Is_Scx=lyci}', "");
Expect(0, 66204, '\p{^Is_Scx=lyci}', "");
Expect(0, 66204, '\P{Is_Scx=lyci}', "");
Expect(1, 66204, '\P{^Is_Scx=lyci}', "");
Expect(0, 66205, '\p{Is_Scx=lyci}', "");
Expect(1, 66205, '\p{^Is_Scx=lyci}', "");
Expect(1, 66205, '\P{Is_Scx=lyci}', "");
Expect(0, 66205, '\P{^Is_Scx=lyci}', "");
Expect(1, 66204, '\p{Is_Scx=_	lyci}', "");
Expect(0, 66204, '\p{^Is_Scx=_	lyci}', "");
Expect(0, 66204, '\P{Is_Scx=_	lyci}', "");
Expect(1, 66204, '\P{^Is_Scx=_	lyci}', "");
Expect(0, 66205, '\p{Is_Scx=_	lyci}', "");
Expect(1, 66205, '\p{^Is_Scx=_	lyci}', "");
Expect(1, 66205, '\P{Is_Scx=_	lyci}', "");
Expect(0, 66205, '\P{^Is_Scx=_	lyci}', "");
Error('\p{Script_Extensions:	:= 	LYDIAN}');
Error('\P{Script_Extensions:	:= 	LYDIAN}');
Expect(1, 67903, '\p{Script_Extensions=lydian}', "");
Expect(0, 67903, '\p{^Script_Extensions=lydian}', "");
Expect(0, 67903, '\P{Script_Extensions=lydian}', "");
Expect(1, 67903, '\P{^Script_Extensions=lydian}', "");
Expect(0, 67904, '\p{Script_Extensions=lydian}', "");
Expect(1, 67904, '\p{^Script_Extensions=lydian}', "");
Expect(1, 67904, '\P{Script_Extensions=lydian}', "");
Expect(0, 67904, '\P{^Script_Extensions=lydian}', "");
Expect(1, 67903, '\p{Script_Extensions: 	LYDIAN}', "");
Expect(0, 67903, '\p{^Script_Extensions: 	LYDIAN}', "");
Expect(0, 67903, '\P{Script_Extensions: 	LYDIAN}', "");
Expect(1, 67903, '\P{^Script_Extensions: 	LYDIAN}', "");
Expect(0, 67904, '\p{Script_Extensions: 	LYDIAN}', "");
Expect(1, 67904, '\p{^Script_Extensions: 	LYDIAN}', "");
Expect(1, 67904, '\P{Script_Extensions: 	LYDIAN}', "");
Expect(0, 67904, '\P{^Script_Extensions: 	LYDIAN}', "");
Error('\p{Scx=	_LYDI/a/}');
Error('\P{Scx=	_LYDI/a/}');
Expect(1, 67903, '\p{Scx=lydi}', "");
Expect(0, 67903, '\p{^Scx=lydi}', "");
Expect(0, 67903, '\P{Scx=lydi}', "");
Expect(1, 67903, '\P{^Scx=lydi}', "");
Expect(0, 67904, '\p{Scx=lydi}', "");
Expect(1, 67904, '\p{^Scx=lydi}', "");
Expect(1, 67904, '\P{Scx=lydi}', "");
Expect(0, 67904, '\P{^Scx=lydi}', "");
Expect(1, 67903, '\p{Scx=		Lydi}', "");
Expect(0, 67903, '\p{^Scx=		Lydi}', "");
Expect(0, 67903, '\P{Scx=		Lydi}', "");
Expect(1, 67903, '\P{^Scx=		Lydi}', "");
Expect(0, 67904, '\p{Scx=		Lydi}', "");
Expect(1, 67904, '\p{^Scx=		Lydi}', "");
Expect(1, 67904, '\P{Scx=		Lydi}', "");
Expect(0, 67904, '\P{^Scx=		Lydi}', "");
Error('\p{Is_Script_Extensions: :=--LYDIAN}');
Error('\P{Is_Script_Extensions: :=--LYDIAN}');
Expect(1, 67903, '\p{Is_Script_Extensions=lydian}', "");
Expect(0, 67903, '\p{^Is_Script_Extensions=lydian}', "");
Expect(0, 67903, '\P{Is_Script_Extensions=lydian}', "");
Expect(1, 67903, '\P{^Is_Script_Extensions=lydian}', "");
Expect(0, 67904, '\p{Is_Script_Extensions=lydian}', "");
Expect(1, 67904, '\p{^Is_Script_Extensions=lydian}', "");
Expect(1, 67904, '\P{Is_Script_Extensions=lydian}', "");
Expect(0, 67904, '\P{^Is_Script_Extensions=lydian}', "");
Expect(1, 67903, '\p{Is_Script_Extensions= 	lydian}', "");
Expect(0, 67903, '\p{^Is_Script_Extensions= 	lydian}', "");
Expect(0, 67903, '\P{Is_Script_Extensions= 	lydian}', "");
Expect(1, 67903, '\P{^Is_Script_Extensions= 	lydian}', "");
Expect(0, 67904, '\p{Is_Script_Extensions= 	lydian}', "");
Expect(1, 67904, '\p{^Is_Script_Extensions= 	lydian}', "");
Expect(1, 67904, '\P{Is_Script_Extensions= 	lydian}', "");
Expect(0, 67904, '\P{^Is_Script_Extensions= 	lydian}', "");
Error('\p{Is_Scx=:=	_Lydi}');
Error('\P{Is_Scx=:=	_Lydi}');
Expect(1, 67903, '\p{Is_Scx=lydi}', "");
Expect(0, 67903, '\p{^Is_Scx=lydi}', "");
Expect(0, 67903, '\P{Is_Scx=lydi}', "");
Expect(1, 67903, '\P{^Is_Scx=lydi}', "");
Expect(0, 67904, '\p{Is_Scx=lydi}', "");
Expect(1, 67904, '\p{^Is_Scx=lydi}', "");
Expect(1, 67904, '\P{Is_Scx=lydi}', "");
Expect(0, 67904, '\P{^Is_Scx=lydi}', "");
Expect(1, 67903, '\p{Is_Scx=_Lydi}', "");
Expect(0, 67903, '\p{^Is_Scx=_Lydi}', "");
Expect(0, 67903, '\P{Is_Scx=_Lydi}', "");
Expect(1, 67903, '\P{^Is_Scx=_Lydi}', "");
Expect(0, 67904, '\p{Is_Scx=_Lydi}', "");
Expect(1, 67904, '\p{^Is_Scx=_Lydi}', "");
Expect(1, 67904, '\P{Is_Scx=_Lydi}', "");
Expect(0, 67904, '\P{^Is_Scx=_Lydi}', "");
Error('\p{Script_Extensions=:=- mandaic}');
Error('\P{Script_Extensions=:=- mandaic}');
Expect(1, 2142, '\p{Script_Extensions=mandaic}', "");
Expect(0, 2142, '\p{^Script_Extensions=mandaic}', "");
Expect(0, 2142, '\P{Script_Extensions=mandaic}', "");
Expect(1, 2142, '\P{^Script_Extensions=mandaic}', "");
Expect(0, 2143, '\p{Script_Extensions=mandaic}', "");
Expect(1, 2143, '\p{^Script_Extensions=mandaic}', "");
Expect(1, 2143, '\P{Script_Extensions=mandaic}', "");
Expect(0, 2143, '\P{^Script_Extensions=mandaic}', "");
Expect(1, 2142, '\p{Script_Extensions=__MANDAIC}', "");
Expect(0, 2142, '\p{^Script_Extensions=__MANDAIC}', "");
Expect(0, 2142, '\P{Script_Extensions=__MANDAIC}', "");
Expect(1, 2142, '\P{^Script_Extensions=__MANDAIC}', "");
Expect(0, 2143, '\p{Script_Extensions=__MANDAIC}', "");
Expect(1, 2143, '\p{^Script_Extensions=__MANDAIC}', "");
Expect(1, 2143, '\P{Script_Extensions=__MANDAIC}', "");
Expect(0, 2143, '\P{^Script_Extensions=__MANDAIC}', "");
Error('\p{Scx=/a/ Mand}');
Error('\P{Scx=/a/ Mand}');
Expect(1, 2142, '\p{Scx=mand}', "");
Expect(0, 2142, '\p{^Scx=mand}', "");
Expect(0, 2142, '\P{Scx=mand}', "");
Expect(1, 2142, '\P{^Scx=mand}', "");
Expect(0, 2143, '\p{Scx=mand}', "");
Expect(1, 2143, '\p{^Scx=mand}', "");
Expect(1, 2143, '\P{Scx=mand}', "");
Expect(0, 2143, '\P{^Scx=mand}', "");
Expect(1, 2142, '\p{Scx=-	Mand}', "");
Expect(0, 2142, '\p{^Scx=-	Mand}', "");
Expect(0, 2142, '\P{Scx=-	Mand}', "");
Expect(1, 2142, '\P{^Scx=-	Mand}', "");
Expect(0, 2143, '\p{Scx=-	Mand}', "");
Expect(1, 2143, '\p{^Scx=-	Mand}', "");
Expect(1, 2143, '\P{Scx=-	Mand}', "");
Expect(0, 2143, '\P{^Scx=-	Mand}', "");
Error('\p{Is_Script_Extensions: :=Mandaic}');
Error('\P{Is_Script_Extensions: :=Mandaic}');
Expect(1, 2142, '\p{Is_Script_Extensions=mandaic}', "");
Expect(0, 2142, '\p{^Is_Script_Extensions=mandaic}', "");
Expect(0, 2142, '\P{Is_Script_Extensions=mandaic}', "");
Expect(1, 2142, '\P{^Is_Script_Extensions=mandaic}', "");
Expect(0, 2143, '\p{Is_Script_Extensions=mandaic}', "");
Expect(1, 2143, '\p{^Is_Script_Extensions=mandaic}', "");
Expect(1, 2143, '\P{Is_Script_Extensions=mandaic}', "");
Expect(0, 2143, '\P{^Is_Script_Extensions=mandaic}', "");
Expect(1, 2142, '\p{Is_Script_Extensions: _Mandaic}', "");
Expect(0, 2142, '\p{^Is_Script_Extensions: _Mandaic}', "");
Expect(0, 2142, '\P{Is_Script_Extensions: _Mandaic}', "");
Expect(1, 2142, '\P{^Is_Script_Extensions: _Mandaic}', "");
Expect(0, 2143, '\p{Is_Script_Extensions: _Mandaic}', "");
Expect(1, 2143, '\p{^Is_Script_Extensions: _Mandaic}', "");
Expect(1, 2143, '\P{Is_Script_Extensions: _Mandaic}', "");
Expect(0, 2143, '\P{^Is_Script_Extensions: _Mandaic}', "");
Error('\p{Is_Scx=		Mand/a/}');
Error('\P{Is_Scx=		Mand/a/}');
Expect(1, 2142, '\p{Is_Scx=mand}', "");
Expect(0, 2142, '\p{^Is_Scx=mand}', "");
Expect(0, 2142, '\P{Is_Scx=mand}', "");
Expect(1, 2142, '\P{^Is_Scx=mand}', "");
Expect(0, 2143, '\p{Is_Scx=mand}', "");
Expect(1, 2143, '\p{^Is_Scx=mand}', "");
Expect(1, 2143, '\P{Is_Scx=mand}', "");
Expect(0, 2143, '\P{^Is_Scx=mand}', "");
Expect(1, 2142, '\p{Is_Scx=	Mand}', "");
Expect(0, 2142, '\p{^Is_Scx=	Mand}', "");
Expect(0, 2142, '\P{Is_Scx=	Mand}', "");
Expect(1, 2142, '\P{^Is_Scx=	Mand}', "");
Expect(0, 2143, '\p{Is_Scx=	Mand}', "");
Expect(1, 2143, '\p{^Is_Scx=	Mand}', "");
Expect(1, 2143, '\P{Is_Scx=	Mand}', "");
Expect(0, 2143, '\P{^Is_Scx=	Mand}', "");
Error('\p{Script_Extensions=:= Meroitic_Cursive}');
Error('\P{Script_Extensions=:= Meroitic_Cursive}');
Expect(1, 68031, '\p{Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\p{^Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\P{Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\P{^Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\p{Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\p{^Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\P{Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\P{^Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\p{Script_Extensions=	meroitic_cursive}', "");
Expect(0, 68031, '\p{^Script_Extensions=	meroitic_cursive}', "");
Expect(0, 68031, '\P{Script_Extensions=	meroitic_cursive}', "");
Expect(1, 68031, '\P{^Script_Extensions=	meroitic_cursive}', "");
Expect(0, 68032, '\p{Script_Extensions=	meroitic_cursive}', "");
Expect(1, 68032, '\p{^Script_Extensions=	meroitic_cursive}', "");
Expect(1, 68032, '\P{Script_Extensions=	meroitic_cursive}', "");
Expect(0, 68032, '\P{^Script_Extensions=	meroitic_cursive}', "");
Error('\p{Scx=_/a/Merc}');
Error('\P{Scx=_/a/Merc}');
Expect(1, 68031, '\p{Scx=merc}', "");
Expect(0, 68031, '\p{^Scx=merc}', "");
Expect(0, 68031, '\P{Scx=merc}', "");
Expect(1, 68031, '\P{^Scx=merc}', "");
Expect(0, 68032, '\p{Scx=merc}', "");
Expect(1, 68032, '\p{^Scx=merc}', "");
Expect(1, 68032, '\P{Scx=merc}', "");
Expect(0, 68032, '\P{^Scx=merc}', "");
Expect(1, 68031, '\p{Scx=	 MERC}', "");
Expect(0, 68031, '\p{^Scx=	 MERC}', "");
Expect(0, 68031, '\P{Scx=	 MERC}', "");
Expect(1, 68031, '\P{^Scx=	 MERC}', "");
Expect(0, 68032, '\p{Scx=	 MERC}', "");
Expect(1, 68032, '\p{^Scx=	 MERC}', "");
Expect(1, 68032, '\P{Scx=	 MERC}', "");
Expect(0, 68032, '\P{^Scx=	 MERC}', "");
Error('\p{Is_Script_Extensions:   	:=Meroitic_cursive}');
Error('\P{Is_Script_Extensions:   	:=Meroitic_cursive}');
Expect(1, 68031, '\p{Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\p{^Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68031, '\P{Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\P{^Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\p{Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\p{^Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68032, '\P{Is_Script_Extensions=meroiticcursive}', "");
Expect(0, 68032, '\P{^Is_Script_Extensions=meroiticcursive}', "");
Expect(1, 68031, '\p{Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(0, 68031, '\p{^Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(0, 68031, '\P{Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(1, 68031, '\P{^Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(0, 68032, '\p{Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(1, 68032, '\p{^Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(1, 68032, '\P{Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Expect(0, 68032, '\P{^Is_Script_Extensions=-Meroitic_CURSIVE}', "");
Error('\p{Is_Scx=/a/ Merc}');
Error('\P{Is_Scx=/a/ Merc}');
Expect(1, 68031, '\p{Is_Scx=merc}', "");
Expect(0, 68031, '\p{^Is_Scx=merc}', "");
Expect(0, 68031, '\P{Is_Scx=merc}', "");
Expect(1, 68031, '\P{^Is_Scx=merc}', "");
Expect(0, 68032, '\p{Is_Scx=merc}', "");
Expect(1, 68032, '\p{^Is_Scx=merc}', "");
Expect(1, 68032, '\P{Is_Scx=merc}', "");
Expect(0, 68032, '\P{^Is_Scx=merc}', "");
Expect(1, 68031, '\p{Is_Scx: --Merc}', "");
Expect(0, 68031, '\p{^Is_Scx: --Merc}', "");
Expect(0, 68031, '\P{Is_Scx: --Merc}', "");
Expect(1, 68031, '\P{^Is_Scx: --Merc}', "");
Expect(0, 68032, '\p{Is_Scx: --Merc}', "");
Expect(1, 68032, '\p{^Is_Scx: --Merc}', "");
Expect(1, 68032, '\P{Is_Scx: --Merc}', "");
Expect(0, 68032, '\P{^Is_Scx: --Merc}', "");
Error('\p{Script_Extensions= /a/meroitic_Hieroglyphs}');
Error('\P{Script_Extensions= /a/meroitic_Hieroglyphs}');
Expect(1, 67999, '\p{Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Script_Extensions=meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Script_Extensions=meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\p{^Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(0, 67999, '\P{Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(1, 67999, '\P{^Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\p{Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\p{^Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(1, 68000, '\P{Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Expect(0, 68000, '\P{^Script_Extensions= 	Meroitic_Hieroglyphs}', "");
Error('\p{Scx=-/a/mero}');
Error('\P{Scx=-/a/mero}');
Expect(1, 67999, '\p{Scx=mero}', "");
Expect(0, 67999, '\p{^Scx=mero}', "");
Expect(0, 67999, '\P{Scx=mero}', "");
Expect(1, 67999, '\P{^Scx=mero}', "");
Expect(0, 68000, '\p{Scx=mero}', "");
Expect(1, 68000, '\p{^Scx=mero}', "");
Expect(1, 68000, '\P{Scx=mero}', "");
Expect(0, 68000, '\P{^Scx=mero}', "");
Expect(1, 67999, '\p{Scx=	-Mero}', "");
Expect(0, 67999, '\p{^Scx=	-Mero}', "");
Expect(0, 67999, '\P{Scx=	-Mero}', "");
Expect(1, 67999, '\P{^Scx=	-Mero}', "");
Expect(0, 68000, '\p{Scx=	-Mero}', "");
Expect(1, 68000, '\p{^Scx=	-Mero}', "");
Expect(1, 68000, '\P{Scx=	-Mero}', "");
Expect(0, 68000, '\P{^Scx=	-Mero}', "");
Error('\p{Is_Script_Extensions=	MEROITIC_Hieroglyphs:=}');
Error('\P{Is_Script_Extensions=	MEROITIC_Hieroglyphs:=}');
Expect(1, 67999, '\p{Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(0, 67999, '\p{^Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(0, 67999, '\P{Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(1, 67999, '\P{^Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(0, 68000, '\p{Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(1, 68000, '\p{^Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(1, 68000, '\P{Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(0, 68000, '\P{^Is_Script_Extensions:	meroitichieroglyphs}', "");
Expect(1, 67999, '\p{Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(0, 67999, '\p{^Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(0, 67999, '\P{Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(1, 67999, '\P{^Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(0, 68000, '\p{Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(1, 68000, '\p{^Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(1, 68000, '\P{Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Expect(0, 68000, '\P{^Is_Script_Extensions= MEROITIC_HIEROGLYPHS}', "");
Error('\p{Is_Scx=/a/Mero}');
Error('\P{Is_Scx=/a/Mero}');
Expect(1, 67999, '\p{Is_Scx=mero}', "");
Expect(0, 67999, '\p{^Is_Scx=mero}', "");
Expect(0, 67999, '\P{Is_Scx=mero}', "");
Expect(1, 67999, '\P{^Is_Scx=mero}', "");
Expect(0, 68000, '\p{Is_Scx=mero}', "");
Expect(1, 68000, '\p{^Is_Scx=mero}', "");
Expect(1, 68000, '\P{Is_Scx=mero}', "");
Expect(0, 68000, '\P{^Is_Scx=mero}', "");
Expect(1, 67999, '\p{Is_Scx=--mero}', "");
Expect(0, 67999, '\p{^Is_Scx=--mero}', "");
Expect(0, 67999, '\P{Is_Scx=--mero}', "");
Expect(1, 67999, '\P{^Is_Scx=--mero}', "");
Expect(0, 68000, '\p{Is_Scx=--mero}', "");
Expect(1, 68000, '\p{^Is_Scx=--mero}', "");
Expect(1, 68000, '\P{Is_Scx=--mero}', "");
Expect(0, 68000, '\P{^Is_Scx=--mero}', "");
Error('\p{Script_Extensions::=- MALAYALAM}');
Error('\P{Script_Extensions::=- MALAYALAM}');
Expect(1, 3455, '\p{Script_Extensions=malayalam}', "");
Expect(0, 3455, '\p{^Script_Extensions=malayalam}', "");
Expect(0, 3455, '\P{Script_Extensions=malayalam}', "");
Expect(1, 3455, '\P{^Script_Extensions=malayalam}', "");
Expect(0, 3456, '\p{Script_Extensions=malayalam}', "");
Expect(1, 3456, '\p{^Script_Extensions=malayalam}', "");
Expect(1, 3456, '\P{Script_Extensions=malayalam}', "");
Expect(0, 3456, '\P{^Script_Extensions=malayalam}', "");
Expect(1, 3455, '\p{Script_Extensions=  Malayalam}', "");
Expect(0, 3455, '\p{^Script_Extensions=  Malayalam}', "");
Expect(0, 3455, '\P{Script_Extensions=  Malayalam}', "");
Expect(1, 3455, '\P{^Script_Extensions=  Malayalam}', "");
Expect(0, 3456, '\p{Script_Extensions=  Malayalam}', "");
Expect(1, 3456, '\p{^Script_Extensions=  Malayalam}', "");
Expect(1, 3456, '\P{Script_Extensions=  Malayalam}', "");
Expect(0, 3456, '\P{^Script_Extensions=  Malayalam}', "");
Error('\p{Scx=	:=MLYM}');
Error('\P{Scx=	:=MLYM}');
Expect(1, 3455, '\p{Scx=mlym}', "");
Expect(0, 3455, '\p{^Scx=mlym}', "");
Expect(0, 3455, '\P{Scx=mlym}', "");
Expect(1, 3455, '\P{^Scx=mlym}', "");
Expect(0, 3456, '\p{Scx=mlym}', "");
Expect(1, 3456, '\p{^Scx=mlym}', "");
Expect(1, 3456, '\P{Scx=mlym}', "");
Expect(0, 3456, '\P{^Scx=mlym}', "");
Expect(1, 3455, '\p{Scx=-MLYM}', "");
Expect(0, 3455, '\p{^Scx=-MLYM}', "");
Expect(0, 3455, '\P{Scx=-MLYM}', "");
Expect(1, 3455, '\P{^Scx=-MLYM}', "");
Expect(0, 3456, '\p{Scx=-MLYM}', "");
Expect(1, 3456, '\p{^Scx=-MLYM}', "");
Expect(1, 3456, '\P{Scx=-MLYM}', "");
Expect(0, 3456, '\P{^Scx=-MLYM}', "");
Error('\p{Is_Script_Extensions=	Malayalam/a/}');
Error('\P{Is_Script_Extensions=	Malayalam/a/}');
Expect(1, 3455, '\p{Is_Script_Extensions=malayalam}', "");
Expect(0, 3455, '\p{^Is_Script_Extensions=malayalam}', "");
Expect(0, 3455, '\P{Is_Script_Extensions=malayalam}', "");
Expect(1, 3455, '\P{^Is_Script_Extensions=malayalam}', "");
Expect(0, 3456, '\p{Is_Script_Extensions=malayalam}', "");
Expect(1, 3456, '\p{^Is_Script_Extensions=malayalam}', "");
Expect(1, 3456, '\P{Is_Script_Extensions=malayalam}', "");
Expect(0, 3456, '\P{^Is_Script_Extensions=malayalam}', "");
Expect(1, 3455, '\p{Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(0, 3455, '\p{^Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(0, 3455, '\P{Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(1, 3455, '\P{^Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(0, 3456, '\p{Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(1, 3456, '\p{^Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(1, 3456, '\P{Is_Script_Extensions: 	-MALAYALAM}', "");
Expect(0, 3456, '\P{^Is_Script_Extensions: 	-MALAYALAM}', "");
Error('\p{Is_Scx=/a/-MLYM}');
Error('\P{Is_Scx=/a/-MLYM}');
Expect(1, 3455, '\p{Is_Scx: mlym}', "");
Expect(0, 3455, '\p{^Is_Scx: mlym}', "");
Expect(0, 3455, '\P{Is_Scx: mlym}', "");
Expect(1, 3455, '\P{^Is_Scx: mlym}', "");
Expect(0, 3456, '\p{Is_Scx: mlym}', "");
Expect(1, 3456, '\p{^Is_Scx: mlym}', "");
Expect(1, 3456, '\P{Is_Scx: mlym}', "");
Expect(0, 3456, '\P{^Is_Scx: mlym}', "");
Expect(1, 3455, '\p{Is_Scx: _-mlym}', "");
Expect(0, 3455, '\p{^Is_Scx: _-mlym}', "");
Expect(0, 3455, '\P{Is_Scx: _-mlym}', "");
Expect(1, 3455, '\P{^Is_Scx: _-mlym}', "");
Expect(0, 3456, '\p{Is_Scx: _-mlym}', "");
Expect(1, 3456, '\p{^Is_Scx: _-mlym}', "");
Expect(1, 3456, '\P{Is_Scx: _-mlym}', "");
Expect(0, 3456, '\P{^Is_Scx: _-mlym}', "");
Error('\p{Script_Extensions= _MONGOLIAN/a/}');
Error('\P{Script_Extensions= _MONGOLIAN/a/}');
Expect(1, 6314, '\p{Script_Extensions=mongolian}', "");
Expect(0, 6314, '\p{^Script_Extensions=mongolian}', "");
Expect(0, 6314, '\P{Script_Extensions=mongolian}', "");
Expect(1, 6314, '\P{^Script_Extensions=mongolian}', "");
Expect(0, 6315, '\p{Script_Extensions=mongolian}', "");
Expect(1, 6315, '\p{^Script_Extensions=mongolian}', "");
Expect(1, 6315, '\P{Script_Extensions=mongolian}', "");
Expect(0, 6315, '\P{^Script_Extensions=mongolian}', "");
Expect(1, 6314, '\p{Script_Extensions=	mongolian}', "");
Expect(0, 6314, '\p{^Script_Extensions=	mongolian}', "");
Expect(0, 6314, '\P{Script_Extensions=	mongolian}', "");
Expect(1, 6314, '\P{^Script_Extensions=	mongolian}', "");
Expect(0, 6315, '\p{Script_Extensions=	mongolian}', "");
Expect(1, 6315, '\p{^Script_Extensions=	mongolian}', "");
Expect(1, 6315, '\P{Script_Extensions=	mongolian}', "");
Expect(0, 6315, '\P{^Script_Extensions=	mongolian}', "");
Error('\p{Scx=:=-Mong}');
Error('\P{Scx=:=-Mong}');
Expect(1, 6314, '\p{Scx=mong}', "");
Expect(0, 6314, '\p{^Scx=mong}', "");
Expect(0, 6314, '\P{Scx=mong}', "");
Expect(1, 6314, '\P{^Scx=mong}', "");
Expect(0, 6315, '\p{Scx=mong}', "");
Expect(1, 6315, '\p{^Scx=mong}', "");
Expect(1, 6315, '\P{Scx=mong}', "");
Expect(0, 6315, '\P{^Scx=mong}', "");
Expect(1, 6314, '\p{Scx=	 Mong}', "");
Expect(0, 6314, '\p{^Scx=	 Mong}', "");
Expect(0, 6314, '\P{Scx=	 Mong}', "");
Expect(1, 6314, '\P{^Scx=	 Mong}', "");
Expect(0, 6315, '\p{Scx=	 Mong}', "");
Expect(1, 6315, '\p{^Scx=	 Mong}', "");
Expect(1, 6315, '\P{Scx=	 Mong}', "");
Expect(0, 6315, '\P{^Scx=	 Mong}', "");
Error('\p{Is_Script_Extensions=-/a/Mongolian}');
Error('\P{Is_Script_Extensions=-/a/Mongolian}');
Expect(1, 6314, '\p{Is_Script_Extensions=mongolian}', "");
Expect(0, 6314, '\p{^Is_Script_Extensions=mongolian}', "");
Expect(0, 6314, '\P{Is_Script_Extensions=mongolian}', "");
Expect(1, 6314, '\P{^Is_Script_Extensions=mongolian}', "");
Expect(0, 6315, '\p{Is_Script_Extensions=mongolian}', "");
Expect(1, 6315, '\p{^Is_Script_Extensions=mongolian}', "");
Expect(1, 6315, '\P{Is_Script_Extensions=mongolian}', "");
Expect(0, 6315, '\P{^Is_Script_Extensions=mongolian}', "");
Expect(1, 6314, '\p{Is_Script_Extensions=_Mongolian}', "");
Expect(0, 6314, '\p{^Is_Script_Extensions=_Mongolian}', "");
Expect(0, 6314, '\P{Is_Script_Extensions=_Mongolian}', "");
Expect(1, 6314, '\P{^Is_Script_Extensions=_Mongolian}', "");
Expect(0, 6315, '\p{Is_Script_Extensions=_Mongolian}', "");
Expect(1, 6315, '\p{^Is_Script_Extensions=_Mongolian}', "");
Expect(1, 6315, '\P{Is_Script_Extensions=_Mongolian}', "");
Expect(0, 6315, '\P{^Is_Script_Extensions=_Mongolian}', "");
Error('\p{Is_Scx=/a/-Mong}');
Error('\P{Is_Scx=/a/-Mong}');
Expect(1, 6314, '\p{Is_Scx=mong}', "");
Expect(0, 6314, '\p{^Is_Scx=mong}', "");
Expect(0, 6314, '\P{Is_Scx=mong}', "");
Expect(1, 6314, '\P{^Is_Scx=mong}', "");
Expect(0, 6315, '\p{Is_Scx=mong}', "");
Expect(1, 6315, '\p{^Is_Scx=mong}', "");
Expect(1, 6315, '\P{Is_Scx=mong}', "");
Expect(0, 6315, '\P{^Is_Scx=mong}', "");
Expect(1, 6314, '\p{Is_Scx= -Mong}', "");
Expect(0, 6314, '\p{^Is_Scx= -Mong}', "");
Expect(0, 6314, '\P{Is_Scx= -Mong}', "");
Expect(1, 6314, '\P{^Is_Scx= -Mong}', "");
Expect(0, 6315, '\p{Is_Scx= -Mong}', "");
Expect(1, 6315, '\p{^Is_Scx= -Mong}', "");
Expect(1, 6315, '\P{Is_Scx= -Mong}', "");
Expect(0, 6315, '\P{^Is_Scx= -Mong}', "");
Error('\p{Script_Extensions:   -:=meetei_MAYEK}');
Error('\P{Script_Extensions:   -:=meetei_MAYEK}');
Expect(1, 44025, '\p{Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\p{^Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\P{Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\P{^Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\p{Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\p{^Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\P{Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\P{^Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\p{Script_Extensions= -Meetei_Mayek}', "");
Expect(0, 44025, '\p{^Script_Extensions= -Meetei_Mayek}', "");
Expect(0, 44025, '\P{Script_Extensions= -Meetei_Mayek}', "");
Expect(1, 44025, '\P{^Script_Extensions= -Meetei_Mayek}', "");
Expect(0, 44026, '\p{Script_Extensions= -Meetei_Mayek}', "");
Expect(1, 44026, '\p{^Script_Extensions= -Meetei_Mayek}', "");
Expect(1, 44026, '\P{Script_Extensions= -Meetei_Mayek}', "");
Expect(0, 44026, '\P{^Script_Extensions= -Meetei_Mayek}', "");
Error('\p{Scx: 	/a/Mtei}');
Error('\P{Scx: 	/a/Mtei}');
Expect(1, 44025, '\p{Scx=mtei}', "");
Expect(0, 44025, '\p{^Scx=mtei}', "");
Expect(0, 44025, '\P{Scx=mtei}', "");
Expect(1, 44025, '\P{^Scx=mtei}', "");
Expect(0, 44026, '\p{Scx=mtei}', "");
Expect(1, 44026, '\p{^Scx=mtei}', "");
Expect(1, 44026, '\P{Scx=mtei}', "");
Expect(0, 44026, '\P{^Scx=mtei}', "");
Expect(1, 44025, '\p{Scx: _ Mtei}', "");
Expect(0, 44025, '\p{^Scx: _ Mtei}', "");
Expect(0, 44025, '\P{Scx: _ Mtei}', "");
Expect(1, 44025, '\P{^Scx: _ Mtei}', "");
Expect(0, 44026, '\p{Scx: _ Mtei}', "");
Expect(1, 44026, '\p{^Scx: _ Mtei}', "");
Expect(1, 44026, '\P{Scx: _ Mtei}', "");
Expect(0, 44026, '\P{^Scx: _ Mtei}', "");
Error('\p{Is_Script_Extensions=/a/	Meetei_MAYEK}');
Error('\P{Is_Script_Extensions=/a/	Meetei_MAYEK}');
Expect(1, 44025, '\p{Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\p{^Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44025, '\P{Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\P{^Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\p{Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\p{^Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44026, '\P{Is_Script_Extensions=meeteimayek}', "");
Expect(0, 44026, '\P{^Is_Script_Extensions=meeteimayek}', "");
Expect(1, 44025, '\p{Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(0, 44025, '\p{^Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(0, 44025, '\P{Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(1, 44025, '\P{^Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(0, 44026, '\p{Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(1, 44026, '\p{^Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(1, 44026, '\P{Is_Script_Extensions=	MEETEI_Mayek}', "");
Expect(0, 44026, '\P{^Is_Script_Extensions=	MEETEI_Mayek}', "");
Error('\p{Is_Scx=/a/	_Mtei}');
Error('\P{Is_Scx=/a/	_Mtei}');
Expect(1, 44025, '\p{Is_Scx=mtei}', "");
Expect(0, 44025, '\p{^Is_Scx=mtei}', "");
Expect(0, 44025, '\P{Is_Scx=mtei}', "");
Expect(1, 44025, '\P{^Is_Scx=mtei}', "");
Expect(0, 44026, '\p{Is_Scx=mtei}', "");
Expect(1, 44026, '\p{^Is_Scx=mtei}', "");
Expect(1, 44026, '\P{Is_Scx=mtei}', "");
Expect(0, 44026, '\P{^Is_Scx=mtei}', "");
Expect(1, 44025, '\p{Is_Scx=_Mtei}', "");
Expect(0, 44025, '\p{^Is_Scx=_Mtei}', "");
Expect(0, 44025, '\P{Is_Scx=_Mtei}', "");
Expect(1, 44025, '\P{^Is_Scx=_Mtei}', "");
Expect(0, 44026, '\p{Is_Scx=_Mtei}', "");
Expect(1, 44026, '\p{^Is_Scx=_Mtei}', "");
Expect(1, 44026, '\P{Is_Scx=_Mtei}', "");
Expect(0, 44026, '\P{^Is_Scx=_Mtei}', "");
Error('\p{Script_Extensions=	/a/MYANMAR}');
Error('\P{Script_Extensions=	/a/MYANMAR}');
Expect(1, 43643, '\p{Script_Extensions=myanmar}', "");
Expect(0, 43643, '\p{^Script_Extensions=myanmar}', "");
Expect(0, 43643, '\P{Script_Extensions=myanmar}', "");
Expect(1, 43643, '\P{^Script_Extensions=myanmar}', "");
Expect(0, 43644, '\p{Script_Extensions=myanmar}', "");
Expect(1, 43644, '\p{^Script_Extensions=myanmar}', "");
Expect(1, 43644, '\P{Script_Extensions=myanmar}', "");
Expect(0, 43644, '\P{^Script_Extensions=myanmar}', "");
Expect(1, 43643, '\p{Script_Extensions=	Myanmar}', "");
Expect(0, 43643, '\p{^Script_Extensions=	Myanmar}', "");
Expect(0, 43643, '\P{Script_Extensions=	Myanmar}', "");
Expect(1, 43643, '\P{^Script_Extensions=	Myanmar}', "");
Expect(0, 43644, '\p{Script_Extensions=	Myanmar}', "");
Expect(1, 43644, '\p{^Script_Extensions=	Myanmar}', "");
Expect(1, 43644, '\P{Script_Extensions=	Myanmar}', "");
Expect(0, 43644, '\P{^Script_Extensions=	Myanmar}', "");
Error('\p{Scx: :=	Mymr}');
Error('\P{Scx: :=	Mymr}');
Expect(1, 43643, '\p{Scx=mymr}', "");
Expect(0, 43643, '\p{^Scx=mymr}', "");
Expect(0, 43643, '\P{Scx=mymr}', "");
Expect(1, 43643, '\P{^Scx=mymr}', "");
Expect(0, 43644, '\p{Scx=mymr}', "");
Expect(1, 43644, '\p{^Scx=mymr}', "");
Expect(1, 43644, '\P{Scx=mymr}', "");
Expect(0, 43644, '\P{^Scx=mymr}', "");
Expect(1, 43643, '\p{Scx=		mymr}', "");
Expect(0, 43643, '\p{^Scx=		mymr}', "");
Expect(0, 43643, '\P{Scx=		mymr}', "");
Expect(1, 43643, '\P{^Scx=		mymr}', "");
Expect(0, 43644, '\p{Scx=		mymr}', "");
Expect(1, 43644, '\p{^Scx=		mymr}', "");
Expect(1, 43644, '\P{Scx=		mymr}', "");
Expect(0, 43644, '\P{^Scx=		mymr}', "");
Error('\p{Is_Script_Extensions:/a/ _Myanmar}');
Error('\P{Is_Script_Extensions:/a/ _Myanmar}');
Expect(1, 43643, '\p{Is_Script_Extensions=myanmar}', "");
Expect(0, 43643, '\p{^Is_Script_Extensions=myanmar}', "");
Expect(0, 43643, '\P{Is_Script_Extensions=myanmar}', "");
Expect(1, 43643, '\P{^Is_Script_Extensions=myanmar}', "");
Expect(0, 43644, '\p{Is_Script_Extensions=myanmar}', "");
Expect(1, 43644, '\p{^Is_Script_Extensions=myanmar}', "");
Expect(1, 43644, '\P{Is_Script_Extensions=myanmar}', "");
Expect(0, 43644, '\P{^Is_Script_Extensions=myanmar}', "");
Expect(1, 43643, '\p{Is_Script_Extensions:   _-Myanmar}', "");
Expect(0, 43643, '\p{^Is_Script_Extensions:   _-Myanmar}', "");
Expect(0, 43643, '\P{Is_Script_Extensions:   _-Myanmar}', "");
Expect(1, 43643, '\P{^Is_Script_Extensions:   _-Myanmar}', "");
Expect(0, 43644, '\p{Is_Script_Extensions:   _-Myanmar}', "");
Expect(1, 43644, '\p{^Is_Script_Extensions:   _-Myanmar}', "");
Expect(1, 43644, '\P{Is_Script_Extensions:   _-Myanmar}', "");
Expect(0, 43644, '\P{^Is_Script_Extensions:   _-Myanmar}', "");
Error('\p{Is_Scx=	 Mymr:=}');
Error('\P{Is_Scx=	 Mymr:=}');
Expect(1, 43643, '\p{Is_Scx:mymr}', "");
Expect(0, 43643, '\p{^Is_Scx:mymr}', "");
Expect(0, 43643, '\P{Is_Scx:mymr}', "");
Expect(1, 43643, '\P{^Is_Scx:mymr}', "");
Expect(0, 43644, '\p{Is_Scx:mymr}', "");
Expect(1, 43644, '\p{^Is_Scx:mymr}', "");
Expect(1, 43644, '\P{Is_Scx:mymr}', "");
Expect(0, 43644, '\P{^Is_Scx:mymr}', "");
Expect(1, 43643, '\p{Is_Scx=Mymr}', "");
Expect(0, 43643, '\p{^Is_Scx=Mymr}', "");
Expect(0, 43643, '\P{Is_Scx=Mymr}', "");
Expect(1, 43643, '\P{^Is_Scx=Mymr}', "");
Expect(0, 43644, '\p{Is_Scx=Mymr}', "");
Expect(1, 43644, '\p{^Is_Scx=Mymr}', "");
Expect(1, 43644, '\P{Is_Scx=Mymr}', "");
Expect(0, 43644, '\P{^Is_Scx=Mymr}', "");
Error('\p{Script_Extensions=-:=nko}');
Error('\P{Script_Extensions=-:=nko}');
Expect(1, 2042, '\p{Script_Extensions=nko}', "");
Expect(0, 2042, '\p{^Script_Extensions=nko}', "");
Expect(0, 2042, '\P{Script_Extensions=nko}', "");
Expect(1, 2042, '\P{^Script_Extensions=nko}', "");
Expect(0, 2043, '\p{Script_Extensions=nko}', "");
Expect(1, 2043, '\p{^Script_Extensions=nko}', "");
Expect(1, 2043, '\P{Script_Extensions=nko}', "");
Expect(0, 2043, '\P{^Script_Extensions=nko}', "");
Expect(1, 2042, '\p{Script_Extensions:   _ Nko}', "");
Expect(0, 2042, '\p{^Script_Extensions:   _ Nko}', "");
Expect(0, 2042, '\P{Script_Extensions:   _ Nko}', "");
Expect(1, 2042, '\P{^Script_Extensions:   _ Nko}', "");
Expect(0, 2043, '\p{Script_Extensions:   _ Nko}', "");
Expect(1, 2043, '\p{^Script_Extensions:   _ Nko}', "");
Expect(1, 2043, '\P{Script_Extensions:   _ Nko}', "");
Expect(0, 2043, '\P{^Script_Extensions:   _ Nko}', "");
Error('\p{Scx=:=_	nkoo}');
Error('\P{Scx=:=_	nkoo}');
Expect(1, 2042, '\p{Scx=nkoo}', "");
Expect(0, 2042, '\p{^Scx=nkoo}', "");
Expect(0, 2042, '\P{Scx=nkoo}', "");
Expect(1, 2042, '\P{^Scx=nkoo}', "");
Expect(0, 2043, '\p{Scx=nkoo}', "");
Expect(1, 2043, '\p{^Scx=nkoo}', "");
Expect(1, 2043, '\P{Scx=nkoo}', "");
Expect(0, 2043, '\P{^Scx=nkoo}', "");
Expect(1, 2042, '\p{Scx=-	nkoo}', "");
Expect(0, 2042, '\p{^Scx=-	nkoo}', "");
Expect(0, 2042, '\P{Scx=-	nkoo}', "");
Expect(1, 2042, '\P{^Scx=-	nkoo}', "");
Expect(0, 2043, '\p{Scx=-	nkoo}', "");
Expect(1, 2043, '\p{^Scx=-	nkoo}', "");
Expect(1, 2043, '\P{Scx=-	nkoo}', "");
Expect(0, 2043, '\P{^Scx=-	nkoo}', "");
Error('\p{Is_Script_Extensions=/a/-_Nko}');
Error('\P{Is_Script_Extensions=/a/-_Nko}');
Expect(1, 2042, '\p{Is_Script_Extensions=nko}', "");
Expect(0, 2042, '\p{^Is_Script_Extensions=nko}', "");
Expect(0, 2042, '\P{Is_Script_Extensions=nko}', "");
Expect(1, 2042, '\P{^Is_Script_Extensions=nko}', "");
Expect(0, 2043, '\p{Is_Script_Extensions=nko}', "");
Expect(1, 2043, '\p{^Is_Script_Extensions=nko}', "");
Expect(1, 2043, '\P{Is_Script_Extensions=nko}', "");
Expect(0, 2043, '\P{^Is_Script_Extensions=nko}', "");
Expect(1, 2042, '\p{Is_Script_Extensions=	 Nko}', "");
Expect(0, 2042, '\p{^Is_Script_Extensions=	 Nko}', "");
Expect(0, 2042, '\P{Is_Script_Extensions=	 Nko}', "");
Expect(1, 2042, '\P{^Is_Script_Extensions=	 Nko}', "");
Expect(0, 2043, '\p{Is_Script_Extensions=	 Nko}', "");
Expect(1, 2043, '\p{^Is_Script_Extensions=	 Nko}', "");
Expect(1, 2043, '\P{Is_Script_Extensions=	 Nko}', "");
Expect(0, 2043, '\P{^Is_Script_Extensions=	 Nko}', "");
Error('\p{Is_Scx=:=_NKOO}');
Error('\P{Is_Scx=:=_NKOO}');
Expect(1, 2042, '\p{Is_Scx=nkoo}', "");
Expect(0, 2042, '\p{^Is_Scx=nkoo}', "");
Expect(0, 2042, '\P{Is_Scx=nkoo}', "");
Expect(1, 2042, '\P{^Is_Scx=nkoo}', "");
Expect(0, 2043, '\p{Is_Scx=nkoo}', "");
Expect(1, 2043, '\p{^Is_Scx=nkoo}', "");
Expect(1, 2043, '\P{Is_Scx=nkoo}', "");
Expect(0, 2043, '\P{^Is_Scx=nkoo}', "");
Expect(1, 2042, '\p{Is_Scx=-nkoo}', "");
Expect(0, 2042, '\p{^Is_Scx=-nkoo}', "");
Expect(0, 2042, '\P{Is_Scx=-nkoo}', "");
Expect(1, 2042, '\P{^Is_Scx=-nkoo}', "");
Expect(0, 2043, '\p{Is_Scx=-nkoo}', "");
Expect(1, 2043, '\p{^Is_Scx=-nkoo}', "");
Expect(1, 2043, '\P{Is_Scx=-nkoo}', "");
Expect(0, 2043, '\P{^Is_Scx=-nkoo}', "");
Error('\p{Script_Extensions=:=ogham}');
Error('\P{Script_Extensions=:=ogham}');
Expect(1, 5788, '\p{Script_Extensions=ogham}', "");
Expect(0, 5788, '\p{^Script_Extensions=ogham}', "");
Expect(0, 5788, '\P{Script_Extensions=ogham}', "");
Expect(1, 5788, '\P{^Script_Extensions=ogham}', "");
Expect(0, 5789, '\p{Script_Extensions=ogham}', "");
Expect(1, 5789, '\p{^Script_Extensions=ogham}', "");
Expect(1, 5789, '\P{Script_Extensions=ogham}', "");
Expect(0, 5789, '\P{^Script_Extensions=ogham}', "");
Expect(1, 5788, '\p{Script_Extensions= -Ogham}', "");
Expect(0, 5788, '\p{^Script_Extensions= -Ogham}', "");
Expect(0, 5788, '\P{Script_Extensions= -Ogham}', "");
Expect(1, 5788, '\P{^Script_Extensions= -Ogham}', "");
Expect(0, 5789, '\p{Script_Extensions= -Ogham}', "");
Expect(1, 5789, '\p{^Script_Extensions= -Ogham}', "");
Expect(1, 5789, '\P{Script_Extensions= -Ogham}', "");
Expect(0, 5789, '\P{^Script_Extensions= -Ogham}', "");
Error('\p{Scx:   -	ogam:=}');
Error('\P{Scx:   -	ogam:=}');
Expect(1, 5788, '\p{Scx=ogam}', "");
Expect(0, 5788, '\p{^Scx=ogam}', "");
Expect(0, 5788, '\P{Scx=ogam}', "");
Expect(1, 5788, '\P{^Scx=ogam}', "");
Expect(0, 5789, '\p{Scx=ogam}', "");
Expect(1, 5789, '\p{^Scx=ogam}', "");
Expect(1, 5789, '\P{Scx=ogam}', "");
Expect(0, 5789, '\P{^Scx=ogam}', "");
Expect(1, 5788, '\p{Scx=	OGAM}', "");
Expect(0, 5788, '\p{^Scx=	OGAM}', "");
Expect(0, 5788, '\P{Scx=	OGAM}', "");
Expect(1, 5788, '\P{^Scx=	OGAM}', "");
Expect(0, 5789, '\p{Scx=	OGAM}', "");
Expect(1, 5789, '\p{^Scx=	OGAM}', "");
Expect(1, 5789, '\P{Scx=	OGAM}', "");
Expect(0, 5789, '\P{^Scx=	OGAM}', "");
Error('\p{Is_Script_Extensions=/a/Ogham}');
Error('\P{Is_Script_Extensions=/a/Ogham}');
Expect(1, 5788, '\p{Is_Script_Extensions=ogham}', "");
Expect(0, 5788, '\p{^Is_Script_Extensions=ogham}', "");
Expect(0, 5788, '\P{Is_Script_Extensions=ogham}', "");
Expect(1, 5788, '\P{^Is_Script_Extensions=ogham}', "");
Expect(0, 5789, '\p{Is_Script_Extensions=ogham}', "");
Expect(1, 5789, '\p{^Is_Script_Extensions=ogham}', "");
Expect(1, 5789, '\P{Is_Script_Extensions=ogham}', "");
Expect(0, 5789, '\P{^Is_Script_Extensions=ogham}', "");
Expect(1, 5788, '\p{Is_Script_Extensions=-	Ogham}', "");
Expect(0, 5788, '\p{^Is_Script_Extensions=-	Ogham}', "");
Expect(0, 5788, '\P{Is_Script_Extensions=-	Ogham}', "");
Expect(1, 5788, '\P{^Is_Script_Extensions=-	Ogham}', "");
Expect(0, 5789, '\p{Is_Script_Extensions=-	Ogham}', "");
Expect(1, 5789, '\p{^Is_Script_Extensions=-	Ogham}', "");
Expect(1, 5789, '\P{Is_Script_Extensions=-	Ogham}', "");
Expect(0, 5789, '\P{^Is_Script_Extensions=-	Ogham}', "");
Error('\p{Is_Scx:   -/a/Ogam}');
Error('\P{Is_Scx:   -/a/Ogam}');
Expect(1, 5788, '\p{Is_Scx:ogam}', "");
Expect(0, 5788, '\p{^Is_Scx:ogam}', "");
Expect(0, 5788, '\P{Is_Scx:ogam}', "");
Expect(1, 5788, '\P{^Is_Scx:ogam}', "");
Expect(0, 5789, '\p{Is_Scx:ogam}', "");
Expect(1, 5789, '\p{^Is_Scx:ogam}', "");
Expect(1, 5789, '\P{Is_Scx:ogam}', "");
Expect(0, 5789, '\P{^Is_Scx:ogam}', "");
Expect(1, 5788, '\p{Is_Scx=-	Ogam}', "");
Expect(0, 5788, '\p{^Is_Scx=-	Ogam}', "");
Expect(0, 5788, '\P{Is_Scx=-	Ogam}', "");
Expect(1, 5788, '\P{^Is_Scx=-	Ogam}', "");
Expect(0, 5789, '\p{Is_Scx=-	Ogam}', "");
Expect(1, 5789, '\p{^Is_Scx=-	Ogam}', "");
Expect(1, 5789, '\P{Is_Scx=-	Ogam}', "");
Expect(0, 5789, '\P{^Is_Scx=-	Ogam}', "");
Error('\p{Script_Extensions=_	Ol_chiki:=}');
Error('\P{Script_Extensions=_	Ol_chiki:=}');
Expect(1, 7295, '\p{Script_Extensions=olchiki}', "");
Expect(0, 7295, '\p{^Script_Extensions=olchiki}', "");
Expect(0, 7295, '\P{Script_Extensions=olchiki}', "");
Expect(1, 7295, '\P{^Script_Extensions=olchiki}', "");
Expect(0, 7296, '\p{Script_Extensions=olchiki}', "");
Expect(1, 7296, '\p{^Script_Extensions=olchiki}', "");
Expect(1, 7296, '\P{Script_Extensions=olchiki}', "");
Expect(0, 7296, '\P{^Script_Extensions=olchiki}', "");
Expect(1, 7295, '\p{Script_Extensions=	-OL_Chiki}', "");
Expect(0, 7295, '\p{^Script_Extensions=	-OL_Chiki}', "");
Expect(0, 7295, '\P{Script_Extensions=	-OL_Chiki}', "");
Expect(1, 7295, '\P{^Script_Extensions=	-OL_Chiki}', "");
Expect(0, 7296, '\p{Script_Extensions=	-OL_Chiki}', "");
Expect(1, 7296, '\p{^Script_Extensions=	-OL_Chiki}', "");
Expect(1, 7296, '\P{Script_Extensions=	-OL_Chiki}', "");
Expect(0, 7296, '\P{^Script_Extensions=	-OL_Chiki}', "");
Error('\p{Scx=/a/ -olck}');
Error('\P{Scx=/a/ -olck}');
Expect(1, 7295, '\p{Scx=olck}', "");
Expect(0, 7295, '\p{^Scx=olck}', "");
Expect(0, 7295, '\P{Scx=olck}', "");
Expect(1, 7295, '\P{^Scx=olck}', "");
Expect(0, 7296, '\p{Scx=olck}', "");
Expect(1, 7296, '\p{^Scx=olck}', "");
Expect(1, 7296, '\P{Scx=olck}', "");
Expect(0, 7296, '\P{^Scx=olck}', "");
Expect(1, 7295, '\p{Scx=_olck}', "");
Expect(0, 7295, '\p{^Scx=_olck}', "");
Expect(0, 7295, '\P{Scx=_olck}', "");
Expect(1, 7295, '\P{^Scx=_olck}', "");
Expect(0, 7296, '\p{Scx=_olck}', "");
Expect(1, 7296, '\p{^Scx=_olck}', "");
Expect(1, 7296, '\P{Scx=_olck}', "");
Expect(0, 7296, '\P{^Scx=_olck}', "");
Error('\p{Is_Script_Extensions=		ol_Chiki:=}');
Error('\P{Is_Script_Extensions=		ol_Chiki:=}');
Expect(1, 7295, '\p{Is_Script_Extensions=olchiki}', "");
Expect(0, 7295, '\p{^Is_Script_Extensions=olchiki}', "");
Expect(0, 7295, '\P{Is_Script_Extensions=olchiki}', "");
Expect(1, 7295, '\P{^Is_Script_Extensions=olchiki}', "");
Expect(0, 7296, '\p{Is_Script_Extensions=olchiki}', "");
Expect(1, 7296, '\p{^Is_Script_Extensions=olchiki}', "");
Expect(1, 7296, '\P{Is_Script_Extensions=olchiki}', "");
Expect(0, 7296, '\P{^Is_Script_Extensions=olchiki}', "");
Expect(1, 7295, '\p{Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7295, '\p{^Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7295, '\P{Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(1, 7295, '\P{^Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7296, '\p{Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(1, 7296, '\p{^Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(1, 7296, '\P{Is_Script_Extensions=	 Ol_Chiki}', "");
Expect(0, 7296, '\P{^Is_Script_Extensions=	 Ol_Chiki}', "");
Error('\p{Is_Scx=_-Olck:=}');
Error('\P{Is_Scx=_-Olck:=}');
Expect(1, 7295, '\p{Is_Scx=olck}', "");
Expect(0, 7295, '\p{^Is_Scx=olck}', "");
Expect(0, 7295, '\P{Is_Scx=olck}', "");
Expect(1, 7295, '\P{^Is_Scx=olck}', "");
Expect(0, 7296, '\p{Is_Scx=olck}', "");
Expect(1, 7296, '\p{^Is_Scx=olck}', "");
Expect(1, 7296, '\P{Is_Scx=olck}', "");
Expect(0, 7296, '\P{^Is_Scx=olck}', "");
Expect(1, 7295, '\p{Is_Scx=_OLCK}', "");
Expect(0, 7295, '\p{^Is_Scx=_OLCK}', "");
Expect(0, 7295, '\P{Is_Scx=_OLCK}', "");
Expect(1, 7295, '\P{^Is_Scx=_OLCK}', "");
Expect(0, 7296, '\p{Is_Scx=_OLCK}', "");
Expect(1, 7296, '\p{^Is_Scx=_OLCK}', "");
Expect(1, 7296, '\P{Is_Scx=_OLCK}', "");
Expect(0, 7296, '\P{^Is_Scx=_OLCK}', "");
Error('\p{Script_Extensions=/a/-Old_Turkic}');
Error('\P{Script_Extensions=/a/-Old_Turkic}');
Expect(1, 68680, '\p{Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\p{^Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\P{Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\P{^Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\p{Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\p{^Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\P{Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\P{^Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\p{Script_Extensions= 	Old_Turkic}', "");
Expect(0, 68680, '\p{^Script_Extensions= 	Old_Turkic}', "");
Expect(0, 68680, '\P{Script_Extensions= 	Old_Turkic}', "");
Expect(1, 68680, '\P{^Script_Extensions= 	Old_Turkic}', "");
Expect(0, 68681, '\p{Script_Extensions= 	Old_Turkic}', "");
Expect(1, 68681, '\p{^Script_Extensions= 	Old_Turkic}', "");
Expect(1, 68681, '\P{Script_Extensions= 	Old_Turkic}', "");
Expect(0, 68681, '\P{^Script_Extensions= 	Old_Turkic}', "");
Error('\p{Scx= Orkh:=}');
Error('\P{Scx= Orkh:=}');
Expect(1, 68680, '\p{Scx=orkh}', "");
Expect(0, 68680, '\p{^Scx=orkh}', "");
Expect(0, 68680, '\P{Scx=orkh}', "");
Expect(1, 68680, '\P{^Scx=orkh}', "");
Expect(0, 68681, '\p{Scx=orkh}', "");
Expect(1, 68681, '\p{^Scx=orkh}', "");
Expect(1, 68681, '\P{Scx=orkh}', "");
Expect(0, 68681, '\P{^Scx=orkh}', "");
Expect(1, 68680, '\p{Scx=_	Orkh}', "");
Expect(0, 68680, '\p{^Scx=_	Orkh}', "");
Expect(0, 68680, '\P{Scx=_	Orkh}', "");
Expect(1, 68680, '\P{^Scx=_	Orkh}', "");
Expect(0, 68681, '\p{Scx=_	Orkh}', "");
Expect(1, 68681, '\p{^Scx=_	Orkh}', "");
Expect(1, 68681, '\P{Scx=_	Orkh}', "");
Expect(0, 68681, '\P{^Scx=_	Orkh}', "");
Error('\p{Is_Script_Extensions=:=_ OLD_turkic}');
Error('\P{Is_Script_Extensions=:=_ OLD_turkic}');
Expect(1, 68680, '\p{Is_Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\p{^Is_Script_Extensions=oldturkic}', "");
Expect(0, 68680, '\P{Is_Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\P{^Is_Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\p{Is_Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\p{^Is_Script_Extensions=oldturkic}', "");
Expect(1, 68681, '\P{Is_Script_Extensions=oldturkic}', "");
Expect(0, 68681, '\P{^Is_Script_Extensions=oldturkic}', "");
Expect(1, 68680, '\p{Is_Script_Extensions=-_old_turkic}', "");
Expect(0, 68680, '\p{^Is_Script_Extensions=-_old_turkic}', "");
Expect(0, 68680, '\P{Is_Script_Extensions=-_old_turkic}', "");
Expect(1, 68680, '\P{^Is_Script_Extensions=-_old_turkic}', "");
Expect(0, 68681, '\p{Is_Script_Extensions=-_old_turkic}', "");
Expect(1, 68681, '\p{^Is_Script_Extensions=-_old_turkic}', "");
Expect(1, 68681, '\P{Is_Script_Extensions=-_old_turkic}', "");
Expect(0, 68681, '\P{^Is_Script_Extensions=-_old_turkic}', "");
Error('\p{Is_Scx= /a/Orkh}');
Error('\P{Is_Scx= /a/Orkh}');
Expect(1, 68680, '\p{Is_Scx=orkh}', "");
Expect(0, 68680, '\p{^Is_Scx=orkh}', "");
Expect(0, 68680, '\P{Is_Scx=orkh}', "");
Expect(1, 68680, '\P{^Is_Scx=orkh}', "");
Expect(0, 68681, '\p{Is_Scx=orkh}', "");
Expect(1, 68681, '\p{^Is_Scx=orkh}', "");
Expect(1, 68681, '\P{Is_Scx=orkh}', "");
Expect(0, 68681, '\P{^Is_Scx=orkh}', "");
Expect(1, 68680, '\p{Is_Scx=- ORKH}', "");
Expect(0, 68680, '\p{^Is_Scx=- ORKH}', "");
Expect(0, 68680, '\P{Is_Scx=- ORKH}', "");
Expect(1, 68680, '\P{^Is_Scx=- ORKH}', "");
Expect(0, 68681, '\p{Is_Scx=- ORKH}', "");
Expect(1, 68681, '\p{^Is_Scx=- ORKH}', "");
Expect(1, 68681, '\P{Is_Scx=- ORKH}', "");
Expect(0, 68681, '\P{^Is_Scx=- ORKH}', "");
Error('\p{Script_Extensions=_/a/Oriya}');
Error('\P{Script_Extensions=_/a/Oriya}');
Expect(1, 2935, '\p{Script_Extensions=oriya}', "");
Expect(0, 2935, '\p{^Script_Extensions=oriya}', "");
Expect(0, 2935, '\P{Script_Extensions=oriya}', "");
Expect(1, 2935, '\P{^Script_Extensions=oriya}', "");
Expect(0, 2936, '\p{Script_Extensions=oriya}', "");
Expect(1, 2936, '\p{^Script_Extensions=oriya}', "");
Expect(1, 2936, '\P{Script_Extensions=oriya}', "");
Expect(0, 2936, '\P{^Script_Extensions=oriya}', "");
Expect(1, 2935, '\p{Script_Extensions= 	Oriya}', "");
Expect(0, 2935, '\p{^Script_Extensions= 	Oriya}', "");
Expect(0, 2935, '\P{Script_Extensions= 	Oriya}', "");
Expect(1, 2935, '\P{^Script_Extensions= 	Oriya}', "");
Expect(0, 2936, '\p{Script_Extensions= 	Oriya}', "");
Expect(1, 2936, '\p{^Script_Extensions= 	Oriya}', "");
Expect(1, 2936, '\P{Script_Extensions= 	Oriya}', "");
Expect(0, 2936, '\P{^Script_Extensions= 	Oriya}', "");
Error('\p{Scx=	-Orya/a/}');
Error('\P{Scx=	-Orya/a/}');
Expect(1, 2935, '\p{Scx=orya}', "");
Expect(0, 2935, '\p{^Scx=orya}', "");
Expect(0, 2935, '\P{Scx=orya}', "");
Expect(1, 2935, '\P{^Scx=orya}', "");
Expect(0, 2936, '\p{Scx=orya}', "");
Expect(1, 2936, '\p{^Scx=orya}', "");
Expect(1, 2936, '\P{Scx=orya}', "");
Expect(0, 2936, '\P{^Scx=orya}', "");
Expect(1, 2935, '\p{Scx: 	 Orya}', "");
Expect(0, 2935, '\p{^Scx: 	 Orya}', "");
Expect(0, 2935, '\P{Scx: 	 Orya}', "");
Expect(1, 2935, '\P{^Scx: 	 Orya}', "");
Expect(0, 2936, '\p{Scx: 	 Orya}', "");
Expect(1, 2936, '\p{^Scx: 	 Orya}', "");
Expect(1, 2936, '\P{Scx: 	 Orya}', "");
Expect(0, 2936, '\P{^Scx: 	 Orya}', "");
Error('\p{Is_Script_Extensions= :=Oriya}');
Error('\P{Is_Script_Extensions= :=Oriya}');
Expect(1, 2935, '\p{Is_Script_Extensions=oriya}', "");
Expect(0, 2935, '\p{^Is_Script_Extensions=oriya}', "");
Expect(0, 2935, '\P{Is_Script_Extensions=oriya}', "");
Expect(1, 2935, '\P{^Is_Script_Extensions=oriya}', "");
Expect(0, 2936, '\p{Is_Script_Extensions=oriya}', "");
Expect(1, 2936, '\p{^Is_Script_Extensions=oriya}', "");
Expect(1, 2936, '\P{Is_Script_Extensions=oriya}', "");
Expect(0, 2936, '\P{^Is_Script_Extensions=oriya}', "");
Expect(1, 2935, '\p{Is_Script_Extensions=- oriya}', "");
Expect(0, 2935, '\p{^Is_Script_Extensions=- oriya}', "");
Expect(0, 2935, '\P{Is_Script_Extensions=- oriya}', "");
Expect(1, 2935, '\P{^Is_Script_Extensions=- oriya}', "");
Expect(0, 2936, '\p{Is_Script_Extensions=- oriya}', "");
Expect(1, 2936, '\p{^Is_Script_Extensions=- oriya}', "");
Expect(1, 2936, '\P{Is_Script_Extensions=- oriya}', "");
Expect(0, 2936, '\P{^Is_Script_Extensions=- oriya}', "");
Error('\p{Is_Scx=:=-	Orya}');
Error('\P{Is_Scx=:=-	Orya}');
Expect(1, 2935, '\p{Is_Scx=orya}', "");
Expect(0, 2935, '\p{^Is_Scx=orya}', "");
Expect(0, 2935, '\P{Is_Scx=orya}', "");
Expect(1, 2935, '\P{^Is_Scx=orya}', "");
Expect(0, 2936, '\p{Is_Scx=orya}', "");
Expect(1, 2936, '\p{^Is_Scx=orya}', "");
Expect(1, 2936, '\P{Is_Scx=orya}', "");
Expect(0, 2936, '\P{^Is_Scx=orya}', "");
Expect(1, 2935, '\p{Is_Scx=_orya}', "");
Expect(0, 2935, '\p{^Is_Scx=_orya}', "");
Expect(0, 2935, '\P{Is_Scx=_orya}', "");
Expect(1, 2935, '\P{^Is_Scx=_orya}', "");
Expect(0, 2936, '\p{Is_Scx=_orya}', "");
Expect(1, 2936, '\p{^Is_Scx=_orya}', "");
Expect(1, 2936, '\P{Is_Scx=_orya}', "");
Expect(0, 2936, '\P{^Is_Scx=_orya}', "");
Error('\p{Script_Extensions=:=OSMANYA}');
Error('\P{Script_Extensions=:=OSMANYA}');
Expect(1, 66729, '\p{Script_Extensions=osmanya}', "");
Expect(0, 66729, '\p{^Script_Extensions=osmanya}', "");
Expect(0, 66729, '\P{Script_Extensions=osmanya}', "");
Expect(1, 66729, '\P{^Script_Extensions=osmanya}', "");
Expect(0, 66730, '\p{Script_Extensions=osmanya}', "");
Expect(1, 66730, '\p{^Script_Extensions=osmanya}', "");
Expect(1, 66730, '\P{Script_Extensions=osmanya}', "");
Expect(0, 66730, '\P{^Script_Extensions=osmanya}', "");
Expect(1, 66729, '\p{Script_Extensions:   _	Osmanya}', "");
Expect(0, 66729, '\p{^Script_Extensions:   _	Osmanya}', "");
Expect(0, 66729, '\P{Script_Extensions:   _	Osmanya}', "");
Expect(1, 66729, '\P{^Script_Extensions:   _	Osmanya}', "");
Expect(0, 66730, '\p{Script_Extensions:   _	Osmanya}', "");
Expect(1, 66730, '\p{^Script_Extensions:   _	Osmanya}', "");
Expect(1, 66730, '\P{Script_Extensions:   _	Osmanya}', "");
Expect(0, 66730, '\P{^Script_Extensions:   _	Osmanya}', "");
Error('\p{Scx=/a/-	OSMA}');
Error('\P{Scx=/a/-	OSMA}');
Expect(1, 66729, '\p{Scx=osma}', "");
Expect(0, 66729, '\p{^Scx=osma}', "");
Expect(0, 66729, '\P{Scx=osma}', "");
Expect(1, 66729, '\P{^Scx=osma}', "");
Expect(0, 66730, '\p{Scx=osma}', "");
Expect(1, 66730, '\p{^Scx=osma}', "");
Expect(1, 66730, '\P{Scx=osma}', "");
Expect(0, 66730, '\P{^Scx=osma}', "");
Expect(1, 66729, '\p{Scx=- Osma}', "");
Expect(0, 66729, '\p{^Scx=- Osma}', "");
Expect(0, 66729, '\P{Scx=- Osma}', "");
Expect(1, 66729, '\P{^Scx=- Osma}', "");
Expect(0, 66730, '\p{Scx=- Osma}', "");
Expect(1, 66730, '\p{^Scx=- Osma}', "");
Expect(1, 66730, '\P{Scx=- Osma}', "");
Expect(0, 66730, '\P{^Scx=- Osma}', "");
Error('\p{Is_Script_Extensions=:=-_osmanya}');
Error('\P{Is_Script_Extensions=:=-_osmanya}');
Expect(1, 66729, '\p{Is_Script_Extensions=osmanya}', "");
Expect(0, 66729, '\p{^Is_Script_Extensions=osmanya}', "");
Expect(0, 66729, '\P{Is_Script_Extensions=osmanya}', "");
Expect(1, 66729, '\P{^Is_Script_Extensions=osmanya}', "");
Expect(0, 66730, '\p{Is_Script_Extensions=osmanya}', "");
Expect(1, 66730, '\p{^Is_Script_Extensions=osmanya}', "");
Expect(1, 66730, '\P{Is_Script_Extensions=osmanya}', "");
Expect(0, 66730, '\P{^Is_Script_Extensions=osmanya}', "");
Expect(1, 66729, '\p{Is_Script_Extensions=_	Osmanya}', "");
Expect(0, 66729, '\p{^Is_Script_Extensions=_	Osmanya}', "");
Expect(0, 66729, '\P{Is_Script_Extensions=_	Osmanya}', "");
Expect(1, 66729, '\P{^Is_Script_Extensions=_	Osmanya}', "");
Expect(0, 66730, '\p{Is_Script_Extensions=_	Osmanya}', "");
Expect(1, 66730, '\p{^Is_Script_Extensions=_	Osmanya}', "");
Expect(1, 66730, '\P{Is_Script_Extensions=_	Osmanya}', "");
Expect(0, 66730, '\P{^Is_Script_Extensions=_	Osmanya}', "");
Error('\p{Is_Scx=:=-	Osma}');
Error('\P{Is_Scx=:=-	Osma}');
Expect(1, 66729, '\p{Is_Scx=osma}', "");
Expect(0, 66729, '\p{^Is_Scx=osma}', "");
Expect(0, 66729, '\P{Is_Scx=osma}', "");
Expect(1, 66729, '\P{^Is_Scx=osma}', "");
Expect(0, 66730, '\p{Is_Scx=osma}', "");
Expect(1, 66730, '\p{^Is_Scx=osma}', "");
Expect(1, 66730, '\P{Is_Scx=osma}', "");
Expect(0, 66730, '\P{^Is_Scx=osma}', "");
Expect(1, 66729, '\p{Is_Scx=  osma}', "");
Expect(0, 66729, '\p{^Is_Scx=  osma}', "");
Expect(0, 66729, '\P{Is_Scx=  osma}', "");
Expect(1, 66729, '\P{^Is_Scx=  osma}', "");
Expect(0, 66730, '\p{Is_Scx=  osma}', "");
Expect(1, 66730, '\p{^Is_Scx=  osma}', "");
Expect(1, 66730, '\P{Is_Scx=  osma}', "");
Expect(0, 66730, '\P{^Is_Scx=  osma}', "");
Error('\p{Script_Extensions= :=PHAGS_pa}');
Error('\P{Script_Extensions= :=PHAGS_pa}');
Expect(1, 43127, '\p{Script_Extensions=phagspa}', "");
Expect(0, 43127, '\p{^Script_Extensions=phagspa}', "");
Expect(0, 43127, '\P{Script_Extensions=phagspa}', "");
Expect(1, 43127, '\P{^Script_Extensions=phagspa}', "");
Expect(0, 43128, '\p{Script_Extensions=phagspa}', "");
Expect(1, 43128, '\p{^Script_Extensions=phagspa}', "");
Expect(1, 43128, '\P{Script_Extensions=phagspa}', "");
Expect(0, 43128, '\P{^Script_Extensions=phagspa}', "");
Expect(1, 43127, '\p{Script_Extensions=-	phags_pa}', "");
Expect(0, 43127, '\p{^Script_Extensions=-	phags_pa}', "");
Expect(0, 43127, '\P{Script_Extensions=-	phags_pa}', "");
Expect(1, 43127, '\P{^Script_Extensions=-	phags_pa}', "");
Expect(0, 43128, '\p{Script_Extensions=-	phags_pa}', "");
Expect(1, 43128, '\p{^Script_Extensions=-	phags_pa}', "");
Expect(1, 43128, '\P{Script_Extensions=-	phags_pa}', "");
Expect(0, 43128, '\P{^Script_Extensions=-	phags_pa}', "");
Error('\p{Scx=/a/ phag}');
Error('\P{Scx=/a/ phag}');
Expect(1, 43127, '\p{Scx=phag}', "");
Expect(0, 43127, '\p{^Scx=phag}', "");
Expect(0, 43127, '\P{Scx=phag}', "");
Expect(1, 43127, '\P{^Scx=phag}', "");
Expect(0, 43128, '\p{Scx=phag}', "");
Expect(1, 43128, '\p{^Scx=phag}', "");
Expect(1, 43128, '\P{Scx=phag}', "");
Expect(0, 43128, '\P{^Scx=phag}', "");
Expect(1, 43127, '\p{Scx=_ phag}', "");
Expect(0, 43127, '\p{^Scx=_ phag}', "");
Expect(0, 43127, '\P{Scx=_ phag}', "");
Expect(1, 43127, '\P{^Scx=_ phag}', "");
Expect(0, 43128, '\p{Scx=_ phag}', "");
Expect(1, 43128, '\p{^Scx=_ phag}', "");
Expect(1, 43128, '\P{Scx=_ phag}', "");
Expect(0, 43128, '\P{^Scx=_ phag}', "");
Error('\p{Is_Script_Extensions=/a/_	Phags_Pa}');
Error('\P{Is_Script_Extensions=/a/_	Phags_Pa}');
Expect(1, 43127, '\p{Is_Script_Extensions=phagspa}', "");
Expect(0, 43127, '\p{^Is_Script_Extensions=phagspa}', "");
Expect(0, 43127, '\P{Is_Script_Extensions=phagspa}', "");
Expect(1, 43127, '\P{^Is_Script_Extensions=phagspa}', "");
Expect(0, 43128, '\p{Is_Script_Extensions=phagspa}', "");
Expect(1, 43128, '\p{^Is_Script_Extensions=phagspa}', "");
Expect(1, 43128, '\P{Is_Script_Extensions=phagspa}', "");
Expect(0, 43128, '\P{^Is_Script_Extensions=phagspa}', "");
Expect(1, 43127, '\p{Is_Script_Extensions= -Phags_pa}', "");
Expect(0, 43127, '\p{^Is_Script_Extensions= -Phags_pa}', "");
Expect(0, 43127, '\P{Is_Script_Extensions= -Phags_pa}', "");
Expect(1, 43127, '\P{^Is_Script_Extensions= -Phags_pa}', "");
Expect(0, 43128, '\p{Is_Script_Extensions= -Phags_pa}', "");
Expect(1, 43128, '\p{^Is_Script_Extensions= -Phags_pa}', "");
Expect(1, 43128, '\P{Is_Script_Extensions= -Phags_pa}', "");
Expect(0, 43128, '\P{^Is_Script_Extensions= -Phags_pa}', "");
Error('\p{Is_Scx=_:=Phag}');
Error('\P{Is_Scx=_:=Phag}');
Expect(1, 43127, '\p{Is_Scx=phag}', "");
Expect(0, 43127, '\p{^Is_Scx=phag}', "");
Expect(0, 43127, '\P{Is_Scx=phag}', "");
Expect(1, 43127, '\P{^Is_Scx=phag}', "");
Expect(0, 43128, '\p{Is_Scx=phag}', "");
Expect(1, 43128, '\p{^Is_Scx=phag}', "");
Expect(1, 43128, '\P{Is_Scx=phag}', "");
Expect(0, 43128, '\P{^Is_Scx=phag}', "");
Expect(1, 43127, '\p{Is_Scx=  PHAG}', "");
Expect(0, 43127, '\p{^Is_Scx=  PHAG}', "");
Expect(0, 43127, '\P{Is_Scx=  PHAG}', "");
Expect(1, 43127, '\P{^Is_Scx=  PHAG}', "");
Expect(0, 43128, '\p{Is_Scx=  PHAG}', "");
Expect(1, 43128, '\p{^Is_Scx=  PHAG}', "");
Expect(1, 43128, '\P{Is_Scx=  PHAG}', "");
Expect(0, 43128, '\P{^Is_Scx=  PHAG}', "");
Error('\p{Script_Extensions=-	INSCRIPTIONAL_Pahlavi/a/}');
Error('\P{Script_Extensions=-	INSCRIPTIONAL_Pahlavi/a/}');
Expect(1, 68479, '\p{Script_Extensions: inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Script_Extensions: inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Script_Extensions: inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Script_Extensions: inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Script_Extensions: inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Script_Extensions: inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Script_Extensions: inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Script_Extensions: inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(0, 68479, '\p{^Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(0, 68479, '\P{Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(1, 68479, '\P{^Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(0, 68480, '\p{Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(1, 68480, '\p{^Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(1, 68480, '\P{Script_Extensions=-	inscriptional_pahlavi}', "");
Expect(0, 68480, '\P{^Script_Extensions=-	inscriptional_pahlavi}', "");
Error('\p{Scx=:=--Phli}');
Error('\P{Scx=:=--Phli}');
Expect(1, 68479, '\p{Scx=phli}', "");
Expect(0, 68479, '\p{^Scx=phli}', "");
Expect(0, 68479, '\P{Scx=phli}', "");
Expect(1, 68479, '\P{^Scx=phli}', "");
Expect(0, 68480, '\p{Scx=phli}', "");
Expect(1, 68480, '\p{^Scx=phli}', "");
Expect(1, 68480, '\P{Scx=phli}', "");
Expect(0, 68480, '\P{^Scx=phli}', "");
Expect(1, 68479, '\p{Scx= Phli}', "");
Expect(0, 68479, '\p{^Scx= Phli}', "");
Expect(0, 68479, '\P{Scx= Phli}', "");
Expect(1, 68479, '\P{^Scx= Phli}', "");
Expect(0, 68480, '\p{Scx= Phli}', "");
Expect(1, 68480, '\p{^Scx= Phli}', "");
Expect(1, 68480, '\P{Scx= Phli}', "");
Expect(0, 68480, '\P{^Scx= Phli}', "");
Error('\p{Is_Script_Extensions= inscriptional_Pahlavi/a/}');
Error('\P{Is_Script_Extensions= inscriptional_Pahlavi/a/}');
Expect(1, 68479, '\p{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68479, '\p{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68479, '\P{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68479, '\P{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68480, '\p{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68480, '\p{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68480, '\P{Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(0, 68480, '\P{^Is_Script_Extensions=inscriptionalpahlavi}', "");
Expect(1, 68479, '\p{Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(0, 68479, '\p{^Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(0, 68479, '\P{Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(1, 68479, '\P{^Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(0, 68480, '\p{Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(1, 68480, '\p{^Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(1, 68480, '\P{Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Expect(0, 68480, '\P{^Is_Script_Extensions=		INSCRIPTIONAL_pahlavi}', "");
Error('\p{Is_Scx=	/a/PHLI}');
Error('\P{Is_Scx=	/a/PHLI}');
Expect(1, 68479, '\p{Is_Scx=phli}', "");
Expect(0, 68479, '\p{^Is_Scx=phli}', "");
Expect(0, 68479, '\P{Is_Scx=phli}', "");
Expect(1, 68479, '\P{^Is_Scx=phli}', "");
Expect(0, 68480, '\p{Is_Scx=phli}', "");
Expect(1, 68480, '\p{^Is_Scx=phli}', "");
Expect(1, 68480, '\P{Is_Scx=phli}', "");
Expect(0, 68480, '\P{^Is_Scx=phli}', "");
Expect(1, 68479, '\p{Is_Scx= 	phli}', "");
Expect(0, 68479, '\p{^Is_Scx= 	phli}', "");
Expect(0, 68479, '\P{Is_Scx= 	phli}', "");
Expect(1, 68479, '\P{^Is_Scx= 	phli}', "");
Expect(0, 68480, '\p{Is_Scx= 	phli}', "");
Expect(1, 68480, '\p{^Is_Scx= 	phli}', "");
Expect(1, 68480, '\P{Is_Scx= 	phli}', "");
Expect(0, 68480, '\P{^Is_Scx= 	phli}', "");
Error('\p{Script_Extensions=:=_-Phoenician}');
Error('\P{Script_Extensions=:=_-Phoenician}');
Expect(1, 67871, '\p{Script_Extensions:	phoenician}', "");
Expect(0, 67871, '\p{^Script_Extensions:	phoenician}', "");
Expect(0, 67871, '\P{Script_Extensions:	phoenician}', "");
Expect(1, 67871, '\P{^Script_Extensions:	phoenician}', "");
Expect(0, 67872, '\p{Script_Extensions:	phoenician}', "");
Expect(1, 67872, '\p{^Script_Extensions:	phoenician}', "");
Expect(1, 67872, '\P{Script_Extensions:	phoenician}', "");
Expect(0, 67872, '\P{^Script_Extensions:	phoenician}', "");
Expect(1, 67871, '\p{Script_Extensions=	phoenician}', "");
Expect(0, 67871, '\p{^Script_Extensions=	phoenician}', "");
Expect(0, 67871, '\P{Script_Extensions=	phoenician}', "");
Expect(1, 67871, '\P{^Script_Extensions=	phoenician}', "");
Expect(0, 67872, '\p{Script_Extensions=	phoenician}', "");
Expect(1, 67872, '\p{^Script_Extensions=	phoenician}', "");
Expect(1, 67872, '\P{Script_Extensions=	phoenician}', "");
Expect(0, 67872, '\P{^Script_Extensions=	phoenician}', "");
Error('\p{Scx=/a/--PHNX}');
Error('\P{Scx=/a/--PHNX}');
Expect(1, 67871, '\p{Scx=phnx}', "");
Expect(0, 67871, '\p{^Scx=phnx}', "");
Expect(0, 67871, '\P{Scx=phnx}', "");
Expect(1, 67871, '\P{^Scx=phnx}', "");
Expect(0, 67872, '\p{Scx=phnx}', "");
Expect(1, 67872, '\p{^Scx=phnx}', "");
Expect(1, 67872, '\P{Scx=phnx}', "");
Expect(0, 67872, '\P{^Scx=phnx}', "");
Expect(1, 67871, '\p{Scx=Phnx}', "");
Expect(0, 67871, '\p{^Scx=Phnx}', "");
Expect(0, 67871, '\P{Scx=Phnx}', "");
Expect(1, 67871, '\P{^Scx=Phnx}', "");
Expect(0, 67872, '\p{Scx=Phnx}', "");
Expect(1, 67872, '\p{^Scx=Phnx}', "");
Expect(1, 67872, '\P{Scx=Phnx}', "");
Expect(0, 67872, '\P{^Scx=Phnx}', "");
Error('\p{Is_Script_Extensions=_:=Phoenician}');
Error('\P{Is_Script_Extensions=_:=Phoenician}');
Expect(1, 67871, '\p{Is_Script_Extensions=phoenician}', "");
Expect(0, 67871, '\p{^Is_Script_Extensions=phoenician}', "");
Expect(0, 67871, '\P{Is_Script_Extensions=phoenician}', "");
Expect(1, 67871, '\P{^Is_Script_Extensions=phoenician}', "");
Expect(0, 67872, '\p{Is_Script_Extensions=phoenician}', "");
Expect(1, 67872, '\p{^Is_Script_Extensions=phoenician}', "");
Expect(1, 67872, '\P{Is_Script_Extensions=phoenician}', "");
Expect(0, 67872, '\P{^Is_Script_Extensions=phoenician}', "");
Expect(1, 67871, '\p{Is_Script_Extensions= _Phoenician}', "");
Expect(0, 67871, '\p{^Is_Script_Extensions= _Phoenician}', "");
Expect(0, 67871, '\P{Is_Script_Extensions= _Phoenician}', "");
Expect(1, 67871, '\P{^Is_Script_Extensions= _Phoenician}', "");
Expect(0, 67872, '\p{Is_Script_Extensions= _Phoenician}', "");
Expect(1, 67872, '\p{^Is_Script_Extensions= _Phoenician}', "");
Expect(1, 67872, '\P{Is_Script_Extensions= _Phoenician}', "");
Expect(0, 67872, '\P{^Is_Script_Extensions= _Phoenician}', "");
Error('\p{Is_Scx= :=PHNX}');
Error('\P{Is_Scx= :=PHNX}');
Expect(1, 67871, '\p{Is_Scx=phnx}', "");
Expect(0, 67871, '\p{^Is_Scx=phnx}', "");
Expect(0, 67871, '\P{Is_Scx=phnx}', "");
Expect(1, 67871, '\P{^Is_Scx=phnx}', "");
Expect(0, 67872, '\p{Is_Scx=phnx}', "");
Expect(1, 67872, '\p{^Is_Scx=phnx}', "");
Expect(1, 67872, '\P{Is_Scx=phnx}', "");
Expect(0, 67872, '\P{^Is_Scx=phnx}', "");
Expect(1, 67871, '\p{Is_Scx=	_Phnx}', "");
Expect(0, 67871, '\p{^Is_Scx=	_Phnx}', "");
Expect(0, 67871, '\P{Is_Scx=	_Phnx}', "");
Expect(1, 67871, '\P{^Is_Scx=	_Phnx}', "");
Expect(0, 67872, '\p{Is_Scx=	_Phnx}', "");
Expect(1, 67872, '\p{^Is_Scx=	_Phnx}', "");
Expect(1, 67872, '\P{Is_Scx=	_Phnx}', "");
Expect(0, 67872, '\P{^Is_Scx=	_Phnx}', "");
Error('\p{Script_Extensions=/a/Miao}');
Error('\P{Script_Extensions=/a/Miao}');
Expect(1, 94111, '\p{Script_Extensions=miao}', "");
Expect(0, 94111, '\p{^Script_Extensions=miao}', "");
Expect(0, 94111, '\P{Script_Extensions=miao}', "");
Expect(1, 94111, '\P{^Script_Extensions=miao}', "");
Expect(0, 94112, '\p{Script_Extensions=miao}', "");
Expect(1, 94112, '\p{^Script_Extensions=miao}', "");
Expect(1, 94112, '\P{Script_Extensions=miao}', "");
Expect(0, 94112, '\P{^Script_Extensions=miao}', "");
Expect(1, 94111, '\p{Script_Extensions=	_Miao}', "");
Expect(0, 94111, '\p{^Script_Extensions=	_Miao}', "");
Expect(0, 94111, '\P{Script_Extensions=	_Miao}', "");
Expect(1, 94111, '\P{^Script_Extensions=	_Miao}', "");
Expect(0, 94112, '\p{Script_Extensions=	_Miao}', "");
Expect(1, 94112, '\p{^Script_Extensions=	_Miao}', "");
Expect(1, 94112, '\P{Script_Extensions=	_Miao}', "");
Expect(0, 94112, '\P{^Script_Extensions=	_Miao}', "");
Error('\p{Scx:   :=plrd}');
Error('\P{Scx:   :=plrd}');
Expect(1, 94111, '\p{Scx=plrd}', "");
Expect(0, 94111, '\p{^Scx=plrd}', "");
Expect(0, 94111, '\P{Scx=plrd}', "");
Expect(1, 94111, '\P{^Scx=plrd}', "");
Expect(0, 94112, '\p{Scx=plrd}', "");
Expect(1, 94112, '\p{^Scx=plrd}', "");
Expect(1, 94112, '\P{Scx=plrd}', "");
Expect(0, 94112, '\P{^Scx=plrd}', "");
Expect(1, 94111, '\p{Scx=	-PLRD}', "");
Expect(0, 94111, '\p{^Scx=	-PLRD}', "");
Expect(0, 94111, '\P{Scx=	-PLRD}', "");
Expect(1, 94111, '\P{^Scx=	-PLRD}', "");
Expect(0, 94112, '\p{Scx=	-PLRD}', "");
Expect(1, 94112, '\p{^Scx=	-PLRD}', "");
Expect(1, 94112, '\P{Scx=	-PLRD}', "");
Expect(0, 94112, '\P{^Scx=	-PLRD}', "");
Error('\p{Is_Script_Extensions=	Miao:=}');
Error('\P{Is_Script_Extensions=	Miao:=}');
Expect(1, 94111, '\p{Is_Script_Extensions=miao}', "");
Expect(0, 94111, '\p{^Is_Script_Extensions=miao}', "");
Expect(0, 94111, '\P{Is_Script_Extensions=miao}', "");
Expect(1, 94111, '\P{^Is_Script_Extensions=miao}', "");
Expect(0, 94112, '\p{Is_Script_Extensions=miao}', "");
Expect(1, 94112, '\p{^Is_Script_Extensions=miao}', "");
Expect(1, 94112, '\P{Is_Script_Extensions=miao}', "");
Expect(0, 94112, '\P{^Is_Script_Extensions=miao}', "");
Expect(1, 94111, '\p{Is_Script_Extensions=-MIAO}', "");
Expect(0, 94111, '\p{^Is_Script_Extensions=-MIAO}', "");
Expect(0, 94111, '\P{Is_Script_Extensions=-MIAO}', "");
Expect(1, 94111, '\P{^Is_Script_Extensions=-MIAO}', "");
Expect(0, 94112, '\p{Is_Script_Extensions=-MIAO}', "");
Expect(1, 94112, '\p{^Is_Script_Extensions=-MIAO}', "");
Expect(1, 94112, '\P{Is_Script_Extensions=-MIAO}', "");
Expect(0, 94112, '\P{^Is_Script_Extensions=-MIAO}', "");
Error('\p{Is_Scx=:=	PLRD}');
Error('\P{Is_Scx=:=	PLRD}');
Expect(1, 94111, '\p{Is_Scx=plrd}', "");
Expect(0, 94111, '\p{^Is_Scx=plrd}', "");
Expect(0, 94111, '\P{Is_Scx=plrd}', "");
Expect(1, 94111, '\P{^Is_Scx=plrd}', "");
Expect(0, 94112, '\p{Is_Scx=plrd}', "");
Expect(1, 94112, '\p{^Is_Scx=plrd}', "");
Expect(1, 94112, '\P{Is_Scx=plrd}', "");
Expect(0, 94112, '\P{^Is_Scx=plrd}', "");
Expect(1, 94111, '\p{Is_Scx:     Plrd}', "");
Expect(0, 94111, '\p{^Is_Scx:     Plrd}', "");
Expect(0, 94111, '\P{Is_Scx:     Plrd}', "");
Expect(1, 94111, '\P{^Is_Scx:     Plrd}', "");
Expect(0, 94112, '\p{Is_Scx:     Plrd}', "");
Expect(1, 94112, '\p{^Is_Scx:     Plrd}', "");
Expect(1, 94112, '\P{Is_Scx:     Plrd}', "");
Expect(0, 94112, '\P{^Is_Scx:     Plrd}', "");
Error('\p{Script_Extensions=  Inscriptional_parthian:=}');
Error('\P{Script_Extensions=  Inscriptional_parthian:=}');
Expect(1, 68447, '\p{Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Script_Extensions=Inscriptional_Parthian}', "");
Expect(0, 68447, '\p{^Script_Extensions=Inscriptional_Parthian}', "");
Expect(0, 68447, '\P{Script_Extensions=Inscriptional_Parthian}', "");
Expect(1, 68447, '\P{^Script_Extensions=Inscriptional_Parthian}', "");
Expect(0, 68448, '\p{Script_Extensions=Inscriptional_Parthian}', "");
Expect(1, 68448, '\p{^Script_Extensions=Inscriptional_Parthian}', "");
Expect(1, 68448, '\P{Script_Extensions=Inscriptional_Parthian}', "");
Expect(0, 68448, '\P{^Script_Extensions=Inscriptional_Parthian}', "");
Error('\p{Scx=/a/-	Prti}');
Error('\P{Scx=/a/-	Prti}');
Expect(1, 68447, '\p{Scx=prti}', "");
Expect(0, 68447, '\p{^Scx=prti}', "");
Expect(0, 68447, '\P{Scx=prti}', "");
Expect(1, 68447, '\P{^Scx=prti}', "");
Expect(0, 68448, '\p{Scx=prti}', "");
Expect(1, 68448, '\p{^Scx=prti}', "");
Expect(1, 68448, '\P{Scx=prti}', "");
Expect(0, 68448, '\P{^Scx=prti}', "");
Expect(1, 68447, '\p{Scx=-	Prti}', "");
Expect(0, 68447, '\p{^Scx=-	Prti}', "");
Expect(0, 68447, '\P{Scx=-	Prti}', "");
Expect(1, 68447, '\P{^Scx=-	Prti}', "");
Expect(0, 68448, '\p{Scx=-	Prti}', "");
Expect(1, 68448, '\p{^Scx=-	Prti}', "");
Expect(1, 68448, '\P{Scx=-	Prti}', "");
Expect(0, 68448, '\P{^Scx=-	Prti}', "");
Error('\p{Is_Script_Extensions=		inscriptional_PARTHIAN:=}');
Error('\P{Is_Script_Extensions=		inscriptional_PARTHIAN:=}');
Expect(1, 68447, '\p{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\p{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68447, '\P{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\P{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\p{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\p{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68448, '\P{Is_Script_Extensions=inscriptionalparthian}', "");
Expect(0, 68448, '\P{^Is_Script_Extensions=inscriptionalparthian}', "");
Expect(1, 68447, '\p{Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(0, 68447, '\p{^Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(0, 68447, '\P{Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(1, 68447, '\P{^Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(0, 68448, '\p{Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(1, 68448, '\p{^Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(1, 68448, '\P{Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Expect(0, 68448, '\P{^Is_Script_Extensions:    	Inscriptional_Parthian}', "");
Error('\p{Is_Scx=	-Prti/a/}');
Error('\P{Is_Scx=	-Prti/a/}');
Expect(1, 68447, '\p{Is_Scx=prti}', "");
Expect(0, 68447, '\p{^Is_Scx=prti}', "");
Expect(0, 68447, '\P{Is_Scx=prti}', "");
Expect(1, 68447, '\P{^Is_Scx=prti}', "");
Expect(0, 68448, '\p{Is_Scx=prti}', "");
Expect(1, 68448, '\p{^Is_Scx=prti}', "");
Expect(1, 68448, '\P{Is_Scx=prti}', "");
Expect(0, 68448, '\P{^Is_Scx=prti}', "");
Expect(1, 68447, '\p{Is_Scx=  Prti}', "");
Expect(0, 68447, '\p{^Is_Scx=  Prti}', "");
Expect(0, 68447, '\P{Is_Scx=  Prti}', "");
Expect(1, 68447, '\P{^Is_Scx=  Prti}', "");
Expect(0, 68448, '\p{Is_Scx=  Prti}', "");
Expect(1, 68448, '\p{^Is_Scx=  Prti}', "");
Expect(1, 68448, '\P{Is_Scx=  Prti}', "");
Expect(0, 68448, '\P{^Is_Scx=  Prti}', "");
Error('\p{Script_Extensions=/a/-	REJANG}');
Error('\P{Script_Extensions=/a/-	REJANG}');
Expect(1, 43359, '\p{Script_Extensions=rejang}', "");
Expect(0, 43359, '\p{^Script_Extensions=rejang}', "");
Expect(0, 43359, '\P{Script_Extensions=rejang}', "");
Expect(1, 43359, '\P{^Script_Extensions=rejang}', "");
Expect(0, 43360, '\p{Script_Extensions=rejang}', "");
Expect(1, 43360, '\p{^Script_Extensions=rejang}', "");
Expect(1, 43360, '\P{Script_Extensions=rejang}', "");
Expect(0, 43360, '\P{^Script_Extensions=rejang}', "");
Expect(1, 43359, '\p{Script_Extensions=__rejang}', "");
Expect(0, 43359, '\p{^Script_Extensions=__rejang}', "");
Expect(0, 43359, '\P{Script_Extensions=__rejang}', "");
Expect(1, 43359, '\P{^Script_Extensions=__rejang}', "");
Expect(0, 43360, '\p{Script_Extensions=__rejang}', "");
Expect(1, 43360, '\p{^Script_Extensions=__rejang}', "");
Expect(1, 43360, '\P{Script_Extensions=__rejang}', "");
Expect(0, 43360, '\P{^Script_Extensions=__rejang}', "");
Error('\p{Scx=	 RJNG:=}');
Error('\P{Scx=	 RJNG:=}');
Expect(1, 43359, '\p{Scx=rjng}', "");
Expect(0, 43359, '\p{^Scx=rjng}', "");
Expect(0, 43359, '\P{Scx=rjng}', "");
Expect(1, 43359, '\P{^Scx=rjng}', "");
Expect(0, 43360, '\p{Scx=rjng}', "");
Expect(1, 43360, '\p{^Scx=rjng}', "");
Expect(1, 43360, '\P{Scx=rjng}', "");
Expect(0, 43360, '\P{^Scx=rjng}', "");
Expect(1, 43359, '\p{Scx:	__rjng}', "");
Expect(0, 43359, '\p{^Scx:	__rjng}', "");
Expect(0, 43359, '\P{Scx:	__rjng}', "");
Expect(1, 43359, '\P{^Scx:	__rjng}', "");
Expect(0, 43360, '\p{Scx:	__rjng}', "");
Expect(1, 43360, '\p{^Scx:	__rjng}', "");
Expect(1, 43360, '\P{Scx:	__rjng}', "");
Expect(0, 43360, '\P{^Scx:	__rjng}', "");
Error('\p{Is_Script_Extensions=:= rejang}');
Error('\P{Is_Script_Extensions=:= rejang}');
Expect(1, 43359, '\p{Is_Script_Extensions=rejang}', "");
Expect(0, 43359, '\p{^Is_Script_Extensions=rejang}', "");
Expect(0, 43359, '\P{Is_Script_Extensions=rejang}', "");
Expect(1, 43359, '\P{^Is_Script_Extensions=rejang}', "");
Expect(0, 43360, '\p{Is_Script_Extensions=rejang}', "");
Expect(1, 43360, '\p{^Is_Script_Extensions=rejang}', "");
Expect(1, 43360, '\P{Is_Script_Extensions=rejang}', "");
Expect(0, 43360, '\P{^Is_Script_Extensions=rejang}', "");
Expect(1, 43359, '\p{Is_Script_Extensions= Rejang}', "");
Expect(0, 43359, '\p{^Is_Script_Extensions= Rejang}', "");
Expect(0, 43359, '\P{Is_Script_Extensions= Rejang}', "");
Expect(1, 43359, '\P{^Is_Script_Extensions= Rejang}', "");
Expect(0, 43360, '\p{Is_Script_Extensions= Rejang}', "");
Expect(1, 43360, '\p{^Is_Script_Extensions= Rejang}', "");
Expect(1, 43360, '\P{Is_Script_Extensions= Rejang}', "");
Expect(0, 43360, '\P{^Is_Script_Extensions= Rejang}', "");
Error('\p{Is_Scx=	:=Rjng}');
Error('\P{Is_Scx=	:=Rjng}');
Expect(1, 43359, '\p{Is_Scx=rjng}', "");
Expect(0, 43359, '\p{^Is_Scx=rjng}', "");
Expect(0, 43359, '\P{Is_Scx=rjng}', "");
Expect(1, 43359, '\P{^Is_Scx=rjng}', "");
Expect(0, 43360, '\p{Is_Scx=rjng}', "");
Expect(1, 43360, '\p{^Is_Scx=rjng}', "");
Expect(1, 43360, '\P{Is_Scx=rjng}', "");
Expect(0, 43360, '\P{^Is_Scx=rjng}', "");
Expect(1, 43359, '\p{Is_Scx=-	Rjng}', "");
Expect(0, 43359, '\p{^Is_Scx=-	Rjng}', "");
Expect(0, 43359, '\P{Is_Scx=-	Rjng}', "");
Expect(1, 43359, '\P{^Is_Scx=-	Rjng}', "");
Expect(0, 43360, '\p{Is_Scx=-	Rjng}', "");
Expect(1, 43360, '\p{^Is_Scx=-	Rjng}', "");
Expect(1, 43360, '\P{Is_Scx=-	Rjng}', "");
Expect(0, 43360, '\P{^Is_Scx=-	Rjng}', "");
Error('\p{Script_Extensions= /a/runic}');
Error('\P{Script_Extensions= /a/runic}');
Expect(1, 5872, '\p{Script_Extensions=runic}', "");
Expect(0, 5872, '\p{^Script_Extensions=runic}', "");
Expect(0, 5872, '\P{Script_Extensions=runic}', "");
Expect(1, 5872, '\P{^Script_Extensions=runic}', "");
Expect(0, 5873, '\p{Script_Extensions=runic}', "");
Expect(1, 5873, '\p{^Script_Extensions=runic}', "");
Expect(1, 5873, '\P{Script_Extensions=runic}', "");
Expect(0, 5873, '\P{^Script_Extensions=runic}', "");
Expect(1, 5872, '\p{Script_Extensions=Runic}', "");
Expect(0, 5872, '\p{^Script_Extensions=Runic}', "");
Expect(0, 5872, '\P{Script_Extensions=Runic}', "");
Expect(1, 5872, '\P{^Script_Extensions=Runic}', "");
Expect(0, 5873, '\p{Script_Extensions=Runic}', "");
Expect(1, 5873, '\p{^Script_Extensions=Runic}', "");
Expect(1, 5873, '\P{Script_Extensions=Runic}', "");
Expect(0, 5873, '\P{^Script_Extensions=Runic}', "");
Error('\p{Scx=_ Runr:=}');
Error('\P{Scx=_ Runr:=}');
Expect(1, 5872, '\p{Scx=runr}', "");
Expect(0, 5872, '\p{^Scx=runr}', "");
Expect(0, 5872, '\P{Scx=runr}', "");
Expect(1, 5872, '\P{^Scx=runr}', "");
Expect(0, 5873, '\p{Scx=runr}', "");
Expect(1, 5873, '\p{^Scx=runr}', "");
Expect(1, 5873, '\P{Scx=runr}', "");
Expect(0, 5873, '\P{^Scx=runr}', "");
Expect(1, 5872, '\p{Scx:   	 Runr}', "");
Expect(0, 5872, '\p{^Scx:   	 Runr}', "");
Expect(0, 5872, '\P{Scx:   	 Runr}', "");
Expect(1, 5872, '\P{^Scx:   	 Runr}', "");
Expect(0, 5873, '\p{Scx:   	 Runr}', "");
Expect(1, 5873, '\p{^Scx:   	 Runr}', "");
Expect(1, 5873, '\P{Scx:   	 Runr}', "");
Expect(0, 5873, '\P{^Scx:   	 Runr}', "");
Error('\p{Is_Script_Extensions=:=_runic}');
Error('\P{Is_Script_Extensions=:=_runic}');
Expect(1, 5872, '\p{Is_Script_Extensions=runic}', "");
Expect(0, 5872, '\p{^Is_Script_Extensions=runic}', "");
Expect(0, 5872, '\P{Is_Script_Extensions=runic}', "");
Expect(1, 5872, '\P{^Is_Script_Extensions=runic}', "");
Expect(0, 5873, '\p{Is_Script_Extensions=runic}', "");
Expect(1, 5873, '\p{^Is_Script_Extensions=runic}', "");
Expect(1, 5873, '\P{Is_Script_Extensions=runic}', "");
Expect(0, 5873, '\P{^Is_Script_Extensions=runic}', "");
Expect(1, 5872, '\p{Is_Script_Extensions=_ Runic}', "");
Expect(0, 5872, '\p{^Is_Script_Extensions=_ Runic}', "");
Expect(0, 5872, '\P{Is_Script_Extensions=_ Runic}', "");
Expect(1, 5872, '\P{^Is_Script_Extensions=_ Runic}', "");
Expect(0, 5873, '\p{Is_Script_Extensions=_ Runic}', "");
Expect(1, 5873, '\p{^Is_Script_Extensions=_ Runic}', "");
Expect(1, 5873, '\P{Is_Script_Extensions=_ Runic}', "");
Expect(0, 5873, '\P{^Is_Script_Extensions=_ Runic}', "");
Error('\p{Is_Scx=	_Runr/a/}');
Error('\P{Is_Scx=	_Runr/a/}');
Expect(1, 5872, '\p{Is_Scx=runr}', "");
Expect(0, 5872, '\p{^Is_Scx=runr}', "");
Expect(0, 5872, '\P{Is_Scx=runr}', "");
Expect(1, 5872, '\P{^Is_Scx=runr}', "");
Expect(0, 5873, '\p{Is_Scx=runr}', "");
Expect(1, 5873, '\p{^Is_Scx=runr}', "");
Expect(1, 5873, '\P{Is_Scx=runr}', "");
Expect(0, 5873, '\P{^Is_Scx=runr}', "");
Expect(1, 5872, '\p{Is_Scx=	runr}', "");
Expect(0, 5872, '\p{^Is_Scx=	runr}', "");
Expect(0, 5872, '\P{Is_Scx=	runr}', "");
Expect(1, 5872, '\P{^Is_Scx=	runr}', "");
Expect(0, 5873, '\p{Is_Scx=	runr}', "");
Expect(1, 5873, '\p{^Is_Scx=	runr}', "");
Expect(1, 5873, '\P{Is_Scx=	runr}', "");
Expect(0, 5873, '\P{^Is_Scx=	runr}', "");
Error('\p{Script_Extensions=--samaritan/a/}');
Error('\P{Script_Extensions=--samaritan/a/}');
Expect(1, 2110, '\p{Script_Extensions=samaritan}', "");
Expect(0, 2110, '\p{^Script_Extensions=samaritan}', "");
Expect(0, 2110, '\P{Script_Extensions=samaritan}', "");
Expect(1, 2110, '\P{^Script_Extensions=samaritan}', "");
Expect(0, 2111, '\p{Script_Extensions=samaritan}', "");
Expect(1, 2111, '\p{^Script_Extensions=samaritan}', "");
Expect(1, 2111, '\P{Script_Extensions=samaritan}', "");
Expect(0, 2111, '\P{^Script_Extensions=samaritan}', "");
Expect(1, 2110, '\p{Script_Extensions=_Samaritan}', "");
Expect(0, 2110, '\p{^Script_Extensions=_Samaritan}', "");
Expect(0, 2110, '\P{Script_Extensions=_Samaritan}', "");
Expect(1, 2110, '\P{^Script_Extensions=_Samaritan}', "");
Expect(0, 2111, '\p{Script_Extensions=_Samaritan}', "");
Expect(1, 2111, '\p{^Script_Extensions=_Samaritan}', "");
Expect(1, 2111, '\P{Script_Extensions=_Samaritan}', "");
Expect(0, 2111, '\P{^Script_Extensions=_Samaritan}', "");
Error('\p{Scx= :=Samr}');
Error('\P{Scx= :=Samr}');
Expect(1, 2110, '\p{Scx=samr}', "");
Expect(0, 2110, '\p{^Scx=samr}', "");
Expect(0, 2110, '\P{Scx=samr}', "");
Expect(1, 2110, '\P{^Scx=samr}', "");
Expect(0, 2111, '\p{Scx=samr}', "");
Expect(1, 2111, '\p{^Scx=samr}', "");
Expect(1, 2111, '\P{Scx=samr}', "");
Expect(0, 2111, '\P{^Scx=samr}', "");
Expect(1, 2110, '\p{Scx=	-Samr}', "");
Expect(0, 2110, '\p{^Scx=	-Samr}', "");
Expect(0, 2110, '\P{Scx=	-Samr}', "");
Expect(1, 2110, '\P{^Scx=	-Samr}', "");
Expect(0, 2111, '\p{Scx=	-Samr}', "");
Expect(1, 2111, '\p{^Scx=	-Samr}', "");
Expect(1, 2111, '\P{Scx=	-Samr}', "");
Expect(0, 2111, '\P{^Scx=	-Samr}', "");
Error('\p{Is_Script_Extensions= Samaritan:=}');
Error('\P{Is_Script_Extensions= Samaritan:=}');
Expect(1, 2110, '\p{Is_Script_Extensions=samaritan}', "");
Expect(0, 2110, '\p{^Is_Script_Extensions=samaritan}', "");
Expect(0, 2110, '\P{Is_Script_Extensions=samaritan}', "");
Expect(1, 2110, '\P{^Is_Script_Extensions=samaritan}', "");
Expect(0, 2111, '\p{Is_Script_Extensions=samaritan}', "");
Expect(1, 2111, '\p{^Is_Script_Extensions=samaritan}', "");
Expect(1, 2111, '\P{Is_Script_Extensions=samaritan}', "");
Expect(0, 2111, '\P{^Is_Script_Extensions=samaritan}', "");
Expect(1, 2110, '\p{Is_Script_Extensions=	SAMARITAN}', "");
Expect(0, 2110, '\p{^Is_Script_Extensions=	SAMARITAN}', "");
Expect(0, 2110, '\P{Is_Script_Extensions=	SAMARITAN}', "");
Expect(1, 2110, '\P{^Is_Script_Extensions=	SAMARITAN}', "");
Expect(0, 2111, '\p{Is_Script_Extensions=	SAMARITAN}', "");
Expect(1, 2111, '\p{^Is_Script_Extensions=	SAMARITAN}', "");
Expect(1, 2111, '\P{Is_Script_Extensions=	SAMARITAN}', "");
Expect(0, 2111, '\P{^Is_Script_Extensions=	SAMARITAN}', "");
Error('\p{Is_Scx=_/a/samr}');
Error('\P{Is_Scx=_/a/samr}');
Expect(1, 2110, '\p{Is_Scx:	samr}', "");
Expect(0, 2110, '\p{^Is_Scx:	samr}', "");
Expect(0, 2110, '\P{Is_Scx:	samr}', "");
Expect(1, 2110, '\P{^Is_Scx:	samr}', "");
Expect(0, 2111, '\p{Is_Scx:	samr}', "");
Expect(1, 2111, '\p{^Is_Scx:	samr}', "");
Expect(1, 2111, '\P{Is_Scx:	samr}', "");
Expect(0, 2111, '\P{^Is_Scx:	samr}', "");
Expect(1, 2110, '\p{Is_Scx=	-Samr}', "");
Expect(0, 2110, '\p{^Is_Scx=	-Samr}', "");
Expect(0, 2110, '\P{Is_Scx=	-Samr}', "");
Expect(1, 2110, '\P{^Is_Scx=	-Samr}', "");
Expect(0, 2111, '\p{Is_Scx=	-Samr}', "");
Expect(1, 2111, '\p{^Is_Scx=	-Samr}', "");
Expect(1, 2111, '\P{Is_Scx=	-Samr}', "");
Expect(0, 2111, '\P{^Is_Scx=	-Samr}', "");
Error('\p{Script_Extensions=/a/_old_South_arabian}');
Error('\P{Script_Extensions=/a/_old_South_arabian}');
Expect(1, 68223, '\p{Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\P{Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\p{Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\P{Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\p{Script_Extensions= OLD_South_arabian}', "");
Expect(0, 68223, '\p{^Script_Extensions= OLD_South_arabian}', "");
Expect(0, 68223, '\P{Script_Extensions= OLD_South_arabian}', "");
Expect(1, 68223, '\P{^Script_Extensions= OLD_South_arabian}', "");
Expect(0, 68224, '\p{Script_Extensions= OLD_South_arabian}', "");
Expect(1, 68224, '\p{^Script_Extensions= OLD_South_arabian}', "");
Expect(1, 68224, '\P{Script_Extensions= OLD_South_arabian}', "");
Expect(0, 68224, '\P{^Script_Extensions= OLD_South_arabian}', "");
Error('\p{Scx=:=_-Sarb}');
Error('\P{Scx=:=_-Sarb}');
Expect(1, 68223, '\p{Scx=sarb}', "");
Expect(0, 68223, '\p{^Scx=sarb}', "");
Expect(0, 68223, '\P{Scx=sarb}', "");
Expect(1, 68223, '\P{^Scx=sarb}', "");
Expect(0, 68224, '\p{Scx=sarb}', "");
Expect(1, 68224, '\p{^Scx=sarb}', "");
Expect(1, 68224, '\P{Scx=sarb}', "");
Expect(0, 68224, '\P{^Scx=sarb}', "");
Expect(1, 68223, '\p{Scx=_-sarb}', "");
Expect(0, 68223, '\p{^Scx=_-sarb}', "");
Expect(0, 68223, '\P{Scx=_-sarb}', "");
Expect(1, 68223, '\P{^Scx=_-sarb}', "");
Expect(0, 68224, '\p{Scx=_-sarb}', "");
Expect(1, 68224, '\p{^Scx=_-sarb}', "");
Expect(1, 68224, '\P{Scx=_-sarb}', "");
Expect(0, 68224, '\P{^Scx=_-sarb}', "");
Error('\p{Is_Script_Extensions:	_/a/Old_south_arabian}');
Error('\P{Is_Script_Extensions:	_/a/Old_south_arabian}');
Expect(1, 68223, '\p{Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\p{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68223, '\P{Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\P{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\p{Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\p{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68224, '\P{Is_Script_Extensions=oldsoutharabian}', "");
Expect(0, 68224, '\P{^Is_Script_Extensions=oldsoutharabian}', "");
Expect(1, 68223, '\p{Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(0, 68223, '\p{^Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(0, 68223, '\P{Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(1, 68223, '\P{^Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(0, 68224, '\p{Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(1, 68224, '\p{^Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(1, 68224, '\P{Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Expect(0, 68224, '\P{^Is_Script_Extensions:	_OLD_SOUTH_Arabian}', "");
Error('\p{Is_Scx=/a/- sarb}');
Error('\P{Is_Scx=/a/- sarb}');
Expect(1, 68223, '\p{Is_Scx:   sarb}', "");
Expect(0, 68223, '\p{^Is_Scx:   sarb}', "");
Expect(0, 68223, '\P{Is_Scx:   sarb}', "");
Expect(1, 68223, '\P{^Is_Scx:   sarb}', "");
Expect(0, 68224, '\p{Is_Scx:   sarb}', "");
Expect(1, 68224, '\p{^Is_Scx:   sarb}', "");
Expect(1, 68224, '\P{Is_Scx:   sarb}', "");
Expect(0, 68224, '\P{^Is_Scx:   sarb}', "");
Expect(1, 68223, '\p{Is_Scx=__Sarb}', "");
Expect(0, 68223, '\p{^Is_Scx=__Sarb}', "");
Expect(0, 68223, '\P{Is_Scx=__Sarb}', "");
Expect(1, 68223, '\P{^Is_Scx=__Sarb}', "");
Expect(0, 68224, '\p{Is_Scx=__Sarb}', "");
Expect(1, 68224, '\p{^Is_Scx=__Sarb}', "");
Expect(1, 68224, '\P{Is_Scx=__Sarb}', "");
Expect(0, 68224, '\P{^Is_Scx=__Sarb}', "");
Error('\p{Script_Extensions=	_saurashtra:=}');
Error('\P{Script_Extensions=	_saurashtra:=}');
Expect(1, 43225, '\p{Script_Extensions=saurashtra}', "");
Expect(0, 43225, '\p{^Script_Extensions=saurashtra}', "");
Expect(0, 43225, '\P{Script_Extensions=saurashtra}', "");
Expect(1, 43225, '\P{^Script_Extensions=saurashtra}', "");
Expect(0, 43226, '\p{Script_Extensions=saurashtra}', "");
Expect(1, 43226, '\p{^Script_Extensions=saurashtra}', "");
Expect(1, 43226, '\P{Script_Extensions=saurashtra}', "");
Expect(0, 43226, '\P{^Script_Extensions=saurashtra}', "");
Expect(1, 43225, '\p{Script_Extensions=-SAURASHTRA}', "");
Expect(0, 43225, '\p{^Script_Extensions=-SAURASHTRA}', "");
Expect(0, 43225, '\P{Script_Extensions=-SAURASHTRA}', "");
Expect(1, 43225, '\P{^Script_Extensions=-SAURASHTRA}', "");
Expect(0, 43226, '\p{Script_Extensions=-SAURASHTRA}', "");
Expect(1, 43226, '\p{^Script_Extensions=-SAURASHTRA}', "");
Expect(1, 43226, '\P{Script_Extensions=-SAURASHTRA}', "");
Expect(0, 43226, '\P{^Script_Extensions=-SAURASHTRA}', "");
Error('\p{Scx=_:=Saur}');
Error('\P{Scx=_:=Saur}');
Expect(1, 43225, '\p{Scx=saur}', "");
Expect(0, 43225, '\p{^Scx=saur}', "");
Expect(0, 43225, '\P{Scx=saur}', "");
Expect(1, 43225, '\P{^Scx=saur}', "");
Expect(0, 43226, '\p{Scx=saur}', "");
Expect(1, 43226, '\p{^Scx=saur}', "");
Expect(1, 43226, '\P{Scx=saur}', "");
Expect(0, 43226, '\P{^Scx=saur}', "");
Expect(1, 43225, '\p{Scx=__SAUR}', "");
Expect(0, 43225, '\p{^Scx=__SAUR}', "");
Expect(0, 43225, '\P{Scx=__SAUR}', "");
Expect(1, 43225, '\P{^Scx=__SAUR}', "");
Expect(0, 43226, '\p{Scx=__SAUR}', "");
Expect(1, 43226, '\p{^Scx=__SAUR}', "");
Expect(1, 43226, '\P{Scx=__SAUR}', "");
Expect(0, 43226, '\P{^Scx=__SAUR}', "");
Error('\p{Is_Script_Extensions=:=-	saurashtra}');
Error('\P{Is_Script_Extensions=:=-	saurashtra}');
Expect(1, 43225, '\p{Is_Script_Extensions:	saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script_Extensions:	saurashtra}', "");
Expect(0, 43225, '\P{Is_Script_Extensions:	saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script_Extensions:	saurashtra}', "");
Expect(0, 43226, '\p{Is_Script_Extensions:	saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script_Extensions:	saurashtra}', "");
Expect(1, 43226, '\P{Is_Script_Extensions:	saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script_Extensions:	saurashtra}', "");
Expect(1, 43225, '\p{Is_Script_Extensions= Saurashtra}', "");
Expect(0, 43225, '\p{^Is_Script_Extensions= Saurashtra}', "");
Expect(0, 43225, '\P{Is_Script_Extensions= Saurashtra}', "");
Expect(1, 43225, '\P{^Is_Script_Extensions= Saurashtra}', "");
Expect(0, 43226, '\p{Is_Script_Extensions= Saurashtra}', "");
Expect(1, 43226, '\p{^Is_Script_Extensions= Saurashtra}', "");
Expect(1, 43226, '\P{Is_Script_Extensions= Saurashtra}', "");
Expect(0, 43226, '\P{^Is_Script_Extensions= Saurashtra}', "");
Error('\p{Is_Scx=/a/_Saur}');
Error('\P{Is_Scx=/a/_Saur}');
Expect(1, 43225, '\p{Is_Scx=saur}', "");
Expect(0, 43225, '\p{^Is_Scx=saur}', "");
Expect(0, 43225, '\P{Is_Scx=saur}', "");
Expect(1, 43225, '\P{^Is_Scx=saur}', "");
Expect(0, 43226, '\p{Is_Scx=saur}', "");
Expect(1, 43226, '\p{^Is_Scx=saur}', "");
Expect(1, 43226, '\P{Is_Scx=saur}', "");
Expect(0, 43226, '\P{^Is_Scx=saur}', "");
Expect(1, 43225, '\p{Is_Scx= SAUR}', "");
Expect(0, 43225, '\p{^Is_Scx= SAUR}', "");
Expect(0, 43225, '\P{Is_Scx= SAUR}', "");
Expect(1, 43225, '\P{^Is_Scx= SAUR}', "");
Expect(0, 43226, '\p{Is_Scx= SAUR}', "");
Expect(1, 43226, '\p{^Is_Scx= SAUR}', "");
Expect(1, 43226, '\P{Is_Scx= SAUR}', "");
Expect(0, 43226, '\P{^Is_Scx= SAUR}', "");
Error('\p{Script_Extensions=	/a/SHAVIAN}');
Error('\P{Script_Extensions=	/a/SHAVIAN}');
Expect(1, 66687, '\p{Script_Extensions=shavian}', "");
Expect(0, 66687, '\p{^Script_Extensions=shavian}', "");
Expect(0, 66687, '\P{Script_Extensions=shavian}', "");
Expect(1, 66687, '\P{^Script_Extensions=shavian}', "");
Expect(0, 66688, '\p{Script_Extensions=shavian}', "");
Expect(1, 66688, '\p{^Script_Extensions=shavian}', "");
Expect(1, 66688, '\P{Script_Extensions=shavian}', "");
Expect(0, 66688, '\P{^Script_Extensions=shavian}', "");
Expect(1, 66687, '\p{Script_Extensions=_	Shavian}', "");
Expect(0, 66687, '\p{^Script_Extensions=_	Shavian}', "");
Expect(0, 66687, '\P{Script_Extensions=_	Shavian}', "");
Expect(1, 66687, '\P{^Script_Extensions=_	Shavian}', "");
Expect(0, 66688, '\p{Script_Extensions=_	Shavian}', "");
Expect(1, 66688, '\p{^Script_Extensions=_	Shavian}', "");
Expect(1, 66688, '\P{Script_Extensions=_	Shavian}', "");
Expect(0, 66688, '\P{^Script_Extensions=_	Shavian}', "");
Error('\p{Scx=-shaw/a/}');
Error('\P{Scx=-shaw/a/}');
Expect(1, 66687, '\p{Scx=shaw}', "");
Expect(0, 66687, '\p{^Scx=shaw}', "");
Expect(0, 66687, '\P{Scx=shaw}', "");
Expect(1, 66687, '\P{^Scx=shaw}', "");
Expect(0, 66688, '\p{Scx=shaw}', "");
Expect(1, 66688, '\p{^Scx=shaw}', "");
Expect(1, 66688, '\P{Scx=shaw}', "");
Expect(0, 66688, '\P{^Scx=shaw}', "");
Expect(1, 66687, '\p{Scx=	SHAW}', "");
Expect(0, 66687, '\p{^Scx=	SHAW}', "");
Expect(0, 66687, '\P{Scx=	SHAW}', "");
Expect(1, 66687, '\P{^Scx=	SHAW}', "");
Expect(0, 66688, '\p{Scx=	SHAW}', "");
Expect(1, 66688, '\p{^Scx=	SHAW}', "");
Expect(1, 66688, '\P{Scx=	SHAW}', "");
Expect(0, 66688, '\P{^Scx=	SHAW}', "");
Error('\p{Is_Script_Extensions= _shavian/a/}');
Error('\P{Is_Script_Extensions= _shavian/a/}');
Expect(1, 66687, '\p{Is_Script_Extensions=shavian}', "");
Expect(0, 66687, '\p{^Is_Script_Extensions=shavian}', "");
Expect(0, 66687, '\P{Is_Script_Extensions=shavian}', "");
Expect(1, 66687, '\P{^Is_Script_Extensions=shavian}', "");
Expect(0, 66688, '\p{Is_Script_Extensions=shavian}', "");
Expect(1, 66688, '\p{^Is_Script_Extensions=shavian}', "");
Expect(1, 66688, '\P{Is_Script_Extensions=shavian}', "");
Expect(0, 66688, '\P{^Is_Script_Extensions=shavian}', "");
Expect(1, 66687, '\p{Is_Script_Extensions=__Shavian}', "");
Expect(0, 66687, '\p{^Is_Script_Extensions=__Shavian}', "");
Expect(0, 66687, '\P{Is_Script_Extensions=__Shavian}', "");
Expect(1, 66687, '\P{^Is_Script_Extensions=__Shavian}', "");
Expect(0, 66688, '\p{Is_Script_Extensions=__Shavian}', "");
Expect(1, 66688, '\p{^Is_Script_Extensions=__Shavian}', "");
Expect(1, 66688, '\P{Is_Script_Extensions=__Shavian}', "");
Expect(0, 66688, '\P{^Is_Script_Extensions=__Shavian}', "");
Error('\p{Is_Scx:	SHAW:=}');
Error('\P{Is_Scx:	SHAW:=}');
Expect(1, 66687, '\p{Is_Scx=shaw}', "");
Expect(0, 66687, '\p{^Is_Scx=shaw}', "");
Expect(0, 66687, '\P{Is_Scx=shaw}', "");
Expect(1, 66687, '\P{^Is_Scx=shaw}', "");
Expect(0, 66688, '\p{Is_Scx=shaw}', "");
Expect(1, 66688, '\p{^Is_Scx=shaw}', "");
Expect(1, 66688, '\P{Is_Scx=shaw}', "");
Expect(0, 66688, '\P{^Is_Scx=shaw}', "");
Expect(1, 66687, '\p{Is_Scx=_Shaw}', "");
Expect(0, 66687, '\p{^Is_Scx=_Shaw}', "");
Expect(0, 66687, '\P{Is_Scx=_Shaw}', "");
Expect(1, 66687, '\P{^Is_Scx=_Shaw}', "");
Expect(0, 66688, '\p{Is_Scx=_Shaw}', "");
Expect(1, 66688, '\p{^Is_Scx=_Shaw}', "");
Expect(1, 66688, '\P{Is_Scx=_Shaw}', "");
Expect(0, 66688, '\P{^Is_Scx=_Shaw}', "");
Error('\p{Script_Extensions= :=Sharada}');
Error('\P{Script_Extensions= :=Sharada}');
Expect(1, 70105, '\p{Script_Extensions=sharada}', "");
Expect(0, 70105, '\p{^Script_Extensions=sharada}', "");
Expect(0, 70105, '\P{Script_Extensions=sharada}', "");
Expect(1, 70105, '\P{^Script_Extensions=sharada}', "");
Expect(0, 70106, '\p{Script_Extensions=sharada}', "");
Expect(1, 70106, '\p{^Script_Extensions=sharada}', "");
Expect(1, 70106, '\P{Script_Extensions=sharada}', "");
Expect(0, 70106, '\P{^Script_Extensions=sharada}', "");
Expect(1, 70105, '\p{Script_Extensions:	_-Sharada}', "");
Expect(0, 70105, '\p{^Script_Extensions:	_-Sharada}', "");
Expect(0, 70105, '\P{Script_Extensions:	_-Sharada}', "");
Expect(1, 70105, '\P{^Script_Extensions:	_-Sharada}', "");
Expect(0, 70106, '\p{Script_Extensions:	_-Sharada}', "");
Expect(1, 70106, '\p{^Script_Extensions:	_-Sharada}', "");
Expect(1, 70106, '\P{Script_Extensions:	_-Sharada}', "");
Expect(0, 70106, '\P{^Script_Extensions:	_-Sharada}', "");
Error('\p{Scx=/a/-SHRD}');
Error('\P{Scx=/a/-SHRD}');
Expect(1, 70105, '\p{Scx=shrd}', "");
Expect(0, 70105, '\p{^Scx=shrd}', "");
Expect(0, 70105, '\P{Scx=shrd}', "");
Expect(1, 70105, '\P{^Scx=shrd}', "");
Expect(0, 70106, '\p{Scx=shrd}', "");
Expect(1, 70106, '\p{^Scx=shrd}', "");
Expect(1, 70106, '\P{Scx=shrd}', "");
Expect(0, 70106, '\P{^Scx=shrd}', "");
Expect(1, 70105, '\p{Scx=_-shrd}', "");
Expect(0, 70105, '\p{^Scx=_-shrd}', "");
Expect(0, 70105, '\P{Scx=_-shrd}', "");
Expect(1, 70105, '\P{^Scx=_-shrd}', "");
Expect(0, 70106, '\p{Scx=_-shrd}', "");
Expect(1, 70106, '\p{^Scx=_-shrd}', "");
Expect(1, 70106, '\P{Scx=_-shrd}', "");
Expect(0, 70106, '\P{^Scx=_-shrd}', "");
Error('\p{Is_Script_Extensions=:=Sharada}');
Error('\P{Is_Script_Extensions=:=Sharada}');
Expect(1, 70105, '\p{Is_Script_Extensions=sharada}', "");
Expect(0, 70105, '\p{^Is_Script_Extensions=sharada}', "");
Expect(0, 70105, '\P{Is_Script_Extensions=sharada}', "");
Expect(1, 70105, '\P{^Is_Script_Extensions=sharada}', "");
Expect(0, 70106, '\p{Is_Script_Extensions=sharada}', "");
Expect(1, 70106, '\p{^Is_Script_Extensions=sharada}', "");
Expect(1, 70106, '\P{Is_Script_Extensions=sharada}', "");
Expect(0, 70106, '\P{^Is_Script_Extensions=sharada}', "");
Expect(1, 70105, '\p{Is_Script_Extensions= _Sharada}', "");
Expect(0, 70105, '\p{^Is_Script_Extensions= _Sharada}', "");
Expect(0, 70105, '\P{Is_Script_Extensions= _Sharada}', "");
Expect(1, 70105, '\P{^Is_Script_Extensions= _Sharada}', "");
Expect(0, 70106, '\p{Is_Script_Extensions= _Sharada}', "");
Expect(1, 70106, '\p{^Is_Script_Extensions= _Sharada}', "");
Expect(1, 70106, '\P{Is_Script_Extensions= _Sharada}', "");
Expect(0, 70106, '\P{^Is_Script_Extensions= _Sharada}', "");
Error('\p{Is_Scx=:= _SHRD}');
Error('\P{Is_Scx=:= _SHRD}');
Expect(1, 70105, '\p{Is_Scx=shrd}', "");
Expect(0, 70105, '\p{^Is_Scx=shrd}', "");
Expect(0, 70105, '\P{Is_Scx=shrd}', "");
Expect(1, 70105, '\P{^Is_Scx=shrd}', "");
Expect(0, 70106, '\p{Is_Scx=shrd}', "");
Expect(1, 70106, '\p{^Is_Scx=shrd}', "");
Expect(1, 70106, '\P{Is_Scx=shrd}', "");
Expect(0, 70106, '\P{^Is_Scx=shrd}', "");
Expect(1, 70105, '\p{Is_Scx=-	Shrd}', "");
Expect(0, 70105, '\p{^Is_Scx=-	Shrd}', "");
Expect(0, 70105, '\P{Is_Scx=-	Shrd}', "");
Expect(1, 70105, '\P{^Is_Scx=-	Shrd}', "");
Expect(0, 70106, '\p{Is_Scx=-	Shrd}', "");
Expect(1, 70106, '\p{^Is_Scx=-	Shrd}', "");
Expect(1, 70106, '\P{Is_Scx=-	Shrd}', "");
Expect(0, 70106, '\P{^Is_Scx=-	Shrd}', "");
Error('\p{Script_Extensions=-/a/Sinhala}');
Error('\P{Script_Extensions=-/a/Sinhala}');
Expect(1, 3572, '\p{Script_Extensions=sinhala}', "");
Expect(0, 3572, '\p{^Script_Extensions=sinhala}', "");
Expect(0, 3572, '\P{Script_Extensions=sinhala}', "");
Expect(1, 3572, '\P{^Script_Extensions=sinhala}', "");
Expect(0, 3573, '\p{Script_Extensions=sinhala}', "");
Expect(1, 3573, '\p{^Script_Extensions=sinhala}', "");
Expect(1, 3573, '\P{Script_Extensions=sinhala}', "");
Expect(0, 3573, '\P{^Script_Extensions=sinhala}', "");
Expect(1, 3572, '\p{Script_Extensions=	_Sinhala}', "");
Expect(0, 3572, '\p{^Script_Extensions=	_Sinhala}', "");
Expect(0, 3572, '\P{Script_Extensions=	_Sinhala}', "");
Expect(1, 3572, '\P{^Script_Extensions=	_Sinhala}', "");
Expect(0, 3573, '\p{Script_Extensions=	_Sinhala}', "");
Expect(1, 3573, '\p{^Script_Extensions=	_Sinhala}', "");
Expect(1, 3573, '\P{Script_Extensions=	_Sinhala}', "");
Expect(0, 3573, '\P{^Script_Extensions=	_Sinhala}', "");
Error('\p{Scx=/a/sinh}');
Error('\P{Scx=/a/sinh}');
Expect(1, 3572, '\p{Scx=sinh}', "");
Expect(0, 3572, '\p{^Scx=sinh}', "");
Expect(0, 3572, '\P{Scx=sinh}', "");
Expect(1, 3572, '\P{^Scx=sinh}', "");
Expect(0, 3573, '\p{Scx=sinh}', "");
Expect(1, 3573, '\p{^Scx=sinh}', "");
Expect(1, 3573, '\P{Scx=sinh}', "");
Expect(0, 3573, '\P{^Scx=sinh}', "");
Expect(1, 3572, '\p{Scx:   --Sinh}', "");
Expect(0, 3572, '\p{^Scx:   --Sinh}', "");
Expect(0, 3572, '\P{Scx:   --Sinh}', "");
Expect(1, 3572, '\P{^Scx:   --Sinh}', "");
Expect(0, 3573, '\p{Scx:   --Sinh}', "");
Expect(1, 3573, '\p{^Scx:   --Sinh}', "");
Expect(1, 3573, '\P{Scx:   --Sinh}', "");
Expect(0, 3573, '\P{^Scx:   --Sinh}', "");
Error('\p{Is_Script_Extensions=/a/	_sinhala}');
Error('\P{Is_Script_Extensions=/a/	_sinhala}');
Expect(1, 3572, '\p{Is_Script_Extensions=sinhala}', "");
Expect(0, 3572, '\p{^Is_Script_Extensions=sinhala}', "");
Expect(0, 3572, '\P{Is_Script_Extensions=sinhala}', "");
Expect(1, 3572, '\P{^Is_Script_Extensions=sinhala}', "");
Expect(0, 3573, '\p{Is_Script_Extensions=sinhala}', "");
Expect(1, 3573, '\p{^Is_Script_Extensions=sinhala}', "");
Expect(1, 3573, '\P{Is_Script_Extensions=sinhala}', "");
Expect(0, 3573, '\P{^Is_Script_Extensions=sinhala}', "");
Expect(1, 3572, '\p{Is_Script_Extensions=	_sinhala}', "");
Expect(0, 3572, '\p{^Is_Script_Extensions=	_sinhala}', "");
Expect(0, 3572, '\P{Is_Script_Extensions=	_sinhala}', "");
Expect(1, 3572, '\P{^Is_Script_Extensions=	_sinhala}', "");
Expect(0, 3573, '\p{Is_Script_Extensions=	_sinhala}', "");
Expect(1, 3573, '\p{^Is_Script_Extensions=	_sinhala}', "");
Expect(1, 3573, '\P{Is_Script_Extensions=	_sinhala}', "");
Expect(0, 3573, '\P{^Is_Script_Extensions=	_sinhala}', "");
Error('\p{Is_Scx=:=	 sinh}');
Error('\P{Is_Scx=:=	 sinh}');
Expect(1, 3572, '\p{Is_Scx=sinh}', "");
Expect(0, 3572, '\p{^Is_Scx=sinh}', "");
Expect(0, 3572, '\P{Is_Scx=sinh}', "");
Expect(1, 3572, '\P{^Is_Scx=sinh}', "");
Expect(0, 3573, '\p{Is_Scx=sinh}', "");
Expect(1, 3573, '\p{^Is_Scx=sinh}', "");
Expect(1, 3573, '\P{Is_Scx=sinh}', "");
Expect(0, 3573, '\P{^Is_Scx=sinh}', "");
Expect(1, 3572, '\p{Is_Scx=--SINH}', "");
Expect(0, 3572, '\p{^Is_Scx=--SINH}', "");
Expect(0, 3572, '\P{Is_Scx=--SINH}', "");
Expect(1, 3572, '\P{^Is_Scx=--SINH}', "");
Expect(0, 3573, '\p{Is_Scx=--SINH}', "");
Expect(1, 3573, '\p{^Is_Scx=--SINH}', "");
Expect(1, 3573, '\P{Is_Scx=--SINH}', "");
Expect(0, 3573, '\P{^Is_Scx=--SINH}', "");
Error('\p{Script_Extensions=-Sora_SOMPENG:=}');
Error('\P{Script_Extensions=-Sora_SOMPENG:=}');
Expect(1, 69881, '\p{Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\p{^Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\P{Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\P{^Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\p{Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\p{^Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\P{Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\P{^Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\p{Script_Extensions=__Sora_SOMPENG}', "");
Expect(0, 69881, '\p{^Script_Extensions=__Sora_SOMPENG}', "");
Expect(0, 69881, '\P{Script_Extensions=__Sora_SOMPENG}', "");
Expect(1, 69881, '\P{^Script_Extensions=__Sora_SOMPENG}', "");
Expect(0, 69882, '\p{Script_Extensions=__Sora_SOMPENG}', "");
Expect(1, 69882, '\p{^Script_Extensions=__Sora_SOMPENG}', "");
Expect(1, 69882, '\P{Script_Extensions=__Sora_SOMPENG}', "");
Expect(0, 69882, '\P{^Script_Extensions=__Sora_SOMPENG}', "");
Error('\p{Scx=:=-Sora}');
Error('\P{Scx=:=-Sora}');
Expect(1, 69881, '\p{Scx:   sora}', "");
Expect(0, 69881, '\p{^Scx:   sora}', "");
Expect(0, 69881, '\P{Scx:   sora}', "");
Expect(1, 69881, '\P{^Scx:   sora}', "");
Expect(0, 69882, '\p{Scx:   sora}', "");
Expect(1, 69882, '\p{^Scx:   sora}', "");
Expect(1, 69882, '\P{Scx:   sora}', "");
Expect(0, 69882, '\P{^Scx:   sora}', "");
Expect(1, 69881, '\p{Scx=_	SORA}', "");
Expect(0, 69881, '\p{^Scx=_	SORA}', "");
Expect(0, 69881, '\P{Scx=_	SORA}', "");
Expect(1, 69881, '\P{^Scx=_	SORA}', "");
Expect(0, 69882, '\p{Scx=_	SORA}', "");
Expect(1, 69882, '\p{^Scx=_	SORA}', "");
Expect(1, 69882, '\P{Scx=_	SORA}', "");
Expect(0, 69882, '\P{^Scx=_	SORA}', "");
Error('\p{Is_Script_Extensions=-:=Sora_sompeng}');
Error('\P{Is_Script_Extensions=-:=Sora_sompeng}');
Expect(1, 69881, '\p{Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\p{^Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69881, '\P{Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\P{^Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\p{Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\p{^Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69882, '\P{Is_Script_Extensions=sorasompeng}', "");
Expect(0, 69882, '\P{^Is_Script_Extensions=sorasompeng}', "");
Expect(1, 69881, '\p{Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(0, 69881, '\p{^Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(0, 69881, '\P{Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(1, 69881, '\P{^Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(0, 69882, '\p{Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(1, 69882, '\p{^Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(1, 69882, '\P{Is_Script_Extensions=_SORA_SOMPENG}', "");
Expect(0, 69882, '\P{^Is_Script_Extensions=_SORA_SOMPENG}', "");
Error('\p{Is_Scx=:= 	SORA}');
Error('\P{Is_Scx=:= 	SORA}');
Expect(1, 69881, '\p{Is_Scx=sora}', "");
Expect(0, 69881, '\p{^Is_Scx=sora}', "");
Expect(0, 69881, '\P{Is_Scx=sora}', "");
Expect(1, 69881, '\P{^Is_Scx=sora}', "");
Expect(0, 69882, '\p{Is_Scx=sora}', "");
Expect(1, 69882, '\p{^Is_Scx=sora}', "");
Expect(1, 69882, '\P{Is_Scx=sora}', "");
Expect(0, 69882, '\P{^Is_Scx=sora}', "");
Expect(1, 69881, '\p{Is_Scx=	Sora}', "");
Expect(0, 69881, '\p{^Is_Scx=	Sora}', "");
Expect(0, 69881, '\P{Is_Scx=	Sora}', "");
Expect(1, 69881, '\P{^Is_Scx=	Sora}', "");
Expect(0, 69882, '\p{Is_Scx=	Sora}', "");
Expect(1, 69882, '\p{^Is_Scx=	Sora}', "");
Expect(1, 69882, '\P{Is_Scx=	Sora}', "");
Expect(0, 69882, '\P{^Is_Scx=	Sora}', "");
Error('\p{Script_Extensions= :=Sundanese}');
Error('\P{Script_Extensions= :=Sundanese}');
Expect(1, 7367, '\p{Script_Extensions=sundanese}', "");
Expect(0, 7367, '\p{^Script_Extensions=sundanese}', "");
Expect(0, 7367, '\P{Script_Extensions=sundanese}', "");
Expect(1, 7367, '\P{^Script_Extensions=sundanese}', "");
Expect(0, 7368, '\p{Script_Extensions=sundanese}', "");
Expect(1, 7368, '\p{^Script_Extensions=sundanese}', "");
Expect(1, 7368, '\P{Script_Extensions=sundanese}', "");
Expect(0, 7368, '\P{^Script_Extensions=sundanese}', "");
Expect(1, 7367, '\p{Script_Extensions=_sundanese}', "");
Expect(0, 7367, '\p{^Script_Extensions=_sundanese}', "");
Expect(0, 7367, '\P{Script_Extensions=_sundanese}', "");
Expect(1, 7367, '\P{^Script_Extensions=_sundanese}', "");
Expect(0, 7368, '\p{Script_Extensions=_sundanese}', "");
Expect(1, 7368, '\p{^Script_Extensions=_sundanese}', "");
Expect(1, 7368, '\P{Script_Extensions=_sundanese}', "");
Expect(0, 7368, '\P{^Script_Extensions=_sundanese}', "");
Error('\p{Scx=/a/ _Sund}');
Error('\P{Scx=/a/ _Sund}');
Expect(1, 7367, '\p{Scx=sund}', "");
Expect(0, 7367, '\p{^Scx=sund}', "");
Expect(0, 7367, '\P{Scx=sund}', "");
Expect(1, 7367, '\P{^Scx=sund}', "");
Expect(0, 7368, '\p{Scx=sund}', "");
Expect(1, 7368, '\p{^Scx=sund}', "");
Expect(1, 7368, '\P{Scx=sund}', "");
Expect(0, 7368, '\P{^Scx=sund}', "");
Expect(1, 7367, '\p{Scx=_ Sund}', "");
Expect(0, 7367, '\p{^Scx=_ Sund}', "");
Expect(0, 7367, '\P{Scx=_ Sund}', "");
Expect(1, 7367, '\P{^Scx=_ Sund}', "");
Expect(0, 7368, '\p{Scx=_ Sund}', "");
Expect(1, 7368, '\p{^Scx=_ Sund}', "");
Expect(1, 7368, '\P{Scx=_ Sund}', "");
Expect(0, 7368, '\P{^Scx=_ Sund}', "");
Error('\p{Is_Script_Extensions= :=Sundanese}');
Error('\P{Is_Script_Extensions= :=Sundanese}');
Expect(1, 7367, '\p{Is_Script_Extensions=sundanese}', "");
Expect(0, 7367, '\p{^Is_Script_Extensions=sundanese}', "");
Expect(0, 7367, '\P{Is_Script_Extensions=sundanese}', "");
Expect(1, 7367, '\P{^Is_Script_Extensions=sundanese}', "");
Expect(0, 7368, '\p{Is_Script_Extensions=sundanese}', "");
Expect(1, 7368, '\p{^Is_Script_Extensions=sundanese}', "");
Expect(1, 7368, '\P{Is_Script_Extensions=sundanese}', "");
Expect(0, 7368, '\P{^Is_Script_Extensions=sundanese}', "");
Expect(1, 7367, '\p{Is_Script_Extensions=_Sundanese}', "");
Expect(0, 7367, '\p{^Is_Script_Extensions=_Sundanese}', "");
Expect(0, 7367, '\P{Is_Script_Extensions=_Sundanese}', "");
Expect(1, 7367, '\P{^Is_Script_Extensions=_Sundanese}', "");
Expect(0, 7368, '\p{Is_Script_Extensions=_Sundanese}', "");
Expect(1, 7368, '\p{^Is_Script_Extensions=_Sundanese}', "");
Expect(1, 7368, '\P{Is_Script_Extensions=_Sundanese}', "");
Expect(0, 7368, '\P{^Is_Script_Extensions=_Sundanese}', "");
Error('\p{Is_Scx=-	Sund/a/}');
Error('\P{Is_Scx=-	Sund/a/}');
Expect(1, 7367, '\p{Is_Scx=sund}', "");
Expect(0, 7367, '\p{^Is_Scx=sund}', "");
Expect(0, 7367, '\P{Is_Scx=sund}', "");
Expect(1, 7367, '\P{^Is_Scx=sund}', "");
Expect(0, 7368, '\p{Is_Scx=sund}', "");
Expect(1, 7368, '\p{^Is_Scx=sund}', "");
Expect(1, 7368, '\P{Is_Scx=sund}', "");
Expect(0, 7368, '\P{^Is_Scx=sund}', "");
Error('\p{Script_Extensions=/a/ _syloti_NAGRI}');
Error('\P{Script_Extensions=/a/ _syloti_NAGRI}');
Expect(1, 43051, '\p{Script_Extensions:sylotinagri}', "");
Expect(0, 43051, '\p{^Script_Extensions:sylotinagri}', "");
Expect(0, 43051, '\P{Script_Extensions:sylotinagri}', "");
Expect(1, 43051, '\P{^Script_Extensions:sylotinagri}', "");
Expect(0, 43052, '\p{Script_Extensions:sylotinagri}', "");
Expect(1, 43052, '\p{^Script_Extensions:sylotinagri}', "");
Expect(1, 43052, '\P{Script_Extensions:sylotinagri}', "");
Expect(0, 43052, '\P{^Script_Extensions:sylotinagri}', "");
Expect(1, 43051, '\p{Script_Extensions=-Syloti_nagri}', "");
Expect(0, 43051, '\p{^Script_Extensions=-Syloti_nagri}', "");
Expect(0, 43051, '\P{Script_Extensions=-Syloti_nagri}', "");
Expect(1, 43051, '\P{^Script_Extensions=-Syloti_nagri}', "");
Expect(0, 43052, '\p{Script_Extensions=-Syloti_nagri}', "");
Expect(1, 43052, '\p{^Script_Extensions=-Syloti_nagri}', "");
Expect(1, 43052, '\P{Script_Extensions=-Syloti_nagri}', "");
Expect(0, 43052, '\P{^Script_Extensions=-Syloti_nagri}', "");
Error('\p{Scx:			SYLO:=}');
Error('\P{Scx:			SYLO:=}');
Expect(1, 43051, '\p{Scx=sylo}', "");
Expect(0, 43051, '\p{^Scx=sylo}', "");
Expect(0, 43051, '\P{Scx=sylo}', "");
Expect(1, 43051, '\P{^Scx=sylo}', "");
Expect(0, 43052, '\p{Scx=sylo}', "");
Expect(1, 43052, '\p{^Scx=sylo}', "");
Expect(1, 43052, '\P{Scx=sylo}', "");
Expect(0, 43052, '\P{^Scx=sylo}', "");
Expect(1, 43051, '\p{Scx:		-Sylo}', "");
Expect(0, 43051, '\p{^Scx:		-Sylo}', "");
Expect(0, 43051, '\P{Scx:		-Sylo}', "");
Expect(1, 43051, '\P{^Scx:		-Sylo}', "");
Expect(0, 43052, '\p{Scx:		-Sylo}', "");
Expect(1, 43052, '\p{^Scx:		-Sylo}', "");
Expect(1, 43052, '\P{Scx:		-Sylo}', "");
Expect(0, 43052, '\P{^Scx:		-Sylo}', "");
Error('\p{Is_Script_Extensions:   := _Syloti_Nagri}');
Error('\P{Is_Script_Extensions:   := _Syloti_Nagri}');
Expect(1, 43051, '\p{Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43051, '\p{^Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43051, '\P{Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43051, '\P{^Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43052, '\p{Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43052, '\p{^Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43052, '\P{Is_Script_Extensions=sylotinagri}', "");
Expect(0, 43052, '\P{^Is_Script_Extensions=sylotinagri}', "");
Expect(1, 43051, '\p{Is_Script_Extensions=_Syloti_nagri}', "");
Expect(0, 43051, '\p{^Is_Script_Extensions=_Syloti_nagri}', "");
Expect(0, 43051, '\P{Is_Script_Extensions=_Syloti_nagri}', "");
Expect(1, 43051, '\P{^Is_Script_Extensions=_Syloti_nagri}', "");
Expect(0, 43052, '\p{Is_Script_Extensions=_Syloti_nagri}', "");
Expect(1, 43052, '\p{^Is_Script_Extensions=_Syloti_nagri}', "");
Expect(1, 43052, '\P{Is_Script_Extensions=_Syloti_nagri}', "");
Expect(0, 43052, '\P{^Is_Script_Extensions=_Syloti_nagri}', "");
Error('\p{Is_Scx=- Sylo/a/}');
Error('\P{Is_Scx=- Sylo/a/}');
Expect(1, 43051, '\p{Is_Scx:	sylo}', "");
Expect(0, 43051, '\p{^Is_Scx:	sylo}', "");
Expect(0, 43051, '\P{Is_Scx:	sylo}', "");
Expect(1, 43051, '\P{^Is_Scx:	sylo}', "");
Expect(0, 43052, '\p{Is_Scx:	sylo}', "");
Expect(1, 43052, '\p{^Is_Scx:	sylo}', "");
Expect(1, 43052, '\P{Is_Scx:	sylo}', "");
Expect(0, 43052, '\P{^Is_Scx:	sylo}', "");
Expect(1, 43051, '\p{Is_Scx=_	SYLO}', "");
Expect(0, 43051, '\p{^Is_Scx=_	SYLO}', "");
Expect(0, 43051, '\P{Is_Scx=_	SYLO}', "");
Expect(1, 43051, '\P{^Is_Scx=_	SYLO}', "");
Expect(0, 43052, '\p{Is_Scx=_	SYLO}', "");
Expect(1, 43052, '\p{^Is_Scx=_	SYLO}', "");
Expect(1, 43052, '\P{Is_Scx=_	SYLO}', "");
Expect(0, 43052, '\P{^Is_Scx=_	SYLO}', "");
Error('\p{Script_Extensions=	:=Syriac}');
Error('\P{Script_Extensions=	:=Syriac}');
Expect(1, 1871, '\p{Script_Extensions=syriac}', "");
Expect(0, 1871, '\p{^Script_Extensions=syriac}', "");
Expect(0, 1871, '\P{Script_Extensions=syriac}', "");
Expect(1, 1871, '\P{^Script_Extensions=syriac}', "");
Expect(0, 1872, '\p{Script_Extensions=syriac}', "");
Expect(1, 1872, '\p{^Script_Extensions=syriac}', "");
Expect(1, 1872, '\P{Script_Extensions=syriac}', "");
Expect(0, 1872, '\P{^Script_Extensions=syriac}', "");
Expect(1, 1871, '\p{Script_Extensions=-syriac}', "");
Expect(0, 1871, '\p{^Script_Extensions=-syriac}', "");
Expect(0, 1871, '\P{Script_Extensions=-syriac}', "");
Expect(1, 1871, '\P{^Script_Extensions=-syriac}', "");
Expect(0, 1872, '\p{Script_Extensions=-syriac}', "");
Expect(1, 1872, '\p{^Script_Extensions=-syriac}', "");
Expect(1, 1872, '\P{Script_Extensions=-syriac}', "");
Expect(0, 1872, '\P{^Script_Extensions=-syriac}', "");
Error('\p{Scx= syrc:=}');
Error('\P{Scx= syrc:=}');
Expect(1, 1871, '\p{Scx=syrc}', "");
Expect(0, 1871, '\p{^Scx=syrc}', "");
Expect(0, 1871, '\P{Scx=syrc}', "");
Expect(1, 1871, '\P{^Scx=syrc}', "");
Expect(0, 1872, '\p{Scx=syrc}', "");
Expect(1, 1872, '\p{^Scx=syrc}', "");
Expect(1, 1872, '\P{Scx=syrc}', "");
Expect(0, 1872, '\P{^Scx=syrc}', "");
Expect(1, 1871, '\p{Scx=	_SYRC}', "");
Expect(0, 1871, '\p{^Scx=	_SYRC}', "");
Expect(0, 1871, '\P{Scx=	_SYRC}', "");
Expect(1, 1871, '\P{^Scx=	_SYRC}', "");
Expect(0, 1872, '\p{Scx=	_SYRC}', "");
Expect(1, 1872, '\p{^Scx=	_SYRC}', "");
Expect(1, 1872, '\P{Scx=	_SYRC}', "");
Expect(0, 1872, '\P{^Scx=	_SYRC}', "");
Error('\p{Is_Script_Extensions=:=_ SYRIAC}');
Error('\P{Is_Script_Extensions=:=_ SYRIAC}');
Expect(1, 1871, '\p{Is_Script_Extensions=syriac}', "");
Expect(0, 1871, '\p{^Is_Script_Extensions=syriac}', "");
Expect(0, 1871, '\P{Is_Script_Extensions=syriac}', "");
Expect(1, 1871, '\P{^Is_Script_Extensions=syriac}', "");
Expect(0, 1872, '\p{Is_Script_Extensions=syriac}', "");
Expect(1, 1872, '\p{^Is_Script_Extensions=syriac}', "");
Expect(1, 1872, '\P{Is_Script_Extensions=syriac}', "");
Expect(0, 1872, '\P{^Is_Script_Extensions=syriac}', "");
Expect(1, 1871, '\p{Is_Script_Extensions=  SYRIAC}', "");
Expect(0, 1871, '\p{^Is_Script_Extensions=  SYRIAC}', "");
Expect(0, 1871, '\P{Is_Script_Extensions=  SYRIAC}', "");
Expect(1, 1871, '\P{^Is_Script_Extensions=  SYRIAC}', "");
Expect(0, 1872, '\p{Is_Script_Extensions=  SYRIAC}', "");
Expect(1, 1872, '\p{^Is_Script_Extensions=  SYRIAC}', "");
Expect(1, 1872, '\P{Is_Script_Extensions=  SYRIAC}', "");
Expect(0, 1872, '\P{^Is_Script_Extensions=  SYRIAC}', "");
Error('\p{Is_Scx::=--Syrc}');
Error('\P{Is_Scx::=--Syrc}');
Expect(1, 1871, '\p{Is_Scx=syrc}', "");
Expect(0, 1871, '\p{^Is_Scx=syrc}', "");
Expect(0, 1871, '\P{Is_Scx=syrc}', "");
Expect(1, 1871, '\P{^Is_Scx=syrc}', "");
Expect(0, 1872, '\p{Is_Scx=syrc}', "");
Expect(1, 1872, '\p{^Is_Scx=syrc}', "");
Expect(1, 1872, '\P{Is_Scx=syrc}', "");
Expect(0, 1872, '\P{^Is_Scx=syrc}', "");
Expect(1, 1871, '\p{Is_Scx=- Syrc}', "");
Expect(0, 1871, '\p{^Is_Scx=- Syrc}', "");
Expect(0, 1871, '\P{Is_Scx=- Syrc}', "");
Expect(1, 1871, '\P{^Is_Scx=- Syrc}', "");
Expect(0, 1872, '\p{Is_Scx=- Syrc}', "");
Expect(1, 1872, '\p{^Is_Scx=- Syrc}', "");
Expect(1, 1872, '\P{Is_Scx=- Syrc}', "");
Expect(0, 1872, '\P{^Is_Scx=- Syrc}', "");
Error('\p{Script_Extensions=	/a/Tagbanwa}');
Error('\P{Script_Extensions=	/a/Tagbanwa}');
Expect(1, 6003, '\p{Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\p{^Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\P{Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\P{^Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\p{Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\p{^Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\P{Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\P{^Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\p{Script_Extensions=	_Tagbanwa}', "");
Expect(0, 6003, '\p{^Script_Extensions=	_Tagbanwa}', "");
Expect(0, 6003, '\P{Script_Extensions=	_Tagbanwa}', "");
Expect(1, 6003, '\P{^Script_Extensions=	_Tagbanwa}', "");
Expect(0, 6004, '\p{Script_Extensions=	_Tagbanwa}', "");
Expect(1, 6004, '\p{^Script_Extensions=	_Tagbanwa}', "");
Expect(1, 6004, '\P{Script_Extensions=	_Tagbanwa}', "");
Expect(0, 6004, '\P{^Script_Extensions=	_Tagbanwa}', "");
Error('\p{Scx=:=Tagb}');
Error('\P{Scx=:=Tagb}');
Expect(1, 6003, '\p{Scx=tagb}', "");
Expect(0, 6003, '\p{^Scx=tagb}', "");
Expect(0, 6003, '\P{Scx=tagb}', "");
Expect(1, 6003, '\P{^Scx=tagb}', "");
Expect(0, 6004, '\p{Scx=tagb}', "");
Expect(1, 6004, '\p{^Scx=tagb}', "");
Expect(1, 6004, '\P{Scx=tagb}', "");
Expect(0, 6004, '\P{^Scx=tagb}', "");
Expect(1, 6003, '\p{Scx=__TAGB}', "");
Expect(0, 6003, '\p{^Scx=__TAGB}', "");
Expect(0, 6003, '\P{Scx=__TAGB}', "");
Expect(1, 6003, '\P{^Scx=__TAGB}', "");
Expect(0, 6004, '\p{Scx=__TAGB}', "");
Expect(1, 6004, '\p{^Scx=__TAGB}', "");
Expect(1, 6004, '\P{Scx=__TAGB}', "");
Expect(0, 6004, '\P{^Scx=__TAGB}', "");
Error('\p{Is_Script_Extensions=_/a/TAGBANWA}');
Error('\P{Is_Script_Extensions=_/a/TAGBANWA}');
Expect(1, 6003, '\p{Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script_Extensions=tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script_Extensions=tagbanwa}', "");
Expect(1, 6003, '\p{Is_Script_Extensions= -Tagbanwa}', "");
Expect(0, 6003, '\p{^Is_Script_Extensions= -Tagbanwa}', "");
Expect(0, 6003, '\P{Is_Script_Extensions= -Tagbanwa}', "");
Expect(1, 6003, '\P{^Is_Script_Extensions= -Tagbanwa}', "");
Expect(0, 6004, '\p{Is_Script_Extensions= -Tagbanwa}', "");
Expect(1, 6004, '\p{^Is_Script_Extensions= -Tagbanwa}', "");
Expect(1, 6004, '\P{Is_Script_Extensions= -Tagbanwa}', "");
Expect(0, 6004, '\P{^Is_Script_Extensions= -Tagbanwa}', "");
Error('\p{Is_Scx=:=_tagb}');
Error('\P{Is_Scx=:=_tagb}');
Expect(1, 6003, '\p{Is_Scx: tagb}', "");
Expect(0, 6003, '\p{^Is_Scx: tagb}', "");
Expect(0, 6003, '\P{Is_Scx: tagb}', "");
Expect(1, 6003, '\P{^Is_Scx: tagb}', "");
Expect(0, 6004, '\p{Is_Scx: tagb}', "");
Expect(1, 6004, '\p{^Is_Scx: tagb}', "");
Expect(1, 6004, '\P{Is_Scx: tagb}', "");
Expect(0, 6004, '\P{^Is_Scx: tagb}', "");
Expect(1, 6003, '\p{Is_Scx=- Tagb}', "");
Expect(0, 6003, '\p{^Is_Scx=- Tagb}', "");
Expect(0, 6003, '\P{Is_Scx=- Tagb}', "");
Expect(1, 6003, '\P{^Is_Scx=- Tagb}', "");
Expect(0, 6004, '\p{Is_Scx=- Tagb}', "");
Expect(1, 6004, '\p{^Is_Scx=- Tagb}', "");
Expect(1, 6004, '\P{Is_Scx=- Tagb}', "");
Expect(0, 6004, '\P{^Is_Scx=- Tagb}', "");
Error('\p{Script_Extensions=-_Takri/a/}');
Error('\P{Script_Extensions=-_Takri/a/}');
Expect(1, 71369, '\p{Script_Extensions=takri}', "");
Expect(0, 71369, '\p{^Script_Extensions=takri}', "");
Expect(0, 71369, '\P{Script_Extensions=takri}', "");
Expect(1, 71369, '\P{^Script_Extensions=takri}', "");
Expect(0, 71370, '\p{Script_Extensions=takri}', "");
Expect(1, 71370, '\p{^Script_Extensions=takri}', "");
Expect(1, 71370, '\P{Script_Extensions=takri}', "");
Expect(0, 71370, '\P{^Script_Extensions=takri}', "");
Expect(1, 71369, '\p{Script_Extensions=-	Takri}', "");
Expect(0, 71369, '\p{^Script_Extensions=-	Takri}', "");
Expect(0, 71369, '\P{Script_Extensions=-	Takri}', "");
Expect(1, 71369, '\P{^Script_Extensions=-	Takri}', "");
Expect(0, 71370, '\p{Script_Extensions=-	Takri}', "");
Expect(1, 71370, '\p{^Script_Extensions=-	Takri}', "");
Expect(1, 71370, '\P{Script_Extensions=-	Takri}', "");
Expect(0, 71370, '\P{^Script_Extensions=-	Takri}', "");
Error('\p{Scx:	-:=takr}');
Error('\P{Scx:	-:=takr}');
Expect(1, 71369, '\p{Scx=takr}', "");
Expect(0, 71369, '\p{^Scx=takr}', "");
Expect(0, 71369, '\P{Scx=takr}', "");
Expect(1, 71369, '\P{^Scx=takr}', "");
Expect(0, 71370, '\p{Scx=takr}', "");
Expect(1, 71370, '\p{^Scx=takr}', "");
Expect(1, 71370, '\P{Scx=takr}', "");
Expect(0, 71370, '\P{^Scx=takr}', "");
Expect(1, 71369, '\p{Scx:- Takr}', "");
Expect(0, 71369, '\p{^Scx:- Takr}', "");
Expect(0, 71369, '\P{Scx:- Takr}', "");
Expect(1, 71369, '\P{^Scx:- Takr}', "");
Expect(0, 71370, '\p{Scx:- Takr}', "");
Expect(1, 71370, '\p{^Scx:- Takr}', "");
Expect(1, 71370, '\P{Scx:- Takr}', "");
Expect(0, 71370, '\P{^Scx:- Takr}', "");
Error('\p{Is_Script_Extensions=/a/-	takri}');
Error('\P{Is_Script_Extensions=/a/-	takri}');
Expect(1, 71369, '\p{Is_Script_Extensions=takri}', "");
Expect(0, 71369, '\p{^Is_Script_Extensions=takri}', "");
Expect(0, 71369, '\P{Is_Script_Extensions=takri}', "");
Expect(1, 71369, '\P{^Is_Script_Extensions=takri}', "");
Expect(0, 71370, '\p{Is_Script_Extensions=takri}', "");
Expect(1, 71370, '\p{^Is_Script_Extensions=takri}', "");
Expect(1, 71370, '\P{Is_Script_Extensions=takri}', "");
Expect(0, 71370, '\P{^Is_Script_Extensions=takri}', "");
Expect(1, 71369, '\p{Is_Script_Extensions=-Takri}', "");
Expect(0, 71369, '\p{^Is_Script_Extensions=-Takri}', "");
Expect(0, 71369, '\P{Is_Script_Extensions=-Takri}', "");
Expect(1, 71369, '\P{^Is_Script_Extensions=-Takri}', "");
Expect(0, 71370, '\p{Is_Script_Extensions=-Takri}', "");
Expect(1, 71370, '\p{^Is_Script_Extensions=-Takri}', "");
Expect(1, 71370, '\P{Is_Script_Extensions=-Takri}', "");
Expect(0, 71370, '\P{^Is_Script_Extensions=-Takri}', "");
Error('\p{Is_Scx=/a/	_Takr}');
Error('\P{Is_Scx=/a/	_Takr}');
Expect(1, 71369, '\p{Is_Scx=takr}', "");
Expect(0, 71369, '\p{^Is_Scx=takr}', "");
Expect(0, 71369, '\P{Is_Scx=takr}', "");
Expect(1, 71369, '\P{^Is_Scx=takr}', "");
Expect(0, 71370, '\p{Is_Scx=takr}', "");
Expect(1, 71370, '\p{^Is_Scx=takr}', "");
Expect(1, 71370, '\P{Is_Scx=takr}', "");
Expect(0, 71370, '\P{^Is_Scx=takr}', "");
Expect(1, 71369, '\p{Is_Scx=--Takr}', "");
Expect(0, 71369, '\p{^Is_Scx=--Takr}', "");
Expect(0, 71369, '\P{Is_Scx=--Takr}', "");
Expect(1, 71369, '\P{^Is_Scx=--Takr}', "");
Expect(0, 71370, '\p{Is_Scx=--Takr}', "");
Expect(1, 71370, '\p{^Is_Scx=--Takr}', "");
Expect(1, 71370, '\P{Is_Scx=--Takr}', "");
Expect(0, 71370, '\P{^Is_Scx=--Takr}', "");
Error('\p{Script_Extensions=-:=Tai_le}');
Error('\P{Script_Extensions=-:=Tai_le}');
Expect(1, 6516, '\p{Script_Extensions=taile}', "");
Expect(0, 6516, '\p{^Script_Extensions=taile}', "");
Expect(0, 6516, '\P{Script_Extensions=taile}', "");
Expect(1, 6516, '\P{^Script_Extensions=taile}', "");
Expect(0, 6517, '\p{Script_Extensions=taile}', "");
Expect(1, 6517, '\p{^Script_Extensions=taile}', "");
Expect(1, 6517, '\P{Script_Extensions=taile}', "");
Expect(0, 6517, '\P{^Script_Extensions=taile}', "");
Expect(1, 6516, '\p{Script_Extensions=-_Tai_LE}', "");
Expect(0, 6516, '\p{^Script_Extensions=-_Tai_LE}', "");
Expect(0, 6516, '\P{Script_Extensions=-_Tai_LE}', "");
Expect(1, 6516, '\P{^Script_Extensions=-_Tai_LE}', "");
Expect(0, 6517, '\p{Script_Extensions=-_Tai_LE}', "");
Expect(1, 6517, '\p{^Script_Extensions=-_Tai_LE}', "");
Expect(1, 6517, '\P{Script_Extensions=-_Tai_LE}', "");
Expect(0, 6517, '\P{^Script_Extensions=-_Tai_LE}', "");
Error('\p{Scx=:=	 tale}');
Error('\P{Scx=:=	 tale}');
Expect(1, 6516, '\p{Scx=tale}', "");
Expect(0, 6516, '\p{^Scx=tale}', "");
Expect(0, 6516, '\P{Scx=tale}', "");
Expect(1, 6516, '\P{^Scx=tale}', "");
Expect(0, 6517, '\p{Scx=tale}', "");
Expect(1, 6517, '\p{^Scx=tale}', "");
Expect(1, 6517, '\P{Scx=tale}', "");
Expect(0, 6517, '\P{^Scx=tale}', "");
Expect(1, 6516, '\p{Scx=-Tale}', "");
Expect(0, 6516, '\p{^Scx=-Tale}', "");
Expect(0, 6516, '\P{Scx=-Tale}', "");
Expect(1, 6516, '\P{^Scx=-Tale}', "");
Expect(0, 6517, '\p{Scx=-Tale}', "");
Expect(1, 6517, '\p{^Scx=-Tale}', "");
Expect(1, 6517, '\P{Scx=-Tale}', "");
Expect(0, 6517, '\P{^Scx=-Tale}', "");
Error('\p{Is_Script_Extensions=	:=tai_Le}');
Error('\P{Is_Script_Extensions=	:=tai_Le}');
Expect(1, 6516, '\p{Is_Script_Extensions=taile}', "");
Expect(0, 6516, '\p{^Is_Script_Extensions=taile}', "");
Expect(0, 6516, '\P{Is_Script_Extensions=taile}', "");
Expect(1, 6516, '\P{^Is_Script_Extensions=taile}', "");
Expect(0, 6517, '\p{Is_Script_Extensions=taile}', "");
Expect(1, 6517, '\p{^Is_Script_Extensions=taile}', "");
Expect(1, 6517, '\P{Is_Script_Extensions=taile}', "");
Expect(0, 6517, '\P{^Is_Script_Extensions=taile}', "");
Expect(1, 6516, '\p{Is_Script_Extensions=-_TAI_Le}', "");
Expect(0, 6516, '\p{^Is_Script_Extensions=-_TAI_Le}', "");
Expect(0, 6516, '\P{Is_Script_Extensions=-_TAI_Le}', "");
Expect(1, 6516, '\P{^Is_Script_Extensions=-_TAI_Le}', "");
Expect(0, 6517, '\p{Is_Script_Extensions=-_TAI_Le}', "");
Expect(1, 6517, '\p{^Is_Script_Extensions=-_TAI_Le}', "");
Expect(1, 6517, '\P{Is_Script_Extensions=-_TAI_Le}', "");
Expect(0, 6517, '\P{^Is_Script_Extensions=-_TAI_Le}', "");
Error('\p{Is_Scx=:=_	Tale}');
Error('\P{Is_Scx=:=_	Tale}');
Expect(1, 6516, '\p{Is_Scx=tale}', "");
Expect(0, 6516, '\p{^Is_Scx=tale}', "");
Expect(0, 6516, '\P{Is_Scx=tale}', "");
Expect(1, 6516, '\P{^Is_Scx=tale}', "");
Expect(0, 6517, '\p{Is_Scx=tale}', "");
Expect(1, 6517, '\p{^Is_Scx=tale}', "");
Expect(1, 6517, '\P{Is_Scx=tale}', "");
Expect(0, 6517, '\P{^Is_Scx=tale}', "");
Expect(1, 6516, '\p{Is_Scx=_	TALE}', "");
Expect(0, 6516, '\p{^Is_Scx=_	TALE}', "");
Expect(0, 6516, '\P{Is_Scx=_	TALE}', "");
Expect(1, 6516, '\P{^Is_Scx=_	TALE}', "");
Expect(0, 6517, '\p{Is_Scx=_	TALE}', "");
Expect(1, 6517, '\p{^Is_Scx=_	TALE}', "");
Expect(1, 6517, '\P{Is_Scx=_	TALE}', "");
Expect(0, 6517, '\P{^Is_Scx=_	TALE}', "");
Error('\p{Script_Extensions= New_Tai_Lue/a/}');
Error('\P{Script_Extensions= New_Tai_Lue/a/}');
Expect(1, 6623, '\p{Script_Extensions=newtailue}', "");
Expect(0, 6623, '\p{^Script_Extensions=newtailue}', "");
Expect(0, 6623, '\P{Script_Extensions=newtailue}', "");
Expect(1, 6623, '\P{^Script_Extensions=newtailue}', "");
Expect(0, 6624, '\p{Script_Extensions=newtailue}', "");
Expect(1, 6624, '\p{^Script_Extensions=newtailue}', "");
Expect(1, 6624, '\P{Script_Extensions=newtailue}', "");
Expect(0, 6624, '\P{^Script_Extensions=newtailue}', "");
Expect(1, 6623, '\p{Script_Extensions=	 New_Tai_Lue}', "");
Expect(0, 6623, '\p{^Script_Extensions=	 New_Tai_Lue}', "");
Expect(0, 6623, '\P{Script_Extensions=	 New_Tai_Lue}', "");
Expect(1, 6623, '\P{^Script_Extensions=	 New_Tai_Lue}', "");
Expect(0, 6624, '\p{Script_Extensions=	 New_Tai_Lue}', "");
Expect(1, 6624, '\p{^Script_Extensions=	 New_Tai_Lue}', "");
Expect(1, 6624, '\P{Script_Extensions=	 New_Tai_Lue}', "");
Expect(0, 6624, '\P{^Script_Extensions=	 New_Tai_Lue}', "");
Error('\p{Scx=-	Talu/a/}');
Error('\P{Scx=-	Talu/a/}');
Expect(1, 6623, '\p{Scx=talu}', "");
Expect(0, 6623, '\p{^Scx=talu}', "");
Expect(0, 6623, '\P{Scx=talu}', "");
Expect(1, 6623, '\P{^Scx=talu}', "");
Expect(0, 6624, '\p{Scx=talu}', "");
Expect(1, 6624, '\p{^Scx=talu}', "");
Expect(1, 6624, '\P{Scx=talu}', "");
Expect(0, 6624, '\P{^Scx=talu}', "");
Expect(1, 6623, '\p{Scx=__talu}', "");
Expect(0, 6623, '\p{^Scx=__talu}', "");
Expect(0, 6623, '\P{Scx=__talu}', "");
Expect(1, 6623, '\P{^Scx=__talu}', "");
Expect(0, 6624, '\p{Scx=__talu}', "");
Expect(1, 6624, '\p{^Scx=__talu}', "");
Expect(1, 6624, '\P{Scx=__talu}', "");
Expect(0, 6624, '\P{^Scx=__talu}', "");
Error('\p{Is_Script_Extensions=/a/new_Tai_lue}');
Error('\P{Is_Script_Extensions=/a/new_Tai_lue}');
Expect(1, 6623, '\p{Is_Script_Extensions=newtailue}', "");
Expect(0, 6623, '\p{^Is_Script_Extensions=newtailue}', "");
Expect(0, 6623, '\P{Is_Script_Extensions=newtailue}', "");
Expect(1, 6623, '\P{^Is_Script_Extensions=newtailue}', "");
Expect(0, 6624, '\p{Is_Script_Extensions=newtailue}', "");
Expect(1, 6624, '\p{^Is_Script_Extensions=newtailue}', "");
Expect(1, 6624, '\P{Is_Script_Extensions=newtailue}', "");
Expect(0, 6624, '\P{^Is_Script_Extensions=newtailue}', "");
Expect(1, 6623, '\p{Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(0, 6623, '\p{^Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(0, 6623, '\P{Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(1, 6623, '\P{^Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(0, 6624, '\p{Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(1, 6624, '\p{^Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(1, 6624, '\P{Is_Script_Extensions=-NEW_Tai_Lue}', "");
Expect(0, 6624, '\P{^Is_Script_Extensions=-NEW_Tai_Lue}', "");
Error('\p{Is_Scx=	:=Talu}');
Error('\P{Is_Scx=	:=Talu}');
Expect(1, 6623, '\p{Is_Scx:   talu}', "");
Expect(0, 6623, '\p{^Is_Scx:   talu}', "");
Expect(0, 6623, '\P{Is_Scx:   talu}', "");
Expect(1, 6623, '\P{^Is_Scx:   talu}', "");
Expect(0, 6624, '\p{Is_Scx:   talu}', "");
Expect(1, 6624, '\p{^Is_Scx:   talu}', "");
Expect(1, 6624, '\P{Is_Scx:   talu}', "");
Expect(0, 6624, '\P{^Is_Scx:   talu}', "");
Expect(1, 6623, '\p{Is_Scx=	 Talu}', "");
Expect(0, 6623, '\p{^Is_Scx=	 Talu}', "");
Expect(0, 6623, '\P{Is_Scx=	 Talu}', "");
Expect(1, 6623, '\P{^Is_Scx=	 Talu}', "");
Expect(0, 6624, '\p{Is_Scx=	 Talu}', "");
Expect(1, 6624, '\p{^Is_Scx=	 Talu}', "");
Expect(1, 6624, '\P{Is_Scx=	 Talu}', "");
Expect(0, 6624, '\P{^Is_Scx=	 Talu}', "");
Error('\p{Script_Extensions=	Tamil:=}');
Error('\P{Script_Extensions=	Tamil:=}');
Expect(1, 3066, '\p{Script_Extensions=tamil}', "");
Expect(0, 3066, '\p{^Script_Extensions=tamil}', "");
Expect(0, 3066, '\P{Script_Extensions=tamil}', "");
Expect(1, 3066, '\P{^Script_Extensions=tamil}', "");
Expect(0, 3067, '\p{Script_Extensions=tamil}', "");
Expect(1, 3067, '\p{^Script_Extensions=tamil}', "");
Expect(1, 3067, '\P{Script_Extensions=tamil}', "");
Expect(0, 3067, '\P{^Script_Extensions=tamil}', "");
Expect(1, 3066, '\p{Script_Extensions=-_TAMIL}', "");
Expect(0, 3066, '\p{^Script_Extensions=-_TAMIL}', "");
Expect(0, 3066, '\P{Script_Extensions=-_TAMIL}', "");
Expect(1, 3066, '\P{^Script_Extensions=-_TAMIL}', "");
Expect(0, 3067, '\p{Script_Extensions=-_TAMIL}', "");
Expect(1, 3067, '\p{^Script_Extensions=-_TAMIL}', "");
Expect(1, 3067, '\P{Script_Extensions=-_TAMIL}', "");
Expect(0, 3067, '\P{^Script_Extensions=-_TAMIL}', "");
Error('\p{Scx=_:=Taml}');
Error('\P{Scx=_:=Taml}');
Expect(1, 3066, '\p{Scx=taml}', "");
Expect(0, 3066, '\p{^Scx=taml}', "");
Expect(0, 3066, '\P{Scx=taml}', "");
Expect(1, 3066, '\P{^Scx=taml}', "");
Expect(0, 3067, '\p{Scx=taml}', "");
Expect(1, 3067, '\p{^Scx=taml}', "");
Expect(1, 3067, '\P{Scx=taml}', "");
Expect(0, 3067, '\P{^Scx=taml}', "");
Expect(1, 3066, '\p{Scx= Taml}', "");
Expect(0, 3066, '\p{^Scx= Taml}', "");
Expect(0, 3066, '\P{Scx= Taml}', "");
Expect(1, 3066, '\P{^Scx= Taml}', "");
Expect(0, 3067, '\p{Scx= Taml}', "");
Expect(1, 3067, '\p{^Scx= Taml}', "");
Expect(1, 3067, '\P{Scx= Taml}', "");
Expect(0, 3067, '\P{^Scx= Taml}', "");
Error('\p{Is_Script_Extensions=:=tamil}');
Error('\P{Is_Script_Extensions=:=tamil}');
Expect(1, 3066, '\p{Is_Script_Extensions=tamil}', "");
Expect(0, 3066, '\p{^Is_Script_Extensions=tamil}', "");
Expect(0, 3066, '\P{Is_Script_Extensions=tamil}', "");
Expect(1, 3066, '\P{^Is_Script_Extensions=tamil}', "");
Expect(0, 3067, '\p{Is_Script_Extensions=tamil}', "");
Expect(1, 3067, '\p{^Is_Script_Extensions=tamil}', "");
Expect(1, 3067, '\P{Is_Script_Extensions=tamil}', "");
Expect(0, 3067, '\P{^Is_Script_Extensions=tamil}', "");
Expect(1, 3066, '\p{Is_Script_Extensions=_-Tamil}', "");
Expect(0, 3066, '\p{^Is_Script_Extensions=_-Tamil}', "");
Expect(0, 3066, '\P{Is_Script_Extensions=_-Tamil}', "");
Expect(1, 3066, '\P{^Is_Script_Extensions=_-Tamil}', "");
Expect(0, 3067, '\p{Is_Script_Extensions=_-Tamil}', "");
Expect(1, 3067, '\p{^Is_Script_Extensions=_-Tamil}', "");
Expect(1, 3067, '\P{Is_Script_Extensions=_-Tamil}', "");
Expect(0, 3067, '\P{^Is_Script_Extensions=_-Tamil}', "");
Error('\p{Is_Scx: -:=Taml}');
Error('\P{Is_Scx: -:=Taml}');
Expect(1, 3066, '\p{Is_Scx=taml}', "");
Expect(0, 3066, '\p{^Is_Scx=taml}', "");
Expect(0, 3066, '\P{Is_Scx=taml}', "");
Expect(1, 3066, '\P{^Is_Scx=taml}', "");
Expect(0, 3067, '\p{Is_Scx=taml}', "");
Expect(1, 3067, '\p{^Is_Scx=taml}', "");
Expect(1, 3067, '\P{Is_Scx=taml}', "");
Expect(0, 3067, '\P{^Is_Scx=taml}', "");
Expect(1, 3066, '\p{Is_Scx=_-TAML}', "");
Expect(0, 3066, '\p{^Is_Scx=_-TAML}', "");
Expect(0, 3066, '\P{Is_Scx=_-TAML}', "");
Expect(1, 3066, '\P{^Is_Scx=_-TAML}', "");
Expect(0, 3067, '\p{Is_Scx=_-TAML}', "");
Expect(1, 3067, '\p{^Is_Scx=_-TAML}', "");
Expect(1, 3067, '\P{Is_Scx=_-TAML}', "");
Expect(0, 3067, '\P{^Is_Scx=_-TAML}', "");
Error('\p{Script_Extensions=:= Tai_VIET}');
Error('\P{Script_Extensions=:= Tai_VIET}');
Expect(1, 43743, '\p{Script_Extensions=taiviet}', "");
Expect(0, 43743, '\p{^Script_Extensions=taiviet}', "");
Expect(0, 43743, '\P{Script_Extensions=taiviet}', "");
Expect(1, 43743, '\P{^Script_Extensions=taiviet}', "");
Expect(0, 43744, '\p{Script_Extensions=taiviet}', "");
Expect(1, 43744, '\p{^Script_Extensions=taiviet}', "");
Expect(1, 43744, '\P{Script_Extensions=taiviet}', "");
Expect(0, 43744, '\P{^Script_Extensions=taiviet}', "");
Expect(1, 43743, '\p{Script_Extensions:		 Tai_Viet}', "");
Expect(0, 43743, '\p{^Script_Extensions:		 Tai_Viet}', "");
Expect(0, 43743, '\P{Script_Extensions:		 Tai_Viet}', "");
Expect(1, 43743, '\P{^Script_Extensions:		 Tai_Viet}', "");
Expect(0, 43744, '\p{Script_Extensions:		 Tai_Viet}', "");
Expect(1, 43744, '\p{^Script_Extensions:		 Tai_Viet}', "");
Expect(1, 43744, '\P{Script_Extensions:		 Tai_Viet}', "");
Expect(0, 43744, '\P{^Script_Extensions:		 Tai_Viet}', "");
Error('\p{Scx= 	Tavt/a/}');
Error('\P{Scx= 	Tavt/a/}');
Expect(1, 43743, '\p{Scx: tavt}', "");
Expect(0, 43743, '\p{^Scx: tavt}', "");
Expect(0, 43743, '\P{Scx: tavt}', "");
Expect(1, 43743, '\P{^Scx: tavt}', "");
Expect(0, 43744, '\p{Scx: tavt}', "");
Expect(1, 43744, '\p{^Scx: tavt}', "");
Expect(1, 43744, '\P{Scx: tavt}', "");
Expect(0, 43744, '\P{^Scx: tavt}', "");
Expect(1, 43743, '\p{Scx= _Tavt}', "");
Expect(0, 43743, '\p{^Scx= _Tavt}', "");
Expect(0, 43743, '\P{Scx= _Tavt}', "");
Expect(1, 43743, '\P{^Scx= _Tavt}', "");
Expect(0, 43744, '\p{Scx= _Tavt}', "");
Expect(1, 43744, '\p{^Scx= _Tavt}', "");
Expect(1, 43744, '\P{Scx= _Tavt}', "");
Expect(0, 43744, '\P{^Scx= _Tavt}', "");
Error('\p{Is_Script_Extensions=/a/-	tai_Viet}');
Error('\P{Is_Script_Extensions=/a/-	tai_Viet}');
Expect(1, 43743, '\p{Is_Script_Extensions=taiviet}', "");
Expect(0, 43743, '\p{^Is_Script_Extensions=taiviet}', "");
Expect(0, 43743, '\P{Is_Script_Extensions=taiviet}', "");
Expect(1, 43743, '\P{^Is_Script_Extensions=taiviet}', "");
Expect(0, 43744, '\p{Is_Script_Extensions=taiviet}', "");
Expect(1, 43744, '\p{^Is_Script_Extensions=taiviet}', "");
Expect(1, 43744, '\P{Is_Script_Extensions=taiviet}', "");
Expect(0, 43744, '\P{^Is_Script_Extensions=taiviet}', "");
Expect(1, 43743, '\p{Is_Script_Extensions= Tai_Viet}', "");
Expect(0, 43743, '\p{^Is_Script_Extensions= Tai_Viet}', "");
Expect(0, 43743, '\P{Is_Script_Extensions= Tai_Viet}', "");
Expect(1, 43743, '\P{^Is_Script_Extensions= Tai_Viet}', "");
Expect(0, 43744, '\p{Is_Script_Extensions= Tai_Viet}', "");
Expect(1, 43744, '\p{^Is_Script_Extensions= Tai_Viet}', "");
Expect(1, 43744, '\P{Is_Script_Extensions= Tai_Viet}', "");
Expect(0, 43744, '\P{^Is_Script_Extensions= Tai_Viet}', "");
Error('\p{Is_Scx=	:=Tavt}');
Error('\P{Is_Scx=	:=Tavt}');
Expect(1, 43743, '\p{Is_Scx=tavt}', "");
Expect(0, 43743, '\p{^Is_Scx=tavt}', "");
Expect(0, 43743, '\P{Is_Scx=tavt}', "");
Expect(1, 43743, '\P{^Is_Scx=tavt}', "");
Expect(0, 43744, '\p{Is_Scx=tavt}', "");
Expect(1, 43744, '\p{^Is_Scx=tavt}', "");
Expect(1, 43744, '\P{Is_Scx=tavt}', "");
Expect(0, 43744, '\P{^Is_Scx=tavt}', "");
Expect(1, 43743, '\p{Is_Scx=  Tavt}', "");
Expect(0, 43743, '\p{^Is_Scx=  Tavt}', "");
Expect(0, 43743, '\P{Is_Scx=  Tavt}', "");
Expect(1, 43743, '\P{^Is_Scx=  Tavt}', "");
Expect(0, 43744, '\p{Is_Scx=  Tavt}', "");
Expect(1, 43744, '\p{^Is_Scx=  Tavt}', "");
Expect(1, 43744, '\P{Is_Scx=  Tavt}', "");
Expect(0, 43744, '\P{^Is_Scx=  Tavt}', "");
Error('\p{Script_Extensions:		/a/telugu}');
Error('\P{Script_Extensions:		/a/telugu}');
Expect(1, 3199, '\p{Script_Extensions=telugu}', "");
Expect(0, 3199, '\p{^Script_Extensions=telugu}', "");
Expect(0, 3199, '\P{Script_Extensions=telugu}', "");
Expect(1, 3199, '\P{^Script_Extensions=telugu}', "");
Expect(0, 3200, '\p{Script_Extensions=telugu}', "");
Expect(1, 3200, '\p{^Script_Extensions=telugu}', "");
Expect(1, 3200, '\P{Script_Extensions=telugu}', "");
Expect(0, 3200, '\P{^Script_Extensions=telugu}', "");
Expect(1, 3199, '\p{Script_Extensions: _telugu}', "");
Expect(0, 3199, '\p{^Script_Extensions: _telugu}', "");
Expect(0, 3199, '\P{Script_Extensions: _telugu}', "");
Expect(1, 3199, '\P{^Script_Extensions: _telugu}', "");
Expect(0, 3200, '\p{Script_Extensions: _telugu}', "");
Expect(1, 3200, '\p{^Script_Extensions: _telugu}', "");
Expect(1, 3200, '\P{Script_Extensions: _telugu}', "");
Expect(0, 3200, '\P{^Script_Extensions: _telugu}', "");
Error('\p{Scx=:=-	TELU}');
Error('\P{Scx=:=-	TELU}');
Expect(1, 3199, '\p{Scx=telu}', "");
Expect(0, 3199, '\p{^Scx=telu}', "");
Expect(0, 3199, '\P{Scx=telu}', "");
Expect(1, 3199, '\P{^Scx=telu}', "");
Expect(0, 3200, '\p{Scx=telu}', "");
Expect(1, 3200, '\p{^Scx=telu}', "");
Expect(1, 3200, '\P{Scx=telu}', "");
Expect(0, 3200, '\P{^Scx=telu}', "");
Expect(1, 3199, '\p{Scx=-telu}', "");
Expect(0, 3199, '\p{^Scx=-telu}', "");
Expect(0, 3199, '\P{Scx=-telu}', "");
Expect(1, 3199, '\P{^Scx=-telu}', "");
Expect(0, 3200, '\p{Scx=-telu}', "");
Expect(1, 3200, '\p{^Scx=-telu}', "");
Expect(1, 3200, '\P{Scx=-telu}', "");
Expect(0, 3200, '\P{^Scx=-telu}', "");
Error('\p{Is_Script_Extensions=-_Telugu/a/}');
Error('\P{Is_Script_Extensions=-_Telugu/a/}');
Expect(1, 3199, '\p{Is_Script_Extensions:   telugu}', "");
Expect(0, 3199, '\p{^Is_Script_Extensions:   telugu}', "");
Expect(0, 3199, '\P{Is_Script_Extensions:   telugu}', "");
Expect(1, 3199, '\P{^Is_Script_Extensions:   telugu}', "");
Expect(0, 3200, '\p{Is_Script_Extensions:   telugu}', "");
Expect(1, 3200, '\p{^Is_Script_Extensions:   telugu}', "");
Expect(1, 3200, '\P{Is_Script_Extensions:   telugu}', "");
Expect(0, 3200, '\P{^Is_Script_Extensions:   telugu}', "");
Expect(1, 3199, '\p{Is_Script_Extensions=_TELUGU}', "");
Expect(0, 3199, '\p{^Is_Script_Extensions=_TELUGU}', "");
Expect(0, 3199, '\P{Is_Script_Extensions=_TELUGU}', "");
Expect(1, 3199, '\P{^Is_Script_Extensions=_TELUGU}', "");
Expect(0, 3200, '\p{Is_Script_Extensions=_TELUGU}', "");
Expect(1, 3200, '\p{^Is_Script_Extensions=_TELUGU}', "");
Expect(1, 3200, '\P{Is_Script_Extensions=_TELUGU}', "");
Expect(0, 3200, '\P{^Is_Script_Extensions=_TELUGU}', "");
Error('\p{Is_Scx=:=_Telu}');
Error('\P{Is_Scx=:=_Telu}');
Expect(1, 3199, '\p{Is_Scx=telu}', "");
Expect(0, 3199, '\p{^Is_Scx=telu}', "");
Expect(0, 3199, '\P{Is_Scx=telu}', "");
Expect(1, 3199, '\P{^Is_Scx=telu}', "");
Expect(0, 3200, '\p{Is_Scx=telu}', "");
Expect(1, 3200, '\p{^Is_Scx=telu}', "");
Expect(1, 3200, '\P{Is_Scx=telu}', "");
Expect(0, 3200, '\P{^Is_Scx=telu}', "");
Expect(1, 3199, '\p{Is_Scx=- telu}', "");
Expect(0, 3199, '\p{^Is_Scx=- telu}', "");
Expect(0, 3199, '\P{Is_Scx=- telu}', "");
Expect(1, 3199, '\P{^Is_Scx=- telu}', "");
Expect(0, 3200, '\p{Is_Scx=- telu}', "");
Expect(1, 3200, '\p{^Is_Scx=- telu}', "");
Expect(1, 3200, '\P{Is_Scx=- telu}', "");
Expect(0, 3200, '\P{^Is_Scx=- telu}', "");
Error('\p{Script_Extensions=:=Tifinagh}');
Error('\P{Script_Extensions=:=Tifinagh}');
Expect(1, 11647, '\p{Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\p{^Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\P{Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\P{^Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\p{Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\p{^Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\P{Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\P{^Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\p{Script_Extensions=_-tifinagh}', "");
Expect(0, 11647, '\p{^Script_Extensions=_-tifinagh}', "");
Expect(0, 11647, '\P{Script_Extensions=_-tifinagh}', "");
Expect(1, 11647, '\P{^Script_Extensions=_-tifinagh}', "");
Expect(0, 11648, '\p{Script_Extensions=_-tifinagh}', "");
Expect(1, 11648, '\p{^Script_Extensions=_-tifinagh}', "");
Expect(1, 11648, '\P{Script_Extensions=_-tifinagh}', "");
Expect(0, 11648, '\P{^Script_Extensions=_-tifinagh}', "");
Error('\p{Scx=	_Tfng/a/}');
Error('\P{Scx=	_Tfng/a/}');
Expect(1, 11647, '\p{Scx:tfng}', "");
Expect(0, 11647, '\p{^Scx:tfng}', "");
Expect(0, 11647, '\P{Scx:tfng}', "");
Expect(1, 11647, '\P{^Scx:tfng}', "");
Expect(0, 11648, '\p{Scx:tfng}', "");
Expect(1, 11648, '\p{^Scx:tfng}', "");
Expect(1, 11648, '\P{Scx:tfng}', "");
Expect(0, 11648, '\P{^Scx:tfng}', "");
Expect(1, 11647, '\p{Scx=-tfng}', "");
Expect(0, 11647, '\p{^Scx=-tfng}', "");
Expect(0, 11647, '\P{Scx=-tfng}', "");
Expect(1, 11647, '\P{^Scx=-tfng}', "");
Expect(0, 11648, '\p{Scx=-tfng}', "");
Expect(1, 11648, '\p{^Scx=-tfng}', "");
Expect(1, 11648, '\P{Scx=-tfng}', "");
Expect(0, 11648, '\P{^Scx=-tfng}', "");
Error('\p{Is_Script_Extensions=/a/	 TIFINAGH}');
Error('\P{Is_Script_Extensions=/a/	 TIFINAGH}');
Expect(1, 11647, '\p{Is_Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\p{^Is_Script_Extensions=tifinagh}', "");
Expect(0, 11647, '\P{Is_Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\P{^Is_Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\p{Is_Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\p{^Is_Script_Extensions=tifinagh}', "");
Expect(1, 11648, '\P{Is_Script_Extensions=tifinagh}', "");
Expect(0, 11648, '\P{^Is_Script_Extensions=tifinagh}', "");
Expect(1, 11647, '\p{Is_Script_Extensions=		TIFINAGH}', "");
Expect(0, 11647, '\p{^Is_Script_Extensions=		TIFINAGH}', "");
Expect(0, 11647, '\P{Is_Script_Extensions=		TIFINAGH}', "");
Expect(1, 11647, '\P{^Is_Script_Extensions=		TIFINAGH}', "");
Expect(0, 11648, '\p{Is_Script_Extensions=		TIFINAGH}', "");
Expect(1, 11648, '\p{^Is_Script_Extensions=		TIFINAGH}', "");
Expect(1, 11648, '\P{Is_Script_Extensions=		TIFINAGH}', "");
Expect(0, 11648, '\P{^Is_Script_Extensions=		TIFINAGH}', "");
Error('\p{Is_Scx=-Tfng/a/}');
Error('\P{Is_Scx=-Tfng/a/}');
Expect(1, 11647, '\p{Is_Scx=tfng}', "");
Expect(0, 11647, '\p{^Is_Scx=tfng}', "");
Expect(0, 11647, '\P{Is_Scx=tfng}', "");
Expect(1, 11647, '\P{^Is_Scx=tfng}', "");
Expect(0, 11648, '\p{Is_Scx=tfng}', "");
Expect(1, 11648, '\p{^Is_Scx=tfng}', "");
Expect(1, 11648, '\P{Is_Scx=tfng}', "");
Expect(0, 11648, '\P{^Is_Scx=tfng}', "");
Expect(1, 11647, '\p{Is_Scx=	-TFNG}', "");
Expect(0, 11647, '\p{^Is_Scx=	-TFNG}', "");
Expect(0, 11647, '\P{Is_Scx=	-TFNG}', "");
Expect(1, 11647, '\P{^Is_Scx=	-TFNG}', "");
Expect(0, 11648, '\p{Is_Scx=	-TFNG}', "");
Expect(1, 11648, '\p{^Is_Scx=	-TFNG}', "");
Expect(1, 11648, '\P{Is_Scx=	-TFNG}', "");
Expect(0, 11648, '\P{^Is_Scx=	-TFNG}', "");
Error('\p{Script_Extensions=	 Tagalog:=}');
Error('\P{Script_Extensions=	 Tagalog:=}');
Expect(1, 5942, '\p{Script_Extensions=tagalog}', "");
Expect(0, 5942, '\p{^Script_Extensions=tagalog}', "");
Expect(0, 5942, '\P{Script_Extensions=tagalog}', "");
Expect(1, 5942, '\P{^Script_Extensions=tagalog}', "");
Expect(0, 5943, '\p{Script_Extensions=tagalog}', "");
Expect(1, 5943, '\p{^Script_Extensions=tagalog}', "");
Expect(1, 5943, '\P{Script_Extensions=tagalog}', "");
Expect(0, 5943, '\P{^Script_Extensions=tagalog}', "");
Expect(1, 5942, '\p{Script_Extensions=-tagalog}', "");
Expect(0, 5942, '\p{^Script_Extensions=-tagalog}', "");
Expect(0, 5942, '\P{Script_Extensions=-tagalog}', "");
Expect(1, 5942, '\P{^Script_Extensions=-tagalog}', "");
Expect(0, 5943, '\p{Script_Extensions=-tagalog}', "");
Expect(1, 5943, '\p{^Script_Extensions=-tagalog}', "");
Expect(1, 5943, '\P{Script_Extensions=-tagalog}', "");
Expect(0, 5943, '\P{^Script_Extensions=-tagalog}', "");
Error('\p{Scx= -Tglg:=}');
Error('\P{Scx= -Tglg:=}');
Expect(1, 5942, '\p{Scx=tglg}', "");
Expect(0, 5942, '\p{^Scx=tglg}', "");
Expect(0, 5942, '\P{Scx=tglg}', "");
Expect(1, 5942, '\P{^Scx=tglg}', "");
Expect(0, 5943, '\p{Scx=tglg}', "");
Expect(1, 5943, '\p{^Scx=tglg}', "");
Expect(1, 5943, '\P{Scx=tglg}', "");
Expect(0, 5943, '\P{^Scx=tglg}', "");
Expect(1, 5942, '\p{Scx=_TGLG}', "");
Expect(0, 5942, '\p{^Scx=_TGLG}', "");
Expect(0, 5942, '\P{Scx=_TGLG}', "");
Expect(1, 5942, '\P{^Scx=_TGLG}', "");
Expect(0, 5943, '\p{Scx=_TGLG}', "");
Expect(1, 5943, '\p{^Scx=_TGLG}', "");
Expect(1, 5943, '\P{Scx=_TGLG}', "");
Expect(0, 5943, '\P{^Scx=_TGLG}', "");
Error('\p{Is_Script_Extensions=-tagalog/a/}');
Error('\P{Is_Script_Extensions=-tagalog/a/}');
Expect(1, 5942, '\p{Is_Script_Extensions=tagalog}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions=tagalog}', "");
Expect(0, 5942, '\P{Is_Script_Extensions=tagalog}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions=tagalog}', "");
Expect(0, 5943, '\p{Is_Script_Extensions=tagalog}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions=tagalog}', "");
Expect(1, 5943, '\P{Is_Script_Extensions=tagalog}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions=tagalog}', "");
Expect(1, 5942, '\p{Is_Script_Extensions= tagalog}', "");
Expect(0, 5942, '\p{^Is_Script_Extensions= tagalog}', "");
Expect(0, 5942, '\P{Is_Script_Extensions= tagalog}', "");
Expect(1, 5942, '\P{^Is_Script_Extensions= tagalog}', "");
Expect(0, 5943, '\p{Is_Script_Extensions= tagalog}', "");
Expect(1, 5943, '\p{^Is_Script_Extensions= tagalog}', "");
Expect(1, 5943, '\P{Is_Script_Extensions= tagalog}', "");
Expect(0, 5943, '\P{^Is_Script_Extensions= tagalog}', "");
Error('\p{Is_Scx=	Tglg:=}');
Error('\P{Is_Scx=	Tglg:=}');
Expect(1, 5942, '\p{Is_Scx=tglg}', "");
Expect(0, 5942, '\p{^Is_Scx=tglg}', "");
Expect(0, 5942, '\P{Is_Scx=tglg}', "");
Expect(1, 5942, '\P{^Is_Scx=tglg}', "");
Expect(0, 5943, '\p{Is_Scx=tglg}', "");
Expect(1, 5943, '\p{^Is_Scx=tglg}', "");
Expect(1, 5943, '\P{Is_Scx=tglg}', "");
Expect(0, 5943, '\P{^Is_Scx=tglg}', "");
Expect(1, 5942, '\p{Is_Scx=	_Tglg}', "");
Expect(0, 5942, '\p{^Is_Scx=	_Tglg}', "");
Expect(0, 5942, '\P{Is_Scx=	_Tglg}', "");
Expect(1, 5942, '\P{^Is_Scx=	_Tglg}', "");
Expect(0, 5943, '\p{Is_Scx=	_Tglg}', "");
Expect(1, 5943, '\p{^Is_Scx=	_Tglg}', "");
Expect(1, 5943, '\P{Is_Scx=	_Tglg}', "");
Expect(0, 5943, '\P{^Is_Scx=	_Tglg}', "");
Error('\p{Script_Extensions= -thaana:=}');
Error('\P{Script_Extensions= -thaana:=}');
Expect(1, 65021, '\p{Script_Extensions=thaana}', "");
Expect(0, 65021, '\p{^Script_Extensions=thaana}', "");
Expect(0, 65021, '\P{Script_Extensions=thaana}', "");
Expect(1, 65021, '\P{^Script_Extensions=thaana}', "");
Expect(0, 65022, '\p{Script_Extensions=thaana}', "");
Expect(1, 65022, '\p{^Script_Extensions=thaana}', "");
Expect(1, 65022, '\P{Script_Extensions=thaana}', "");
Expect(0, 65022, '\P{^Script_Extensions=thaana}', "");
Expect(1, 65021, '\p{Script_Extensions=_	Thaana}', "");
Expect(0, 65021, '\p{^Script_Extensions=_	Thaana}', "");
Expect(0, 65021, '\P{Script_Extensions=_	Thaana}', "");
Expect(1, 65021, '\P{^Script_Extensions=_	Thaana}', "");
Expect(0, 65022, '\p{Script_Extensions=_	Thaana}', "");
Expect(1, 65022, '\p{^Script_Extensions=_	Thaana}', "");
Expect(1, 65022, '\P{Script_Extensions=_	Thaana}', "");
Expect(0, 65022, '\P{^Script_Extensions=_	Thaana}', "");
Error('\p{Scx=-Thaa:=}');
Error('\P{Scx=-Thaa:=}');
Expect(1, 65021, '\p{Scx=thaa}', "");
Expect(0, 65021, '\p{^Scx=thaa}', "");
Expect(0, 65021, '\P{Scx=thaa}', "");
Expect(1, 65021, '\P{^Scx=thaa}', "");
Expect(0, 65022, '\p{Scx=thaa}', "");
Expect(1, 65022, '\p{^Scx=thaa}', "");
Expect(1, 65022, '\P{Scx=thaa}', "");
Expect(0, 65022, '\P{^Scx=thaa}', "");
Expect(1, 65021, '\p{Scx: _Thaa}', "");
Expect(0, 65021, '\p{^Scx: _Thaa}', "");
Expect(0, 65021, '\P{Scx: _Thaa}', "");
Expect(1, 65021, '\P{^Scx: _Thaa}', "");
Expect(0, 65022, '\p{Scx: _Thaa}', "");
Expect(1, 65022, '\p{^Scx: _Thaa}', "");
Expect(1, 65022, '\P{Scx: _Thaa}', "");
Expect(0, 65022, '\P{^Scx: _Thaa}', "");
Error('\p{Is_Script_Extensions=_THAANA/a/}');
Error('\P{Is_Script_Extensions=_THAANA/a/}');
Expect(1, 65021, '\p{Is_Script_Extensions:   thaana}', "");
Expect(0, 65021, '\p{^Is_Script_Extensions:   thaana}', "");
Expect(0, 65021, '\P{Is_Script_Extensions:   thaana}', "");
Expect(1, 65021, '\P{^Is_Script_Extensions:   thaana}', "");
Expect(0, 65022, '\p{Is_Script_Extensions:   thaana}', "");
Expect(1, 65022, '\p{^Is_Script_Extensions:   thaana}', "");
Expect(1, 65022, '\P{Is_Script_Extensions:   thaana}', "");
Expect(0, 65022, '\P{^Is_Script_Extensions:   thaana}', "");
Expect(1, 65021, '\p{Is_Script_Extensions=-	thaana}', "");
Expect(0, 65021, '\p{^Is_Script_Extensions=-	thaana}', "");
Expect(0, 65021, '\P{Is_Script_Extensions=-	thaana}', "");
Expect(1, 65021, '\P{^Is_Script_Extensions=-	thaana}', "");
Expect(0, 65022, '\p{Is_Script_Extensions=-	thaana}', "");
Expect(1, 65022, '\p{^Is_Script_Extensions=-	thaana}', "");
Expect(1, 65022, '\P{Is_Script_Extensions=-	thaana}', "");
Expect(0, 65022, '\P{^Is_Script_Extensions=-	thaana}', "");
Error('\p{Is_Scx=-:=THAA}');
Error('\P{Is_Scx=-:=THAA}');
Expect(1, 65021, '\p{Is_Scx=thaa}', "");
Expect(0, 65021, '\p{^Is_Scx=thaa}', "");
Expect(0, 65021, '\P{Is_Scx=thaa}', "");
Expect(1, 65021, '\P{^Is_Scx=thaa}', "");
Expect(0, 65022, '\p{Is_Scx=thaa}', "");
Expect(1, 65022, '\p{^Is_Scx=thaa}', "");
Expect(1, 65022, '\P{Is_Scx=thaa}', "");
Expect(0, 65022, '\P{^Is_Scx=thaa}', "");
Expect(1, 65021, '\p{Is_Scx= thaa}', "");
Expect(0, 65021, '\p{^Is_Scx= thaa}', "");
Expect(0, 65021, '\P{Is_Scx= thaa}', "");
Expect(1, 65021, '\P{^Is_Scx= thaa}', "");
Expect(0, 65022, '\p{Is_Scx= thaa}', "");
Expect(1, 65022, '\p{^Is_Scx= thaa}', "");
Expect(1, 65022, '\P{Is_Scx= thaa}', "");
Expect(0, 65022, '\P{^Is_Scx= thaa}', "");
Error('\p{Script_Extensions=:=	THAI}');
Error('\P{Script_Extensions=:=	THAI}');
Expect(1, 3675, '\p{Script_Extensions=thai}', "");
Expect(0, 3675, '\p{^Script_Extensions=thai}', "");
Expect(0, 3675, '\P{Script_Extensions=thai}', "");
Expect(1, 3675, '\P{^Script_Extensions=thai}', "");
Expect(0, 3676, '\p{Script_Extensions=thai}', "");
Expect(1, 3676, '\p{^Script_Extensions=thai}', "");
Expect(1, 3676, '\P{Script_Extensions=thai}', "");
Expect(0, 3676, '\P{^Script_Extensions=thai}', "");
Expect(1, 3675, '\p{Script_Extensions=-	Thai}', "");
Expect(0, 3675, '\p{^Script_Extensions=-	Thai}', "");
Expect(0, 3675, '\P{Script_Extensions=-	Thai}', "");
Expect(1, 3675, '\P{^Script_Extensions=-	Thai}', "");
Expect(0, 3676, '\p{Script_Extensions=-	Thai}', "");
Expect(1, 3676, '\p{^Script_Extensions=-	Thai}', "");
Expect(1, 3676, '\P{Script_Extensions=-	Thai}', "");
Expect(0, 3676, '\P{^Script_Extensions=-	Thai}', "");
Error('\p{Scx=/a/  Thai}');
Error('\P{Scx=/a/  Thai}');
Expect(1, 3675, '\p{Scx=thai}', "");
Expect(0, 3675, '\p{^Scx=thai}', "");
Expect(0, 3675, '\P{Scx=thai}', "");
Expect(1, 3675, '\P{^Scx=thai}', "");
Expect(0, 3676, '\p{Scx=thai}', "");
Expect(1, 3676, '\p{^Scx=thai}', "");
Expect(1, 3676, '\P{Scx=thai}', "");
Expect(0, 3676, '\P{^Scx=thai}', "");
Expect(1, 3675, '\p{Scx=-_Thai}', "");
Expect(0, 3675, '\p{^Scx=-_Thai}', "");
Expect(0, 3675, '\P{Scx=-_Thai}', "");
Expect(1, 3675, '\P{^Scx=-_Thai}', "");
Expect(0, 3676, '\p{Scx=-_Thai}', "");
Expect(1, 3676, '\p{^Scx=-_Thai}', "");
Expect(1, 3676, '\P{Scx=-_Thai}', "");
Expect(0, 3676, '\P{^Scx=-_Thai}', "");
Error('\p{Is_Script_Extensions= :=Thai}');
Error('\P{Is_Script_Extensions= :=Thai}');
Expect(1, 3675, '\p{Is_Script_Extensions=thai}', "");
Expect(0, 3675, '\p{^Is_Script_Extensions=thai}', "");
Expect(0, 3675, '\P{Is_Script_Extensions=thai}', "");
Expect(1, 3675, '\P{^Is_Script_Extensions=thai}', "");
Expect(0, 3676, '\p{Is_Script_Extensions=thai}', "");
Expect(1, 3676, '\p{^Is_Script_Extensions=thai}', "");
Expect(1, 3676, '\P{Is_Script_Extensions=thai}', "");
Expect(0, 3676, '\P{^Is_Script_Extensions=thai}', "");
Expect(1, 3675, '\p{Is_Script_Extensions=  thai}', "");
Expect(0, 3675, '\p{^Is_Script_Extensions=  thai}', "");
Expect(0, 3675, '\P{Is_Script_Extensions=  thai}', "");
Expect(1, 3675, '\P{^Is_Script_Extensions=  thai}', "");
Expect(0, 3676, '\p{Is_Script_Extensions=  thai}', "");
Expect(1, 3676, '\p{^Is_Script_Extensions=  thai}', "");
Expect(1, 3676, '\P{Is_Script_Extensions=  thai}', "");
Expect(0, 3676, '\P{^Is_Script_Extensions=  thai}', "");
Error('\p{Is_Scx=:=-	Thai}');
Error('\P{Is_Scx=:=-	Thai}');
Expect(1, 3675, '\p{Is_Scx=thai}', "");
Expect(0, 3675, '\p{^Is_Scx=thai}', "");
Expect(0, 3675, '\P{Is_Scx=thai}', "");
Expect(1, 3675, '\P{^Is_Scx=thai}', "");
Expect(0, 3676, '\p{Is_Scx=thai}', "");
Expect(1, 3676, '\p{^Is_Scx=thai}', "");
Expect(1, 3676, '\P{Is_Scx=thai}', "");
Expect(0, 3676, '\P{^Is_Scx=thai}', "");
Expect(1, 3675, '\p{Is_Scx=_	thai}', "");
Expect(0, 3675, '\p{^Is_Scx=_	thai}', "");
Expect(0, 3675, '\P{Is_Scx=_	thai}', "");
Expect(1, 3675, '\P{^Is_Scx=_	thai}', "");
Expect(0, 3676, '\p{Is_Scx=_	thai}', "");
Expect(1, 3676, '\p{^Is_Scx=_	thai}', "");
Expect(1, 3676, '\P{Is_Scx=_	thai}', "");
Expect(0, 3676, '\P{^Is_Scx=_	thai}', "");
Error('\p{Script_Extensions=--TIBETAN:=}');
Error('\P{Script_Extensions=--TIBETAN:=}');
Expect(1, 4058, '\p{Script_Extensions=tibetan}', "");
Expect(0, 4058, '\p{^Script_Extensions=tibetan}', "");
Expect(0, 4058, '\P{Script_Extensions=tibetan}', "");
Expect(1, 4058, '\P{^Script_Extensions=tibetan}', "");
Expect(0, 4059, '\p{Script_Extensions=tibetan}', "");
Expect(1, 4059, '\p{^Script_Extensions=tibetan}', "");
Expect(1, 4059, '\P{Script_Extensions=tibetan}', "");
Expect(0, 4059, '\P{^Script_Extensions=tibetan}', "");
Expect(1, 4058, '\p{Script_Extensions=	-tibetan}', "");
Expect(0, 4058, '\p{^Script_Extensions=	-tibetan}', "");
Expect(0, 4058, '\P{Script_Extensions=	-tibetan}', "");
Expect(1, 4058, '\P{^Script_Extensions=	-tibetan}', "");
Expect(0, 4059, '\p{Script_Extensions=	-tibetan}', "");
Expect(1, 4059, '\p{^Script_Extensions=	-tibetan}', "");
Expect(1, 4059, '\P{Script_Extensions=	-tibetan}', "");
Expect(0, 4059, '\P{^Script_Extensions=	-tibetan}', "");
Error('\p{Scx=:=	Tibt}');
Error('\P{Scx=:=	Tibt}');
Expect(1, 4058, '\p{Scx=tibt}', "");
Expect(0, 4058, '\p{^Scx=tibt}', "");
Expect(0, 4058, '\P{Scx=tibt}', "");
Expect(1, 4058, '\P{^Scx=tibt}', "");
Expect(0, 4059, '\p{Scx=tibt}', "");
Expect(1, 4059, '\p{^Scx=tibt}', "");
Expect(1, 4059, '\P{Scx=tibt}', "");
Expect(0, 4059, '\P{^Scx=tibt}', "");
Expect(1, 4058, '\p{Scx=--TIBT}', "");
Expect(0, 4058, '\p{^Scx=--TIBT}', "");
Expect(0, 4058, '\P{Scx=--TIBT}', "");
Expect(1, 4058, '\P{^Scx=--TIBT}', "");
Expect(0, 4059, '\p{Scx=--TIBT}', "");
Expect(1, 4059, '\p{^Scx=--TIBT}', "");
Expect(1, 4059, '\P{Scx=--TIBT}', "");
Expect(0, 4059, '\P{^Scx=--TIBT}', "");
Error('\p{Is_Script_Extensions=-/a/TIBETAN}');
Error('\P{Is_Script_Extensions=-/a/TIBETAN}');
Expect(1, 4058, '\p{Is_Script_Extensions=tibetan}', "");
Expect(0, 4058, '\p{^Is_Script_Extensions=tibetan}', "");
Expect(0, 4058, '\P{Is_Script_Extensions=tibetan}', "");
Expect(1, 4058, '\P{^Is_Script_Extensions=tibetan}', "");
Expect(0, 4059, '\p{Is_Script_Extensions=tibetan}', "");
Expect(1, 4059, '\p{^Is_Script_Extensions=tibetan}', "");
Expect(1, 4059, '\P{Is_Script_Extensions=tibetan}', "");
Expect(0, 4059, '\P{^Is_Script_Extensions=tibetan}', "");
Expect(1, 4058, '\p{Is_Script_Extensions=		Tibetan}', "");
Expect(0, 4058, '\p{^Is_Script_Extensions=		Tibetan}', "");
Expect(0, 4058, '\P{Is_Script_Extensions=		Tibetan}', "");
Expect(1, 4058, '\P{^Is_Script_Extensions=		Tibetan}', "");
Expect(0, 4059, '\p{Is_Script_Extensions=		Tibetan}', "");
Expect(1, 4059, '\p{^Is_Script_Extensions=		Tibetan}', "");
Expect(1, 4059, '\P{Is_Script_Extensions=		Tibetan}', "");
Expect(0, 4059, '\P{^Is_Script_Extensions=		Tibetan}', "");
Error('\p{Is_Scx= :=tibt}');
Error('\P{Is_Scx= :=tibt}');
Expect(1, 4058, '\p{Is_Scx=tibt}', "");
Expect(0, 4058, '\p{^Is_Scx=tibt}', "");
Expect(0, 4058, '\P{Is_Scx=tibt}', "");
Expect(1, 4058, '\P{^Is_Scx=tibt}', "");
Expect(0, 4059, '\p{Is_Scx=tibt}', "");
Expect(1, 4059, '\p{^Is_Scx=tibt}', "");
Expect(1, 4059, '\P{Is_Scx=tibt}', "");
Expect(0, 4059, '\P{^Is_Scx=tibt}', "");
Expect(1, 4058, '\p{Is_Scx=_ TIBT}', "");
Expect(0, 4058, '\p{^Is_Scx=_ TIBT}', "");
Expect(0, 4058, '\P{Is_Scx=_ TIBT}', "");
Expect(1, 4058, '\P{^Is_Scx=_ TIBT}', "");
Expect(0, 4059, '\p{Is_Scx=_ TIBT}', "");
Expect(1, 4059, '\p{^Is_Scx=_ TIBT}', "");
Expect(1, 4059, '\P{Is_Scx=_ TIBT}', "");
Expect(0, 4059, '\P{^Is_Scx=_ TIBT}', "");
Error('\p{Script_Extensions=-:=ugaritic}');
Error('\P{Script_Extensions=-:=ugaritic}');
Expect(1, 66463, '\p{Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\p{^Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\P{Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\P{^Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\p{Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\p{^Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\P{Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\P{^Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\p{Script_Extensions= Ugaritic}', "");
Expect(0, 66463, '\p{^Script_Extensions= Ugaritic}', "");
Expect(0, 66463, '\P{Script_Extensions= Ugaritic}', "");
Expect(1, 66463, '\P{^Script_Extensions= Ugaritic}', "");
Expect(0, 66464, '\p{Script_Extensions= Ugaritic}', "");
Expect(1, 66464, '\p{^Script_Extensions= Ugaritic}', "");
Expect(1, 66464, '\P{Script_Extensions= Ugaritic}', "");
Expect(0, 66464, '\P{^Script_Extensions= Ugaritic}', "");
Error('\p{Scx=/a/	Ugar}');
Error('\P{Scx=/a/	Ugar}');
Expect(1, 66463, '\p{Scx=ugar}', "");
Expect(0, 66463, '\p{^Scx=ugar}', "");
Expect(0, 66463, '\P{Scx=ugar}', "");
Expect(1, 66463, '\P{^Scx=ugar}', "");
Expect(0, 66464, '\p{Scx=ugar}', "");
Expect(1, 66464, '\p{^Scx=ugar}', "");
Expect(1, 66464, '\P{Scx=ugar}', "");
Expect(0, 66464, '\P{^Scx=ugar}', "");
Expect(1, 66463, '\p{Scx=-Ugar}', "");
Expect(0, 66463, '\p{^Scx=-Ugar}', "");
Expect(0, 66463, '\P{Scx=-Ugar}', "");
Expect(1, 66463, '\P{^Scx=-Ugar}', "");
Expect(0, 66464, '\p{Scx=-Ugar}', "");
Expect(1, 66464, '\p{^Scx=-Ugar}', "");
Expect(1, 66464, '\P{Scx=-Ugar}', "");
Expect(0, 66464, '\P{^Scx=-Ugar}', "");
Error('\p{Is_Script_Extensions=-:=UGARITIC}');
Error('\P{Is_Script_Extensions=-:=UGARITIC}');
Expect(1, 66463, '\p{Is_Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script_Extensions=ugaritic}', "");
Expect(0, 66463, '\P{Is_Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\p{Is_Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script_Extensions=ugaritic}', "");
Expect(1, 66464, '\P{Is_Script_Extensions=ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script_Extensions=ugaritic}', "");
Expect(1, 66463, '\p{Is_Script_Extensions= Ugaritic}', "");
Expect(0, 66463, '\p{^Is_Script_Extensions= Ugaritic}', "");
Expect(0, 66463, '\P{Is_Script_Extensions= Ugaritic}', "");
Expect(1, 66463, '\P{^Is_Script_Extensions= Ugaritic}', "");
Expect(0, 66464, '\p{Is_Script_Extensions= Ugaritic}', "");
Expect(1, 66464, '\p{^Is_Script_Extensions= Ugaritic}', "");
Expect(1, 66464, '\P{Is_Script_Extensions= Ugaritic}', "");
Expect(0, 66464, '\P{^Is_Script_Extensions= Ugaritic}', "");
Error('\p{Is_Scx=:=	 Ugar}');
Error('\P{Is_Scx=:=	 Ugar}');
Expect(1, 66463, '\p{Is_Scx=ugar}', "");
Expect(0, 66463, '\p{^Is_Scx=ugar}', "");
Expect(0, 66463, '\P{Is_Scx=ugar}', "");
Expect(1, 66463, '\P{^Is_Scx=ugar}', "");
Expect(0, 66464, '\p{Is_Scx=ugar}', "");
Expect(1, 66464, '\p{^Is_Scx=ugar}', "");
Expect(1, 66464, '\P{Is_Scx=ugar}', "");
Expect(0, 66464, '\P{^Is_Scx=ugar}', "");
Expect(1, 66463, '\p{Is_Scx=- ugar}', "");
Expect(0, 66463, '\p{^Is_Scx=- ugar}', "");
Expect(0, 66463, '\P{Is_Scx=- ugar}', "");
Expect(1, 66463, '\P{^Is_Scx=- ugar}', "");
Expect(0, 66464, '\p{Is_Scx=- ugar}', "");
Expect(1, 66464, '\p{^Is_Scx=- ugar}', "");
Expect(1, 66464, '\P{Is_Scx=- ugar}', "");
Expect(0, 66464, '\P{^Is_Scx=- ugar}', "");
Error('\p{Script_Extensions:	:=	Vai}');
Error('\P{Script_Extensions:	:=	Vai}');
Expect(1, 42539, '\p{Script_Extensions=vai}', "");
Expect(0, 42539, '\p{^Script_Extensions=vai}', "");
Expect(0, 42539, '\P{Script_Extensions=vai}', "");
Expect(1, 42539, '\P{^Script_Extensions=vai}', "");
Expect(0, 42540, '\p{Script_Extensions=vai}', "");
Expect(1, 42540, '\p{^Script_Extensions=vai}', "");
Expect(1, 42540, '\P{Script_Extensions=vai}', "");
Expect(0, 42540, '\P{^Script_Extensions=vai}', "");
Expect(1, 42539, '\p{Script_Extensions=	vai}', "");
Expect(0, 42539, '\p{^Script_Extensions=	vai}', "");
Expect(0, 42539, '\P{Script_Extensions=	vai}', "");
Expect(1, 42539, '\P{^Script_Extensions=	vai}', "");
Expect(0, 42540, '\p{Script_Extensions=	vai}', "");
Expect(1, 42540, '\p{^Script_Extensions=	vai}', "");
Expect(1, 42540, '\P{Script_Extensions=	vai}', "");
Expect(0, 42540, '\P{^Script_Extensions=	vai}', "");
Error('\p{Scx=-	vaii/a/}');
Error('\P{Scx=-	vaii/a/}');
Expect(1, 42539, '\p{Scx=vaii}', "");
Expect(0, 42539, '\p{^Scx=vaii}', "");
Expect(0, 42539, '\P{Scx=vaii}', "");
Expect(1, 42539, '\P{^Scx=vaii}', "");
Expect(0, 42540, '\p{Scx=vaii}', "");
Expect(1, 42540, '\p{^Scx=vaii}', "");
Expect(1, 42540, '\P{Scx=vaii}', "");
Expect(0, 42540, '\P{^Scx=vaii}', "");
Expect(1, 42539, '\p{Scx=-VAII}', "");
Expect(0, 42539, '\p{^Scx=-VAII}', "");
Expect(0, 42539, '\P{Scx=-VAII}', "");
Expect(1, 42539, '\P{^Scx=-VAII}', "");
Expect(0, 42540, '\p{Scx=-VAII}', "");
Expect(1, 42540, '\p{^Scx=-VAII}', "");
Expect(1, 42540, '\P{Scx=-VAII}', "");
Expect(0, 42540, '\P{^Scx=-VAII}', "");
Error('\p{Is_Script_Extensions=:= Vai}');
Error('\P{Is_Script_Extensions=:= Vai}');
Expect(1, 42539, '\p{Is_Script_Extensions=vai}', "");
Expect(0, 42539, '\p{^Is_Script_Extensions=vai}', "");
Expect(0, 42539, '\P{Is_Script_Extensions=vai}', "");
Expect(1, 42539, '\P{^Is_Script_Extensions=vai}', "");
Expect(0, 42540, '\p{Is_Script_Extensions=vai}', "");
Expect(1, 42540, '\p{^Is_Script_Extensions=vai}', "");
Expect(1, 42540, '\P{Is_Script_Extensions=vai}', "");
Expect(0, 42540, '\P{^Is_Script_Extensions=vai}', "");
Expect(1, 42539, '\p{Is_Script_Extensions=		vai}', "");
Expect(0, 42539, '\p{^Is_Script_Extensions=		vai}', "");
Expect(0, 42539, '\P{Is_Script_Extensions=		vai}', "");
Expect(1, 42539, '\P{^Is_Script_Extensions=		vai}', "");
Expect(0, 42540, '\p{Is_Script_Extensions=		vai}', "");
Expect(1, 42540, '\p{^Is_Script_Extensions=		vai}', "");
Expect(1, 42540, '\P{Is_Script_Extensions=		vai}', "");
Expect(0, 42540, '\P{^Is_Script_Extensions=		vai}', "");
Error('\p{Is_Scx=:= -VAII}');
Error('\P{Is_Scx=:= -VAII}');
Expect(1, 42539, '\p{Is_Scx=vaii}', "");
Expect(0, 42539, '\p{^Is_Scx=vaii}', "");
Expect(0, 42539, '\P{Is_Scx=vaii}', "");
Expect(1, 42539, '\P{^Is_Scx=vaii}', "");
Expect(0, 42540, '\p{Is_Scx=vaii}', "");
Expect(1, 42540, '\p{^Is_Scx=vaii}', "");
Expect(1, 42540, '\P{Is_Scx=vaii}', "");
Expect(0, 42540, '\P{^Is_Scx=vaii}', "");
Expect(1, 42539, '\p{Is_Scx= _vaii}', "");
Expect(0, 42539, '\p{^Is_Scx= _vaii}', "");
Expect(0, 42539, '\P{Is_Scx= _vaii}', "");
Expect(1, 42539, '\P{^Is_Scx= _vaii}', "");
Expect(0, 42540, '\p{Is_Scx= _vaii}', "");
Expect(1, 42540, '\p{^Is_Scx= _vaii}', "");
Expect(1, 42540, '\P{Is_Scx= _vaii}', "");
Expect(0, 42540, '\P{^Is_Scx= _vaii}', "");
Error('\p{Script_Extensions=_:=Old_Persian}');
Error('\P{Script_Extensions=_:=Old_Persian}');
Expect(1, 66517, '\p{Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\p{^Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\P{Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\P{^Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\p{Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\p{^Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\P{Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\P{^Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\p{Script_Extensions:    _old_Persian}', "");
Expect(0, 66517, '\p{^Script_Extensions:    _old_Persian}', "");
Expect(0, 66517, '\P{Script_Extensions:    _old_Persian}', "");
Expect(1, 66517, '\P{^Script_Extensions:    _old_Persian}', "");
Expect(0, 66518, '\p{Script_Extensions:    _old_Persian}', "");
Expect(1, 66518, '\p{^Script_Extensions:    _old_Persian}', "");
Expect(1, 66518, '\P{Script_Extensions:    _old_Persian}', "");
Expect(0, 66518, '\P{^Script_Extensions:    _old_Persian}', "");
Error('\p{Scx=	/a/xpeo}');
Error('\P{Scx=	/a/xpeo}');
Expect(1, 66517, '\p{Scx=xpeo}', "");
Expect(0, 66517, '\p{^Scx=xpeo}', "");
Expect(0, 66517, '\P{Scx=xpeo}', "");
Expect(1, 66517, '\P{^Scx=xpeo}', "");
Expect(0, 66518, '\p{Scx=xpeo}', "");
Expect(1, 66518, '\p{^Scx=xpeo}', "");
Expect(1, 66518, '\P{Scx=xpeo}', "");
Expect(0, 66518, '\P{^Scx=xpeo}', "");
Expect(1, 66517, '\p{Scx=__Xpeo}', "");
Expect(0, 66517, '\p{^Scx=__Xpeo}', "");
Expect(0, 66517, '\P{Scx=__Xpeo}', "");
Expect(1, 66517, '\P{^Scx=__Xpeo}', "");
Expect(0, 66518, '\p{Scx=__Xpeo}', "");
Expect(1, 66518, '\p{^Scx=__Xpeo}', "");
Expect(1, 66518, '\P{Scx=__Xpeo}', "");
Expect(0, 66518, '\P{^Scx=__Xpeo}', "");
Error('\p{Is_Script_Extensions=--Old_Persian/a/}');
Error('\P{Is_Script_Extensions=--Old_Persian/a/}');
Expect(1, 66517, '\p{Is_Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\p{^Is_Script_Extensions=oldpersian}', "");
Expect(0, 66517, '\P{Is_Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\P{^Is_Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\p{Is_Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\p{^Is_Script_Extensions=oldpersian}', "");
Expect(1, 66518, '\P{Is_Script_Extensions=oldpersian}', "");
Expect(0, 66518, '\P{^Is_Script_Extensions=oldpersian}', "");
Expect(1, 66517, '\p{Is_Script_Extensions=_	Old_Persian}', "");
Expect(0, 66517, '\p{^Is_Script_Extensions=_	Old_Persian}', "");
Expect(0, 66517, '\P{Is_Script_Extensions=_	Old_Persian}', "");
Expect(1, 66517, '\P{^Is_Script_Extensions=_	Old_Persian}', "");
Expect(0, 66518, '\p{Is_Script_Extensions=_	Old_Persian}', "");
Expect(1, 66518, '\p{^Is_Script_Extensions=_	Old_Persian}', "");
Expect(1, 66518, '\P{Is_Script_Extensions=_	Old_Persian}', "");
Expect(0, 66518, '\P{^Is_Script_Extensions=_	Old_Persian}', "");
Error('\p{Is_Scx=	-Xpeo:=}');
Error('\P{Is_Scx=	-Xpeo:=}');
Expect(1, 66517, '\p{Is_Scx=xpeo}', "");
Expect(0, 66517, '\p{^Is_Scx=xpeo}', "");
Expect(0, 66517, '\P{Is_Scx=xpeo}', "");
Expect(1, 66517, '\P{^Is_Scx=xpeo}', "");
Expect(0, 66518, '\p{Is_Scx=xpeo}', "");
Expect(1, 66518, '\p{^Is_Scx=xpeo}', "");
Expect(1, 66518, '\P{Is_Scx=xpeo}', "");
Expect(0, 66518, '\P{^Is_Scx=xpeo}', "");
Expect(1, 66517, '\p{Is_Scx=- XPEO}', "");
Expect(0, 66517, '\p{^Is_Scx=- XPEO}', "");
Expect(0, 66517, '\P{Is_Scx=- XPEO}', "");
Expect(1, 66517, '\P{^Is_Scx=- XPEO}', "");
Expect(0, 66518, '\p{Is_Scx=- XPEO}', "");
Expect(1, 66518, '\p{^Is_Scx=- XPEO}', "");
Expect(1, 66518, '\P{Is_Scx=- XPEO}', "");
Expect(0, 66518, '\P{^Is_Scx=- XPEO}', "");
Error('\p{Script_Extensions:_:=cuneiform}');
Error('\P{Script_Extensions:_:=cuneiform}');
Expect(1, 74867, '\p{Script_Extensions=cuneiform}', "");
Expect(0, 74867, '\p{^Script_Extensions=cuneiform}', "");
Expect(0, 74867, '\P{Script_Extensions=cuneiform}', "");
Expect(1, 74867, '\P{^Script_Extensions=cuneiform}', "");
Expect(0, 74868, '\p{Script_Extensions=cuneiform}', "");
Expect(1, 74868, '\p{^Script_Extensions=cuneiform}', "");
Expect(1, 74868, '\P{Script_Extensions=cuneiform}', "");
Expect(0, 74868, '\P{^Script_Extensions=cuneiform}', "");
Error('\p{Scx=__Xsux/a/}');
Error('\P{Scx=__Xsux/a/}');
Expect(1, 74867, '\p{Scx: xsux}', "");
Expect(0, 74867, '\p{^Scx: xsux}', "");
Expect(0, 74867, '\P{Scx: xsux}', "");
Expect(1, 74867, '\P{^Scx: xsux}', "");
Expect(0, 74868, '\p{Scx: xsux}', "");
Expect(1, 74868, '\p{^Scx: xsux}', "");
Expect(1, 74868, '\P{Scx: xsux}', "");
Expect(0, 74868, '\P{^Scx: xsux}', "");
Expect(1, 74867, '\p{Scx:	 Xsux}', "");
Expect(0, 74867, '\p{^Scx:	 Xsux}', "");
Expect(0, 74867, '\P{Scx:	 Xsux}', "");
Expect(1, 74867, '\P{^Scx:	 Xsux}', "");
Expect(0, 74868, '\p{Scx:	 Xsux}', "");
Expect(1, 74868, '\p{^Scx:	 Xsux}', "");
Expect(1, 74868, '\P{Scx:	 Xsux}', "");
Expect(0, 74868, '\P{^Scx:	 Xsux}', "");
Error('\p{Is_Script_Extensions=/a/Cuneiform}');
Error('\P{Is_Script_Extensions=/a/Cuneiform}');
Expect(1, 74867, '\p{Is_Script_Extensions=cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script_Extensions=cuneiform}', "");
Expect(0, 74867, '\P{Is_Script_Extensions=cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script_Extensions=cuneiform}', "");
Expect(0, 74868, '\p{Is_Script_Extensions=cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script_Extensions=cuneiform}', "");
Expect(1, 74868, '\P{Is_Script_Extensions=cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script_Extensions=cuneiform}', "");
Expect(1, 74867, '\p{Is_Script_Extensions=	 Cuneiform}', "");
Expect(0, 74867, '\p{^Is_Script_Extensions=	 Cuneiform}', "");
Expect(0, 74867, '\P{Is_Script_Extensions=	 Cuneiform}', "");
Expect(1, 74867, '\P{^Is_Script_Extensions=	 Cuneiform}', "");
Expect(0, 74868, '\p{Is_Script_Extensions=	 Cuneiform}', "");
Expect(1, 74868, '\p{^Is_Script_Extensions=	 Cuneiform}', "");
Expect(1, 74868, '\P{Is_Script_Extensions=	 Cuneiform}', "");
Expect(0, 74868, '\P{^Is_Script_Extensions=	 Cuneiform}', "");
Error('\p{Is_Scx=_-Xsux:=}');
Error('\P{Is_Scx=_-Xsux:=}');
Expect(1, 74867, '\p{Is_Scx=xsux}', "");
Expect(0, 74867, '\p{^Is_Scx=xsux}', "");
Expect(0, 74867, '\P{Is_Scx=xsux}', "");
Expect(1, 74867, '\P{^Is_Scx=xsux}', "");
Expect(0, 74868, '\p{Is_Scx=xsux}', "");
Expect(1, 74868, '\p{^Is_Scx=xsux}', "");
Expect(1, 74868, '\P{Is_Scx=xsux}', "");
Expect(0, 74868, '\P{^Is_Scx=xsux}', "");
Expect(1, 74867, '\p{Is_Scx=	XSUX}', "");
Expect(0, 74867, '\p{^Is_Scx=	XSUX}', "");
Expect(0, 74867, '\P{Is_Scx=	XSUX}', "");
Expect(1, 74867, '\P{^Is_Scx=	XSUX}', "");
Expect(0, 74868, '\p{Is_Scx=	XSUX}', "");
Expect(1, 74868, '\p{^Is_Scx=	XSUX}', "");
Expect(1, 74868, '\P{Is_Scx=	XSUX}', "");
Expect(0, 74868, '\P{^Is_Scx=	XSUX}', "");
Error('\p{Script_Extensions=_YI:=}');
Error('\P{Script_Extensions=_YI:=}');
Expect(1, 65381, '\p{Script_Extensions=yi}', "");
Expect(0, 65381, '\p{^Script_Extensions=yi}', "");
Expect(0, 65381, '\P{Script_Extensions=yi}', "");
Expect(1, 65381, '\P{^Script_Extensions=yi}', "");
Expect(0, 65382, '\p{Script_Extensions=yi}', "");
Expect(1, 65382, '\p{^Script_Extensions=yi}', "");
Expect(1, 65382, '\P{Script_Extensions=yi}', "");
Expect(0, 65382, '\P{^Script_Extensions=yi}', "");
Expect(1, 65381, '\p{Script_Extensions=_-Yi}', "");
Expect(0, 65381, '\p{^Script_Extensions=_-Yi}', "");
Expect(0, 65381, '\P{Script_Extensions=_-Yi}', "");
Expect(1, 65381, '\P{^Script_Extensions=_-Yi}', "");
Expect(0, 65382, '\p{Script_Extensions=_-Yi}', "");
Expect(1, 65382, '\p{^Script_Extensions=_-Yi}', "");
Expect(1, 65382, '\P{Script_Extensions=_-Yi}', "");
Expect(0, 65382, '\P{^Script_Extensions=_-Yi}', "");
Error('\p{Scx= :=Yiii}');
Error('\P{Scx= :=Yiii}');
Expect(1, 65381, '\p{Scx=yiii}', "");
Expect(0, 65381, '\p{^Scx=yiii}', "");
Expect(0, 65381, '\P{Scx=yiii}', "");
Expect(1, 65381, '\P{^Scx=yiii}', "");
Expect(0, 65382, '\p{Scx=yiii}', "");
Expect(1, 65382, '\p{^Scx=yiii}', "");
Expect(1, 65382, '\P{Scx=yiii}', "");
Expect(0, 65382, '\P{^Scx=yiii}', "");
Expect(1, 65381, '\p{Scx=_	YIII}', "");
Expect(0, 65381, '\p{^Scx=_	YIII}', "");
Expect(0, 65381, '\P{Scx=_	YIII}', "");
Expect(1, 65381, '\P{^Scx=_	YIII}', "");
Expect(0, 65382, '\p{Scx=_	YIII}', "");
Expect(1, 65382, '\p{^Scx=_	YIII}', "");
Expect(1, 65382, '\P{Scx=_	YIII}', "");
Expect(0, 65382, '\P{^Scx=_	YIII}', "");
Error('\p{Is_Script_Extensions:	:=__Yi}');
Error('\P{Is_Script_Extensions:	:=__Yi}');
Expect(1, 65381, '\p{Is_Script_Extensions=yi}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=yi}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=yi}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=yi}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=yi}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=yi}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=yi}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=yi}', "");
Expect(1, 65381, '\p{Is_Script_Extensions=-_Yi}', "");
Expect(0, 65381, '\p{^Is_Script_Extensions=-_Yi}', "");
Expect(0, 65381, '\P{Is_Script_Extensions=-_Yi}', "");
Expect(1, 65381, '\P{^Is_Script_Extensions=-_Yi}', "");
Expect(0, 65382, '\p{Is_Script_Extensions=-_Yi}', "");
Expect(1, 65382, '\p{^Is_Script_Extensions=-_Yi}', "");
Expect(1, 65382, '\P{Is_Script_Extensions=-_Yi}', "");
Expect(0, 65382, '\P{^Is_Script_Extensions=-_Yi}', "");
Error('\p{Is_Scx:   	/a/Yiii}');
Error('\P{Is_Scx:   	/a/Yiii}');
Expect(1, 65381, '\p{Is_Scx=yiii}', "");
Expect(0, 65381, '\p{^Is_Scx=yiii}', "");
Expect(0, 65381, '\P{Is_Scx=yiii}', "");
Expect(1, 65381, '\P{^Is_Scx=yiii}', "");
Expect(0, 65382, '\p{Is_Scx=yiii}', "");
Expect(1, 65382, '\p{^Is_Scx=yiii}', "");
Expect(1, 65382, '\P{Is_Scx=yiii}', "");
Expect(0, 65382, '\P{^Is_Scx=yiii}', "");
Expect(1, 65381, '\p{Is_Scx=_ Yiii}', "");
Expect(0, 65381, '\p{^Is_Scx=_ Yiii}', "");
Expect(0, 65381, '\P{Is_Scx=_ Yiii}', "");
Expect(1, 65381, '\P{^Is_Scx=_ Yiii}', "");
Expect(0, 65382, '\p{Is_Scx=_ Yiii}', "");
Expect(1, 65382, '\p{^Is_Scx=_ Yiii}', "");
Expect(1, 65382, '\P{Is_Scx=_ Yiii}', "");
Expect(0, 65382, '\P{^Is_Scx=_ Yiii}', "");
Error('\p{Script_Extensions=	_inherited:=}');
Error('\P{Script_Extensions=	_inherited:=}');
Expect(1, 917999, '\p{Script_Extensions=inherited}', "");
Expect(0, 917999, '\p{^Script_Extensions=inherited}', "");
Expect(0, 917999, '\P{Script_Extensions=inherited}', "");
Expect(1, 917999, '\P{^Script_Extensions=inherited}', "");
Expect(0, 918000, '\p{Script_Extensions=inherited}', "");
Expect(1, 918000, '\p{^Script_Extensions=inherited}', "");
Expect(1, 918000, '\P{Script_Extensions=inherited}', "");
Expect(0, 918000, '\P{^Script_Extensions=inherited}', "");
Expect(1, 917999, '\p{Script_Extensions=-	INHERITED}', "");
Expect(0, 917999, '\p{^Script_Extensions=-	INHERITED}', "");
Expect(0, 917999, '\P{Script_Extensions=-	INHERITED}', "");
Expect(1, 917999, '\P{^Script_Extensions=-	INHERITED}', "");
Expect(0, 918000, '\p{Script_Extensions=-	INHERITED}', "");
Expect(1, 918000, '\p{^Script_Extensions=-	INHERITED}', "");
Expect(1, 918000, '\P{Script_Extensions=-	INHERITED}', "");
Expect(0, 918000, '\P{^Script_Extensions=-	INHERITED}', "");
Error('\p{Scx: 	-Zinh/a/}');
Error('\P{Scx: 	-Zinh/a/}');
Expect(1, 917999, '\p{Scx=zinh}', "");
Expect(0, 917999, '\p{^Scx=zinh}', "");
Expect(0, 917999, '\P{Scx=zinh}', "");
Expect(1, 917999, '\P{^Scx=zinh}', "");
Expect(0, 918000, '\p{Scx=zinh}', "");
Expect(1, 918000, '\p{^Scx=zinh}', "");
Expect(1, 918000, '\P{Scx=zinh}', "");
Expect(0, 918000, '\P{^Scx=zinh}', "");
Expect(1, 917999, '\p{Scx=_Zinh}', "");
Expect(0, 917999, '\p{^Scx=_Zinh}', "");
Expect(0, 917999, '\P{Scx=_Zinh}', "");
Expect(1, 917999, '\P{^Scx=_Zinh}', "");
Expect(0, 918000, '\p{Scx=_Zinh}', "");
Expect(1, 918000, '\p{^Scx=_Zinh}', "");
Expect(1, 918000, '\P{Scx=_Zinh}', "");
Expect(0, 918000, '\P{^Scx=_Zinh}', "");
Error('\p{Is_Script_Extensions= 	QAAI/a/}');
Error('\P{Is_Script_Extensions= 	QAAI/a/}');
Expect(1, 917999, '\p{Is_Script_Extensions=qaai}', "");
Expect(0, 917999, '\p{^Is_Script_Extensions=qaai}', "");
Expect(0, 917999, '\P{Is_Script_Extensions=qaai}', "");
Expect(1, 917999, '\P{^Is_Script_Extensions=qaai}', "");
Expect(0, 918000, '\p{Is_Script_Extensions=qaai}', "");
Expect(1, 918000, '\p{^Is_Script_Extensions=qaai}', "");
Expect(1, 918000, '\P{Is_Script_Extensions=qaai}', "");
Expect(0, 918000, '\P{^Is_Script_Extensions=qaai}', "");
Error('\p{Is_Scx=/a/ _inherited}');
Error('\P{Is_Scx=/a/ _inherited}');
Expect(1, 917999, '\p{Is_Scx:	inherited}', "");
Expect(0, 917999, '\p{^Is_Scx:	inherited}', "");
Expect(0, 917999, '\P{Is_Scx:	inherited}', "");
Expect(1, 917999, '\P{^Is_Scx:	inherited}', "");
Expect(0, 918000, '\p{Is_Scx:	inherited}', "");
Expect(1, 918000, '\p{^Is_Scx:	inherited}', "");
Expect(1, 918000, '\P{Is_Scx:	inherited}', "");
Expect(0, 918000, '\P{^Is_Scx:	inherited}', "");
Expect(1, 917999, '\p{Is_Scx=_ Inherited}', "");
Expect(0, 917999, '\p{^Is_Scx=_ Inherited}', "");
Expect(0, 917999, '\P{Is_Scx=_ Inherited}', "");
Expect(1, 917999, '\P{^Is_Scx=_ Inherited}', "");
Expect(0, 918000, '\p{Is_Scx=_ Inherited}', "");
Expect(1, 918000, '\p{^Is_Scx=_ Inherited}', "");
Expect(1, 918000, '\P{Is_Scx=_ Inherited}', "");
Expect(0, 918000, '\P{^Is_Scx=_ Inherited}', "");
Error('\p{Script_Extensions=/a/COMMON}');
Error('\P{Script_Extensions=/a/COMMON}');
Expect(1, 917631, '\p{Script_Extensions=common}', "");
Expect(0, 917631, '\p{^Script_Extensions=common}', "");
Expect(0, 917631, '\P{Script_Extensions=common}', "");
Expect(1, 917631, '\P{^Script_Extensions=common}', "");
Expect(0, 917632, '\p{Script_Extensions=common}', "");
Expect(1, 917632, '\p{^Script_Extensions=common}', "");
Expect(1, 917632, '\P{Script_Extensions=common}', "");
Expect(0, 917632, '\P{^Script_Extensions=common}', "");
Expect(1, 917631, '\p{Script_Extensions=--common}', "");
Expect(0, 917631, '\p{^Script_Extensions=--common}', "");
Expect(0, 917631, '\P{Script_Extensions=--common}', "");
Expect(1, 917631, '\P{^Script_Extensions=--common}', "");
Expect(0, 917632, '\p{Script_Extensions=--common}', "");
Expect(1, 917632, '\p{^Script_Extensions=--common}', "");
Expect(1, 917632, '\P{Script_Extensions=--common}', "");
Expect(0, 917632, '\P{^Script_Extensions=--common}', "");
Error('\p{Scx= Zyyy:=}');
Error('\P{Scx= Zyyy:=}');
Expect(1, 917631, '\p{Scx=zyyy}', "");
Expect(0, 917631, '\p{^Scx=zyyy}', "");
Expect(0, 917631, '\P{Scx=zyyy}', "");
Expect(1, 917631, '\P{^Scx=zyyy}', "");
Expect(0, 917632, '\p{Scx=zyyy}', "");
Expect(1, 917632, '\p{^Scx=zyyy}', "");
Expect(1, 917632, '\P{Scx=zyyy}', "");
Expect(0, 917632, '\P{^Scx=zyyy}', "");
Expect(1, 917631, '\p{Scx=	Zyyy}', "");
Expect(0, 917631, '\p{^Scx=	Zyyy}', "");
Expect(0, 917631, '\P{Scx=	Zyyy}', "");
Expect(1, 917631, '\P{^Scx=	Zyyy}', "");
Expect(0, 917632, '\p{Scx=	Zyyy}', "");
Expect(1, 917632, '\p{^Scx=	Zyyy}', "");
Expect(1, 917632, '\P{Scx=	Zyyy}', "");
Expect(0, 917632, '\P{^Scx=	Zyyy}', "");
Error('\p{Is_Script_Extensions=:= 	Common}');
Error('\P{Is_Script_Extensions=:= 	Common}');
Expect(1, 917631, '\p{Is_Script_Extensions=common}', "");
Expect(0, 917631, '\p{^Is_Script_Extensions=common}', "");
Expect(0, 917631, '\P{Is_Script_Extensions=common}', "");
Expect(1, 917631, '\P{^Is_Script_Extensions=common}', "");
Expect(0, 917632, '\p{Is_Script_Extensions=common}', "");
Expect(1, 917632, '\p{^Is_Script_Extensions=common}', "");
Expect(1, 917632, '\P{Is_Script_Extensions=common}', "");
Expect(0, 917632, '\P{^Is_Script_Extensions=common}', "");
Expect(1, 917631, '\p{Is_Script_Extensions=	 Common}', "");
Expect(0, 917631, '\p{^Is_Script_Extensions=	 Common}', "");
Expect(0, 917631, '\P{Is_Script_Extensions=	 Common}', "");
Expect(1, 917631, '\P{^Is_Script_Extensions=	 Common}', "");
Expect(0, 917632, '\p{Is_Script_Extensions=	 Common}', "");
Expect(1, 917632, '\p{^Is_Script_Extensions=	 Common}', "");
Expect(1, 917632, '\P{Is_Script_Extensions=	 Common}', "");
Expect(0, 917632, '\P{^Is_Script_Extensions=	 Common}', "");
Error('\p{Is_Scx=:=_Zyyy}');
Error('\P{Is_Scx=:=_Zyyy}');
Expect(1, 917631, '\p{Is_Scx=zyyy}', "");
Expect(0, 917631, '\p{^Is_Scx=zyyy}', "");
Expect(0, 917631, '\P{Is_Scx=zyyy}', "");
Expect(1, 917631, '\P{^Is_Scx=zyyy}', "");
Expect(0, 917632, '\p{Is_Scx=zyyy}', "");
Expect(1, 917632, '\p{^Is_Scx=zyyy}', "");
Expect(1, 917632, '\P{Is_Scx=zyyy}', "");
Expect(0, 917632, '\P{^Is_Scx=zyyy}', "");
Error('\p{Script_Extensions=:=  Unknown}');
Error('\P{Script_Extensions=:=  Unknown}');
Expect(1, 918000, '\p{Script_Extensions:unknown}', "");
Expect(0, 918000, '\p{^Script_Extensions:unknown}', "");
Expect(0, 918000, '\P{Script_Extensions:unknown}', "");
Expect(1, 918000, '\P{^Script_Extensions:unknown}', "");
Expect(0, 917999, '\p{Script_Extensions:unknown}', "");
Expect(1, 917999, '\p{^Script_Extensions:unknown}', "");
Expect(1, 917999, '\P{Script_Extensions:unknown}', "");
Expect(0, 917999, '\P{^Script_Extensions:unknown}', "");
Expect(1, 918000, '\p{Script_Extensions=-Unknown}', "");
Expect(0, 918000, '\p{^Script_Extensions=-Unknown}', "");
Expect(0, 918000, '\P{Script_Extensions=-Unknown}', "");
Expect(1, 918000, '\P{^Script_Extensions=-Unknown}', "");
Expect(0, 917999, '\p{Script_Extensions=-Unknown}', "");
Expect(1, 917999, '\p{^Script_Extensions=-Unknown}', "");
Expect(1, 917999, '\P{Script_Extensions=-Unknown}', "");
Expect(0, 917999, '\P{^Script_Extensions=-Unknown}', "");
Error('\p{Scx=	 Zzzz/a/}');
Error('\P{Scx=	 Zzzz/a/}');
Expect(1, 918000, '\p{Scx=zzzz}', "");
Expect(0, 918000, '\p{^Scx=zzzz}', "");
Expect(0, 918000, '\P{Scx=zzzz}', "");
Expect(1, 918000, '\P{^Scx=zzzz}', "");
Expect(0, 917999, '\p{Scx=zzzz}', "");
Expect(1, 917999, '\p{^Scx=zzzz}', "");
Expect(1, 917999, '\P{Scx=zzzz}', "");
Expect(0, 917999, '\P{^Scx=zzzz}', "");
Expect(1, 918000, '\p{Scx=_ZZZZ}', "");
Expect(0, 918000, '\p{^Scx=_ZZZZ}', "");
Expect(0, 918000, '\P{Scx=_ZZZZ}', "");
Expect(1, 918000, '\P{^Scx=_ZZZZ}', "");
Expect(0, 917999, '\p{Scx=_ZZZZ}', "");
Expect(1, 917999, '\p{^Scx=_ZZZZ}', "");
Expect(1, 917999, '\P{Scx=_ZZZZ}', "");
Expect(0, 917999, '\P{^Scx=_ZZZZ}', "");
Error('\p{Is_Script_Extensions=_Unknown/a/}');
Error('\P{Is_Script_Extensions=_Unknown/a/}');
Expect(1, 918000, '\p{Is_Script_Extensions=unknown}', "");
Expect(0, 918000, '\p{^Is_Script_Extensions=unknown}', "");
Expect(0, 918000, '\P{Is_Script_Extensions=unknown}', "");
Expect(1, 918000, '\P{^Is_Script_Extensions=unknown}', "");
Expect(0, 917999, '\p{Is_Script_Extensions=unknown}', "");
Expect(1, 917999, '\p{^Is_Script_Extensions=unknown}', "");
Expect(1, 917999, '\P{Is_Script_Extensions=unknown}', "");
Expect(0, 917999, '\P{^Is_Script_Extensions=unknown}', "");
Expect(1, 918000, '\p{Is_Script_Extensions=_-unknown}', "");
Expect(0, 918000, '\p{^Is_Script_Extensions=_-unknown}', "");
Expect(0, 918000, '\P{Is_Script_Extensions=_-unknown}', "");
Expect(1, 918000, '\P{^Is_Script_Extensions=_-unknown}', "");
Expect(0, 917999, '\p{Is_Script_Extensions=_-unknown}', "");
Expect(1, 917999, '\p{^Is_Script_Extensions=_-unknown}', "");
Expect(1, 917999, '\P{Is_Script_Extensions=_-unknown}', "");
Expect(0, 917999, '\P{^Is_Script_Extensions=_-unknown}', "");
Error('\p{Is_Scx=:=_zzzz}');
Error('\P{Is_Scx=:=_zzzz}');
Expect(1, 918000, '\p{Is_Scx:   zzzz}', "");
Expect(0, 918000, '\p{^Is_Scx:   zzzz}', "");
Expect(0, 918000, '\P{Is_Scx:   zzzz}', "");
Expect(1, 918000, '\P{^Is_Scx:   zzzz}', "");
Expect(0, 917999, '\p{Is_Scx:   zzzz}', "");
Expect(1, 917999, '\p{^Is_Scx:   zzzz}', "");
Expect(1, 917999, '\P{Is_Scx:   zzzz}', "");
Expect(0, 917999, '\P{^Is_Scx:   zzzz}', "");
Expect(1, 918000, '\p{Is_Scx: __zzzz}', "");
Expect(0, 918000, '\p{^Is_Scx: __zzzz}', "");
Expect(0, 918000, '\P{Is_Scx: __zzzz}', "");
Expect(1, 918000, '\P{^Is_Scx: __zzzz}', "");
Expect(0, 917999, '\p{Is_Scx: __zzzz}', "");
Expect(1, 917999, '\p{^Is_Scx: __zzzz}', "");
Expect(1, 917999, '\P{Is_Scx: __zzzz}', "");
Expect(0, 917999, '\P{^Is_Scx: __zzzz}', "");
Test_X('÷ 0020 ÷ 0020 ÷');
Test_X('÷ 0020 × 0308 ÷ 0020 ÷');
Test_X('÷ 0020 ÷ 000D ÷');
Test_X('÷ 0020 × 0308 ÷ 000D ÷');
Test_X('÷ 0020 ÷ 000A ÷');
Test_X('÷ 0020 × 0308 ÷ 000A ÷');
Test_X('÷ 0020 ÷ 0001 ÷');
Test_X('÷ 0020 × 0308 ÷ 0001 ÷');
Test_X('÷ 0020 × 0300 ÷');
Test_X('÷ 0020 × 0308 × 0300 ÷');
Test_X('÷ 0020 × 0903 ÷');
Test_X('÷ 0020 × 0308 × 0903 ÷');
Test_X('÷ 0020 ÷ 1100 ÷');
Test_X('÷ 0020 × 0308 ÷ 1100 ÷');
Test_X('÷ 0020 ÷ 1160 ÷');
Test_X('÷ 0020 × 0308 ÷ 1160 ÷');
Test_X('÷ 0020 ÷ 11A8 ÷');
Test_X('÷ 0020 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0020 ÷ AC00 ÷');
Test_X('÷ 0020 × 0308 ÷ AC00 ÷');
Test_X('÷ 0020 ÷ AC01 ÷');
Test_X('÷ 0020 × 0308 ÷ AC01 ÷');
Test_X('÷ 0020 ÷ 1F1E6 ÷');
Test_X('÷ 0020 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0020 ÷ 0378 ÷');
Test_X('÷ 0020 × 0308 ÷ 0378 ÷');
Test_X('÷ 0020 ÷ D800 ÷');
Test_X('÷ 0020 × 0308 ÷ D800 ÷');
Test_X('÷ 000D ÷ 0020 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 0020 ÷');
Test_X('÷ 000D ÷ 000D ÷');
Test_X('÷ 000D ÷ 0308 ÷ 000D ÷');
Test_X('÷ 000D × 000A ÷');
Test_X('÷ 000D ÷ 0308 ÷ 000A ÷');
Test_X('÷ 000D ÷ 0001 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 0001 ÷');
Test_X('÷ 000D ÷ 0300 ÷');
Test_X('÷ 000D ÷ 0308 × 0300 ÷');
Test_X('÷ 000D ÷ 0903 ÷');
Test_X('÷ 000D ÷ 0308 × 0903 ÷');
Test_X('÷ 000D ÷ 1100 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 1100 ÷');
Test_X('÷ 000D ÷ 1160 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 1160 ÷');
Test_X('÷ 000D ÷ 11A8 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ 000D ÷ AC00 ÷');
Test_X('÷ 000D ÷ 0308 ÷ AC00 ÷');
Test_X('÷ 000D ÷ AC01 ÷');
Test_X('÷ 000D ÷ 0308 ÷ AC01 ÷');
Test_X('÷ 000D ÷ 1F1E6 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ 000D ÷ 0378 ÷');
Test_X('÷ 000D ÷ 0308 ÷ 0378 ÷');
Test_X('÷ 000D ÷ D800 ÷');
Test_X('÷ 000D ÷ 0308 ÷ D800 ÷');
Test_X('÷ 000A ÷ 0020 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 0020 ÷');
Test_X('÷ 000A ÷ 000D ÷');
Test_X('÷ 000A ÷ 0308 ÷ 000D ÷');
Test_X('÷ 000A ÷ 000A ÷');
Test_X('÷ 000A ÷ 0308 ÷ 000A ÷');
Test_X('÷ 000A ÷ 0001 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 0001 ÷');
Test_X('÷ 000A ÷ 0300 ÷');
Test_X('÷ 000A ÷ 0308 × 0300 ÷');
Test_X('÷ 000A ÷ 0903 ÷');
Test_X('÷ 000A ÷ 0308 × 0903 ÷');
Test_X('÷ 000A ÷ 1100 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 1100 ÷');
Test_X('÷ 000A ÷ 1160 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 1160 ÷');
Test_X('÷ 000A ÷ 11A8 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ 000A ÷ AC00 ÷');
Test_X('÷ 000A ÷ 0308 ÷ AC00 ÷');
Test_X('÷ 000A ÷ AC01 ÷');
Test_X('÷ 000A ÷ 0308 ÷ AC01 ÷');
Test_X('÷ 000A ÷ 1F1E6 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ 000A ÷ 0378 ÷');
Test_X('÷ 000A ÷ 0308 ÷ 0378 ÷');
Test_X('÷ 000A ÷ D800 ÷');
Test_X('÷ 000A ÷ 0308 ÷ D800 ÷');
Test_X('÷ 0001 ÷ 0020 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 0020 ÷');
Test_X('÷ 0001 ÷ 000D ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 000D ÷');
Test_X('÷ 0001 ÷ 000A ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 000A ÷');
Test_X('÷ 0001 ÷ 0001 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 0001 ÷');
Test_X('÷ 0001 ÷ 0300 ÷');
Test_X('÷ 0001 ÷ 0308 × 0300 ÷');
Test_X('÷ 0001 ÷ 0903 ÷');
Test_X('÷ 0001 ÷ 0308 × 0903 ÷');
Test_X('÷ 0001 ÷ 1100 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 1100 ÷');
Test_X('÷ 0001 ÷ 1160 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 1160 ÷');
Test_X('÷ 0001 ÷ 11A8 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ 0001 ÷ AC00 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ AC00 ÷');
Test_X('÷ 0001 ÷ AC01 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ AC01 ÷');
Test_X('÷ 0001 ÷ 1F1E6 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0001 ÷ 0378 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ 0378 ÷');
Test_X('÷ 0001 ÷ D800 ÷');
Test_X('÷ 0001 ÷ 0308 ÷ D800 ÷');
Test_X('÷ 0300 ÷ 0020 ÷');
Test_X('÷ 0300 × 0308 ÷ 0020 ÷');
Test_X('÷ 0300 ÷ 000D ÷');
Test_X('÷ 0300 × 0308 ÷ 000D ÷');
Test_X('÷ 0300 ÷ 000A ÷');
Test_X('÷ 0300 × 0308 ÷ 000A ÷');
Test_X('÷ 0300 ÷ 0001 ÷');
Test_X('÷ 0300 × 0308 ÷ 0001 ÷');
Test_X('÷ 0300 × 0300 ÷');
Test_X('÷ 0300 × 0308 × 0300 ÷');
Test_X('÷ 0300 × 0903 ÷');
Test_X('÷ 0300 × 0308 × 0903 ÷');
Test_X('÷ 0300 ÷ 1100 ÷');
Test_X('÷ 0300 × 0308 ÷ 1100 ÷');
Test_X('÷ 0300 ÷ 1160 ÷');
Test_X('÷ 0300 × 0308 ÷ 1160 ÷');
Test_X('÷ 0300 ÷ 11A8 ÷');
Test_X('÷ 0300 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0300 ÷ AC00 ÷');
Test_X('÷ 0300 × 0308 ÷ AC00 ÷');
Test_X('÷ 0300 ÷ AC01 ÷');
Test_X('÷ 0300 × 0308 ÷ AC01 ÷');
Test_X('÷ 0300 ÷ 1F1E6 ÷');
Test_X('÷ 0300 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0300 ÷ 0378 ÷');
Test_X('÷ 0300 × 0308 ÷ 0378 ÷');
Test_X('÷ 0300 ÷ D800 ÷');
Test_X('÷ 0300 × 0308 ÷ D800 ÷');
Test_X('÷ 0903 ÷ 0020 ÷');
Test_X('÷ 0903 × 0308 ÷ 0020 ÷');
Test_X('÷ 0903 ÷ 000D ÷');
Test_X('÷ 0903 × 0308 ÷ 000D ÷');
Test_X('÷ 0903 ÷ 000A ÷');
Test_X('÷ 0903 × 0308 ÷ 000A ÷');
Test_X('÷ 0903 ÷ 0001 ÷');
Test_X('÷ 0903 × 0308 ÷ 0001 ÷');
Test_X('÷ 0903 × 0300 ÷');
Test_X('÷ 0903 × 0308 × 0300 ÷');
Test_X('÷ 0903 × 0903 ÷');
Test_X('÷ 0903 × 0308 × 0903 ÷');
Test_X('÷ 0903 ÷ 1100 ÷');
Test_X('÷ 0903 × 0308 ÷ 1100 ÷');
Test_X('÷ 0903 ÷ 1160 ÷');
Test_X('÷ 0903 × 0308 ÷ 1160 ÷');
Test_X('÷ 0903 ÷ 11A8 ÷');
Test_X('÷ 0903 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0903 ÷ AC00 ÷');
Test_X('÷ 0903 × 0308 ÷ AC00 ÷');
Test_X('÷ 0903 ÷ AC01 ÷');
Test_X('÷ 0903 × 0308 ÷ AC01 ÷');
Test_X('÷ 0903 ÷ 1F1E6 ÷');
Test_X('÷ 0903 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0903 ÷ 0378 ÷');
Test_X('÷ 0903 × 0308 ÷ 0378 ÷');
Test_X('÷ 0903 ÷ D800 ÷');
Test_X('÷ 0903 × 0308 ÷ D800 ÷');
Test_X('÷ 1100 ÷ 0020 ÷');
Test_X('÷ 1100 × 0308 ÷ 0020 ÷');
Test_X('÷ 1100 ÷ 000D ÷');
Test_X('÷ 1100 × 0308 ÷ 000D ÷');
Test_X('÷ 1100 ÷ 000A ÷');
Test_X('÷ 1100 × 0308 ÷ 000A ÷');
Test_X('÷ 1100 ÷ 0001 ÷');
Test_X('÷ 1100 × 0308 ÷ 0001 ÷');
Test_X('÷ 1100 × 0300 ÷');
Test_X('÷ 1100 × 0308 × 0300 ÷');
Test_X('÷ 1100 × 0903 ÷');
Test_X('÷ 1100 × 0308 × 0903 ÷');
Test_X('÷ 1100 × 1100 ÷');
Test_X('÷ 1100 × 0308 ÷ 1100 ÷');
Test_X('÷ 1100 × 1160 ÷');
Test_X('÷ 1100 × 0308 ÷ 1160 ÷');
Test_X('÷ 1100 ÷ 11A8 ÷');
Test_X('÷ 1100 × 0308 ÷ 11A8 ÷');
Test_X('÷ 1100 × AC00 ÷');
Test_X('÷ 1100 × 0308 ÷ AC00 ÷');
Test_X('÷ 1100 × AC01 ÷');
Test_X('÷ 1100 × 0308 ÷ AC01 ÷');
Test_X('÷ 1100 ÷ 1F1E6 ÷');
Test_X('÷ 1100 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 1100 ÷ 0378 ÷');
Test_X('÷ 1100 × 0308 ÷ 0378 ÷');
Test_X('÷ 1100 ÷ D800 ÷');
Test_X('÷ 1100 × 0308 ÷ D800 ÷');
Test_X('÷ 1160 ÷ 0020 ÷');
Test_X('÷ 1160 × 0308 ÷ 0020 ÷');
Test_X('÷ 1160 ÷ 000D ÷');
Test_X('÷ 1160 × 0308 ÷ 000D ÷');
Test_X('÷ 1160 ÷ 000A ÷');
Test_X('÷ 1160 × 0308 ÷ 000A ÷');
Test_X('÷ 1160 ÷ 0001 ÷');
Test_X('÷ 1160 × 0308 ÷ 0001 ÷');
Test_X('÷ 1160 × 0300 ÷');
Test_X('÷ 1160 × 0308 × 0300 ÷');
Test_X('÷ 1160 × 0903 ÷');
Test_X('÷ 1160 × 0308 × 0903 ÷');
Test_X('÷ 1160 ÷ 1100 ÷');
Test_X('÷ 1160 × 0308 ÷ 1100 ÷');
Test_X('÷ 1160 × 1160 ÷');
Test_X('÷ 1160 × 0308 ÷ 1160 ÷');
Test_X('÷ 1160 × 11A8 ÷');
Test_X('÷ 1160 × 0308 ÷ 11A8 ÷');
Test_X('÷ 1160 ÷ AC00 ÷');
Test_X('÷ 1160 × 0308 ÷ AC00 ÷');
Test_X('÷ 1160 ÷ AC01 ÷');
Test_X('÷ 1160 × 0308 ÷ AC01 ÷');
Test_X('÷ 1160 ÷ 1F1E6 ÷');
Test_X('÷ 1160 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 1160 ÷ 0378 ÷');
Test_X('÷ 1160 × 0308 ÷ 0378 ÷');
Test_X('÷ 1160 ÷ D800 ÷');
Test_X('÷ 1160 × 0308 ÷ D800 ÷');
Test_X('÷ 11A8 ÷ 0020 ÷');
Test_X('÷ 11A8 × 0308 ÷ 0020 ÷');
Test_X('÷ 11A8 ÷ 000D ÷');
Test_X('÷ 11A8 × 0308 ÷ 000D ÷');
Test_X('÷ 11A8 ÷ 000A ÷');
Test_X('÷ 11A8 × 0308 ÷ 000A ÷');
Test_X('÷ 11A8 ÷ 0001 ÷');
Test_X('÷ 11A8 × 0308 ÷ 0001 ÷');
Test_X('÷ 11A8 × 0300 ÷');
Test_X('÷ 11A8 × 0308 × 0300 ÷');
Test_X('÷ 11A8 × 0903 ÷');
Test_X('÷ 11A8 × 0308 × 0903 ÷');
Test_X('÷ 11A8 ÷ 1100 ÷');
Test_X('÷ 11A8 × 0308 ÷ 1100 ÷');
Test_X('÷ 11A8 ÷ 1160 ÷');
Test_X('÷ 11A8 × 0308 ÷ 1160 ÷');
Test_X('÷ 11A8 × 11A8 ÷');
Test_X('÷ 11A8 × 0308 ÷ 11A8 ÷');
Test_X('÷ 11A8 ÷ AC00 ÷');
Test_X('÷ 11A8 × 0308 ÷ AC00 ÷');
Test_X('÷ 11A8 ÷ AC01 ÷');
Test_X('÷ 11A8 × 0308 ÷ AC01 ÷');
Test_X('÷ 11A8 ÷ 1F1E6 ÷');
Test_X('÷ 11A8 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 11A8 ÷ 0378 ÷');
Test_X('÷ 11A8 × 0308 ÷ 0378 ÷');
Test_X('÷ 11A8 ÷ D800 ÷');
Test_X('÷ 11A8 × 0308 ÷ D800 ÷');
Test_X('÷ AC00 ÷ 0020 ÷');
Test_X('÷ AC00 × 0308 ÷ 0020 ÷');
Test_X('÷ AC00 ÷ 000D ÷');
Test_X('÷ AC00 × 0308 ÷ 000D ÷');
Test_X('÷ AC00 ÷ 000A ÷');
Test_X('÷ AC00 × 0308 ÷ 000A ÷');
Test_X('÷ AC00 ÷ 0001 ÷');
Test_X('÷ AC00 × 0308 ÷ 0001 ÷');
Test_X('÷ AC00 × 0300 ÷');
Test_X('÷ AC00 × 0308 × 0300 ÷');
Test_X('÷ AC00 × 0903 ÷');
Test_X('÷ AC00 × 0308 × 0903 ÷');
Test_X('÷ AC00 ÷ 1100 ÷');
Test_X('÷ AC00 × 0308 ÷ 1100 ÷');
Test_X('÷ AC00 × 1160 ÷');
Test_X('÷ AC00 × 0308 ÷ 1160 ÷');
Test_X('÷ AC00 × 11A8 ÷');
Test_X('÷ AC00 × 0308 ÷ 11A8 ÷');
Test_X('÷ AC00 ÷ AC00 ÷');
Test_X('÷ AC00 × 0308 ÷ AC00 ÷');
Test_X('÷ AC00 ÷ AC01 ÷');
Test_X('÷ AC00 × 0308 ÷ AC01 ÷');
Test_X('÷ AC00 ÷ 1F1E6 ÷');
Test_X('÷ AC00 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ AC00 ÷ 0378 ÷');
Test_X('÷ AC00 × 0308 ÷ 0378 ÷');
Test_X('÷ AC00 ÷ D800 ÷');
Test_X('÷ AC00 × 0308 ÷ D800 ÷');
Test_X('÷ AC01 ÷ 0020 ÷');
Test_X('÷ AC01 × 0308 ÷ 0020 ÷');
Test_X('÷ AC01 ÷ 000D ÷');
Test_X('÷ AC01 × 0308 ÷ 000D ÷');
Test_X('÷ AC01 ÷ 000A ÷');
Test_X('÷ AC01 × 0308 ÷ 000A ÷');
Test_X('÷ AC01 ÷ 0001 ÷');
Test_X('÷ AC01 × 0308 ÷ 0001 ÷');
Test_X('÷ AC01 × 0300 ÷');
Test_X('÷ AC01 × 0308 × 0300 ÷');
Test_X('÷ AC01 × 0903 ÷');
Test_X('÷ AC01 × 0308 × 0903 ÷');
Test_X('÷ AC01 ÷ 1100 ÷');
Test_X('÷ AC01 × 0308 ÷ 1100 ÷');
Test_X('÷ AC01 ÷ 1160 ÷');
Test_X('÷ AC01 × 0308 ÷ 1160 ÷');
Test_X('÷ AC01 × 11A8 ÷');
Test_X('÷ AC01 × 0308 ÷ 11A8 ÷');
Test_X('÷ AC01 ÷ AC00 ÷');
Test_X('÷ AC01 × 0308 ÷ AC00 ÷');
Test_X('÷ AC01 ÷ AC01 ÷');
Test_X('÷ AC01 × 0308 ÷ AC01 ÷');
Test_X('÷ AC01 ÷ 1F1E6 ÷');
Test_X('÷ AC01 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ AC01 ÷ 0378 ÷');
Test_X('÷ AC01 × 0308 ÷ 0378 ÷');
Test_X('÷ AC01 ÷ D800 ÷');
Test_X('÷ AC01 × 0308 ÷ D800 ÷');
Test_X('÷ 1F1E6 ÷ 0020 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 0020 ÷');
Test_X('÷ 1F1E6 ÷ 000D ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 000D ÷');
Test_X('÷ 1F1E6 ÷ 000A ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 000A ÷');
Test_X('÷ 1F1E6 ÷ 0001 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 0001 ÷');
Test_X('÷ 1F1E6 × 0300 ÷');
Test_X('÷ 1F1E6 × 0308 × 0300 ÷');
Test_X('÷ 1F1E6 × 0903 ÷');
Test_X('÷ 1F1E6 × 0308 × 0903 ÷');
Test_X('÷ 1F1E6 ÷ 1100 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 1100 ÷');
Test_X('÷ 1F1E6 ÷ 1160 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 1160 ÷');
Test_X('÷ 1F1E6 ÷ 11A8 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 11A8 ÷');
Test_X('÷ 1F1E6 ÷ AC00 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ AC00 ÷');
Test_X('÷ 1F1E6 ÷ AC01 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ AC01 ÷');
Test_X('÷ 1F1E6 × 1F1E6 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 1F1E6 ÷ 0378 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ 0378 ÷');
Test_X('÷ 1F1E6 ÷ D800 ÷');
Test_X('÷ 1F1E6 × 0308 ÷ D800 ÷');
Test_X('÷ 0378 ÷ 0020 ÷');
Test_X('÷ 0378 × 0308 ÷ 0020 ÷');
Test_X('÷ 0378 ÷ 000D ÷');
Test_X('÷ 0378 × 0308 ÷ 000D ÷');
Test_X('÷ 0378 ÷ 000A ÷');
Test_X('÷ 0378 × 0308 ÷ 000A ÷');
Test_X('÷ 0378 ÷ 0001 ÷');
Test_X('÷ 0378 × 0308 ÷ 0001 ÷');
Test_X('÷ 0378 × 0300 ÷');
Test_X('÷ 0378 × 0308 × 0300 ÷');
Test_X('÷ 0378 × 0903 ÷');
Test_X('÷ 0378 × 0308 × 0903 ÷');
Test_X('÷ 0378 ÷ 1100 ÷');
Test_X('÷ 0378 × 0308 ÷ 1100 ÷');
Test_X('÷ 0378 ÷ 1160 ÷');
Test_X('÷ 0378 × 0308 ÷ 1160 ÷');
Test_X('÷ 0378 ÷ 11A8 ÷');
Test_X('÷ 0378 × 0308 ÷ 11A8 ÷');
Test_X('÷ 0378 ÷ AC00 ÷');
Test_X('÷ 0378 × 0308 ÷ AC00 ÷');
Test_X('÷ 0378 ÷ AC01 ÷');
Test_X('÷ 0378 × 0308 ÷ AC01 ÷');
Test_X('÷ 0378 ÷ 1F1E6 ÷');
Test_X('÷ 0378 × 0308 ÷ 1F1E6 ÷');
Test_X('÷ 0378 ÷ 0378 ÷');
Test_X('÷ 0378 × 0308 ÷ 0378 ÷');
Test_X('÷ 0378 ÷ D800 ÷');
Test_X('÷ 0378 × 0308 ÷ D800 ÷');
Test_X('÷ D800 ÷ 0020 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 0020 ÷');
Test_X('÷ D800 ÷ 000D ÷');
Test_X('÷ D800 ÷ 0308 ÷ 000D ÷');
Test_X('÷ D800 ÷ 000A ÷');
Test_X('÷ D800 ÷ 0308 ÷ 000A ÷');
Test_X('÷ D800 ÷ 0001 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 0001 ÷');
Test_X('÷ D800 ÷ 0300 ÷');
Test_X('÷ D800 ÷ 0308 × 0300 ÷');
Test_X('÷ D800 ÷ 0903 ÷');
Test_X('÷ D800 ÷ 0308 × 0903 ÷');
Test_X('÷ D800 ÷ 1100 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 1100 ÷');
Test_X('÷ D800 ÷ 1160 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 1160 ÷');
Test_X('÷ D800 ÷ 11A8 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 11A8 ÷');
Test_X('÷ D800 ÷ AC00 ÷');
Test_X('÷ D800 ÷ 0308 ÷ AC00 ÷');
Test_X('÷ D800 ÷ AC01 ÷');
Test_X('÷ D800 ÷ 0308 ÷ AC01 ÷');
Test_X('÷ D800 ÷ 1F1E6 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 1F1E6 ÷');
Test_X('÷ D800 ÷ 0378 ÷');
Test_X('÷ D800 ÷ 0308 ÷ 0378 ÷');
Test_X('÷ D800 ÷ D800 ÷');
Test_X('÷ D800 ÷ 0308 ÷ D800 ÷');
Test_X('÷ 0061 ÷ 1F1E6 ÷ 0062 ÷');
Test_X('÷ 1F1F7 × 1F1FA ÷');
Test_X('÷ 1F1F7 × 1F1FA × 1F1F8 ÷');
Test_X('÷ 1F1F7 × 1F1FA × 1F1F8 × 1F1EA ÷');
Test_X('÷ 1F1F7 × 1F1FA ÷ 200B ÷ 1F1F8 × 1F1EA ÷');
Test_X('÷ 1F1E6 × 1F1E7 × 1F1E8 ÷');
Test_X('÷ 1F1E6 × 200D ÷ 1F1E7 × 1F1E8 ÷');
Test_X('÷ 1F1E6 × 1F1E7 × 200D ÷ 1F1E8 ÷');
Test_X('÷ 0020 × 200D ÷ 0646 ÷');
Test_X('÷ 0646 × 200D ÷ 0020 ÷');
Finished();
